```@meta
EditURL = "BjordalsbakkeModel.jl"
```

# Importing the required packages

````julia
using CirculatorySystemModels
using CirculatorySystemModels.ModelingToolkit
using CirculatorySystemModels.DifferentialEquations
using Plots
````

# A simple single-chamber model

![Single chamber, closed-loop, lumped parameter model of the systemic circulation and the left ventricle. The circuit equivalent formulation of the model is depicted, with the pressures of each compartment, as well as most of the mechanical parameters. The model describes three compartments: the left ventricular, arterial and venous compartments. 𝑃𝑡ℎ is the intrathoracic pressure, 𝑃𝑙𝑣 is the left ventricular pressure and 𝐸𝑙𝑣(𝑡) indicates the left ventricular elastance function.](./BjordalsbakkeModelSketch.png)


This follows Bjørdalsbakke et al.

Bjørdalsbakke, N.L., Sturdy, J.T., Hose, D.R., Hellevik, L.R., 2022. Parameter estimation for closed-loop lumped parameter models of the systemic circulation using synthetic data. Mathematical Biosciences 343, 108731. https://doi.org/10.1016/j.mbs.2021.108731


Changes from the published version above:

- Capacitors are replaced by compliances. These are identical to capacitors, but have an additional parameter, the unstrained volume $V_0$, which allows for realistic blood volume modelling.
  Compliances have an inlet and an oulet in line with the flow, rather than the ground connector of the dangling capacitor.
- The aortic resistor is combined with the valve (diode) in the `ResistorDiode` element.

[Jupyter Notebook](./BjordalsbakkeModel.ipynb)

## Define the parameters

All the parameters are taken from table 1 of [Bjørdalsbakke2022].

Cycle time in seconds

````julia
τ = 0.85
````

````
0.85
````

Double Hill parameters for the ventricle

````julia
Eₘᵢₙ = 0.03
Eₘₐₓ = 1.5
n1LV    = 1.32;
n2LV    = 21.9;
Tau1fLV = 0.303 * τ;
Tau2fLV = 0.508 * τ
````

````
0.4318
````

Resistances and Compliances

````julia
Rs = 1.11
Csa = 1.13
Csv = 11.0
````

````
11.0
````

Valve parameters

Aortic valve basic

````julia
Zao = 0.033
````

````
0.033
````

Mitral valve basic

````julia
Rmv = 0.006
````

````
0.006
````

Inital Pressure (mean cardiac filling pressure)

````julia
MCFP = 7.0
````

````
7.0
````

## Calculating the additional `k` parameter

The ventricle elastance is modelled as:

$$E_{l v}(t)=\left(E_{\max }-E_{\min }\right) e(t)+E_{\min }$$

where $e$ is a double-Hill function, i.e., two Hill-functions, which are multiplied by each other:

$$e(\tau)= k \times \frac{\left(\tau / \tau_1\right)^{n_1}}{1+\left(\tau / \tau_1\right)^{n_1}} \times \frac{1}{1+\left(\tau / \tau_2\right)^{n_2}}$$

and $k$ is a scaling factor to assure that $e(t)$ has a maximum of $e(t)_{max} = 1$:

$$k = \max \left(\frac{\left(\tau / \tau_1\right)^{n_1}}{1+\left(\tau / \tau_1\right)^{n_1}} \times \frac{1}{1+\left(\tau / \tau_2\right)^{n_2}} \right)^{-1}$$

````julia
nstep = 1000
t = LinRange(0, τ, nstep)

kLV = 1 / maximum((t ./ Tau1fLV).^n1LV ./ (1 .+ (t ./ Tau1fLV).^n1LV) .* 1 ./ (1 .+ (t ./ Tau2fLV).^n2LV))
````

````
1.6721792928965973
````

## Set up the model elements

Set up time as a variable `t`

````julia
@variables t
````

````
1-element Vector{Num}:
 t
````

Heart is modelled as a single chamber (we call it `LV` for "Left Ventricle" so the model can be extended later, if required):

````julia
@named LV = DHChamber(V₀ = 0.0, Eₘₐₓ=Eₘₐₓ, Eₘᵢₙ=Eₘᵢₙ, n₁=n1LV, n₂=n2LV, τ = τ, τ₁=Tau1fLV, τ₂=Tau2fLV, k = kLV, Eshift=0.0, Ev=Inf)
````

````
Model LV with 4 (6) equations
States (6):
  V(t) [defaults to 2.0]
  p(t) [defaults to 0.0]
  in₊p(t) [defaults to 1.0]
  in₊q(t) [defaults to 1.0]
  out₊p(t) [defaults to 1.0]
  out₊q(t) [defaults to 1.0]
Parameters (11):
  V₀ [defaults to 0.0]
  Eₘᵢₙ [defaults to 0.03]
  Eₘₐₓ [defaults to 1.5]
  n₁ [defaults to 1.32]
  n₂ [defaults to 21.9]
  τ [defaults to 0.85]
  τ₁ [defaults to 0.25755]
  τ₂ [defaults to 0.4318]
  k [defaults to 1.67218]
  Eshift [defaults to 0.0]
  Ev [defaults to Inf]
````

The two valves are simple diodes with a small resistance
(resistance is needed, since perfect diodes would connect two elastances/compliances, which will lead to unstable oscillations):

````julia
@named AV = ResistorDiode(R=Zao)
@named MV = ResistorDiode(R=Rmv)
````

````
Model MV with 4 (6) equations
States (6):
  Δp(t) [defaults to 0.0]
  q(t) [defaults to 0.0]
  in₊p(t) [defaults to 1.0]
  in₊q(t) [defaults to 1.0]
  out₊p(t) [defaults to 1.0]
  out₊q(t) [defaults to 1.0]
Parameters (1):
  R [defaults to 0.006]
````

The main components of the circuit are 1 resistor `Rs` and two compliances for systemic arteries `Csa`,
and systemic veins `Csv` (names are arbitrary).

````julia
@named Rs = Resistor(R=Rs)

@named Csa = Compliance(C=Csa)
@named Csv = Compliance(C=Csv)
````

````
Model Csv with 4 (6) equations
States (6):
  V(t) [defaults to 0.0]
  p(t) [defaults to 0.0]
  in₊p(t) [defaults to 1.0]
  in₊q(t) [defaults to 1.0]
  out₊p(t) [defaults to 1.0]
  out₊q(t) [defaults to 1.0]
Parameters (2):
  V₀ [defaults to 0.0]
  C [defaults to 11.0]
````

We also need to define a base pressure level, which we use the `Ground` element for:

````julia
@named ground = Ground(P=0)
````

````
Model ground with 1 (2) equations
States (2):
  g₊p(t) [defaults to 1.0]
  g₊q(t) [defaults to 1.0]
Parameters (1):
  P [defaults to 0]
````

## Build the system

### Connections

The system is built using the `connect` function. `connect` sets up the Kirchhoff laws:

- pressures are the same in all connected branches on a connector
- sum of all flow rates at a connector is zero

The resulting set of Kirchhoff equations is stored in `circ_eqs`:

````julia
circ_eqs = [
    connect(LV.out, AV.in)
    connect(AV.out, Csa.in)
    connect(Csa.out, Rs.in)
    connect(Rs.out, Csv.in)
    connect(Csv.out, MV.in)
    connect(MV.out, LV.in)
]
````

````
6-element Vector{Equation}:
 connect(LV.out, AV.in)
 connect(AV.out, Csa.in)
 connect(Csa.out, Rs.in)
 connect(Rs.out, Csv.in)
 connect(Csv.out, MV.in)
 connect(MV.out, LV.in)
````

### Add the component equations

In a second step, the system of Kirchhoff equations is completed by the component equations (both ODEs and AEs), resulting in the full, overdefined ODE set `circ_model`.

_Note: we do this in two steps._

````julia
@named _circ_model = ODESystem(circ_eqs, t)

@named circ_model = compose(_circ_model,
                          [LV, AV, MV, Rs, Csa, Csv, ground])
````

````
Model circ_model with 25 (38) equations
States (38):
  LV₊V(t) [defaults to 2.0]
  LV₊p(t) [defaults to 0.0]
  LV₊in₊p(t) [defaults to 1.0]
  LV₊in₊q(t) [defaults to 1.0]
  LV₊out₊p(t) [defaults to 1.0]
  LV₊out₊q(t) [defaults to 1.0]
  AV₊Δp(t) [defaults to 0.0]
  AV₊q(t) [defaults to 0.0]
  AV₊in₊p(t) [defaults to 1.0]
  AV₊in₊q(t) [defaults to 1.0]
  AV₊out₊p(t) [defaults to 1.0]
  AV₊out₊q(t) [defaults to 1.0]
  MV₊Δp(t) [defaults to 0.0]
  MV₊q(t) [defaults to 0.0]
  MV₊in₊p(t) [defaults to 1.0]
  MV₊in₊q(t) [defaults to 1.0]
  MV₊out₊p(t) [defaults to 1.0]
  MV₊out₊q(t) [defaults to 1.0]
  Rs₊Δp(t) [defaults to 0.0]
  Rs₊q(t) [defaults to 0.0]
  Rs₊in₊p(t) [defaults to 1.0]
  Rs₊in₊q(t) [defaults to 1.0]
  Rs₊out₊p(t) [defaults to 1.0]
  Rs₊out₊q(t) [defaults to 1.0]
  Csa₊V(t) [defaults to 0.0]
  Csa₊p(t) [defaults to 0.0]
  Csa₊in₊p(t) [defaults to 1.0]
  Csa₊in₊q(t) [defaults to 1.0]
  Csa₊out₊p(t) [defaults to 1.0]
  Csa₊out₊q(t) [defaults to 1.0]
  Csv₊V(t) [defaults to 0.0]
  Csv₊p(t) [defaults to 0.0]
  Csv₊in₊p(t) [defaults to 1.0]
  Csv₊in₊q(t) [defaults to 1.0]
  Csv₊out₊p(t) [defaults to 1.0]
  Csv₊out₊q(t) [defaults to 1.0]
  ground₊g₊p(t) [defaults to 1.0]
  ground₊g₊q(t) [defaults to 1.0]
Parameters (19):
  LV₊V₀ [defaults to 0.0]
  LV₊Eₘᵢₙ [defaults to 0.03]
  LV₊Eₘₐₓ [defaults to 1.5]
  LV₊n₁ [defaults to 1.32]
  LV₊n₂ [defaults to 21.9]
  LV₊τ [defaults to 0.85]
  LV₊τ₁ [defaults to 0.25755]
  LV₊τ₂ [defaults to 0.4318]
  LV₊k [defaults to 1.67218]
  LV₊Eshift [defaults to 0.0]
  LV₊Ev [defaults to Inf]
  AV₊R [defaults to 0.033]
  MV₊R [defaults to 0.006]
  Rs₊R [defaults to 1.11]
  Csa₊V₀ [defaults to 0.0]
  Csa₊C [defaults to 1.13]
  Csv₊V₀ [defaults to 0.0]
  Csv₊C [defaults to 11.0]
  ground₊P [defaults to 0]
````

### Simplify the ODE system

The crucial step in any acausal modelling is the sympification and reduction of the OD(A)E system to the minimal set of equations. ModelingToolkit.jl does this in the `structural_simplify` function.

````julia
circ_sys = structural_simplify(circ_model)
````

````
Model circ_model with 3 equations
States (3):
  LV₊p(t) [defaults to 0.0]
  Csa₊p(t) [defaults to 0.0]
  Csv₊p(t) [defaults to 0.0]
Parameters (19):
  LV₊V₀ [defaults to 0.0]
  LV₊Eₘᵢₙ [defaults to 0.03]
  LV₊Eₘₐₓ [defaults to 1.5]
  LV₊n₁ [defaults to 1.32]
  LV₊n₂ [defaults to 21.9]
  LV₊τ [defaults to 0.85]
  LV₊τ₁ [defaults to 0.25755]
  LV₊τ₂ [defaults to 0.4318]
  LV₊k [defaults to 1.67218]
  LV₊Eshift [defaults to 0.0]
  LV₊Ev [defaults to Inf]
  AV₊R [defaults to 0.033]
  MV₊R [defaults to 0.006]
  Rs₊R [defaults to 1.11]
  Csa₊V₀ [defaults to 0.0]
  Csa₊C [defaults to 1.13]
  Csv₊V₀ [defaults to 0.0]
  Csv₊C [defaults to 11.0]
  ground₊P [defaults to 0]
Incidence matrix:3×6 SparseArrays.SparseMatrixCSC{Num, Int64} with 12 stored entries:
 ×  ×  ×  ×  ⋅  ⋅
 ×  ×  ×  ⋅  ×  ⋅
 ×  ×  ×  ⋅  ⋅  ×
````

`circ_sys` is now the minimal system of equations. In this case it consists of 3 ODEs for the three pressures.

_Note: this reduces and optimises the ODE system. It is, therefore, not always obvious, which states it will use and which it will drop. We can use the `states` and `observed` function to check this. It is recommended to do this, since small changes can reorder states, observables, and parameters._

States in the system are now:

````julia
states(circ_sys)
````

````
3-element Vector{Any}:
 LV₊p(t)
 Csa₊p(t)
 Csv₊p(t)
````

Observed variables - the system will drop these from the ODE system that is solved, but it keeps all the algebraic equations needed to calculate them in the system object, as well as the `ODEProblem` and solution object - are:

````julia
observed(circ_sys)
````

````
35-element Vector{Equation}:
 LV₊in₊p(t) ~ LV₊p(t)
 LV₊V(t) ~ LV₊V₀ + LV₊p(t) / (LV₊Eₘᵢₙ + (LV₊k*(LV₊Eₘₐₓ - LV₊Eₘᵢₙ)*((rem(t + LV₊τ*(1 - LV₊Eshift), LV₊τ) / LV₊τ₁)^LV₊n₁)) / ((1 + (rem(t + LV₊τ*(1 - LV₊Eshift), LV₊τ) / LV₊τ₁)^LV₊n₁)*(1 + (rem(t + LV₊τ*(1 - LV₊Eshift), LV₊τ) / LV₊τ₂)^LV₊n₂)))
 MV₊Δp(t) ~ LV₊p(t) - Csv₊p(t)
 AV₊Δp(t) ~ Csa₊p(t) - LV₊p(t)
 Rs₊Δp(t) ~ Csv₊p(t) - Csa₊p(t)
 Csa₊in₊p(t) ~ Csa₊p(t)
 Csa₊V(t) ~ Csa₊V₀ + Csa₊C*Csa₊p(t)
 Csv₊in₊p(t) ~ Csv₊p(t)
 Csv₊V(t) ~ Csv₊V₀ + Csv₊C*Csv₊p(t)
 ground₊g₊p(t) ~ ground₊P
 ground₊g₊q(t) ~ -0.0
 AV₊in₊p(t) ~ LV₊in₊p(t)
 MV₊out₊p(t) ~ LV₊in₊p(t)
 MV₊q(t) ~ (-MV₊Δp(t)*(MV₊Δp(t) < 0)) / MV₊R
 AV₊q(t) ~ (-AV₊Δp(t)*(AV₊Δp(t) < 0)) / AV₊R
 Rs₊q(t) ~ (-Rs₊Δp(t)) / Rs₊R
 Csa₊out₊p(t) ~ Csa₊in₊p(t)
 AV₊out₊p(t) ~ Csa₊in₊p(t)
 Rs₊in₊p(t) ~ Csa₊in₊p(t)
 Csv₊out₊p(t) ~ Csv₊in₊p(t)
 Rs₊out₊p(t) ~ Csv₊in₊p(t)
 MV₊in₊p(t) ~ Csv₊in₊p(t)
 LV₊out₊p(t) ~ AV₊in₊p(t)
 Csv₊out₊q(t) ~ -MV₊q(t)
 MV₊out₊q(t) ~ -MV₊q(t)
 LV₊out₊q(t) ~ -AV₊q(t)
 AV₊out₊q(t) ~ -AV₊q(t)
 Csa₊in₊q(t) ~ AV₊q(t)
 Rs₊out₊q(t) ~ -Rs₊q(t)
 Csa₊out₊q(t) ~ -Rs₊q(t)
 LV₊in₊q(t) ~ -Csv₊out₊q(t)
 MV₊in₊q(t) ~ -MV₊out₊q(t)
 AV₊in₊q(t) ~ -AV₊out₊q(t)
 Rs₊in₊q(t) ~ -Rs₊out₊q(t)
 Csv₊in₊q(t) ~ -Csa₊out₊q(t)
````

And the parameters (these could be reordered, so check these, too):

````julia
parameters(circ_sys)
````

````
19-element Vector{SymbolicUtils.BasicSymbolic{Real}}:
 LV₊V₀
 LV₊Eₘᵢₙ
 LV₊Eₘₐₓ
 LV₊n₁
 LV₊n₂
 LV₊τ
 LV₊τ₁
 LV₊τ₂
 LV₊k
 LV₊Eshift
 LV₊Ev
 AV₊R
 MV₊R
 Rs₊R
 Csa₊V₀
 Csa₊C
 Csv₊V₀
 Csv₊C
 ground₊P
````

### Define the ODE problem

First defined initial conditions `u0` and the time span for simulation:

_Note: the initial conditions are defined as a parameter map, rather than a vector, since the parameter map allows for changes in order._

````julia
u0 = [
        LV.p => MCFP
        Csa.p => MCFP
        Csv.p => MCFP
        ]
````

````
3-element Vector{Pair{Num, Float64}}:
  LV₊p(t) => 7.0
 Csa₊p(t) => 7.0
 Csv₊p(t) => 7.0
````

````julia
tspan = (0, 20)
````

````
(0, 20)
````

in this case we use the mean cardiac filling pressure as initial condition, and simulate 20 seconds.

Then we can define the problem:

````julia
prob = ODEProblem(circ_sys, u0, tspan)
````

````
ODEProblem with uType Vector{Float64} and tType Int64. In-place: true
timespan: (0, 20)
u0: 3-element Vector{Float64}:
 7.0
 7.0
 7.0
````

## Simulate

The ODE problem is now in the MTK/DifferentialEquations.jl format and we can use any DifferentialEquations.jl solver to solve it:

````julia
sol = solve(prob, Vern7(), reltol=1e-12, abstol=1e-12);
````

## Results

````julia
p1 = plot(sol, idxs=[LV.p,  Csa.in.p], tspan=(16 * τ, 17 * τ), xlabel = "Time [s]", ylabel = "Pressure [mmHg]",  hidexaxis = nothing) # Make a line plot
p2 = plot(sol, idxs=[LV.V], tspan=(16 * τ, 17 * τ),xlabel = "Time [s]", ylabel = "Volume [ml]",  linkaxes = :all)
p3 = plot(sol, idxs=[Csa.in.q,Csv.in.q], tspan=(16 * τ, 17 * τ),xlabel = "Time [s]", ylabel = "Flow rate [ml/s]", linkaxes = :all)
p4 = plot(sol, idxs=(LV.V, LV.p), tspan=(16 * τ, 17 * τ),xlabel = "Volume [ml]", ylabel = "Pressure [mmHg]", linkaxes = :all)

plot(p1, p2, p3, p4; layout=@layout([a b; c d]), legend = true)
````

```@raw html
<?xml version="1.0" encoding="utf-8"?>
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="600" height="400" viewBox="0 0 2400 1600">
<defs>
  <clipPath id="clip400">
    <rect x="0" y="0" width="2400" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip400)" d="M0 1600 L2400 1600 L2400 0 L0 0  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip401">
    <rect x="480" y="0" width="1681" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip400)" d="M235.283 623.18 L1154.2 623.18 L1154.2 47.2441 L235.283 47.2441  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip402">
    <rect x="235" y="47" width="920" height="577"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip402)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="235.283,623.18 235.283,47.2441 "/>
<polyline clip-path="url(#clip402)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="451.499,623.18 451.499,47.2441 "/>
<polyline clip-path="url(#clip402)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="667.716,623.18 667.716,47.2441 "/>
<polyline clip-path="url(#clip402)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="883.932,623.18 883.932,47.2441 "/>
<polyline clip-path="url(#clip402)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1100.15,623.18 1100.15,47.2441 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,623.18 1154.2,623.18 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,623.18 235.283,604.282 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="451.499,623.18 451.499,604.282 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="667.716,623.18 667.716,604.282 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="883.932,623.18 883.932,604.282 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1100.15,623.18 1100.15,604.282 "/>
<path clip-path="url(#clip400)" d="M187.274 681.645 L194.913 681.645 L194.913 655.279 L186.603 656.946 L186.603 652.687 L194.866 651.02 L199.542 651.02 L199.542 681.645 L207.181 681.645 L207.181 685.58 L187.274 685.58 L187.274 681.645 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M230.792 666.946 Q234.149 667.663 236.024 669.932 Q237.922 672.2 237.922 675.534 Q237.922 680.649 234.403 683.45 Q230.885 686.251 224.403 686.251 Q222.227 686.251 219.913 685.811 Q217.621 685.395 215.167 684.538 L215.167 680.024 Q217.112 681.159 219.426 681.737 Q221.741 682.316 224.264 682.316 Q228.663 682.316 230.954 680.58 Q233.269 678.844 233.269 675.534 Q233.269 672.478 231.116 670.765 Q228.987 669.029 225.167 669.029 L221.139 669.029 L221.139 665.186 L225.352 665.186 Q228.801 665.186 230.63 663.821 Q232.459 662.432 232.459 659.839 Q232.459 657.177 230.561 655.765 Q228.686 654.33 225.167 654.33 Q223.246 654.33 221.047 654.747 Q218.848 655.163 216.209 656.043 L216.209 651.876 Q218.871 651.136 221.186 650.765 Q223.524 650.395 225.584 650.395 Q230.908 650.395 234.01 652.825 Q237.112 655.233 237.112 659.353 Q237.112 662.223 235.468 664.214 Q233.825 666.182 230.792 666.946 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M246.787 679.7 L251.672 679.7 L251.672 685.58 L246.787 685.58 L246.787 679.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M272.435 666.436 Q269.287 666.436 267.435 668.589 Q265.607 670.742 265.607 674.492 Q265.607 678.219 267.435 680.395 Q269.287 682.547 272.435 682.547 Q275.584 682.547 277.412 680.395 Q279.264 678.219 279.264 674.492 Q279.264 670.742 277.412 668.589 Q275.584 666.436 272.435 666.436 M281.718 651.784 L281.718 656.043 Q279.959 655.21 278.153 654.77 Q276.371 654.33 274.611 654.33 Q269.982 654.33 267.528 657.455 Q265.098 660.58 264.75 666.899 Q266.116 664.886 268.176 663.821 Q270.236 662.733 272.713 662.733 Q277.922 662.733 280.931 665.904 Q283.963 669.052 283.963 674.492 Q283.963 679.816 280.815 683.034 Q277.667 686.251 272.435 686.251 Q266.44 686.251 263.269 681.668 Q260.098 677.061 260.098 668.335 Q260.098 660.14 263.986 655.279 Q267.875 650.395 274.426 650.395 Q276.185 650.395 277.968 650.742 Q279.773 651.089 281.718 651.784 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M403.618 681.645 L411.256 681.645 L411.256 655.279 L402.946 656.946 L402.946 652.687 L411.21 651.02 L415.886 651.02 L415.886 681.645 L423.525 681.645 L423.525 685.58 L403.618 685.58 L403.618 681.645 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M447.136 666.946 Q450.492 667.663 452.367 669.932 Q454.265 672.2 454.265 675.534 Q454.265 680.649 450.747 683.45 Q447.228 686.251 440.747 686.251 Q438.571 686.251 436.256 685.811 Q433.965 685.395 431.511 684.538 L431.511 680.024 Q433.455 681.159 435.77 681.737 Q438.085 682.316 440.608 682.316 Q445.006 682.316 447.298 680.58 Q449.613 678.844 449.613 675.534 Q449.613 672.478 447.46 670.765 Q445.33 669.029 441.511 669.029 L437.483 669.029 L437.483 665.186 L441.696 665.186 Q445.145 665.186 446.974 663.821 Q448.803 662.432 448.803 659.839 Q448.803 657.177 446.904 655.765 Q445.029 654.33 441.511 654.33 Q439.59 654.33 437.391 654.747 Q435.191 655.163 432.553 656.043 L432.553 651.876 Q435.215 651.136 437.529 650.765 Q439.867 650.395 441.928 650.395 Q447.252 650.395 450.353 652.825 Q453.455 655.233 453.455 659.353 Q453.455 662.223 451.812 664.214 Q450.168 666.182 447.136 666.946 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M463.131 679.7 L468.015 679.7 L468.015 685.58 L463.131 685.58 L463.131 679.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M488.2 669.168 Q484.867 669.168 482.946 670.95 Q481.048 672.733 481.048 675.858 Q481.048 678.983 482.946 680.765 Q484.867 682.547 488.2 682.547 Q491.534 682.547 493.455 680.765 Q495.376 678.96 495.376 675.858 Q495.376 672.733 493.455 670.95 Q491.557 669.168 488.2 669.168 M483.525 667.177 Q480.515 666.436 478.826 664.376 Q477.159 662.316 477.159 659.353 Q477.159 655.21 480.099 652.802 Q483.062 650.395 488.2 650.395 Q493.362 650.395 496.302 652.802 Q499.242 655.21 499.242 659.353 Q499.242 662.316 497.552 664.376 Q495.886 666.436 492.9 667.177 Q496.279 667.964 498.154 670.256 Q500.052 672.548 500.052 675.858 Q500.052 680.881 496.974 683.566 Q493.918 686.251 488.2 686.251 Q482.483 686.251 479.404 683.566 Q476.349 680.881 476.349 675.858 Q476.349 672.548 478.247 670.256 Q480.145 667.964 483.525 667.177 M481.812 659.793 Q481.812 662.478 483.478 663.983 Q485.168 665.487 488.2 665.487 Q491.21 665.487 492.9 663.983 Q494.612 662.478 494.612 659.793 Q494.612 657.108 492.9 655.603 Q491.21 654.099 488.2 654.099 Q485.168 654.099 483.478 655.603 Q481.812 657.108 481.812 659.793 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M619.788 681.645 L627.427 681.645 L627.427 655.279 L619.116 656.946 L619.116 652.687 L627.38 651.02 L632.056 651.02 L632.056 681.645 L639.695 681.645 L639.695 685.58 L619.788 685.58 L619.788 681.645 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M661.987 655.094 L650.181 673.543 L661.987 673.543 L661.987 655.094 M660.76 651.02 L666.639 651.02 L666.639 673.543 L671.57 673.543 L671.57 677.432 L666.639 677.432 L666.639 685.58 L661.987 685.58 L661.987 677.432 L646.385 677.432 L646.385 672.918 L660.76 651.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M679.301 679.7 L684.186 679.7 L684.186 685.58 L679.301 685.58 L679.301 679.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M704.371 654.099 Q700.76 654.099 698.931 657.663 Q697.125 661.205 697.125 668.335 Q697.125 675.441 698.931 679.006 Q700.76 682.547 704.371 682.547 Q708.005 682.547 709.81 679.006 Q711.639 675.441 711.639 668.335 Q711.639 661.205 709.81 657.663 Q708.005 654.099 704.371 654.099 M704.371 650.395 Q710.181 650.395 713.236 655.001 Q716.315 659.585 716.315 668.335 Q716.315 677.061 713.236 681.668 Q710.181 686.251 704.371 686.251 Q698.56 686.251 695.482 681.668 Q692.426 677.061 692.426 668.335 Q692.426 659.585 695.482 655.001 Q698.56 650.395 704.371 650.395 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M836.803 681.645 L844.442 681.645 L844.442 655.279 L836.131 656.946 L836.131 652.687 L844.395 651.02 L849.071 651.02 L849.071 681.645 L856.71 681.645 L856.71 685.58 L836.803 685.58 L836.803 681.645 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M879.002 655.094 L867.196 673.543 L879.002 673.543 L879.002 655.094 M877.775 651.02 L883.654 651.02 L883.654 673.543 L888.585 673.543 L888.585 677.432 L883.654 677.432 L883.654 685.58 L879.002 685.58 L879.002 677.432 L863.4 677.432 L863.4 672.918 L877.775 651.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M896.316 679.7 L901.201 679.7 L901.201 685.58 L896.316 685.58 L896.316 679.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M915.413 681.645 L931.733 681.645 L931.733 685.58 L909.788 685.58 L909.788 681.645 Q912.45 678.89 917.034 674.26 Q921.64 669.608 922.821 668.265 Q925.066 665.742 925.946 664.006 Q926.849 662.247 926.849 660.557 Q926.849 657.802 924.904 656.066 Q922.983 654.33 919.881 654.33 Q917.682 654.33 915.228 655.094 Q912.798 655.858 910.02 657.409 L910.02 652.687 Q912.844 651.552 915.298 650.974 Q917.751 650.395 919.788 650.395 Q925.159 650.395 928.353 653.08 Q931.548 655.765 931.548 660.256 Q931.548 662.386 930.737 664.307 Q929.95 666.205 927.844 668.798 Q927.265 669.469 924.163 672.686 Q921.062 675.881 915.413 681.645 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1051.98 681.645 L1059.62 681.645 L1059.62 655.279 L1051.31 656.946 L1051.31 652.687 L1059.57 651.02 L1064.25 651.02 L1064.25 681.645 L1071.88 681.645 L1071.88 685.58 L1051.98 685.58 L1051.98 681.645 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1094.18 655.094 L1082.37 673.543 L1094.18 673.543 L1094.18 655.094 M1092.95 651.02 L1098.83 651.02 L1098.83 673.543 L1103.76 673.543 L1103.76 677.432 L1098.83 677.432 L1098.83 685.58 L1094.18 685.58 L1094.18 677.432 L1078.57 677.432 L1078.57 672.918 L1092.95 651.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1111.49 679.7 L1116.38 679.7 L1116.38 685.58 L1111.49 685.58 L1111.49 679.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1139.41 655.094 L1127.6 673.543 L1139.41 673.543 L1139.41 655.094 M1138.18 651.02 L1144.06 651.02 L1144.06 673.543 L1148.99 673.543 L1148.99 677.432 L1144.06 677.432 L1144.06 685.58 L1139.41 685.58 L1139.41 677.432 L1123.81 677.432 L1123.81 672.918 L1138.18 651.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M564.914 720.524 L605.114 720.524 L605.114 725.935 L588.244 725.935 L588.244 768.044 L581.783 768.044 L581.783 725.935 L564.914 725.935 L564.914 720.524 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M609.06 732.396 L614.917 732.396 L614.917 768.044 L609.06 768.044 L609.06 732.396 M609.06 718.519 L614.917 718.519 L614.917 725.935 L609.06 725.935 L609.06 718.519 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M654.925 739.239 Q657.121 735.292 660.177 733.414 Q663.233 731.537 667.37 731.537 Q672.94 731.537 675.964 735.451 Q678.988 739.335 678.988 746.528 L678.988 768.044 L673.099 768.044 L673.099 746.719 Q673.099 741.594 671.285 739.112 Q669.471 736.629 665.747 736.629 Q661.195 736.629 658.554 739.653 Q655.912 742.677 655.912 747.896 L655.912 768.044 L650.024 768.044 L650.024 746.719 Q650.024 741.563 648.209 739.112 Q646.395 736.629 642.608 736.629 Q638.12 736.629 635.478 739.685 Q632.836 742.708 632.836 747.896 L632.836 768.044 L626.948 768.044 L626.948 732.396 L632.836 732.396 L632.836 737.934 Q634.841 734.656 637.642 733.096 Q640.443 731.537 644.295 731.537 Q648.178 731.537 650.883 733.51 Q653.62 735.483 654.925 739.239 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M721.16 748.756 L721.16 751.62 L694.233 751.62 Q694.615 757.668 697.862 760.851 Q701.14 764.002 706.965 764.002 Q710.339 764.002 713.49 763.174 Q716.673 762.347 719.792 760.691 L719.792 766.23 Q716.641 767.566 713.331 768.267 Q710.02 768.967 706.615 768.967 Q698.085 768.967 693.088 764.002 Q688.122 759.036 688.122 750.57 Q688.122 741.817 692.833 736.693 Q697.575 731.537 705.596 731.537 Q712.79 731.537 716.959 736.183 Q721.16 740.799 721.16 748.756 M715.304 747.037 Q715.24 742.231 712.599 739.366 Q709.989 736.502 705.66 736.502 Q700.758 736.502 697.798 739.271 Q694.87 742.04 694.424 747.069 L715.304 747.037 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M750.952 718.519 L764.447 718.519 L764.447 723.07 L756.808 723.07 L756.808 772.086 L764.447 772.086 L764.447 776.638 L750.952 776.638 L750.952 718.519 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M799.65 733.446 L799.65 738.984 Q797.167 737.711 794.493 737.075 Q791.82 736.438 788.955 736.438 Q784.595 736.438 782.399 737.775 Q780.234 739.112 780.234 741.785 Q780.234 743.822 781.794 745 Q783.353 746.146 788.064 747.196 L790.069 747.642 Q796.308 748.979 798.918 751.429 Q801.559 753.848 801.559 758.209 Q801.559 763.174 797.613 766.07 Q793.698 768.967 786.823 768.967 Q783.958 768.967 780.839 768.394 Q777.752 767.853 774.314 766.739 L774.314 760.691 Q777.561 762.378 780.712 763.238 Q783.863 764.065 786.95 764.065 Q791.088 764.065 793.316 762.665 Q795.544 761.233 795.544 758.654 Q795.544 756.267 793.92 754.994 Q792.329 753.721 786.886 752.543 L784.849 752.066 Q779.407 750.92 776.988 748.565 Q774.569 746.178 774.569 742.04 Q774.569 737.011 778.134 734.274 Q781.698 731.537 788.255 731.537 Q791.501 731.537 794.366 732.014 Q797.231 732.491 799.65 733.446 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M824.571 718.519 L824.571 776.638 L811.076 776.638 L811.076 772.086 L818.683 772.086 L818.683 723.07 L811.076 723.07 L811.076 718.519 L824.571 718.519 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip402)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="235.283,517.067 1154.2,517.067 "/>
<polyline clip-path="url(#clip402)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="235.283,409.672 1154.2,409.672 "/>
<polyline clip-path="url(#clip402)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="235.283,302.277 1154.2,302.277 "/>
<polyline clip-path="url(#clip402)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="235.283,194.881 1154.2,194.881 "/>
<polyline clip-path="url(#clip402)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="235.283,87.4857 1154.2,87.4857 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,623.18 235.283,47.2441 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,517.067 254.18,517.067 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,409.672 254.18,409.672 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,302.277 254.18,302.277 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,194.881 254.18,194.881 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,87.4857 254.18,87.4857 "/>
<path clip-path="url(#clip400)" d="M152.2 530.412 L168.519 530.412 L168.519 534.347 L146.575 534.347 L146.575 530.412 Q149.237 527.658 153.82 523.028 Q158.427 518.375 159.607 517.033 Q161.852 514.51 162.732 512.773 Q163.635 511.014 163.635 509.324 Q163.635 506.57 161.69 504.834 Q159.769 503.098 156.667 503.098 Q154.468 503.098 152.015 503.861 Q149.584 504.625 146.806 506.176 L146.806 501.454 Q149.63 500.32 152.084 499.741 Q154.538 499.162 156.575 499.162 Q161.945 499.162 165.14 501.848 Q168.334 504.533 168.334 509.023 Q168.334 511.153 167.524 513.074 Q166.737 514.973 164.63 517.565 Q164.052 518.236 160.95 521.454 Q157.848 524.648 152.2 530.412 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M178.38 499.787 L196.737 499.787 L196.737 503.723 L182.663 503.723 L182.663 512.195 Q183.681 511.848 184.7 511.685 Q185.718 511.5 186.737 511.5 Q192.524 511.5 195.903 514.672 Q199.283 517.843 199.283 523.26 Q199.283 528.838 195.811 531.94 Q192.338 535.019 186.019 535.019 Q183.843 535.019 181.575 534.648 Q179.329 534.278 176.922 533.537 L176.922 528.838 Q179.005 529.972 181.227 530.528 Q183.45 531.084 185.926 531.084 Q189.931 531.084 192.269 528.977 Q194.607 526.871 194.607 523.26 Q194.607 519.648 192.269 517.542 Q189.931 515.435 185.926 515.435 Q184.051 515.435 182.176 515.852 Q180.325 516.269 178.38 517.148 L178.38 499.787 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M147.223 392.392 L165.579 392.392 L165.579 396.327 L151.505 396.327 L151.505 404.799 Q152.524 404.452 153.542 404.29 Q154.561 404.105 155.579 404.105 Q161.366 404.105 164.746 407.276 Q168.126 410.447 168.126 415.864 Q168.126 421.443 164.653 424.545 Q161.181 427.623 154.862 427.623 Q152.686 427.623 150.417 427.253 Q148.172 426.883 145.765 426.142 L145.765 421.443 Q147.848 422.577 150.07 423.133 Q152.292 423.688 154.769 423.688 Q158.774 423.688 161.112 421.582 Q163.45 419.475 163.45 415.864 Q163.45 412.253 161.112 410.147 Q158.774 408.04 154.769 408.04 Q152.894 408.04 151.019 408.457 Q149.167 408.873 147.223 409.753 L147.223 392.392 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M187.338 395.471 Q183.727 395.471 181.899 399.035 Q180.093 402.577 180.093 409.707 Q180.093 416.813 181.899 420.378 Q183.727 423.92 187.338 423.92 Q190.973 423.92 192.778 420.378 Q194.607 416.813 194.607 409.707 Q194.607 402.577 192.778 399.035 Q190.973 395.471 187.338 395.471 M187.338 391.767 Q193.149 391.767 196.204 396.373 Q199.283 400.957 199.283 409.707 Q199.283 418.434 196.204 423.04 Q193.149 427.623 187.338 427.623 Q181.528 427.623 178.45 423.04 Q175.394 418.434 175.394 409.707 Q175.394 400.957 178.45 396.373 Q181.528 391.767 187.338 391.767 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M146.991 284.997 L169.214 284.997 L169.214 286.987 L156.667 319.557 L151.783 319.557 L163.589 288.932 L146.991 288.932 L146.991 284.997 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M178.38 284.997 L196.737 284.997 L196.737 288.932 L182.663 288.932 L182.663 297.404 Q183.681 297.057 184.7 296.895 Q185.718 296.709 186.737 296.709 Q192.524 296.709 195.903 299.881 Q199.283 303.052 199.283 308.469 Q199.283 314.047 195.811 317.149 Q192.338 320.228 186.019 320.228 Q183.843 320.228 181.575 319.858 Q179.329 319.487 176.922 318.746 L176.922 314.047 Q179.005 315.182 181.227 315.737 Q183.45 316.293 185.926 316.293 Q189.931 316.293 192.269 314.186 Q194.607 312.08 194.607 308.469 Q194.607 304.858 192.269 302.751 Q189.931 300.645 185.926 300.645 Q184.051 300.645 182.176 301.061 Q180.325 301.478 178.38 302.358 L178.38 284.997 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M117.825 208.226 L125.464 208.226 L125.464 181.86 L117.154 183.527 L117.154 179.268 L125.418 177.601 L130.093 177.601 L130.093 208.226 L137.732 208.226 L137.732 212.161 L117.825 212.161 L117.825 208.226 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M157.177 180.68 Q153.566 180.68 151.737 184.245 Q149.931 187.786 149.931 194.916 Q149.931 202.022 151.737 205.587 Q153.566 209.129 157.177 209.129 Q160.811 209.129 162.616 205.587 Q164.445 202.022 164.445 194.916 Q164.445 187.786 162.616 184.245 Q160.811 180.68 157.177 180.68 M157.177 176.976 Q162.987 176.976 166.042 181.583 Q169.121 186.166 169.121 194.916 Q169.121 203.643 166.042 208.249 Q162.987 212.832 157.177 212.832 Q151.366 212.832 148.288 208.249 Q145.232 203.643 145.232 194.916 Q145.232 186.166 148.288 181.583 Q151.366 176.976 157.177 176.976 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M187.338 180.68 Q183.727 180.68 181.899 184.245 Q180.093 187.786 180.093 194.916 Q180.093 202.022 181.899 205.587 Q183.727 209.129 187.338 209.129 Q190.973 209.129 192.778 205.587 Q194.607 202.022 194.607 194.916 Q194.607 187.786 192.778 184.245 Q190.973 180.68 187.338 180.68 M187.338 176.976 Q193.149 176.976 196.204 181.583 Q199.283 186.166 199.283 194.916 Q199.283 203.643 196.204 208.249 Q193.149 212.832 187.338 212.832 Q181.528 212.832 178.45 208.249 Q175.394 203.643 175.394 194.916 Q175.394 186.166 178.45 181.583 Q181.528 176.976 187.338 176.976 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M118.82 100.831 L126.459 100.831 L126.459 74.465 L118.149 76.1316 L118.149 71.8724 L126.413 70.2057 L131.089 70.2057 L131.089 100.831 L138.728 100.831 L138.728 104.766 L118.82 104.766 L118.82 100.831 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M152.2 100.831 L168.519 100.831 L168.519 104.766 L146.575 104.766 L146.575 100.831 Q149.237 98.076 153.82 93.4464 Q158.427 88.7936 159.607 87.451 Q161.852 84.9279 162.732 83.1918 Q163.635 81.4325 163.635 79.7427 Q163.635 76.9881 161.69 75.252 Q159.769 73.5159 156.667 73.5159 Q154.468 73.5159 152.015 74.2798 Q149.584 75.0437 146.806 76.5946 L146.806 71.8724 Q149.63 70.7382 152.084 70.1595 Q154.538 69.5807 156.575 69.5807 Q161.945 69.5807 165.14 72.2659 Q168.334 74.9511 168.334 79.4418 Q168.334 81.5714 167.524 83.4927 Q166.737 85.3909 164.63 87.9834 Q164.052 88.6547 160.95 91.8723 Q157.848 95.0667 152.2 100.831 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M178.38 70.2057 L196.737 70.2057 L196.737 74.1409 L182.663 74.1409 L182.663 82.6131 Q183.681 82.2659 184.7 82.1038 Q185.718 81.9186 186.737 81.9186 Q192.524 81.9186 195.903 85.0899 Q199.283 88.2612 199.283 93.6778 Q199.283 99.2565 195.811 102.358 Q192.338 105.437 186.019 105.437 Q183.843 105.437 181.575 105.067 Q179.329 104.696 176.922 103.956 L176.922 99.2565 Q179.005 100.391 181.227 100.946 Q183.45 101.502 185.926 101.502 Q189.931 101.502 192.269 99.3954 Q194.607 97.2889 194.607 93.6778 Q194.607 90.0668 192.269 87.9603 Q189.931 85.8538 185.926 85.8538 Q184.051 85.8538 182.176 86.2705 Q180.325 86.6871 178.38 87.5668 L178.38 70.2057 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M24.6612 606.439 L42.517 606.439 L42.517 598.354 Q42.517 593.867 40.1935 591.416 Q37.87 588.965 33.5732 588.965 Q29.3082 588.965 26.9847 591.416 Q24.6612 593.867 24.6612 598.354 L24.6612 606.439 M19.3777 612.868 L19.3777 598.354 Q19.3777 590.365 23.0061 586.291 Q26.6027 582.185 33.5732 582.185 Q40.6073 582.185 44.2039 586.291 Q47.8005 590.365 47.8005 598.354 L47.8005 606.439 L66.8977 606.439 L66.8977 612.868 L19.3777 612.868 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M36.7242 554.304 Q36.1513 555.29 35.8967 556.468 Q35.6102 557.614 35.6102 559.014 Q35.6102 563.98 38.8567 566.653 Q42.0714 569.295 48.1188 569.295 L66.8977 569.295 L66.8977 575.183 L31.2497 575.183 L31.2497 569.295 L36.7879 569.295 Q33.5414 567.449 31.9818 564.489 Q30.3903 561.529 30.3903 557.296 Q30.3903 556.691 30.4858 555.959 Q30.5495 555.227 30.7086 554.336 L36.7242 554.304 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M47.6096 519.101 L50.4741 519.101 L50.4741 546.028 Q56.5216 545.646 59.7044 542.4 Q62.8554 539.121 62.8554 533.297 Q62.8554 529.923 62.0279 526.772 Q61.2004 523.589 59.5453 520.47 L65.0834 520.47 Q66.4202 523.621 67.1205 526.931 Q67.8207 530.241 67.8207 533.647 Q67.8207 542.177 62.8554 547.174 Q57.8902 552.139 49.4238 552.139 Q40.6709 552.139 35.5466 547.429 Q30.3903 542.686 30.3903 534.665 Q30.3903 527.472 35.0373 523.303 Q39.6524 519.101 47.6096 519.101 M45.8908 524.958 Q41.0847 525.021 38.2202 527.663 Q35.3556 530.273 35.3556 534.602 Q35.3556 539.503 38.1247 542.463 Q40.8937 545.392 45.9227 545.837 L45.8908 524.958 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M32.3 486.764 L37.8382 486.764 Q36.5651 489.246 35.9285 491.92 Q35.2919 494.593 35.2919 497.458 Q35.2919 501.818 36.6287 504.015 Q37.9655 506.179 40.6391 506.179 Q42.6761 506.179 43.8538 504.619 Q44.9996 503.06 46.05 498.349 L46.4956 496.344 Q47.8324 490.106 50.2832 487.496 Q52.7021 484.854 57.0626 484.854 Q62.0279 484.854 64.9243 488.801 Q67.8207 492.715 67.8207 499.59 Q67.8207 502.455 67.2478 505.574 Q66.7067 508.662 65.5927 512.099 L59.5453 512.099 Q61.2322 508.853 62.0916 505.702 Q62.9191 502.55 62.9191 499.463 Q62.9191 495.325 61.5186 493.097 Q60.0864 490.869 57.5082 490.869 Q55.1211 490.869 53.848 492.493 Q52.5748 494.084 51.3972 499.527 L50.9197 501.564 Q49.7739 507.006 47.4186 509.425 Q45.0315 511.844 40.8937 511.844 Q35.8648 511.844 33.1276 508.28 Q30.3903 504.715 30.3903 498.158 Q30.3903 494.912 30.8678 492.047 Q31.3452 489.182 32.3 486.764 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M32.3 452.802 L37.8382 452.802 Q36.5651 455.285 35.9285 457.959 Q35.2919 460.632 35.2919 463.497 Q35.2919 467.857 36.6287 470.054 Q37.9655 472.218 40.6391 472.218 Q42.6761 472.218 43.8538 470.658 Q44.9996 469.099 46.05 464.388 L46.4956 462.383 Q47.8324 456.144 50.2832 453.535 Q52.7021 450.893 57.0626 450.893 Q62.0279 450.893 64.9243 454.84 Q67.8207 458.754 67.8207 465.629 Q67.8207 468.494 67.2478 471.613 Q66.7067 474.701 65.5927 478.138 L59.5453 478.138 Q61.2322 474.891 62.0916 471.74 Q62.9191 468.589 62.9191 465.502 Q62.9191 461.364 61.5186 459.136 Q60.0864 456.908 57.5082 456.908 Q55.1211 456.908 53.848 458.532 Q52.5748 460.123 51.3972 465.566 L50.9197 467.603 Q49.7739 473.045 47.4186 475.464 Q45.0315 477.883 40.8937 477.883 Q35.8648 477.883 33.1276 474.319 Q30.3903 470.754 30.3903 464.197 Q30.3903 460.951 30.8678 458.086 Q31.3452 455.221 32.3 452.802 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M52.8294 442.172 L31.2497 442.172 L31.2497 436.315 L52.6066 436.315 Q57.6674 436.315 60.2137 434.342 Q62.7281 432.369 62.7281 428.422 Q62.7281 423.679 59.7044 420.942 Q56.6807 418.173 51.4608 418.173 L31.2497 418.173 L31.2497 412.317 L66.8977 412.317 L66.8977 418.173 L61.4232 418.173 Q64.6697 420.306 66.2611 423.138 Q67.8207 425.939 67.8207 429.663 Q67.8207 435.806 64.0013 438.989 Q60.1818 442.172 52.8294 442.172 M30.3903 427.435 L30.3903 427.435 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M36.7242 379.597 Q36.1513 380.584 35.8967 381.761 Q35.6102 382.907 35.6102 384.307 Q35.6102 389.273 38.8567 391.946 Q42.0714 394.588 48.1188 394.588 L66.8977 394.588 L66.8977 400.476 L31.2497 400.476 L31.2497 394.588 L36.7879 394.588 Q33.5414 392.742 31.9818 389.782 Q30.3903 386.822 30.3903 382.589 Q30.3903 381.984 30.4858 381.252 Q30.5495 380.52 30.7086 379.629 L36.7242 379.597 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M47.6096 344.395 L50.4741 344.395 L50.4741 371.321 Q56.5216 370.939 59.7044 367.693 Q62.8554 364.415 62.8554 358.59 Q62.8554 355.216 62.0279 352.065 Q61.2004 348.882 59.5453 345.763 L65.0834 345.763 Q66.4202 348.914 67.1205 352.224 Q67.8207 355.534 67.8207 358.94 Q67.8207 367.47 62.8554 372.467 Q57.8902 377.433 49.4238 377.433 Q40.6709 377.433 35.5466 372.722 Q30.3903 367.979 30.3903 359.959 Q30.3903 352.765 35.0373 348.596 Q39.6524 344.395 47.6096 344.395 M45.8908 350.251 Q41.0847 350.315 38.2202 352.956 Q35.3556 355.566 35.3556 359.895 Q35.3556 364.797 38.1247 367.757 Q40.8937 370.685 45.9227 371.13 L45.8908 350.251 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M17.3725 314.603 L17.3725 301.108 L21.9239 301.108 L21.9239 308.747 L70.9399 308.747 L70.9399 301.108 L75.4914 301.108 L75.4914 314.603 L17.3725 314.603 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M38.0928 260.876 Q34.1461 258.68 32.2682 255.625 Q30.3903 252.569 30.3903 248.431 Q30.3903 242.861 34.3052 239.838 Q38.1883 236.814 45.3816 236.814 L66.8977 236.814 L66.8977 242.702 L45.5725 242.702 Q40.4481 242.702 37.9655 244.517 Q35.4829 246.331 35.4829 250.055 Q35.4829 254.606 38.5066 257.248 Q41.5303 259.89 46.7502 259.89 L66.8977 259.89 L66.8977 265.778 L45.5725 265.778 Q40.4163 265.778 37.9655 267.592 Q35.4829 269.406 35.4829 273.194 Q35.4829 277.682 38.5384 280.324 Q41.5621 282.965 46.7502 282.965 L66.8977 282.965 L66.8977 288.854 L31.2497 288.854 L31.2497 282.965 L36.7879 282.965 Q33.5095 280.96 31.9499 278.159 Q30.3903 275.358 30.3903 271.507 Q30.3903 267.624 32.3637 264.919 Q34.3371 262.181 38.0928 260.876 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M38.0928 197.379 Q34.1461 195.182 32.2682 192.127 Q30.3903 189.071 30.3903 184.934 Q30.3903 179.364 34.3052 176.34 Q38.1883 173.316 45.3816 173.316 L66.8977 173.316 L66.8977 179.204 L45.5725 179.204 Q40.4481 179.204 37.9655 181.019 Q35.4829 182.833 35.4829 186.557 Q35.4829 191.108 38.5066 193.75 Q41.5303 196.392 46.7502 196.392 L66.8977 196.392 L66.8977 202.28 L45.5725 202.28 Q40.4163 202.28 37.9655 204.094 Q35.4829 205.909 35.4829 209.696 Q35.4829 214.184 38.5384 216.826 Q41.5621 219.468 46.7502 219.468 L66.8977 219.468 L66.8977 225.356 L31.2497 225.356 L31.2497 219.468 L36.7879 219.468 Q33.5095 217.462 31.9499 214.661 Q30.3903 211.86 30.3903 208.009 Q30.3903 204.126 32.3637 201.421 Q34.3371 198.683 38.0928 197.379 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M19.3777 161.38 L19.3777 154.951 L38.8567 154.951 L38.8567 131.589 L19.3777 131.589 L19.3777 125.16 L66.8977 125.16 L66.8977 131.589 L44.2676 131.589 L44.2676 154.951 L66.8977 154.951 L66.8977 161.38 L19.3777 161.38 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M48.6599 89.1615 Q42.2942 89.1615 38.7931 91.8033 Q35.2919 94.4132 35.2919 99.1557 Q35.2919 103.866 38.7931 106.508 Q42.2942 109.118 48.6599 109.118 Q54.9938 109.118 58.4949 106.508 Q61.9961 103.866 61.9961 99.1557 Q61.9961 94.4132 58.4949 91.8033 Q54.9938 89.1615 48.6599 89.1615 M62.4735 83.305 Q71.5765 83.305 76.0006 87.3473 Q80.4566 91.3895 80.4566 99.7286 Q80.4566 102.816 79.9792 105.553 Q79.5336 108.29 78.5787 110.869 L72.8814 110.869 Q74.2819 108.29 74.9503 105.776 Q75.6187 103.262 75.6187 100.652 Q75.6187 94.8906 72.595 92.0261 Q69.6031 89.1615 63.5238 89.1615 L60.6274 89.1615 Q63.7785 90.9757 65.3381 93.8085 Q66.8977 96.6412 66.8977 100.588 Q66.8977 107.145 61.9006 111.155 Q56.9035 115.165 48.6599 115.165 Q40.3845 115.165 35.3874 111.155 Q30.3903 107.145 30.3903 100.588 Q30.3903 96.6412 31.9499 93.8085 Q33.5095 90.9757 36.6606 89.1615 L31.2497 89.1615 L31.2497 83.305 L62.4735 83.305 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M17.3725 57.5558 L75.4914 57.5558 L75.4914 71.0511 L70.9399 71.0511 L70.9399 63.444 L21.9239 63.444 L21.9239 71.0511 L17.3725 71.0511 L17.3725 57.5558 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip402)" style="stroke:#009af9; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,603.676 235.292,603.674 235.301,603.67 235.31,603.667 235.32,603.663 235.329,603.658 235.338,603.653 235.347,603.648 235.356,603.643 235.366,603.638 235.375,603.632 235.384,603.626 235.393,603.62 235.402,603.614 235.412,603.607 235.421,603.601 235.43,603.594 235.439,603.588 235.448,603.581 235.457,603.574 235.467,603.567 235.476,603.559 235.485,603.552 235.494,603.544 235.503,603.537 235.513,603.529 235.522,603.521 235.531,603.514 235.54,603.506 235.549,603.498 235.559,603.49 235.568,603.481 235.577,603.473 235.586,603.465 235.595,603.456 235.604,603.448 235.614,603.439 235.623,603.43 235.632,603.422 235.641,603.413 235.65,603.404 235.66,603.395 235.669,603.386 235.678,603.377 235.687,603.367 235.696,603.358 235.706,603.349 235.715,603.34 235.724,603.33 235.733,603.321 235.742,603.311 235.752,603.301 235.761,603.292 235.77,603.282 235.779,603.272 235.788,603.262 235.797,603.252 235.807,603.242 235.816,603.232 235.825,603.222 235.834,603.212 235.843,603.202 235.853,603.192 235.862,603.181 235.871,603.171 235.88,603.161 235.889,603.15 235.899,603.14 235.908,603.129 235.917,603.119 235.926,603.108 235.935,603.097 235.944,603.086 235.954,603.076 235.963,603.065 235.972,603.054 235.981,603.043 235.99,603.032 236,603.021 236.009,603.01 236.018,602.999 236.027,602.988 236.036,602.976 236.046,602.965 236.055,602.954 236.064,602.943 236.073,602.931 236.082,602.92 236.092,602.908 236.101,602.897 236.11,602.885 236.119,602.874 236.128,602.862 236.137,602.85 236.147,602.839 236.156,602.827 236.165,602.815 236.174,602.803 236.183,602.792 236.193,602.78 236.202,602.768 236.211,602.756 236.22,602.744 236.229,602.732 236.239,602.72 236.248,602.708 236.257,602.696 236.266,602.683 236.275,602.671 236.284,602.659 236.294,602.647 236.303,602.634 236.312,602.622 236.321,602.61 236.33,602.597 236.34,602.585 236.349,602.572 236.358,602.56 236.367,602.547 236.376,602.534 236.386,602.522 236.395,602.509 236.404,602.496 236.413,602.484 236.422,602.471 236.432,602.458 236.441,602.445 236.45,602.433 236.459,602.42 236.468,602.407 236.477,602.394 236.487,602.381 236.496,602.368 236.505,602.355 236.514,602.342 236.523,602.329 236.533,602.315 236.542,602.302 236.551,602.289 236.56,602.276 236.569,602.263 236.579,602.249 236.588,602.236 236.597,602.223 236.606,602.209 236.615,602.196 236.624,602.182 236.634,602.169 236.643,602.156 236.652,602.142 236.661,602.128 236.67,602.115 236.68,602.101 236.689,602.088 236.698,602.074 236.707,602.06 236.716,602.047 236.726,602.033 236.735,602.019 236.744,602.005 236.753,601.992 236.762,601.978 236.772,601.964 236.781,601.95 236.79,601.936 236.799,601.922 236.808,601.908 236.817,601.894 236.827,601.88 236.836,601.866 236.845,601.852 236.854,601.838 236.863,601.824 236.873,601.809 236.882,601.795 236.891,601.781 236.9,601.767 236.909,601.752 236.919,601.738 236.928,601.724 236.937,601.71 236.946,601.695 236.955,601.681 236.964,601.666 236.974,601.652 236.983,601.637 236.992,601.623 237.001,601.608 237.01,601.594 237.02,601.579 237.029,601.565 237.038,601.55 237.047,601.535 237.056,601.521 237.066,601.506 237.075,601.491 237.084,601.477 237.093,601.462 237.102,601.447 237.112,601.432 237.121,601.417 237.13,601.403 237.139,601.388 237.148,601.373 237.157,601.358 237.167,601.343 237.176,601.328 237.185,601.313 237.194,601.298 237.203,601.283 237.213,601.268 237.222,601.253 237.231,601.238 237.24,601.222 237.249,601.207 237.259,601.192 237.268,601.177 237.277,601.162 237.286,601.146 237.295,601.131 237.304,601.116 237.314,601.101 237.323,601.085 237.332,601.07 237.341,601.054 237.35,601.039 237.36,601.024 237.369,601.008 237.378,600.993 237.387,600.977 237.396,600.962 237.406,600.946 237.415,600.931 237.424,600.915 237.433,600.9 237.442,600.884 237.452,600.868 237.461,600.853 237.47,600.837 237.479,600.821 237.488,600.806 237.497,600.79 237.507,600.774 237.516,600.758 237.525,600.742 237.534,600.727 237.543,600.711 237.553,600.695 237.562,600.679 237.571,600.663 237.58,600.647 237.589,600.631 237.599,600.615 237.608,600.599 237.617,600.583 237.626,600.567 237.635,600.551 237.644,600.535 237.654,600.519 237.663,600.503 237.672,600.487 237.681,600.471 237.69,600.455 237.7,600.438 237.709,600.422 237.718,600.406 237.727,600.39 237.736,600.374 237.746,600.357 237.755,600.341 237.764,600.325 237.773,600.308 237.782,600.292 237.792,600.276 237.801,600.259 237.81,600.243 237.819,600.226 237.828,600.21 237.837,600.193 237.847,600.177 237.856,600.16 237.865,600.144 237.874,600.127 237.883,600.111 237.893,600.094 237.902,600.078 237.911,600.061 237.92,600.044 237.929,600.028 237.939,600.011 237.948,599.994 237.957,599.978 237.966,599.961 237.975,599.944 237.985,599.928 237.994,599.911 238.003,599.894 238.012,599.877 238.021,599.86 238.03,599.843 238.04,599.827 238.049,599.81 238.058,599.793 238.067,599.776 238.076,599.759 238.086,599.742 238.095,599.725 238.104,599.708 238.113,599.691 238.122,599.674 238.132,599.657 238.141,599.64 238.15,599.623 238.159,599.606 238.168,599.589 238.177,599.572 238.187,599.554 238.196,599.537 238.205,599.52 238.214,599.503 238.223,599.486 238.233,599.468 238.242,599.451 238.251,599.434 238.26,599.417 238.269,599.399 238.279,599.382 238.288,599.365 238.297,599.347 238.306,599.33 238.315,599.313 238.325,599.295 238.334,599.278 238.343,599.26 238.352,599.243 238.361,599.226 238.37,599.208 238.38,599.191 238.389,599.173 238.398,599.156 238.407,599.138 238.416,599.12 238.426,599.103 238.435,599.085 238.444,599.068 238.453,599.05 238.462,599.032 238.472,599.015 238.481,598.997 238.49,598.979 238.499,598.962 238.508,598.944 238.517,598.926 238.527,598.908 238.536,598.891 238.545,598.873 238.554,598.855 238.563,598.837 238.573,598.82 238.582,598.802 238.591,598.784 238.6,598.766 238.609,598.748 238.619,598.73 238.628,598.712 238.637,598.694 238.646,598.676 238.655,598.658 238.665,598.64 238.674,598.622 238.683,598.604 238.692,598.586 238.701,598.568 238.71,598.55 238.72,598.532 238.729,598.514 238.738,598.496 238.747,598.478 238.756,598.46 238.766,598.442 238.775,598.423 238.784,598.405 238.793,598.387 238.802,598.369 238.812,598.351 238.821,598.332 238.83,598.314 238.839,598.296 238.848,598.278 238.857,598.259 238.867,598.241 238.876,598.223 238.885,598.204 238.894,598.186 238.903,598.168 238.913,598.149 238.922,598.131 238.931,598.112 238.94,598.094 238.949,598.076 238.959,598.057 238.968,598.039 238.977,598.02 238.986,598.002 238.995,597.983 239.005,597.965 239.014,597.946 239.023,597.928 239.032,597.909 239.041,597.89 239.05,597.872 239.06,597.853 239.069,597.835 239.078,597.816 239.087,597.797 239.096,597.779 239.106,597.76 239.115,597.741 239.124,597.723 239.133,597.704 239.142,597.685 239.152,597.666 239.161,597.648 239.17,597.629 239.179,597.61 239.188,597.591 239.197,597.572 239.207,597.554 239.216,597.535 239.225,597.516 239.234,597.497 239.243,597.478 239.253,597.459 239.262,597.44 239.271,597.421 239.28,597.402 239.289,597.383 239.299,597.364 239.308,597.345 239.317,597.326 239.326,597.307 239.335,597.288 239.345,597.269 239.354,597.25 239.363,597.231 239.372,597.212 239.381,597.193 239.39,597.174 239.4,597.155 239.409,597.136 239.418,597.117 239.427,597.098 239.436,597.078 239.446,597.059 239.455,597.04 239.464,597.021 239.473,597.002 239.482,596.982 239.492,596.963 239.501,596.944 239.51,596.925 239.519,596.905 239.528,596.886 239.537,596.867 239.547,596.847 239.556,596.828 239.565,596.809 239.574,596.789 239.583,596.77 239.593,596.75 239.602,596.731 239.611,596.712 239.62,596.692 239.629,596.673 239.639,596.653 239.648,596.634 239.657,596.614 239.666,596.595 239.675,596.575 239.685,596.556 239.694,596.536 239.703,596.517 239.712,596.497 239.721,596.478 239.73,596.458 239.74,596.439 239.749,596.419 239.758,596.399 239.767,596.38 239.776,596.36 239.786,596.34 239.795,596.321 239.804,596.301 239.813,596.281 239.822,596.262 239.832,596.242 239.841,596.222 239.85,596.202 239.859,596.183 239.868,596.163 239.877,596.143 239.887,596.123 239.896,596.104 239.905,596.084 239.914,596.064 239.923,596.044 239.933,596.024 239.942,596.004 239.951,595.984 239.96,595.965 239.969,595.945 239.979,595.925 239.988,595.905 239.997,595.885 240.006,595.865 240.015,595.845 240.025,595.825 240.034,595.805 240.043,595.785 240.052,595.765 240.061,595.745 240.07,595.725 240.08,595.705 240.089,595.685 240.098,595.665 240.107,595.645 240.116,595.625 240.126,595.605 240.135,595.585 240.144,595.564 240.153,595.544 240.162,595.524 240.172,595.504 240.181,595.484 240.19,595.464 240.199,595.443 240.208,595.423 240.217,595.403 240.227,595.383 240.236,595.363 240.245,595.342 240.254,595.322 240.263,595.302 240.273,595.281 240.282,595.261 240.291,595.241 240.3,595.221 240.309,595.2 240.319,595.18 240.328,595.159 240.337,595.139 240.346,595.119 240.355,595.098 240.365,595.078 240.374,595.058 240.383,595.037 240.392,595.017 240.401,594.996 240.41,594.976 240.42,594.955 240.429,594.935 240.438,594.914 240.447,594.894 240.456,594.873 240.466,594.853 240.475,594.832 240.484,594.812 240.493,594.791 240.502,594.771 240.512,594.75 240.521,594.729 240.53,594.709 240.539,594.688 240.548,594.668 240.558,594.647 240.567,594.626 240.576,594.606 240.585,594.585 240.594,594.564 240.603,594.544 240.613,594.523 240.622,594.502 240.631,594.481 240.64,594.461 240.649,594.44 240.659,594.419 240.668,594.398 240.677,594.378 240.686,594.357 240.695,594.336 240.705,594.315 240.714,594.294 240.723,594.274 240.732,594.253 240.741,594.232 240.75,594.211 240.76,594.19 240.769,594.169 240.778,594.148 240.787,594.128 240.796,594.107 240.806,594.086 240.815,594.065 240.824,594.044 240.833,594.023 240.842,594.002 240.852,593.981 240.861,593.96 240.87,593.939 240.879,593.918 240.888,593.897 240.898,593.876 240.907,593.855 240.916,593.834 240.925,593.813 240.934,593.792 240.943,593.771 240.953,593.749 240.962,593.728 240.971,593.707 240.98,593.686 240.989,593.665 240.999,593.644 241.008,593.623 241.017,593.601 241.026,593.58 241.035,593.559 241.045,593.538 241.054,593.517 241.063,593.496 241.072,593.474 241.081,593.453 241.09,593.432 241.1,593.411 241.109,593.389 241.118,593.368 241.127,593.347 241.136,593.325 241.146,593.304 241.155,593.283 241.164,593.261 241.173,593.24 241.182,593.219 241.192,593.197 241.201,593.176 241.21,593.155 241.219,593.133 241.228,593.112 241.238,593.09 241.247,593.069 241.256,593.048 241.265,593.026 241.274,593.005 241.283,592.983 241.293,592.962 241.302,592.94 241.311,592.919 241.32,592.897 241.329,592.876 241.339,592.854 241.348,592.833 241.357,592.811 241.366,592.79 241.375,592.768 241.385,592.746 241.394,592.725 241.403,592.703 241.412,592.682 241.421,592.66 241.43,592.638 241.44,592.617 241.449,592.595 241.458,592.574 241.467,592.552 241.476,592.53 241.486,592.509 241.495,592.487 241.504,592.465 241.513,592.443 241.522,592.422 241.532,592.4 241.541,592.378 241.55,592.356 241.559,592.335 241.568,592.313 241.578,592.291 241.587,592.269 241.596,592.248 241.605,592.226 241.614,592.204 241.623,592.182 241.633,592.16 241.642,592.138 241.651,592.117 241.66,592.095 241.669,592.073 241.679,592.051 241.688,592.029 241.697,592.007 241.706,591.985 241.715,591.963 241.725,591.941 241.734,591.92 241.743,591.898 241.752,591.876 241.761,591.854 241.77,591.832 241.78,591.81 241.789,591.788 241.798,591.766 241.807,591.744 241.816,591.722 241.826,591.7 241.835,591.678 241.844,591.656 241.853,591.634 241.862,591.611 241.872,591.589 241.881,591.567 241.89,591.545 241.899,591.523 241.908,591.501 241.918,591.479 241.927,591.457 241.936,591.435 241.945,591.412 241.954,591.39 241.963,591.368 241.973,591.346 241.982,591.324 241.991,591.301 242,591.279 242.009,591.257 242.019,591.235 242.028,591.213 242.037,591.19 242.046,591.168 242.055,591.146 242.065,591.124 242.074,591.101 242.083,591.079 242.092,591.057 242.101,591.034 242.11,591.012 242.12,590.99 242.129,590.967 242.138,590.945 242.147,590.923 242.156,590.9 242.166,590.878 242.175,590.856 242.184,590.833 242.193,590.811 242.202,590.788 242.212,590.766 242.221,590.744 242.23,590.721 242.239,590.699 242.248,590.676 242.258,590.654 242.267,590.631 242.276,590.609 242.285,590.586 242.294,590.564 242.303,590.541 242.313,590.519 242.322,590.496 242.331,590.474 242.34,590.451 242.349,590.429 242.359,590.406 242.368,590.384 242.377,590.361 242.386,590.338 242.395,590.316 242.405,590.293 242.414,590.271 242.423,590.248 242.432,590.225 242.441,590.203 242.45,590.18 242.46,590.157 242.469,590.135 242.478,590.112 242.487,590.089 242.496,590.067 242.506,590.044 242.515,590.021 242.524,589.999 242.533,589.976 242.542,589.953 242.552,589.93 242.561,589.908 242.57,589.885 242.579,589.862 242.588,589.839 242.598,589.817 242.607,589.794 242.616,589.771 242.625,589.748 242.634,589.725 242.643,589.703 242.653,589.68 242.662,589.657 242.671,589.634 242.68,589.611 242.689,589.588 242.699,589.565 242.708,589.543 242.717,589.52 242.726,589.497 242.735,589.474 242.745,589.451 242.754,589.428 242.763,589.405 242.772,589.382 242.781,589.359 242.79,589.336 242.8,589.313 242.809,589.29 242.818,589.267 242.827,589.244 242.836,589.221 242.846,589.198 242.855,589.175 242.864,589.152 242.873,589.129 242.882,589.106 242.892,589.083 242.901,589.06 242.91,589.037 242.919,589.014 242.928,588.991 242.938,588.968 242.947,588.945 242.956,588.922 242.965,588.898 242.974,588.875 242.983,588.852 242.993,588.829 243.002,588.806 243.011,588.783 243.02,588.76 243.029,588.736 243.039,588.713 243.048,588.69 243.057,588.667 243.066,588.644 243.075,588.62 243.085,588.597 243.094,588.574 243.103,588.551 243.112,588.527 243.121,588.504 243.131,588.481 243.14,588.458 243.149,588.434 243.158,588.411 243.167,588.388 243.176,588.365 243.186,588.341 243.195,588.318 243.204,588.295 243.213,588.271 243.222,588.248 243.232,588.225 243.241,588.201 243.25,588.178 243.259,588.154 243.268,588.131 243.278,588.108 243.287,588.084 243.296,588.061 243.305,588.037 243.314,588.014 243.323,587.991 243.333,587.967 243.342,587.944 243.351,587.92 243.36,587.897 243.369,587.873 243.379,587.85 243.388,587.826 243.397,587.803 243.406,587.779 243.415,587.756 243.425,587.732 243.434,587.709 243.443,587.685 243.452,587.662 243.461,587.638 243.471,587.615 243.48,587.591 243.489,587.567 243.498,587.544 243.507,587.52 243.516,587.497 243.526,587.473 243.535,587.449 243.544,587.426 243.553,587.402 243.562,587.379 243.572,587.355 243.581,587.331 243.59,587.308 243.599,587.284 243.608,587.26 243.618,587.237 243.627,587.213 243.636,587.189 243.645,587.166 243.654,587.142 243.663,587.118 243.673,587.094 243.682,587.071 243.691,587.047 243.7,587.023 243.709,586.999 243.719,586.976 243.728,586.952 243.737,586.928 243.746,586.904 243.755,586.88 243.765,586.857 243.774,586.833 243.783,586.809 243.792,586.785 243.801,586.761 243.811,586.738 243.82,586.714 243.829,586.69 243.838,586.666 243.847,586.642 243.856,586.618 243.866,586.594 243.875,586.57 243.884,586.547 243.893,586.523 243.902,586.499 243.912,586.475 243.921,586.451 243.93,586.427 243.939,586.403 243.948,586.379 243.958,586.355 243.967,586.331 243.976,586.307 243.985,586.283 243.994,586.259 244.003,586.235 244.013,586.211 244.022,586.187 244.031,586.163 244.04,586.139 244.049,586.115 244.059,586.091 244.068,586.067 244.077,586.043 244.086,586.019 244.095,585.995 244.105,585.971 244.114,585.947 244.123,585.922 244.132,585.898 244.141,585.874 244.151,585.85 244.16,585.826 244.169,585.802 244.178,585.778 244.187,585.754 244.196,585.729 244.206,585.705 244.215,585.681 244.224,585.657 244.233,585.633 244.242,585.609 244.252,585.584 244.261,585.56 244.27,585.536 244.279,585.512 244.288,585.487 244.298,585.463 244.307,585.439 244.316,585.415 244.325,585.391 244.334,585.366 244.343,585.342 244.353,585.318 244.362,585.293 244.371,585.269 244.38,585.245 244.389,585.221 244.399,585.196 244.408,585.172 244.417,585.148 244.426,585.123 244.435,585.099 244.445,585.075 244.454,585.05 244.463,585.026 244.472,585.001 244.481,584.977 244.491,584.953 244.5,584.928 244.509,584.904 244.518,584.88 244.527,584.855 244.536,584.831 244.546,584.806 244.555,584.782 244.564,584.757 244.573,584.733 244.582,584.708 244.592,584.684 244.601,584.66 244.61,584.635 244.619,584.611 244.628,584.586 244.638,584.562 244.647,584.537 244.656,584.513 244.665,584.488 244.674,584.464 244.683,584.439 244.693,584.415 244.702,584.39 244.711,584.365 244.72,584.341 244.729,584.316 244.739,584.292 244.748,584.267 244.757,584.243 244.766,584.218 244.775,584.193 244.785,584.169 244.794,584.144 244.803,584.12 244.812,584.095 244.821,584.07 244.831,584.046 244.84,584.021 244.849,583.996 244.858,583.972 244.867,583.947 244.876,583.922 244.886,583.898 244.895,583.873 244.904,583.848 244.913,583.824 244.922,583.799 244.932,583.774 244.941,583.749 244.95,583.725 244.959,583.7 244.968,583.675 244.978,583.65 244.987,583.626 244.996,583.601 245.005,583.576 245.014,583.551 245.023,583.527 245.033,583.502 245.042,583.477 245.051,583.452 245.06,583.427 245.069,583.403 245.079,583.378 245.088,583.353 245.097,583.328 245.106,583.303 245.115,583.278 245.125,583.254 245.134,583.229 245.143,583.204 245.152,583.179 245.161,583.154 245.171,583.129 245.18,583.104 245.189,583.079 245.198,583.054 245.207,583.029 245.216,583.005 245.226,582.98 245.235,582.955 245.244,582.93 245.253,582.905 245.262,582.88 245.272,582.855 245.281,582.83 245.29,582.805 245.299,582.78 245.308,582.755 245.318,582.73 245.327,582.705 245.336,582.68 245.345,582.655 245.354,582.63 245.364,582.605 245.373,582.58 245.382,582.555 245.391,582.53 245.4,582.505 245.409,582.48 245.419,582.455 245.428,582.429 245.437,582.404 245.446,582.379 245.455,582.354 245.465,582.329 245.474,582.304 245.483,582.279 245.492,582.254 245.501,582.229 245.511,582.203 245.52,582.178 245.529,582.153 245.538,582.128 245.547,582.103 245.556,582.078 245.566,582.053 245.575,582.027 245.584,582.002 245.593,581.977 245.602,581.952 245.612,581.927 245.621,581.901 245.63,581.876 245.639,581.851 245.648,581.826 245.658,581.8 245.667,581.775 245.676,581.75 245.685,581.725 245.694,581.699 245.704,581.674 245.713,581.649 245.722,581.624 245.731,581.598 245.74,581.573 245.749,581.548 245.759,581.522 245.768,581.497 245.777,581.472 245.786,581.446 245.795,581.421 245.805,581.396 245.814,581.37 245.823,581.345 245.832,581.32 245.841,581.294 245.851,581.269 245.86,581.244 245.869,581.218 245.878,581.193 245.887,581.167 245.896,581.142 245.906,581.117 245.915,581.091 245.924,581.066 245.933,581.04 245.942,581.015 245.952,580.989 245.961,580.964 245.97,580.939 245.979,580.913 245.988,580.888 245.998,580.862 246.007,580.837 246.016,580.811 246.025,580.786 246.034,580.76 246.044,580.735 246.053,580.709 246.062,580.684 246.071,580.658 246.08,580.633 246.089,580.607 246.099,580.582 246.108,580.556 246.117,580.53 246.126,580.505 246.135,580.479 246.145,580.454 246.154,580.428 246.163,580.403 246.172,580.377 246.181,580.351 246.191,580.326 246.2,580.3 246.209,580.275 246.218,580.249 246.227,580.223 246.236,580.198 246.246,580.172 246.255,580.146 246.264,580.121 246.273,580.095 246.282,580.07 246.292,580.044 246.301,580.018 246.31,579.992 246.319,579.967 246.328,579.941 246.338,579.915 246.347,579.89 246.356,579.864 246.365,579.838 246.374,579.813 246.384,579.787 246.393,579.761 246.402,579.735 246.411,579.71 246.42,579.684 246.429,579.658 246.439,579.632 246.448,579.607 246.457,579.581 246.466,579.555 246.475,579.529 246.485,579.503 246.494,579.478 246.503,579.452 246.512,579.426 246.521,579.4 246.531,579.374 246.54,579.349 246.549,579.323 246.558,579.297 246.567,579.271 246.576,579.245 246.586,579.219 246.595,579.193 246.604,579.168 246.613,579.142 246.622,579.116 246.632,579.09 246.641,579.064 246.65,579.038 246.659,579.012 246.668,578.986 246.678,578.96 246.687,578.934 246.696,578.908 246.705,578.883 246.714,578.857 246.724,578.831 246.733,578.805 246.742,578.779 246.751,578.753 246.76,578.727 246.769,578.701 246.779,578.675 246.788,578.649 246.797,578.623 246.806,578.597 246.815,578.571 246.825,578.545 246.834,578.519 246.843,578.493 246.852,578.467 246.861,578.441 246.871,578.415 246.88,578.389 246.889,578.363 246.898,578.337 246.907,578.31 246.916,578.284 246.926,578.258 246.935,578.232 246.944,578.206 246.953,578.18 246.962,578.154 246.972,578.128 246.981,578.102 246.99,578.076 246.999,578.049 247.008,578.023 247.018,577.997 247.027,577.971 247.036,577.945 247.045,577.919 247.054,577.893 247.064,577.866 247.073,577.84 247.082,577.814 247.091,577.788 247.1,577.762 247.109,577.736 247.119,577.709 247.128,577.683 247.137,577.657 247.146,577.631 247.155,577.605 247.165,577.578 247.174,577.552 247.183,577.526 247.192,577.5 247.201,577.473 247.211,577.447 247.22,577.421 247.229,577.395 247.238,577.368 247.247,577.342 247.256,577.316 247.266,577.289 247.275,577.263 247.284,577.237 247.293,577.211 247.302,577.184 247.312,577.158 247.321,577.132 247.33,577.105 247.339,577.079 247.348,577.053 247.358,577.026 247.367,577 247.376,576.974 247.385,576.947 247.394,576.921 247.404,576.894 247.413,576.868 247.422,576.842 247.431,576.815 247.44,576.789 247.449,576.763 247.459,576.736 247.468,576.71 247.477,576.683 247.486,576.657 247.495,576.63 247.505,576.604 247.514,576.578 247.523,576.551 247.532,576.525 247.541,576.498 247.551,576.472 247.56,576.445 247.569,576.419 247.578,576.392 247.587,576.366 247.596,576.339 247.606,576.313 247.615,576.286 247.624,576.26 247.633,576.233 247.642,576.207 247.652,576.18 247.661,576.154 247.67,576.127 247.679,576.101 247.688,576.074 247.698,576.048 247.707,576.021 247.716,575.995 247.725,575.968 247.734,575.941 247.744,575.915 247.753,575.888 247.762,575.862 247.771,575.835 247.78,575.808 247.789,575.782 247.799,575.755 247.808,575.729 247.817,575.702 247.826,575.675 247.835,575.649 247.845,575.622 247.854,575.595 247.863,575.569 247.872,575.542 247.881,575.516 247.891,575.489 247.9,575.462 247.909,575.436 247.918,575.409 247.927,575.382 247.937,575.355 247.946,575.329 247.955,575.302 247.964,575.275 247.973,575.249 247.982,575.222 247.992,575.195 248.001,575.169 248.01,575.142 248.019,575.115 248.028,575.088 248.038,575.062 248.047,575.035 248.056,575.008 248.065,574.981 248.074,574.955 248.084,574.928 248.093,574.901 248.102,574.874 248.111,574.847 248.12,574.821 248.129,574.794 248.139,574.767 248.148,574.74 248.157,574.713 248.166,574.687 248.175,574.66 248.185,574.633 248.194,574.606 248.203,574.579 248.212,574.552 248.221,574.525 248.231,574.499 248.24,574.472 248.249,574.445 248.258,574.418 248.267,574.391 248.277,574.364 248.286,574.337 248.295,574.31 248.304,574.284 248.313,574.257 248.322,574.23 248.332,574.203 248.341,574.176 248.35,574.149 248.359,574.122 248.368,574.095 248.378,574.068 248.387,574.041 248.396,574.014 248.405,573.987 248.414,573.96 248.424,573.933 248.433,573.906 248.442,573.879 248.451,573.852 248.46,573.825 248.469,573.798 248.479,573.771 248.488,573.744 248.497,573.717 248.506,573.69 248.515,573.663 248.525,573.636 248.534,573.609 248.543,573.582 248.552,573.555 248.561,573.528 248.571,573.501 248.58,573.474 248.589,573.447 248.598,573.42 248.607,573.393 248.617,573.366 248.626,573.339 248.635,573.312 248.644,573.285 248.653,573.258 248.662,573.23 248.672,573.203 248.681,573.176 248.69,573.149 248.699,573.122 248.708,573.095 248.718,573.068 248.727,573.041 248.736,573.013 248.745,572.986 248.754,572.959 248.764,572.932 248.773,572.905 248.782,572.878 248.791,572.851 248.8,572.823 248.809,572.796 248.819,572.769 248.828,572.742 248.837,572.715 248.846,572.687 248.855,572.66 248.865,572.633 248.874,572.606 248.883,572.579 248.892,572.551 248.901,572.524 248.911,572.497 248.92,572.47 248.929,572.442 248.938,572.415 248.947,572.388 248.957,572.361 248.966,572.333 248.975,572.306 248.984,572.279 248.993,572.251 249.002,572.224 249.012,572.197 249.021,572.17 249.03,572.142 249.039,572.115 249.048,572.088 249.058,572.06 249.067,572.033 249.076,572.006 249.085,571.978 249.094,571.951 249.104,571.924 249.113,571.896 249.122,571.869 249.131,571.842 249.14,571.814 249.149,571.787 249.159,571.76 249.168,571.732 249.177,571.705 249.186,571.677 249.195,571.65 249.205,571.623 249.214,571.595 249.223,571.568 249.232,571.54 249.241,571.513 249.251,571.486 249.26,571.458 249.269,571.431 249.278,571.403 249.287,571.376 249.297,571.348 249.306,571.321 249.315,571.294 249.324,571.266 249.333,571.239 249.342,571.211 249.352,571.184 249.361,571.156 249.37,571.129 249.379,571.101 249.388,571.074 249.398,571.046 249.407,571.019 249.416,570.991 249.425,570.964 249.434,570.936 249.444,570.909 249.453,570.881 249.462,570.854 249.471,570.826 249.48,570.799 249.489,570.771 249.499,570.743 249.508,570.716 249.517,570.688 249.526,570.661 249.535,570.633 249.545,570.606 249.554,570.578 249.563,570.55 249.572,570.523 249.581,570.495 249.591,570.468 249.6,570.44 249.609,570.412 249.618,570.385 249.627,570.357 249.637,570.33 249.646,570.302 249.655,570.274 249.664,570.247 249.673,570.219 249.682,570.191 249.692,570.164 249.701,570.136 249.71,570.108 249.719,570.081 249.728,570.053 249.738,570.025 249.747,569.998 249.756,569.97 249.765,569.942 249.774,569.915 249.784,569.887 249.793,569.859 249.802,569.832 249.811,569.804 249.82,569.776 249.829,569.748 249.839,569.721 249.848,569.693 249.857,569.665 249.866,569.638 249.875,569.61 249.885,569.582 249.894,569.554 249.903,569.527 249.912,569.499 249.921,569.471 249.931,569.443 249.94,569.415 249.949,569.388 249.958,569.36 249.967,569.332 249.977,569.304 249.986,569.277 249.995,569.249 250.004,569.221 250.013,569.193 250.022,569.165 250.032,569.137 250.041,569.11 250.05,569.082 250.059,569.054 250.068,569.026 250.078,568.998 250.087,568.97 250.096,568.943 250.105,568.915 250.114,568.887 250.124,568.859 250.133,568.831 250.142,568.803 250.151,568.775 250.16,568.747 250.169,568.72 250.179,568.692 250.188,568.664 250.197,568.636 250.206,568.608 250.215,568.58 250.225,568.552 250.234,568.524 250.243,568.496 250.252,568.468 250.261,568.44 250.271,568.412 250.28,568.385 250.289,568.357 250.298,568.329 250.307,568.301 250.317,568.273 250.326,568.245 250.335,568.217 250.344,568.189 250.353,568.161 250.362,568.133 250.372,568.105 250.381,568.077 250.39,568.049 250.399,568.021 250.408,567.993 250.418,567.965 250.427,567.937 250.436,567.909 250.445,567.881 250.454,567.853 250.464,567.825 250.473,567.797 250.482,567.769 250.491,567.74 250.5,567.712 250.51,567.684 250.519,567.656 250.528,567.628 250.537,567.6 250.546,567.572 250.555,567.544 250.565,567.516 250.574,567.488 250.583,567.46 250.592,567.432 250.601,567.404 250.611,567.375 250.62,567.347 250.629,567.319 250.638,567.291 250.647,567.263 250.657,567.235 250.666,567.207 250.675,567.179 250.684,567.15 250.693,567.122 250.702,567.094 250.712,567.066 250.721,567.038 250.73,567.01 250.739,566.981 250.748,566.953 250.758,566.925 250.767,566.897 250.776,566.869 250.785,566.841 250.794,566.812 250.804,566.784 250.813,566.756 250.822,566.728 250.831,566.7 250.84,566.671 250.85,566.643 250.859,566.615 250.868,566.587 250.877,566.558 250.886,566.53 250.895,566.502 250.905,566.474 250.914,566.445 250.923,566.417 250.932,566.389 250.941,566.361 250.951,566.332 250.96,566.304 250.969,566.276 250.978,566.247 250.987,566.219 250.997,566.191 251.006,566.163 251.015,566.134 251.024,566.106 251.033,566.078 251.042,566.049 251.052,566.021 251.061,565.993 251.07,565.964 251.079,565.936 251.088,565.908 251.098,565.879 251.107,565.851 251.116,565.823 251.125,565.794 251.134,565.766 251.144,565.738 251.153,565.709 251.162,565.681 251.171,565.653 251.18,565.624 251.19,565.596 251.199,565.567 251.208,565.539 251.217,565.511 251.226,565.482 251.235,565.454 251.245,565.425 251.254,565.397 251.263,565.369 251.272,565.34 251.281,565.312 251.291,565.283 251.3,565.255 251.309,565.226 251.318,565.198 251.327,565.17 251.337,565.141 251.346,565.113 251.355,565.084 251.364,565.056 251.373,565.027 251.382,564.999 251.392,564.97 251.401,564.942 251.41,564.913 251.419,564.885 251.428,564.856 251.438,564.828 251.447,564.799 251.456,564.771 251.465,564.742 251.474,564.714 251.484,564.685 251.493,564.657 251.502,564.628 251.511,564.6 251.52,564.571 251.53,564.543 251.539,564.514 251.548,564.486 251.557,564.457 251.566,564.428 251.575,564.4 251.585,564.371 251.594,564.343 251.603,564.314 251.612,564.286 251.621,564.257 251.631,564.228 251.64,564.2 251.649,564.171 251.658,564.143 251.667,564.114 251.677,564.085 251.686,564.057 251.695,564.028 251.704,564 251.713,563.971 251.722,563.942 251.732,563.914 251.741,563.885 251.75,563.856 251.759,563.828 251.768,563.799 251.778,563.77 251.787,563.742 251.796,563.713 251.805,563.684 251.814,563.656 251.824,563.627 251.833,563.598 251.842,563.57 251.851,563.541 251.86,563.512 251.87,563.484 251.879,563.455 251.888,563.426 251.897,563.398 251.906,563.369 251.915,563.34 251.925,563.311 251.934,563.283 251.943,563.254 251.952,563.225 251.961,563.197 251.971,563.168 251.98,563.139 251.989,563.11 251.998,563.082 252.007,563.053 252.017,563.024 252.026,562.995 252.035,562.967 252.044,562.938 252.053,562.909 252.062,562.88 252.072,562.851 252.081,562.823 252.09,562.794 252.099,562.765 252.108,562.736 252.118,562.707 252.127,562.679 252.136,562.65 252.145,562.621 252.154,562.592 252.164,562.563 252.173,562.535 252.182,562.506 252.191,562.477 252.2,562.448 252.21,562.419 252.219,562.39 252.228,562.362 252.237,562.333 252.246,562.304 252.255,562.275 252.265,562.246 252.274,562.217 252.283,562.188 252.292,562.159 252.301,562.131 252.311,562.102 252.32,562.073 252.329,562.044 252.338,562.015 252.347,561.986 252.357,561.957 252.366,561.928 252.375,561.899 252.384,561.87 252.393,561.842 252.402,561.813 252.412,561.784 252.421,561.755 252.43,561.726 252.439,561.697 252.448,561.668 252.458,561.639 252.467,561.61 252.476,561.581 252.485,561.552 252.494,561.523 252.504,561.494 252.513,561.465 252.522,561.436 252.531,561.407 252.54,561.378 252.55,561.349 252.559,561.32 252.568,561.291 252.577,561.262 252.586,561.233 252.595,561.204 252.605,561.175 252.614,561.146 252.623,561.117 252.632,561.088 252.641,561.059 252.651,561.03 252.66,561.001 252.669,560.972 252.678,560.943 252.687,560.914 252.697,560.885 252.706,560.856 252.715,560.827 252.724,560.798 252.733,560.769 252.743,560.74 252.752,560.71 252.761,560.681 252.77,560.652 252.779,560.623 252.788,560.594 252.798,560.565 252.807,560.536 252.816,560.507 252.825,560.478 252.834,560.449 252.844,560.419 252.853,560.39 252.862,560.361 252.871,560.332 252.88,560.303 252.89,560.274 252.899,560.245 252.908,560.216 252.917,560.186 252.926,560.157 252.935,560.128 252.945,560.099 252.954,560.07 252.963,560.041 252.972,560.011 252.981,559.982 252.991,559.953 253,559.924 253.009,559.895 253.018,559.866 253.027,559.836 253.037,559.807 253.046,559.778 253.055,559.749 253.064,559.72 253.073,559.69 253.083,559.661 253.092,559.632 253.101,559.603 253.11,559.573 253.119,559.544 253.128,559.515 253.138,559.486 253.147,559.457 253.156,559.427 253.165,559.398 253.174,559.369 253.184,559.34 253.193,559.31 253.202,559.281 253.211,559.252 253.22,559.222 253.23,559.193 253.239,559.164 253.248,559.135 253.257,559.105 253.266,559.076 253.275,559.047 253.285,559.017 253.294,558.988 253.303,558.959 253.312,558.93 253.321,558.9 253.331,558.871 253.34,558.842 253.349,558.812 253.358,558.783 253.367,558.754 253.377,558.724 253.386,558.695 253.395,558.666 253.404,558.636 253.413,558.607 253.423,558.578 253.432,558.548 253.441,558.519 253.45,558.49 253.459,558.46 253.468,558.431 253.478,558.401 253.487,558.372 253.496,558.343 253.505,558.313 253.514,558.284 253.524,558.254 253.533,558.225 253.542,558.196 253.551,558.166 253.56,558.137 253.57,558.107 253.579,558.078 253.588,558.049 253.597,558.019 253.606,557.99 253.615,557.96 253.625,557.931 253.634,557.901 253.643,557.872 253.652,557.843 253.661,557.813 253.671,557.784 253.68,557.754 253.689,557.725 253.698,557.695 253.707,557.666 253.717,557.636 253.726,557.607 253.735,557.577 253.744,557.548 253.753,557.518 253.763,557.489 253.772,557.459 253.781,557.43 253.79,557.4 253.799,557.371 253.808,557.341 253.818,557.312 253.827,557.282 253.836,557.253 253.845,557.223 253.854,557.194 253.864,557.164 253.873,557.135 253.882,557.105 253.891,557.076 253.9,557.046 253.91,557.017 253.919,556.987 253.928,556.957 253.937,556.928 253.946,556.898 253.955,556.869 253.965,556.839 253.974,556.81 253.983,556.78 253.992,556.751 254.001,556.721 254.011,556.691 254.02,556.662 254.029,556.632 254.038,556.603 254.047,556.573 254.057,556.543 254.066,556.514 254.075,556.484 254.084,556.455 254.093,556.425 254.103,556.395 254.112,556.366 254.121,556.336 254.13,556.306 254.139,556.277 254.148,556.247 254.158,556.217 254.167,556.188 254.176,556.158 254.185,556.129 254.194,556.099 254.204,556.069 254.213,556.04 254.222,556.01 254.231,555.98 254.24,555.951 254.25,555.921 254.259,555.891 254.268,555.861 254.277,555.832 254.286,555.802 254.295,555.772 254.305,555.743 254.314,555.713 254.323,555.683 254.332,555.654 254.341,555.624 254.351,555.594 254.36,555.564 254.369,555.535 254.378,555.505 254.387,555.475 254.397,555.445 254.406,555.416 254.415,555.386 254.424,555.356 254.433,555.326 254.443,555.297 254.452,555.267 254.461,555.237 254.47,555.207 254.479,555.178 254.488,555.148 254.498,555.118 254.507,555.088 254.516,555.059 254.525,555.029 254.534,554.999 254.544,554.969 254.553,554.939 254.562,554.91 254.571,554.88 254.58,554.85 254.59,554.82 254.599,554.79 254.608,554.761 254.617,554.731 254.626,554.701 254.635,554.671 254.645,554.641 254.654,554.611 254.663,554.582 254.672,554.552 254.681,554.522 254.691,554.492 254.7,554.462 254.709,554.432 254.718,554.403 254.727,554.373 254.737,554.343 254.746,554.313 254.755,554.283 254.764,554.253 254.773,554.223 254.783,554.193 254.792,554.164 254.801,554.134 254.81,554.104 254.819,554.074 254.828,554.044 254.838,554.014 254.847,553.984 254.856,553.954 254.865,553.924 254.874,553.894 254.884,553.864 254.893,553.835 254.902,553.805 254.911,553.775 254.92,553.745 254.93,553.715 254.939,553.685 254.948,553.655 254.957,553.625 254.966,553.595 254.975,553.565 254.985,553.535 254.994,553.505 255.003,553.475 255.012,553.445 255.021,553.415 255.031,553.385 255.04,553.355 255.049,553.325 255.058,553.295 255.067,553.265 255.077,553.235 255.086,553.205 255.095,553.175 255.104,553.145 255.113,553.115 255.123,553.085 255.132,553.055 255.141,553.025 255.15,552.995 255.159,552.965 255.168,552.935 255.178,552.905 255.187,552.875 255.196,552.845 255.205,552.815 255.214,552.785 255.224,552.755 255.233,552.725 255.242,552.695 255.251,552.665 255.26,552.635 255.27,552.605 255.279,552.575 255.288,552.545 255.297,552.515 255.306,552.485 255.316,552.454 255.325,552.424 255.334,552.394 255.343,552.364 255.352,552.334 255.361,552.304 255.371,552.274 255.38,552.244 255.389,552.214 255.398,552.184 255.407,552.154 255.417,552.123 255.426,552.093 255.435,552.063 255.444,552.033 255.453,552.003 255.463,551.973 255.472,551.943 255.481,551.913 255.49,551.882 255.499,551.852 255.508,551.822 255.518,551.792 255.527,551.762 255.536,551.732 255.545,551.701 255.554,551.671 255.564,551.641 255.573,551.611 255.582,551.581 255.591,551.551 255.6,551.52 255.61,551.49 255.619,551.46 255.628,551.43 255.637,551.4 255.646,551.37 255.656,551.339 255.665,551.309 255.674,551.279 255.683,551.249 255.692,551.218 255.701,551.188 255.711,551.158 255.72,551.128 255.729,551.098 255.738,551.067 255.747,551.037 255.757,551.007 255.766,550.977 255.775,550.946 255.784,550.916 255.793,550.886 255.803,550.856 255.812,550.825 255.821,550.795 255.83,550.765 255.839,550.735 255.848,550.704 255.858,550.674 255.867,550.644 255.876,550.614 255.885,550.583 255.894,550.553 255.904,550.523 255.913,550.492 255.922,550.462 255.931,550.432 255.94,550.402 255.95,550.371 255.959,550.341 255.968,550.311 255.977,550.28 255.986,550.25 255.996,550.22 256.005,550.189 256.014,550.159 256.023,550.129 256.032,550.098 256.041,550.068 256.051,550.038 256.06,550.007 256.069,549.977 256.078,549.947 256.087,549.916 256.097,549.886 256.106,549.856 256.115,549.825 256.124,549.795 256.133,549.765 256.143,549.734 256.152,549.704 256.161,549.673 256.17,549.643 256.179,549.613 256.188,549.582 256.198,549.552 256.207,549.521 256.216,549.491 256.225,549.461 256.234,549.43 256.244,549.4 256.253,549.369 256.262,549.339 256.271,549.309 256.28,549.278 256.29,549.248 256.299,549.217 256.308,549.187 256.317,549.157 256.326,549.126 256.336,549.096 256.345,549.065 256.354,549.035 256.363,549.004 256.372,548.974 256.381,548.943 256.391,548.913 256.4,548.883 256.409,548.852 256.418,548.822 256.427,548.791 256.437,548.761 256.446,548.73 256.455,548.7 256.464,548.669 256.473,548.639 256.483,548.608 256.492,548.578 256.501,548.547 256.51,548.517 256.519,548.486 256.528,548.456 256.538,548.425 256.547,548.395 256.556,548.364 256.565,548.334 256.574,548.303 256.584,548.273 256.593,548.242 256.602,548.212 256.611,548.181 256.62,548.151 256.63,548.12 256.639,548.09 256.648,548.059 256.657,548.028 256.666,547.998 256.676,547.967 256.685,547.937 256.694,547.906 256.703,547.876 256.712,547.845 256.721,547.815 256.731,547.784 256.74,547.753 256.749,547.723 256.758,547.692 256.767,547.662 256.777,547.631 256.786,547.601 256.795,547.57 256.804,547.539 256.813,547.509 256.823,547.478 256.832,547.448 256.841,547.417 256.85,547.386 256.859,547.356 256.868,547.325 256.878,547.295 256.887,547.264 256.896,547.233 256.905,547.203 256.914,547.172 256.924,547.141 256.933,547.111 256.942,547.08 256.951,547.049 256.96,547.019 256.97,546.988 256.979,546.958 256.988,546.927 256.997,546.896 257.006,546.866 257.016,546.835 257.025,546.804 257.034,546.774 257.043,546.743 257.052,546.712 257.061,546.682 257.071,546.651 257.08,546.62 257.089,546.589 257.098,546.559 257.107,546.528 257.117,546.497 257.126,546.467 257.135,546.436 257.144,546.405 257.153,546.375 257.163,546.344 257.172,546.313 257.181,546.282 257.19,546.252 257.199,546.221 257.208,546.19 257.218,546.16 257.227,546.129 257.236,546.098 257.245,546.067 257.254,546.037 257.264,546.006 257.273,545.975 257.282,545.944 257.291,545.914 257.3,545.883 257.31,545.852 257.319,545.821 257.328,545.791 257.337,545.76 257.346,545.729 257.356,545.698 257.365,545.668 257.374,545.637 257.383,545.606 257.392,545.575 257.401,545.544 257.411,545.514 257.42,545.483 257.429,545.452 257.438,545.421 257.447,545.39 257.457,545.36 257.466,545.329 257.475,545.298 257.484,545.267 257.493,545.236 257.503,545.206 257.512,545.175 257.521,545.144 257.53,545.113 257.539,545.082 257.548,545.051 257.558,545.021 257.567,544.99 257.576,544.959 257.585,544.928 257.594,544.897 257.604,544.866 257.613,544.835 257.622,544.805 257.631,544.774 257.64,544.743 257.65,544.712 257.659,544.681 257.668,544.65 257.677,544.619 257.686,544.589 257.696,544.558 257.705,544.527 257.714,544.496 257.723,544.465 257.732,544.434 257.741,544.403 257.751,544.372 257.76,544.341 257.769,544.311 257.778,544.28 257.787,544.249 257.797,544.218 257.806,544.187 257.815,544.156 257.824,544.125 257.833,544.094 257.843,544.063 257.852,544.032 257.861,544.001 257.87,543.97 257.879,543.939 257.889,543.909 257.898,543.878 257.907,543.847 257.916,543.816 257.925,543.785 257.934,543.754 257.944,543.723 257.953,543.692 257.962,543.661 257.971,543.63 257.98,543.599 257.99,543.568 257.999,543.537 258.008,543.506 258.017,543.475 258.026,543.444 258.036,543.413 258.045,543.382 258.054,543.351 258.063,543.32 258.072,543.289 258.081,543.258 258.091,543.227 258.1,543.196 258.109,543.165 258.118,543.134 258.127,543.103 258.137,543.072 258.146,543.041 258.155,543.01 258.164,542.979 258.173,542.948 258.183,542.917 258.192,542.886 258.201,542.855 258.21,542.824 258.219,542.793 258.229,542.762 258.238,542.731 258.247,542.7 258.256,542.669 258.265,542.637 258.274,542.606 258.284,542.575 258.293,542.544 258.302,542.513 258.311,542.482 258.32,542.451 258.33,542.42 258.339,542.389 258.348,542.358 258.357,542.327 258.366,542.296 258.376,542.265 258.385,542.233 258.394,542.202 258.403,542.171 258.412,542.14 258.421,542.109 258.431,542.078 258.44,542.047 258.449,542.016 258.458,541.985 258.467,541.954 258.477,541.922 258.486,541.891 258.495,541.86 258.504,541.829 258.513,541.798 258.523,541.767 258.532,541.736 258.541,541.704 258.55,541.673 258.559,541.642 258.569,541.611 258.578,541.58 258.587,541.549 258.596,541.518 258.605,541.486 258.614,541.455 258.624,541.424 258.633,541.393 258.642,541.362 258.651,541.331 258.66,541.299 258.67,541.268 258.679,541.237 258.688,541.206 258.697,541.175 258.706,541.143 258.716,541.112 258.725,541.081 258.734,541.05 258.743,541.019 258.752,540.987 258.761,540.956 258.771,540.925 258.78,540.894 258.789,540.863 258.798,540.831 258.807,540.8 258.817,540.769 258.826,540.738 258.835,540.707 258.844,540.675 258.853,540.644 258.863,540.613 258.872,540.582 258.881,540.55 258.89,540.519 258.899,540.488 258.909,540.457 258.918,540.425 258.927,540.394 258.936,540.363 258.945,540.332 258.954,540.3 258.964,540.269 258.973,540.238 258.982,540.207 258.991,540.175 259,540.144 259.01,540.113 259.019,540.081 259.028,540.05 259.037,540.019 259.046,539.988 259.056,539.956 259.065,539.925 259.074,539.894 259.083,539.862 259.092,539.831 259.101,539.8 259.111,539.768 259.12,539.737 259.129,539.706 259.138,539.675 259.147,539.643 259.157,539.612 259.166,539.581 259.175,539.549 259.184,539.518 259.193,539.487 259.203,539.455 259.212,539.424 259.221,539.393 259.23,539.361 259.239,539.33 259.249,539.299 259.258,539.267 259.267,539.236 259.276,539.204 259.285,539.173 259.294,539.142 259.304,539.11 259.313,539.079 259.322,539.048 259.331,539.016 259.34,538.985 259.35,538.954 259.359,538.922 259.368,538.891 259.377,538.859 259.386,538.828 259.396,538.797 259.405,538.765 259.414,538.734 259.423,538.702 259.432,538.671 259.441,538.64 259.451,538.608 259.46,538.577 259.469,538.545 259.478,538.514 259.487,538.483 259.497,538.451 259.506,538.42 259.515,538.388 259.524,538.357 259.533,538.325 259.543,538.294 259.552,538.263 259.561,538.231 259.57,538.2 259.579,538.168 259.589,538.137 259.598,538.105 259.607,538.074 259.616,538.042 259.625,538.011 259.634,537.98 259.644,537.948 259.653,537.917 259.662,537.885 259.671,537.854 259.68,537.822 259.69,537.791 259.699,537.759 259.708,537.728 259.717,537.696 259.726,537.665 259.736,537.633 259.745,537.602 259.754,537.57 259.763,537.539 259.772,537.507 259.781,537.476 259.791,537.444 259.8,537.413 259.809,537.381 259.818,537.35 259.827,537.318 259.837,537.287 259.846,537.255 259.855,537.224 259.864,537.192 259.873,537.161 259.883,537.129 259.892,537.098 259.901,537.066 259.91,537.035 259.919,537.003 259.929,536.971 259.938,536.94 259.947,536.908 259.956,536.877 259.965,536.845 259.974,536.814 259.984,536.782 259.993,536.751 260.002,536.719 260.011,536.687 260.02,536.656 260.03,536.624 260.039,536.593 260.048,536.561 260.057,536.53 260.066,536.498 260.076,536.466 260.085,536.435 260.094,536.403 260.103,536.372 260.112,536.34 260.122,536.309 260.131,536.277 260.14,536.245 260.149,536.214 260.158,536.182 260.167,536.151 260.177,536.119 260.186,536.087 260.195,536.056 260.204,536.024 260.213,535.992 260.223,535.961 260.232,535.929 260.241,535.898 260.25,535.866 260.259,535.834 260.269,535.803 260.278,535.771 260.287,535.739 260.296,535.708 260.305,535.676 260.314,535.644 260.324,535.613 260.333,535.581 260.342,535.55 260.351,535.518 260.36,535.486 260.37,535.455 260.379,535.423 260.388,535.391 260.397,535.36 260.406,535.328 260.416,535.296 260.425,535.265 260.434,535.233 260.443,535.201 260.452,535.169 260.462,535.138 260.471,535.106 260.48,535.074 260.489,535.043 260.498,535.011 260.507,534.979 260.517,534.948 260.526,534.916 260.535,534.884 260.544,534.853 260.553,534.821 260.563,534.789 260.572,534.757 260.581,534.726 260.59,534.694 260.599,534.662 260.609,534.63 260.618,534.599 260.627,534.567 260.636,534.535 260.645,534.504 260.654,534.472 260.664,534.44 260.673,534.408 260.682,534.377 260.691,534.345 260.7,534.313 260.71,534.281 260.719,534.25 260.728,534.218 260.737,534.186 260.746,534.154 260.756,534.123 260.765,534.091 260.774,534.059 260.783,534.027 260.792,533.995 260.802,533.964 260.811,533.932 260.82,533.9 260.829,533.868 260.838,533.837 260.847,533.805 260.857,533.773 260.866,533.741 260.875,533.709 260.884,533.678 260.893,533.646 260.903,533.614 260.912,533.582 260.921,533.55 260.93,533.519 260.939,533.487 260.949,533.455 260.958,533.423 260.967,533.391 260.976,533.359 260.985,533.328 260.994,533.296 261.004,533.264 261.013,533.232 261.022,533.2 261.031,533.168 261.04,533.137 261.05,533.105 261.059,533.073 261.068,533.041 261.077,533.009 261.086,532.977 261.096,532.946 261.105,532.914 261.114,532.882 261.123,532.85 261.132,532.818 261.142,532.786 261.151,532.754 261.16,532.723 261.169,532.691 261.178,532.659 261.187,532.627 261.197,532.595 261.206,532.563 261.215,532.531 261.224,532.499 261.233,532.467 261.243,532.436 261.252,532.404 261.261,532.372 261.27,532.34 261.279,532.308 261.289,532.276 261.298,532.244 261.307,532.212 261.316,532.18 261.325,532.148 261.334,532.117 261.344,532.085 261.353,532.053 261.362,532.021 261.371,531.989 261.38,531.957 261.39,531.925 261.399,531.893 261.408,531.861 261.417,531.829 261.426,531.797 261.436,531.765 261.445,531.733 261.454,531.701 261.463,531.669 261.472,531.638 261.482,531.606 261.491,531.574 261.5,531.542 261.509,531.51 261.518,531.478 261.527,531.446 261.537,531.414 261.546,531.382 261.555,531.35 261.564,531.318 261.573,531.286 261.583,531.254 261.592,531.222 261.601,531.19 261.61,531.158 261.619,531.126 261.629,531.094 261.638,531.062 261.647,531.03 261.656,530.998 261.665,530.966 261.674,530.934 261.684,530.902 261.693,530.87 261.702,530.838 261.711,530.806 261.72,530.774 261.73,530.742 261.739,530.71 261.748,530.678 261.757,530.646 261.766,530.614 261.776,530.582 261.785,530.55 261.794,530.518 261.803,530.486 261.812,530.454 261.822,530.422 261.831,530.39 261.84,530.358 261.849,530.326 261.858,530.293 261.867,530.261 261.877,530.229 261.886,530.197 261.895,530.165 261.904,530.133 261.913,530.101 261.923,530.069 261.932,530.037 261.941,530.005 261.95,529.973 261.959,529.941 261.969,529.909 261.978,529.877 261.987,529.845 261.996,529.812 262.005,529.78 262.014,529.748 262.024,529.716 262.033,529.684 262.042,529.652 262.051,529.62 262.06,529.588 262.07,529.556 262.079,529.524 262.088,529.492 262.097,529.459 262.106,529.427 262.116,529.395 262.125,529.363 262.134,529.331 262.143,529.299 262.152,529.267 262.162,529.235 262.171,529.203 262.18,529.17 262.189,529.138 262.198,529.106 262.207,529.074 262.217,529.042 262.226,529.01 262.235,528.978 262.244,528.945 262.253,528.913 262.263,528.881 262.272,528.849 262.281,528.817 262.29,528.785 262.299,528.753 262.309,528.72 262.318,528.688 262.327,528.656 262.336,528.624 262.345,528.592 262.354,528.56 262.364,528.527 262.373,528.495 262.382,528.463 262.391,528.431 262.4,528.399 262.41,528.366 262.419,528.334 262.428,528.302 262.437,528.27 262.446,528.238 262.456,528.206 262.465,528.173 262.474,528.141 262.483,528.109 262.492,528.077 262.502,528.045 262.511,528.012 262.52,527.98 262.529,527.948 262.538,527.916 262.547,527.883 262.557,527.851 262.566,527.819 262.575,527.787 262.584,527.755 262.593,527.722 262.603,527.69 262.612,527.658 262.621,527.626 262.63,527.593 262.639,527.561 262.649,527.529 262.658,527.497 262.667,527.464 262.676,527.432 262.685,527.4 262.695,527.368 262.704,527.335 262.713,527.303 262.722,527.271 262.731,527.239 262.74,527.206 262.75,527.174 262.759,527.142 262.768,527.11 262.777,527.077 262.786,527.045 262.796,527.013 262.805,526.981 262.814,526.948 262.823,526.916 262.832,526.884 262.842,526.851 262.851,526.819 262.86,526.787 262.869,526.755 262.878,526.722 262.887,526.69 262.897,526.658 262.906,526.625 262.915,526.593 262.924,526.561 262.933,526.528 262.943,526.496 262.952,526.464 262.961,526.431 262.97,526.399 262.979,526.367 262.989,526.335 262.998,526.302 263.007,526.27 263.016,526.238 263.025,526.205 263.035,526.173 263.044,526.141 263.053,526.108 263.062,526.076 263.071,526.044 263.08,526.011 263.09,525.979 263.099,525.947 263.108,525.914 263.117,525.882 263.126,525.849 263.136,525.817 263.145,525.785 263.154,525.752 263.163,525.72 263.172,525.688 263.182,525.655 263.191,525.623 263.2,525.591 263.209,525.558 263.218,525.526 263.227,525.493 263.237,525.461 263.246,525.429 263.255,525.396 263.264,525.364 263.273,525.332 263.283,525.299 263.292,525.267 263.301,525.234 263.31,525.202 263.319,525.17 263.329,525.137 263.338,525.105 263.347,525.072 263.356,525.04 263.365,525.008 263.375,524.975 263.384,524.943 263.393,524.91 263.402,524.878 263.411,524.846 263.42,524.813 263.43,524.781 263.439,524.748 263.448,524.716 263.457,524.683 263.466,524.651 263.476,524.619 263.485,524.586 263.494,524.554 263.503,524.521 263.512,524.489 263.522,524.456 263.531,524.424 263.54,524.391 263.549,524.359 263.558,524.327 263.567,524.294 263.577,524.262 263.586,524.229 263.595,524.197 263.604,524.164 263.613,524.132 263.623,524.099 263.632,524.067 263.641,524.034 263.65,524.002 263.659,523.969 263.669,523.937 263.678,523.904 263.687,523.872 263.696,523.84 263.705,523.807 263.715,523.775 263.724,523.742 263.733,523.71 263.742,523.677 263.751,523.645 263.76,523.612 263.77,523.58 263.779,523.547 263.788,523.515 263.797,523.482 263.806,523.45 263.816,523.417 263.825,523.385 263.834,523.352 263.843,523.32 263.852,523.287 263.862,523.254 263.871,523.222 263.88,523.189 263.889,523.157 263.898,523.124 263.907,523.092 263.917,523.059 263.926,523.027 263.935,522.994 263.944,522.962 263.953,522.929 263.963,522.897 263.972,522.864 263.981,522.832 263.99,522.799 263.999,522.766 264.009,522.734 264.018,522.701 264.027,522.669 264.036,522.636 264.045,522.604 264.055,522.571 264.064,522.539 264.073,522.506 264.082,522.473 264.091,522.441 264.1,522.408 264.11,522.376 264.119,522.343 264.128,522.311 264.137,522.278 264.146,522.245 264.156,522.213 264.165,522.18 264.174,522.148 264.183,522.115 264.192,522.082 264.202,522.05 264.211,522.017 264.22,521.985 264.229,521.952 264.238,521.919 264.247,521.887 264.257,521.854 264.266,521.822 264.275,521.789 264.284,521.756 264.293,521.724 264.303,521.691 264.312,521.659 264.321,521.626 264.33,521.593 264.339,521.561 264.349,521.528 264.358,521.495 264.367,521.463 264.376,521.43 264.385,521.398 264.395,521.365 264.404,521.332 264.413,521.3 264.422,521.267 264.431,521.234 264.44,521.202 264.45,521.169 264.459,521.136 264.468,521.104 264.477,521.071 264.486,521.038 264.496,521.006 264.505,520.973 264.514,520.94 264.523,520.908 264.532,520.875 264.542,520.842 264.551,520.81 264.56,520.777 264.569,520.744 264.578,520.712 264.587,520.679 264.597,520.646 264.606,520.614 264.615,520.581 264.624,520.548 264.633,520.516 264.643,520.483 264.652,520.45 264.661,520.418 264.67,520.385 264.679,520.352 264.689,520.32 264.698,520.287 264.707,520.254 264.716,520.221 264.725,520.189 264.735,520.156 264.744,520.123 264.753,520.091 264.762,520.058 264.771,520.025 264.78,519.992 264.79,519.96 264.799,519.927 264.808,519.894 264.817,519.862 264.826,519.829 264.836,519.796 264.845,519.763 264.854,519.731 264.863,519.698 264.872,519.665 264.882,519.632 264.891,519.6 264.9,519.567 264.909,519.534 264.918,519.501 264.927,519.469 264.937,519.436 264.946,519.403 264.955,519.37 264.964,519.338 264.973,519.305 264.983,519.272 264.992,519.239 265.001,519.207 265.01,519.174 265.019,519.141 265.029,519.108 265.038,519.076 265.047,519.043 265.056,519.01 265.065,518.977 265.075,518.944 265.084,518.912 265.093,518.879 265.102,518.846 265.111,518.813 265.12,518.78 265.13,518.748 265.139,518.715 265.148,518.682 265.157,518.649 265.166,518.616 265.176,518.584 265.185,518.551 265.194,518.518 265.203,518.485 265.212,518.452 265.222,518.42 265.231,518.387 265.24,518.354 265.249,518.321 265.258,518.288 265.268,518.256 265.277,518.223 265.286,518.19 265.295,518.157 265.304,518.124 265.313,518.091 265.323,518.059 265.332,518.026 265.341,517.993 265.35,517.96 265.359,517.927 265.369,517.894 265.378,517.862 265.387,517.829 265.396,517.796 265.405,517.763 265.415,517.73 265.424,517.697 265.433,517.664 265.442,517.632 265.451,517.599 265.46,517.566 265.47,517.533 265.479,517.5 265.488,517.467 265.497,517.434 265.506,517.402 265.516,517.369 265.525,517.336 265.534,517.303 265.543,517.27 265.552,517.237 265.562,517.204 265.571,517.171 265.58,517.139 265.589,517.106 265.598,517.073 265.608,517.04 265.617,517.007 265.626,516.974 265.635,516.941 265.644,516.908 265.653,516.875 265.663,516.843 265.672,516.81 265.681,516.777 265.69,516.744 265.699,516.711 265.709,516.678 265.718,516.645 265.727,516.612 265.736,516.579 265.745,516.546 265.755,516.513 265.764,516.481 265.773,516.448 265.782,516.415 265.791,516.382 265.8,516.349 265.81,516.316 265.819,516.283 265.828,516.25 265.837,516.217 265.846,516.184 265.856,516.151 265.865,516.118 265.874,516.085 265.883,516.052 265.892,516.019 265.902,515.986 265.911,515.954 265.92,515.921 265.929,515.888 265.938,515.855 265.948,515.822 265.957,515.789 265.966,515.756 265.975,515.723 265.984,515.69 265.993,515.657 266.003,515.624 266.012,515.591 266.021,515.558 266.03,515.525 266.039,515.492 266.049,515.459 266.058,515.426 266.067,515.393 266.076,515.36 266.085,515.327 266.095,515.294 266.104,515.261 266.113,515.228 266.122,515.195 266.131,515.162 266.14,515.129 266.15,515.096 266.159,515.063 266.168,515.03 266.177,514.997 266.186,514.964 266.196,514.931 266.205,514.898 266.214,514.865 266.223,514.832 266.232,514.799 266.242,514.766 266.251,514.733 266.26,514.7 266.269,514.667 266.278,514.634 266.288,514.601 266.297,514.568 266.306,514.535 266.315,514.502 266.324,514.469 266.333,514.436 266.343,514.403 266.352,514.37 266.361,514.337 266.37,514.304 266.379,514.271 266.389,514.238 266.398,514.205 266.407,514.172 266.416,514.139 266.425,514.105 266.435,514.072 266.444,514.039 266.453,514.006 266.462,513.973 266.471,513.94 266.48,513.907 266.49,513.874 266.499,513.841 266.508,513.808 266.517,513.775 266.526,513.742 266.536,513.709 266.545,513.676 266.554,513.643 266.563,513.61 266.572,513.576 266.582,513.543 266.591,513.51 266.6,513.477 266.609,513.444 266.618,513.411 266.628,513.378 266.637,513.345 266.646,513.312 266.655,513.279 266.664,513.246 266.673,513.212 266.683,513.179 266.692,513.146 266.701,513.113 266.71,513.08 266.719,513.047 266.729,513.014 266.738,512.981 266.747,512.948 266.756,512.915 266.765,512.881 266.775,512.848 266.784,512.815 266.793,512.782 266.802,512.749 266.811,512.716 266.82,512.683 266.83,512.65 266.839,512.616 266.848,512.583 266.857,512.55 266.866,512.517 266.876,512.484 266.885,512.451 266.894,512.418 266.903,512.384 266.912,512.351 266.922,512.318 266.931,512.285 266.94,512.252 266.949,512.219 266.958,512.186 266.968,512.152 266.977,512.119 266.986,512.086 266.995,512.053 267.004,512.02 267.013,511.987 267.023,511.953 267.032,511.92 267.041,511.887 267.05,511.854 267.059,511.821 267.069,511.788 267.078,511.754 267.087,511.721 267.096,511.688 267.105,511.655 267.115,511.622 267.124,511.589 267.133,511.555 267.142,511.522 267.151,511.489 267.16,511.456 267.17,511.423 267.179,511.389 267.188,511.356 267.197,511.323 267.206,511.29 267.216,511.257 267.225,511.223 267.234,511.19 267.243,511.157 267.252,511.124 267.262,511.091 267.271,511.057 267.28,511.024 267.289,510.991 267.298,510.958 267.308,510.925 267.317,510.891 267.326,510.858 267.335,510.825 267.344,510.792 267.353,510.758 267.363,510.725 267.372,510.692 267.381,510.659 267.39,510.626 267.399,510.592 267.409,510.559 267.418,510.526 267.427,510.493 267.436,510.459 267.445,510.426 267.455,510.393 267.464,510.36 267.473,510.326 267.482,510.293 267.491,510.26 267.501,510.227 267.51,510.193 267.519,510.16 267.528,510.127 267.537,510.094 267.546,510.06 267.556,510.027 267.565,509.994 267.574,509.961 267.583,509.927 267.592,509.894 267.602,509.861 267.611,509.828 267.62,509.794 267.629,509.761 267.638,509.728 267.648,509.694 267.657,509.661 267.666,509.628 267.675,509.595 267.684,509.561 267.693,509.528 267.703,509.495 267.712,509.461 267.721,509.428 267.73,509.395 267.739,509.362 267.749,509.328 267.758,509.295 267.767,509.262 267.776,509.228 267.785,509.195 267.795,509.162 267.804,509.128 267.813,509.095 267.822,509.062 267.831,509.029 267.841,508.995 267.85,508.962 267.859,508.929 267.868,508.895 267.877,508.862 267.886,508.829 267.896,508.795 267.905,508.762 267.914,508.729 267.923,508.695 267.932,508.662 267.942,508.629 267.951,508.595 267.96,508.562 267.969,508.529 267.978,508.495 267.988,508.462 267.997,508.429 268.006,508.395 268.015,508.362 268.024,508.329 268.033,508.295 268.043,508.262 268.052,508.229 268.061,508.195 268.07,508.162 268.079,508.129 268.089,508.095 268.098,508.062 268.107,508.028 268.116,507.995 268.125,507.962 268.135,507.928 268.144,507.895 268.153,507.862 268.162,507.828 268.171,507.795 268.181,507.762 268.19,507.728 268.199,507.695 268.208,507.661 268.217,507.628 268.226,507.595 268.236,507.561 268.245,507.528 268.254,507.495 268.263,507.461 268.272,507.428 268.282,507.394 268.291,507.361 268.3,507.328 268.309,507.294 268.318,507.261 268.328,507.227 268.337,507.194 268.346,507.161 268.355,507.127 268.364,507.094 268.373,507.06 268.383,507.027 268.392,506.994 268.401,506.96 268.41,506.927 268.419,506.893 268.429,506.86 268.438,506.827 268.447,506.793 268.456,506.76 268.465,506.726 268.475,506.693 268.484,506.659 268.493,506.626 268.502,506.593 268.511,506.559 268.521,506.526 268.53,506.492 268.539,506.459 268.548,506.425 268.557,506.392 268.566,506.359 268.576,506.325 268.585,506.292 268.594,506.258 268.603,506.225 268.612,506.191 268.622,506.158 268.631,506.124 268.64,506.091 268.649,506.058 268.658,506.024 268.668,505.991 268.677,505.957 268.686,505.924 268.695,505.89 268.704,505.857 268.713,505.823 268.723,505.79 268.732,505.756 268.741,505.723 268.75,505.689 268.759,505.656 268.769,505.623 268.778,505.589 268.787,505.556 268.796,505.522 268.805,505.489 268.815,505.455 268.824,505.422 268.833,505.388 268.842,505.355 268.851,505.321 268.861,505.288 268.87,505.254 268.879,505.221 268.888,505.187 268.897,505.154 268.906,505.12 268.916,505.087 268.925,505.053 268.934,505.02 268.943,504.986 268.952,504.953 268.962,504.919 268.971,504.886 268.98,504.852 268.989,504.819 268.998,504.785 269.008,504.752 269.017,504.718 269.026,504.685 269.035,504.651 269.044,504.618 269.053,504.584 269.063,504.551 269.072,504.517 269.081,504.484 269.09,504.45 269.099,504.416 269.109,504.383 269.118,504.349 269.127,504.316 269.136,504.282 269.145,504.249 269.155,504.215 269.164,504.182 269.173,504.148 269.182,504.115 269.191,504.081 269.201,504.048 269.21,504.014 269.219,503.981 269.228,503.947 269.237,503.913 269.246,503.88 269.256,503.846 269.265,503.813 269.274,503.779 269.283,503.746 269.292,503.712 269.302,503.679 269.311,503.645 269.32,503.611 269.329,503.578 269.338,503.544 269.348,503.511 269.357,503.477 269.366,503.444 269.375,503.41 269.384,503.376 269.393,503.343 269.403,503.309 269.412,503.276 269.421,503.242 269.43,503.209 269.439,503.175 269.449,503.141 269.458,503.108 269.467,503.074 269.476,503.041 269.485,503.007 269.495,502.973 269.504,502.94 269.513,502.906 269.522,502.873 269.531,502.839 269.541,502.805 269.55,502.772 269.559,502.738 269.568,502.705 269.577,502.671 269.586,502.637 269.596,502.604 269.605,502.57 269.614,502.537 269.623,502.503 269.632,502.469 269.642,502.436 269.651,502.402 269.66,502.369 269.669,502.335 269.678,502.301 269.688,502.268 269.697,502.234 269.706,502.2 269.715,502.167 269.724,502.133 269.733,502.1 269.743,502.066 269.752,502.032 269.761,501.999 269.77,501.965 269.779,501.931 269.789,501.898 269.798,501.864 269.807,501.83 269.816,501.797 269.825,501.763 269.835,501.73 269.844,501.696 269.853,501.662 269.862,501.629 269.871,501.595 269.881,501.561 269.89,501.528 269.899,501.494 269.908,501.46 269.917,501.427 269.926,501.393 269.936,501.359 269.945,501.326 269.954,501.292 269.963,501.258 269.972,501.225 269.982,501.191 269.991,501.157 270,501.124 270.009,501.09 270.018,501.056 270.028,501.023 270.037,500.989 270.046,500.955 270.055,500.922 270.064,500.888 270.074,500.854 270.083,500.821 270.092,500.787 270.101,500.753 270.11,500.719 270.119,500.686 270.129,500.652 270.138,500.618 270.147,500.585 270.156,500.551 270.165,500.517 270.175,500.484 270.184,500.45 270.193,500.416 270.202,500.382 270.211,500.349 270.221,500.315 270.23,500.281 270.239,500.248 270.248,500.214 270.257,500.18 270.266,500.147 270.276,500.113 270.285,500.079 270.294,500.045 270.303,500.012 270.312,499.978 270.322,499.944 270.331,499.911 270.34,499.877 270.349,499.843 270.358,499.809 270.368,499.776 270.377,499.742 270.386,499.708 270.395,499.674 270.404,499.641 270.414,499.607 270.423,499.573 270.432,499.539 270.441,499.506 270.45,499.472 270.459,499.438 270.469,499.404 270.478,499.371 270.487,499.337 270.496,499.303 270.505,499.27 270.515,499.236 270.524,499.202 270.533,499.168 270.542,499.134 270.551,499.101 270.561,499.067 270.57,499.033 270.579,498.999 270.588,498.966 270.597,498.932 270.606,498.898 270.616,498.864 270.625,498.831 270.634,498.797 270.643,498.763 270.652,498.729 270.662,498.696 270.671,498.662 270.68,498.628 270.689,498.594 270.698,498.56 270.708,498.527 270.717,498.493 270.726,498.459 270.735,498.425 270.744,498.392 270.754,498.358 270.763,498.324 270.772,498.29 270.781,498.256 270.79,498.223 270.799,498.189 270.809,498.155 270.818,498.121 270.827,498.087 270.836,498.054 270.845,498.02 270.855,497.986 270.864,497.952 270.873,497.918 270.882,497.885 270.891,497.851 270.901,497.817 270.91,497.783 270.919,497.749 270.928,497.716 270.937,497.682 270.946,497.648 270.956,497.614 270.965,497.58 270.974,497.546 270.983,497.513 270.992,497.479 271.002,497.445 271.011,497.411 271.02,497.377 271.029,497.344 271.038,497.31 271.048,497.276 271.057,497.242 271.066,497.208 271.075,497.174 271.084,497.141 271.094,497.107 271.103,497.073 271.112,497.039 271.121,497.005 271.13,496.971 271.139,496.937 271.149,496.904 271.158,496.87 271.167,496.836 271.176,496.802 271.185,496.768 271.195,496.734 271.204,496.701 271.213,496.667 271.222,496.633 271.231,496.599 271.241,496.565 271.25,496.531 271.259,496.497 271.268,496.464 271.277,496.43 271.286,496.396 271.296,496.362 271.305,496.328 271.314,496.294 271.323,496.26 271.332,496.226 271.342,496.193 271.351,496.159 271.36,496.125 271.369,496.091 271.378,496.057 271.388,496.023 271.397,495.989 271.406,495.955 271.415,495.922 271.424,495.888 271.434,495.854 271.443,495.82 271.452,495.786 271.461,495.752 271.47,495.718 271.479,495.684 271.489,495.65 271.498,495.617 271.507,495.583 271.516,495.549 271.525,495.515 271.535,495.481 271.544,495.447 271.553,495.413 271.562,495.379 271.571,495.345 271.581,495.311 271.59,495.278 271.599,495.244 271.608,495.21 271.617,495.176 271.626,495.142 271.636,495.108 271.645,495.074 271.654,495.04 271.663,495.006 271.672,494.972 271.682,494.938 271.691,494.904 271.7,494.871 271.709,494.837 271.718,494.803 271.728,494.769 271.737,494.735 271.746,494.701 271.755,494.667 271.764,494.633 271.774,494.599 271.783,494.565 271.792,494.531 271.801,494.497 271.81,494.463 271.819,494.429 271.829,494.395 271.838,494.361 271.847,494.328 271.856,494.294 271.865,494.26 271.875,494.226 271.884,494.192 271.893,494.158 271.902,494.124 271.911,494.09 271.921,494.056 271.93,494.022 271.939,493.988 271.948,493.954 271.957,493.92 271.966,493.886 271.976,493.852 271.985,493.818 271.994,493.784 272.003,493.75 272.012,493.716 272.022,493.682 272.031,493.648 272.04,493.614 272.049,493.58 272.058,493.546 272.068,493.512 272.077,493.479 272.086,493.445 272.095,493.411 272.104,493.377 272.114,493.343 272.123,493.309 272.132,493.275 272.141,493.241 272.15,493.207 272.159,493.173 272.169,493.139 272.178,493.105 272.187,493.071 272.196,493.037 272.205,493.003 272.215,492.969 272.224,492.935 272.233,492.901 272.242,492.867 272.251,492.833 272.261,492.799 272.27,492.765 272.279,492.731 272.288,492.697 272.297,492.663 272.306,492.629 272.316,492.595 272.325,492.561 272.334,492.527 272.343,492.493 272.352,492.459 272.362,492.425 272.371,492.391 272.38,492.357 272.389,492.323 272.398,492.289 272.408,492.255 272.417,492.22 272.426,492.186 272.435,492.152 272.444,492.118 272.454,492.084 272.463,492.05 272.472,492.016 272.481,491.982 272.49,491.948 272.499,491.914 272.509,491.88 272.518,491.846 272.527,491.812 272.536,491.778 272.545,491.744 272.555,491.71 272.564,491.676 272.573,491.642 272.582,491.608 272.591,491.574 272.601,491.54 272.61,491.506 272.619,491.472 272.628,491.438 272.637,491.404 272.647,491.37 272.656,491.335 272.665,491.301 272.674,491.267 272.683,491.233 272.692,491.199 272.702,491.165 272.711,491.131 272.72,491.097 272.729,491.063 272.738,491.029 272.748,490.995 272.757,490.961 272.766,490.927 272.775,490.893 272.784,490.859 272.794,490.824 272.803,490.79 272.812,490.756 272.821,490.722 272.83,490.688 272.839,490.654 272.849,490.62 272.858,490.586 272.867,490.552 272.876,490.518 272.885,490.484 272.895,490.45 272.904,490.416 272.913,490.381 272.922,490.347 272.931,490.313 272.941,490.279 272.95,490.245 272.959,490.211 272.968,490.177 272.977,490.143 272.987,490.109 272.996,490.075 273.005,490.04 273.014,490.006 273.023,489.972 273.032,489.938 273.042,489.904 273.051,489.87 273.06,489.836 273.069,489.802 273.078,489.768 273.088,489.734 273.097,489.699 273.106,489.665 273.115,489.631 273.124,489.597 273.134,489.563 273.143,489.529 273.152,489.495 273.161,489.461 273.17,489.426 273.179,489.392 273.189,489.358 273.198,489.324 273.207,489.29 273.216,489.256 273.225,489.222 273.235,489.188 273.244,489.153 273.253,489.119 273.262,489.085 273.271,489.051 273.281,489.017 273.29,488.983 273.299,488.949 273.308,488.914 273.317,488.88 273.327,488.846 273.336,488.812 273.345,488.778 273.354,488.744 273.363,488.71 273.372,488.675 273.382,488.641 273.391,488.607 273.4,488.573 273.409,488.539 273.418,488.505 273.428,488.471 273.437,488.436 273.446,488.402 273.455,488.368 273.464,488.334 273.474,488.3 273.483,488.266 273.492,488.231 273.501,488.197 273.51,488.163 273.519,488.129 273.529,488.095 273.538,488.061 273.547,488.026 273.556,487.992 273.565,487.958 273.575,487.924 273.584,487.89 273.593,487.856 273.602,487.821 273.611,487.787 273.621,487.753 273.63,487.719 273.639,487.685 273.648,487.65 273.657,487.616 273.667,487.582 273.676,487.548 273.685,487.514 273.694,487.48 273.703,487.445 273.712,487.411 273.722,487.377 273.731,487.343 273.74,487.309 273.749,487.274 273.758,487.24 273.768,487.206 273.777,487.172 273.786,487.138 273.795,487.103 273.804,487.069 273.814,487.035 273.823,487.001 273.832,486.967 273.841,486.932 273.85,486.898 273.859,486.864 273.869,486.83 273.878,486.796 273.887,486.761 273.896,486.727 273.905,486.693 273.915,486.659 273.924,486.624 273.933,486.59 273.942,486.556 273.951,486.522 273.961,486.488 273.97,486.453 273.979,486.419 273.988,486.385 273.997,486.351 274.007,486.316 274.016,486.282 274.025,486.248 274.034,486.214 274.043,486.18 274.052,486.145 274.062,486.111 274.071,486.077 274.08,486.043 274.089,486.008 274.098,485.974 274.108,485.94 274.117,485.906 274.126,485.871 274.135,485.837 274.144,485.803 274.154,485.769 274.163,485.734 274.172,485.7 274.181,485.666 274.19,485.632 274.199,485.597 274.209,485.563 274.218,485.529 274.227,485.495 274.236,485.46 274.245,485.426 274.255,485.392 274.264,485.358 274.273,485.323 274.282,485.289 274.291,485.255 274.301,485.221 274.31,485.186 274.319,485.152 274.328,485.118 274.337,485.084 274.347,485.049 274.356,485.015 274.365,484.981 274.374,484.946 274.383,484.912 274.392,484.878 274.402,484.844 274.411,484.809 274.42,484.775 274.429,484.741 274.438,484.706 274.448,484.672 274.457,484.638 274.466,484.604 274.475,484.569 274.484,484.535 274.494,484.501 274.503,484.467 274.512,484.432 274.521,484.398 274.53,484.364 274.539,484.329 274.549,484.295 274.558,484.261 274.567,484.226 274.576,484.192 274.585,484.158 274.595,484.124 274.604,484.089 274.613,484.055 274.622,484.021 274.631,483.986 274.641,483.952 274.65,483.918 274.659,483.883 274.668,483.849 274.677,483.815 274.687,483.781 274.696,483.746 274.705,483.712 274.714,483.678 274.723,483.643 274.732,483.609 274.742,483.575 274.751,483.54 274.76,483.506 274.769,483.472 274.778,483.437 274.788,483.403 274.797,483.369 274.806,483.334 274.815,483.3 274.824,483.266 274.834,483.231 274.843,483.197 274.852,483.163 274.861,483.128 274.87,483.094 274.88,483.06 274.889,483.025 274.898,482.991 274.907,482.957 274.916,482.922 274.925,482.888 274.935,482.854 274.944,482.819 274.953,482.785 274.962,482.751 274.971,482.716 274.981,482.682 274.99,482.648 274.999,482.613 275.008,482.579 275.017,482.545 275.027,482.51 275.036,482.476 275.045,482.442 275.054,482.407 275.063,482.373 275.072,482.339 275.082,482.304 275.091,482.27 275.1,482.236 275.109,482.201 275.118,482.167 275.128,482.132 275.137,482.098 275.146,482.064 275.155,482.029 275.164,481.995 275.174,481.961 275.183,481.926 275.192,481.892 275.201,481.858 275.21,481.823 275.22,481.789 275.229,481.754 275.238,481.72 275.247,481.686 275.256,481.651 275.265,481.617 275.275,481.583 275.284,481.548 275.293,481.514 275.302,481.479 275.311,481.445 275.321,481.411 275.33,481.376 275.339,481.342 275.348,481.308 275.357,481.273 275.367,481.239 275.376,481.204 275.385,481.17 275.394,481.136 275.403,481.101 275.412,481.067 275.422,481.032 275.431,480.998 275.44,480.964 275.449,480.929 275.458,480.895 275.468,480.86 275.477,480.826 275.486,480.792 275.495,480.757 275.504,480.723 275.514,480.688 275.523,480.654 275.532,480.62 275.541,480.585 275.55,480.551 275.56,480.516 275.569,480.482 275.578,480.448 275.587,480.413 275.596,480.379 275.605,480.344 275.615,480.31 275.624,480.276 275.633,480.241 275.642,480.207 275.651,480.172 275.661,480.138 275.67,480.103 275.679,480.069 275.688,480.035 275.697,480 275.707,479.966 275.716,479.931 275.725,479.897 275.734,479.862 275.743,479.828 275.752,479.794 275.762,479.759 275.771,479.725 275.78,479.69 275.789,479.656 275.798,479.621 275.808,479.587 275.817,479.553 275.826,479.518 275.835,479.484 275.844,479.449 275.854,479.415 275.863,479.38 275.872,479.346 275.881,479.312 275.89,479.277 275.9,479.243 275.909,479.208 275.918,479.174 275.927,479.139 275.936,479.105 275.945,479.07 275.955,479.036 275.964,479.001 275.973,478.967 275.982,478.933 275.991,478.898 276.001,478.864 276.01,478.829 276.019,478.795 276.028,478.76 276.037,478.726 276.047,478.691 276.056,478.657 276.065,478.622 276.074,478.588 276.083,478.554 276.092,478.519 276.102,478.485 276.111,478.45 276.12,478.416 276.129,478.381 276.138,478.347 276.148,478.312 276.157,478.278 276.166,478.243 276.175,478.209 276.184,478.174 276.194,478.14 276.203,478.105 276.212,478.071 276.221,478.036 276.23,478.002 276.24,477.967 276.249,477.933 276.258,477.898 276.267,477.864 276.276,477.83 276.285,477.795 276.295,477.761 276.304,477.726 276.313,477.692 276.322,477.657 276.331,477.623 276.341,477.588 276.35,477.554 276.359,477.519 276.368,477.485 276.377,477.45 276.387,477.416 276.396,477.381 276.405,477.347 276.414,477.312 276.423,477.278 276.432,477.243 276.442,477.209 276.451,477.174 276.46,477.14 276.469,477.105 276.478,477.071 276.488,477.036 276.497,477.002 276.506,476.967 276.515,476.933 276.524,476.898 276.534,476.864 276.543,476.829 276.552,476.795 276.561,476.76 276.57,476.725 276.58,476.691 276.589,476.656 276.598,476.622 276.607,476.587 276.616,476.553 276.625,476.518 276.635,476.484 276.644,476.449 276.653,476.415 276.662,476.38 276.671,476.346 276.681,476.311 276.69,476.277 276.699,476.242 276.708,476.208 276.717,476.173 276.727,476.139 276.736,476.104 276.745,476.07 276.754,476.035 276.763,476 276.772,475.966 276.782,475.931 276.791,475.897 276.8,475.862 276.809,475.828 276.818,475.793 276.828,475.759 276.837,475.724 276.846,475.69 276.855,475.655 276.864,475.62 276.874,475.586 276.883,475.551 276.892,475.517 276.901,475.482 276.91,475.448 276.92,475.413 276.929,475.379 276.938,475.344 276.947,475.31 276.956,475.275 276.965,475.24 276.975,475.206 276.984,475.171 276.993,475.137 277.002,475.102 277.011,475.068 277.021,475.033 277.03,474.999 277.039,474.964 277.048,474.929 277.057,474.895 277.067,474.86 277.076,474.826 277.085,474.791 277.094,474.757 277.103,474.722 277.112,474.687 277.122,474.653 277.131,474.618 277.14,474.584 277.149,474.549 277.158,474.515 277.168,474.48 277.177,474.445 277.186,474.411 277.195,474.376 277.204,474.342 277.214,474.307 277.223,474.272 277.232,474.238 277.241,474.203 277.25,474.169 277.26,474.134 277.269,474.1 277.278,474.065 277.287,474.03 277.296,473.996 277.305,473.961 277.315,473.927 277.324,473.892 277.333,473.857 277.342,473.823 277.351,473.788 277.361,473.754 277.37,473.719 277.379,473.684 277.388,473.65 277.397,473.615 277.407,473.581 277.416,473.546 277.425,473.511 277.434,473.477 277.443,473.442 277.453,473.408 277.462,473.373 277.471,473.338 277.48,473.304 277.489,473.269 277.498,473.235 277.508,473.2 277.517,473.165 277.526,473.131 277.535,473.096 277.544,473.062 277.554,473.027 277.563,472.992 277.572,472.958 277.581,472.923 277.59,472.889 277.6,472.854 277.609,472.819 277.618,472.785 277.627,472.75 277.636,472.715 277.645,472.681 277.655,472.646 277.664,472.612 277.673,472.577 277.682,472.542 277.691,472.508 277.701,472.473 277.71,472.438 277.719,472.404 277.728,472.369 277.737,472.335 277.747,472.3 277.756,472.265 277.765,472.231 277.774,472.196 277.783,472.161 277.793,472.127 277.802,472.092 277.811,472.057 277.82,472.023 277.829,471.988 277.838,471.954 277.848,471.919 277.857,471.884 277.866,471.85 277.875,471.815 277.884,471.78 277.894,471.746 277.903,471.711 277.912,471.676 277.921,471.642 277.93,471.607 277.94,471.572 277.949,471.538 277.958,471.503 277.967,471.468 277.976,471.434 277.985,471.399 277.995,471.364 278.004,471.33 278.013,471.295 278.022,471.261 278.031,471.226 278.041,471.191 278.05,471.157 278.059,471.122 278.068,471.087 278.077,471.053 278.087,471.018 278.096,470.983 278.105,470.949 278.114,470.914 278.123,470.879 278.133,470.845 278.142,470.81 278.151,470.775 278.16,470.741 278.169,470.706 278.178,470.671 278.188,470.637 278.197,470.602 278.206,470.567 278.215,470.532 278.224,470.498 278.234,470.463 278.243,470.428 278.252,470.394 278.261,470.359 278.27,470.324 278.28,470.29 278.289,470.255 278.298,470.22 278.307,470.186 278.316,470.151 278.325,470.116 278.335,470.082 278.344,470.047 278.353,470.012 278.362,469.978 278.371,469.943 278.381,469.908 278.39,469.873 278.399,469.839 278.408,469.804 278.417,469.769 278.427,469.735 278.436,469.7 278.445,469.665 278.454,469.631 278.463,469.596 278.473,469.561 278.482,469.527 278.491,469.492 278.5,469.457 278.509,469.422 278.518,469.388 278.528,469.353 278.537,469.318 278.546,469.284 278.555,469.249 278.564,469.214 278.574,469.179 278.583,469.145 278.592,469.11 278.601,469.075 278.61,469.041 278.62,469.006 278.629,468.971 278.638,468.936 278.647,468.902 278.656,468.867 278.665,468.832 278.675,468.798 278.684,468.763 278.693,468.728 278.702,468.693 278.711,468.659 278.721,468.624 278.73,468.589 278.739,468.555 278.748,468.52 278.757,468.485 278.767,468.45 278.776,468.416 278.785,468.381 278.794,468.346 278.803,468.311 278.813,468.277 278.822,468.242 278.831,468.207 278.84,468.173 278.849,468.138 278.858,468.103 278.868,468.068 278.877,468.034 278.886,467.999 278.895,467.964 278.904,467.929 278.914,467.895 278.923,467.86 278.932,467.825 278.941,467.79 278.95,467.756 278.96,467.721 278.969,467.686 278.978,467.651 278.987,467.617 278.996,467.582 279.005,467.547 279.015,467.513 279.024,467.478 279.033,467.443 279.042,467.408 279.051,467.374 279.061,467.339 279.07,467.304 279.079,467.269 279.088,467.235 279.097,467.2 279.107,467.165 279.116,467.13 279.125,467.095 279.134,467.061 279.143,467.026 279.153,466.991 279.162,466.956 279.171,466.922 279.18,466.887 279.189,466.852 279.198,466.817 279.208,466.783 279.217,466.748 279.226,466.713 279.235,466.678 279.244,466.644 279.254,466.609 279.263,466.574 279.272,466.539 279.281,466.504 279.29,466.47 279.3,466.435 279.309,466.4 279.318,466.365 279.327,466.331 279.336,466.296 279.345,466.261 279.355,466.226 279.364,466.192 279.373,466.157 279.382,466.122 279.391,466.087 279.401,466.052 279.41,466.018 279.419,465.983 279.428,465.948 279.437,465.913 279.447,465.879 279.456,465.844 279.465,465.809 279.474,465.774 279.483,465.739 279.493,465.705 279.502,465.67 279.511,465.635 279.52,465.6 279.529,465.565 279.538,465.531 279.548,465.496 279.557,465.461 279.566,465.426 279.575,465.391 279.584,465.357 279.594,465.322 279.603,465.287 279.612,465.252 279.621,465.217 279.63,465.183 279.64,465.148 279.649,465.113 279.658,465.078 279.667,465.043 279.676,465.009 279.685,464.974 279.695,464.939 279.704,464.904 279.713,464.869 279.722,464.835 279.731,464.8 279.741,464.765 279.75,464.73 279.759,464.695 279.768,464.661 279.777,464.626 279.787,464.591 279.796,464.556 279.805,464.521 279.814,464.487 279.823,464.452 279.833,464.417 279.842,464.382 279.851,464.347 279.86,464.312 279.869,464.278 279.878,464.243 279.888,464.208 279.897,464.173 279.906,464.138 279.915,464.104 279.924,464.069 279.934,464.034 279.943,463.999 279.952,463.964 279.961,463.929 279.97,463.895 279.98,463.86 279.989,463.825 279.998,463.79 280.007,463.755 280.016,463.72 280.026,463.686 280.035,463.651 280.044,463.616 280.053,463.581 280.062,463.546 280.071,463.511 280.081,463.477 280.09,463.442 280.099,463.407 280.108,463.372 280.117,463.337 280.127,463.302 280.136,463.268 280.145,463.233 280.154,463.198 280.163,463.163 280.173,463.128 280.182,463.093 280.191,463.058 280.2,463.024 280.209,462.989 280.218,462.954 280.228,462.919 280.237,462.884 280.246,462.849 280.255,462.815 280.264,462.78 280.274,462.745 280.283,462.71 280.292,462.675 280.301,462.64 280.31,462.605 280.32,462.571 280.329,462.536 280.338,462.501 280.347,462.466 280.356,462.431 280.366,462.396 280.375,462.361 280.384,462.327 280.393,462.292 280.402,462.257 280.411,462.222 280.421,462.187 280.43,462.152 280.439,462.117 280.448,462.083 280.457,462.048 280.467,462.013 280.476,461.978 280.485,461.943 280.494,461.908 280.503,461.873 280.513,461.838 280.522,461.804 280.531,461.769 280.54,461.734 280.549,461.699 280.558,461.664 280.568,461.629 280.577,461.594 280.586,461.559 280.595,461.525 280.604,461.49 280.614,461.455 280.623,461.42 280.632,461.385 280.641,461.35 280.65,461.315 280.66,461.28 280.669,461.246 280.678,461.211 280.687,461.176 280.696,461.141 280.706,461.106 280.715,461.071 280.724,461.036 280.733,461.001 280.742,460.966 280.751,460.932 280.761,460.897 280.77,460.862 280.779,460.827 280.788,460.792 280.797,460.757 280.807,460.722 280.816,460.687 280.825,460.652 280.834,460.618 280.843,460.583 280.853,460.548 280.862,460.513 280.871,460.478 280.88,460.443 280.889,460.408 280.898,460.373 280.908,460.338 280.917,460.303 280.926,460.269 280.935,460.234 280.944,460.199 280.954,460.164 280.963,460.129 280.972,460.094 280.981,460.059 280.99,460.024 281,459.989 281.009,459.954 281.018,459.92 281.027,459.885 281.036,459.85 281.046,459.815 281.055,459.78 281.064,459.745 281.073,459.71 281.082,459.675 281.091,459.64 281.101,459.605 281.11,459.57 281.119,459.535 281.128,459.501 281.137,459.466 281.147,459.431 281.156,459.396 281.165,459.361 281.174,459.326 281.183,459.291 281.193,459.256 281.202,459.221 281.211,459.186 281.22,459.151 281.229,459.116 281.238,459.082 281.248,459.047 281.257,459.012 281.266,458.977 281.275,458.942 281.284,458.907 281.294,458.872 281.303,458.837 281.312,458.802 281.321,458.767 281.33,458.732 281.34,458.697 281.349,458.662 281.358,458.627 281.367,458.593 281.376,458.558 281.386,458.523 281.395,458.488 281.404,458.453 281.413,458.418 281.422,458.383 281.431,458.348 281.441,458.313 281.45,458.278 281.459,458.243 281.468,458.208 281.477,458.173 281.487,458.138 281.496,458.103 281.505,458.068 281.514,458.033 281.523,457.999 281.533,457.964 281.542,457.929 281.551,457.894 281.56,457.859 281.569,457.824 281.578,457.789 281.588,457.754 281.597,457.719 281.606,457.684 281.615,457.649 281.624,457.614 281.634,457.579 281.643,457.544 281.652,457.509 281.661,457.474 281.67,457.439 281.68,457.404 281.689,457.369 281.698,457.334 281.707,457.299 281.716,457.265 281.726,457.23 281.735,457.195 281.744,457.16 281.753,457.125 281.762,457.09 281.771,457.055 281.781,457.02 281.79,456.985 281.799,456.95 281.808,456.915 281.817,456.88 281.827,456.845 281.836,456.81 281.845,456.775 281.854,456.74 281.863,456.705 281.873,456.67 281.882,456.635 281.891,456.6 281.9,456.565 281.909,456.53 281.918,456.495 281.928,456.46 281.937,456.425 281.946,456.39 281.955,456.355 281.964,456.32 281.974,456.285 281.983,456.25 281.992,456.215 282.001,456.18 282.01,456.146 282.02,456.111 282.029,456.076 282.038,456.041 282.047,456.006 282.056,455.971 282.066,455.936 282.075,455.901 282.084,455.866 282.093,455.831 282.102,455.796 282.111,455.761 282.121,455.726 282.13,455.691 282.139,455.656 282.148,455.621 282.157,455.586 282.167,455.551 282.176,455.516 282.185,455.481 282.194,455.446 282.203,455.411 282.213,455.376 282.222,455.341 282.231,455.306 282.24,455.271 282.249,455.236 282.259,455.201 282.268,455.166 282.277,455.131 282.286,455.096 282.295,455.061 282.304,455.026 282.314,454.991 282.323,454.956 282.332,454.921 282.341,454.886 282.35,454.851 282.36,454.816 282.369,454.781 282.378,454.746 282.387,454.711 282.396,454.676 282.406,454.641 282.415,454.606 282.424,454.571 282.433,454.536 282.442,454.501 282.451,454.466 282.461,454.431 282.47,454.396 282.479,454.361 282.488,454.326 282.497,454.291 282.507,454.256 282.516,454.221 282.525,454.186 282.534,454.151 282.543,454.116 282.553,454.081 282.562,454.046 282.571,454.011 282.58,453.976 282.589,453.941 282.599,453.906 282.608,453.871 282.617,453.836 282.626,453.801 282.635,453.765 282.644,453.73 282.654,453.695 282.663,453.66 282.672,453.625 282.681,453.59 282.69,453.555 282.7,453.52 282.709,453.485 282.718,453.45 282.727,453.415 282.736,453.38 282.746,453.345 282.755,453.31 282.764,453.275 282.773,453.24 282.782,453.205 282.791,453.17 282.801,453.135 282.81,453.1 282.819,453.065 282.828,453.03 282.837,452.995 282.847,452.96 282.856,452.925 282.865,452.89 282.874,452.855 282.883,452.82 282.893,452.785 282.902,452.75 282.911,452.715 282.92,452.68 282.929,452.645 282.939,452.609 282.948,452.574 282.957,452.539 282.966,452.504 282.975,452.469 282.984,452.434 282.994,452.399 283.003,452.364 283.012,452.329 283.021,452.294 283.03,452.259 283.04,452.224 283.049,452.189 283.058,452.154 283.067,452.119 283.076,452.084 283.086,452.049 283.095,452.014 283.104,451.979 283.113,451.944 283.122,451.909 283.131,451.873 283.141,451.838 283.15,451.803 283.159,451.768 283.168,451.733 283.177,451.698 283.187,451.663 283.196,451.628 283.205,451.593 283.214,451.558 283.223,451.523 283.233,451.488 283.242,451.453 283.251,451.418 283.26,451.383 283.269,451.348 283.279,451.313 283.288,451.278 283.297,451.242 283.306,451.207 283.315,451.172 283.324,451.137 283.334,451.102 283.343,451.067 283.352,451.032 283.361,450.997 283.37,450.962 283.38,450.927 283.389,450.892 283.398,450.857 283.407,450.822 283.416,450.787 283.426,450.752 283.435,450.716 283.444,450.681 283.453,450.646 283.462,450.611 283.471,450.576 283.481,450.541 283.49,450.506 283.499,450.471 283.508,450.436 283.517,450.401 283.527,450.366 283.536,450.331 283.545,450.296 283.554,450.26 283.563,450.225 283.573,450.19 283.582,450.155 283.591,450.12 283.6,450.085 283.609,450.05 283.619,450.015 283.628,449.98 283.637,449.945 283.646,449.91 283.655,449.875 283.664,449.84 283.674,449.804 283.683,449.769 283.692,449.734 283.701,449.699 283.71,449.664 283.72,449.629 283.729,449.594 283.738,449.559 283.747,449.524 283.756,449.489 283.766,449.454 283.775,449.418 283.784,449.383 283.793,449.348 283.802,449.313 283.811,449.278 283.821,449.243 283.83,449.208 283.839,449.173 283.848,449.138 283.857,449.103 283.867,449.068 283.876,449.032 283.885,448.997 283.894,448.962 283.903,448.927 283.913,448.892 283.922,448.857 283.931,448.822 283.94,448.787 283.949,448.752 283.959,448.717 283.968,448.681 283.977,448.646 283.986,448.611 283.995,448.576 284.004,448.541 284.014,448.506 284.023,448.471 284.032,448.436 284.041,448.401 284.05,448.365 284.06,448.33 284.069,448.295 284.078,448.26 284.087,448.225 284.096,448.19 284.106,448.155 284.115,448.12 284.124,448.085 284.133,448.049 284.142,448.014 284.151,447.979 284.161,447.944 284.17,447.909 284.179,447.874 284.188,447.839 284.197,447.804 284.207,447.769 284.216,447.733 284.225,447.698 284.234,447.663 284.243,447.628 284.253,447.593 284.262,447.558 284.271,447.523 284.28,447.488 284.289,447.452 284.299,447.417 284.308,447.382 284.317,447.347 284.326,447.312 284.335,447.277 284.344,447.242 284.354,447.207 284.363,447.172 284.372,447.136 284.381,447.101 284.39,447.066 284.4,447.031 284.409,446.996 284.418,446.961 284.427,446.926 284.436,446.89 284.446,446.855 284.455,446.82 284.464,446.785 284.473,446.75 284.482,446.715 284.491,446.68 284.501,446.645 284.51,446.609 284.519,446.574 284.528,446.539 284.537,446.504 284.547,446.469 284.556,446.434 284.565,446.399 284.574,446.364 284.583,446.328 284.593,446.293 284.602,446.258 284.611,446.223 284.62,446.188 284.629,446.153 284.639,446.118 284.648,446.082 284.657,446.047 284.666,446.012 284.675,445.977 284.684,445.942 284.694,445.907 284.703,445.872 284.712,445.836 284.721,445.801 284.73,445.766 284.74,445.731 284.749,445.696 284.758,445.661 284.767,445.626 284.776,445.59 284.786,445.555 284.795,445.52 284.804,445.485 284.813,445.45 284.822,445.415 284.832,445.379 284.841,445.344 284.85,445.309 284.859,445.274 284.868,445.239 284.877,445.204 284.887,445.169 284.896,445.133 284.905,445.098 284.914,445.063 284.923,445.028 284.933,444.993 284.942,444.958 284.951,444.922 284.96,444.887 284.969,444.852 284.979,444.817 284.988,444.782 284.997,444.747 285.006,444.712 285.015,444.676 285.024,444.641 285.034,444.606 285.043,444.571 285.052,444.536 285.061,444.501 285.07,444.465 285.08,444.43 285.089,444.395 285.098,444.36 285.107,444.325 285.116,444.29 285.126,444.254 285.135,444.219 285.144,444.184 285.153,444.149 285.162,444.114 285.172,444.079 285.181,444.043 285.19,444.008 285.199,443.973 285.208,443.938 285.217,443.903 285.227,443.868 285.236,443.832 285.245,443.797 285.254,443.762 285.263,443.727 285.273,443.692 285.282,443.657 285.291,443.621 285.3,443.586 285.309,443.551 285.319,443.516 285.328,443.481 285.337,443.445 285.346,443.41 285.355,443.375 285.364,443.34 285.374,443.305 285.383,443.27 285.392,443.234 285.401,443.199 285.41,443.164 285.42,443.129 285.429,443.094 285.438,443.059 285.447,443.023 285.456,442.988 285.466,442.953 285.475,442.918 285.484,442.883 285.493,442.847 285.502,442.812 285.512,442.777 285.521,442.742 285.53,442.707 285.539,442.672 285.548,442.636 285.557,442.601 285.567,442.566 285.576,442.531 285.585,442.496 285.594,442.46 285.603,442.425 285.613,442.39 285.622,442.355 285.631,442.32 285.64,442.284 285.649,442.249 285.659,442.214 285.668,442.179 285.677,442.144 285.686,442.108 285.695,442.073 285.704,442.038 285.714,442.003 285.723,441.968 285.732,441.932 285.741,441.897 285.75,441.862 285.76,441.827 285.769,441.792 285.778,441.757 285.787,441.721 285.796,441.686 285.806,441.651 285.815,441.616 285.824,441.581 285.833,441.545 285.842,441.51 285.852,441.475 285.861,441.44 285.87,441.404 285.879,441.369 285.888,441.334 285.897,441.299 285.907,441.264 285.916,441.228 285.925,441.193 285.934,441.158 285.943,441.123 285.953,441.088 285.962,441.052 285.971,441.017 285.98,440.982 285.989,440.947 285.999,440.912 286.008,440.876 286.017,440.841 286.026,440.806 286.035,440.771 286.044,440.736 286.054,440.7 286.063,440.665 286.072,440.63 286.081,440.595 286.09,440.56 286.1,440.524 286.109,440.489 286.118,440.454 286.127,440.419 286.136,440.383 286.146,440.348 286.155,440.313 286.164,440.278 286.173,440.243 286.182,440.207 286.192,440.172 286.201,440.137 286.21,440.102 286.219,440.066 286.228,440.031 286.237,439.996 286.247,439.961 286.256,439.926 286.265,439.89 286.274,439.855 286.283,439.82 286.293,439.785 286.302,439.75 286.311,439.714 286.32,439.679 286.329,439.644 286.339,439.609 286.348,439.573 286.357,439.538 286.366,439.503 286.375,439.468 286.384,439.432 286.394,439.397 286.403,439.362 286.412,439.327 286.421,439.292 286.43,439.256 286.44,439.221 286.449,439.186 286.458,439.151 286.467,439.115 286.476,439.08 286.486,439.045 286.495,439.01 286.504,438.974 286.513,438.939 286.522,438.904 286.532,438.869 286.541,438.834 286.55,438.798 286.559,438.763 286.568,438.728 286.577,438.693 286.587,438.657 286.596,438.622 286.605,438.587 286.614,438.552 286.623,438.516 286.633,438.481 286.642,438.446 286.651,438.411 286.66,438.375 286.669,438.34 286.679,438.305 286.688,438.27 286.697,438.235 286.706,438.199 286.715,438.164 286.724,438.129 286.734,438.094 286.743,438.058 286.752,438.023 286.761,437.988 286.77,437.953 286.78,437.917 286.789,437.882 286.798,437.847 286.807,437.812 286.816,437.776 286.826,437.741 286.835,437.706 286.844,437.671 286.853,437.635 286.862,437.6 286.872,437.565 286.881,437.53 286.89,437.494 286.899,437.459 286.908,437.424 286.917,437.389 286.927,437.353 286.936,437.318 286.945,437.283 286.954,437.248 286.963,437.212 286.973,437.177 286.982,437.142 286.991,437.107 287,437.071 287.009,437.036 287.019,437.001 287.028,436.966 287.037,436.93 287.046,436.895 287.055,436.86 287.064,436.825 287.074,436.789 287.083,436.754 287.092,436.719 287.101,436.684 287.11,436.648 287.12,436.613 287.129,436.578 287.138,436.543 287.147,436.507 287.156,436.472 287.166,436.437 287.175,436.402 287.184,436.366 287.193,436.331 287.202,436.296 287.212,436.26 287.221,436.225 287.23,436.19 287.239,436.155 287.248,436.119 287.257,436.084 287.267,436.049 287.276,436.014 287.285,435.978 287.294,435.943 287.303,435.908 287.313,435.873 287.322,435.837 287.331,435.802 287.34,435.767 287.349,435.731 287.359,435.696 287.368,435.661 287.377,435.626 287.386,435.59 287.395,435.555 287.405,435.52 287.414,435.485 287.423,435.449 287.432,435.414 287.441,435.379 287.45,435.344 287.46,435.308 287.469,435.273 287.478,435.238 287.487,435.202 287.496,435.167 287.506,435.132 287.515,435.097 287.524,435.061 287.533,435.026 287.542,434.991 287.552,434.956 287.561,434.92 287.57,434.885 287.579,434.85 287.588,434.814 287.597,434.779 287.607,434.744 287.616,434.709 287.625,434.673 287.634,434.638 287.643,434.603 287.653,434.567 287.662,434.532 287.671,434.497 287.68,434.462 287.689,434.426 287.699,434.391 287.708,434.356 287.717,434.32 287.726,434.285 287.735,434.25 287.745,434.215 287.754,434.179 287.763,434.144 287.772,434.109 287.781,434.073 287.79,434.038 287.8,434.003 287.809,433.968 287.818,433.932 287.827,433.897 287.836,433.862 287.846,433.826 287.855,433.791 287.864,433.756 287.873,433.721 287.882,433.685 287.892,433.65 287.901,433.615 287.91,433.579 287.919,433.544 287.928,433.509 287.937,433.474 287.947,433.438 287.956,433.403 287.965,433.368 287.974,433.332 287.983,433.297 287.993,433.262 288.002,433.227 288.011,433.191 288.02,433.156 288.029,433.121 288.039,433.085 288.048,433.05 288.057,433.015 288.066,432.98 288.075,432.944 288.085,432.909 288.094,432.874 288.103,432.838 288.112,432.803 288.121,432.768 288.13,432.732 288.14,432.697 288.149,432.662 288.158,432.627 288.167,432.591 288.176,432.556 288.186,432.521 288.195,432.485 288.204,432.45 288.213,432.415 288.222,432.379 288.232,432.344 288.241,432.309 288.25,432.274 288.259,432.238 288.268,432.203 288.277,432.168 288.287,432.132 288.296,432.097 288.305,432.062 288.314,432.026 288.323,431.991 288.333,431.956 288.342,431.92 288.351,431.885 288.36,431.85 288.369,431.815 288.379,431.779 288.388,431.744 288.397,431.709 288.406,431.673 288.415,431.638 288.425,431.603 288.434,431.567 288.443,431.532 288.452,431.497 288.461,431.461 288.47,431.426 288.48,431.391 288.489,431.356 288.498,431.32 288.507,431.285 288.516,431.25 288.526,431.214 288.535,431.179 288.544,431.144 288.553,431.108 288.562,431.073 288.572,431.038 288.581,431.002 288.59,430.967 288.599,430.932 288.608,430.896 288.617,430.861 288.627,430.826 288.636,430.791 288.645,430.755 288.654,430.72 288.663,430.685 288.673,430.649 288.682,430.614 288.691,430.579 288.7,430.543 288.709,430.508 288.719,430.473 288.728,430.437 288.737,430.402 288.746,430.367 288.755,430.331 288.765,430.296 288.774,430.261 288.783,430.225 288.792,430.19 288.801,430.155 288.81,430.119 288.82,430.084 288.829,430.049 288.838,430.014 288.847,429.978 288.856,429.943 288.866,429.908 288.875,429.872 288.884,429.837 288.893,429.802 288.902,429.766 288.912,429.731 288.921,429.696 288.93,429.66 288.939,429.625 288.948,429.59 288.957,429.554 288.967,429.519 288.976,429.484 288.985,429.448 288.994,429.413 289.003,429.378 289.013,429.342 289.022,429.307 289.031,429.272 289.04,429.236 289.049,429.201 289.059,429.166 289.068,429.13 289.077,429.095 289.086,429.06 289.095,429.024 289.105,428.989 289.114,428.954 289.123,428.918 289.132,428.883 289.141,428.848 289.15,428.812 289.16,428.777 289.169,428.742 289.178,428.706 289.187,428.671 289.196,428.636 289.206,428.6 289.215,428.565 289.224,428.53 289.233,428.494 289.242,428.459 289.252,428.424 289.261,428.388 289.27,428.353 289.279,428.318 289.288,428.282 289.297,428.247 289.307,428.212 289.316,428.176 289.325,428.141 289.334,428.106 289.343,428.07 289.353,428.035 289.362,428 289.371,427.964 289.38,427.929 289.389,427.894 289.399,427.858 289.408,427.823 289.417,427.788 289.426,427.752 289.435,427.717 289.445,427.682 289.454,427.646 289.463,427.611 289.472,427.576 289.481,427.54 289.49,427.505 289.5,427.469 289.509,427.434 289.518,427.399 289.527,427.363 289.536,427.328 289.546,427.293 289.555,427.257 289.564,427.222 289.573,427.187 289.582,427.151 289.592,427.116 289.601,427.081 289.61,427.045 289.619,427.01 289.628,426.975 289.638,426.939 289.647,426.904 289.656,426.869 289.665,426.833 289.674,426.798 289.683,426.763 289.693,426.727 289.702,426.692 289.711,426.656 289.72,426.621 289.729,426.586 289.739,426.55 289.748,426.515 289.757,426.48 289.766,426.444 289.775,426.409 289.785,426.374 289.794,426.338 289.803,426.303 289.812,426.268 289.821,426.232 289.83,426.197 289.84,426.162 289.849,426.126 289.858,426.091 289.867,426.055 289.876,426.02 289.886,425.985 289.895,425.949 289.904,425.914 289.913,425.879 289.922,425.843 289.932,425.808 289.941,425.773 289.95,425.737 289.959,425.702 289.968,425.667 289.978,425.631 289.987,425.596 289.996,425.561 290.005,425.525 290.014,425.49 290.023,425.454 290.033,425.419 290.042,425.384 290.051,425.348 290.06,425.313 290.069,425.278 290.079,425.242 290.088,425.207 290.097,425.172 290.106,425.136 290.115,425.101 290.125,425.065 290.134,425.03 290.143,424.995 290.152,424.959 290.161,424.924 290.17,424.889 290.18,424.853 290.189,424.818 290.198,424.783 290.207,424.747 290.216,424.712 290.226,424.676 290.235,424.641 290.244,424.606 290.253,424.57 290.262,424.535 290.272,424.5 290.281,424.464 290.29,424.429 290.299,424.394 290.308,424.358 290.318,424.323 290.327,424.287 290.336,424.252 290.345,424.217 290.354,424.181 290.363,424.146 290.373,424.111 290.382,424.075 290.391,424.04 290.4,424.004 290.409,423.969 290.419,423.934 290.428,423.898 290.437,423.863 290.446,423.828 290.455,423.792 290.465,423.757 290.474,423.722 290.483,423.686 290.492,423.651 290.501,423.615 290.51,423.58 290.52,423.545 290.529,423.509 290.538,423.474 290.547,423.439 290.556,423.403 290.566,423.368 290.575,423.332 290.584,423.297 290.593,423.262 290.602,423.226 290.612,423.191 290.621,423.156 290.63,423.12 290.639,423.085 290.648,423.049 290.658,423.014 290.667,422.979 290.676,422.943 290.685,422.908 290.694,422.873 290.703,422.837 290.713,422.802 290.722,422.766 290.731,422.731 290.74,422.696 290.749,422.66 290.759,422.625 290.768,422.589 290.777,422.554 290.786,422.519 290.795,422.483 290.805,422.448 290.814,422.413 290.823,422.377 290.832,422.342 290.841,422.306 290.85,422.271 290.86,422.236 290.869,422.2 290.878,422.165 290.887,422.13 290.896,422.094 290.906,422.059 290.915,422.023 290.924,421.988 290.933,421.953 290.942,421.917 290.952,421.882 290.961,421.846 290.97,421.811 290.979,421.776 290.988,421.74 290.998,421.705 291.007,421.67 291.016,421.634 291.025,421.599 291.034,421.563 291.043,421.528 291.053,421.493 291.062,421.457 291.071,421.422 291.08,421.386 291.089,421.351 291.099,421.316 291.108,421.28 291.117,421.245 291.126,421.21 291.135,421.174 291.145,421.139 291.154,421.103 291.163,421.068 291.172,421.033 291.181,420.997 291.19,420.962 291.2,420.926 291.209,420.891 291.218,420.856 291.227,420.82 291.236,420.785 291.246,420.749 291.255,420.714 291.264,420.679 291.273,420.643 291.282,420.608 291.292,420.572 291.301,420.537 291.31,420.502 291.319,420.466 291.328,420.431 291.338,420.396 291.347,420.36 291.356,420.325 291.365,420.289 291.374,420.254 291.383,420.219 291.393,420.183 291.402,420.148 291.411,420.112 291.42,420.077 291.429,420.042 291.439,420.006 291.448,419.971 291.457,419.935 291.466,419.9 291.475,419.865 291.485,419.829 291.494,419.794 291.503,419.758 291.512,419.723 291.521,419.688 291.53,419.652 291.54,419.617 291.549,419.581 291.558,419.546 291.567,419.511 291.576,419.475 291.586,419.44 291.595,419.404 291.604,419.369 291.613,419.334 291.622,419.298 291.632,419.263 291.641,419.227 291.65,419.192 291.659,419.157 291.668,419.121 291.678,419.086 291.687,419.05 291.696,419.015 291.705,418.98 291.714,418.944 291.723,418.909 291.733,418.873 291.742,418.838 291.751,418.803 291.76,418.767 291.769,418.732 291.779,418.696 291.788,418.661 291.797,418.626 291.806,418.59 291.815,418.555 291.825,418.519 291.834,418.484 291.843,418.449 291.852,418.413 291.861,418.378 291.87,418.342 291.88,418.307 291.889,418.272 291.898,418.236 291.907,418.201 291.916,418.165 291.926,418.13 291.935,418.095 291.944,418.059 291.953,418.024 291.962,417.988 291.972,417.953 291.981,417.918 291.99,417.882 291.999,417.847 292.008,417.811 292.018,417.776 292.027,417.74 292.036,417.705 292.045,417.67 292.054,417.634 292.063,417.599 292.073,417.563 292.082,417.528 292.091,417.493 292.1,417.457 292.109,417.422 292.119,417.386 292.128,417.351 292.137,417.316 292.146,417.28 292.155,417.245 292.165,417.209 292.174,417.174 292.183,417.139 292.192,417.103 292.201,417.068 292.211,417.032 292.22,416.997 292.229,416.961 292.238,416.926 292.247,416.891 292.256,416.855 292.266,416.82 292.275,416.784 292.284,416.749 292.293,416.714 292.302,416.678 292.312,416.643 292.321,416.607 292.33,416.572 292.339,416.537 292.348,416.501 292.358,416.466 292.367,416.43 292.376,416.395 292.385,416.359 292.394,416.324 292.403,416.289 292.413,416.253 292.422,416.218 292.431,416.182 292.44,416.147 292.449,416.112 292.459,416.076 292.468,416.041 292.477,416.005 292.486,415.97 292.495,415.934 292.505,415.899 292.514,415.864 292.523,415.828 292.532,415.793 292.541,415.757 292.551,415.722 292.56,415.687 292.569,415.651 292.578,415.616 292.587,415.58 292.596,415.545 292.606,415.509 292.615,415.474 292.624,415.439 292.633,415.403 292.642,415.368 292.652,415.332 292.661,415.297 292.67,415.262 292.679,415.226 292.688,415.191 292.698,415.155 292.707,415.12 292.716,415.084 292.725,415.049 292.734,415.014 292.743,414.978 292.753,414.943 292.762,414.907 292.771,414.872 292.78,414.836 292.789,414.801 292.799,414.766 292.808,414.73 292.817,414.695 292.826,414.659 292.835,414.624 292.845,414.589 292.854,414.553 292.863,414.518 292.872,414.482 292.881,414.447 292.891,414.411 292.9,414.376 292.909,414.341 292.918,414.305 292.927,414.27 292.936,414.234 292.946,414.199 292.955,414.163 292.964,414.128 292.973,414.093 292.982,414.057 292.992,414.022 293.001,413.986 293.01,413.951 293.019,413.915 293.028,413.88 293.038,413.845 293.047,413.809 293.056,413.774 293.065,413.738 293.074,413.703 293.083,413.667 293.093,413.632 293.102,413.597 293.111,413.561 293.12,413.526 293.129,413.49 293.139,413.455 293.148,413.419 293.157,413.384 293.166,413.349 293.175,413.313 293.185,413.278 293.194,413.242 293.203,413.207 293.212,413.171 293.221,413.136 293.231,413.101 293.24,413.065 293.249,413.03 293.258,412.994 293.267,412.959 293.276,412.923 293.286,412.888 293.295,412.853 293.304,412.817 293.313,412.782 293.322,412.746 293.332,412.711 293.341,412.675 293.35,412.64 293.359,412.605 293.368,412.569 293.378,412.534 293.387,412.498 293.396,412.463 293.405,412.427 293.414,412.392 293.423,412.357 293.433,412.321 293.442,412.286 293.451,412.25 293.46,412.215 293.469,412.179 293.479,412.144 293.488,412.109 293.497,412.073 293.506,412.038 293.515,412.002 293.525,411.967 293.534,411.931 293.543,411.896 293.552,411.861 293.561,411.825 293.571,411.79 293.58,411.754 293.589,411.719 293.598,411.683 293.607,411.648 293.616,411.613 293.626,411.577 293.635,411.542 293.644,411.506 293.653,411.471 293.662,411.435 293.672,411.4 293.681,411.364 293.69,411.329 293.699,411.294 293.708,411.258 293.718,411.223 293.727,411.187 293.736,411.152 293.745,411.116 293.754,411.081 293.763,411.046 293.773,411.01 293.782,410.975 293.791,410.939 293.8,410.904 293.809,410.868 293.819,410.833 293.828,410.797 293.837,410.762 293.846,410.727 293.855,410.691 293.865,410.656 293.874,410.62 293.883,410.585 293.892,410.549 293.901,410.514 293.911,410.479 293.92,410.443 293.929,410.408 293.938,410.372 293.947,410.337 293.956,410.301 293.966,410.266 293.975,410.23 293.984,410.195 293.993,410.16 294.002,410.124 294.012,410.089 294.021,410.053 294.03,410.018 294.039,409.982 294.048,409.947 294.058,409.912 294.067,409.876 294.076,409.841 294.085,409.805 294.094,409.77 294.103,409.734 294.113,409.699 294.122,409.663 294.131,409.628 294.14,409.593 294.149,409.557 294.159,409.522 294.168,409.486 294.177,409.451 294.186,409.415 294.195,409.38 294.205,409.344 294.214,409.309 294.223,409.274 294.232,409.238 294.241,409.203 294.251,409.167 294.26,409.132 294.269,409.096 294.278,409.061 294.287,409.025 294.296,408.99 294.306,408.955 294.315,408.919 294.324,408.884 294.333,408.848 294.342,408.813 294.352,408.777 294.361,408.742 294.37,408.706 294.379,408.671 294.388,408.636 294.398,408.6 294.407,408.565 294.416,408.529 294.425,408.494 294.434,408.458 294.443,408.423 294.453,408.388 294.462,408.352 294.471,408.317 294.48,408.281 294.489,408.246 294.499,408.21 294.508,408.175 294.517,408.139 294.526,408.104 294.535,408.068 294.545,408.033 294.554,407.998 294.563,407.962 294.572,407.927 294.581,407.891 294.591,407.856 294.6,407.82 294.609,407.785 294.618,407.749 294.627,407.714 294.636,407.679 294.646,407.643 294.655,407.608 294.664,407.572 294.673,407.537 294.682,407.501 294.692,407.466 294.701,407.43 294.71,407.395 294.719,407.36 294.728,407.324 294.738,407.289 294.747,407.253 294.756,407.218 294.765,407.182 294.774,407.147 294.784,407.111 294.793,407.076 294.802,407.041 294.811,407.005 294.82,406.97 294.829,406.934 294.839,406.899 294.848,406.863 294.857,406.828 294.866,406.792 294.875,406.757 294.885,406.722 294.894,406.686 294.903,406.651 294.912,406.615 294.921,406.58 294.931,406.544 294.94,406.509 294.949,406.473 294.958,406.438 294.967,406.402 294.976,406.367 294.986,406.332 294.995,406.296 295.004,406.261 295.013,406.225 295.022,406.19 295.032,406.154 295.041,406.119 295.05,406.083 295.059,406.048 295.068,406.013 295.078,405.977 295.087,405.942 295.096,405.906 295.105,405.871 295.114,405.835 295.124,405.8 295.133,405.764 295.142,405.729 295.151,405.693 295.16,405.658 295.169,405.623 295.179,405.587 295.188,405.552 295.197,405.516 295.206,405.481 295.215,405.445 295.225,405.41 295.234,405.374 295.243,405.339 295.252,405.304 295.261,405.268 295.271,405.233 295.28,405.197 295.289,405.162 295.298,405.126 295.307,405.091 295.316,405.055 295.326,405.02 295.335,404.984 295.344,404.949 295.353,404.914 295.362,404.878 295.372,404.843 295.381,404.807 295.39,404.772 295.399,404.736 295.408,404.701 295.418,404.665 295.427,404.63 295.436,404.594 295.445,404.559 295.454,404.524 295.464,404.488 295.473,404.453 295.482,404.417 295.491,404.382 295.5,404.346 295.509,404.311 295.519,404.275 295.528,404.24 295.537,404.204 295.546,404.169 295.555,404.134 295.565,404.098 295.574,404.063 295.583,404.027 295.592,403.992 295.601,403.956 295.611,403.921 295.62,403.885 295.629,403.85 295.638,403.814 295.647,403.779 295.656,403.744 295.666,403.708 295.675,403.673 295.684,403.637 295.693,403.602 295.702,403.566 295.712,403.531 295.721,403.495 295.73,403.46 295.739,403.424 295.748,403.389 295.758,403.354 295.767,403.318 295.776,403.283 295.785,403.247 295.794,403.212 295.804,403.176 295.813,403.141 295.822,403.105 295.831,403.07 295.84,403.034 295.849,402.999 295.859,402.964 295.868,402.928 295.877,402.893 295.886,402.857 295.895,402.822 295.905,402.786 295.914,402.751 295.923,402.715 295.932,402.68 295.941,402.644 295.951,402.609 295.96,402.574 295.969,402.538 295.978,402.503 295.987,402.467 295.996,402.432 296.006,402.396 296.015,402.361 296.024,402.325 296.033,402.29 296.042,402.254 296.052,402.219 296.061,402.184 296.07,402.148 296.079,402.113 296.088,402.077 296.098,402.042 296.107,402.006 296.116,401.971 296.125,401.935 296.134,401.9 296.144,401.864 296.153,401.829 296.162,401.794 296.171,401.758 296.18,401.723 296.189,401.687 296.199,401.652 296.208,401.616 296.217,401.581 296.226,401.545 296.235,401.51 296.245,401.474 296.254,401.439 296.263,401.404 296.272,401.368 296.281,401.333 296.291,401.297 296.3,401.262 296.309,401.226 296.318,401.191 296.327,401.155 296.336,401.12 296.346,401.084 296.355,401.049 296.364,401.013 296.373,400.978 296.382,400.943 296.392,400.907 296.401,400.872 296.41,400.836 296.419,400.801 296.428,400.765 296.438,400.73 296.447,400.694 296.456,400.659 296.465,400.623 296.474,400.588 296.484,400.553 296.493,400.517 296.502,400.482 296.511,400.446 296.52,400.411 296.529,400.375 296.539,400.34 296.548,400.304 296.557,400.269 296.566,400.233 296.575,400.198 296.585,400.162 296.594,400.127 296.603,400.092 296.612,400.056 296.621,400.021 296.631,399.985 296.64,399.95 296.649,399.914 296.658,399.879 296.667,399.843 296.676,399.808 296.686,399.772 296.695,399.737 296.704,399.702 296.713,399.666 296.722,399.631 296.732,399.595 296.741,399.56 296.75,399.524 296.759,399.489 296.768,399.453 296.778,399.418 296.787,399.382 296.796,399.347 296.805,399.311 296.814,399.276 296.824,399.241 296.833,399.205 296.842,399.17 296.851,399.134 296.86,399.099 296.869,399.063 296.879,399.028 296.888,398.992 296.897,398.957 296.906,398.921 296.915,398.886 296.925,398.851 296.934,398.815 296.943,398.78 296.952,398.744 296.961,398.709 296.971,398.673 296.98,398.638 296.989,398.602 296.998,398.567 297.007,398.531 297.017,398.496 297.026,398.46 297.035,398.425 297.044,398.39 297.053,398.354 297.062,398.319 297.072,398.283 297.081,398.248 297.09,398.212 297.099,398.177 297.108,398.141 297.118,398.106 297.127,398.07 297.136,398.035 297.145,397.999 297.154,397.964 297.164,397.929 297.173,397.893 297.182,397.858 297.191,397.822 297.2,397.787 297.209,397.751 297.219,397.716 297.228,397.68 297.237,397.645 297.246,397.609 297.255,397.574 297.265,397.539 297.274,397.503 297.283,397.468 297.292,397.432 297.301,397.397 297.311,397.361 297.32,397.326 297.329,397.29 297.338,397.255 297.347,397.219 297.357,397.184 297.366,397.148 297.375,397.113 297.384,397.078 297.393,397.042 297.402,397.007 297.412,396.971 297.421,396.936 297.43,396.9 297.439,396.865 297.448,396.829 297.458,396.794 297.467,396.758 297.476,396.723 297.485,396.687 297.494,396.652 297.504,396.617 297.513,396.581 297.522,396.546 297.531,396.51 297.54,396.475 297.549,396.439 297.559,396.404 297.568,396.368 297.577,396.333 297.586,396.297 297.595,396.262 297.605,396.227 297.614,396.191 297.623,396.156 297.632,396.12 297.641,396.085 297.651,396.049 297.66,396.014 297.669,395.978 297.678,395.943 297.687,395.907 297.697,395.872 297.706,395.836 297.715,395.801 297.724,395.766 297.733,395.73 297.742,395.695 297.752,395.659 297.761,395.624 297.77,395.588 297.779,395.553 297.788,395.517 297.798,395.482 297.807,395.446 297.816,395.411 297.825,395.376 297.834,395.34 297.844,395.305 297.853,395.269 297.862,395.234 297.871,395.198 297.88,395.163 297.889,395.127 297.899,395.092 297.908,395.056 297.917,395.021 297.926,394.985 297.935,394.95 297.945,394.915 297.954,394.879 297.963,394.844 297.972,394.808 297.981,394.773 297.991,394.737 298,394.702 298.009,394.666 298.018,394.631 298.027,394.595 298.037,394.56 298.046,394.525 298.055,394.489 298.064,394.454 298.073,394.418 298.082,394.383 298.092,394.347 298.101,394.312 298.11,394.276 298.119,394.241 298.128,394.205 298.138,394.17 298.147,394.134 298.156,394.099 298.165,394.064 298.174,394.028 298.184,393.993 298.193,393.957 298.202,393.922 298.211,393.886 298.22,393.851 298.229,393.815 298.239,393.78 298.248,393.744 298.257,393.709 298.266,393.674 298.275,393.638 298.285,393.603 298.294,393.567 298.303,393.532 298.312,393.496 298.321,393.461 298.331,393.425 298.34,393.39 298.349,393.354 298.358,393.319 298.367,393.283 298.377,393.248 298.386,393.213 298.395,393.177 298.404,393.142 298.413,393.106 298.422,393.071 298.432,393.035 298.441,393 298.45,392.964 298.459,392.929 298.468,392.893 298.478,392.858 298.487,392.823 298.496,392.787 298.505,392.752 298.514,392.716 298.524,392.681 298.533,392.645 298.542,392.61 298.551,392.574 298.56,392.539 298.569,392.503 298.579,392.468 298.588,392.432 298.597,392.397 298.606,392.362 298.615,392.326 298.625,392.291 298.634,392.255 298.643,392.22 298.652,392.184 298.661,392.149 298.671,392.113 298.68,392.078 298.689,392.042 298.698,392.007 298.707,391.972 298.717,391.936 298.726,391.901 298.735,391.865 298.744,391.83 298.753,391.794 298.762,391.759 298.772,391.723 298.781,391.688 298.79,391.652 298.799,391.617 298.808,391.582 298.818,391.546 298.827,391.511 298.836,391.475 298.845,391.44 298.854,391.404 298.864,391.369 298.873,391.333 298.882,391.298 298.891,391.262 298.9,391.227 298.909,391.192 298.919,391.156 298.928,391.121 298.937,391.085 298.946,391.05 298.955,391.014 298.965,390.979 298.974,390.943 298.983,390.908 298.992,390.872 299.001,390.837 299.011,390.802 299.02,390.766 299.029,390.731 299.038,390.695 299.047,390.66 299.057,390.624 299.066,390.589 299.075,390.553 299.084,390.518 299.093,390.482 299.102,390.447 299.112,390.412 299.121,390.376 299.13,390.341 299.139,390.305 299.148,390.27 299.158,390.234 299.167,390.199 299.176,390.163 299.185,390.128 299.194,390.092 299.204,390.057 299.213,390.022 299.222,389.986 299.231,389.951 299.24,389.915 299.249,389.88 299.259,389.844 299.268,389.809 299.277,389.773 299.286,389.738 299.295,389.702 299.305,389.667 299.314,389.632 299.323,389.596 299.332,389.561 299.341,389.525 299.351,389.49 299.36,389.454 299.369,389.419 299.378,389.383 299.387,389.348 299.397,389.312 299.406,389.277 299.415,389.242 299.424,389.206 299.433,389.171 299.442,389.135 299.452,389.1 299.461,389.064 299.47,389.029 299.479,388.993 299.488,388.958 299.498,388.923 299.507,388.887 299.516,388.852 299.525,388.816 299.534,388.781 299.544,388.745 299.553,388.71 299.562,388.674 299.571,388.639 299.58,388.603 299.59,388.568 299.599,388.533 299.608,388.497 299.617,388.462 299.626,388.426 299.635,388.391 299.645,388.355 299.654,388.32 299.663,388.284 299.672,388.249 299.681,388.213 299.691,388.178 299.7,388.143 299.709,388.107 299.718,388.072 299.727,388.036 299.737,388.001 299.746,387.965 299.755,387.93 299.764,387.894 299.773,387.859 299.782,387.824 299.792,387.788 299.801,387.753 299.81,387.717 299.819,387.682 299.828,387.646 299.838,387.611 299.847,387.575 299.856,387.54 299.865,387.504 299.874,387.469 299.884,387.434 299.893,387.398 299.902,387.363 299.911,387.327 299.92,387.292 299.93,387.256 299.939,387.221 299.948,387.185 299.957,387.15 299.966,387.115 299.975,387.079 299.985,387.044 299.994,387.008 300.003,386.973 300.012,386.937 300.021,386.902 300.031,386.866 300.04,386.831 300.049,386.796 300.058,386.76 300.067,386.725 300.077,386.689 300.086,386.654 300.095,386.618 300.104,386.583 300.113,386.547 300.122,386.512 300.132,386.477 300.141,386.441 300.15,386.406 300.159,386.37 300.168,386.335 300.178,386.299 300.187,386.264 300.196,386.228 300.205,386.193 300.214,386.157 300.224,386.122 300.233,386.087 300.242,386.051 300.251,386.016 300.26,385.98 300.27,385.945 300.279,385.909 300.288,385.874 300.297,385.838 300.306,385.803 300.315,385.768 300.325,385.732 300.334,385.697 300.343,385.661 300.352,385.626 300.361,385.59 300.371,385.555 300.38,385.519 300.389,385.484 300.398,385.449 300.407,385.413 300.417,385.378 300.426,385.342 300.435,385.307 300.444,385.271 300.453,385.236 300.462,385.2 300.472,385.165 300.481,385.13 300.49,385.094 300.499,385.059 300.508,385.023 300.518,384.988 300.527,384.952 300.536,384.917 300.545,384.882 300.554,384.846 300.564,384.811 300.573,384.775 300.582,384.74 300.591,384.704 300.6,384.669 300.61,384.633 300.619,384.598 300.628,384.563 300.637,384.527 300.646,384.492 300.655,384.456 300.665,384.421 300.674,384.385 300.683,384.35 300.692,384.314 300.701,384.279 300.711,384.244 300.72,384.208 300.729,384.173 300.738,384.137 300.747,384.102 300.757,384.066 300.766,384.031 300.775,383.995 300.784,383.96 300.793,383.925 300.802,383.889 300.812,383.854 300.821,383.818 300.83,383.783 300.839,383.747 300.848,383.712 300.858,383.677 300.867,383.641 300.876,383.606 300.885,383.57 300.894,383.535 300.904,383.499 300.913,383.464 300.922,383.428 300.931,383.393 300.94,383.358 300.95,383.322 300.959,383.287 300.968,383.251 300.977,383.216 300.986,383.18 300.995,383.145 301.005,383.109 301.014,383.074 301.023,383.039 301.032,383.003 301.041,382.968 301.051,382.932 301.06,382.897 301.069,382.861 301.078,382.826 301.087,382.791 301.097,382.755 301.106,382.72 301.115,382.684 301.124,382.649 301.133,382.613 301.142,382.578 301.152,382.543 301.161,382.507 301.17,382.472 301.179,382.436 301.188,382.401 301.198,382.365 301.207,382.33 301.216,382.294 301.225,382.259 301.234,382.224 301.244,382.188 301.253,382.153 301.262,382.117 301.271,382.082 301.28,382.046 301.29,382.011 301.299,381.976 301.308,381.94 301.317,381.905 301.326,381.869 301.335,381.834 301.345,381.798 301.354,381.763 301.363,381.728 301.372,381.692 301.381,381.657 301.391,381.621 301.4,381.586 301.409,381.55 301.418,381.515 301.427,381.479 301.437,381.444 301.446,381.409 301.455,381.373 301.464,381.338 301.473,381.302 301.482,381.267 301.492,381.231 301.501,381.196 301.51,381.161 301.519,381.125 301.528,381.09 301.538,381.054 301.547,381.019 301.556,380.983 301.565,380.948 301.574,380.913 301.584,380.877 301.593,380.842 301.602,380.806 301.611,380.771 301.62,380.735 301.63,380.7 301.639,380.665 301.648,380.629 301.657,380.594 301.666,380.558 301.675,380.523 301.685,380.487 301.694,380.452 301.703,380.417 301.712,380.381 301.721,380.346 301.731,380.31 301.74,380.275 301.749,380.239 301.758,380.204 301.767,380.169 301.777,380.133 301.786,380.098 301.795,380.062 301.804,380.027 301.813,379.991 301.822,379.956 301.832,379.921 301.841,379.885 301.85,379.85 301.859,379.814 301.868,379.779 301.878,379.743 301.887,379.708 301.896,379.673 301.905,379.637 301.914,379.602 301.924,379.566 301.933,379.531 301.942,379.495 301.951,379.46 301.96,379.425 301.97,379.389 301.979,379.354 301.988,379.318 301.997,379.283 302.006,379.248 302.015,379.212 302.025,379.177 302.034,379.141 302.043,379.106 302.052,379.07 302.061,379.035 302.071,379 302.08,378.964 302.089,378.929 302.098,378.893 302.107,378.858 302.117,378.822 302.126,378.787 302.135,378.752 302.144,378.716 302.153,378.681 302.163,378.645 302.172,378.61 302.181,378.574 302.19,378.539 302.199,378.504 302.208,378.468 302.218,378.433 302.227,378.397 302.236,378.362 302.245,378.327 302.254,378.291 302.264,378.256 302.273,378.22 302.282,378.185 302.291,378.149 302.3,378.114 302.31,378.079 302.319,378.043 302.328,378.008 302.337,377.972 302.346,377.937 302.355,377.901 302.365,377.866 302.374,377.831 302.383,377.795 302.392,377.76 302.401,377.724 302.411,377.689 302.42,377.654 302.429,377.618 302.438,377.583 302.447,377.547 302.457,377.512 302.466,377.476 302.475,377.441 302.484,377.406 302.493,377.37 302.503,377.335 302.512,377.299 302.521,377.264 302.53,377.229 302.539,377.193 302.548,377.158 302.558,377.122 302.567,377.087 302.576,377.051 302.585,377.016 302.594,376.981 302.604,376.945 302.613,376.91 302.622,376.874 302.631,376.839 302.64,376.804 302.65,376.768 302.659,376.733 302.668,376.697 302.677,376.662 302.686,376.627 302.695,376.591 302.705,376.556 302.714,376.52 302.723,376.485 302.732,376.449 302.741,376.414 302.751,376.379 302.76,376.343 302.769,376.308 302.778,376.272 302.787,376.237 302.797,376.202 302.806,376.166 302.815,376.131 302.824,376.095 302.833,376.06 302.843,376.024 302.852,375.989 302.861,375.954 302.87,375.918 302.879,375.883 302.888,375.847 302.898,375.812 302.907,375.777 302.916,375.741 302.925,375.706 302.934,375.67 302.944,375.635 302.953,375.6 302.962,375.564 302.971,375.529 302.98,375.493 302.99,375.458 302.999,375.423 303.008,375.387 303.017,375.352 303.026,375.316 303.035,375.281 303.045,375.245 303.054,375.21 303.063,375.175 303.072,375.139 303.081,375.104 303.091,375.068 303.1,375.033 303.109,374.998 303.118,374.962 303.127,374.927 303.137,374.891 303.146,374.856 303.155,374.821 303.164,374.785 303.173,374.75 303.183,374.714 303.192,374.679 303.201,374.644 303.21,374.608 303.219,374.573 303.228,374.537 303.238,374.502 303.247,374.467 303.256,374.431 303.265,374.396 303.274,374.36 303.284,374.325 303.293,374.29 303.302,374.254 303.311,374.219 303.32,374.183 303.33,374.148 303.339,374.113 303.348,374.077 303.357,374.042 303.366,374.006 303.375,373.971 303.385,373.936 303.394,373.9 303.403,373.865 303.412,373.829 303.421,373.794 303.431,373.759 303.44,373.723 303.449,373.688 303.458,373.652 303.467,373.617 303.477,373.582 303.486,373.546 303.495,373.511 303.504,373.475 303.513,373.44 303.523,373.405 303.532,373.369 303.541,373.334 303.55,373.298 303.559,373.263 303.568,373.228 303.578,373.192 303.587,373.157 303.596,373.121 303.605,373.086 303.614,373.051 303.624,373.015 303.633,372.98 303.642,372.944 303.651,372.909 303.66,372.874 303.67,372.838 303.679,372.803 303.688,372.767 303.697,372.732 303.706,372.697 303.715,372.661 303.725,372.626 303.734,372.59 303.743,372.555 303.752,372.52 303.761,372.484 303.771,372.449 303.78,372.413 303.789,372.378 303.798,372.343 303.807,372.307 303.817,372.272 303.826,372.236 303.835,372.201 303.844,372.166 303.853,372.13 303.863,372.095 303.872,372.06 303.881,372.024 303.89,371.989 303.899,371.953 303.908,371.918 303.918,371.883 303.927,371.847 303.936,371.812 303.945,371.776 303.954,371.741 303.964,371.706 303.973,371.67 303.982,371.635 303.991,371.599 304,371.564 304.01,371.529 304.019,371.493 304.028,371.458 304.037,371.423 304.046,371.387 304.055,371.352 304.065,371.316 304.074,371.281 304.083,371.246 304.092,371.21 304.101,371.175 304.111,371.139 304.12,371.104 304.129,371.069 304.138,371.033 304.147,370.998 304.157,370.962 304.166,370.927 304.175,370.892 304.184,370.856 304.193,370.821 304.203,370.786 304.212,370.75 304.221,370.715 304.23,370.679 304.239,370.644 304.248,370.609 304.258,370.573 304.267,370.538 304.276,370.502 304.285,370.467 304.294,370.432 304.304,370.396 304.313,370.361 304.322,370.326 304.331,370.29 304.34,370.255 304.35,370.219 304.359,370.184 304.368,370.149 304.377,370.113 304.386,370.078 304.395,370.043 304.405,370.007 304.414,369.972 304.423,369.936 304.432,369.901 304.441,369.866 304.451,369.83 304.46,369.795 304.469,369.759 304.478,369.724 304.487,369.689 304.497,369.653 304.506,369.618 304.515,369.583 304.524,369.547 304.533,369.512 304.543,369.476 304.552,369.441 304.561,369.406 304.57,369.37 304.579,369.335 304.588,369.3 304.598,369.264 304.607,369.229 304.616,369.193 304.625,369.158 304.634,369.123 304.644,369.087 304.653,369.052 304.662,369.017 304.671,368.981 304.68,368.946 304.69,368.91 304.699,368.875 304.708,368.84 304.717,368.804 304.726,368.769 304.736,368.734 304.745,368.698 304.754,368.663 304.763,368.627 304.772,368.592 304.781,368.557 304.791,368.521 304.8,368.486 304.809,368.451 304.818,368.415 304.827,368.38 304.837,368.344 304.846,368.309 304.855,368.274 304.864,368.238 304.873,368.203 304.883,368.168 304.892,368.132 304.901,368.097 304.91,368.061 304.919,368.026 304.928,367.991 304.938,367.955 304.947,367.92 304.956,367.885 304.965,367.849 304.974,367.814 304.984,367.779 304.993,367.743 305.002,367.708 305.011,367.672 305.02,367.637 305.03,367.602 305.039,367.566 305.048,367.531 305.057,367.496 305.066,367.46 305.076,367.425 305.085,367.39 305.094,367.354 305.103,367.319 305.112,367.283 305.121,367.248 305.131,367.213 305.14,367.177 305.149,367.142 305.158,367.107 305.167,367.071 305.177,367.036 305.186,367.001 305.195,366.965 305.204,366.93 305.213,366.894 305.223,366.859 305.232,366.824 305.241,366.788 305.25,366.753 305.259,366.718 305.268,366.682 305.278,366.647 305.287,366.612 305.296,366.576 305.305,366.541 305.314,366.505 305.324,366.47 305.333,366.435 305.342,366.399 305.351,366.364 305.36,366.329 305.37,366.293 305.379,366.258 305.388,366.223 305.397,366.187 305.406,366.152 305.416,366.116 305.425,366.081 305.434,366.046 305.443,366.01 305.452,365.975 305.461,365.94 305.471,365.904 305.48,365.869 305.489,365.834 305.498,365.798 305.507,365.763 305.517,365.728 305.526,365.692 305.535,365.657 305.544,365.622 305.553,365.586 305.563,365.551 305.572,365.515 305.581,365.48 305.59,365.445 305.599,365.409 305.608,365.374 305.618,365.339 305.627,365.303 305.636,365.268 305.645,365.233 305.654,365.197 305.664,365.162 305.673,365.127 305.682,365.091 305.691,365.056 305.7,365.021 305.71,364.985 305.719,364.95 305.728,364.914 305.737,364.879 305.746,364.844 305.756,364.808 305.765,364.773 305.774,364.738 305.783,364.702 305.792,364.667 305.801,364.632 305.811,364.596 305.82,364.561 305.829,364.526 305.838,364.49 305.847,364.455 305.857,364.42 305.866,364.384 305.875,364.349 305.884,364.314 305.893,364.278 305.903,364.243 305.912,364.208 305.921,364.172 305.93,364.137 305.939,364.101 305.948,364.066 305.958,364.031 305.967,363.995 305.976,363.96 305.985,363.925 305.994,363.889 306.004,363.854 306.013,363.819 306.022,363.783 306.031,363.748 306.04,363.713 306.05,363.677 306.059,363.642 306.068,363.607 306.077,363.571 306.086,363.536 306.096,363.501 306.105,363.465 306.114,363.43 306.123,363.395 306.132,363.359 306.141,363.324 306.151,363.289 306.16,363.253 306.169,363.218 306.178,363.183 306.187,363.147 306.197,363.112 306.206,363.077 306.215,363.041 306.224,363.006 306.233,362.971 306.243,362.935 306.252,362.9 306.261,362.865 306.27,362.829 306.279,362.794 306.288,362.759 306.298,362.723 306.307,362.688 306.316,362.653 306.325,362.617 306.334,362.582 306.344,362.547 306.353,362.511 306.362,362.476 306.371,362.441 306.38,362.405 306.39,362.37 306.399,362.335 306.408,362.299 306.417,362.264 306.426,362.229 306.436,362.193 306.445,362.158 306.454,362.123 306.463,362.087 306.472,362.052 306.481,362.017 306.491,361.981 306.5,361.946 306.509,361.911 306.518,361.875 306.527,361.84 306.537,361.805 306.546,361.769 306.555,361.734 306.564,361.699 306.573,361.663 306.583,361.628 306.592,361.593 306.601,361.557 306.61,361.522 306.619,361.487 306.628,361.451 306.638,361.416 306.647,361.381 306.656,361.345 306.665,361.31 306.674,361.275 306.684,361.239 306.693,361.204 306.702,361.169 306.711,361.133 306.72,361.098 306.73,361.063 306.739,361.027 306.748,360.992 306.757,360.957 306.766,360.921 306.776,360.886 306.785,360.851 306.794,360.816 306.803,360.78 306.812,360.745 306.821,360.71 306.831,360.674 306.84,360.639 306.849,360.604 306.858,360.568 306.867,360.533 306.877,360.498 306.886,360.462 306.895,360.427 306.904,360.392 306.913,360.356 306.923,360.321 306.932,360.286 306.941,360.25 306.95,360.215 306.959,360.18 306.969,360.144 306.978,360.109 306.987,360.074 306.996,360.038 307.005,360.003 307.014,359.968 307.024,359.933 307.033,359.897 307.042,359.862 307.051,359.827 307.06,359.791 307.07,359.756 307.079,359.721 307.088,359.685 307.097,359.65 307.106,359.615 307.116,359.579 307.125,359.544 307.134,359.509 307.143,359.473 307.152,359.438 307.161,359.403 307.171,359.368 307.18,359.332 307.189,359.297 307.198,359.262 307.207,359.226 307.217,359.191 307.226,359.156 307.235,359.12 307.244,359.085 307.253,359.05 307.263,359.014 307.272,358.979 307.281,358.944 307.29,358.909 307.299,358.873 307.309,358.838 307.318,358.803 307.327,358.767 307.336,358.732 307.345,358.697 307.354,358.661 307.364,358.626 307.373,358.591 307.382,358.555 307.391,358.52 307.4,358.485 307.41,358.45 307.419,358.414 307.428,358.379 307.437,358.344 307.446,358.308 307.456,358.273 307.465,358.238 307.474,358.202 307.483,358.167 307.492,358.132 307.501,358.097 307.511,358.061 307.52,358.026 307.529,357.991 307.538,357.955 307.547,357.92 307.557,357.885 307.566,357.849 307.575,357.814 307.584,357.779 307.593,357.744 307.603,357.708 307.612,357.673 307.621,357.638 307.63,357.602 307.639,357.567 307.649,357.532 307.658,357.496 307.667,357.461 307.676,357.426 307.685,357.391 307.694,357.355 307.704,357.32 307.713,357.285 307.722,357.249 307.731,357.214 307.74,357.179 307.75,357.143 307.759,357.108 307.768,357.073 307.777,357.038 307.786,357.002 307.796,356.967 307.805,356.932 307.814,356.896 307.823,356.861 307.832,356.826 307.841,356.791 307.851,356.755 307.86,356.72 307.869,356.685 307.878,356.649 307.887,356.614 307.897,356.579 307.906,356.544 307.915,356.508 307.924,356.473 307.933,356.438 307.943,356.402 307.952,356.367 307.961,356.332 307.97,356.297 307.979,356.261 307.989,356.226 307.998,356.191 308.007,356.155 308.016,356.12 308.025,356.085 308.034,356.05 308.044,356.014 308.053,355.979 308.062,355.944 308.071,355.908 308.08,355.873 308.09,355.838 308.099,355.803 308.108,355.767 308.117,355.732 308.126,355.697 308.136,355.661 308.145,355.626 308.154,355.591 308.163,355.556 308.172,355.52 308.181,355.485 308.191,355.45 308.2,355.414 308.209,355.379 308.218,355.344 308.227,355.309 308.237,355.273 308.246,355.238 308.255,355.203 308.264,355.167 308.273,355.132 308.283,355.097 308.292,355.062 308.301,355.026 308.31,354.991 308.319,354.956 308.329,354.921 308.338,354.885 308.347,354.85 308.356,354.815 308.365,354.779 308.374,354.744 308.384,354.709 308.393,354.674 308.402,354.638 308.411,354.603 308.42,354.568 308.43,354.533 308.439,354.497 308.448,354.462 308.457,354.427 308.466,354.391 308.476,354.356 308.485,354.321 308.494,354.286 308.503,354.25 308.512,354.215 308.521,354.18 308.531,354.145 308.54,354.109 308.549,354.074 308.558,354.039 308.567,354.003 308.577,353.968 308.586,353.933 308.595,353.898 308.604,353.862 308.613,353.827 308.623,353.792 308.632,353.757 308.641,353.721 308.65,353.686 308.659,353.651 308.669,353.616 308.678,353.58 308.687,353.545 308.696,353.51 308.705,353.474 308.714,353.439 308.724,353.404 308.733,353.369 308.742,353.333 308.751,353.298 308.76,353.263 308.77,353.228 308.779,353.192 308.788,353.157 308.797,353.122 308.806,353.087 308.816,353.051 308.825,353.016 308.834,352.981 308.843,352.946 308.852,352.91 308.861,352.875 308.871,352.84 308.88,352.805 308.889,352.769 308.898,352.734 308.907,352.699 308.917,352.663 308.926,352.628 308.935,352.593 308.944,352.558 308.953,352.522 308.963,352.487 308.972,352.452 308.981,352.417 308.99,352.381 308.999,352.346 309.009,352.311 309.018,352.276 309.027,352.24 309.036,352.205 309.045,352.17 309.054,352.135 309.064,352.099 309.073,352.064 309.082,352.029 309.091,351.994 309.1,351.958 309.11,351.923 309.119,351.888 309.128,351.853 309.137,351.817 309.146,351.782 309.156,351.747 309.165,351.712 309.174,351.676 309.183,351.641 309.192,351.606 309.201,351.571 309.211,351.535 309.22,351.5 309.229,351.465 309.238,351.43 309.247,351.394 309.257,351.359 309.266,351.324 309.275,351.289 309.284,351.253 309.293,351.218 309.303,351.183 309.312,351.148 309.321,351.112 309.33,351.077 309.339,351.042 309.349,351.007 309.358,350.972 309.367,350.936 309.376,350.901 309.385,350.866 309.394,350.831 309.404,350.795 309.413,350.76 309.422,350.725 309.431,350.69 309.44,350.654 309.45,350.619 309.459,350.584 309.468,350.549 309.477,350.513 309.486,350.478 309.496,350.443 309.505,350.408 309.514,350.372 309.523,350.337 309.532,350.302 309.542,350.267 309.551,350.231 309.56,350.196 309.569,350.161 309.578,350.126 309.587,350.091 309.597,350.055 309.606,350.02 309.615,349.985 309.624,349.95 309.633,349.914 309.643,349.879 309.652,349.844 309.661,349.809 309.67,349.773 309.679,349.738 309.689,349.703 309.698,349.668 309.707,349.633 309.716,349.597 309.725,349.562 309.734,349.527 309.744,349.492 309.753,349.456 309.762,349.421 309.771,349.386 309.78,349.351 309.79,349.315 309.799,349.28 309.808,349.245 309.817,349.21 309.826,349.175 309.836,349.139 309.845,349.104 309.854,349.069 309.863,349.034 309.872,348.998 309.882,348.963 309.891,348.928 309.9,348.893 309.909,348.858 309.918,348.822 309.927,348.787 309.937,348.752 309.946,348.717 309.955,348.681 309.964,348.646 309.973,348.611 309.983,348.576 309.992,348.541 310.001,348.505 310.01,348.47 310.019,348.435 310.029,348.4 310.038,348.364 310.047,348.329 310.056,348.294 310.065,348.259 310.074,348.224 310.084,348.188 310.093,348.153 310.102,348.118 310.111,348.083 310.12,348.047 310.13,348.012 310.139,347.977 310.148,347.942 310.157,347.907 310.166,347.871 310.176,347.836 310.185,347.801 310.194,347.766 310.203,347.731 310.212,347.695 310.222,347.66 310.231,347.625 310.24,347.59 310.249,347.555 310.258,347.519 310.267,347.484 310.277,347.449 310.286,347.414 310.295,347.378 310.304,347.343 310.313,347.308 310.323,347.273 310.332,347.238 310.341,347.202 310.35,347.167 310.359,347.132 310.369,347.097 310.378,347.062 310.387,347.026 310.396,346.991 310.405,346.956 310.414,346.921 310.424,346.886 310.433,346.85 310.442,346.815 310.451,346.78 310.46,346.745 310.47,346.71 310.479,346.674 310.488,346.639 310.497,346.604 310.506,346.569 310.516,346.534 310.525,346.498 310.534,346.463 310.543,346.428 310.552,346.393 310.562,346.358 310.571,346.322 310.58,346.287 310.589,346.252 310.598,346.217 310.607,346.182 310.617,346.146 310.626,346.111 310.635,346.076 310.644,346.041 310.653,346.006 310.663,345.97 310.672,345.935 310.681,345.9 310.69,345.865 310.699,345.83 310.709,345.794 310.718,345.759 310.727,345.724 310.736,345.689 310.745,345.654 310.754,345.618 310.764,345.583 310.773,345.548 310.782,345.513 310.791,345.478 310.8,345.442 310.81,345.407 310.819,345.372 310.828,345.337 310.837,345.302 310.846,345.267 310.856,345.231 310.865,345.196 310.874,345.161 310.883,345.126 310.892,345.091 310.902,345.055 310.911,345.02 310.92,344.985 310.929,344.95 310.938,344.915 310.947,344.879 310.957,344.844 310.966,344.809 310.975,344.774 310.984,344.739 310.993,344.704 311.003,344.668 311.012,344.633 311.021,344.598 311.03,344.563 311.039,344.528 311.049,344.492 311.058,344.457 311.067,344.422 311.076,344.387 311.085,344.352 311.094,344.317 311.104,344.281 311.113,344.246 311.122,344.211 311.131,344.176 311.14,344.141 311.15,344.105 311.159,344.07 311.168,344.035 311.177,344 311.186,343.965 311.196,343.93 311.205,343.894 311.214,343.859 311.223,343.824 311.232,343.789 311.242,343.754 311.251,343.719 311.26,343.683 311.269,343.648 311.278,343.613 311.287,343.578 311.297,343.543 311.306,343.508 311.315,343.472 311.324,343.437 311.333,343.402 311.343,343.367 311.352,343.332 311.361,343.296 311.37,343.261 311.379,343.226 311.389,343.191 311.398,343.156 311.407,343.121 311.416,343.085 311.425,343.05 311.434,343.015 311.444,342.98 311.453,342.945 311.462,342.91 311.471,342.874 311.48,342.839 311.49,342.804 311.499,342.769 311.508,342.734 311.517,342.699 311.526,342.663 311.536,342.628 311.545,342.593 311.554,342.558 311.563,342.523 311.572,342.488 311.582,342.453 311.591,342.417 311.6,342.382 311.609,342.347 311.618,342.312 311.627,342.277 311.637,342.242 311.646,342.206 311.655,342.171 311.664,342.136 311.673,342.101 311.683,342.066 311.692,342.031 311.701,341.995 311.71,341.96 311.719,341.925 311.729,341.89 311.738,341.855 311.747,341.82 311.756,341.785 311.765,341.749 311.774,341.714 311.784,341.679 311.793,341.644 311.802,341.609 311.811,341.574 311.82,341.538 311.83,341.503 311.839,341.468 311.848,341.433 311.857,341.398 311.866,341.363 311.876,341.328 311.885,341.292 311.894,341.257 311.903,341.222 311.912,341.187 311.922,341.152 311.931,341.117 311.94,341.082 311.949,341.046 311.958,341.011 311.967,340.976 311.977,340.941 311.986,340.906 311.995,340.871 312.004,340.836 312.013,340.8 312.023,340.765 312.032,340.73 312.041,340.695 312.05,340.66 312.059,340.625 312.069,340.59 312.078,340.554 312.087,340.519 312.096,340.484 312.105,340.449 312.115,340.414 312.124,340.379 312.133,340.344 312.142,340.308 312.151,340.273 312.16,340.238 312.17,340.203 312.179,340.168 312.188,340.133 312.197,340.098 312.206,340.062 312.216,340.027 312.225,339.992 312.234,339.957 312.243,339.922 312.252,339.887 312.262,339.852 312.271,339.816 312.28,339.781 312.289,339.746 312.298,339.711 312.307,339.676 312.317,339.641 312.326,339.606 312.335,339.571 312.344,339.535 312.353,339.5 312.363,339.465 312.372,339.43 312.381,339.395 312.39,339.36 312.399,339.325 312.409,339.29 312.418,339.254 312.427,339.219 312.436,339.184 312.445,339.149 312.455,339.114 312.464,339.079 312.473,339.044 312.482,339.009 312.491,338.973 312.5,338.938 312.51,338.903 312.519,338.868 312.528,338.833 312.537,338.798 312.546,338.763 312.556,338.728 312.565,338.692 312.574,338.657 312.583,338.622 312.592,338.587 312.602,338.552 312.611,338.517 312.62,338.482 312.629,338.447 312.638,338.411 312.647,338.376 312.657,338.341 312.666,338.306 312.675,338.271 312.684,338.236 312.693,338.201 312.703,338.166 312.712,338.131 312.721,338.095 312.73,338.06 312.739,338.025 312.749,337.99 312.758,337.955 312.767,337.92 312.776,337.885 312.785,337.85 312.795,337.814 312.804,337.779 312.813,337.744 312.822,337.709 312.831,337.674 312.84,337.639 312.85,337.604 312.859,337.569 312.868,337.534 312.877,337.499 312.886,337.463 312.896,337.428 312.905,337.393 312.914,337.358 312.923,337.323 312.932,337.288 312.942,337.253 312.951,337.218 312.96,337.183 312.969,337.147 312.978,337.112 312.987,337.077 312.997,337.042 313.006,337.007 313.015,336.972 313.024,336.937 313.033,336.902 313.043,336.867 313.052,336.832 313.061,336.796 313.07,336.761 313.079,336.726 313.089,336.691 313.098,336.656 313.107,336.621 313.116,336.586 313.125,336.551 313.135,336.516 313.144,336.481 313.153,336.445 313.162,336.41 313.171,336.375 313.18,336.34 313.19,336.305 313.199,336.27 313.208,336.235 313.217,336.2 313.226,336.165 313.236,336.13 313.245,336.094 313.254,336.059 313.263,336.024 313.272,335.989 313.282,335.954 313.291,335.919 313.3,335.884 313.309,335.849 313.318,335.814 313.327,335.779 313.337,335.744 313.346,335.708 313.355,335.673 313.364,335.638 313.373,335.603 313.383,335.568 313.392,335.533 313.401,335.498 313.41,335.463 313.419,335.428 313.429,335.393 313.438,335.358 313.447,335.323 313.456,335.287 313.465,335.252 313.475,335.217 313.484,335.182 313.493,335.147 313.502,335.112 313.511,335.077 313.52,335.042 313.53,335.007 313.539,334.972 313.548,334.937 313.557,334.902 313.566,334.866 313.576,334.831 313.585,334.796 313.594,334.761 313.603,334.726 313.612,334.691 313.622,334.656 313.631,334.621 313.64,334.586 313.649,334.551 313.658,334.516 313.667,334.481 313.677,334.446 313.686,334.41 313.695,334.375 313.704,334.34 313.713,334.305 313.723,334.27 313.732,334.235 313.741,334.2 313.75,334.165 313.759,334.13 313.769,334.095 313.778,334.06 313.787,334.025 313.796,333.99 313.805,333.955 313.815,333.919 313.824,333.884 313.833,333.849 313.842,333.814 313.851,333.779 313.86,333.744 313.87,333.709 313.879,333.674 313.888,333.639 313.897,333.604 313.906,333.569 313.916,333.534 313.925,333.499 313.934,333.464 313.943,333.429 313.952,333.394 313.962,333.358 313.971,333.323 313.98,333.288 313.989,333.253 313.998,333.218 314.007,333.183 314.017,333.148 314.026,333.113 314.035,333.078 314.044,333.043 314.053,333.008 314.063,332.973 314.072,332.938 314.081,332.903 314.09,332.868 314.099,332.833 314.109,332.798 314.118,332.762 314.127,332.727 314.136,332.692 314.145,332.657 314.155,332.622 314.164,332.587 314.173,332.552 314.182,332.517 314.191,332.482 314.2,332.447 314.21,332.412 314.219,332.377 314.228,332.342 314.237,332.307 314.246,332.272 314.256,332.237 314.265,332.202 314.274,332.167 314.283,332.132 314.292,332.096 314.302,332.061 314.311,332.026 314.32,331.991 314.329,331.956 314.338,331.921 314.348,331.886 314.357,331.851 314.366,331.816 314.375,331.781 314.384,331.746 314.393,331.711 314.403,331.676 314.412,331.641 314.421,331.606 314.43,331.571 314.439,331.536 314.449,331.501 314.458,331.466 314.467,331.431 314.476,331.396 314.485,331.361 314.495,331.326 314.504,331.291 314.513,331.255 314.522,331.22 314.531,331.185 314.54,331.15 314.55,331.115 314.559,331.08 314.568,331.045 314.577,331.01 314.586,330.975 314.596,330.94 314.605,330.905 314.614,330.87 314.623,330.835 314.632,330.8 314.642,330.765 314.651,330.73 314.66,330.695 314.669,330.66 314.678,330.625 314.688,330.59 314.697,330.555 314.706,330.52 314.715,330.485 314.724,330.45 314.733,330.415 314.743,330.38 314.752,330.345 314.761,330.31 314.77,330.275 314.779,330.24 314.789,330.205 314.798,330.17 314.807,330.134 314.816,330.099 314.825,330.064 314.835,330.029 314.844,329.994 314.853,329.959 314.862,329.924 314.871,329.889 314.88,329.854 314.89,329.819 314.899,329.784 314.908,329.749 314.917,329.714 314.926,329.679 314.936,329.644 314.945,329.609 314.954,329.574 314.963,329.539 314.972,329.504 314.982,329.469 314.991,329.434 315,329.399 315.009,329.364 315.018,329.329 315.028,329.294 315.037,329.259 315.046,329.224 315.055,329.189 315.064,329.154 315.073,329.119 315.083,329.084 315.092,329.049 315.101,329.014 315.11,328.979 315.119,328.944 315.129,328.909 315.138,328.874 315.147,328.839 315.156,328.804 315.165,328.769 315.175,328.734 315.184,328.699 315.193,328.664 315.202,328.629 315.211,328.594 315.22,328.559 315.23,328.524 315.239,328.489 315.248,328.454 315.257,328.419 315.266,328.384 315.276,328.349 315.285,328.314 315.294,328.279 315.303,328.244 315.312,328.209 315.322,328.174 315.331,328.139 315.34,328.104 315.349,328.069 315.358,328.034 315.368,327.999 315.377,327.964 315.386,327.929 315.395,327.894 315.404,327.859 315.413,327.824 315.423,327.789 315.432,327.754 315.441,327.719 315.45,327.684 315.459,327.649 315.469,327.614 315.478,327.579 315.487,327.544 315.496,327.509 315.505,327.474 315.515,327.439 315.524,327.404 315.533,327.369 315.542,327.334 315.551,327.299 315.56,327.264 315.57,327.229 315.579,327.194 315.588,327.159 315.597,327.124 315.606,327.089 315.616,327.054 315.625,327.019 315.634,326.984 315.643,326.949 315.652,326.914 315.662,326.879 315.671,326.844 315.68,326.809 315.689,326.774 315.698,326.739 315.708,326.704 315.717,326.669 315.726,326.634 315.735,326.599 315.744,326.564 315.753,326.529 315.763,326.494 315.772,326.459 315.781,326.424 315.79,326.389 315.799,326.354 315.809,326.319 315.818,326.284 315.827,326.249 315.836,326.214 315.845,326.18 315.855,326.145 315.864,326.11 315.873,326.075 315.882,326.04 315.891,326.005 315.9,325.97 315.91,325.935 315.919,325.9 315.928,325.865 315.937,325.83 315.946,325.795 315.956,325.76 315.965,325.725 315.974,325.69 315.983,325.655 315.992,325.62 316.002,325.585 316.011,325.55 316.02,325.515 316.029,325.48 316.038,325.445 316.048,325.41 316.057,325.375 316.066,325.34 316.075,325.305 316.084,325.27 316.093,325.235 316.103,325.2 316.112,325.165 316.121,325.13 316.13,325.096 316.139,325.061 316.149,325.026 316.158,324.991 316.167,324.956 316.176,324.921 316.185,324.886 316.195,324.851 316.204,324.816 316.213,324.781 316.222,324.746 316.231,324.711 316.24,324.676 316.25,324.641 316.259,324.606 316.268,324.571 316.277,324.536 316.286,324.501 316.296,324.466 316.305,324.431 316.314,324.396 316.323,324.361 316.332,324.326 316.342,324.292 316.351,324.257 316.36,324.222 316.369,324.187 316.378,324.152 316.388,324.117 316.397,324.082 316.406,324.047 316.415,324.012 316.424,323.977 316.433,323.942 316.443,323.907 316.452,323.872 316.461,323.837 316.47,323.802 316.479,323.767 316.489,323.732 316.498,323.697 316.507,323.662 316.516,323.628 316.525,323.593 316.535,323.558 316.544,323.523 316.553,323.488 316.562,323.453 316.571,323.418 316.58,323.383 316.59,323.348 316.599,323.313 316.608,323.278 316.617,323.243 316.626,323.208 316.636,323.173 316.645,323.138 316.654,323.103 316.663,323.068 316.672,323.034 316.682,322.999 316.691,322.964 316.7,322.929 316.709,322.894 316.718,322.859 316.728,322.824 316.737,322.789 316.746,322.754 316.755,322.719 316.764,322.684 316.773,322.649 316.783,322.614 316.792,322.579 316.801,322.544 316.81,322.51 316.819,322.475 316.829,322.44 316.838,322.405 316.847,322.37 316.856,322.335 316.865,322.3 316.875,322.265 316.884,322.23 316.893,322.195 316.902,322.16 316.911,322.125 316.921,322.09 316.93,322.056 316.939,322.021 316.948,321.986 316.957,321.951 316.966,321.916 316.976,321.881 316.985,321.846 316.994,321.811 317.003,321.776 317.012,321.741 317.022,321.706 317.031,321.671 317.04,321.637 317.049,321.602 317.058,321.567 317.068,321.532 317.077,321.497 317.086,321.462 317.095,321.427 317.104,321.392 317.113,321.357 317.123,321.322 317.132,321.287 317.141,321.252 317.15,321.218 317.159,321.183 317.169,321.148 317.178,321.113 317.187,321.078 317.196,321.043 317.205,321.008 317.215,320.973 317.224,320.938 317.233,320.903 317.242,320.868 317.251,320.834 317.261,320.799 317.27,320.764 317.279,320.729 317.288,320.694 317.297,320.659 317.306,320.624 317.316,320.589 317.325,320.554 317.334,320.519 317.343,320.484 317.352,320.45 317.362,320.415 317.371,320.38 317.38,320.345 317.389,320.31 317.398,320.275 317.408,320.24 317.417,320.205 317.426,320.17 317.435,320.136 317.444,320.101 317.453,320.066 317.463,320.031 317.472,319.996 317.481,319.961 317.49,319.926 317.499,319.891 317.509,319.856 317.518,319.821 317.527,319.787 317.536,319.752 317.545,319.717 317.555,319.682 317.564,319.647 317.573,319.612 317.582,319.577 317.591,319.542 317.601,319.507 317.61,319.473 317.619,319.438 317.628,319.403 317.637,319.368 317.646,319.333 317.656,319.298 317.665,319.263 317.674,319.228 317.683,319.193 317.692,319.159 317.702,319.124 317.711,319.089 317.72,319.054 317.729,319.019 317.738,318.984 317.748,318.949 317.757,318.914 317.766,318.88 317.775,318.845 317.784,318.81 317.793,318.775 317.803,318.74 317.812,318.705 317.821,318.67 317.83,318.635 317.839,318.6 317.849,318.566 317.858,318.531 317.867,318.496 317.876,318.461 317.885,318.426 317.895,318.391 317.904,318.356 317.913,318.321 317.922,318.287 317.931,318.252 317.941,318.217 317.95,318.182 317.959,318.147 317.968,318.112 317.977,318.077 317.986,318.043 317.996,318.008 318.005,317.973 318.014,317.938 318.023,317.903 318.032,317.868 318.042,317.833 318.051,317.798 318.06,317.764 318.069,317.729 318.078,317.694 318.088,317.659 318.097,317.624 318.106,317.589 318.115,317.554 318.124,317.52 318.133,317.485 318.143,317.45 318.152,317.415 318.161,317.38 318.17,317.345 318.179,317.31 318.189,317.276 318.198,317.241 318.207,317.206 318.216,317.171 318.225,317.136 318.235,317.101 318.244,317.066 318.253,317.032 318.262,316.997 318.271,316.962 318.281,316.927 318.29,316.892 318.299,316.857 318.308,316.822 318.317,316.788 318.326,316.753 318.336,316.718 318.345,316.683 318.354,316.648 318.363,316.613 318.372,316.578 318.382,316.544 318.391,316.509 318.4,316.474 318.409,316.439 318.418,316.404 318.428,316.369 318.437,316.335 318.446,316.3 318.455,316.265 318.464,316.23 318.473,316.195 318.483,316.16 318.492,316.125 318.501,316.091 318.51,316.056 318.519,316.021 318.529,315.986 318.538,315.951 318.547,315.916 318.556,315.882 318.565,315.847 318.575,315.812 318.584,315.777 318.593,315.742 318.602,315.707 318.611,315.673 318.621,315.638 318.63,315.603 318.639,315.568 318.648,315.533 318.657,315.498 318.666,315.464 318.676,315.429 318.685,315.394 318.694,315.359 318.703,315.324 318.712,315.289 318.722,315.255 318.731,315.22 318.74,315.185 318.749,315.15 318.758,315.115 318.768,315.08 318.777,315.046 318.786,315.011 318.795,314.976 318.804,314.941 318.813,314.906 318.823,314.871 318.832,314.837 318.841,314.802 318.85,314.767 318.859,314.732 318.869,314.697 318.878,314.663 318.887,314.628 318.896,314.593 318.905,314.558 318.915,314.523 318.924,314.488 318.933,314.454 318.942,314.419 318.951,314.384 318.961,314.349 318.97,314.314 318.979,314.28 318.988,314.245 318.997,314.21 319.006,314.175 319.016,314.14 319.025,314.105 319.034,314.071 319.043,314.036 319.052,314.001 319.062,313.966 319.071,313.931 319.08,313.897 319.089,313.862 319.098,313.827 319.108,313.792 319.117,313.757 319.126,313.722 319.135,313.688 319.144,313.653 319.153,313.618 319.163,313.583 319.172,313.548 319.181,313.514 319.19,313.479 319.199,313.444 319.209,313.409 319.218,313.374 319.227,313.34 319.236,313.305 319.245,313.27 319.255,313.235 319.264,313.2 319.273,313.166 319.282,313.131 319.291,313.096 319.301,313.061 319.31,313.026 319.319,312.992 319.328,312.957 319.337,312.922 319.346,312.887 319.356,312.852 319.365,312.818 319.374,312.783 319.383,312.748 319.392,312.713 319.402,312.678 319.411,312.644 319.42,312.609 319.429,312.574 319.438,312.539 319.448,312.504 319.457,312.47 319.466,312.435 319.475,312.4 319.484,312.365 319.494,312.331 319.503,312.296 319.512,312.261 319.521,312.226 319.53,312.191 319.539,312.157 319.549,312.122 319.558,312.087 319.567,312.052 319.576,312.017 319.585,311.983 319.595,311.948 319.604,311.913 319.613,311.878 319.622,311.844 319.631,311.809 319.641,311.774 319.65,311.739 319.659,311.704 319.668,311.67 319.677,311.635 319.686,311.6 319.696,311.565 319.705,311.531 319.714,311.496 319.723,311.461 319.732,311.426 319.742,311.391 319.751,311.357 319.76,311.322 319.769,311.287 319.778,311.252 319.788,311.218 319.797,311.183 319.806,311.148 319.815,311.113 319.824,311.078 319.834,311.044 319.843,311.009 319.852,310.974 319.861,310.939 319.87,310.905 319.879,310.87 319.889,310.835 319.898,310.8 319.907,310.766 319.916,310.731 319.925,310.696 319.935,310.661 319.944,310.626 319.953,310.592 319.962,310.557 319.971,310.522 319.981,310.487 319.99,310.453 319.999,310.418 320.008,310.383 320.017,310.348 320.026,310.314 320.036,310.279 320.045,310.244 320.054,310.209 320.063,310.175 320.072,310.14 320.082,310.105 320.091,310.07 320.1,310.036 320.109,310.001 320.118,309.966 320.128,309.931 320.137,309.897 320.146,309.862 320.155,309.827 320.164,309.792 320.174,309.758 320.183,309.723 320.192,309.688 320.201,309.653 320.21,309.619 320.219,309.584 320.229,309.549 320.238,309.514 320.247,309.48 320.256,309.445 320.265,309.41 320.275,309.375 320.284,309.341 320.293,309.306 320.302,309.271 320.311,309.236 320.321,309.202 320.33,309.167 320.339,309.132 320.348,309.097 320.357,309.063 320.366,309.028 320.376,308.993 320.385,308.958 320.394,308.924 320.403,308.889 320.412,308.854 320.422,308.819 320.431,308.785 320.44,308.75 320.449,308.715 320.458,308.68 320.468,308.646 320.477,308.611 320.486,308.576 320.495,308.542 320.504,308.507 320.514,308.472 320.523,308.437 320.532,308.403 320.541,308.368 320.55,308.333 320.559,308.298 320.569,308.264 320.578,308.229 320.587,308.194 320.596,308.16 320.605,308.125 320.615,308.09 320.624,308.055 320.633,308.021 320.642,307.986 320.651,307.951 320.661,307.916 320.67,307.882 320.679,307.847 320.688,307.812 320.697,307.778 320.706,307.743 320.716,307.708 320.725,307.673 320.734,307.639 320.743,307.604 320.752,307.569 320.762,307.534 320.771,307.5 320.78,307.465 320.789,307.43 320.798,307.396 320.808,307.361 320.817,307.326 320.826,307.291 320.835,307.257 320.844,307.222 320.854,307.187 320.863,307.153 320.872,307.118 320.881,307.083 320.89,307.048 320.899,307.014 320.909,306.979 320.918,306.944 320.927,306.91 320.936,306.875 320.945,306.84 320.955,306.806 320.964,306.771 320.973,306.736 320.982,306.701 320.991,306.667 321.001,306.632 321.01,306.597 321.019,306.563 321.028,306.528 321.037,306.493 321.046,306.458 321.056,306.424 321.065,306.389 321.074,306.354 321.083,306.32 321.092,306.285 321.102,306.25 321.111,306.216 321.12,306.181 321.129,306.146 321.138,306.111 321.148,306.077 321.157,306.042 321.166,306.007 321.175,305.973 321.184,305.938 321.194,305.903 321.203,305.869 321.212,305.834 321.221,305.799 321.23,305.765 321.239,305.73 321.249,305.695 321.258,305.66 321.267,305.626 321.276,305.591 321.285,305.556 321.295,305.522 321.304,305.487 321.313,305.452 321.322,305.418 321.331,305.383 321.341,305.348 321.35,305.314 321.359,305.279 321.368,305.244 321.377,305.21 321.386,305.175 321.396,305.14 321.405,305.105 321.414,305.071 321.423,305.036 321.432,305.001 321.442,304.967 321.451,304.932 321.46,304.897 321.469,304.863 321.478,304.828 321.488,304.793 321.497,304.759 321.506,304.724 321.515,304.689 321.524,304.655 321.534,304.62 321.543,304.585 321.552,304.551 321.561,304.516 321.57,304.481 321.579,304.447 321.589,304.412 321.598,304.377 321.607,304.343 321.616,304.308 321.625,304.273 321.635,304.239 321.644,304.204 321.653,304.169 321.662,304.135 321.671,304.1 321.681,304.065 321.69,304.031 321.699,303.996 321.708,303.961 321.717,303.927 321.727,303.892 321.736,303.857 321.745,303.823 321.754,303.788 321.763,303.753 321.772,303.719 321.782,303.684 321.791,303.649 321.8,303.615 321.809,303.58 321.818,303.545 321.828,303.511 321.837,303.476 321.846,303.441 321.855,303.407 321.864,303.372 321.874,303.337 321.883,303.303 321.892,303.268 321.901,303.233 321.91,303.199 321.919,303.164 321.929,303.129 321.938,303.095 321.947,303.06 321.956,303.025 321.965,302.991 321.975,302.956 321.984,302.922 321.993,302.887 322.002,302.852 322.011,302.818 322.021,302.783 322.03,302.748 322.039,302.714 322.048,302.679 322.057,302.644 322.067,302.61 322.076,302.575 322.085,302.54 322.094,302.506 322.103,302.471 322.112,302.437 322.122,302.402 322.131,302.367 322.14,302.333 322.149,302.298 322.158,302.263 322.168,302.229 322.177,302.194 322.186,302.159 322.195,302.125 322.204,302.09 322.214,302.056 322.223,302.021 322.232,301.986 322.241,301.952 322.25,301.917 322.259,301.882 322.269,301.848 322.278,301.813 322.287,301.778 322.296,301.744 322.305,301.709 322.315,301.675 322.324,301.64 322.333,301.605 322.342,301.571 322.351,301.536 322.361,301.501 322.37,301.467 322.379,301.432 322.388,301.398 322.397,301.363 322.407,301.328 322.416,301.294 322.425,301.259 322.434,301.224 322.443,301.19 322.452,301.155 322.462,301.121 322.471,301.086 322.48,301.051 322.489,301.017 322.498,300.982 322.508,300.947 322.517,300.913 322.526,300.878 322.535,300.844 322.544,300.809 322.554,300.774 322.563,300.74 322.572,300.705 322.581,300.671 322.59,300.636 322.599,300.601 322.609,300.567 322.618,300.532 322.627,300.497 322.636,300.463 322.645,300.428 322.655,300.394 322.664,300.359 322.673,300.324 322.682,300.29 322.691,300.255 322.701,300.221 322.71,300.186 322.719,300.151 322.728,300.117 322.737,300.082 322.747,300.048 322.756,300.013 322.765,299.978 322.774,299.944 322.783,299.909 322.792,299.875 322.802,299.84 322.811,299.805 322.82,299.771 322.829,299.736 322.838,299.702 322.848,299.667 322.857,299.632 322.866,299.598 322.875,299.563 322.884,299.529 322.894,299.494 322.903,299.459 322.912,299.425 322.921,299.39 322.93,299.356 322.939,299.321 322.949,299.286 322.958,299.252 322.967,299.217 322.976,299.183 322.985,299.148 322.995,299.113 323.004,299.079 323.013,299.044 323.022,299.01 323.031,298.975 323.041,298.941 323.05,298.906 323.059,298.871 323.068,298.837 323.077,298.802 323.087,298.768 323.096,298.733 323.105,298.698 323.114,298.664 323.123,298.629 323.132,298.595 323.142,298.56 323.151,298.526 323.16,298.491 323.169,298.456 323.178,298.422 323.188,298.387 323.197,298.353 323.206,298.318 323.215,298.284 323.224,298.249 323.234,298.214 323.243,298.18 323.252,298.145 323.261,298.111 323.27,298.076 323.279,298.041 323.289,298.007 323.298,297.972 323.307,297.938 323.316,297.903 323.325,297.869 323.335,297.834 323.344,297.8 323.353,297.765 323.362,297.73 323.371,297.696 323.381,297.661 323.39,297.627 323.399,297.592 323.408,297.558 323.417,297.523 323.427,297.488 323.436,297.454 323.445,297.419 323.454,297.385 323.463,297.35 323.472,297.316 323.482,297.281 323.491,297.246 323.5,297.212 323.509,297.177 323.518,297.143 323.528,297.108 323.537,297.074 323.546,297.039 323.555,297.005 323.564,296.97 323.574,296.935 323.583,296.901 323.592,296.866 323.601,296.832 323.61,296.797 323.619,296.763 323.629,296.728 323.638,296.694 323.647,296.659 323.656,296.625 323.665,296.59 323.675,296.555 323.684,296.521 323.693,296.486 323.702,296.452 323.711,296.417 323.721,296.383 323.73,296.348 323.739,296.314 323.748,296.279 323.757,296.245 323.767,296.21 323.776,296.175 323.785,296.141 323.794,296.106 323.803,296.072 323.812,296.037 323.822,296.003 323.831,295.968 323.84,295.934 323.849,295.899 323.858,295.865 323.868,295.83 323.877,295.796 323.886,295.761 323.895,295.726 323.904,295.692 323.914,295.657 323.923,295.623 323.932,295.588 323.941,295.554 323.95,295.519 323.959,295.485 323.969,295.45 323.978,295.416 323.987,295.381 323.996,295.347 324.005,295.312 324.015,295.278 324.024,295.243 324.033,295.208 324.042,295.174 324.051,295.139 324.061,295.105 324.07,295.07 324.079,295.036 324.088,295.001 324.097,294.967 324.107,294.932 324.116,294.898 324.125,294.863 324.134,294.829 324.143,294.794 324.152,294.76 324.162,294.725 324.171,294.691 324.18,294.656 324.189,294.622 324.198,294.587 324.208,294.553 324.217,294.518 324.226,294.484 324.235,294.449 324.244,294.415 324.254,294.38 324.263,294.346 324.272,294.311 324.281,294.277 324.29,294.242 324.3,294.207 324.309,294.173 324.318,294.138 324.327,294.104 324.336,294.069 324.345,294.035 324.355,294 324.364,293.966 324.373,293.931 324.382,293.897 324.391,293.862 324.401,293.828 324.41,293.793 324.419,293.759 324.428,293.724 324.437,293.69 324.447,293.655 324.456,293.621 324.465,293.586 324.474,293.552 324.483,293.517 324.492,293.483 324.502,293.448 324.511,293.414 324.52,293.379 324.529,293.345 324.538,293.31 324.548,293.276 324.557,293.241 324.566,293.207 324.575,293.172 324.584,293.138 324.594,293.103 324.603,293.069 324.612,293.035 324.621,293 324.63,292.966 324.64,292.931 324.649,292.897 324.658,292.862 324.667,292.828 324.676,292.793 324.685,292.759 324.695,292.724 324.704,292.69 324.713,292.655 324.722,292.621 324.731,292.586 324.741,292.552 324.75,292.517 324.759,292.483 324.768,292.448 324.777,292.414 324.787,292.379 324.796,292.345 324.805,292.31 324.814,292.276 324.823,292.241 324.832,292.207 324.842,292.172 324.851,292.138 324.86,292.103 324.869,292.069 324.878,292.035 324.888,292 324.897,291.966 324.906,291.931 324.915,291.897 324.924,291.862 324.934,291.828 324.943,291.793 324.952,291.759 324.961,291.724 324.97,291.69 324.98,291.655 324.989,291.621 324.998,291.586 325.007,291.552 325.016,291.518 325.025,291.483 325.035,291.449 325.044,291.414 325.053,291.38 325.062,291.345 325.071,291.311 325.081,291.276 325.09,291.242 325.099,291.207 325.108,291.173 325.117,291.138 325.127,291.104 325.136,291.07 325.145,291.035 325.154,291.001 325.163,290.966 325.172,290.932 325.182,290.897 325.191,290.863 325.2,290.828 325.209,290.794 325.218,290.759 325.228,290.725 325.237,290.691 325.246,290.656 325.255,290.622 325.264,290.587 325.274,290.553 325.283,290.518 325.292,290.484 325.301,290.449 325.31,290.415 325.32,290.38 325.329,290.346 325.338,290.312 325.347,290.277 325.356,290.243 325.365,290.208 325.375,290.174 325.384,290.139 325.393,290.105 325.402,290.07 325.411,290.036 325.421,290.002 325.43,289.967 325.439,289.933 325.448,289.898 325.457,289.864 325.467,289.829 325.476,289.795 325.485,289.761 325.494,289.726 325.503,289.692 325.512,289.657 325.522,289.623 325.531,289.588 325.54,289.554 325.549,289.52 325.558,289.485 325.568,289.451 325.577,289.416 325.586,289.382 325.595,289.347 325.604,289.313 325.614,289.279 325.623,289.244 325.632,289.21 325.641,289.175 325.65,289.141 325.66,289.106 325.669,289.072 325.678,289.038 325.687,289.003 325.696,288.969 325.705,288.934 325.715,288.9 325.724,288.865 325.733,288.831 325.742,288.797 325.751,288.762 325.761,288.728 325.77,288.693 325.779,288.659 325.788,288.625 325.797,288.59 325.807,288.556 325.816,288.521 325.825,288.487 325.834,288.452 325.843,288.418 325.852,288.384 325.862,288.349 325.871,288.315 325.88,288.28 325.889,288.246 325.898,288.212 325.908,288.177 325.917,288.143 325.926,288.108 325.935,288.074 325.944,288.04 325.954,288.005 325.963,287.971 325.972,287.936 325.981,287.902 325.99,287.868 326,287.833 326.009,287.799 326.018,287.764 326.027,287.73 326.036,287.696 326.045,287.661 326.055,287.627 326.064,287.592 326.073,287.558 326.082,287.524 326.091,287.489 326.101,287.455 326.11,287.42 326.119,287.386 326.128,287.352 326.137,287.317 326.147,287.283 326.156,287.248 326.165,287.214 326.174,287.18 326.183,287.145 326.192,287.111 326.202,287.076 326.211,287.042 326.22,287.008 326.229,286.973 326.238,286.939 326.248,286.904 326.257,286.87 326.266,286.836 326.275,286.801 326.284,286.767 326.294,286.733 326.303,286.698 326.312,286.664 326.321,286.629 326.33,286.595 326.34,286.561 326.349,286.526 326.358,286.492 326.367,286.458 326.376,286.423 326.385,286.389 326.395,286.354 326.404,286.32 326.413,286.286 326.422,286.251 326.431,286.217 326.441,286.182 326.45,286.148 326.459,286.114 326.468,286.079 326.477,286.045 326.487,286.011 326.496,285.976 326.505,285.942 326.514,285.908 326.523,285.873 326.532,285.839 326.542,285.804 326.551,285.77 326.56,285.736 326.569,285.701 326.578,285.667 326.588,285.633 326.597,285.598 326.606,285.564 326.615,285.53 326.624,285.495 326.634,285.461 326.643,285.426 326.652,285.392 326.661,285.358 326.67,285.323 326.68,285.289 326.689,285.255 326.698,285.22 326.707,285.186 326.716,285.152 326.725,285.117 326.735,285.083 326.744,285.048 326.753,285.014 326.762,284.98 326.771,284.945 326.781,284.911 326.79,284.877 326.799,284.842 326.808,284.808 326.817,284.774 326.827,284.739 326.836,284.705 326.845,284.671 326.854,284.636 326.863,284.602 326.873,284.568 326.882,284.533 326.891,284.499 326.9,284.465 326.909,284.43 326.918,284.396 326.928,284.362 326.937,284.327 326.946,284.293 326.955,284.259 326.964,284.224 326.974,284.19 326.983,284.155 326.992,284.121 327.001,284.087 327.01,284.052 327.02,284.018 327.029,283.984 327.038,283.949 327.047,283.915 327.056,283.881 327.065,283.846 327.075,283.812 327.084,283.778 327.093,283.743 327.102,283.709 327.111,283.675 327.121,283.64 327.13,283.606 327.139,283.572 327.148,283.538 327.157,283.503 327.167,283.469 327.176,283.435 327.185,283.4 327.194,283.366 327.203,283.332 327.213,283.297 327.222,283.263 327.231,283.229 327.24,283.194 327.249,283.16 327.258,283.126 327.268,283.091 327.277,283.057 327.286,283.023 327.295,282.988 327.304,282.954 327.314,282.92 327.323,282.885 327.332,282.851 327.341,282.817 327.35,282.782 327.36,282.748 327.369,282.714 327.378,282.68 327.387,282.645 327.396,282.611 327.405,282.577 327.415,282.542 327.424,282.508 327.433,282.474 327.442,282.439 327.451,282.405 327.461,282.371 327.47,282.336 327.479,282.302 327.488,282.268 327.497,282.233 327.507,282.199 327.516,282.165 327.525,282.131 327.534,282.096 327.543,282.062 327.553,282.028 327.562,281.993 327.571,281.959 327.58,281.925 327.589,281.89 327.598,281.856 327.608,281.822 327.617,281.788 327.626,281.753 327.635,281.719 327.644,281.685 327.654,281.65 327.663,281.616 327.672,281.582 327.681,281.548 327.69,281.513 327.7,281.479 327.709,281.445 327.718,281.41 327.727,281.376 327.736,281.342 327.745,281.308 327.755,281.273 327.764,281.239 327.773,281.205 327.782,281.17 327.791,281.136 327.801,281.102 327.81,281.068 327.819,281.033 327.828,280.999 327.837,280.965 327.847,280.93 327.856,280.896 327.865,280.862 327.874,280.828 327.883,280.793 327.893,280.759 327.902,280.725 327.911,280.69 327.92,280.656 327.929,280.622 327.938,280.588 327.948,280.553 327.957,280.519 327.966,280.485 327.975,280.45 327.984,280.416 327.994,280.382 328.003,280.348 328.012,280.313 328.021,280.279 328.03,280.245 328.04,280.211 328.049,280.176 328.058,280.142 328.067,280.108 328.076,280.074 328.085,280.039 328.095,280.005 328.104,279.971 328.113,279.936 328.122,279.902 328.131,279.868 328.141,279.834 328.15,279.799 328.159,279.765 328.168,279.731 328.177,279.697 328.187,279.662 328.196,279.628 328.205,279.594 328.214,279.56 328.223,279.525 328.233,279.491 328.242,279.457 328.251,279.423 328.26,279.388 328.269,279.354 328.278,279.32 328.288,279.286 328.297,279.251 328.306,279.217 328.315,279.183 328.324,279.149 328.334,279.114 328.343,279.08 328.352,279.046 328.361,279.012 328.37,278.977 328.38,278.943 328.389,278.909 328.398,278.875 328.407,278.84 328.416,278.806 328.425,278.772 328.435,278.738 328.444,278.703 328.453,278.669 328.462,278.635 328.471,278.601 328.481,278.566 328.49,278.532 328.499,278.498 328.508,278.464 328.517,278.429 328.527,278.395 328.536,278.361 328.545,278.327 328.554,278.293 328.563,278.258 328.573,278.224 328.582,278.19 328.591,278.156 328.6,278.121 328.609,278.087 328.618,278.053 328.628,278.019 328.637,277.984 328.646,277.95 328.655,277.916 328.664,277.882 328.674,277.848 328.683,277.813 328.692,277.779 328.701,277.745 328.71,277.711 328.72,277.676 328.729,277.642 328.738,277.608 328.747,277.574 328.756,277.54 328.765,277.505 328.775,277.471 328.784,277.437 328.793,277.403 328.802,277.368 328.811,277.334 328.821,277.3 328.83,277.266 328.839,277.232 328.848,277.197 328.857,277.163 328.867,277.129 328.876,277.095 328.885,277.061 328.894,277.026 328.903,276.992 328.913,276.958 328.922,276.924 328.931,276.889 328.94,276.855 328.949,276.821 328.958,276.787 328.968,276.753 328.977,276.718 328.986,276.684 328.995,276.65 329.004,276.616 329.014,276.582 329.023,276.547 329.032,276.513 329.041,276.479 329.05,276.445 329.06,276.411 329.069,276.376 329.078,276.342 329.087,276.308 329.096,276.274 329.106,276.24 329.115,276.205 329.124,276.171 329.133,276.137 329.142,276.103 329.151,276.069 329.161,276.034 329.17,276 329.179,275.966 329.188,275.932 329.197,275.898 329.207,275.864 329.216,275.829 329.225,275.795 329.234,275.761 329.243,275.727 329.253,275.693 329.262,275.658 329.271,275.624 329.28,275.59 329.289,275.556 329.298,275.522 329.308,275.487 329.317,275.453 329.326,275.419 329.335,275.385 329.344,275.351 329.354,275.317 329.363,275.282 329.372,275.248 329.381,275.214 329.39,275.18 329.4,275.146 329.409,275.112 329.418,275.077 329.427,275.043 329.436,275.009 329.446,274.975 329.455,274.941 329.464,274.906 329.473,274.872 329.482,274.838 329.491,274.804 329.501,274.77 329.51,274.736 329.519,274.701 329.528,274.667 329.537,274.633 329.547,274.599 329.556,274.565 329.565,274.531 329.574,274.496 329.583,274.462 329.593,274.428 329.602,274.394 329.611,274.36 329.62,274.326 329.629,274.291 329.638,274.257 329.648,274.223 329.657,274.189 329.666,274.155 329.675,274.121 329.684,274.087 329.694,274.052 329.703,274.018 329.712,273.984 329.721,273.95 329.73,273.916 329.74,273.882 329.749,273.847 329.758,273.813 329.767,273.779 329.776,273.745 329.786,273.711 329.795,273.677 329.804,273.643 329.813,273.608 329.822,273.574 329.831,273.54 329.841,273.506 329.85,273.472 329.859,273.438 329.868,273.404 329.877,273.369 329.887,273.335 329.896,273.301 329.905,273.267 329.914,273.233 329.923,273.199 329.933,273.165 329.942,273.13 329.951,273.096 329.96,273.062 329.969,273.028 329.978,272.994 329.988,272.96 329.997,272.926 330.006,272.891 330.015,272.857 330.024,272.823 330.034,272.789 330.043,272.755 330.052,272.721 330.061,272.687 330.07,272.653 330.08,272.618 330.089,272.584 330.098,272.55 330.107,272.516 330.116,272.482 330.126,272.448 330.135,272.414 330.144,272.38 330.153,272.345 330.162,272.311 330.171,272.277 330.181,272.243 330.19,272.209 330.199,272.175 330.208,272.141 330.217,272.107 330.227,272.072 330.236,272.038 330.245,272.004 330.254,271.97 330.263,271.936 330.273,271.902 330.282,271.868 330.291,271.834 330.3,271.799 330.309,271.765 330.318,271.731 330.328,271.697 330.337,271.663 330.346,271.629 330.355,271.595 330.364,271.561 330.374,271.527 330.383,271.492 330.392,271.458 330.401,271.424 330.41,271.39 330.42,271.356 330.429,271.322 330.438,271.288 330.447,271.254 330.456,271.22 330.466,271.186 330.475,271.151 330.484,271.117 330.493,271.083 330.502,271.049 330.511,271.015 330.521,270.981 330.53,270.947 330.539,270.913 330.548,270.879 330.557,270.845 330.567,270.81 330.576,270.776 330.585,270.742 330.594,270.708 330.603,270.674 330.613,270.64 330.622,270.606 330.631,270.572 330.64,270.538 330.649,270.504 330.658,270.47 330.668,270.435 330.677,270.401 330.686,270.367 330.695,270.333 330.704,270.299 330.714,270.265 330.723,270.231 330.732,270.197 330.741,270.163 330.75,270.129 330.76,270.095 330.769,270.061 330.778,270.026 330.787,269.992 330.796,269.958 330.806,269.924 330.815,269.89 330.824,269.856 330.833,269.822 330.842,269.788 330.851,269.754 330.861,269.72 330.87,269.686 330.879,269.652 330.888,269.618 330.897,269.583 330.907,269.549 330.916,269.515 330.925,269.481 330.934,269.447 330.943,269.413 330.953,269.379 330.962,269.345 330.971,269.311 330.98,269.277 330.989,269.243 330.998,269.209 331.008,269.175 331.017,269.141 331.026,269.107 331.035,269.073 331.044,269.039 331.054,269.005 331.063,268.971 331.072,268.937 331.081,268.903 331.09,268.869 331.1,268.835 331.109,268.801 331.118,268.767 331.127,268.733 331.136,268.699 331.146,268.665 331.155,268.631 331.164,268.597 331.173,268.563 331.182,268.529 331.191,268.495 331.201,268.461 331.21,268.427 331.219,268.393 331.228,268.359 331.237,268.326 331.247,268.292 331.256,268.258 331.265,268.224 331.274,268.19 331.283,268.156 331.293,268.122 331.302,268.088 331.311,268.055 331.32,268.021 331.329,267.987 331.338,267.953 331.348,267.919 331.357,267.885 331.366,267.852 331.375,267.818 331.384,267.784 331.394,267.75 331.403,267.716 331.412,267.682 331.421,267.649 331.43,267.615 331.44,267.581 331.449,267.547 331.458,267.514 331.467,267.48 331.476,267.446 331.486,267.412 331.495,267.379 331.504,267.345 331.513,267.311 331.522,267.277 331.531,267.244 331.541,267.21 331.55,267.176 331.559,267.142 331.568,267.109 331.577,267.075 331.587,267.041 331.596,267.008 331.605,266.974 331.614,266.94 331.623,266.907 331.633,266.873 331.642,266.839 331.651,266.806 331.66,266.772 331.669,266.738 331.679,266.705 331.688,266.671 331.697,266.637 331.706,266.604 331.715,266.57 331.724,266.537 331.734,266.503 331.743,266.469 331.752,266.436 331.761,266.402 331.77,266.369 331.78,266.335 331.789,266.301 331.798,266.268 331.807,266.234 331.816,266.201 331.826,266.167 331.835,266.134 331.844,266.1 331.853,266.067 331.862,266.033 331.871,265.999 331.881,265.966 331.89,265.932 331.899,265.899 331.908,265.865 331.917,265.832 331.927,265.798 331.936,265.765 331.945,265.731 331.954,265.698 331.963,265.665 331.973,265.631 331.982,265.598 331.991,265.564 332,265.531 332.009,265.497 332.019,265.464 332.028,265.43 332.037,265.397 332.046,265.363 332.055,265.33 332.064,265.297 332.074,265.263 332.083,265.23 332.092,265.196 332.101,265.163 332.11,265.13 332.12,265.096 332.129,265.063 332.138,265.03 332.147,264.996 332.156,264.963 332.166,264.929 332.175,264.896 332.184,264.863 332.193,264.829 332.202,264.796 332.211,264.763 332.221,264.729 332.23,264.696 332.239,264.663 332.248,264.63 332.257,264.596 332.267,264.563 332.276,264.53 332.285,264.496 332.294,264.463 332.303,264.43 332.313,264.397 332.322,264.363 332.331,264.33 332.34,264.297 332.349,264.264 332.359,264.23 332.368,264.197 332.377,264.164 332.386,264.131 332.395,264.097 332.404,264.064 332.414,264.031 332.423,263.998 332.432,263.965 332.441,263.931 332.45,263.898 332.46,263.865 332.469,263.832 332.478,263.799 332.487,263.765 332.496,263.732 332.506,263.699 332.515,263.666 332.524,263.633 332.533,263.6 332.542,263.567 332.551,263.533 332.561,263.5 332.57,263.467 332.579,263.434 332.588,263.401 332.597,263.368 332.607,263.335 332.616,263.302 332.625,263.269 332.634,263.236 332.643,263.202 332.653,263.169 332.662,263.136 332.671,263.103 332.68,263.07 332.689,263.037 332.699,263.004 332.708,262.971 332.717,262.938 332.726,262.905 332.735,262.872 332.744,262.839 332.754,262.806 332.763,262.773 332.772,262.74 332.781,262.707 332.79,262.674 332.8,262.641 332.809,262.608 332.818,262.575 332.827,262.542 332.836,262.509 332.846,262.476 332.855,262.443 332.864,262.41 332.873,262.377 332.882,262.344 332.891,262.311 332.901,262.279 332.91,262.246 332.919,262.213 332.928,262.18 332.937,262.147 332.947,262.114 332.956,262.081 332.965,262.048 332.974,262.015 332.983,261.982 332.993,261.95 333.002,261.917 333.011,261.884 333.02,261.851 333.029,261.818 333.039,261.785 333.048,261.752 333.057,261.72 333.066,261.687 333.075,261.654 333.084,261.621 333.094,261.588 333.103,261.556 333.112,261.523 333.121,261.49 333.13,261.457 333.14,261.424 333.149,261.392 333.158,261.359 333.167,261.326 333.176,261.293 333.186,261.261 333.195,261.228 333.204,261.195 333.213,261.162 333.222,261.13 333.231,261.097 333.241,261.064 333.25,261.031 333.259,260.999 333.268,260.966 333.277,260.933 333.287,260.901 333.296,260.868 333.305,260.835 333.314,260.802 333.323,260.77 333.333,260.737 333.342,260.704 333.351,260.672 333.36,260.639 333.369,260.606 333.379,260.574 333.388,260.541 333.397,260.509 333.406,260.476 333.415,260.443 333.424,260.411 333.434,260.378 333.443,260.345 333.452,260.313 333.461,260.28 333.47,260.248 333.48,260.215 333.489,260.182 333.498,260.15 333.507,260.117 333.516,260.085 333.526,260.052 333.535,260.02 333.544,259.987 333.553,259.955 333.562,259.922 333.571,259.889 333.581,259.857 333.59,259.824 333.599,259.792 333.608,259.759 333.617,259.727 333.627,259.694 333.636,259.662 333.645,259.629 333.654,259.597 333.663,259.564 333.673,259.532 333.682,259.499 333.691,259.467 333.7,259.435 333.709,259.402 333.719,259.37 333.728,259.337 333.737,259.305 333.746,259.272 333.755,259.24 333.764,259.208 333.774,259.175 333.783,259.143 333.792,259.11 333.801,259.078 333.81,259.045 333.82,259.013 333.829,258.981 333.838,258.948 333.847,258.916 333.856,258.884 333.866,258.851 333.875,258.819 333.884,258.786 333.893,258.754 333.902,258.722 333.911,258.689 333.921,258.657 333.93,258.625 333.939,258.592 333.948,258.56 333.957,258.528 333.967,258.496 333.976,258.463 333.985,258.431 333.994,258.399 334.003,258.366 334.013,258.334 334.022,258.302 334.031,258.27 334.04,258.237 334.049,258.205 334.059,258.173 334.068,258.141 334.077,258.108 334.086,258.076 334.095,258.044 334.104,258.012 334.114,257.979 334.123,257.947 334.132,257.915 334.141,257.883 334.15,257.851 334.16,257.818 334.169,257.786 334.178,257.754 334.187,257.722 334.196,257.69 334.206,257.657 334.215,257.625 334.224,257.593 334.233,257.561 334.242,257.529 334.252,257.497 334.261,257.465 334.27,257.432 334.279,257.4 334.288,257.368 334.297,257.336 334.307,257.304 334.316,257.272 334.325,257.24 334.334,257.208 334.343,257.176 334.353,257.144 334.362,257.111 334.371,257.079 334.38,257.047 334.389,257.015 334.399,256.983 334.408,256.951 334.417,256.919 334.426,256.887 334.435,256.855 334.444,256.823 334.454,256.791 334.463,256.759 334.472,256.727 334.481,256.695 334.49,256.663 334.5,256.631 334.509,256.599 334.518,256.567 334.527,256.535 334.536,256.503 334.546,256.471 334.555,256.439 334.564,256.407 334.573,256.375 334.582,256.343 334.592,256.311 334.601,256.279 334.61,256.247 334.619,256.215 334.628,256.184 334.637,256.152 334.647,256.12 334.656,256.088 334.665,256.056 334.674,256.024 334.683,255.992 334.693,255.96 334.702,255.928 334.711,255.896 334.72,255.865 334.729,255.833 334.739,255.801 334.748,255.769 334.757,255.737 334.766,255.705 334.775,255.673 334.784,255.642 334.794,255.61 334.803,255.578 334.812,255.546 334.821,255.514 334.83,255.483 334.84,255.451 334.849,255.419 334.858,255.387 334.867,255.355 334.876,255.324 334.886,255.292 334.895,255.26 334.904,255.228 334.913,255.196 334.922,255.165 334.932,255.133 334.941,255.101 334.95,255.069 334.959,255.038 334.968,255.006 334.977,254.974 334.987,254.943 334.996,254.911 335.005,254.879 335.014,254.847 335.023,254.816 335.033,254.784 335.042,254.752 335.051,254.721 335.06,254.689 335.069,254.657 335.079,254.626 335.088,254.594 335.097,254.562 335.106,254.531 335.115,254.499 335.124,254.467 335.134,254.436 335.143,254.404 335.152,254.373 335.161,254.341 335.17,254.309 335.18,254.278 335.189,254.246 335.198,254.215 335.207,254.183 335.216,254.151 335.226,254.12 335.235,254.088 335.244,254.057 335.253,254.025 335.262,253.993 335.272,253.962 335.281,253.93 335.29,253.899 335.299,253.867 335.308,253.836 335.317,253.804 335.327,253.773 335.336,253.741 335.345,253.71 335.354,253.678 335.363,253.647 335.373,253.615 335.382,253.584 335.391,253.552 335.4,253.521 335.409,253.489 335.419,253.458 335.428,253.426 335.437,253.395 335.446,253.363 335.455,253.332 335.464,253.3 335.474,253.269 335.483,253.238 335.492,253.206 335.501,253.175 335.51,253.143 335.52,253.112 335.529,253.081 335.538,253.049 335.547,253.018 335.556,252.986 335.566,252.955 335.575,252.924 335.584,252.892 335.593,252.861 335.602,252.829 335.612,252.798 335.621,252.767 335.63,252.735 335.639,252.704 335.648,252.673 335.657,252.641 335.667,252.61 335.676,252.579 335.685,252.547 335.694,252.516 335.703,252.485 335.713,252.453 335.722,252.422 335.731,252.391 335.74,252.36 335.749,252.328 335.759,252.297 335.768,252.266 335.777,252.234 335.786,252.203 335.795,252.172 335.804,252.141 335.814,252.109 335.823,252.078 335.832,252.047 335.841,252.016 335.85,251.985 335.86,251.953 335.869,251.922 335.878,251.891 335.887,251.86 335.896,251.828 335.906,251.797 335.915,251.766 335.924,251.735 335.933,251.704 335.942,251.673 335.952,251.641 335.961,251.61 335.97,251.579 335.979,251.548 335.988,251.517 335.997,251.486 336.007,251.454 336.016,251.423 336.025,251.392 336.034,251.361 336.043,251.33 336.053,251.299 336.062,251.268 336.071,251.237 336.08,251.206 336.089,251.174 336.099,251.143 336.108,251.112 336.117,251.081 336.126,251.05 336.135,251.019 336.144,250.988 336.154,250.957 336.163,250.926 336.172,250.895 336.181,250.864 336.19,250.833 336.2,250.802 336.209,250.771 336.218,250.74 336.227,250.709 336.236,250.678 336.246,250.647 336.255,250.616 336.264,250.585 336.273,250.554 336.282,250.523 336.292,250.492 336.301,250.461 336.31,250.43 336.319,250.399 336.328,250.368 336.337,250.337 336.347,250.306 336.356,250.275 336.365,250.244 336.374,250.213 336.383,250.182 336.393,250.151 336.402,250.121 336.411,250.09 336.42,250.059 336.429,250.028 336.439,249.997 336.448,249.966 336.457,249.935 336.466,249.904 336.475,249.873 336.485,249.843 336.494,249.812 336.503,249.781 336.512,249.75 336.521,249.719 336.53,249.688 336.54,249.657 336.549,249.627 336.558,249.596 336.567,249.565 336.576,249.534 336.586,249.503 336.595,249.473 336.604,249.442 336.613,249.411 336.622,249.38 336.632,249.349 336.641,249.319 336.65,249.288 336.659,249.257 336.668,249.226 336.677,249.196 336.687,249.165 336.696,249.134 336.705,249.103 336.714,249.073 336.723,249.042 336.733,249.011 336.742,248.98 336.751,248.95 336.76,248.919 336.769,248.888 336.779,248.858 336.788,248.827 336.797,248.796 336.806,248.765 336.815,248.735 336.825,248.704 336.834,248.673 336.843,248.643 336.852,248.612 336.861,248.581 336.87,248.551 336.88,248.52 336.889,248.49 336.898,248.459 336.907,248.428 336.916,248.398 336.926,248.367 336.935,248.336 336.944,248.306 336.953,248.275 336.962,248.245 336.972,248.214 336.981,248.183 336.99,248.153 336.999,248.122 337.008,248.092 337.017,248.061 337.027,248.031 337.036,248 337.045,247.969 337.054,247.939 337.063,247.908 337.073,247.878 337.082,247.847 337.091,247.817 337.1,247.786 337.109,247.756 337.119,247.725 337.128,247.695 337.137,247.664 337.146,247.634 337.155,247.603 337.165,247.573 337.174,247.542 337.183,247.512 337.192,247.481 337.201,247.451 337.21,247.42 337.22,247.39 337.229,247.36 337.238,247.329 337.247,247.299 337.256,247.268 337.266,247.238 337.275,247.207 337.284,247.177 337.293,247.147 337.302,247.116 337.312,247.086 337.321,247.055 337.33,247.025 337.339,246.995 337.348,246.964 337.357,246.934 337.367,246.903 337.376,246.873 337.385,246.843 337.394,246.812 337.403,246.782 337.413,246.752 337.422,246.721 337.431,246.691 337.44,246.661 337.449,246.63 337.459,246.6 337.468,246.57 337.477,246.539 337.486,246.509 337.495,246.479 337.505,246.448 337.514,246.418 337.523,246.388 337.532,246.358 337.541,246.327 337.55,246.297 337.56,246.267 337.569,246.237 337.578,246.206 337.587,246.176 337.596,246.146 337.606,246.116 337.615,246.085 337.624,246.055 337.633,246.025 337.642,245.995 337.652,245.964 337.661,245.934 337.67,245.904 337.679,245.874 337.688,245.844 337.697,245.813 337.707,245.783 337.716,245.753 337.725,245.723 337.734,245.693 337.743,245.663 337.753,245.632 337.762,245.602 337.771,245.572 337.78,245.542 337.789,245.512 337.799,245.482 337.808,245.452 337.817,245.422 337.826,245.391 337.835,245.361 337.845,245.331 337.854,245.301 337.863,245.271 337.872,245.241 337.881,245.211 337.89,245.181 337.9,245.151 337.909,245.121 337.918,245.091 337.927,245.061 337.936,245.03 337.946,245 337.955,244.97 337.964,244.94 337.973,244.91 337.982,244.88 337.992,244.85 338.001,244.82 338.01,244.79 338.019,244.76 338.028,244.73 338.037,244.7 338.047,244.67 338.056,244.64 338.065,244.61 338.074,244.58 338.083,244.55 338.093,244.52 338.102,244.49 338.111,244.46 338.12,244.43 338.129,244.401 338.139,244.371 338.148,244.341 338.157,244.311 338.166,244.281 338.175,244.251 338.185,244.221 338.194,244.191 338.203,244.161 338.212,244.131 338.221,244.101 338.23,244.071 338.24,244.042 338.249,244.012 338.258,243.982 338.267,243.952 338.276,243.922 338.286,243.892 338.295,243.862 338.304,243.833 338.313,243.803 338.322,243.773 338.332,243.743 338.341,243.713 338.35,243.683 338.359,243.654 338.368,243.624 338.377,243.594 338.387,243.564 338.396,243.534 338.405,243.505 338.414,243.475 338.423,243.445 338.433,243.415 338.442,243.385 338.451,243.356 338.46,243.326 338.469,243.296 338.479,243.266 338.488,243.237 338.497,243.207 338.506,243.177 338.515,243.147 338.525,243.118 338.534,243.088 338.543,243.058 338.552,243.028 338.561,242.999 338.57,242.969 338.58,242.939 338.589,242.91 338.598,242.88 338.607,242.85 338.616,242.821 338.626,242.791 338.635,242.761 338.644,242.732 338.653,242.702 338.662,242.672 338.672,242.643 338.681,242.613 338.69,242.583 338.699,242.554 338.708,242.524 338.717,242.495 338.727,242.465 338.736,242.435 338.745,242.406 338.754,242.376 338.763,242.347 338.773,242.317 338.782,242.287 338.791,242.258 338.8,242.228 338.809,242.199 338.819,242.169 338.828,242.139 338.837,242.11 338.846,242.08 338.855,242.051 338.865,242.021 338.874,241.992 338.883,241.962 338.892,241.933 338.901,241.903 338.91,241.874 338.92,241.844 338.929,241.815 338.938,241.785 338.947,241.756 338.956,241.726 338.966,241.697 338.975,241.667 338.984,241.638 338.993,241.608 339.002,241.579 339.012,241.549 339.021,241.52 339.03,241.49 339.039,241.461 339.048,241.432 339.058,241.402 339.067,241.373 339.076,241.343 339.085,241.314 339.094,241.284 339.103,241.255 339.113,241.226 339.122,241.196 339.131,241.167 339.14,241.137 339.149,241.108 339.159,241.079 339.168,241.049 339.177,241.02 339.186,240.991 339.195,240.961 339.205,240.932 339.214,240.903 339.223,240.873 339.232,240.844 339.241,240.814 339.25,240.785 339.26,240.756 339.269,240.727 339.278,240.697 339.287,240.668 339.296,240.639 339.306,240.609 339.315,240.58 339.324,240.551 339.333,240.521 339.342,240.492 339.352,240.463 339.361,240.434 339.37,240.404 339.379,240.375 339.388,240.346 339.398,240.317 339.407,240.287 339.416,240.258 339.425,240.229 339.434,240.2 339.443,240.17 339.453,240.141 339.462,240.112 339.471,240.083 339.48,240.054 339.489,240.024 339.499,239.995 339.508,239.966 339.517,239.937 339.526,239.908 339.535,239.878 339.545,239.849 339.554,239.82 339.563,239.791 339.572,239.762 339.581,239.733 339.59,239.704 339.6,239.674 339.609,239.645 339.618,239.616 339.627,239.587 339.636,239.558 339.646,239.529 339.655,239.5 339.664,239.471 339.673,239.441 339.682,239.412 339.692,239.383 339.701,239.354 339.71,239.325 339.719,239.296 339.728,239.267 339.738,239.238 339.747,239.209 339.756,239.18 339.765,239.151 339.774,239.122 339.783,239.093 339.793,239.064 339.802,239.035 339.811,239.006 339.82,238.977 339.829,238.948 339.839,238.919 339.848,238.89 339.857,238.861 339.866,238.832 339.875,238.803 339.885,238.774 339.894,238.745 339.903,238.716 339.912,238.687 339.921,238.658 339.93,238.629 339.94,238.6 339.949,238.571 339.958,238.542 339.967,238.513 339.976,238.484 339.986,238.455 339.995,238.426 340.004,238.397 340.013,238.368 340.022,238.339 340.032,238.311 340.041,238.282 340.05,238.253 340.059,238.224 340.068,238.195 340.078,238.166 340.087,238.137 340.096,238.108 340.105,238.08 340.114,238.051 340.123,238.022 340.133,237.993 340.142,237.964 340.151,237.935 340.16,237.906 340.169,237.878 340.179,237.849 340.188,237.82 340.197,237.791 340.206,237.762 340.215,237.734 340.225,237.705 340.234,237.676 340.243,237.647 340.252,237.618 340.261,237.59 340.27,237.561 340.28,237.532 340.289,237.503 340.298,237.475 340.307,237.446 340.316,237.417 340.326,237.388 340.335,237.36 340.344,237.331 340.353,237.302 340.362,237.273 340.372,237.245 340.381,237.216 340.39,237.187 340.399,237.159 340.408,237.13 340.418,237.101 340.427,237.072 340.436,237.044 340.445,237.015 340.454,236.986 340.463,236.958 340.473,236.929 340.482,236.9 340.491,236.872 340.5,236.843 340.509,236.814 340.519,236.786 340.528,236.757 340.537,236.729 340.546,236.7 340.555,236.671 340.565,236.643 340.574,236.614 340.583,236.586 340.592,236.557 340.601,236.528 340.61,236.5 340.62,236.471 340.629,236.443 340.638,236.414 340.647,236.385 340.656,236.357 340.666,236.328 340.675,236.3 340.684,236.271 340.693,236.243 340.702,236.214 340.712,236.186 340.721,236.157 340.73,236.129 340.739,236.1 340.748,236.071 340.758,236.043 340.767,236.014 340.776,235.986 340.785,235.957 340.794,235.929 340.803,235.9 340.813,235.872 340.822,235.844 340.831,235.815 340.84,235.787 340.849,235.758 340.859,235.73 340.868,235.701 340.877,235.673 340.886,235.644 340.895,235.616 340.905,235.587 340.914,235.559 340.923,235.531 340.932,235.502 340.941,235.474 340.95,235.445 340.96,235.417 340.969,235.389 340.978,235.36 340.987,235.332 340.996,235.303 341.006,235.275 341.015,235.247 341.024,235.218 341.033,235.19 341.042,235.162 341.052,235.133 341.061,235.105 341.07,235.077 341.079,235.048 341.088,235.02 341.098,234.992 341.107,234.963 341.116,234.935 341.125,234.907 341.134,234.878 341.143,234.85 341.153,234.822 341.162,234.793 341.171,234.765 341.18,234.737 341.189,234.709 341.199,234.68 341.208,234.652 341.217,234.624 341.226,234.595 341.235,234.567 341.245,234.539 341.254,234.511 341.263,234.482 341.272,234.454 341.281,234.426 341.29,234.398 341.3,234.37 341.309,234.341 341.318,234.313 341.327,234.285 341.336,234.257 341.346,234.228 341.355,234.2 341.364,234.172 341.373,234.144 341.382,234.116 341.392,234.088 341.401,234.059 341.41,234.031 341.419,234.003 341.428,233.975 341.438,233.947 341.447,233.919 341.456,233.891 341.465,233.862 341.474,233.834 341.483,233.806 341.493,233.778 341.502,233.75 341.511,233.722 341.52,233.694 341.529,233.666 341.539,233.638 341.548,233.609 341.557,233.581 341.566,233.553 341.575,233.525 341.585,233.497 341.594,233.469 341.603,233.441 341.612,233.413 341.621,233.385 341.631,233.357 341.64,233.329 341.649,233.301 341.658,233.273 341.667,233.245 341.676,233.217 341.686,233.189 341.695,233.161 341.704,233.133 341.713,233.105 341.722,233.077 341.732,233.049 341.741,233.021 341.75,232.993 341.759,232.965 341.768,232.937 341.778,232.909 341.787,232.881 341.796,232.853 341.805,232.825 341.814,232.797 341.823,232.769 341.833,232.741 341.842,232.713 341.851,232.685 341.86,232.657 341.869,232.629 341.879,232.601 341.888,232.574 341.897,232.546 341.906,232.518 341.915,232.49 341.925,232.462 341.934,232.434 341.943,232.406 341.952,232.378 341.961,232.35 341.971,232.323 341.98,232.295 341.989,232.267 341.998,232.239 342.007,232.211 342.016,232.183 342.026,232.156 342.035,232.128 342.044,232.1 342.053,232.072 342.062,232.044 342.072,232.016 342.081,231.989 342.09,231.961 342.099,231.933 342.108,231.905 342.118,231.877 342.127,231.85 342.136,231.822 342.145,231.794 342.154,231.766 342.163,231.739 342.173,231.711 342.182,231.683 342.191,231.655 342.2,231.628 342.209,231.6 342.219,231.572 342.228,231.544 342.237,231.517 342.246,231.489 342.255,231.461 342.265,231.434 342.274,231.406 342.283,231.378 342.292,231.35 342.301,231.323 342.311,231.295 342.32,231.267 342.329,231.24 342.338,231.212 342.347,231.184 342.356,231.157 342.366,231.129 342.375,231.101 342.384,231.074 342.393,231.046 342.402,231.018 342.412,230.991 342.421,230.963 342.43,230.936 342.439,230.908 342.448,230.88 342.458,230.853 342.467,230.825 342.476,230.798 342.485,230.77 342.494,230.742 342.503,230.715 342.513,230.687 342.522,230.66 342.531,230.632 342.54,230.605 342.549,230.577 342.559,230.549 342.568,230.522 342.577,230.494 342.586,230.467 342.595,230.439 342.605,230.412 342.614,230.384 342.623,230.357 342.632,230.329 342.641,230.302 342.651,230.274 342.66,230.247 342.669,230.219 342.678,230.192 342.687,230.164 342.696,230.137 342.706,230.109 342.715,230.082 342.724,230.054 342.733,230.027 342.742,229.999 342.752,229.972 342.761,229.944 342.77,229.917 342.779,229.89 342.788,229.862 342.798,229.835 342.807,229.807 342.816,229.78 342.825,229.752 342.834,229.725 342.843,229.698 342.853,229.67 342.862,229.643 342.871,229.615 342.88,229.588 342.889,229.561 342.899,229.533 342.908,229.506 342.917,229.479 342.926,229.451 342.935,229.424 342.945,229.396 342.954,229.369 342.963,229.342 342.972,229.314 342.981,229.287 342.991,229.26 343,229.232 343.009,229.205 343.018,229.178 343.027,229.151 343.036,229.123 343.046,229.096 343.055,229.069 343.064,229.041 343.073,229.014 343.082,228.987 343.092,228.959 343.101,228.932 343.11,228.905 343.119,228.878 343.128,228.85 343.138,228.823 343.147,228.796 343.156,228.769 343.165,228.741 343.174,228.714 343.183,228.687 343.193,228.66 343.202,228.633 343.211,228.605 343.22,228.578 343.229,228.551 343.239,228.524 343.248,228.497 343.257,228.469 343.266,228.442 343.275,228.415 343.285,228.388 343.294,228.361 343.303,228.333 343.312,228.306 343.321,228.279 343.331,228.252 343.34,228.225 343.349,228.198 343.358,228.171 343.367,228.143 343.376,228.116 343.386,228.089 343.395,228.062 343.404,228.035 343.413,228.008 343.422,227.981 343.432,227.954 343.441,227.927 343.45,227.899 343.459,227.872 343.468,227.845 343.478,227.818 343.487,227.791 343.496,227.764 343.505,227.737 343.514,227.71 343.523,227.683 343.533,227.656 343.542,227.629 343.551,227.602 343.56,227.575 343.569,227.548 343.579,227.521 343.588,227.494 343.597,227.467 343.606,227.44 343.615,227.413 343.625,227.386 343.634,227.359 343.643,227.332 343.652,227.305 343.661,227.278 343.671,227.251 343.68,227.224 343.689,227.197 343.698,227.17 343.707,227.143 343.716,227.116 343.726,227.089 343.735,227.062 343.744,227.035 343.753,227.008 343.762,226.981 343.772,226.954 343.781,226.927 343.79,226.9 343.799,226.874 343.808,226.847 343.818,226.82 343.827,226.793 343.836,226.766 343.845,226.739 343.854,226.712 343.864,226.685 343.873,226.658 343.882,226.632 343.891,226.605 343.9,226.578 343.909,226.551 343.919,226.524 343.928,226.497 343.937,226.471 343.946,226.444 343.955,226.417 343.965,226.39 343.974,226.363 343.983,226.336 343.992,226.31 344.001,226.283 344.011,226.256 344.02,226.229 344.029,226.202 344.038,226.176 344.047,226.149 344.056,226.122 344.066,226.095 344.075,226.069 344.084,226.042 344.093,226.015 344.102,225.988 344.112,225.961 344.121,225.935 344.13,225.908 344.139,225.881 344.148,225.855 344.158,225.828 344.167,225.801 344.176,225.774 344.185,225.748 344.194,225.721 344.204,225.694 344.213,225.668 344.222,225.641 344.231,225.614 344.24,225.588 344.249,225.561 344.259,225.534 344.268,225.507 344.277,225.481 344.286,225.454 344.295,225.428 344.305,225.401 344.314,225.374 344.323,225.348 344.332,225.321 344.341,225.294 344.351,225.268 344.36,225.241 344.369,225.214 344.378,225.188 344.387,225.161 344.396,225.135 344.406,225.108 344.415,225.081 344.424,225.055 344.433,225.028 344.442,225.002 344.452,224.975 344.461,224.949 344.47,224.922 344.479,224.895 344.488,224.869 344.498,224.842 344.507,224.816 344.516,224.789 344.525,224.763 344.534,224.736 344.544,224.71 344.553,224.683 344.562,224.657 344.571,224.63 344.58,224.604 344.589,224.577 344.599,224.551 344.608,224.524 344.617,224.498 344.626,224.471 344.635,224.445 344.645,224.418 344.654,224.392 344.663,224.365 344.672,224.339 344.681,224.312 344.691,224.286 344.7,224.259 344.709,224.233 344.718,224.207 344.727,224.18 344.736,224.154 344.746,224.127 344.755,224.101 344.764,224.074 344.773,224.048 344.782,224.022 344.792,223.995 344.801,223.969 344.81,223.942 344.819,223.916 344.828,223.89 344.838,223.863 344.847,223.837 344.856,223.811 344.865,223.784 344.874,223.758 344.884,223.731 344.893,223.705 344.902,223.679 344.911,223.652 344.92,223.626 344.929,223.6 344.939,223.573 344.948,223.547 344.957,223.521 344.966,223.494 344.975,223.468 344.985,223.442 344.994,223.416 345.003,223.389 345.012,223.363 345.021,223.337 345.031,223.31 345.04,223.284 345.049,223.258 345.058,223.232 345.067,223.205 345.076,223.179 345.086,223.153 345.095,223.127 345.104,223.1 345.113,223.074 345.122,223.048 345.132,223.022 345.141,222.995 345.15,222.969 345.159,222.943 345.168,222.917 345.178,222.891 345.187,222.864 345.196,222.838 345.205,222.812 345.214,222.786 345.224,222.76 345.233,222.733 345.242,222.707 345.251,222.681 345.26,222.655 345.269,222.629 345.279,222.603 345.288,222.576 345.297,222.55 345.306,222.524 345.315,222.498 345.325,222.472 345.334,222.446 345.343,222.42 345.352,222.394 345.361,222.367 345.371,222.341 345.38,222.315 345.389,222.289 345.398,222.263 345.407,222.237 345.416,222.211 345.426,222.185 345.435,222.159 345.444,222.133 345.453,222.107 345.462,222.081 345.472,222.054 345.481,222.028 345.49,222.002 345.499,221.976 345.508,221.95 345.518,221.924 345.527,221.898 345.536,221.872 345.545,221.846 345.554,221.82 345.564,221.794 345.573,221.768 345.582,221.742 345.591,221.716 345.6,221.69 345.609,221.664 345.619,221.638 345.628,221.612 345.637,221.586 345.646,221.56 345.655,221.534 345.665,221.508 345.674,221.482 345.683,221.456 345.692,221.43 345.701,221.405 345.711,221.379 345.72,221.353 345.729,221.327 345.738,221.301 345.747,221.275 345.756,221.249 345.766,221.223 345.775,221.197 345.784,221.171 345.793,221.145 345.802,221.12 345.812,221.094 345.821,221.068 345.83,221.042 345.839,221.016 345.848,220.99 345.858,220.964 345.867,220.938 345.876,220.913 345.885,220.887 345.894,220.861 345.904,220.835 345.913,220.809 345.922,220.783 345.931,220.758 345.94,220.732 345.949,220.706 345.959,220.68 345.968,220.654 345.977,220.628 345.986,220.603 345.995,220.577 346.005,220.551 346.014,220.525 346.023,220.5 346.032,220.474 346.041,220.448 346.051,220.422 346.06,220.396 346.069,220.371 346.078,220.345 346.087,220.319 346.096,220.293 346.106,220.268 346.115,220.242 346.124,220.216 346.133,220.191 346.142,220.165 346.152,220.139 346.161,220.113 346.17,220.088 346.179,220.062 346.188,220.036 346.198,220.011 346.207,219.985 346.216,219.959 346.225,219.934 346.234,219.908 346.244,219.882 346.253,219.857 346.262,219.831 346.271,219.805 346.28,219.78 346.289,219.754 346.299,219.728 346.308,219.703 346.317,219.677 346.326,219.651 346.335,219.626 346.345,219.6 346.354,219.574 346.363,219.549 346.372,219.523 346.381,219.498 346.391,219.472 346.4,219.446 346.409,219.421 346.418,219.395 346.427,219.37 346.437,219.344 346.446,219.319 346.455,219.293 346.464,219.267 346.473,219.242 346.482,219.216 346.492,219.191 346.501,219.165 346.51,219.14 346.519,219.114 346.528,219.089 346.538,219.063 346.547,219.038 346.556,219.012 346.565,218.987 346.574,218.961 346.584,218.936 346.593,218.91 346.602,218.885 346.611,218.859 346.62,218.834 346.629,218.808 346.639,218.783 346.648,218.757 346.657,218.732 346.666,218.706 346.675,218.681 346.685,218.655 346.694,218.63 346.703,218.604 346.712,218.579 346.721,218.554 346.731,218.528 346.74,218.503 346.749,218.477 346.758,218.452 346.767,218.427 346.777,218.401 346.786,218.376 346.795,218.35 346.804,218.325 346.813,218.3 346.822,218.274 346.832,218.249 346.841,218.223 346.85,218.198 346.859,218.173 346.868,218.147 346.878,218.122 346.887,218.097 346.896,218.071 346.905,218.046 346.914,218.021 346.924,217.995 346.933,217.97 346.942,217.945 346.951,217.919 346.96,217.894 346.969,217.869 346.979,217.843 346.988,217.818 346.997,217.793 347.006,217.767 347.015,217.742 347.025,217.717 347.034,217.692 347.043,217.666 347.052,217.641 347.061,217.616 347.071,217.591 347.08,217.565 347.089,217.54 347.098,217.515 347.107,217.49 347.117,217.464 347.126,217.439 347.135,217.414 347.144,217.389 347.153,217.363 347.162,217.338 347.172,217.313 347.181,217.288 347.19,217.263 347.199,217.237 347.208,217.212 347.218,217.187 347.227,217.162 347.236,217.137 347.245,217.111 347.254,217.086 347.264,217.061 347.273,217.036 347.282,217.011 347.291,216.986 347.3,216.96 347.309,216.935 347.319,216.91 347.328,216.885 347.337,216.86 347.346,216.835 347.355,216.81 347.365,216.785 347.374,216.759 347.383,216.734 347.392,216.709 347.401,216.684 347.411,216.659 347.42,216.634 347.429,216.609 347.438,216.584 347.447,216.559 347.457,216.534 347.466,216.509 347.475,216.483 347.484,216.458 347.493,216.433 347.502,216.408 347.512,216.383 347.521,216.358 347.53,216.333 347.539,216.308 347.548,216.283 347.558,216.258 347.567,216.233 347.576,216.208 347.585,216.183 347.594,216.158 347.604,216.133 347.613,216.108 347.622,216.083 347.631,216.058 347.64,216.033 347.649,216.008 347.659,215.983 347.668,215.958 347.677,215.933 347.686,215.908 347.695,215.883 347.705,215.858 347.714,215.833 347.723,215.808 347.732,215.784 347.741,215.759 347.751,215.734 347.76,215.709 347.769,215.684 347.778,215.659 347.787,215.634 347.797,215.609 347.806,215.584 347.815,215.559 347.824,215.534 347.833,215.51 347.842,215.485 347.852,215.46 347.861,215.435 347.87,215.41 347.879,215.385 347.888,215.36 347.898,215.335 347.907,215.311 347.916,215.286 347.925,215.261 347.934,215.236 347.944,215.211 347.953,215.186 347.962,215.162 347.971,215.137 347.98,215.112 347.989,215.087 347.999,215.062 348.008,215.037 348.017,215.013 348.026,214.988 348.035,214.963 348.045,214.938 348.054,214.914 348.063,214.889 348.072,214.864 348.081,214.839 348.091,214.814 348.1,214.79 348.109,214.765 348.118,214.74 348.127,214.715 348.137,214.691 348.146,214.666 348.155,214.641 348.164,214.616 348.173,214.592 348.182,214.567 348.192,214.542 348.201,214.518 348.21,214.493 348.219,214.468 348.228,214.444 348.238,214.419 348.247,214.394 348.256,214.369 348.265,214.345 348.274,214.32 348.284,214.295 348.293,214.271 348.302,214.246 348.311,214.221 348.32,214.197 348.329,214.172 348.339,214.147 348.348,214.123 348.357,214.098 348.366,214.074 348.375,214.049 348.385,214.024 348.394,214 348.403,213.975 348.412,213.95 348.421,213.926 348.431,213.901 348.44,213.877 348.449,213.852 348.458,213.828 348.467,213.803 348.477,213.778 348.486,213.754 348.495,213.729 348.504,213.705 348.513,213.68 348.522,213.656 348.532,213.631 348.541,213.606 348.55,213.582 348.559,213.557 348.568,213.533 348.578,213.508 348.587,213.484 348.596,213.459 348.605,213.435 348.614,213.41 348.624,213.386 348.633,213.361 348.642,213.337 348.651,213.312 348.66,213.288 348.669,213.263 348.679,213.239 348.688,213.214 348.697,213.19 348.706,213.165 348.715,213.141 348.725,213.116 348.734,213.092 348.743,213.068 348.752,213.043 348.761,213.019 348.771,212.994 348.78,212.97 348.789,212.945 348.798,212.921 348.807,212.896 348.817,212.872 348.826,212.848 348.835,212.823 348.844,212.799 348.853,212.774 348.862,212.75 348.872,212.726 348.881,212.701 348.89,212.677 348.899,212.653 348.908,212.628 348.918,212.604 348.927,212.579 348.936,212.555 348.945,212.531 348.954,212.506 348.964,212.482 348.973,212.458 348.982,212.433 348.991,212.409 349,212.385 349.01,212.36 349.019,212.336 349.028,212.312 349.037,212.287 349.046,212.263 349.055,212.239 349.065,212.215 349.074,212.19 349.083,212.166 349.092,212.142 349.101,212.117 349.111,212.093 349.12,212.069 349.129,212.045 349.138,212.02 349.147,211.996 349.157,211.972 349.166,211.948 349.175,211.923 349.184,211.899 349.193,211.875 349.202,211.851 349.212,211.826 349.221,211.802 349.23,211.778 349.239,211.754 349.248,211.73 349.258,211.705 349.267,211.681 349.276,211.657 349.285,211.633 349.294,211.609 349.304,211.584 349.313,211.56 349.322,211.536 349.331,211.512 349.34,211.488 349.35,211.463 349.359,211.439 349.368,211.415 349.377,211.391 349.386,211.367 349.395,211.343 349.405,211.319 349.414,211.294 349.423,211.27 349.432,211.246 349.441,211.222 349.451,211.198 349.46,211.174 349.469,211.15 349.478,211.126 349.487,211.102 349.497,211.078 349.506,211.053 349.515,211.029 349.524,211.005 349.533,210.981 349.542,210.957 349.552,210.933 349.561,210.909 349.57,210.885 349.579,210.861 349.588,210.837 349.598,210.813 349.607,210.789 349.616,210.765 349.625,210.741 349.634,210.717 349.644,210.693 349.653,210.669 349.662,210.645 349.671,210.621 349.68,210.597 349.69,210.573 349.699,210.549 349.708,210.525 349.717,210.501 349.726,210.477 349.735,210.453 349.745,210.429 349.754,210.405 349.763,210.381 349.772,210.357 349.781,210.333 349.791,210.309 349.8,210.285 349.809,210.261 349.818,210.237 349.827,210.213 349.837,210.189 349.846,210.165 349.855,210.141 349.864,210.117 349.873,210.093 349.882,210.07 349.892,210.046 349.901,210.022 349.91,209.998 349.919,209.974 349.928,209.95 349.938,209.926 349.947,209.902 349.956,209.878 349.965,209.855 349.974,209.831 349.984,209.807 349.993,209.783 350.002,209.759 350.011,209.735 350.02,209.711 350.03,209.688 350.039,209.664 350.048,209.64 350.057,209.616 350.066,209.592 350.075,209.568 350.085,209.545 350.094,209.521 350.103,209.497 350.112,209.473 350.121,209.449 350.131,209.426 350.14,209.402 350.149,209.378 350.158,209.354 350.167,209.33 350.177,209.307 350.186,209.283 350.195,209.259 350.204,209.235 350.213,209.212 350.222,209.188 350.232,209.164 350.241,209.14 350.25,209.117 350.259,209.093 350.268,209.069 350.278,209.046 350.287,209.022 350.296,208.998 350.305,208.974 350.314,208.951 350.324,208.927 350.333,208.903 350.342,208.88 350.351,208.856 350.36,208.832 350.37,208.808 350.379,208.785 350.388,208.761 350.397,208.737 350.406,208.714 350.415,208.69 350.425,208.666 350.434,208.643 350.443,208.619 350.452,208.596 350.461,208.572 350.471,208.548 350.48,208.525 350.489,208.501 350.498,208.477 350.507,208.454 350.517,208.43 350.526,208.407 350.535,208.383 350.544,208.359 350.553,208.336 350.562,208.312 350.572,208.289 350.581,208.265 350.59,208.241 350.599,208.218 350.608,208.194 350.618,208.171 350.627,208.147 350.636,208.124 350.645,208.1 350.654,208.076 350.664,208.053 350.673,208.029 350.682,208.006 350.691,207.982 350.7,207.959 350.71,207.935 350.719,207.912 350.728,207.888 350.737,207.865 350.746,207.841 350.755,207.818 350.765,207.794 350.774,207.771 350.783,207.747 350.792,207.724 350.801,207.7 350.811,207.677 350.82,207.653 350.829,207.63 350.838,207.606 350.847,207.583 350.857,207.559 350.866,207.536 350.875,207.513 350.884,207.489 350.893,207.466 350.902,207.442 350.912,207.419 350.921,207.395 350.93,207.372 350.939,207.349 350.948,207.325 350.958,207.302 350.967,207.278 350.976,207.255 350.985,207.231 350.994,207.208 351.004,207.185 351.013,207.161 351.022,207.138 351.031,207.115 351.04,207.091 351.05,207.068 351.059,207.044 351.068,207.021 351.077,206.998 351.086,206.974 351.095,206.951 351.105,206.928 351.114,206.904 351.123,206.881 351.132,206.858 351.141,206.834 351.151,206.811 351.16,206.788 351.169,206.764 351.178,206.741 351.187,206.718 351.197,206.695 351.206,206.671 351.215,206.648 351.224,206.625 351.233,206.601 351.243,206.578 351.252,206.555 351.261,206.532 351.27,206.508 351.279,206.485 351.288,206.462 351.298,206.439 351.307,206.415 351.316,206.392 351.325,206.369 351.334,206.346 351.344,206.322 351.353,206.299 351.362,206.276 351.371,206.253 351.38,206.229 351.39,206.206 351.399,206.183 351.408,206.16 351.417,206.137 351.426,206.113 351.435,206.09 351.445,206.067 351.454,206.044 351.463,206.021 351.472,205.998 351.481,205.974 351.491,205.951 351.5,205.928 351.509,205.905 351.518,205.882 351.527,205.859 351.537,205.835 351.546,205.812 351.555,205.789 351.564,205.766 351.573,205.743 351.583,205.72 351.592,205.697 351.601,205.674 351.61,205.65 351.619,205.627 351.628,205.604 351.638,205.581 351.647,205.558 351.656,205.535 351.665,205.512 351.674,205.489 351.684,205.466 351.693,205.443 351.702,205.42 351.711,205.396 351.72,205.373 351.73,205.35 351.739,205.327 351.748,205.304 351.757,205.281 351.766,205.258 351.775,205.235 351.785,205.212 351.794,205.189 351.803,205.166 351.812,205.143 351.821,205.12 351.831,205.097 351.84,205.074 351.849,205.051 351.858,205.028 351.867,205.005 351.877,204.982 351.886,204.959 351.895,204.936 351.904,204.913 351.913,204.89 351.923,204.867 351.932,204.844 351.941,204.821 351.95,204.798 351.959,204.775 351.968,204.752 351.978,204.729 351.987,204.706 351.996,204.684 352.005,204.661 352.014,204.638 352.024,204.615 352.033,204.592 352.042,204.569 352.051,204.546 352.06,204.523 352.07,204.5 352.079,204.477 352.088,204.454 352.097,204.432 352.106,204.409 352.115,204.386 352.125,204.363 352.134,204.34 352.143,204.317 352.152,204.294 352.161,204.271 352.171,204.249 352.18,204.226 352.189,204.203 352.198,204.18 352.207,204.157 352.217,204.134 352.226,204.112 352.235,204.089 352.244,204.066 352.253,204.043 352.263,204.02 352.272,203.997 352.281,203.975 352.29,203.952 352.299,203.929 352.308,203.906 352.318,203.883 352.327,203.861 352.336,203.838 352.345,203.815 352.354,203.792 352.364,203.77 352.373,203.747 352.382,203.724 352.391,203.701 352.4,203.679 352.41,203.656 352.419,203.633 352.428,203.61 352.437,203.588 352.446,203.565 352.455,203.542 352.465,203.519 352.474,203.497 352.483,203.474 352.492,203.451 352.501,203.429 352.511,203.406 352.52,203.383 352.529,203.36 352.538,203.338 352.547,203.315 352.557,203.292 352.566,203.27 352.575,203.247 352.584,203.224 352.593,203.202 352.603,203.179 352.612,203.156 352.621,203.134 352.63,203.111 352.639,203.088 352.648,203.066 352.658,203.043 352.667,203.02 352.676,202.998 352.685,202.975 352.694,202.953 352.704,202.93 352.713,202.907 352.722,202.885 352.731,202.862 352.74,202.84 352.75,202.817 352.759,202.794 352.768,202.772 352.777,202.749 352.786,202.727 352.795,202.704 352.805,202.681 352.814,202.659 352.823,202.636 352.832,202.614 352.841,202.591 352.851,202.569 352.86,202.546 352.869,202.524 352.878,202.501 352.887,202.479 352.897,202.456 352.906,202.433 352.915,202.411 352.924,202.388 352.933,202.366 352.943,202.343 352.952,202.321 352.961,202.298 352.97,202.276 352.979,202.253 352.988,202.231 352.998,202.208 353.007,202.186 353.016,202.163 353.025,202.141 353.034,202.119 353.044,202.096 353.053,202.074 353.062,202.051 353.071,202.029 353.08,202.006 353.09,201.984 353.099,201.961 353.108,201.939 353.117,201.916 353.126,201.894 353.135,201.872 353.145,201.849 353.154,201.827 353.163,201.804 353.172,201.782 353.181,201.76 353.191,201.737 353.2,201.715 353.209,201.692 353.218,201.67 353.227,201.648 353.237,201.625 353.246,201.603 353.255,201.58 353.264,201.558 353.273,201.536 353.283,201.513 353.292,201.491 353.301,201.469 353.31,201.446 353.319,201.424 353.328,201.402 353.338,201.379 353.347,201.357 353.356,201.335 353.365,201.312 353.374,201.29 353.384,201.268 353.393,201.245 353.402,201.223 353.411,201.201 353.42,201.179 353.43,201.156 353.439,201.134 353.448,201.112 353.457,201.089 353.466,201.067 353.475,201.045 353.485,201.023 353.494,201 353.503,200.978 353.512,200.956 353.521,200.933 353.531,200.911 353.54,200.889 353.549,200.867 353.558,200.845 353.567,200.822 353.577,200.8 353.586,200.778 353.595,200.756 353.604,200.733 353.613,200.711 353.623,200.689 353.632,200.667 353.641,200.645 353.65,200.622 353.659,200.6 353.668,200.578 353.678,200.556 353.687,200.534 353.696,200.511 353.705,200.489 353.714,200.467 353.724,200.445 353.733,200.423 353.742,200.401 353.751,200.378 353.76,200.356 353.77,200.334 353.779,200.312 353.788,200.29 353.797,200.268 353.806,200.246 353.816,200.224 353.825,200.201 353.834,200.179 353.843,200.157 353.852,200.135 353.861,200.113 353.871,200.091 353.88,200.069 353.889,200.047 353.898,200.025 353.907,200.003 353.917,199.98 353.926,199.958 353.935,199.936 353.944,199.914 353.953,199.892 353.963,199.87 353.972,199.848 353.981,199.826 353.99,199.804 353.999,199.782 354.008,199.76 354.018,199.738 354.027,199.716 354.036,199.694 354.045,199.672 354.054,199.65 354.064,199.628 354.073,199.606 354.082,199.584 354.091,199.562 354.1,199.54 354.11,199.518 354.119,199.496 354.128,199.474 354.137,199.452 354.146,199.43 354.156,199.408 354.165,199.386 354.174,199.364 354.183,199.342 354.192,199.32 354.201,199.298 354.211,199.276 354.22,199.254 354.229,199.232 354.238,199.21 354.247,199.188 354.257,199.166 354.266,199.144 354.275,199.122 354.284,199.101 354.293,199.079 354.303,199.057 354.312,199.035 354.321,199.013 354.33,198.991 354.339,198.969 354.348,198.947 354.358,198.925 354.367,198.903 354.376,198.882 354.385,198.86 354.394,198.838 354.404,198.816 354.413,198.794 354.422,198.772 354.431,198.75 354.44,198.729 354.45,198.707 354.459,198.685 354.468,198.663 354.477,198.641 354.486,198.619 354.496,198.597 354.505,198.576 354.514,198.554 354.523,198.532 354.532,198.51 354.541,198.488 354.551,198.467 354.56,198.445 354.569,198.423 354.578,198.401 354.587,198.379 354.597,198.358 354.606,198.336 354.615,198.314 354.624,198.292 354.633,198.271 354.643,198.249 354.652,198.227 354.661,198.205 354.67,198.184 354.679,198.162 354.688,198.14 354.698,198.118 354.707,198.097 354.716,198.075 354.725,198.053 354.734,198.031 354.744,198.01 354.753,197.988 354.762,197.966 354.771,197.944 354.78,197.923 354.79,197.901 354.799,197.879 354.808,197.858 354.817,197.836 354.826,197.814 354.836,197.793 354.845,197.771 354.854,197.749 354.863,197.728 354.872,197.706 354.881,197.684 354.891,197.663 354.9,197.641 354.909,197.619 354.918,197.598 354.927,197.576 354.937,197.554 354.946,197.533 354.955,197.511 354.964,197.49 354.973,197.468 354.983,197.446 354.992,197.425 355.001,197.403 355.01,197.381 355.019,197.36 355.028,197.338 355.038,197.317 355.047,197.295 355.056,197.273 355.065,197.252 355.074,197.23 355.084,197.209 355.093,197.187 355.102,197.166 355.111,197.144 355.12,197.123 355.13,197.101 355.139,197.079 355.148,197.058 355.157,197.036 355.166,197.015 355.176,196.993 355.185,196.972 355.194,196.95 355.203,196.929 355.212,196.907 355.221,196.886 355.231,196.864 355.24,196.843 355.249,196.821 355.258,196.8 355.267,196.778 355.277,196.757 355.286,196.735 355.295,196.714 355.304,196.692 355.313,196.671 355.323,196.649 355.332,196.628 355.341,196.606 355.35,196.585 355.359,196.563 355.368,196.542 355.378,196.52 355.387,196.499 355.396,196.478 355.405,196.456 355.414,196.435 355.424,196.413 355.433,196.392 355.442,196.37 355.451,196.349 355.46,196.328 355.47,196.306 355.479,196.285 355.488,196.263 355.497,196.242 355.506,196.221 355.516,196.199 355.525,196.178 355.534,196.156 355.543,196.135 355.552,196.114 355.561,196.092 355.571,196.071 355.58,196.05 355.589,196.028 355.598,196.007 355.607,195.986 355.617,195.964 355.626,195.943 355.635,195.921 355.644,195.9 355.653,195.879 355.663,195.857 355.672,195.836 355.681,195.815 355.69,195.794 355.699,195.772 355.708,195.751 355.718,195.73 355.727,195.708 355.736,195.687 355.745,195.666 355.754,195.644 355.764,195.623 355.773,195.602 355.782,195.581 355.791,195.559 355.8,195.538 355.81,195.517 355.819,195.496 355.828,195.474 355.837,195.453 355.846,195.432 355.856,195.411 355.865,195.389 355.874,195.368 355.883,195.347 355.892,195.326 355.901,195.304 355.911,195.283 355.92,195.262 355.929,195.241 355.938,195.219 355.947,195.198 355.957,195.177 355.966,195.156 355.975,195.135 355.984,195.113 355.993,195.092 356.003,195.071 356.012,195.05 356.021,195.029 356.03,195.008 356.039,194.986 356.048,194.965 356.058,194.944 356.067,194.923 356.076,194.902 356.085,194.881 356.094,194.859 356.104,194.838 356.113,194.817 356.122,194.796 356.131,194.775 356.14,194.754 356.15,194.733 356.159,194.712 356.168,194.69 356.177,194.669 356.186,194.648 356.196,194.627 356.205,194.606 356.214,194.585 356.223,194.564 356.232,194.543 356.241,194.522 356.251,194.501 356.26,194.48 356.269,194.458 356.278,194.437 356.287,194.416 356.297,194.395 356.306,194.374 356.315,194.353 356.324,194.332 356.333,194.311 356.343,194.29 356.352,194.269 356.361,194.248 356.37,194.227 356.379,194.206 356.389,194.185 356.398,194.164 356.407,194.143 356.416,194.122 356.425,194.101 356.434,194.08 356.444,194.059 356.453,194.038 356.462,194.017 356.471,193.996 356.48,193.975 356.49,193.954 356.499,193.933 356.508,193.912 356.517,193.891 356.526,193.87 356.536,193.849 356.545,193.828 356.554,193.807 356.563,193.786 356.572,193.765 356.581,193.744 356.591,193.723 356.6,193.702 356.609,193.681 356.618,193.661 356.627,193.64 356.637,193.619 356.646,193.598 356.655,193.577 356.664,193.556 356.673,193.535 356.683,193.514 356.692,193.493 356.701,193.472 356.71,193.452 356.719,193.431 356.729,193.41 356.738,193.389 356.747,193.368 356.756,193.347 356.765,193.326 356.774,193.305 356.784,193.285 356.793,193.264 356.802,193.243 356.811,193.222 356.82,193.201 356.83,193.18 356.839,193.159 356.848,193.139 356.857,193.118 356.866,193.097 356.876,193.076 356.885,193.055 356.894,193.035 356.903,193.014 356.912,192.993 356.921,192.972 356.931,192.951 356.94,192.931 356.949,192.91 356.958,192.889 356.967,192.868 356.977,192.847 356.986,192.827 356.995,192.806 357.004,192.785 357.013,192.764 357.023,192.744 357.032,192.723 357.041,192.702 357.05,192.681 357.059,192.661 357.069,192.64 357.078,192.619 357.087,192.598 357.096,192.578 357.105,192.557 357.114,192.536 357.124,192.516 357.133,192.495 357.142,192.474 357.151,192.453 357.16,192.433 357.17,192.412 357.179,192.391 357.188,192.371 357.197,192.35 357.206,192.329 357.216,192.309 357.225,192.288 357.234,192.267 357.243,192.247 357.252,192.226 357.261,192.205 357.271,192.185 357.28,192.164 357.289,192.143 357.298,192.123 357.307,192.102 357.317,192.081 357.326,192.061 357.335,192.04 357.344,192.019 357.353,191.999 357.363,191.978 357.372,191.958 357.381,191.937 357.39,191.916 357.399,191.896 357.409,191.875 357.418,191.855 357.427,191.834 357.436,191.813 357.445,191.793 357.454,191.772 357.464,191.752 357.473,191.731 357.482,191.711 357.491,191.69 357.5,191.669 357.51,191.649 357.519,191.628 357.528,191.608 357.537,191.587 357.546,191.567 357.556,191.546 357.565,191.526 357.574,191.505 357.583,191.485 357.592,191.464 357.601,191.443 357.611,191.423 357.62,191.402 357.629,191.382 357.638,191.361 357.647,191.341 357.657,191.32 357.666,191.3 357.675,191.279 357.684,191.259 357.693,191.238 357.703,191.218 357.712,191.198 357.721,191.177 357.73,191.157 357.739,191.136 357.749,191.116 357.758,191.095 357.767,191.075 357.776,191.054 357.785,191.034 357.794,191.013 357.804,190.993 357.813,190.973 357.822,190.952 357.831,190.932 357.84,190.911 357.85,190.891 357.859,190.87 357.868,190.85 357.877,190.83 357.886,190.809 357.896,190.789 357.905,190.768 357.914,190.748 357.923,190.728 357.932,190.707 357.941,190.687 357.951,190.666 357.96,190.646 357.969,190.626 357.978,190.605 357.987,190.585 357.997,190.565 358.006,190.544 358.015,190.524 358.024,190.504 358.033,190.483 358.043,190.463 358.052,190.443 358.061,190.422 358.07,190.402 358.079,190.382 358.089,190.361 358.098,190.341 358.107,190.321 358.116,190.3 358.125,190.28 358.134,190.26 358.144,190.239 358.153,190.219 358.162,190.199 358.171,190.178 358.18,190.158 358.19,190.138 358.199,190.118 358.208,190.097 358.217,190.077 358.226,190.057 358.236,190.037 358.245,190.016 358.254,189.996 358.263,189.976 358.272,189.956 358.281,189.935 358.291,189.915 358.3,189.895 358.309,189.875 358.318,189.854 358.327,189.834 358.337,189.814 358.346,189.794 358.355,189.774 358.364,189.753 358.373,189.733 358.383,189.713 358.392,189.693 358.401,189.672 358.41,189.652 358.419,189.632 358.429,189.612 358.438,189.592 358.447,189.572 358.456,189.551 358.465,189.531 358.474,189.511 358.484,189.491 358.493,189.471 358.502,189.451 358.511,189.43 358.52,189.41 358.53,189.39 358.539,189.37 358.548,189.35 358.557,189.33 358.566,189.31 358.576,189.289 358.585,189.269 358.594,189.249 358.603,189.229 358.612,189.209 358.621,189.189 358.631,189.169 358.64,189.149 358.649,189.129 358.658,189.108 358.667,189.088 358.677,189.068 358.686,189.048 358.695,189.028 358.704,189.008 358.713,188.988 358.723,188.968 358.732,188.948 358.741,188.928 358.75,188.908 358.759,188.888 358.769,188.868 358.778,188.848 358.787,188.828 358.796,188.808 358.805,188.788 358.814,188.767 358.824,188.747 358.833,188.727 358.842,188.707 358.851,188.687 358.86,188.667 358.87,188.647 358.879,188.627 358.888,188.607 358.897,188.587 358.906,188.567 358.916,188.547 358.925,188.527 358.934,188.507 358.943,188.487 358.952,188.467 358.962,188.447 358.971,188.428 358.98,188.408 358.989,188.388 358.998,188.368 359.007,188.348 359.017,188.328 359.026,188.308 359.035,188.288 359.044,188.268 359.053,188.248 359.063,188.228 359.072,188.208 359.081,188.188 359.09,188.168 359.099,188.148 359.109,188.128 359.118,188.109 359.127,188.089 359.136,188.069 359.145,188.049 359.154,188.029 359.164,188.009 359.173,187.989 359.182,187.969 359.191,187.949 359.2,187.929 359.21,187.91 359.219,187.89 359.228,187.87 359.237,187.85 359.246,187.83 359.256,187.81 359.265,187.79 359.274,187.771 359.283,187.751 359.292,187.731 359.302,187.711 359.311,187.691 359.32,187.671 359.329,187.652 359.338,187.632 359.347,187.612 359.357,187.592 359.366,187.572 359.375,187.553 359.384,187.533 359.393,187.513 359.403,187.493 359.412,187.473 359.421,187.454 359.43,187.434 359.439,187.414 359.449,187.394 359.458,187.374 359.467,187.355 359.476,187.335 359.485,187.315 359.494,187.295 359.504,187.276 359.513,187.256 359.522,187.236 359.531,187.216 359.54,187.197 359.55,187.177 359.559,187.157 359.568,187.137 359.577,187.118 359.586,187.098 359.596,187.078 359.605,187.059 359.614,187.039 359.623,187.019 359.632,186.999 359.642,186.98 359.651,186.96 359.66,186.94 359.669,186.921 359.678,186.901 359.687,186.881 359.697,186.862 359.706,186.842 359.715,186.822 359.724,186.803 359.733,186.783 359.743,186.763 359.752,186.744 359.761,186.724 359.77,186.704 359.779,186.685 359.789,186.665 359.798,186.645 359.807,186.626 359.816,186.606 359.825,186.586 359.834,186.567 359.844,186.547 359.853,186.527 359.862,186.508 359.871,186.488 359.88,186.469 359.89,186.449 359.899,186.429 359.908,186.41 359.917,186.39 359.926,186.371 359.936,186.351 359.945,186.331 359.954,186.312 359.963,186.292 359.972,186.273 359.982,186.253 359.991,186.234 360,186.214 360.009,186.194 360.018,186.175 360.027,186.155 360.037,186.136 360.046,186.116 360.055,186.097 360.064,186.077 360.073,186.058 360.083,186.038 360.092,186.019 360.101,185.999 360.11,185.98 360.119,185.96 360.129,185.941 360.138,185.921 360.147,185.902 360.156,185.882 360.165,185.863 360.174,185.843 360.184,185.824 360.193,185.804 360.202,185.785 360.211,185.765 360.22,185.746 360.23,185.726 360.239,185.707 360.248,185.687 360.257,185.668 360.266,185.648 360.276,185.629 360.285,185.609 360.294,185.59 360.303,185.57 360.312,185.551 360.322,185.532 360.331,185.512 360.34,185.493 360.349,185.473 360.358,185.454 360.367,185.434 360.377,185.415 360.386,185.396 360.395,185.376 360.404,185.357 360.413,185.337 360.423,185.318 360.432,185.299 360.441,185.279 360.45,185.26 360.459,185.24 360.469,185.221 360.478,185.202 360.487,185.182 360.496,185.163 360.505,185.144 360.514,185.124 360.524,185.105 360.533,185.086 360.542,185.066 360.551,185.047 360.56,185.027 360.57,185.008 360.579,184.989 360.588,184.969 360.597,184.95 360.606,184.931 360.616,184.911 360.625,184.892 360.634,184.873 360.643,184.854 360.652,184.834 360.662,184.815 360.671,184.796 360.68,184.776 360.689,184.757 360.698,184.738 360.707,184.718 360.717,184.699 360.726,184.68 360.735,184.661 360.744,184.641 360.753,184.622 360.763,184.603 360.772,184.584 360.781,184.564 360.79,184.545 360.799,184.526 360.809,184.506 360.818,184.487 360.827,184.468 360.836,184.449 360.845,184.43 360.854,184.41 360.864,184.391 360.873,184.372 360.882,184.353 360.891,184.333 360.9,184.314 360.91,184.295 360.919,184.276 360.928,184.257 360.937,184.237 360.946,184.218 360.956,184.199 360.965,184.18 360.974,184.161 360.983,184.141 360.992,184.122 361.002,184.103 361.011,184.084 361.02,184.065 361.029,184.046 361.038,184.026 361.047,184.007 361.057,183.988 361.066,183.969 361.075,183.95 361.084,183.931 361.093,183.911 361.103,183.892 361.112,183.873 361.121,183.854 361.13,183.835 361.139,183.816 361.149,183.797 361.158,183.778 361.167,183.758 361.176,183.739 361.185,183.72 361.195,183.701 361.204,183.682 361.213,183.663 361.222,183.644 361.231,183.625 361.24,183.606 361.25,183.587 361.259,183.568 361.268,183.548 361.277,183.529 361.286,183.51 361.296,183.491 361.305,183.472 361.314,183.453 361.323,183.434 361.332,183.415 361.342,183.396 361.351,183.377 361.36,183.358 361.369,183.339 361.378,183.32 361.387,183.301 361.397,183.282 361.406,183.263 361.415,183.244 361.424,183.225 361.433,183.206 361.443,183.187 361.452,183.168 361.461,183.149 361.47,183.13 361.479,183.111 361.489,183.092 361.498,183.073 361.507,183.054 361.516,183.035 361.525,183.016 361.535,182.997 361.544,182.978 361.553,182.959 361.562,182.94 361.571,182.921 361.58,182.902 361.59,182.883 361.599,182.864 361.608,182.845 361.617,182.826 361.626,182.807 361.636,182.788 361.645,182.769 361.654,182.75 361.663,182.732 361.672,182.713 361.682,182.694 361.691,182.675 361.7,182.656 361.709,182.637 361.718,182.618 361.727,182.599 361.737,182.58 361.746,182.561 361.755,182.542 361.764,182.524 361.773,182.505 361.783,182.486 361.792,182.467 361.801,182.448 361.81,182.429 361.819,182.41 361.829,182.391 361.838,182.373 361.847,182.354 361.856,182.335 361.865,182.316 361.875,182.297 361.884,182.278 361.893,182.26 361.902,182.241 361.911,182.222 361.92,182.203 361.93,182.184 361.939,182.165 361.948,182.147 361.957,182.128 361.966,182.109 361.976,182.09 361.985,182.071 361.994,182.053 362.003,182.034 362.012,182.015 362.022,181.996 362.031,181.977 362.04,181.959 362.049,181.94 362.058,181.921 362.067,181.902 362.077,181.884 362.086,181.865 362.095,181.846 362.104,181.827 362.113,181.808 362.123,181.79 362.132,181.771 362.141,181.752 362.15,181.733 362.159,181.715 362.169,181.696 362.178,181.677 362.187,181.659 362.196,181.64 362.205,181.621 362.215,181.602 362.224,181.584 362.233,181.565 362.242,181.546 362.251,181.528 362.26,181.509 362.27,181.49 362.279,181.471 362.288,181.453 362.297,181.434 362.306,181.415 362.316,181.397 362.325,181.378 362.334,181.359 362.343,181.341 362.352,181.322 362.362,181.303 362.371,181.285 362.38,181.266 362.389,181.247 362.398,181.229 362.407,181.21 362.417,181.191 362.426,181.173 362.435,181.154 362.444,181.136 362.453,181.117 362.463,181.098 362.472,181.08 362.481,181.061 362.49,181.042 362.499,181.024 362.509,181.005 362.518,180.987 362.527,180.968 362.536,180.949 362.545,180.931 362.555,180.912 362.564,180.894 362.573,180.875 362.582,180.856 362.591,180.838 362.6,180.819 362.61,180.801 362.619,180.782 362.628,180.764 362.637,180.745 362.646,180.726 362.656,180.708 362.665,180.689 362.674,180.671 362.683,180.652 362.692,180.634 362.702,180.615 362.711,180.597 362.72,180.578 362.729,180.56 362.738,180.541 362.747,180.523 362.757,180.504 362.766,180.486 362.775,180.467 362.784,180.449 362.793,180.43 362.803,180.412 362.812,180.393 362.821,180.375 362.83,180.356 362.839,180.338 362.849,180.319 362.858,180.301 362.867,180.282 362.876,180.264 362.885,180.245 362.895,180.227 362.904,180.208 362.913,180.19 362.922,180.171 362.931,180.153 362.94,180.134 362.95,180.116 362.959,180.098 362.968,180.079 362.977,180.061 362.986,180.042 362.996,180.024 363.005,180.005 363.014,179.987 363.023,179.969 363.032,179.95 363.042,179.932 363.051,179.913 363.06,179.895 363.069,179.876 363.078,179.858 363.087,179.84 363.097,179.821 363.106,179.803 363.115,179.785 363.124,179.766 363.133,179.748 363.143,179.729 363.152,179.711 363.161,179.693 363.17,179.674 363.179,179.656 363.189,179.638 363.198,179.619 363.207,179.601 363.216,179.582 363.225,179.564 363.235,179.546 363.244,179.527 363.253,179.509 363.262,179.491 363.271,179.472 363.28,179.454 363.29,179.436 363.299,179.418 363.308,179.399 363.317,179.381 363.326,179.363 363.336,179.344 363.345,179.326 363.354,179.308 363.363,179.289 363.372,179.271 363.382,179.253 363.391,179.235 363.4,179.216 363.409,179.198 363.418,179.18 363.427,179.161 363.437,179.143 363.446,179.125 363.455,179.107 363.464,179.088 363.473,179.07 363.483,179.052 363.492,179.034 363.501,179.015 363.51,178.997 363.519,178.979 363.529,178.961 363.538,178.942 363.547,178.924 363.556,178.906 363.565,178.888 363.575,178.87 363.584,178.851 363.593,178.833 363.602,178.815 363.611,178.797 363.62,178.778 363.63,178.76 363.639,178.742 363.648,178.724 363.657,178.706 363.666,178.688 363.676,178.669 363.685,178.651 363.694,178.633 363.703,178.615 363.712,178.597 363.722,178.578 363.731,178.56 363.74,178.542 363.749,178.524 363.758,178.506 363.768,178.488 363.777,178.47 363.786,178.451 363.795,178.433 363.804,178.415 363.813,178.397 363.823,178.379 363.832,178.361 363.841,178.343 363.85,178.325 363.859,178.306 363.869,178.288 363.878,178.27 363.887,178.252 363.896,178.234 363.905,178.216 363.915,178.198 363.924,178.18 363.933,178.162 363.942,178.144 363.951,178.125 363.96,178.107 363.97,178.089 363.979,178.071 363.988,178.053 363.997,178.035 364.006,178.017 364.016,177.999 364.025,177.981 364.034,177.963 364.043,177.945 364.052,177.927 364.062,177.909 364.071,177.891 364.08,177.873 364.089,177.855 364.098,177.837 364.108,177.819 364.117,177.801 364.126,177.783 364.135,177.764 364.144,177.746 364.153,177.728 364.163,177.71 364.172,177.692 364.181,177.674 364.19,177.656 364.199,177.638 364.209,177.62 364.218,177.602 364.227,177.585 364.236,177.567 364.245,177.549 364.255,177.531 364.264,177.513 364.273,177.495 364.282,177.477 364.291,177.459 364.3,177.441 364.31,177.423 364.319,177.405 364.328,177.387 364.337,177.369 364.346,177.351 364.356,177.333 364.365,177.315 364.374,177.297 364.383,177.279 364.392,177.261 364.402,177.243 364.411,177.226 364.42,177.208 364.429,177.19 364.438,177.172 364.448,177.154 364.457,177.136 364.466,177.118 364.475,177.1 364.484,177.082 364.493,177.064 364.503,177.047 364.512,177.029 364.521,177.011 364.53,176.993 364.539,176.975 364.549,176.957 364.558,176.939 364.567,176.921 364.576,176.904 364.585,176.886 364.595,176.868 364.604,176.85 364.613,176.832 364.622,176.814 364.631,176.796 364.64,176.779 364.65,176.761 364.659,176.743 364.668,176.725 364.677,176.707 364.686,176.69 364.696,176.672 364.705,176.654 364.714,176.636 364.723,176.618 364.732,176.6 364.742,176.583 364.751,176.565 364.76,176.547 364.769,176.529 364.778,176.512 364.788,176.494 364.797,176.476 364.806,176.458 364.815,176.44 364.824,176.423 364.833,176.405 364.843,176.387 364.852,176.369 364.861,176.352 364.87,176.334 364.879,176.316 364.889,176.298 364.898,176.281 364.907,176.263 364.916,176.245 364.925,176.227 364.935,176.21 364.944,176.192 364.953,176.174 364.962,176.156 364.971,176.139 364.98,176.121 364.99,176.103 364.999,176.086 365.008,176.068 365.017,176.05 365.026,176.032 365.036,176.015 365.045,175.997 365.054,175.979 365.063,175.962 365.072,175.944 365.082,175.926 365.091,175.909 365.1,175.891 365.109,175.873 365.118,175.856 365.128,175.838 365.137,175.82 365.146,175.803 365.155,175.785 365.164,175.767 365.173,175.75 365.183,175.732 365.192,175.714 365.201,175.697 365.21,175.679 365.219,175.662 365.229,175.644 365.238,175.626 365.247,175.609 365.256,175.591 365.265,175.573 365.275,175.556 365.284,175.538 365.293,175.521 365.302,175.503 365.311,175.485 365.32,175.468 365.33,175.45 365.339,175.433 365.348,175.415 365.357,175.397 365.366,175.38 365.376,175.362 365.385,175.345 365.394,175.327 365.403,175.31 365.412,175.292 365.422,175.274 365.431,175.257 365.44,175.239 365.449,175.222 365.458,175.204 365.468,175.187 365.477,175.169 365.486,175.152 365.495,175.134 365.504,175.117 365.513,175.099 365.523,175.081 365.532,175.064 365.541,175.046 365.55,175.029 365.559,175.011 365.569,174.994 365.578,174.976 365.587,174.959 365.596,174.941 365.605,174.924 365.615,174.906 365.624,174.889 365.633,174.871 365.642,174.854 365.651,174.836 365.66,174.819 365.67,174.802 365.679,174.784 365.688,174.767 365.697,174.749 365.706,174.732 365.716,174.714 365.725,174.697 365.734,174.679 365.743,174.662 365.752,174.644 365.762,174.627 365.771,174.61 365.78,174.592 365.789,174.575 365.798,174.557 365.808,174.54 365.817,174.522 365.826,174.505 365.835,174.488 365.844,174.47 365.853,174.453 365.863,174.435 365.872,174.418 365.881,174.4 365.89,174.383 365.899,174.366 365.909,174.348 365.918,174.331 365.927,174.314 365.936,174.296 365.945,174.279 365.955,174.261 365.964,174.244 365.973,174.227 365.982,174.209 365.991,174.192 366,174.175 366.01,174.157 366.019,174.14 366.028,174.122 366.037,174.105 366.046,174.088 366.056,174.07 366.065,174.053 366.074,174.036 366.083,174.018 366.092,174.001 366.102,173.984 366.111,173.966 366.12,173.949 366.129,173.932 366.138,173.915 366.148,173.897 366.157,173.88 366.166,173.863 366.175,173.845 366.184,173.828 366.193,173.811 366.203,173.793 366.212,173.776 366.221,173.759 366.23,173.742 366.239,173.724 366.249,173.707 366.258,173.69 366.267,173.672 366.276,173.655 366.285,173.638 366.295,173.621 366.304,173.603 366.313,173.586 366.322,173.569 366.331,173.552 366.341,173.534 366.35,173.517 366.359,173.5 366.368,173.483 366.377,173.465 366.386,173.448 366.396,173.431 366.405,173.414 366.414,173.397 366.423,173.379 366.432,173.362 366.442,173.345 366.451,173.328 366.46,173.311 366.469,173.293 366.478,173.276 366.488,173.259 366.497,173.242 366.506,173.225 366.515,173.207 366.524,173.19 366.533,173.173 366.543,173.156 366.552,173.139 366.561,173.122 366.57,173.104 366.579,173.087 366.589,173.07 366.598,173.053 366.607,173.036 366.616,173.019 366.625,173.001 366.635,172.984 366.644,172.967 366.653,172.95 366.662,172.933 366.671,172.916 366.681,172.899 366.69,172.881 366.699,172.864 366.708,172.847 366.717,172.83 366.726,172.813 366.736,172.796 366.745,172.779 366.754,172.762 366.763,172.745 366.772,172.728 366.782,172.71 366.791,172.693 366.8,172.676 366.809,172.659 366.818,172.642 366.828,172.625 366.837,172.608 366.846,172.591 366.855,172.574 366.864,172.557 366.873,172.54 366.883,172.523 366.892,172.506 366.901,172.488 366.91,172.471 366.919,172.454 366.929,172.437 366.938,172.42 366.947,172.403 366.956,172.386 366.965,172.369 366.975,172.352 366.984,172.335 366.993,172.318 367.002,172.301 367.011,172.284 367.021,172.267 367.03,172.25 367.039,172.233 367.048,172.216 367.057,172.199 367.066,172.182 367.076,172.165 367.085,172.148 367.094,172.131 367.103,172.114 367.112,172.097 367.122,172.08 367.131,172.063 367.14,172.046 367.149,172.029 367.158,172.012 367.168,171.995 367.177,171.978 367.186,171.961 367.195,171.944 367.204,171.927 367.213,171.911 367.223,171.894 367.232,171.877 367.241,171.86 367.25,171.843 367.259,171.826 367.269,171.809 367.278,171.792 367.287,171.775 367.296,171.758 367.305,171.741 367.315,171.724 367.324,171.707 367.333,171.69 367.342,171.674 367.351,171.657 367.361,171.64 367.37,171.623 367.379,171.606 367.388,171.589 367.397,171.572 367.406,171.555 367.416,171.538 367.425,171.522 367.434,171.505 367.443,171.488 367.452,171.471 367.462,171.454 367.471,171.437 367.48,171.42 367.489,171.404 367.498,171.387 367.508,171.37 367.517,171.353 367.526,171.336 367.535,171.319 367.544,171.302 367.553,171.286 367.563,171.269 367.572,171.252 367.581,171.235 367.59,171.218 367.599,171.201 367.609,171.185 367.618,171.168 367.627,171.151 367.636,171.134 367.645,171.117 367.655,171.101 367.664,171.084 367.673,171.067 367.682,171.05 367.691,171.033 367.701,171.017 367.71,171 367.719,170.983 367.728,170.966 367.737,170.95 367.746,170.933 367.756,170.916 367.765,170.899 367.774,170.882 367.783,170.866 367.792,170.849 367.802,170.832 367.811,170.815 367.82,170.799 367.829,170.782 367.838,170.765 367.848,170.749 367.857,170.732 367.866,170.715 367.875,170.698 367.884,170.682 367.893,170.665 367.903,170.648 367.912,170.631 367.921,170.615 367.93,170.598 367.939,170.581 367.949,170.565 367.958,170.548 367.967,170.531 367.976,170.515 367.985,170.498 367.995,170.481 368.004,170.464 368.013,170.448 368.022,170.431 368.031,170.414 368.041,170.398 368.05,170.381 368.059,170.364 368.068,170.348 368.077,170.331 368.086,170.314 368.096,170.298 368.105,170.281 368.114,170.264 368.123,170.248 368.132,170.231 368.142,170.215 368.151,170.198 368.16,170.181 368.169,170.165 368.178,170.148 368.188,170.131 368.197,170.115 368.206,170.098 368.215,170.082 368.224,170.065 368.233,170.048 368.243,170.032 368.252,170.015 368.261,169.999 368.27,169.982 368.279,169.965 368.289,169.949 368.298,169.932 368.307,169.916 368.316,169.899 368.325,169.882 368.335,169.866 368.344,169.849 368.353,169.833 368.362,169.816 368.371,169.8 368.381,169.783 368.39,169.766 368.399,169.75 368.408,169.733 368.417,169.717 368.426,169.7 368.436,169.684 368.445,169.667 368.454,169.651 368.463,169.634 368.472,169.618 368.482,169.601 368.491,169.584 368.5,169.568 368.509,169.551 368.518,169.535 368.528,169.518 368.537,169.502 368.546,169.485 368.555,169.469 368.564,169.452 368.574,169.436 368.583,169.419 368.592,169.403 368.601,169.386 368.61,169.37 368.619,169.353 368.629,169.337 368.638,169.321 368.647,169.304 368.656,169.288 368.665,169.271 368.675,169.255 368.684,169.238 368.693,169.222 368.702,169.205 368.711,169.189 368.721,169.172 368.73,169.156 368.739,169.139 368.748,169.123 368.757,169.107 368.766,169.09 368.776,169.074 368.785,169.057 368.794,169.041 368.803,169.024 368.812,169.008 368.822,168.992 368.831,168.975 368.84,168.959 368.849,168.942 368.858,168.926 368.868,168.91 368.877,168.893 368.886,168.877 368.895,168.86 368.904,168.844 368.914,168.828 368.923,168.811 368.932,168.795 368.941,168.778 368.95,168.762 368.959,168.746 368.969,168.729 368.978,168.713 368.987,168.697 368.996,168.68 369.005,168.664 369.015,168.648 369.024,168.631 369.033,168.615 369.042,168.598 369.051,168.582 369.061,168.566 369.07,168.549 369.079,168.533 369.088,168.517 369.097,168.5 369.106,168.484 369.116,168.468 369.125,168.451 369.134,168.435 369.143,168.419 369.152,168.403 369.162,168.386 369.171,168.37 369.18,168.354 369.189,168.337 369.198,168.321 369.208,168.305 369.217,168.288 369.226,168.272 369.235,168.256 369.244,168.24 369.254,168.223 369.263,168.207 369.272,168.191 369.281,168.175 369.29,168.158 369.299,168.142 369.309,168.126 369.318,168.109 369.327,168.093 369.336,168.077 369.345,168.061 369.355,168.044 369.364,168.028 369.373,168.012 369.382,167.996 369.391,167.98 369.401,167.963 369.41,167.947 369.419,167.931 369.428,167.915 369.437,167.898 369.446,167.882 369.456,167.866 369.465,167.85 369.474,167.834 369.483,167.817 369.492,167.801 369.502,167.785 369.511,167.769 369.52,167.753 369.529,167.736 369.538,167.72 369.548,167.704 369.557,167.688 369.566,167.672 369.575,167.655 369.584,167.639 369.594,167.623 369.603,167.607 369.612,167.591 369.621,167.575 369.63,167.558 369.639,167.542 369.649,167.526 369.658,167.51 369.667,167.494 369.676,167.478 369.685,167.462 369.695,167.445 369.704,167.429 369.713,167.413 369.722,167.397 369.731,167.381 369.741,167.365 369.75,167.349 369.759,167.333 369.768,167.316 369.777,167.3 369.786,167.284 369.796,167.268 369.805,167.252 369.814,167.236 369.823,167.22 369.832,167.204 369.842,167.188 369.851,167.172 369.86,167.155 369.869,167.139 369.878,167.123 369.888,167.107 369.897,167.091 369.906,167.075 369.915,167.059 369.924,167.043 369.934,167.027 369.943,167.011 369.952,166.995 369.961,166.979 369.97,166.963 369.979,166.947 369.989,166.931 369.998,166.915 370.007,166.899 370.016,166.882 370.025,166.866 370.035,166.85 370.044,166.834 370.053,166.818 370.062,166.802 370.071,166.786 370.081,166.77 370.09,166.754 370.099,166.738 370.108,166.722 370.117,166.706 370.126,166.69 370.136,166.674 370.145,166.658 370.154,166.642 370.163,166.626 370.172,166.61 370.182,166.594 370.191,166.578 370.2,166.562 370.209,166.546 370.218,166.53 370.228,166.514 370.237,166.499 370.246,166.483 370.255,166.467 370.264,166.451 370.274,166.435 370.283,166.419 370.292,166.403 370.301,166.387 370.31,166.371 370.319,166.355 370.329,166.339 370.338,166.323 370.347,166.307 370.356,166.291 370.365,166.275 370.375,166.259 370.384,166.243 370.393,166.228 370.402,166.212 370.411,166.196 370.421,166.18 370.43,166.164 370.439,166.148 370.448,166.132 370.457,166.116 370.466,166.1 370.476,166.084 370.485,166.069 370.494,166.053 370.503,166.037 370.512,166.021 370.522,166.005 370.531,165.989 370.54,165.973 370.549,165.957 370.558,165.942 370.568,165.926 370.577,165.91 370.586,165.894 370.595,165.878 370.604,165.862 370.614,165.846 370.623,165.831 370.632,165.815 370.641,165.799 370.65,165.783 370.659,165.767 370.669,165.751 370.678,165.736 370.687,165.72 370.696,165.704 370.705,165.688 370.715,165.672 370.724,165.656 370.733,165.641 370.742,165.625 370.751,165.609 370.761,165.593 370.77,165.577 370.779,165.562 370.788,165.546 370.797,165.53 370.806,165.514 370.816,165.498 370.825,165.483 370.834,165.467 370.843,165.451 370.852,165.435 370.862,165.42 370.871,165.404 370.88,165.388 370.889,165.372 370.898,165.357 370.908,165.341 370.917,165.325 370.926,165.309 370.935,165.294 370.944,165.278 370.954,165.262 370.963,165.246 370.972,165.231 370.981,165.215 370.99,165.199 370.999,165.183 371.009,165.168 371.018,165.152 371.027,165.136 371.036,165.12 371.045,165.105 371.055,165.089 371.064,165.073 371.073,165.058 371.082,165.042 371.091,165.026 371.101,165.011 371.11,164.995 371.119,164.979 371.128,164.963 371.137,164.948 371.147,164.932 371.156,164.916 371.165,164.901 371.174,164.885 371.183,164.869 371.192,164.854 371.202,164.838 371.211,164.822 371.22,164.807 371.229,164.791 371.238,164.775 371.248,164.76 371.257,164.744 371.266,164.728 371.275,164.713 371.284,164.697 371.294,164.682 371.303,164.666 371.312,164.65 371.321,164.635 371.33,164.619 371.339,164.603 371.349,164.588 371.358,164.572 371.367,164.557 371.376,164.541 371.385,164.525 371.395,164.51 371.404,164.494 371.413,164.479 371.422,164.463 371.431,164.447 371.441,164.432 371.45,164.416 371.459,164.401 371.468,164.385 371.477,164.369 371.487,164.354 371.496,164.338 371.505,164.323 371.514,164.307 371.523,164.292 371.532,164.276 371.542,164.26 371.551,164.245 371.56,164.229 371.569,164.214 371.578,164.198 371.588,164.183 371.597,164.167 371.606,164.152 371.615,164.136 371.624,164.12 371.634,164.105 371.643,164.089 371.652,164.074 371.661,164.058 371.67,164.043 371.679,164.027 371.689,164.012 371.698,163.996 371.707,163.981 371.716,163.965 371.725,163.95 371.735,163.934 371.744,163.919 371.753,163.903 371.762,163.888 371.771,163.872 371.781,163.857 371.79,163.841 371.799,163.826 371.808,163.81 371.817,163.795 371.827,163.779 371.836,163.764 371.845,163.748 371.854,163.733 371.863,163.718 371.872,163.702 371.882,163.687 371.891,163.671 371.9,163.656 371.909,163.64 371.918,163.625 371.928,163.609 371.937,163.594 371.946,163.578 371.955,163.563 371.964,163.548 371.974,163.532 371.983,163.517 371.992,163.501 372.001,163.486 372.01,163.47 372.019,163.455 372.029,163.44 372.038,163.424 372.047,163.409 372.056,163.393 372.065,163.378 372.075,163.363 372.084,163.347 372.093,163.332 372.102,163.316 372.111,163.301 372.121,163.286 372.13,163.27 372.139,163.255 372.148,163.24 372.157,163.224 372.167,163.209 372.176,163.193 372.185,163.178 372.194,163.163 372.203,163.147 372.212,163.132 372.222,163.117 372.231,163.101 372.24,163.086 372.249,163.071 372.258,163.055 372.268,163.04 372.277,163.025 372.286,163.009 372.295,162.994 372.304,162.979 372.314,162.963 372.323,162.948 372.332,162.933 372.341,162.917 372.35,162.902 372.359,162.887 372.369,162.871 372.378,162.856 372.387,162.841 372.396,162.825 372.405,162.81 372.415,162.795 372.424,162.78 372.433,162.764 372.442,162.749 372.451,162.734 372.461,162.718 372.47,162.703 372.479,162.688 372.488,162.673 372.497,162.657 372.507,162.642 372.516,162.627 372.525,162.611 372.534,162.596 372.543,162.581 372.552,162.566 372.562,162.55 372.571,162.535 372.58,162.52 372.589,162.505 372.598,162.489 372.608,162.474 372.617,162.459 372.626,162.444 372.635,162.428 372.644,162.413 372.654,162.398 372.663,162.383 372.672,162.368 372.681,162.352 372.69,162.337 372.699,162.322 372.709,162.307 372.718,162.292 372.727,162.276 372.736,162.261 372.745,162.246 372.755,162.231 372.764,162.216 372.773,162.2 372.782,162.185 372.791,162.17 372.801,162.155 372.81,162.14 372.819,162.124 372.828,162.109 372.837,162.094 372.847,162.079 372.856,162.064 372.865,162.049 372.874,162.033 372.883,162.018 372.892,162.003 372.902,161.988 372.911,161.973 372.92,161.958 372.929,161.943 372.938,161.927 372.948,161.912 372.957,161.897 372.966,161.882 372.975,161.867 372.984,161.852 372.994,161.837 373.003,161.821 373.012,161.806 373.021,161.791 373.03,161.776 373.039,161.761 373.049,161.746 373.058,161.731 373.067,161.716 373.076,161.701 373.085,161.685 373.095,161.67 373.104,161.655 373.113,161.64 373.122,161.625 373.131,161.61 373.141,161.595 373.15,161.58 373.159,161.565 373.168,161.55 373.177,161.535 373.187,161.52 373.196,161.505 373.205,161.489 373.214,161.474 373.223,161.459 373.232,161.444 373.242,161.429 373.251,161.414 373.26,161.399 373.269,161.384 373.278,161.369 373.288,161.354 373.297,161.339 373.306,161.324 373.315,161.309 373.324,161.294 373.334,161.279 373.343,161.264 373.352,161.249 373.361,161.234 373.37,161.219 373.379,161.204 373.389,161.189 373.398,161.174 373.407,161.159 373.416,161.144 373.425,161.129 373.435,161.114 373.444,161.099 373.453,161.084 373.462,161.069 373.471,161.054 373.481,161.039 373.49,161.024 373.499,161.009 373.508,160.994 373.517,160.979 373.527,160.964 373.536,160.949 373.545,160.934 373.554,160.919 373.563,160.904 373.572,160.889 373.582,160.874 373.591,160.859 373.6,160.844 373.609,160.829 373.618,160.814 373.628,160.799 373.637,160.785 373.646,160.77 373.655,160.755 373.664,160.74 373.674,160.725 373.683,160.71 373.692,160.695 373.701,160.68 373.71,160.665 373.72,160.65 373.729,160.635 373.738,160.62 373.747,160.605 373.756,160.591 373.765,160.576 373.775,160.561 373.784,160.546 373.793,160.531 373.802,160.516 373.811,160.501 373.821,160.486 373.83,160.471 373.839,160.457 373.848,160.442 373.857,160.427 373.867,160.412 373.876,160.397 373.885,160.382 373.894,160.367 373.903,160.353 373.912,160.338 373.922,160.323 373.931,160.308 373.94,160.293 373.949,160.278 373.958,160.263 373.968,160.249 373.977,160.234 373.986,160.219 373.995,160.204 374.004,160.189 374.014,160.174 374.023,160.16 374.032,160.145 374.041,160.13 374.05,160.115 374.06,160.1 374.069,160.086 374.078,160.071 374.087,160.056 374.096,160.041 374.105,160.026 374.115,160.011 374.124,159.997 374.133,159.982 374.142,159.967 374.151,159.952 374.161,159.938 374.17,159.923 374.179,159.908 374.188,159.893 374.197,159.878 374.207,159.864 374.216,159.849 374.225,159.834 374.234,159.819 374.243,159.805 374.252,159.79 374.262,159.775 374.271,159.76 374.28,159.746 374.289,159.731 374.298,159.716 374.308,159.701 374.317,159.687 374.326,159.672 374.335,159.657 374.344,159.642 374.354,159.628 374.363,159.613 374.372,159.598 374.381,159.583 374.39,159.569 374.4,159.554 374.409,159.539 374.418,159.525 374.427,159.51 374.436,159.495 374.445,159.481 374.455,159.466 374.464,159.451 374.473,159.436 374.482,159.422 374.491,159.407 374.501,159.392 374.51,159.378 374.519,159.363 374.528,159.348 374.537,159.334 374.547,159.319 374.556,159.304 374.565,159.29 374.574,159.275 374.583,159.26 374.592,159.246 374.602,159.231 374.611,159.216 374.62,159.202 374.629,159.187 374.638,159.172 374.648,159.158 374.657,159.143 374.666,159.128 374.675,159.114 374.684,159.099 374.694,159.085 374.703,159.07 374.712,159.055 374.721,159.041 374.73,159.026 374.74,159.011 374.749,158.997 374.758,158.982 374.767,158.968 374.776,158.953 374.785,158.938 374.795,158.924 374.804,158.909 374.813,158.895 374.822,158.88 374.831,158.865 374.841,158.851 374.85,158.836 374.859,158.822 374.868,158.807 374.877,158.792 374.887,158.778 374.896,158.763 374.905,158.749 374.914,158.734 374.923,158.72 374.932,158.705 374.942,158.69 374.951,158.676 374.96,158.661 374.969,158.647 374.978,158.632 374.988,158.618 374.997,158.603 375.006,158.589 375.015,158.574 375.024,158.559 375.034,158.545 375.043,158.53 375.052,158.516 375.061,158.501 375.07,158.487 375.08,158.472 375.089,158.458 375.098,158.443 375.107,158.429 375.116,158.414 375.125,158.4 375.135,158.385 375.144,158.371 375.153,158.356 375.162,158.342 375.171,158.327 375.181,158.313 375.19,158.298 375.199,158.284 375.208,158.269 375.217,158.255 375.227,158.24 375.236,158.226 375.245,158.211 375.254,158.197 375.263,158.182 375.272,158.168 375.282,158.153 375.291,158.139 375.3,158.125 375.309,158.11 375.318,158.096 375.328,158.081 375.337,158.067 375.346,158.052 375.355,158.038 375.364,158.023 375.374,158.009 375.383,157.994 375.392,157.98 375.401,157.966 375.41,157.951 375.42,157.937 375.429,157.922 375.438,157.908 375.447,157.893 375.456,157.879 375.465,157.865 375.475,157.85 375.484,157.836 375.493,157.821 375.502,157.807 375.511,157.793 375.521,157.778 375.53,157.764 375.539,157.749 375.548,157.735 375.557,157.721 375.567,157.706 375.576,157.692 375.585,157.678 375.594,157.663 375.603,157.649 375.612,157.634 375.622,157.62 375.631,157.606 375.64,157.591 375.649,157.577 375.658,157.563 375.668,157.548 375.677,157.534 375.686,157.519 375.695,157.505 375.704,157.491 375.714,157.476 375.723,157.462 375.732,157.448 375.741,157.433 375.75,157.419 375.76,157.405 375.769,157.39 375.778,157.376 375.787,157.362 375.796,157.347 375.805,157.333 375.815,157.319 375.824,157.304 375.833,157.29 375.842,157.276 375.851,157.262 375.861,157.247 375.87,157.233 375.879,157.219 375.888,157.204 375.897,157.19 375.907,157.176 375.916,157.161 375.925,157.147 375.934,157.133 375.943,157.119 375.953,157.104 375.962,157.09 375.971,157.076 375.98,157.062 375.989,157.047 375.998,157.033 376.008,157.019 376.017,157.004 376.026,156.99 376.035,156.976 376.044,156.962 376.054,156.947 376.063,156.933 376.072,156.919 376.081,156.905 376.09,156.89 376.1,156.876 376.109,156.862 376.118,156.848 376.127,156.834 376.136,156.819 376.145,156.805 376.155,156.791 376.164,156.777 376.173,156.762 376.182,156.748 376.191,156.734 376.201,156.72 376.21,156.706 376.219,156.691 376.228,156.677 376.237,156.663 376.247,156.649 376.256,156.635 376.265,156.62 376.274,156.606 376.283,156.592 376.293,156.578 376.302,156.564 376.311,156.549 376.32,156.535 376.329,156.521 376.338,156.507 376.348,156.493 376.357,156.479 376.366,156.464 376.375,156.45 376.384,156.436 376.394,156.422 376.403,156.408 376.412,156.394 376.421,156.379 376.43,156.365 376.44,156.351 376.449,156.337 376.458,156.323 376.467,156.309 376.476,156.295 376.485,156.28 376.495,156.266 376.504,156.252 376.513,156.238 376.522,156.224 376.531,156.21 376.541,156.196 376.55,156.182 376.559,156.167 376.568,156.153 376.577,156.139 376.587,156.125 376.596,156.111 376.605,156.097 376.614,156.083 376.623,156.069 376.633,156.055 376.642,156.041 376.651,156.026 376.66,156.012 376.669,155.998 376.678,155.984 376.688,155.97 376.697,155.956 376.706,155.942 376.715,155.928 376.724,155.914 376.734,155.9 376.743,155.886 376.752,155.872 376.761,155.858 376.77,155.844 376.78,155.83 376.789,155.815 376.798,155.801 376.807,155.787 376.816,155.773 376.825,155.759 376.835,155.745 376.844,155.731 376.853,155.717 376.862,155.703 376.871,155.689 376.881,155.675 376.89,155.661 376.899,155.647 376.908,155.633 376.917,155.619 376.927,155.605 376.936,155.591 376.945,155.577 376.954,155.563 376.963,155.549 376.973,155.535 376.982,155.521 376.991,155.507 377,155.493 377.009,155.479 377.018,155.465 377.028,155.451 377.037,155.437 377.046,155.423 377.055,155.409 377.064,155.395 377.074,155.381 377.083,155.367 377.092,155.353 377.101,155.339 377.11,155.325 377.12,155.311 377.129,155.297 377.138,155.283 377.147,155.269 377.156,155.255 377.165,155.242 377.175,155.228 377.184,155.214 377.193,155.2 377.202,155.186 377.211,155.172 377.221,155.158 377.23,155.144 377.239,155.13 377.248,155.116 377.257,155.102 377.267,155.088 377.276,155.074 377.285,155.06 377.294,155.046 377.303,155.033 377.313,155.019 377.322,155.005 377.331,154.991 377.34,154.977 377.349,154.963 377.358,154.949 377.368,154.935 377.377,154.921 377.386,154.907 377.395,154.894 377.404,154.88 377.414,154.866 377.423,154.852 377.432,154.838 377.441,154.824 377.45,154.81 377.46,154.796 377.469,154.783 377.478,154.769 377.487,154.755 377.496,154.741 377.505,154.727 377.515,154.713 377.524,154.699 377.533,154.686 377.542,154.672 377.551,154.658 377.561,154.644 377.57,154.63 377.579,154.616 377.588,154.603 377.597,154.589 377.607,154.575 377.616,154.561 377.625,154.547 377.634,154.533 377.643,154.52 377.653,154.506 377.662,154.492 377.671,154.478 377.68,154.464 377.689,154.45 377.698,154.437 377.708,154.423 377.717,154.409 377.726,154.395 377.735,154.381 377.744,154.368 377.754,154.354 377.763,154.34 377.772,154.326 377.781,154.313 377.79,154.299 377.8,154.285 377.809,154.271 377.818,154.257 377.827,154.244 377.836,154.23 377.845,154.216 377.855,154.202 377.864,154.189 377.873,154.175 377.882,154.161 377.891,154.147 377.901,154.134 377.91,154.12 377.919,154.106 377.928,154.092 377.937,154.079 377.947,154.065 377.956,154.051 377.965,154.037 377.974,154.024 377.983,154.01 377.993,153.996 378.002,153.982 378.011,153.969 378.02,153.955 378.029,153.941 378.038,153.928 378.048,153.914 378.057,153.9 378.066,153.886 378.075,153.873 378.084,153.859 378.094,153.845 378.103,153.832 378.112,153.818 378.121,153.804 378.13,153.79 378.14,153.777 378.149,153.763 378.158,153.749 378.167,153.736 378.176,153.722 378.185,153.708 378.195,153.695 378.204,153.681 378.213,153.667 378.222,153.654 378.231,153.64 378.241,153.626 378.25,153.613 378.259,153.599 378.268,153.585 378.277,153.572 378.287,153.558 378.296,153.544 378.305,153.531 378.314,153.517 378.323,153.503 378.333,153.49 378.342,153.476 378.351,153.463 378.36,153.449 378.369,153.435 378.378,153.422 378.388,153.408 378.397,153.394 378.406,153.381 378.415,153.367 378.424,153.354 378.434,153.34 378.443,153.326 378.452,153.313 378.461,153.299 378.47,153.286 378.48,153.272 378.489,153.258 378.498,153.245 378.507,153.231 378.516,153.218 378.526,153.204 378.535,153.19 378.544,153.177 378.553,153.163 378.562,153.15 378.571,153.136 378.581,153.122 378.59,153.109 378.599,153.095 378.608,153.082 378.617,153.068 378.627,153.055 378.636,153.041 378.645,153.028 378.654,153.014 378.663,153 378.673,152.987 378.682,152.973 378.691,152.96 378.7,152.946 378.709,152.933 378.718,152.919 378.728,152.906 378.737,152.892 378.746,152.879 378.755,152.865 378.764,152.851 378.774,152.838 378.783,152.824 378.792,152.811 378.801,152.797 378.81,152.784 378.82,152.77 378.829,152.757 378.838,152.743 378.847,152.73 378.856,152.716 378.866,152.703 378.875,152.689 378.884,152.676 378.893,152.662 378.902,152.649 378.911,152.635 378.921,152.622 378.93,152.608 378.939,152.595 378.948,152.581 378.957,152.568 378.967,152.554 378.976,152.541 378.985,152.528 378.994,152.514 379.003,152.501 379.013,152.487 379.022,152.474 379.031,152.46 379.04,152.447 379.049,152.433 379.058,152.42 379.068,152.406 379.077,152.393 379.086,152.38 379.095,152.366 379.104,152.353 379.114,152.339 379.123,152.326 379.132,152.312 379.141,152.299 379.15,152.285 379.16,152.272 379.169,152.259 379.178,152.245 379.187,152.232 379.196,152.218 379.206,152.205 379.215,152.192 379.224,152.178 379.233,152.165 379.242,152.151 379.251,152.138 379.261,152.125 379.27,152.111 379.279,152.098 379.288,152.084 379.297,152.071 379.307,152.058 379.316,152.044 379.325,152.031 379.334,152.017 379.343,152.004 379.353,151.991 379.362,151.977 379.371,151.964 379.38,151.951 379.389,151.937 379.398,151.924 379.408,151.91 379.417,151.897 379.426,151.884 379.435,151.87 379.444,151.857 379.454,151.844 379.463,151.83 379.472,151.817 379.481,151.804 379.49,151.79 379.5,151.777 379.509,151.764 379.518,151.75 379.527,151.737 379.536,151.724 379.546,151.71 379.555,151.697 379.564,151.684 379.573,151.67 379.582,151.657 379.591,151.644 379.601,151.63 379.61,151.617 379.619,151.604 379.628,151.59 379.637,151.577 379.647,151.564 379.656,151.551 379.665,151.537 379.674,151.524 379.683,151.511 379.693,151.497 379.702,151.484 379.711,151.471 379.72,151.458 379.729,151.444 379.738,151.431 379.748,151.418 379.757,151.404 379.766,151.391 379.775,151.378 379.784,151.365 379.794,151.351 379.803,151.338 379.812,151.325 379.821,151.312 379.83,151.298 379.84,151.285 379.849,151.272 379.858,151.259 379.867,151.245 379.876,151.232 379.886,151.219 379.895,151.206 379.904,151.192 379.913,151.179 379.922,151.166 379.931,151.153 379.941,151.139 379.95,151.126 379.959,151.113 379.968,151.1 379.977,151.087 379.987,151.073 379.996,151.06 380.005,151.047 380.014,151.034 380.023,151.021 380.033,151.007 380.042,150.994 380.051,150.981 380.06,150.968 380.069,150.955 380.078,150.941 380.088,150.928 380.097,150.915 380.106,150.902 380.115,150.889 380.124,150.875 380.134,150.862 380.143,150.849 380.152,150.836 380.161,150.823 380.17,150.81 380.18,150.796 380.189,150.783 380.198,150.77 380.207,150.757 380.216,150.744 380.226,150.731 380.235,150.717 380.244,150.704 380.253,150.691 380.262,150.678 380.271,150.665 380.281,150.652 380.29,150.639 380.299,150.625 380.308,150.612 380.317,150.599 380.327,150.586 380.336,150.573 380.345,150.56 380.354,150.547 380.363,150.534 380.373,150.52 380.382,150.507 380.391,150.494 380.4,150.481 380.409,150.468 380.418,150.455 380.428,150.442 380.437,150.429 380.446,150.416 380.455,150.402 380.464,150.389 380.474,150.376 380.483,150.363 380.492,150.35 380.501,150.337 380.51,150.324 380.52,150.311 380.529,150.298 380.538,150.285 380.547,150.272 380.556,150.258 380.566,150.245 380.575,150.232 380.584,150.219 380.593,150.206 380.602,150.193 380.611,150.18 380.621,150.167 380.63,150.154 380.639,150.141 380.648,150.128 380.657,150.115 380.667,150.102 380.676,150.089 380.685,150.076 380.694,150.063 380.703,150.05 380.713,150.037 380.722,150.024 380.731,150.011 380.74,149.998 380.749,149.984 380.758,149.971 380.768,149.958 380.777,149.945 380.786,149.932 380.795,149.919 380.804,149.906 380.814,149.893 380.823,149.88 380.832,149.867 380.841,149.854 380.85,149.841 380.86,149.828 380.869,149.815 380.878,149.802 380.887,149.789 380.896,149.776 380.906,149.763 380.915,149.75 380.924,149.737 380.933,149.724 380.942,149.711 380.951,149.699 380.961,149.686 380.97,149.673 380.979,149.66 380.988,149.647 380.997,149.634 381.007,149.621 381.016,149.608 381.025,149.595 381.034,149.582 381.043,149.569 381.053,149.556 381.062,149.543 381.071,149.53 381.08,149.517 381.089,149.504 381.099,149.491 381.108,149.478 381.117,149.465 381.126,149.452 381.135,149.439 381.144,149.427 381.154,149.414 381.163,149.401 381.172,149.388 381.181,149.375 381.19,149.362 381.2,149.349 381.209,149.336 381.218,149.323 381.227,149.31 381.236,149.297 381.246,149.284 381.255,149.272 381.264,149.259 381.273,149.246 381.282,149.233 381.291,149.22 381.301,149.207 381.31,149.194 381.319,149.181 381.328,149.168 381.337,149.156 381.347,149.143 381.356,149.13 381.365,149.117 381.374,149.104 381.383,149.091 381.393,149.078 381.402,149.065 381.411,149.053 381.42,149.04 381.429,149.027 381.439,149.014 381.448,149.001 381.457,148.988 381.466,148.975 381.475,148.963 381.484,148.95 381.494,148.937 381.503,148.924 381.512,148.911 381.521,148.898 381.53,148.886 381.54,148.873 381.549,148.86 381.558,148.847 381.567,148.834 381.576,148.821 381.586,148.809 381.595,148.796 381.604,148.783 381.613,148.77 381.622,148.757 381.631,148.745 381.641,148.732 381.65,148.719 381.659,148.706 381.668,148.693 381.677,148.681 381.687,148.668 381.696,148.655 381.705,148.642 381.714,148.629 381.723,148.617 381.733,148.604 381.742,148.591 381.751,148.578 381.76,148.565 381.769,148.553 381.779,148.54 381.788,148.527 381.797,148.514 381.806,148.502 381.815,148.489 381.824,148.476 381.834,148.463 381.843,148.451 381.852,148.438 381.861,148.425 381.87,148.412 381.88,148.4 381.889,148.387 381.898,148.374 381.907,148.361 381.916,148.349 381.926,148.336 381.935,148.323 381.944,148.31 381.953,148.298 381.962,148.285 381.971,148.272 381.981,148.259 381.99,148.247 381.999,148.234 382.008,148.221 382.017,148.209 382.027,148.196 382.036,148.183 382.045,148.17 382.054,148.158 382.063,148.145 382.073,148.132 382.082,148.12 382.091,148.107 382.1,148.094 382.109,148.082 382.119,148.069 382.128,148.056 382.137,148.043 382.146,148.031 382.155,148.018 382.164,148.005 382.174,147.993 382.183,147.98 382.192,147.967 382.201,147.955 382.21,147.942 382.22,147.929 382.229,147.917 382.238,147.904 382.247,147.891 382.256,147.879 382.266,147.866 382.275,147.853 382.284,147.841 382.293,147.828 382.302,147.815 382.311,147.803 382.321,147.79 382.33,147.778 382.339,147.765 382.348,147.752 382.357,147.74 382.367,147.727 382.376,147.714 382.385,147.702 382.394,147.689 382.403,147.676 382.413,147.664 382.422,147.651 382.431,147.639 382.44,147.626 382.449,147.613 382.459,147.601 382.468,147.588 382.477,147.576 382.486,147.563 382.495,147.55 382.504,147.538 382.514,147.525 382.523,147.513 382.532,147.5 382.541,147.487 382.55,147.475 382.56,147.462 382.569,147.45 382.578,147.437 382.587,147.424 382.596,147.412 382.606,147.399 382.615,147.387 382.624,147.374 382.633,147.362 382.642,147.349 382.651,147.336 382.661,147.324 382.67,147.311 382.679,147.299 382.688,147.286 382.697,147.274 382.707,147.261 382.716,147.249 382.725,147.236 382.734,147.223 382.743,147.211 382.753,147.198 382.762,147.186 382.771,147.173 382.78,147.161 382.789,147.148 382.799,147.136 382.808,147.123 382.817,147.111 382.826,147.098 382.835,147.086 382.844,147.073 382.854,147.061 382.863,147.048 382.872,147.036 382.881,147.023 382.89,147.011 382.9,146.998 382.909,146.985 382.918,146.973 382.927,146.96 382.936,146.948 382.946,146.936 382.955,146.923 382.964,146.911 382.973,146.898 382.982,146.886 382.991,146.873 383.001,146.861 383.01,146.848 383.019,146.836 383.028,146.823 383.037,146.811 383.047,146.798 383.056,146.786 383.065,146.773 383.074,146.761 383.083,146.748 383.093,146.736 383.102,146.723 383.111,146.711 383.12,146.698 383.129,146.686 383.139,146.674 383.148,146.661 383.157,146.649 383.166,146.636 383.175,146.624 383.184,146.611 383.194,146.599 383.203,146.586 383.212,146.574 383.221,146.562 383.23,146.549 383.24,146.537 383.249,146.524 383.258,146.512 383.267,146.499 383.276,146.487 383.286,146.475 383.295,146.462 383.304,146.45 383.313,146.437 383.322,146.425 383.332,146.413 383.341,146.4 383.35,146.388 383.359,146.375 383.368,146.363 383.377,146.351 383.387,146.338 383.396,146.326 383.405,146.313 383.414,146.301 383.423,146.289 383.433,146.276 383.442,146.264 383.451,146.252 383.46,146.239 383.469,146.227 383.479,146.214 383.488,146.202 383.497,146.19 383.506,146.177 383.515,146.165 383.524,146.153 383.534,146.14 383.543,146.128 383.552,146.116 383.561,146.103 383.57,146.091 383.58,146.078 383.589,146.066 383.598,146.054 383.607,146.041 383.616,146.029 383.626,146.017 383.635,146.004 383.644,145.992 383.653,145.98 383.662,145.967 383.672,145.955 383.681,145.943 383.69,145.93 383.699,145.918 383.708,145.906 383.717,145.893 383.727,145.881 383.736,145.869 383.745,145.857 383.754,145.844 383.763,145.832 383.773,145.82 383.782,145.807 383.791,145.795 383.8,145.783 383.809,145.77 383.819,145.758 383.828,145.746 383.837,145.734 383.846,145.721 383.855,145.709 383.864,145.697 383.874,145.684 383.883,145.672 383.892,145.66 383.901,145.648 383.91,145.635 383.92,145.623 383.929,145.611 383.938,145.599 383.947,145.586 383.956,145.574 383.966,145.562 383.975,145.549 383.984,145.537 383.993,145.525 384.002,145.513 384.012,145.5 384.021,145.488 384.03,145.476 384.039,145.464 384.048,145.452 384.057,145.439 384.067,145.427 384.076,145.415 384.085,145.403 384.094,145.39 384.103,145.378 384.113,145.366 384.122,145.354 384.131,145.341 384.14,145.329 384.149,145.317 384.159,145.305 384.168,145.293 384.177,145.28 384.186,145.268 384.195,145.256 384.204,145.244 384.214,145.232 384.223,145.219 384.232,145.207 384.241,145.195 384.25,145.183 384.26,145.171 384.269,145.158 384.278,145.146 384.287,145.134 384.296,145.122 384.306,145.11 384.315,145.097 384.324,145.085 384.333,145.073 384.342,145.061 384.352,145.049 384.361,145.037 384.37,145.024 384.379,145.012 384.388,145 384.397,144.988 384.407,144.976 384.416,144.964 384.425,144.951 384.434,144.939 384.443,144.927 384.453,144.915 384.462,144.903 384.471,144.891 384.48,144.879 384.489,144.866 384.499,144.854 384.508,144.842 384.517,144.83 384.526,144.818 384.535,144.806 384.544,144.794 384.554,144.781 384.563,144.769 384.572,144.757 384.581,144.745 384.59,144.733 384.6,144.721 384.609,144.709 384.618,144.697 384.627,144.685 384.636,144.672 384.646,144.66 384.655,144.648 384.664,144.636 384.673,144.624 384.682,144.612 384.692,144.6 384.701,144.588 384.71,144.576 384.719,144.564 384.728,144.552 384.737,144.539 384.747,144.527 384.756,144.515 384.765,144.503 384.774,144.491 384.783,144.479 384.793,144.467 384.802,144.455 384.811,144.443 384.82,144.431 384.829,144.419 384.839,144.407 384.848,144.395 384.857,144.383 384.866,144.37 384.875,144.358 384.884,144.346 384.894,144.334 384.903,144.322 384.912,144.31 384.921,144.298 384.93,144.286 384.94,144.274 384.949,144.262 384.958,144.25 384.967,144.238 384.976,144.226 384.986,144.214 384.995,144.202 385.004,144.19 385.013,144.178 385.022,144.166 385.032,144.154 385.041,144.142 385.05,144.13 385.059,144.118 385.068,144.106 385.077,144.094 385.087,144.082 385.096,144.07 385.105,144.058 385.114,144.046 385.123,144.034 385.133,144.022 385.142,144.01 385.151,143.998 385.16,143.986 385.169,143.974 385.179,143.962 385.188,143.95 385.197,143.938 385.206,143.926 385.215,143.914 385.224,143.902 385.234,143.89 385.243,143.878 385.252,143.866 385.261,143.854 385.27,143.842 385.28,143.83 385.289,143.818 385.298,143.806 385.307,143.794 385.316,143.782 385.326,143.77 385.335,143.758 385.344,143.746 385.353,143.734 385.362,143.723 385.372,143.711 385.381,143.699 385.39,143.687 385.399,143.675 385.408,143.663 385.417,143.651 385.427,143.639 385.436,143.627 385.445,143.615 385.454,143.603 385.463,143.591 385.473,143.579 385.482,143.567 385.491,143.556 385.5,143.544 385.509,143.532 385.519,143.52 385.528,143.508 385.537,143.496 385.546,143.484 385.555,143.472 385.564,143.46 385.574,143.448 385.583,143.436 385.592,143.425 385.601,143.413 385.61,143.401 385.62,143.389 385.629,143.377 385.638,143.365 385.647,143.353 385.656,143.341 385.666,143.329 385.675,143.318 385.684,143.306 385.693,143.294 385.702,143.282 385.712,143.27 385.721,143.258 385.73,143.246 385.739,143.235 385.748,143.223 385.757,143.211 385.767,143.199 385.776,143.187 385.785,143.175 385.794,143.163 385.803,143.152 385.813,143.14 385.822,143.128 385.831,143.116 385.84,143.104 385.849,143.092 385.859,143.081 385.868,143.069 385.877,143.057 385.886,143.045 385.895,143.033 385.905,143.021 385.914,143.01 385.923,142.998 385.932,142.986 385.941,142.974 385.95,142.962 385.96,142.95 385.969,142.939 385.978,142.927 385.987,142.915 385.996,142.903 386.006,142.891 386.015,142.88 386.024,142.868 386.033,142.856 386.042,142.844 386.052,142.832 386.061,142.821 386.07,142.809 386.079,142.797 386.088,142.785 386.097,142.774 386.107,142.762 386.116,142.75 386.125,142.738 386.134,142.726 386.143,142.715 386.153,142.703 386.162,142.691 386.171,142.679 386.18,142.668 386.189,142.656 386.199,142.644 386.208,142.632 386.217,142.621 386.226,142.609 386.235,142.597 386.245,142.585 386.254,142.574 386.263,142.562 386.272,142.55 386.281,142.538 386.29,142.527 386.3,142.515 386.309,142.503 386.318,142.491 386.327,142.48 386.336,142.468 386.346,142.456 386.355,142.444 386.364,142.433 386.373,142.421 386.382,142.409 386.392,142.398 386.401,142.386 386.41,142.374 386.419,142.362 386.428,142.351 386.437,142.339 386.447,142.327 386.456,142.316 386.465,142.304 386.474,142.292 386.483,142.28 386.493,142.269 386.502,142.257 386.511,142.245 386.52,142.234 386.529,142.222 386.539,142.21 386.548,142.199 386.557,142.187 386.566,142.175 386.575,142.164 386.585,142.152 386.594,142.14 386.603,142.129 386.612,142.117 386.621,142.105 386.63,142.094 386.64,142.082 386.649,142.07 386.658,142.059 386.667,142.047 386.676,142.035 386.686,142.024 386.695,142.012 386.704,142 386.713,141.989 386.722,141.977 386.732,141.965 386.741,141.954 386.75,141.942 386.759,141.93 386.768,141.919 386.777,141.907 386.787,141.895 386.796,141.884 386.805,141.872 386.814,141.861 386.823,141.849 386.833,141.837 386.842,141.826 386.851,141.814 386.86,141.802 386.869,141.791 386.879,141.779 386.888,141.768 386.897,141.756 386.906,141.744 386.915,141.733 386.925,141.721 386.934,141.71 386.943,141.698 386.952,141.686 386.961,141.675 386.97,141.663 386.98,141.652 386.989,141.64 386.998,141.628 387.007,141.617 387.016,141.605 387.026,141.594 387.035,141.582 387.044,141.571 387.053,141.559 387.062,141.547 387.072,141.536 387.081,141.524 387.09,141.513 387.099,141.501 387.108,141.49 387.117,141.478 387.127,141.466 387.136,141.455 387.145,141.443 387.154,141.432 387.163,141.42 387.173,141.409 387.182,141.397 387.191,141.386 387.2,141.374 387.209,141.362 387.219,141.351 387.228,141.339 387.237,141.328 387.246,141.316 387.255,141.305 387.265,141.293 387.274,141.282 387.283,141.27 387.292,141.259 387.301,141.247 387.31,141.236 387.32,141.224 387.329,141.213 387.338,141.201 387.347,141.189 387.356,141.178 387.366,141.166 387.375,141.155 387.384,141.143 387.393,141.132 387.402,141.12 387.412,141.109 387.421,141.097 387.43,141.086 387.439,141.074 387.448,141.063 387.457,141.051 387.467,141.04 387.476,141.028 387.485,141.017 387.494,141.006 387.503,140.994 387.513,140.983 387.522,140.971 387.531,140.96 387.54,140.948 387.549,140.937 387.559,140.925 387.568,140.914 387.577,140.902 387.586,140.891 387.595,140.879 387.605,140.868 387.614,140.856 387.623,140.845 387.632,140.833 387.641,140.822 387.65,140.811 387.66,140.799 387.669,140.788 387.678,140.776 387.687,140.765 387.696,140.753 387.706,140.742 387.715,140.73 387.724,140.719 387.733,140.708 387.742,140.696 387.752,140.685 387.761,140.673 387.77,140.662 387.779,140.65 387.788,140.639 387.797,140.628 387.807,140.616 387.816,140.605 387.825,140.593 387.834,140.582 387.843,140.571 387.853,140.559 387.862,140.548 387.871,140.536 387.88,140.525 387.889,140.514 387.899,140.502 387.908,140.491 387.917,140.479 387.926,140.468 387.935,140.457 387.945,140.445 387.954,140.434 387.963,140.422 387.972,140.411 387.981,140.4 387.99,140.388 388,140.377 388.009,140.366 388.018,140.354 388.027,140.343 388.036,140.331 388.046,140.32 388.055,140.309 388.064,140.297 388.073,140.286 388.082,140.275 388.092,140.263 388.101,140.252 388.11,140.24 388.119,140.229 388.128,140.218 388.137,140.206 388.147,140.195 388.156,140.184 388.165,140.172 388.174,140.161 388.183,140.15 388.193,140.138 388.202,140.127 388.211,140.116 388.22,140.104 388.229,140.093 388.239,140.082 388.248,140.07 388.257,140.059 388.266,140.048 388.275,140.036 388.285,140.025 388.294,140.014 388.303,140.002 388.312,139.991 388.321,139.98 388.33,139.969 388.34,139.957 388.349,139.946 388.358,139.935 388.367,139.923 388.376,139.912 388.386,139.901 388.395,139.889 388.404,139.878 388.413,139.867 388.422,139.856 388.432,139.844 388.441,139.833 388.45,139.822 388.459,139.81 388.468,139.799 388.478,139.788 388.487,139.777 388.496,139.765 388.505,139.754 388.514,139.743 388.523,139.731 388.533,139.72 388.542,139.709 388.551,139.698 388.56,139.686 388.569,139.675 388.579,139.664 388.588,139.653 388.597,139.641 388.606,139.63 388.615,139.619 388.625,139.608 388.634,139.596 388.643,139.585 388.652,139.574 388.661,139.563 388.67,139.551 388.68,139.54 388.689,139.529 388.698,139.518 388.707,139.507 388.716,139.495 388.726,139.484 388.735,139.473 388.744,139.462 388.753,139.45 388.762,139.439 388.772,139.428 388.781,139.417 388.79,139.406 388.799,139.394 388.808,139.383 388.818,139.372 388.827,139.361 388.836,139.349 388.845,139.338 388.854,139.327 388.863,139.316 388.873,139.305 388.882,139.293 388.891,139.282 388.9,139.271 388.909,139.26 388.919,139.249 388.928,139.238 388.937,139.226 388.946,139.215 388.955,139.204 388.965,139.193 388.974,139.182 388.983,139.17 388.992,139.159 389.001,139.148 389.01,139.137 389.02,139.126 389.029,139.115 389.038,139.103 389.047,139.092 389.056,139.081 389.066,139.07 389.075,139.059 389.084,139.048 389.093,139.036 389.102,139.025 389.112,139.014 389.121,139.003 389.13,138.992 389.139,138.981 389.148,138.97 389.158,138.958 389.167,138.947 389.176,138.936 389.185,138.925 389.194,138.914 389.203,138.903 389.213,138.892 389.222,138.881 389.231,138.869 389.24,138.858 389.249,138.847 389.259,138.836 389.268,138.825 389.277,138.814 389.286,138.803 389.295,138.792 389.305,138.78 389.314,138.769 389.323,138.758 389.332,138.747 389.341,138.736 389.35,138.725 389.36,138.714 389.369,138.703 389.378,138.692 389.387,138.681 389.396,138.669 389.406,138.658 389.415,138.647 389.424,138.636 389.433,138.625 389.442,138.614 389.452,138.603 389.461,138.592 389.47,138.581 389.479,138.57 389.488,138.559 389.498,138.548 389.507,138.536 389.516,138.525 389.525,138.514 389.534,138.503 389.543,138.492 389.553,138.481 389.562,138.47 389.571,138.459 389.58,138.448 389.589,138.437 389.599,138.426 389.608,138.415 389.617,138.404 389.626,138.393 389.635,138.382 389.645,138.371 389.654,138.36 389.663,138.349 389.672,138.338 389.681,138.327 389.69,138.315 389.7,138.304 389.709,138.293 389.718,138.282 389.727,138.271 389.736,138.26 389.746,138.249 389.755,138.238 389.764,138.227 389.773,138.216 389.782,138.205 389.792,138.194 389.801,138.183 389.81,138.172 389.819,138.161 389.828,138.15 389.838,138.139 389.847,138.128 389.856,138.117 389.865,138.106 389.874,138.095 389.883,138.084 389.893,138.073 389.902,138.062 389.911,138.051 389.92,138.04 389.929,138.029 389.939,138.018 389.948,138.007 389.957,137.996 389.966,137.985 389.975,137.974 389.985,137.963 389.994,137.952 390.003,137.941 390.012,137.931 390.021,137.92 390.03,137.909 390.04,137.898 390.049,137.887 390.058,137.876 390.067,137.865 390.076,137.854 390.086,137.843 390.095,137.832 390.104,137.821 390.113,137.81 390.122,137.799 390.132,137.788 390.141,137.777 390.15,137.766 390.159,137.755 390.168,137.744 390.178,137.733 390.187,137.722 390.196,137.712 390.205,137.701 390.214,137.69 390.223,137.679 390.233,137.668 390.242,137.657 390.251,137.646 390.26,137.635 390.269,137.624 390.279,137.613 390.288,137.602 390.297,137.591 390.306,137.58 390.315,137.57 390.325,137.559 390.334,137.548 390.343,137.537 390.352,137.526 390.361,137.515 390.37,137.504 390.38,137.493 390.389,137.482 390.398,137.471 390.407,137.461 390.416,137.45 390.426,137.439 390.435,137.428 390.444,137.417 390.453,137.406 390.462,137.395 390.472,137.384 390.481,137.374 390.49,137.363 390.499,137.352 390.508,137.341 390.518,137.33 390.527,137.319 390.536,137.308 390.545,137.297 390.554,137.287 390.563,137.276 390.573,137.265 390.582,137.254 390.591,137.243 390.6,137.232 390.609,137.221 390.619,137.211 390.628,137.2 390.637,137.189 390.646,137.178 390.655,137.167 390.665,137.156 390.674,137.146 390.683,137.135 390.692,137.124 390.701,137.113 390.711,137.102 390.72,137.091 390.729,137.081 390.738,137.07 390.747,137.059 390.756,137.048 390.766,137.037 390.775,137.026 390.784,137.016 390.793,137.005 390.802,136.994 390.812,136.983 390.821,136.972 390.83,136.962 390.839,136.951 390.848,136.94 390.858,136.929 390.867,136.918 390.876,136.908 390.885,136.897 390.894,136.886 390.903,136.875 390.913,136.864 390.922,136.854 390.931,136.843 390.94,136.832 390.949,136.821 390.959,136.81 390.968,136.8 390.977,136.789 390.986,136.778 390.995,136.767 391.005,136.757 391.014,136.746 391.023,136.735 391.032,136.724 391.041,136.713 391.051,136.703 391.06,136.692 391.069,136.681 391.078,136.67 391.087,136.66 391.096,136.649 391.106,136.638 391.115,136.627 391.124,136.617 391.133,136.606 391.142,136.595 391.152,136.584 391.161,136.574 391.17,136.563 391.179,136.552 391.188,136.541 391.198,136.531 391.207,136.52 391.216,136.509 391.225,136.498 391.234,136.488 391.243,136.477 391.253,136.466 391.262,136.456 391.271,136.445 391.28,136.434 391.289,136.423 391.299,136.413 391.308,136.402 391.317,136.391 391.326,136.381 391.335,136.37 391.345,136.359 391.354,136.348 391.363,136.338 391.372,136.327 391.381,136.316 391.391,136.306 391.4,136.295 391.409,136.284 391.418,136.274 391.427,136.263 391.436,136.252 391.446,136.241 391.455,136.231 391.464,136.22 391.473,136.209 391.482,136.199 391.492,136.188 391.501,136.177 391.51,136.167 391.519,136.156 391.528,136.145 391.538,136.135 391.547,136.124 391.556,136.113 391.565,136.103 391.574,136.092 391.583,136.081 391.593,136.071 391.602,136.06 391.611,136.049 391.62,136.039 391.629,136.028 391.639,136.017 391.648,136.007 391.657,135.996 391.666,135.985 391.675,135.975 391.685,135.964 391.694,135.954 391.703,135.943 391.712,135.932 391.721,135.922 391.731,135.911 391.74,135.9 391.749,135.89 391.758,135.879 391.767,135.868 391.776,135.858 391.786,135.847 391.795,135.837 391.804,135.826 391.813,135.815 391.822,135.805 391.832,135.794 391.841,135.784 391.85,135.773 391.859,135.762 391.868,135.752 391.878,135.741 391.887,135.73 391.896,135.72 391.905,135.709 391.914,135.699 391.923,135.688 391.933,135.677 391.942,135.667 391.951,135.656 391.96,135.646 391.969,135.635 391.979,135.625 391.988,135.614 391.997,135.603 392.006,135.593 392.015,135.582 392.025,135.572 392.034,135.561 392.043,135.55 392.052,135.54 392.061,135.529 392.071,135.519 392.08,135.508 392.089,135.498 392.098,135.487 392.107,135.476 392.116,135.466 392.126,135.455 392.135,135.445 392.144,135.434 392.153,135.424 392.162,135.413 392.172,135.403 392.181,135.392 392.19,135.381 392.199,135.371 392.208,135.36 392.218,135.35 392.227,135.339 392.236,135.329 392.245,135.318 392.254,135.308 392.263,135.297 392.273,135.287 392.282,135.276 392.291,135.266 392.3,135.255 392.309,135.245 392.319,135.234 392.328,135.223 392.337,135.213 392.346,135.202 392.355,135.192 392.365,135.181 392.374,135.171 392.383,135.16 392.392,135.15 392.401,135.139 392.411,135.129 392.42,135.118 392.429,135.108 392.438,135.097 392.447,135.087 392.456,135.076 392.466,135.066 392.475,135.055 392.484,135.045 392.493,135.034 392.502,135.024 392.512,135.013 392.521,135.003 392.53,134.992 392.539,134.982 392.548,134.971 392.558,134.961 392.567,134.951 392.576,134.94 392.585,134.93 392.594,134.919 392.603,134.909 392.613,134.898 392.622,134.888 392.631,134.877 392.64,134.867 392.649,134.856 392.659,134.846 392.668,134.835 392.677,134.825 392.686,134.814 392.695,134.804 392.705,134.794 392.714,134.783 392.723,134.773 392.732,134.762 392.741,134.752 392.751,134.741 392.76,134.731 392.769,134.72 392.778,134.71 392.787,134.7 392.796,134.689 392.806,134.679 392.815,134.668 392.824,134.658 392.833,134.647 392.842,134.637 392.852,134.627 392.861,134.616 392.87,134.606 392.879,134.595 392.888,134.585 392.898,134.575 392.907,134.564 392.916,134.554 392.925,134.543 392.934,134.533 392.943,134.522 392.953,134.512 392.962,134.502 392.971,134.491 392.98,134.481 392.989,134.47 392.999,134.46 393.008,134.45 393.017,134.439 393.026,134.429 393.035,134.418 393.045,134.408 393.054,134.398 393.063,134.387 393.072,134.377 393.081,134.367 393.091,134.356 393.1,134.346 393.109,134.335 393.118,134.325 393.127,134.315 393.136,134.304 393.146,134.294 393.155,134.284 393.164,134.273 393.173,134.263 393.182,134.252 393.192,134.242 393.201,134.232 393.21,134.221 393.219,134.211 393.228,134.201 393.238,134.19 393.247,134.18 393.256,134.17 393.265,134.159 393.274,134.149 393.284,134.139 393.293,134.128 393.302,134.118 393.311,134.108 393.32,134.097 393.329,134.087 393.339,134.077 393.348,134.066 393.357,134.056 393.366,134.046 393.375,134.035 393.385,134.025 393.394,134.015 393.403,134.004 393.412,133.994 393.421,133.984 393.431,133.973 393.44,133.963 393.449,133.953 393.458,133.942 393.467,133.932 393.476,133.922 393.486,133.911 393.495,133.901 393.504,133.891 393.513,133.881 393.522,133.87 393.532,133.86 393.541,133.85 393.55,133.839 393.559,133.829 393.568,133.819 393.578,133.808 393.587,133.798 393.596,133.788 393.605,133.778 393.614,133.767 393.624,133.757 393.633,133.747 393.642,133.736 393.651,133.726 393.66,133.716 393.669,133.706 393.679,133.695 393.688,133.685 393.697,133.675 393.706,133.665 393.715,133.654 393.725,133.644 393.734,133.634 393.743,133.624 393.752,133.613 393.761,133.603 393.771,133.593 393.78,133.583 393.789,133.572 393.798,133.562 393.807,133.552 393.816,133.542 393.826,133.531 393.835,133.521 393.844,133.511 393.853,133.501 393.862,133.49 393.872,133.48 393.881,133.47 393.89,133.46 393.899,133.449 393.908,133.439 393.918,133.429 393.927,133.419 393.936,133.408 393.945,133.398 393.954,133.388 393.964,133.378 393.973,133.368 393.982,133.357 393.991,133.347 394,133.337 394.009,133.327 394.019,133.317 394.028,133.306 394.037,133.296 394.046,133.286 394.055,133.276 394.065,133.265 394.074,133.255 394.083,133.245 394.092,133.235 394.101,133.225 394.111,133.215 394.12,133.204 394.129,133.194 394.138,133.184 394.147,133.174 394.156,133.164 394.166,133.153 394.175,133.143 394.184,133.133 394.193,133.123 394.202,133.113 394.212,133.102 394.221,133.092 394.23,133.082 394.239,133.072 394.248,133.062 394.258,133.052 394.267,133.041 394.276,133.031 394.285,133.021 394.294,133.011 394.304,133.001 394.313,132.991 394.322,132.981 394.331,132.97 394.34,132.96 394.349,132.95 394.359,132.94 394.368,132.93 394.377,132.92 394.386,132.909 394.395,132.899 394.405,132.889 394.414,132.879 394.423,132.869 394.432,132.859 394.441,132.849 394.451,132.838 394.46,132.828 394.469,132.818 394.478,132.808 394.487,132.798 394.496,132.788 394.506,132.778 394.515,132.768 394.524,132.757 394.533,132.747 394.542,132.737 394.552,132.727 394.561,132.717 394.57,132.707 394.579,132.697 394.588,132.687 394.598,132.677 394.607,132.666 394.616,132.656 394.625,132.646 394.634,132.636 394.644,132.626 394.653,132.616 394.662,132.606 394.671,132.596 394.68,132.586 394.689,132.576 394.699,132.566 394.708,132.555 394.717,132.545 394.726,132.535 394.735,132.525 394.745,132.515 394.754,132.505 394.763,132.495 394.772,132.485 394.781,132.475 394.791,132.465 394.8,132.455 394.809,132.445 394.818,132.435 394.827,132.424 394.836,132.414 394.846,132.404 394.855,132.394 394.864,132.384 394.873,132.374 394.882,132.364 394.892,132.354 394.901,132.344 394.91,132.334 394.919,132.324 394.928,132.314 394.938,132.304 394.947,132.294 394.956,132.284 394.965,132.274 394.974,132.264 394.984,132.254 394.993,132.244 395.002,132.234 395.011,132.223 395.02,132.213 395.029,132.203 395.039,132.193 395.048,132.183 395.057,132.173 395.066,132.163 395.075,132.153 395.085,132.143 395.094,132.133 395.103,132.123 395.112,132.113 395.121,132.103 395.131,132.093 395.14,132.083 395.149,132.073 395.158,132.063 395.167,132.053 395.176,132.043 395.186,132.033 395.195,132.023 395.204,132.013 395.213,132.003 395.222,131.993 395.232,131.983 395.241,131.973 395.25,131.963 395.259,131.953 395.268,131.943 395.278,131.933 395.287,131.923 395.296,131.913 395.305,131.903 395.314,131.893 395.324,131.883 395.333,131.873 395.342,131.863 395.351,131.853 395.36,131.843 395.369,131.833 395.379,131.823 395.388,131.814 395.397,131.804 395.406,131.794 395.415,131.784 395.425,131.774 395.434,131.764 395.443,131.754 395.452,131.744 395.461,131.734 395.471,131.724 395.48,131.714 395.489,131.704 395.498,131.694 395.507,131.684 395.516,131.674 395.526,131.664 395.535,131.654 395.544,131.644 395.553,131.634 395.562,131.624 395.572,131.615 395.581,131.605 395.59,131.595 395.599,131.585 395.608,131.575 395.618,131.565 395.627,131.555 395.636,131.545 395.645,131.535 395.654,131.525 395.664,131.515 395.673,131.505 395.682,131.495 395.691,131.485 395.7,131.476 395.709,131.466 395.719,131.456 395.728,131.446 395.737,131.436 395.746,131.426 395.755,131.416 395.765,131.406 395.774,131.396 395.783,131.386 395.792,131.377 395.801,131.367 395.811,131.357 395.82,131.347 395.829,131.337 395.838,131.327 395.847,131.317 395.857,131.307 395.866,131.297 395.875,131.288 395.884,131.278 395.893,131.268 395.902,131.258 395.912,131.248 395.921,131.238 395.93,131.228 395.939,131.218 395.948,131.209 395.958,131.199 395.967,131.189 395.976,131.179 395.985,131.169 395.994,131.159 396.004,131.149 396.013,131.139 396.022,131.13 396.031,131.12 396.04,131.11 396.049,131.1 396.059,131.09 396.068,131.08 396.077,131.071 396.086,131.061 396.095,131.051 396.105,131.041 396.114,131.031 396.123,131.021 396.132,131.011 396.141,131.002 396.151,130.992 396.16,130.982 396.169,130.972 396.178,130.962 396.187,130.952 396.197,130.943 396.206,130.933 396.215,130.923 396.224,130.913 396.233,130.903 396.242,130.894 396.252,130.884 396.261,130.874 396.27,130.864 396.279,130.854 396.288,130.844 396.298,130.835 396.307,130.825 396.316,130.815 396.325,130.805 396.334,130.795 396.344,130.786 396.353,130.776 396.362,130.766 396.371,130.756 396.38,130.746 396.389,130.737 396.399,130.727 396.408,130.717 396.417,130.707 396.426,130.697 396.435,130.688 396.445,130.678 396.454,130.668 396.463,130.658 396.472,130.649 396.481,130.639 396.491,130.629 396.5,130.619 396.509,130.609 396.518,130.6 396.527,130.59 396.537,130.58 396.546,130.57 396.555,130.561 396.564,130.551 396.573,130.541 396.582,130.531 396.592,130.522 396.601,130.512 396.61,130.502 396.619,130.492 396.628,130.483 396.638,130.473 396.647,130.463 396.656,130.453 396.665,130.444 396.674,130.434 396.684,130.424 396.693,130.414 396.702,130.405 396.711,130.395 396.72,130.385 396.729,130.375 396.739,130.366 396.748,130.356 396.757,130.346 396.766,130.336 396.775,130.327 396.785,130.317 396.794,130.307 396.803,130.298 396.812,130.288 396.821,130.278 396.831,130.268 396.84,130.259 396.849,130.249 396.858,130.239 396.867,130.229 396.877,130.22 396.886,130.21 396.895,130.2 396.904,130.191 396.913,130.181 396.922,130.171 396.932,130.162 396.941,130.152 396.95,130.142 396.959,130.132 396.968,130.123 396.978,130.113 396.987,130.103 396.996,130.094 397.005,130.084 397.014,130.074 397.024,130.065 397.033,130.055 397.042,130.045 397.051,130.036 397.06,130.026 397.069,130.016 397.079,130.006 397.088,129.997 397.097,129.987 397.106,129.977 397.115,129.968 397.125,129.958 397.134,129.948 397.143,129.939 397.152,129.929 397.161,129.919 397.171,129.91 397.18,129.9 397.189,129.89 397.198,129.881 397.207,129.871 397.217,129.862 397.226,129.852 397.235,129.842 397.244,129.833 397.253,129.823 397.262,129.813 397.272,129.804 397.281,129.794 397.29,129.784 397.299,129.775 397.308,129.765 397.318,129.755 397.327,129.746 397.336,129.736 397.345,129.727 397.354,129.717 397.364,129.707 397.373,129.698 397.382,129.688 397.391,129.678 397.4,129.669 397.409,129.659 397.419,129.649 397.428,129.64 397.437,129.63 397.446,129.621 397.455,129.611 397.465,129.601 397.474,129.592 397.483,129.582 397.492,129.573 397.501,129.563 397.511,129.553 397.52,129.544 397.529,129.534 397.538,129.525 397.547,129.515 397.557,129.505 397.566,129.496 397.575,129.486 397.584,129.477 397.593,129.467 397.602,129.457 397.612,129.448 397.621,129.438 397.63,129.429 397.639,129.419 397.648,129.409 397.658,129.4 397.667,129.39 397.676,129.381 397.685,129.371 397.694,129.362 397.704,129.352 397.713,129.342 397.722,129.333 397.731,129.323 397.74,129.314 397.749,129.304 397.759,129.295 397.768,129.285 397.777,129.275 397.786,129.266 397.795,129.256 397.805,129.247 397.814,129.237 397.823,129.228 397.832,129.218 397.841,129.209 397.851,129.199 397.86,129.189 397.869,129.18 397.878,129.17 397.887,129.161 397.897,129.151 397.906,129.142 397.915,129.132 397.924,129.123 397.933,129.113 397.942,129.104 397.952,129.094 397.961,129.085 397.97,129.075 397.979,129.065 397.988,129.056 397.998,129.046 398.007,129.037 398.016,129.027 398.025,129.018 398.034,129.008 398.044,128.999 398.053,128.989 398.062,128.98 398.071,128.97 398.08,128.961 398.09,128.951 398.099,128.942 398.108,128.932 398.117,128.923 398.126,128.913 398.135,128.904 398.145,128.894 398.154,128.885 398.163,128.875 398.172,128.866 398.181,128.856 398.191,128.847 398.2,128.837 398.209,128.828 398.218,128.818 398.227,128.809 398.237,128.799 398.246,128.79 398.255,128.78 398.264,128.771 398.273,128.761 398.282,128.752 398.292,128.742 398.301,128.733 398.31,128.723 398.319,128.714 398.328,128.705 398.338,128.695 398.347,128.686 398.356,128.676 398.365,128.667 398.374,128.657 398.384,128.648 398.393,128.638 398.402,128.629 398.411,128.619 398.42,128.61 398.43,128.6 398.439,128.591 398.448,128.582 398.457,128.572 398.466,128.563 398.475,128.553 398.485,128.544 398.494,128.534 398.503,128.525 398.512,128.515 398.521,128.506 398.531,128.497 398.54,128.487 398.549,128.478 398.558,128.468 398.567,128.459 398.577,128.449 398.586,128.44 398.595,128.431 398.604,128.421 398.613,128.412 398.622,128.402 398.632,128.393 398.641,128.383 398.65,128.374 398.659,128.365 398.668,128.355 398.678,128.346 398.687,128.336 398.696,128.327 398.705,128.317 398.714,128.308 398.724,128.299 398.733,128.289 398.742,128.28 398.751,128.27 398.76,128.261 398.77,128.252 398.779,128.242 398.788,128.233 398.797,128.223 398.806,128.214 398.815,128.205 398.825,128.195 398.834,128.186 398.843,128.177 398.852,128.167 398.861,128.158 398.871,128.148 398.88,128.139 398.889,128.13 398.898,128.12 398.907,128.111 398.917,128.101 398.926,128.092 398.935,128.083 398.944,128.073 398.953,128.064 398.962,128.055 398.972,128.045 398.981,128.036 398.99,128.027 398.999,128.017 399.008,128.008 399.018,127.998 399.027,127.989 399.036,127.98 399.045,127.97 399.054,127.961 399.064,127.952 399.073,127.942 399.082,127.933 399.091,127.924 399.1,127.914 399.11,127.905 399.119,127.896 399.128,127.886 399.137,127.877 399.146,127.868 399.155,127.858 399.165,127.849 399.174,127.84 399.183,127.83 399.192,127.821 399.201,127.812 399.211,127.802 399.22,127.793 399.229,127.784 399.238,127.774 399.247,127.765 399.257,127.756 399.266,127.746 399.275,127.737 399.284,127.728 399.293,127.718 399.302,127.709 399.312,127.7 399.321,127.69 399.33,127.681 399.339,127.672 399.348,127.662 399.358,127.653 399.367,127.644 399.376,127.635 399.385,127.625 399.394,127.616 399.404,127.607 399.413,127.597 399.422,127.588 399.431,127.579 399.44,127.569 399.45,127.56 399.459,127.551 399.468,127.542 399.477,127.532 399.486,127.523 399.495,127.514 399.505,127.504 399.514,127.495 399.523,127.486 399.532,127.477 399.541,127.467 399.551,127.458 399.56,127.449 399.569,127.44 399.578,127.43 399.587,127.421 399.597,127.412 399.606,127.402 399.615,127.393 399.624,127.384 399.633,127.375 399.642,127.365 399.652,127.356 399.661,127.347 399.67,127.338 399.679,127.328 399.688,127.319 399.698,127.31 399.707,127.301 399.716,127.291 399.725,127.282 399.734,127.273 399.744,127.264 399.753,127.254 399.762,127.245 399.771,127.236 399.78,127.227 399.79,127.217 399.799,127.208 399.808,127.199 399.817,127.19 399.826,127.18 399.835,127.171 399.845,127.162 399.854,127.153 399.863,127.144 399.872,127.134 399.881,127.125 399.891,127.116 399.9,127.107 399.909,127.097 399.918,127.088 399.927,127.079 399.937,127.07 399.946,127.061 399.955,127.051 399.964,127.042 399.973,127.033 399.982,127.024 399.992,127.015 400.001,127.005 400.01,126.996 400.019,126.987 400.028,126.978 400.038,126.969 400.047,126.959 400.056,126.95 400.065,126.941 400.074,126.932 400.084,126.923 400.093,126.913 400.102,126.904 400.111,126.895 400.12,126.886 400.13,126.877 400.139,126.867 400.148,126.858 400.157,126.849 400.166,126.84 400.175,126.831 400.185,126.822 400.194,126.812 400.203,126.803 400.212,126.794 400.221,126.785 400.231,126.776 400.24,126.767 400.249,126.757 400.258,126.748 400.267,126.739 400.277,126.73 400.286,126.721 400.295,126.712 400.304,126.702 400.313,126.693 400.322,126.684 400.332,126.675 400.341,126.666 400.35,126.657 400.359,126.648 400.368,126.638 400.378,126.629 400.387,126.62 400.396,126.611 400.405,126.602 400.414,126.593 400.424,126.584 400.433,126.574 400.442,126.565 400.451,126.556 400.46,126.547 400.47,126.538 400.479,126.529 400.488,126.52 400.497,126.51 400.506,126.501 400.515,126.492 400.525,126.483 400.534,126.474 400.543,126.465 400.552,126.456 400.561,126.447 400.571,126.437 400.58,126.428 400.589,126.419 400.598,126.41 400.607,126.401 400.617,126.392 400.626,126.383 400.635,126.374 400.644,126.365 400.653,126.356 400.663,126.346 400.672,126.337 400.681,126.328 400.69,126.319 400.699,126.31 400.708,126.301 400.718,126.292 400.727,126.283 400.736,126.274 400.745,126.265 400.754,126.255 400.764,126.246 400.773,126.237 400.782,126.228 400.791,126.219 400.8,126.21 400.81,126.201 400.819,126.192 400.828,126.183 400.837,126.174 400.846,126.165 400.855,126.156 400.865,126.147 400.874,126.137 400.883,126.128 400.892,126.119 400.901,126.11 400.911,126.101 400.92,126.092 400.929,126.083 400.938,126.074 400.947,126.065 400.957,126.056 400.966,126.047 400.975,126.038 400.984,126.029 400.993,126.02 401.003,126.011 401.012,126.002 401.021,125.993 401.03,125.984 401.039,125.974 401.048,125.965 401.058,125.956 401.067,125.947 401.076,125.938 401.085,125.929 401.094,125.92 401.104,125.911 401.113,125.902 401.122,125.893 401.131,125.884 401.14,125.875 401.15,125.866 401.159,125.857 401.168,125.848 401.177,125.839 401.186,125.83 401.195,125.821 401.205,125.812 401.214,125.803 401.223,125.794 401.232,125.785 401.241,125.776 401.251,125.767 401.26,125.758 401.269,125.749 401.278,125.74 401.287,125.731 401.297,125.722 401.306,125.713 401.315,125.704 401.324,125.695 401.333,125.686 401.343,125.677 401.352,125.668 401.361,125.659 401.37,125.65 401.379,125.641 401.388,125.632 401.398,125.623 401.407,125.614 401.416,125.605 401.425,125.596 401.434,125.587 401.444,125.578 401.453,125.569 401.462,125.56 401.471,125.551 401.48,125.542 401.49,125.533 401.499,125.524 401.508,125.515 401.517,125.506 401.526,125.497 401.535,125.488 401.545,125.479 401.554,125.47 401.563,125.461 401.572,125.452 401.581,125.443 401.591,125.434 401.6,125.425 401.609,125.416 401.618,125.408 401.627,125.399 401.637,125.39 401.646,125.381 401.655,125.372 401.664,125.363 401.673,125.354 401.683,125.345 401.692,125.336 401.701,125.327 401.71,125.318 401.719,125.309 401.728,125.3 401.738,125.291 401.747,125.282 401.756,125.273 401.765,125.264 401.774,125.255 401.784,125.247 401.793,125.238 401.802,125.229 401.811,125.22 401.82,125.211 401.83,125.202 401.839,125.193 401.848,125.184 401.857,125.175 401.866,125.166 401.875,125.157 401.885,125.148 401.894,125.139 401.903,125.131 401.912,125.122 401.921,125.113 401.931,125.104 401.94,125.095 401.949,125.086 401.958,125.077 401.967,125.068 401.977,125.059 401.986,125.05 401.995,125.042 402.004,125.033 402.013,125.024 402.023,125.015 402.032,125.006 402.041,124.997 402.05,124.988 402.059,124.979 402.068,124.97 402.078,124.961 402.087,124.953 402.096,124.944 402.105,124.935 402.114,124.926 402.124,124.917 402.133,124.908 402.142,124.899 402.151,124.89 402.16,124.882 402.17,124.873 402.179,124.864 402.188,124.855 402.197,124.846 402.206,124.837 402.215,124.828 402.225,124.819 402.234,124.811 402.243,124.802 402.252,124.793 402.261,124.784 402.271,124.775 402.28,124.766 402.289,124.757 402.298,124.749 402.307,124.74 402.317,124.731 402.326,124.722 402.335,124.713 402.344,124.704 402.353,124.696 402.363,124.687 402.372,124.678 402.381,124.669 402.39,124.66 402.399,124.651 402.408,124.642 402.418,124.634 402.427,124.625 402.436,124.616 402.445,124.607 402.454,124.598 402.464,124.589 402.473,124.581 402.482,124.572 402.491,124.563 402.5,124.554 402.51,124.545 402.519,124.537 402.528,124.528 402.537,124.519 402.546,124.51 402.555,124.501 402.565,124.492 402.574,124.484 402.583,124.475 402.592,124.466 402.601,124.457 402.611,124.448 402.62,124.44 402.629,124.431 402.638,124.422 402.647,124.413 402.657,124.404 402.666,124.396 402.675,124.387 402.684,124.378 402.693,124.369 402.703,124.36 402.712,124.352 402.721,124.343 402.73,124.334 402.739,124.325 402.748,124.316 402.758,124.308 402.767,124.299 402.776,124.29 402.785,124.281 402.794,124.273 402.804,124.264 402.813,124.255 402.822,124.246 402.831,124.237 402.84,124.229 402.85,124.22 402.859,124.211 402.868,124.202 402.877,124.194 402.886,124.185 402.895,124.176 402.905,124.167 402.914,124.158 402.923,124.15 402.932,124.141 402.941,124.132 402.951,124.123 402.96,124.115 402.969,124.106 402.978,124.097 402.987,124.088 402.997,124.08 403.006,124.071 403.015,124.062 403.024,124.053 403.033,124.045 403.043,124.036 403.052,124.027 403.061,124.018 403.07,124.01 403.079,124.001 403.088,123.992 403.098,123.983 403.107,123.975 403.116,123.966 403.125,123.957 403.134,123.949 403.144,123.94 403.153,123.931 403.162,123.922 403.171,123.914 403.18,123.905 403.19,123.896 403.199,123.887 403.208,123.879 403.217,123.87 403.226,123.861 403.236,123.853 403.245,123.844 403.254,123.835 403.263,123.826 403.272,123.818 403.281,123.809 403.291,123.8 403.3,123.792 403.309,123.783 403.318,123.774 403.327,123.766 403.337,123.757 403.346,123.748 403.355,123.739 403.364,123.731 403.373,123.722 403.383,123.713 403.392,123.705 403.401,123.696 403.41,123.687 403.419,123.679 403.428,123.67 403.438,123.661 403.447,123.652 403.456,123.644 403.465,123.635 403.474,123.626 403.484,123.618 403.493,123.609 403.502,123.6 403.511,123.592 403.52,123.583 403.53,123.574 403.539,123.566 403.548,123.557 403.557,123.548 403.566,123.54 403.576,123.531 403.585,123.522 403.594,123.514 403.603,123.505 403.612,123.496 403.621,123.488 403.631,123.479 403.64,123.47 403.649,123.462 403.658,123.453 403.667,123.444 403.677,123.436 403.686,123.427 403.695,123.418 403.704,123.41 403.713,123.401 403.723,123.393 403.732,123.384 403.741,123.375 403.75,123.367 403.759,123.358 403.768,123.349 403.778,123.341 403.787,123.332 403.796,123.323 403.805,123.315 403.814,123.306 403.824,123.297 403.833,123.289 403.842,123.28 403.851,123.272 403.86,123.263 403.87,123.254 403.879,123.246 403.888,123.237 403.897,123.228 403.906,123.22 403.916,123.211 403.925,123.203 403.934,123.194 403.943,123.185 403.952,123.177 403.961,123.168 403.971,123.16 403.98,123.151 403.989,123.142 403.998,123.134 404.007,123.125 404.017,123.117 404.026,123.108 404.035,123.099 404.044,123.091 404.053,123.082 404.063,123.074 404.072,123.065 404.081,123.056 404.09,123.048 404.099,123.039 404.108,123.031 404.118,123.022 404.127,123.013 404.136,123.005 404.145,122.996 404.154,122.988 404.164,122.979 404.173,122.97 404.182,122.962 404.191,122.953 404.2,122.945 404.21,122.936 404.219,122.928 404.228,122.919 404.237,122.91 404.246,122.902 404.256,122.893 404.265,122.885 404.274,122.876 404.283,122.868 404.292,122.859 404.301,122.85 404.311,122.842 404.32,122.833 404.329,122.825 404.338,122.816 404.347,122.808 404.357,122.799 404.366,122.791 404.375,122.782 404.384,122.773 404.393,122.765 404.403,122.756 404.412,122.748 404.421,122.739 404.43,122.731 404.439,122.722 404.448,122.714 404.458,122.705 404.467,122.697 404.476,122.688 404.485,122.679 404.494,122.671 404.504,122.662 404.513,122.654 404.522,122.645 404.531,122.637 404.54,122.628 404.55,122.62 404.559,122.611 404.568,122.603 404.577,122.594 404.586,122.586 404.596,122.577 404.605,122.569 404.614,122.56 404.623,122.552 404.632,122.543 404.641,122.534 404.651,122.526 404.66,122.517 404.669,122.509 404.678,122.5 404.687,122.492 404.697,122.483 404.706,122.475 404.715,122.466 404.724,122.458 404.733,122.449 404.743,122.441 404.752,122.432 404.761,122.424 404.77,122.415 404.779,122.407 404.788,122.398 404.798,122.39 404.807,122.381 404.816,122.373 404.825,122.364 404.834,122.356 404.844,122.347 404.853,122.339 404.862,122.33 404.871,122.322 404.88,122.314 404.89,122.305 404.899,122.297 404.908,122.288 404.917,122.28 404.926,122.271 404.936,122.263 404.945,122.254 404.954,122.246 404.963,122.237 404.972,122.229 404.981,122.22 404.991,122.212 405,122.203 405.009,122.195 405.018,122.186 405.027,122.178 405.037,122.17 405.046,122.161 405.055,122.153 405.064,122.144 405.073,122.136 405.083,122.127 405.092,122.119 405.101,122.11 405.11,122.102 405.119,122.093 405.128,122.085 405.138,122.077 405.147,122.068 405.156,122.06 405.165,122.051 405.174,122.043 405.184,122.034 405.193,122.026 405.202,122.017 405.211,122.009 405.22,122.001 405.23,121.992 405.239,121.984 405.248,121.975 405.257,121.967 405.266,121.958 405.276,121.95 405.285,121.942 405.294,121.933 405.303,121.925 405.312,121.916 405.321,121.908 405.331,121.899 405.34,121.891 405.349,121.883 405.358,121.874 405.367,121.866 405.377,121.857 405.386,121.849 405.395,121.841 405.404,121.832 405.413,121.824 405.423,121.815 405.432,121.807 405.441,121.799 405.45,121.79 405.459,121.782 405.469,121.773 405.478,121.765 405.487,121.757 405.496,121.748 405.505,121.74 405.514,121.731 405.524,121.723 405.533,121.715 405.542,121.706 405.551,121.698 405.56,121.689 405.57,121.681 405.579,121.673 405.588,121.664 405.597,121.656 405.606,121.647 405.616,121.639 405.625,121.631 405.634,121.622 405.643,121.614 405.652,121.606 405.661,121.597 405.671,121.589 405.68,121.58 405.689,121.572 405.698,121.564 405.707,121.555 405.717,121.547 405.726,121.539 405.735,121.53 405.744,121.522 405.753,121.513 405.763,121.505 405.772,121.497 405.781,121.488 405.79,121.48 405.799,121.472 405.809,121.463 405.818,121.455 405.827,121.447 405.836,121.438 405.845,121.43 405.854,121.422 405.864,121.413 405.873,121.405 405.882,121.397 405.891,121.388 405.9,121.38 405.91,121.372 405.919,121.363 405.928,121.355 405.937,121.347 405.946,121.338 405.956,121.33 405.965,121.322 405.974,121.313 405.983,121.305 405.992,121.297 406.001,121.288 406.011,121.28 406.02,121.272 406.029,121.263 406.038,121.255 406.047,121.247 406.057,121.238 406.066,121.23 406.075,121.222 406.084,121.213 406.093,121.205 406.103,121.197 406.112,121.188 406.121,121.18 406.13,121.172 406.139,121.163 406.149,121.155 406.158,121.147 406.167,121.139 406.176,121.13 406.185,121.122 406.194,121.114 406.204,121.105 406.213,121.097 406.222,121.089 406.231,121.08 406.24,121.072 406.25,121.064 406.259,121.056 406.268,121.047 406.277,121.039 406.286,121.031 406.296,121.022 406.305,121.014 406.314,121.006 406.323,120.998 406.332,120.989 406.341,120.981 406.351,120.973 406.36,120.964 406.369,120.956 406.378,120.948 406.387,120.94 406.397,120.931 406.406,120.923 406.415,120.915 406.424,120.906 406.433,120.898 406.443,120.89 406.452,120.882 406.461,120.873 406.47,120.865 406.479,120.857 406.489,120.849 406.498,120.84 406.507,120.832 406.516,120.824 406.525,120.816 406.534,120.807 406.544,120.799 406.553,120.791 406.562,120.783 406.571,120.774 406.58,120.766 406.59,120.758 406.599,120.75 406.608,120.741 406.617,120.733 406.626,120.725 406.636,120.717 406.645,120.708 406.654,120.7 406.663,120.692 406.672,120.684 406.681,120.675 406.691,120.667 406.7,120.659 406.709,120.651 406.718,120.642 406.727,120.634 406.737,120.626 406.746,120.618 406.755,120.61 406.764,120.601 406.773,120.593 406.783,120.585 406.792,120.577 406.801,120.568 406.81,120.56 406.819,120.552 406.829,120.544 406.838,120.536 406.847,120.527 406.856,120.519 406.865,120.511 406.874,120.503 406.884,120.494 406.893,120.486 406.902,120.478 406.911,120.47 406.92,120.462 406.93,120.453 406.939,120.445 406.948,120.437 406.957,120.429 406.966,120.421 406.976,120.412 406.985,120.404 406.994,120.396 407.003,120.388 407.012,120.38 407.021,120.372 407.031,120.363 407.04,120.355 407.049,120.347 407.058,120.339 407.067,120.331 407.077,120.322 407.086,120.314 407.095,120.306 407.104,120.298 407.113,120.29 407.123,120.281 407.132,120.273 407.141,120.265 407.15,120.257 407.159,120.249 407.169,120.241 407.178,120.232 407.187,120.224 407.196,120.216 407.205,120.208 407.214,120.2 407.224,120.192 407.233,120.183 407.242,120.175 407.251,120.167 407.26,120.159 407.27,120.151 407.279,120.143 407.288,120.135 407.297,120.126 407.306,120.118 407.316,120.11 407.325,120.102 407.334,120.094 407.343,120.086 407.352,120.077 407.361,120.069 407.371,120.061 407.38,120.053 407.389,120.045 407.398,120.037 407.407,120.029 407.417,120.02 407.426,120.012 407.435,120.004 407.444,119.996 407.453,119.988 407.463,119.98 407.472,119.972 407.481,119.964 407.49,119.955 407.499,119.947 407.509,119.939 407.518,119.931 407.527,119.923 407.536,119.915 407.545,119.907 407.554,119.899 407.564,119.89 407.573,119.882 407.582,119.874 407.591,119.866 407.6,119.858 407.61,119.85 407.619,119.842 407.628,119.834 407.637,119.825 407.646,119.817 407.656,119.809 407.665,119.801 407.674,119.793 407.683,119.785 407.692,119.777 407.701,119.769 407.711,119.761 407.72,119.753 407.729,119.744 407.738,119.736 407.747,119.728 407.757,119.72 407.766,119.712 407.775,119.704 407.784,119.696 407.793,119.688 407.803,119.68 407.812,119.672 407.821,119.664 407.83,119.655 407.839,119.647 407.849,119.639 407.858,119.631 407.867,119.623 407.876,119.615 407.885,119.607 407.894,119.599 407.904,119.591 407.913,119.583 407.922,119.575 407.931,119.567 407.94,119.559 407.95,119.55 407.959,119.542 407.968,119.534 407.977,119.526 407.986,119.518 407.996,119.51 408.005,119.502 408.014,119.494 408.023,119.486 408.032,119.478 408.042,119.47 408.051,119.462 408.06,119.454 408.069,119.446 408.078,119.438 408.087,119.43 408.097,119.422 408.106,119.413 408.115,119.405 408.124,119.397 408.133,119.389 408.143,119.381 408.152,119.373 408.161,119.365 408.17,119.357 408.179,119.349 408.189,119.341 408.198,119.333 408.207,119.325 408.216,119.317 408.225,119.309 408.234,119.301 408.244,119.293 408.253,119.285 408.262,119.277 408.271,119.269 408.28,119.261 408.29,119.253 408.299,119.245 408.308,119.237 408.317,119.229 408.326,119.221 408.336,119.213 408.345,119.205 408.354,119.197 408.363,119.189 408.372,119.181 408.382,119.173 408.391,119.165 408.4,119.157 408.409,119.149 408.418,119.141 408.427,119.133 408.437,119.125 408.446,119.117 408.455,119.109 408.464,119.101 408.473,119.093 408.483,119.085 408.492,119.077 408.501,119.069 408.51,119.061 408.519,119.053 408.529,119.045 408.538,119.037 408.547,119.029 408.556,119.021 408.565,119.013 408.574,119.005 408.584,118.997 408.593,118.989 408.602,118.981 408.611,118.973 408.62,118.965 408.63,118.957 408.639,118.949 408.648,118.941 408.657,118.933 408.666,118.925 408.676,118.917 408.685,118.909 408.694,118.901 408.703,118.893 408.712,118.885 408.722,118.877 408.731,118.869 408.74,118.861 408.749,118.853 408.758,118.845 408.767,118.837 408.777,118.829 408.786,118.821 408.795,118.813 408.804,118.805 408.813,118.797 408.823,118.789 408.832,118.781 408.841,118.773 408.85,118.766 408.859,118.758 408.869,118.75 408.878,118.742 408.887,118.734 408.896,118.726 408.905,118.718 408.914,118.71 408.924,118.702 408.933,118.694 408.942,118.686 408.951,118.678 408.96,118.67 408.97,118.662 408.979,118.654 408.988,118.646 408.997,118.638 409.006,118.63 409.016,118.623 409.025,118.615 409.034,118.607 409.043,118.599 409.052,118.591 409.062,118.583 409.071,118.575 409.08,118.567 409.089,118.559 409.098,118.551 409.107,118.543 409.117,118.535 409.126,118.527 409.135,118.52 409.144,118.512 409.153,118.504 409.163,118.496 409.172,118.488 409.181,118.48 409.19,118.472 409.199,118.464 409.209,118.456 409.218,118.448 409.227,118.44 409.236,118.433 409.245,118.425 409.254,118.417 409.264,118.409 409.273,118.401 409.282,118.393 409.291,118.385 409.3,118.377 409.31,118.369 409.319,118.361 409.328,118.354 409.337,118.346 409.346,118.338 409.356,118.33 409.365,118.322 409.374,118.314 409.383,118.306 409.392,118.298 409.402,118.29 409.411,118.283 409.42,118.275 409.429,118.267 409.438,118.259 409.447,118.251 409.457,118.243 409.466,118.235 409.475,118.227 409.484,118.22 409.493,118.212 409.503,118.204 409.512,118.196 409.521,118.188 409.53,118.18 409.539,118.172 409.549,118.165 409.558,118.157 409.567,118.149 409.576,118.141 409.585,118.133 409.594,118.125 409.604,118.117 409.613,118.109 409.622,118.102 409.631,118.094 409.64,118.086 409.65,118.078 409.659,118.07 409.668,118.062 409.677,118.055 409.686,118.047 409.696,118.039 409.705,118.031 409.714,118.023 409.723,118.015 409.732,118.007 409.742,118 409.751,117.992 409.76,117.984 409.769,117.976 409.778,117.968 409.787,117.96 409.797,117.953 409.806,117.945 409.815,117.937 409.824,117.929 409.833,117.921 409.843,117.913 409.852,117.906 409.861,117.898 409.87,117.89 409.879,117.882 409.889,117.874 409.898,117.867 409.907,117.859 409.916,117.851 409.925,117.843 409.934,117.835 409.944,117.827 409.953,117.82 409.962,117.812 409.971,117.804 409.98,117.796 409.99,117.788 409.999,117.781 410.008,117.773 410.017,117.765 410.026,117.757 410.036,117.749 410.045,117.742 410.054,117.734 410.063,117.726 410.072,117.718 410.082,117.71 410.091,117.703 410.1,117.695 410.109,117.687 410.118,117.679 410.127,117.671 410.137,117.664 410.146,117.656 410.155,117.648 410.164,117.64 410.173,117.632 410.183,117.625 410.192,117.617 410.201,117.609 410.21,117.601 410.219,117.593 410.229,117.586 410.238,117.578 410.247,117.57 410.256,117.562 410.265,117.555 410.274,117.547 410.284,117.539 410.293,117.531 410.302,117.524 410.311,117.516 410.32,117.508 410.33,117.5 410.339,117.492 410.348,117.485 410.357,117.477 410.366,117.469 410.376,117.461 410.385,117.454 410.394,117.446 410.403,117.438 410.412,117.43 410.422,117.423 410.431,117.415 410.44,117.407 410.449,117.399 410.458,117.392 410.467,117.384 410.477,117.376 410.486,117.368 410.495,117.361 410.504,117.353 410.513,117.345 410.523,117.337 410.532,117.33 410.541,117.322 410.55,117.314 410.559,117.306 410.569,117.299 410.578,117.291 410.587,117.283 410.596,117.275 410.605,117.268 410.615,117.26 410.624,117.252 410.633,117.245 410.642,117.237 410.651,117.229 410.66,117.221 410.67,117.214 410.679,117.206 410.688,117.198 410.697,117.19 410.706,117.183 410.716,117.175 410.725,117.167 410.734,117.16 410.743,117.152 410.752,117.144 410.762,117.136 410.771,117.129 410.78,117.121 410.789,117.113 410.798,117.106 410.807,117.098 410.817,117.09 410.826,117.082 410.835,117.075 410.844,117.067 410.853,117.059 410.863,117.052 410.872,117.044 410.881,117.036 410.89,117.029 410.899,117.021 410.909,117.013 410.918,117.005 410.927,116.998 410.936,116.99 410.945,116.982 410.955,116.975 410.964,116.967 410.973,116.959 410.982,116.952 410.991,116.944 411,116.936 411.01,116.929 411.019,116.921 411.028,116.913 411.037,116.906 411.046,116.898 411.056,116.89 411.065,116.882 411.074,116.875 411.083,116.867 411.092,116.859 411.102,116.852 411.111,116.844 411.12,116.836 411.129,116.829 411.138,116.821 411.147,116.813 411.157,116.806 411.166,116.798 411.175,116.79 411.184,116.783 411.193,116.775 411.203,116.767 411.212,116.76 411.221,116.752 411.23,116.744 411.239,116.737 411.249,116.729 411.258,116.722 411.267,116.714 411.276,116.706 411.285,116.699 411.295,116.691 411.304,116.683 411.313,116.676 411.322,116.668 411.331,116.66 411.34,116.653 411.35,116.645 411.359,116.637 411.368,116.63 411.377,116.622 411.386,116.614 411.396,116.607 411.405,116.599 411.414,116.592 411.423,116.584 411.432,116.576 411.442,116.569 411.451,116.561 411.46,116.553 411.469,116.546 411.478,116.538 411.487,116.531 411.497,116.523 411.506,116.515 411.515,116.508 411.524,116.5 411.533,116.492 411.543,116.485 411.552,116.477 411.561,116.47 411.57,116.462 411.579,116.454 411.589,116.447 411.598,116.439 411.607,116.431 411.616,116.424 411.625,116.416 411.635,116.409 411.644,116.401 411.653,116.393 411.662,116.386 411.671,116.378 411.68,116.371 411.69,116.363 411.699,116.355 411.708,116.348 411.717,116.34 411.726,116.333 411.736,116.325 411.745,116.317 411.754,116.31 411.763,116.302 411.772,116.295 411.782,116.287 411.791,116.279 411.8,116.272 411.809,116.264 411.818,116.257 411.827,116.249 411.837,116.242 411.846,116.234 411.855,116.226 411.864,116.219 411.873,116.211 411.883,116.204 411.892,116.196 411.901,116.188 411.91,116.181 411.919,116.173 411.929,116.166 411.938,116.158 411.947,116.151 411.956,116.143 411.965,116.135 411.975,116.128 411.984,116.12 411.993,116.113 412.002,116.105 412.011,116.098 412.02,116.09 412.03,116.082 412.039,116.075 412.048,116.067 412.057,116.06 412.066,116.052 412.076,116.045 412.085,116.037 412.094,116.03 412.103,116.022 412.112,116.014 412.122,116.007 412.131,115.999 412.14,115.992 412.149,115.984 412.158,115.977 412.167,115.969 412.177,115.962 412.186,115.954 412.195,115.947 412.204,115.939 412.213,115.931 412.223,115.924 412.232,115.916 412.241,115.909 412.25,115.901 412.259,115.894 412.269,115.886 412.278,115.879 412.287,115.871 412.296,115.864 412.305,115.856 412.315,115.849 412.324,115.841 412.333,115.834 412.342,115.826 412.351,115.819 412.36,115.811 412.37,115.803 412.379,115.796 412.388,115.788 412.397,115.781 412.406,115.773 412.416,115.766 412.425,115.758 412.434,115.751 412.443,115.743 412.452,115.736 412.462,115.728 412.471,115.721 412.48,115.713 412.489,115.706 412.498,115.698 412.507,115.691 412.517,115.683 412.526,115.676 412.535,115.668 412.544,115.661 412.553,115.653 412.563,115.646 412.572,115.638 412.581,115.631 412.59,115.623 412.599,115.616 412.609,115.608 412.618,115.601 412.627,115.593 412.636,115.586 412.645,115.578 412.655,115.571 412.664,115.563 412.673,115.556 412.682,115.548 412.691,115.541 412.7,115.533 412.71,115.526 412.719,115.518 412.728,115.511 412.737,115.504 412.746,115.496 412.756,115.489 412.765,115.481 412.774,115.474 412.783,115.466 412.792,115.459 412.802,115.451 412.811,115.444 412.82,115.436 412.829,115.429 412.838,115.421 412.847,115.414 412.857,115.406 412.866,115.399 412.875,115.391 412.884,115.384 412.893,115.377 412.903,115.369 412.912,115.362 412.921,115.354 412.93,115.347 412.939,115.339 412.949,115.332 412.958,115.324 412.967,115.317 412.976,115.309 412.985,115.302 412.995,115.295 413.004,115.287 413.013,115.28 413.022,115.272 413.031,115.265 413.04,115.257 413.05,115.25 413.059,115.242 413.068,115.235 413.077,115.228 413.086,115.22 413.096,115.213 413.105,115.205 413.114,115.198 413.123,115.19 413.132,115.183 413.142,115.176 413.151,115.168 413.16,115.161 413.169,115.153 413.178,115.146 413.188,115.138 413.197,115.131 413.206,115.124 413.215,115.116 413.224,115.109 413.233,115.101 413.243,115.094 413.252,115.086 413.261,115.079 413.27,115.072 413.279,115.064 413.289,115.057 413.298,115.049 413.307,115.042 413.316,115.035 413.325,115.027 413.335,115.02 413.344,115.012 413.353,115.005 413.362,114.997 413.371,114.99 413.38,114.983 413.39,114.975 413.399,114.968 413.408,114.96 413.417,114.953 413.426,114.946 413.436,114.938 413.445,114.931 413.454,114.923 413.463,114.916 413.472,114.909 413.482,114.901 413.491,114.894 413.5,114.887 413.509,114.879 413.518,114.872 413.528,114.864 413.537,114.857 413.546,114.85 413.555,114.842 413.564,114.835 413.573,114.827 413.583,114.82 413.592,114.813 413.601,114.805 413.61,114.798 413.619,114.791 413.629,114.783 413.638,114.776 413.647,114.768 413.656,114.761 413.665,114.754 413.675,114.746 413.684,114.739 413.693,114.732 413.702,114.724 413.711,114.717 413.72,114.709 413.73,114.702 413.739,114.695 413.748,114.687 413.757,114.68 413.766,114.673 413.776,114.665 413.785,114.658 413.794,114.651 413.803,114.643 413.812,114.636 413.822,114.629 413.831,114.621 413.84,114.614 413.849,114.606 413.858,114.599 413.868,114.592 413.877,114.584 413.886,114.577 413.895,114.57 413.904,114.562 413.913,114.555 413.923,114.548 413.932,114.54 413.941,114.533 413.95,114.526 413.959,114.518 413.969,114.511 413.978,114.504 413.987,114.496 413.996,114.489 414.005,114.482 414.015,114.474 414.024,114.467 414.033,114.46 414.042,114.452 414.051,114.445 414.06,114.438 414.07,114.43 414.079,114.423 414.088,114.416 414.097,114.408 414.106,114.401 414.116,114.394 414.125,114.386 414.134,114.379 414.143,114.372 414.152,114.364 414.162,114.357 414.171,114.35 414.18,114.343 414.189,114.335 414.198,114.328 414.208,114.321 414.217,114.313 414.226,114.306 414.235,114.299 414.244,114.291 414.253,114.284 414.263,114.277 414.272,114.269 414.281,114.262 414.29,114.255 414.299,114.248 414.309,114.24 414.318,114.233 414.327,114.226 414.336,114.218 414.345,114.211 414.355,114.204 414.364,114.197 414.373,114.189 414.382,114.182 414.391,114.175 414.4,114.167 414.41,114.16 414.419,114.153 414.428,114.146 414.437,114.138 414.446,114.131 414.456,114.124 414.465,114.116 414.474,114.109 414.483,114.102 414.492,114.095 414.502,114.087 414.511,114.08 414.52,114.073 414.529,114.065 414.538,114.058 414.548,114.051 414.557,114.044 414.566,114.036 414.575,114.029 414.584,114.022 414.593,114.015 414.603,114.007 414.612,114 414.621,113.993 414.63,113.986 414.639,113.978 414.649,113.971 414.658,113.964 414.667,113.956 414.676,113.949 414.685,113.942 414.695,113.935 414.704,113.927 414.713,113.92 414.722,113.913 414.731,113.906 414.74,113.898 414.75,113.891 414.759,113.884 414.768,113.877 414.777,113.869 414.786,113.862 414.796,113.855 414.805,113.848 414.814,113.84 414.823,113.833 414.832,113.826 414.842,113.819 414.851,113.812 414.86,113.804 414.869,113.797 414.878,113.79 414.888,113.783 414.897,113.775 414.906,113.768 414.915,113.761 414.924,113.754 414.933,113.746 414.943,113.739 414.952,113.732 414.961,113.725 414.97,113.718 414.979,113.71 414.989,113.703 414.998,113.696 415.007,113.689 415.016,113.681 415.025,113.674 415.035,113.667 415.044,113.66 415.053,113.653 415.062,113.645 415.071,113.638 415.08,113.631 415.09,113.624 415.099,113.616 415.108,113.609 415.117,113.602 415.126,113.595 415.136,113.588 415.145,113.58 415.154,113.573 415.163,113.566 415.172,113.559 415.182,113.552 415.191,113.544 415.2,113.537 415.209,113.53 415.218,113.523 415.228,113.516 415.237,113.508 415.246,113.501 415.255,113.494 415.264,113.487 415.273,113.48 415.283,113.473 415.292,113.465 415.301,113.458 415.31,113.451 415.319,113.444 415.329,113.437 415.338,113.429 415.347,113.422 415.356,113.415 415.365,113.408 415.375,113.401 415.384,113.394 415.393,113.386 415.402,113.379 415.411,113.372 415.421,113.365 415.43,113.358 415.439,113.35 415.448,113.343 415.457,113.336 415.466,113.329 415.476,113.322 415.485,113.315 415.494,113.307 415.503,113.3 415.512,113.293 415.522,113.286 415.531,113.279 415.54,113.272 415.549,113.264 415.558,113.257 415.568,113.25 415.577,113.243 415.586,113.236 415.595,113.229 415.604,113.222 415.613,113.214 415.623,113.207 415.632,113.2 415.641,113.193 415.65,113.186 415.659,113.179 415.669,113.171 415.678,113.164 415.687,113.157 415.696,113.15 415.705,113.143 415.715,113.136 415.724,113.129 415.733,113.121 415.742,113.114 415.751,113.107 415.761,113.1 415.77,113.093 415.779,113.086 415.788,113.079 415.797,113.072 415.806,113.064 415.816,113.057 415.825,113.05 415.834,113.043 415.843,113.036 415.852,113.029 415.862,113.022 415.871,113.014 415.88,113.007 415.889,113 415.898,112.993 415.908,112.986 415.917,112.979 415.926,112.972 415.935,112.965 415.944,112.958 415.953,112.95 415.963,112.943 415.972,112.936 415.981,112.929 415.99,112.922 415.999,112.915 416.009,112.908 416.018,112.901 416.027,112.894 416.036,112.886 416.045,112.879 416.055,112.872 416.064,112.865 416.073,112.858 416.082,112.851 416.091,112.844 416.101,112.837 416.11,112.83 416.119,112.823 416.128,112.815 416.137,112.808 416.146,112.801 416.156,112.794 416.165,112.787 416.174,112.78 416.183,112.773 416.192,112.766 416.202,112.759 416.211,112.752 416.22,112.744 416.229,112.737 416.238,112.73 416.248,112.723 416.257,112.716 416.266,112.709 416.275,112.702 416.284,112.695 416.293,112.688 416.303,112.681 416.312,112.674 416.321,112.667 416.33,112.66 416.339,112.652 416.349,112.645 416.358,112.638 416.367,112.631 416.376,112.624 416.385,112.617 416.395,112.61 416.404,112.603 416.413,112.596 416.422,112.589 416.431,112.582 416.441,112.575 416.45,112.568 416.459,112.561 416.468,112.554 416.477,112.546 416.486,112.539 416.496,112.532 416.505,112.525 416.514,112.518 416.523,112.511 416.532,112.504 416.542,112.497 416.551,112.49 416.56,112.483 416.569,112.476 416.578,112.469 416.588,112.462 416.597,112.455 416.606,112.448 416.615,112.441 416.624,112.434 416.633,112.427 416.643,112.42 416.652,112.413 416.661,112.405 416.67,112.398 416.679,112.391 416.689,112.384 416.698,112.377 416.707,112.37 416.716,112.363 416.725,112.356 416.735,112.349 416.744,112.342 416.753,112.335 416.762,112.328 416.771,112.321 416.781,112.314 416.79,112.307 416.799,112.3 416.808,112.293 416.817,112.286 416.826,112.279 416.836,112.272 416.845,112.265 416.854,112.258 416.863,112.251 416.872,112.244 416.882,112.237 416.891,112.23 416.9,112.223 416.909,112.216 416.918,112.209 416.928,112.202 416.937,112.195 416.946,112.188 416.955,112.181 416.964,112.174 416.973,112.167 416.983,112.16 416.992,112.153 417.001,112.146 417.01,112.139 417.019,112.132 417.029,112.125 417.038,112.118 417.047,112.111 417.056,112.104 417.065,112.097 417.075,112.09 417.084,112.083 417.093,112.076 417.102,112.069 417.111,112.062 417.121,112.055 417.13,112.048 417.139,112.041 417.148,112.034 417.157,112.027 417.166,112.02 417.176,112.013 417.185,112.006 417.194,111.999 417.203,111.992 417.212,111.985 417.222,111.978 417.231,111.971 417.24,111.964 417.249,111.957 417.258,111.95 417.268,111.943 417.277,111.936 417.286,111.929 417.295,111.922 417.304,111.915 417.313,111.908 417.323,111.901 417.332,111.894 417.341,111.887 417.35,111.88 417.359,111.873 417.369,111.866 417.378,111.859 417.387,111.852 417.396,111.845 417.405,111.839 417.415,111.832 417.424,111.825 417.433,111.818 417.442,111.811 417.451,111.804 417.461,111.797 417.47,111.79 417.479,111.783 417.488,111.776 417.497,111.769 417.506,111.762 417.516,111.755 417.525,111.748 417.534,111.741 417.543,111.734 417.552,111.727 417.562,111.72 417.571,111.713 417.58,111.706 417.589,111.7 417.598,111.693 417.608,111.686 417.617,111.679 417.626,111.672 417.635,111.665 417.644,111.658 417.653,111.651 417.663,111.644 417.672,111.637 417.681,111.63 417.69,111.623 417.699,111.616 417.709,111.609 417.718,111.602 417.727,111.596 417.736,111.589 417.745,111.582 417.755,111.575 417.764,111.568 417.773,111.561 417.782,111.554 417.791,111.547 417.801,111.54 417.81,111.533 417.819,111.526 417.828,111.519 417.837,111.512 417.846,111.506 417.856,111.499 417.865,111.492 417.874,111.485 417.883,111.478 417.892,111.471 417.902,111.464 417.911,111.457 417.92,111.45 417.929,111.443 417.938,111.436 417.948,111.43 417.957,111.423 417.966,111.416 417.975,111.409 417.984,111.402 417.994,111.395 418.003,111.388 418.012,111.381 418.021,111.374 418.03,111.367 418.039,111.361 418.049,111.354 418.058,111.347 418.067,111.34 418.076,111.333 418.085,111.326 418.095,111.319 418.104,111.312 418.113,111.305 418.122,111.299 418.131,111.292 418.141,111.285 418.15,111.278 418.159,111.271 418.168,111.264 418.177,111.257 418.186,111.25 418.196,111.244 418.205,111.237 418.214,111.23 418.223,111.223 418.232,111.216 418.242,111.209 418.251,111.202 418.26,111.195 418.269,111.189 418.278,111.182 418.288,111.175 418.297,111.168 418.306,111.161 418.315,111.154 418.324,111.147 418.334,111.14 418.343,111.134 418.352,111.127 418.361,111.12 418.37,111.113 418.379,111.106 418.389,111.099 418.398,111.092 418.407,111.086 418.416,111.079 418.425,111.072 418.435,111.065 418.444,111.058 418.453,111.051 418.462,111.044 418.471,111.038 418.481,111.031 418.49,111.024 418.499,111.017 418.508,111.01 418.517,111.003 418.526,110.997 418.536,110.99 418.545,110.983 418.554,110.976 418.563,110.969 418.572,110.962 418.582,110.956 418.591,110.949 418.6,110.942 418.609,110.935 418.618,110.928 418.628,110.921 418.637,110.915 418.646,110.908 418.655,110.901 418.664,110.894 418.674,110.887 418.683,110.88 418.692,110.874 418.701,110.867 418.71,110.86 418.719,110.853 418.729,110.846 418.738,110.839 418.747,110.833 418.756,110.826 418.765,110.819 418.775,110.812 418.784,110.805 418.793,110.799 418.802,110.792 418.811,110.785 418.821,110.778 418.83,110.771 418.839,110.764 418.848,110.758 418.857,110.751 418.866,110.744 418.876,110.737 418.885,110.73 418.894,110.724 418.903,110.717 418.912,110.71 418.922,110.703 418.931,110.696 418.94,110.69 418.949,110.683 418.958,110.676 418.968,110.669 418.977,110.662 418.986,110.656 418.995,110.649 419.004,110.642 419.014,110.635 419.023,110.628 419.032,110.622 419.041,110.615 419.05,110.608 419.059,110.601 419.069,110.594 419.078,110.588 419.087,110.581 419.096,110.574 419.105,110.567 419.115,110.561 419.124,110.554 419.133,110.547 419.142,110.54 419.151,110.533 419.161,110.527 419.17,110.52 419.179,110.513 419.188,110.506 419.197,110.5 419.206,110.493 419.216,110.486 419.225,110.479 419.234,110.472 419.243,110.466 419.252,110.459 419.262,110.452 419.271,110.445 419.28,110.439 419.289,110.432 419.298,110.425 419.308,110.418 419.317,110.412 419.326,110.405 419.335,110.398 419.344,110.391 419.354,110.384 419.363,110.378 419.372,110.371 419.381,110.364 419.39,110.357 419.399,110.351 419.409,110.344 419.418,110.337 419.427,110.33 419.436,110.324 419.445,110.317 419.455,110.31 419.464,110.303 419.473,110.297 419.482,110.29 419.491,110.283 419.501,110.276 419.51,110.27 419.519,110.263 419.528,110.256 419.537,110.249 419.546,110.243 419.556,110.236 419.565,110.229 419.574,110.223 419.583,110.216 419.592,110.209 419.602,110.202 419.611,110.196 419.62,110.189 419.629,110.182 419.638,110.175 419.648,110.169 419.657,110.162 419.666,110.155 419.675,110.148 419.684,110.142 419.694,110.135 419.703,110.128 419.712,110.122 419.721,110.115 419.73,110.108 419.739,110.101 419.749,110.095 419.758,110.088 419.767,110.081 419.776,110.075 419.785,110.068 419.795,110.061 419.804,110.054 419.813,110.048 419.822,110.041 419.831,110.034 419.841,110.028 419.85,110.021 419.859,110.014 419.868,110.007 419.877,110.001 419.886,109.994 419.896,109.987 419.905,109.981 419.914,109.974 419.923,109.967 419.932,109.961 419.942,109.954 419.951,109.947 419.96,109.94 419.969,109.934 419.978,109.927 419.988,109.92 419.997,109.914 420.006,109.907 420.015,109.9 420.024,109.894 420.034,109.887 420.043,109.88 420.052,109.873 420.061,109.867 420.07,109.86 420.079,109.853 420.089,109.847 420.098,109.84 420.107,109.833 420.116,109.827 420.125,109.82 420.135,109.813 420.144,109.807 420.153,109.8 420.162,109.793 420.171,109.787 420.181,109.78 420.19,109.773 420.199,109.767 420.208,109.76 420.217,109.753 420.226,109.747 420.236,109.74 420.245,109.733 420.254,109.727 420.263,109.72 420.272,109.713 420.282,109.707 420.291,109.7 420.3,109.693 420.309,109.687 420.318,109.68 420.328,109.673 420.337,109.667 420.346,109.66 420.355,109.653 420.364,109.647 420.374,109.64 420.383,109.633 420.392,109.627 420.401,109.62 420.41,109.613 420.419,109.607 420.429,109.6 420.438,109.593 420.447,109.587 420.456,109.58 420.465,109.573 420.475,109.567 420.484,109.56 420.493,109.553 420.502,109.547 420.511,109.54 420.521,109.534 420.53,109.527 420.539,109.52 420.548,109.514 420.557,109.507 420.567,109.5 420.576,109.494 420.585,109.487 420.594,109.48 420.603,109.474 420.612,109.467 420.622,109.461 420.631,109.454 420.64,109.447 420.649,109.441 420.658,109.434 420.668,109.427 420.677,109.421 420.686,109.414 420.695,109.408 420.704,109.401 420.714,109.394 420.723,109.388 420.732,109.381 420.741,109.374 420.75,109.368 420.759,109.361 420.769,109.355 420.778,109.348 420.787,109.341 420.796,109.335 420.805,109.328 420.815,109.321 420.824,109.315 420.833,109.308 420.842,109.302 420.851,109.295 420.861,109.288 420.87,109.282 420.879,109.275 420.888,109.269 420.897,109.262 420.907,109.255 420.916,109.249 420.925,109.242 420.934,109.236 420.943,109.229 420.952,109.222 420.962,109.216 420.971,109.209 420.98,109.203 420.989,109.196 420.998,109.189 421.008,109.183 421.017,109.176 421.026,109.17 421.035,109.163 421.044,109.156 421.054,109.15 421.063,109.143 421.072,109.137 421.081,109.13 421.09,109.123 421.099,109.117 421.109,109.11 421.118,109.104 421.127,109.097 421.136,109.091 421.145,109.084 421.155,109.077 421.164,109.071 421.173,109.064 421.182,109.058 421.191,109.051 421.201,109.044 421.21,109.038 421.219,109.031 421.228,109.025 421.237,109.018 421.247,109.012 421.256,109.005 421.265,108.998 421.274,108.992 421.283,108.985 421.292,108.979 421.302,108.972 421.311,108.966 421.32,108.959 421.329,108.953 421.338,108.946 421.348,108.939 421.357,108.933 421.366,108.926 421.375,108.92 421.384,108.913 421.394,108.907 421.403,108.9 421.412,108.893 421.421,108.887 421.43,108.88 421.439,108.874 421.449,108.867 421.458,108.861 421.467,108.854 421.476,108.848 421.485,108.841 421.495,108.835 421.504,108.828 421.513,108.821 421.522,108.815 421.531,108.808 421.541,108.802 421.55,108.795 421.559,108.789 421.568,108.782 421.577,108.776 421.587,108.769 421.596,108.763 421.605,108.756 421.614,108.749 421.623,108.743 421.632,108.736 421.642,108.73 421.651,108.723 421.66,108.717 421.669,108.71 421.678,108.704 421.688,108.697 421.697,108.691 421.706,108.684 421.715,108.678 421.724,108.671 421.734,108.665 421.743,108.658 421.752,108.652 421.761,108.645 421.77,108.639 421.779,108.632 421.789,108.625 421.798,108.619 421.807,108.612 421.816,108.606 421.825,108.599 421.835,108.593 421.844,108.586 421.853,108.58 421.862,108.573 421.871,108.567 421.881,108.56 421.89,108.554 421.899,108.547 421.908,108.541 421.917,108.534 421.927,108.528 421.936,108.521 421.945,108.515 421.954,108.508 421.963,108.502 421.972,108.495 421.982,108.489 421.991,108.482 422,108.476 422.009,108.469 422.018,108.463 422.028,108.456 422.037,108.45 422.046,108.443 422.055,108.437 422.064,108.43 422.074,108.424 422.083,108.417 422.092,108.411 422.101,108.404 422.11,108.398 422.119,108.391 422.129,108.385 422.138,108.378 422.147,108.372 422.156,108.365 422.165,108.359 422.175,108.352 422.184,108.346 422.193,108.339 422.202,108.333 422.211,108.327 422.221,108.32 422.23,108.314 422.239,108.307 422.248,108.301 422.257,108.294 422.267,108.288 422.276,108.281 422.285,108.275 422.294,108.268 422.303,108.262 422.312,108.255 422.322,108.249 422.331,108.242 422.34,108.236 422.349,108.229 422.358,108.223 422.368,108.217 422.377,108.21 422.386,108.204 422.395,108.197 422.404,108.191 422.414,108.184 422.423,108.178 422.432,108.171 422.441,108.165 422.45,108.158 422.459,108.152 422.469,108.145 422.478,108.139 422.487,108.133 422.496,108.126 422.505,108.12 422.515,108.113 422.524,108.107 422.533,108.1 422.542,108.094 422.551,108.087 422.561,108.081 422.57,108.075 422.579,108.068 422.588,108.062 422.597,108.055 422.607,108.049 422.616,108.042 422.625,108.036 422.634,108.029 422.643,108.023 422.652,108.017 422.662,108.01 422.671,108.004 422.68,107.997 422.689,107.991 422.698,107.984 422.708,107.978 422.717,107.972 422.726,107.965 422.735,107.959 422.744,107.952 422.754,107.946 422.763,107.939 422.772,107.933 422.781,107.927 422.79,107.92 422.8,107.914 422.809,107.907 422.818,107.901 422.827,107.894 422.836,107.888 422.845,107.882 422.855,107.875 422.864,107.869 422.873,107.862 422.882,107.856 422.891,107.85 422.901,107.843 422.91,107.837 422.919,107.83 422.928,107.824 422.937,107.817 422.947,107.811 422.956,107.805 422.965,107.798 422.974,107.792 422.983,107.785 422.992,107.779 423.002,107.773 423.011,107.766 423.02,107.76 423.029,107.753 423.038,107.747 423.048,107.741 423.057,107.734 423.066,107.728 423.075,107.721 423.084,107.715 423.094,107.709 423.103,107.702 423.112,107.696 423.121,107.689 423.13,107.683 423.14,107.677 423.149,107.67 423.158,107.664 423.167,107.657 423.176,107.651 423.185,107.645 423.195,107.638 423.204,107.632 423.213,107.626 423.222,107.619 423.231,107.613 423.241,107.606 423.25,107.6 423.259,107.594 423.268,107.587 423.277,107.581 423.287,107.574 423.296,107.568 423.305,107.562 423.314,107.555 423.323,107.549 423.332,107.543 423.342,107.536 423.351,107.53 423.36,107.524 423.369,107.517 423.378,107.511 423.388,107.504 423.397,107.498 423.406,107.492 423.415,107.485 423.424,107.479 423.434,107.473 423.443,107.466 423.452,107.46 423.461,107.453 423.47,107.447 423.48,107.441 423.489,107.434 423.498,107.428 423.507,107.422 423.516,107.415 423.525,107.409 423.535,107.403 423.544,107.396 423.553,107.39 423.562,107.384 423.571,107.377 423.581,107.371 423.59,107.365 423.599,107.358 423.608,107.352 423.617,107.345 423.627,107.339 423.636,107.333 423.645,107.326 423.654,107.32 423.663,107.314 423.672,107.307 423.682,107.301 423.691,107.295 423.7,107.288 423.709,107.282 423.718,107.276 423.728,107.269 423.737,107.263 423.746,107.257 423.755,107.25 423.764,107.244 423.774,107.238 423.783,107.231 423.792,107.225 423.801,107.219 423.81,107.212 423.82,107.206 423.829,107.2 423.838,107.193 423.847,107.187 423.856,107.181 423.865,107.174 423.875,107.168 423.884,107.162 423.893,107.155 423.902,107.149 423.911,107.143 423.921,107.136 423.93,107.13 423.939,107.124 423.948,107.118 423.957,107.111 423.967,107.105 423.976,107.099 423.985,107.092 423.994,107.086 424.003,107.08 424.012,107.073 424.022,107.067 424.031,107.061 424.04,107.054 424.049,107.048 424.058,107.042 424.068,107.036 424.077,107.029 424.086,107.023 424.095,107.017 424.104,107.01 424.114,107.004 424.123,106.998 424.132,106.991 424.141,106.985 424.15,106.979 424.16,106.972 424.169,106.966 424.178,106.96 424.187,106.954 424.196,106.947 424.205,106.941 424.215,106.935 424.224,106.928 424.233,106.922 424.242,106.916 424.251,106.91 424.261,106.903 424.27,106.897 424.279,106.891 424.288,106.884 424.297,106.878 424.307,106.872 424.316,106.866 424.325,106.859 424.334,106.853 424.343,106.847 424.352,106.84 424.362,106.834 424.371,106.828 424.38,106.822 424.389,106.815 424.398,106.809 424.408,106.803 424.417,106.797 424.426,106.79 424.435,106.784 424.444,106.778 424.454,106.771 424.463,106.765 424.472,106.759 424.481,106.753 424.49,106.746 424.5,106.74 424.509,106.734 424.518,106.728 424.527,106.721 424.536,106.715 424.545,106.709 424.555,106.703 424.564,106.696 424.573,106.69 424.582,106.684 424.591,106.677 424.601,106.671 424.61,106.665 424.619,106.659 424.628,106.652 424.637,106.646 424.647,106.64 424.656,106.634 424.665,106.627 424.674,106.621 424.683,106.615 424.692,106.609 424.702,106.602 424.711,106.596 424.72,106.59 424.729,106.584 424.738,106.577 424.748,106.571 424.757,106.565 424.766,106.559 424.775,106.552 424.784,106.546 424.794,106.54 424.803,106.534 424.812,106.528 424.821,106.521 424.83,106.515 424.84,106.509 424.849,106.503 424.858,106.496 424.867,106.49 424.876,106.484 424.885,106.478 424.895,106.471 424.904,106.465 424.913,106.459 424.922,106.453 424.931,106.447 424.941,106.44 424.95,106.434 424.959,106.428 424.968,106.422 424.977,106.415 424.987,106.409 424.996,106.403 425.005,106.397 425.014,106.391 425.023,106.384 425.032,106.378 425.042,106.372 425.051,106.366 425.06,106.359 425.069,106.353 425.078,106.347 425.088,106.341 425.097,106.335 425.106,106.328 425.115,106.322 425.124,106.316 425.134,106.31 425.143,106.304 425.152,106.297 425.161,106.291 425.17,106.285 425.18,106.279 425.189,106.273 425.198,106.266 425.207,106.26 425.216,106.254 425.225,106.248 425.235,106.241 425.244,106.235 425.253,106.229 425.262,106.223 425.271,106.217 425.281,106.211 425.29,106.204 425.299,106.198 425.308,106.192 425.317,106.186 425.327,106.18 425.336,106.173 425.345,106.167 425.354,106.161 425.363,106.155 425.373,106.149 425.382,106.142 425.391,106.136 425.4,106.13 425.409,106.124 425.418,106.118 425.428,106.111 425.437,106.105 425.446,106.099 425.455,106.093 425.464,106.087 425.474,106.081 425.483,106.074 425.492,106.068 425.501,106.062 425.51,106.056 425.52,106.05 425.529,106.044 425.538,106.037 425.547,106.031 425.556,106.025 425.565,106.019 425.575,106.013 425.584,106.007 425.593,106 425.602,105.994 425.611,105.988 425.621,105.982 425.63,105.976 425.639,105.97 425.648,105.963 425.657,105.957 425.667,105.951 425.676,105.945 425.685,105.939 425.694,105.933 425.703,105.926 425.713,105.92 425.722,105.914 425.731,105.908 425.74,105.902 425.749,105.896 425.758,105.889 425.768,105.883 425.777,105.877 425.786,105.871 425.795,105.865 425.804,105.859 425.814,105.853 425.823,105.846 425.832,105.84 425.841,105.834 425.85,105.828 425.86,105.822 425.869,105.816 425.878,105.81 425.887,105.803 425.896,105.797 425.905,105.791 425.915,105.785 425.924,105.779 425.933,105.773 425.942,105.767 425.951,105.76 425.961,105.754 425.97,105.748 425.979,105.742 425.988,105.736 425.997,105.73 426.007,105.724 426.016,105.718 426.025,105.711 426.034,105.705 426.043,105.699 426.053,105.693 426.062,105.687 426.071,105.681 426.08,105.675 426.089,105.668 426.098,105.662 426.108,105.656 426.117,105.65 426.126,105.644 426.135,105.638 426.144,105.632 426.154,105.626 426.163,105.62 426.172,105.613 426.181,105.607 426.19,105.601 426.2,105.595 426.209,105.589 426.218,105.583 426.227,105.577 426.236,105.571 426.245,105.565 426.255,105.558 426.264,105.552 426.273,105.546 426.282,105.54 426.291,105.534 426.301,105.528 426.31,105.522 426.319,105.516 426.328,105.51 426.337,105.503 426.347,105.497 426.356,105.491 426.365,105.485 426.374,105.479 426.383,105.473 426.393,105.467 426.402,105.461 426.411,105.455 426.42,105.449 426.429,105.442 426.438,105.436 426.448,105.43 426.457,105.424 426.466,105.418 426.475,105.412 426.484,105.406 426.494,105.4 426.503,105.394 426.512,105.388 426.521,105.382 426.53,105.375 426.54,105.369 426.549,105.363 426.558,105.357 426.567,105.351 426.576,105.345 426.585,105.339 426.595,105.333 426.604,105.327 426.613,105.321 426.622,105.315 426.631,105.309 426.641,105.303 426.65,105.296 426.659,105.29 426.668,105.284 426.677,105.278 426.687,105.272 426.696,105.266 426.705,105.26 426.714,105.254 426.723,105.248 426.733,105.242 426.742,105.236 426.751,105.23 426.76,105.224 426.769,105.218 426.778,105.211 426.788,105.205 426.797,105.199 426.806,105.193 426.815,105.187 426.824,105.181 426.834,105.175 426.843,105.169 426.852,105.163 426.861,105.157 426.87,105.151 426.88,105.145 426.889,105.139 426.898,105.133 426.907,105.127 426.916,105.121 426.925,105.115 426.935,105.109 426.944,105.102 426.953,105.096 426.962,105.09 426.971,105.084 426.981,105.078 426.99,105.072 426.999,105.066 427.008,105.06 427.017,105.054 427.027,105.048 427.036,105.042 427.045,105.036 427.054,105.03 427.063,105.024 427.073,105.018 427.082,105.012 427.091,105.006 427.1,105 427.109,104.994 427.118,104.988 427.128,104.982 427.137,104.976 427.146,104.97 427.155,104.964 427.164,104.958 427.174,104.952 427.183,104.945 427.192,104.939 427.201,104.933 427.21,104.927 427.22,104.921 427.229,104.915 427.238,104.909 427.247,104.903 427.256,104.897 427.265,104.891 427.275,104.885 427.284,104.879 427.293,104.873 427.302,104.867 427.311,104.861 427.321,104.855 427.33,104.849 427.339,104.843 427.348,104.837 427.357,104.831 427.367,104.825 427.376,104.819 427.385,104.813 427.394,104.807 427.403,104.801 427.413,104.795 427.422,104.789 427.431,104.783 427.44,104.777 427.449,104.771 427.458,104.765 427.468,104.759 427.477,104.753 427.486,104.747 427.495,104.741 427.504,104.735 427.514,104.729 427.523,104.723 427.532,104.717 427.541,104.711 427.55,104.705 427.56,104.699 427.569,104.693 427.578,104.687 427.587,104.681 427.596,104.675 427.605,104.669 427.615,104.663 427.624,104.657 427.633,104.651 427.642,104.645 427.651,104.639 427.661,104.633 427.67,104.627 427.679,104.621 427.688,104.615 427.697,104.609 427.707,104.603 427.716,104.597 427.725,104.591 427.734,104.585 427.743,104.579 427.753,104.573 427.762,104.567 427.771,104.561 427.78,104.555 427.789,104.549 427.798,104.543 427.808,104.537 427.817,104.531 427.826,104.525 427.835,104.519 427.844,104.513 427.854,104.507 427.863,104.502 427.872,104.496 427.881,104.49 427.89,104.484 427.9,104.478 427.909,104.472 427.918,104.466 427.927,104.46 427.936,104.454 427.946,104.448 427.955,104.442 427.964,104.436 427.973,104.43 427.982,104.424 427.991,104.418 428.001,104.412 428.01,104.406 428.019,104.4 428.028,104.394 428.037,104.388 428.047,104.382 428.056,104.376 428.065,104.37 428.074,104.364 428.083,104.358 428.093,104.353 428.102,104.347 428.111,104.341 428.12,104.335 428.129,104.329 428.138,104.323 428.148,104.317 428.157,104.311 428.166,104.305 428.175,104.299 428.184,104.293 428.194,104.287 428.203,104.281 428.212,104.275 428.221,104.269 428.23,104.263 428.24,104.257 428.249,104.251 428.258,104.246 428.267,104.24 428.276,104.234 428.286,104.228 428.295,104.222 428.304,104.216 428.313,104.21 428.322,104.204 428.331,104.198 428.341,104.192 428.35,104.186 428.359,104.18 428.368,104.174 428.377,104.168 428.387,104.162 428.396,104.157 428.405,104.151 428.414,104.145 428.423,104.139 428.433,104.133 428.442,104.127 428.451,104.121 428.46,104.115 428.469,104.109 428.478,104.103 428.488,104.097 428.497,104.091 428.506,104.086 428.515,104.08 428.524,104.074 428.534,104.068 428.543,104.062 428.552,104.056 428.561,104.05 428.57,104.044 428.58,104.038 428.589,104.032 428.598,104.026 428.607,104.02 428.616,104.015 428.626,104.009 428.635,104.003 428.644,103.997 428.653,103.991 428.662,103.985 428.671,103.979 428.681,103.973 428.69,103.967 428.699,103.961 428.708,103.956 428.717,103.95 428.727,103.944 428.736,103.938 428.745,103.932 428.754,103.926 428.763,103.92 428.773,103.914 428.782,103.908 428.791,103.902 428.8,103.897 428.809,103.891 428.818,103.885 428.828,103.879 428.837,103.873 428.846,103.867 428.855,103.861 428.864,103.855 428.874,103.849 428.883,103.844 428.892,103.838 428.901,103.832 428.91,103.826 428.92,103.82 428.929,103.814 428.938,103.808 428.947,103.802 428.956,103.797 428.966,103.791 428.975,103.785 428.984,103.779 428.993,103.773 429.002,103.767 429.011,103.761 429.021,103.755 429.03,103.75 429.039,103.744 429.048,103.738 429.057,103.732 429.067,103.726 429.076,103.72 429.085,103.714 429.094,103.708 429.103,103.703 429.113,103.697 429.122,103.691 429.131,103.685 429.14,103.679 429.149,103.673 429.158,103.667 429.168,103.662 429.177,103.656 429.186,103.65 429.195,103.644 429.204,103.638 429.214,103.632 429.223,103.626 429.232,103.621 429.241,103.615 429.25,103.609 429.26,103.603 429.269,103.597 429.278,103.591 429.287,103.585 429.296,103.58 429.306,103.574 429.315,103.568 429.324,103.562 429.333,103.556 429.342,103.55 429.351,103.544 429.361,103.539 429.37,103.533 429.379,103.527 429.388,103.521 429.397,103.515 429.407,103.509 429.416,103.504 429.425,103.498 429.434,103.492 429.443,103.486 429.453,103.48 429.462,103.474 429.471,103.469 429.48,103.463 429.489,103.457 429.498,103.451 429.508,103.445 429.517,103.439 429.526,103.434 429.535,103.428 429.544,103.422 429.554,103.416 429.563,103.41 429.572,103.404 429.581,103.399 429.59,103.393 429.6,103.387 429.609,103.381 429.618,103.375 429.627,103.369 429.636,103.364 429.646,103.358 429.655,103.352 429.664,103.346 429.673,103.34 429.682,103.335 429.691,103.329 429.701,103.323 429.71,103.317 429.719,103.311 429.728,103.305 429.737,103.3 429.747,103.294 429.756,103.288 429.765,103.282 429.774,103.276 429.783,103.271 429.793,103.265 429.802,103.259 429.811,103.253 429.82,103.247 429.829,103.242 429.838,103.236 429.848,103.23 429.857,103.224 429.866,103.218 429.875,103.213 429.884,103.207 429.894,103.201 429.903,103.195 429.912,103.189 429.921,103.183 429.93,103.178 429.94,103.172 429.949,103.166 429.958,103.16 429.967,103.155 429.976,103.149 429.986,103.143 429.995,103.137 430.004,103.131 430.013,103.126 430.022,103.12 430.031,103.114 430.041,103.108 430.05,103.102 430.059,103.097 430.068,103.091 430.077,103.085 430.087,103.079 430.096,103.073 430.105,103.068 430.114,103.062 430.123,103.056 430.133,103.05 430.142,103.045 430.151,103.039 430.16,103.033 430.169,103.027 430.179,103.021 430.188,103.016 430.197,103.01 430.206,103.004 430.215,102.998 430.224,102.993 430.234,102.987 430.243,102.981 430.252,102.975 430.261,102.969 430.27,102.964 430.28,102.958 430.289,102.952 430.298,102.946 430.307,102.941 430.316,102.935 430.326,102.929 430.335,102.923 430.344,102.918 430.353,102.912 430.362,102.906 430.371,102.9 430.381,102.894 430.39,102.889 430.399,102.883 430.408,102.877 430.417,102.871 430.427,102.866 430.436,102.86 430.445,102.854 430.454,102.848 430.463,102.843 430.473,102.837 430.482,102.831 430.491,102.825 430.5,102.82 430.509,102.814 430.519,102.808 430.528,102.802 430.537,102.797 430.546,102.791 430.555,102.785 430.564,102.779 430.574,102.774 430.583,102.768 430.592,102.762 430.601,102.756 430.61,102.751 430.62,102.745 430.629,102.739 430.638,102.733 430.647,102.728 430.656,102.722 430.666,102.716 430.675,102.71 430.684,102.705 430.693,102.699 430.702,102.693 430.711,102.688 430.721,102.682 430.73,102.676 430.739,102.67 430.748,102.665 430.757,102.659 430.767,102.653 430.776,102.647 430.785,102.642 430.794,102.636 430.803,102.63 430.813,102.625 430.822,102.619 430.831,102.613 430.84,102.607 430.849,102.602 430.859,102.596 430.868,102.59 430.877,102.584 430.886,102.579 430.895,102.573 430.904,102.567 430.914,102.562 430.923,102.556 430.932,102.55 430.941,102.544 430.95,102.539 430.96,102.533 430.969,102.527 430.978,102.522 430.987,102.516 430.996,102.51 431.006,102.504 431.015,102.499 431.024,102.493 431.033,102.487 431.042,102.482 431.051,102.476 431.061,102.47 431.07,102.464 431.079,102.459 431.088,102.453 431.097,102.447 431.107,102.442 431.116,102.436 431.125,102.43 431.134,102.425 431.143,102.419 431.153,102.413 431.162,102.407 431.171,102.402 431.18,102.396 431.189,102.39 431.199,102.385 431.208,102.379 431.217,102.373 431.226,102.368 431.235,102.362 431.244,102.356 431.254,102.35 431.263,102.345 431.272,102.339 431.281,102.333 431.29,102.328 431.3,102.322 431.309,102.316 431.318,102.311 431.327,102.305 431.336,102.299 431.346,102.294 431.355,102.288 431.364,102.282 431.373,102.277 431.382,102.271 431.391,102.265 431.401,102.259 431.41,102.254 431.419,102.248 431.428,102.242 431.437,102.237 431.447,102.231 431.456,102.225 431.465,102.22 431.474,102.214 431.483,102.208 431.493,102.203 431.502,102.197 431.511,102.191 431.52,102.186 431.529,102.18 431.539,102.174 431.548,102.169 431.557,102.163 431.566,102.157 431.575,102.152 431.584,102.146 431.594,102.14 431.603,102.135 431.612,102.129 431.621,102.123 431.63,102.118 431.64,102.112 431.649,102.106 431.658,102.101 431.667,102.095 431.676,102.089 431.686,102.084 431.695,102.078 431.704,102.072 431.713,102.067 431.722,102.061 431.731,102.055 431.741,102.05 431.75,102.044 431.759,102.039 431.768,102.033 431.777,102.027 431.787,102.022 431.796,102.016 431.805,102.01 431.814,102.005 431.823,101.999 431.833,101.993 431.842,101.988 431.851,101.982 431.86,101.976 431.869,101.971 431.879,101.965 431.888,101.959 431.897,101.954 431.906,101.948 431.915,101.943 431.924,101.937 431.934,101.931 431.943,101.926 431.952,101.92 431.961,101.914 431.97,101.909 431.98,101.903 431.989,101.897 431.998,101.892 432.007,101.886 432.016,101.881 432.026,101.875 432.035,101.869 432.044,101.864 432.053,101.858 432.062,101.852 432.071,101.847 432.081,101.841 432.09,101.836 432.099,101.83 432.108,101.824 432.117,101.819 432.127,101.813 432.136,101.807 432.145,101.802 432.154,101.796 432.163,101.791 432.173,101.785 432.182,101.779 432.191,101.774 432.2,101.768 432.209,101.762 432.219,101.757 432.228,101.751 432.237,101.746 432.246,101.74 432.255,101.734 432.264,101.729 432.274,101.723 432.283,101.718 432.292,101.712 432.301,101.706 432.31,101.701 432.32,101.695 432.329,101.69 432.338,101.684 432.347,101.678 432.356,101.673 432.366,101.667 432.375,101.661 432.384,101.656 432.393,101.65 432.402,101.645 432.411,101.639 432.421,101.633 432.43,101.628 432.439,101.622 432.448,101.617 432.457,101.611 432.467,101.605 432.476,101.6 432.485,101.594 432.494,101.589 432.503,101.583 432.513,101.578 432.522,101.572 432.531,101.566 432.54,101.561 432.549,101.555 432.559,101.55 432.568,101.544 432.577,101.538 432.586,101.533 432.595,101.527 432.604,101.522 432.614,101.516 432.623,101.51 432.632,101.505 432.641,101.499 432.65,101.494 432.66,101.488 432.669,101.483 432.678,101.477 432.687,101.471 432.696,101.466 432.706,101.46 432.715,101.455 432.724,101.449 432.733,101.443 432.742,101.438 432.752,101.432 432.761,101.427 432.77,101.421 432.779,101.416 432.788,101.41 432.797,101.404 432.807,101.399 432.816,101.393 432.825,101.388 432.834,101.382 432.843,101.377 432.853,101.371 432.862,101.365 432.871,101.36 432.88,101.354 432.889,101.349 432.899,101.343 432.908,101.338 432.917,101.332 432.926,101.327 432.935,101.321 432.944,101.315 432.954,101.31 432.963,101.304 432.972,101.299 432.981,101.293 432.99,101.288 433,101.282 433.009,101.277 433.018,101.271 433.027,101.265 433.036,101.26 433.046,101.254 433.055,101.249 433.064,101.243 433.073,101.238 433.082,101.232 433.092,101.227 433.101,101.221 433.11,101.215 433.119,101.21 433.128,101.204 433.137,101.199 433.147,101.193 433.156,101.188 433.165,101.182 433.174,101.177 433.183,101.171 433.193,101.166 433.202,101.16 433.211,101.155 433.22,101.149 433.229,101.143 433.239,101.138 433.248,101.132 433.257,101.127 433.266,101.121 433.275,101.116 433.284,101.11 433.294,101.105 433.303,101.099 433.312,101.094 433.321,101.088 433.33,101.083 433.34,101.077 433.349,101.072 433.358,101.066 433.367,101.06 433.376,101.055 433.386,101.049 433.395,101.044 433.404,101.038 433.413,101.033 433.422,101.027 433.432,101.022 433.441,101.016 433.45,101.011 433.459,101.005 433.468,101 433.477,100.994 433.487,100.989 433.496,100.983 433.505,100.978 433.514,100.972 433.523,100.967 433.533,100.961 433.542,100.956 433.551,100.95 433.56,100.945 433.569,100.939 433.579,100.934 433.588,100.928 433.597,100.922 433.606,100.917 433.615,100.911 433.624,100.906 433.634,100.9 433.643,100.895 433.652,100.889 433.661,100.884 433.67,100.878 433.68,100.873 433.689,100.867 433.698,100.862 433.707,100.856 433.716,100.851 433.726,100.845 433.735,100.84 433.744,100.834 433.753,100.829 433.762,100.823 433.772,100.818 433.781,100.812 433.79,100.807 433.799,100.801 433.808,100.796 433.817,100.79 433.827,100.785 433.836,100.779 433.845,100.774 433.854,100.769 433.863,100.763 433.873,100.758 433.882,100.752 433.891,100.747 433.9,100.741 433.909,100.736 433.919,100.73 433.928,100.725 433.937,100.719 433.946,100.714 433.955,100.708 433.964,100.703 433.974,100.697 433.983,100.692 433.992,100.686 434.001,100.681 434.01,100.675 434.02,100.67 434.029,100.664 434.038,100.659 434.047,100.653 434.056,100.648 434.066,100.642 434.075,100.637 434.084,100.631 434.093,100.626 434.102,100.621 434.112,100.615 434.121,100.61 434.13,100.604 434.139,100.599 434.148,100.593 434.157,100.588 434.167,100.582 434.176,100.577 434.185,100.571 434.194,100.566 434.203,100.56 434.213,100.555 434.222,100.549 434.231,100.544 434.24,100.539 434.249,100.533 434.259,100.528 434.268,100.522 434.277,100.517 434.286,100.511 434.295,100.506 434.304,100.5 434.314,100.495 434.323,100.489 434.332,100.484 434.341,100.479 434.35,100.473 434.36,100.468 434.369,100.462 434.378,100.457 434.387,100.451 434.396,100.446 434.406,100.44 434.415,100.435 434.424,100.429 434.433,100.424 434.442,100.419 434.452,100.413 434.461,100.408 434.47,100.402 434.479,100.397 434.488,100.391 434.497,100.386 434.507,100.38 434.516,100.375 434.525,100.37 434.534,100.364 434.543,100.359 434.553,100.353 434.562,100.348 434.571,100.342 434.58,100.337 434.589,100.332 434.599,100.326 434.608,100.321 434.617,100.315 434.626,100.31 434.635,100.304 434.644,100.299 434.654,100.294 434.663,100.288 434.672,100.283 434.681,100.277 434.69,100.272 434.7,100.266 434.709,100.261 434.718,100.256 434.727,100.25 434.736,100.245 434.746,100.239 434.755,100.234 434.764,100.228 434.773,100.223 434.782,100.218 434.792,100.212 434.801,100.207 434.81,100.201 434.819,100.196 434.828,100.19 434.837,100.185 434.847,100.18 434.856,100.174 434.865,100.169 434.874,100.163 434.883,100.158 434.893,100.153 434.902,100.147 434.911,100.142 434.92,100.136 434.929,100.131 434.939,100.126 434.948,100.12 434.957,100.115 434.966,100.109 434.975,100.104 434.984,100.098 434.994,100.093 435.003,100.088 435.012,100.082 435.021,100.077 435.03,100.071 435.04,100.066 435.049,100.061 435.058,100.055 435.067,100.05 435.076,100.044 435.086,100.039 435.095,100.034 435.104,100.028 435.113,100.023 435.122,100.017 435.132,100.012 435.141,100.007 435.15,100.001 435.159,99.9959 435.168,99.9905 435.177,99.9851 435.187,99.9797 435.196,99.9743 435.205,99.9689 435.214,99.9636 435.223,99.9582 435.233,99.9528 435.242,99.9474 435.251,99.942 435.26,99.9366 435.269,99.9312 435.279,99.9259 435.288,99.9205 435.297,99.9151 435.306,99.9097 435.315,99.9043 435.325,99.8989 435.334,99.8936 435.343,99.8882 435.352,99.8828 435.361,99.8774 435.37,99.8721 435.38,99.8667 435.389,99.8613 435.398,99.8559 435.407,99.8506 435.416,99.8452 435.426,99.8398 435.435,99.8344 435.444,99.8291 435.453,99.8237 435.462,99.8183 435.472,99.813 435.481,99.8076 435.49,99.8022 435.499,99.7968 435.508,99.7915 435.517,99.7861 435.527,99.7807 435.536,99.7754 435.545,99.77 435.554,99.7647 435.563,99.7593 435.573,99.7539 435.582,99.7486 435.591,99.7432 435.6,99.7378 435.609,99.7325 435.619,99.7271 435.628,99.7218 435.637,99.7164 435.646,99.7111 435.655,99.7057 435.665,99.7003 435.674,99.695 435.683,99.6896 435.692,99.6843 435.701,99.6789 435.71,99.6736 435.72,99.6682 435.729,99.6629 435.738,99.6575 435.747,99.6522 435.756,99.6468 435.766,99.6415 435.775,99.6361 435.784,99.6308 435.793,99.6254 435.802,99.6201 435.812,99.6147 435.821,99.6094 435.83,99.6041 435.839,99.5987 435.848,99.5934 435.857,99.588 435.867,99.5827 435.876,99.5774 435.885,99.572 435.894,99.5667 435.903,99.5613 435.913,99.556 435.922,99.5507 435.931,99.5453 435.94,99.54 435.949,99.5347 435.959,99.5293 435.968,99.524 435.977,99.5187 435.986,99.5133 435.995,99.508 436.005,99.5027 436.014,99.4973 436.023,99.492 436.032,99.4867 436.041,99.4814 436.05,99.476 436.06,99.4707 436.069,99.4654 436.078,99.46 436.087,99.4547 436.096,99.4494 436.106,99.4441 436.115,99.4388 436.124,99.4334 436.133,99.4281 436.142,99.4228 436.152,99.4175 436.161,99.4121 436.17,99.4068 436.179,99.4015 436.188,99.3962 436.197,99.3909 436.207,99.3856 436.216,99.3802 436.225,99.3749 436.234,99.3696 436.243,99.3643 436.253,99.359 436.262,99.3537 436.271,99.3484 436.28,99.3431 436.289,99.3377 436.299,99.3324 436.308,99.3271 436.317,99.3218 436.326,99.3165 436.335,99.3112 436.345,99.3059 436.354,99.3006 436.363,99.2953 436.372,99.29 436.381,99.2847 436.39,99.2794 436.4,99.2741 436.409,99.2688 436.418,99.2635 436.427,99.2582 436.436,99.2529 436.446,99.2476 436.455,99.2423 436.464,99.237 436.473,99.2317 436.482,99.2264 436.492,99.2211 436.501,99.2158 436.51,99.2105 436.519,99.2052 436.528,99.1999 436.537,99.1946 436.547,99.1893 436.556,99.1841 436.565,99.1788 436.574,99.1735 436.583,99.1682 436.593,99.1629 436.602,99.1576 436.611,99.1523 436.62,99.147 436.629,99.1417 436.639,99.1365 436.648,99.1312 436.657,99.1259 436.666,99.1206 436.675,99.1153 436.685,99.1101 436.694,99.1048 436.703,99.0995 436.712,99.0942 436.721,99.0889 436.73,99.0837 436.74,99.0784 436.749,99.0731 436.758,99.0678 436.767,99.0625 436.776,99.0573 436.786,99.052 436.795,99.0467 436.804,99.0415 436.813,99.0362 436.822,99.0309 436.832,99.0256 436.841,99.0204 436.85,99.0151 436.859,99.0098 436.868,99.0046 436.877,98.9993 436.887,98.994 436.896,98.9888 436.905,98.9835 436.914,98.9782 436.923,98.973 436.933,98.9677 436.942,98.9624 436.951,98.9572 436.96,98.9519 436.969,98.9467 436.979,98.9414 436.988,98.9361 436.997,98.9309 437.006,98.9256 437.015,98.9204 437.025,98.9151 437.034,98.9098 437.043,98.9046 437.052,98.8993 437.061,98.8941 437.07,98.8888 437.08,98.8836 437.089,98.8783 437.098,98.8731 437.107,98.8678 437.116,98.8626 437.126,98.8573 437.135,98.8521 437.144,98.8468 437.153,98.8416 437.162,98.8363 437.172,98.8311 437.181,98.8258 437.19,98.8206 437.199,98.8153 437.208,98.8101 437.217,98.8049 437.227,98.7996 437.236,98.7944 437.245,98.7891 437.254,98.7839 437.263,98.7787 437.273,98.7734 437.282,98.7682 437.291,98.7629 437.3,98.7577 437.309,98.7525 437.319,98.7472 437.328,98.742 437.337,98.7368 437.346,98.7315 437.355,98.7263 437.365,98.7211 437.374,98.7158 437.383,98.7106 437.392,98.7054 437.401,98.7001 437.41,98.6949 437.42,98.6897 437.429,98.6844 437.438,98.6792 437.447,98.674 437.456,98.6688 437.466,98.6635 437.475,98.6583 437.484,98.6531 437.493,98.6479 437.502,98.6426 437.512,98.6374 437.521,98.6322 437.53,98.627 437.539,98.6218 437.548,98.6165 437.558,98.6113 437.567,98.6061 437.576,98.6009 437.585,98.5957 437.594,98.5904 437.603,98.5852 437.613,98.58 437.622,98.5748 437.631,98.5696 437.64,98.5644 437.649,98.5592 437.659,98.5539 437.668,98.5487 437.677,98.5435 437.686,98.5383 437.695,98.5331 437.705,98.5279 437.714,98.5227 437.723,98.5175 437.732,98.5123 437.741,98.5071 437.75,98.5019 437.76,98.4967 437.769,98.4915 437.778,98.4863 437.787,98.481 437.796,98.4758 437.806,98.4706 437.815,98.4654 437.824,98.4602 437.833,98.455 437.842,98.4498 437.852,98.4446 437.861,98.4394 437.87,98.4343 437.879,98.4291 437.888,98.4239 437.898,98.4187 437.907,98.4135 437.916,98.4083 437.925,98.4031 437.934,98.3979 437.943,98.3927 437.953,98.3875 437.962,98.3823 437.971,98.3771 437.98,98.3719 437.989,98.3667 437.999,98.3616 438.008,98.3564 438.017,98.3512 438.026,98.346 438.035,98.3408 438.045,98.3356 438.054,98.3304 438.063,98.3253 438.072,98.3201 438.081,98.3149 438.09,98.3097 438.1,98.3045 438.109,98.2994 438.118,98.2942 438.127,98.289 438.136,98.2838 438.146,98.2786 438.155,98.2735 438.164,98.2683 438.173,98.2631 438.182,98.2579 438.192,98.2528 438.201,98.2476 438.21,98.2424 438.219,98.2372 438.228,98.2321 438.238,98.2269 438.247,98.2217 438.256,98.2166 438.265,98.2114 438.274,98.2062 438.283,98.2011 438.293,98.1959 438.302,98.1907 438.311,98.1856 438.32,98.1804 438.329,98.1752 438.339,98.1701 438.348,98.1649 438.357,98.1597 438.366,98.1546 438.375,98.1494 438.385,98.1442 438.394,98.1391 438.403,98.1339 438.412,98.1288 438.421,98.1236 438.43,98.1185 438.44,98.1133 438.449,98.1081 438.458,98.103 438.467,98.0978 438.476,98.0927 438.486,98.0875 438.495,98.0824 438.504,98.0772 438.513,98.0721 438.522,98.0669 438.532,98.0618 438.541,98.0566 438.55,98.0515 438.559,98.0463 438.568,98.0412 438.578,98.036 438.587,98.0309 438.596,98.0257 438.605,98.0206 438.614,98.0154 438.623,98.0103 438.633,98.0051 438.642,98 438.651,97.9949 438.66,97.9897 438.669,97.9846 438.679,97.9794 438.688,97.9743 438.697,97.9692 438.706,97.964 438.715,97.9589 438.725,97.9537 438.734,97.9486 438.743,97.9435 438.752,97.9383 438.761,97.9332 438.77,97.9281 438.78,97.9229 438.789,97.9178 438.798,97.9127 438.807,97.9075 438.816,97.9024 438.826,97.8973 438.835,97.8921 438.844,97.887 438.853,97.8819 438.862,97.8768 438.872,97.8716 438.881,97.8665 438.89,97.8614 438.899,97.8562 438.908,97.8511 438.918,97.846 438.927,97.8409 438.936,97.8358 438.945,97.8306 438.954,97.8255 438.963,97.8204 438.973,97.8153 438.982,97.8102 438.991,97.805 439,97.7999 439.009,97.7948 439.019,97.7897 439.028,97.7846 439.037,97.7794 439.046,97.7743 439.055,97.7692 439.065,97.7641 439.074,97.759 439.083,97.7539 439.092,97.7488 439.101,97.7437 439.11,97.7385 439.12,97.7334 439.129,97.7283 439.138,97.7232 439.147,97.7181 439.156,97.713 439.166,97.7079 439.175,97.7028 439.184,97.6977 439.193,97.6926 439.202,97.6875 439.212,97.6824 439.221,97.6773 439.23,97.6722 439.239,97.6671 439.248,97.662 439.258,97.6569 439.267,97.6518 439.276,97.6467 439.285,97.6416 439.294,97.6365 439.303,97.6314 439.313,97.6263 439.322,97.6212 439.331,97.6161 439.34,97.611 439.349,97.6059 439.359,97.6008 439.368,97.5957 439.377,97.5906 439.386,97.5855 439.395,97.5804 439.405,97.5753 439.414,97.5702 439.423,97.5652 439.432,97.5601 439.441,97.555 439.45,97.5499 439.46,97.5448 439.469,97.5397 439.478,97.5346 439.487,97.5295 439.496,97.5245 439.506,97.5194 439.515,97.5143 439.524,97.5092 439.533,97.5041 439.542,97.4991 439.552,97.494 439.561,97.4889 439.57,97.4838 439.579,97.4787 439.588,97.4737 439.598,97.4686 439.607,97.4635 439.616,97.4584 439.625,97.4534 439.634,97.4483 439.643,97.4432 439.653,97.4381 439.662,97.4331 439.671,97.428 439.68,97.4229 439.689,97.4178 439.699,97.4128 439.708,97.4077 439.717,97.4026 439.726,97.3976 439.735,97.3925 439.745,97.3874 439.754,97.3824 439.763,97.3773 439.772,97.3722 439.781,97.3672 439.79,97.3621 439.8,97.357 439.809,97.352 439.818,97.3469 439.827,97.3419 439.836,97.3368 439.846,97.3317 439.855,97.3267 439.864,97.3216 439.873,97.3166 439.882,97.3115 439.892,97.3064 439.901,97.3014 439.91,97.2963 439.919,97.2913 439.928,97.2862 439.938,97.2812 439.947,97.2761 439.956,97.2711 439.965,97.266 439.974,97.261 439.983,97.2559 439.993,97.2509 440.002,97.2458 440.011,97.2408 440.02,97.2357 440.029,97.2307 440.039,97.2256 440.048,97.2206 440.057,97.2155 440.066,97.2105 440.075,97.2054 440.085,97.2004 440.094,97.1953 440.103,97.1903 440.112,97.1853 440.121,97.1802 440.131,97.1752 440.14,97.1701 440.149,97.1651 440.158,97.16 440.167,97.155 440.176,97.15 440.186,97.1449 440.195,97.1399 440.204,97.1349 440.213,97.1298 440.222,97.1248 440.232,97.1198 440.241,97.1147 440.25,97.1097 440.259,97.1047 440.268,97.0996 440.278,97.0946 440.287,97.0896 440.296,97.0845 440.305,97.0795 440.314,97.0745 440.323,97.0695 440.333,97.0644 440.342,97.0594 440.351,97.0544 440.36,97.0493 440.369,97.0443 440.379,97.0393 440.388,97.0343 440.397,97.0292 440.406,97.0242 440.415,97.0192 440.425,97.0142 440.434,97.0092 440.443,97.0041 440.452,96.9991 440.461,96.9941 440.471,96.9891 440.48,96.9841 440.489,96.9791 440.498,96.974 440.507,96.969 440.516,96.964 440.526,96.959 440.535,96.954 440.544,96.949 440.553,96.944 440.562,96.9389 440.572,96.9339 440.581,96.9289 440.59,96.9239 440.599,96.9189 440.608,96.9139 440.618,96.9089 440.627,96.9039 440.636,96.8989 440.645,96.8939 440.654,96.8889 440.663,96.8838 440.673,96.8788 440.682,96.8738 440.691,96.8688 440.7,96.8638 440.709,96.8588 440.719,96.8538 440.728,96.8488 440.737,96.8438 440.746,96.8388 440.755,96.8338 440.765,96.8288 440.774,96.8238 440.783,96.8188 440.792,96.8138 440.801,96.8088 440.811,96.8039 440.82,96.7989 440.829,96.7939 440.838,96.7889 440.847,96.7839 440.856,96.7789 440.866,96.7739 440.875,96.7689 440.884,96.7639 440.893,96.7589 440.902,96.7539 440.912,96.7489 440.921,96.744 440.93,96.739 440.939,96.734 440.948,96.729 440.958,96.724 440.967,96.719 440.976,96.714 440.985,96.7091 440.994,96.7041 441.003,96.6991 441.013,96.6941 441.022,96.6891 441.031,96.6841 441.04,96.6792 441.049,96.6742 441.059,96.6692 441.068,96.6642 441.077,96.6593 441.086,96.6543 441.095,96.6493 441.105,96.6443 441.114,96.6393 441.123,96.6344 441.132,96.6294 441.141,96.6244 441.151,96.6195 441.16,96.6145 441.169,96.6095 441.178,96.6045 441.187,96.5996 441.196,96.5946 441.206,96.5896 441.215,96.5847 441.224,96.5797 441.233,96.5747 441.242,96.5698 441.252,96.5648 441.261,96.5598 441.27,96.5549 441.279,96.5499 441.288,96.5449 441.298,96.54 441.307,96.535 441.316,96.5301 441.325,96.5251 441.334,96.5201 441.343,96.5152 441.353,96.5102 441.362,96.5053 441.371,96.5003 441.38,96.4953 441.389,96.4904 441.399,96.4854 441.408,96.4805 441.417,96.4755 441.426,96.4706 441.435,96.4656 441.445,96.4607 441.454,96.4557 441.463,96.4507 441.472,96.4458 441.481,96.4408 441.491,96.4359 441.5,96.4309 441.509,96.426 441.518,96.4211 441.527,96.4161 441.536,96.4112 441.546,96.4062 441.555,96.4013 441.564,96.3963 441.573,96.3914 441.582,96.3864 441.592,96.3815 441.601,96.3765 441.61,96.3716 441.619,96.3667 441.628,96.3617 441.638,96.3568 441.647,96.3518 441.656,96.3469 441.665,96.342 441.674,96.337 441.683,96.3321 441.693,96.3271 441.702,96.3222 441.711,96.3173 441.72,96.3123 441.729,96.3074 441.739,96.3025 441.748,96.2975 441.757,96.2926 441.766,96.2877 441.775,96.2827 441.785,96.2778 441.794,96.2729 441.803,96.268 441.812,96.263 441.821,96.2581 441.831,96.2532 441.84,96.2482 441.849,96.2433 441.858,96.2384 441.867,96.2335 441.876,96.2285 441.886,96.2236 441.895,96.2187 441.904,96.2138 441.913,96.2088 441.922,96.2039 441.932,96.199 441.941,96.1941 441.95,96.1892 441.959,96.1842 441.968,96.1793 441.978,96.1744 441.987,96.1695 441.996,96.1646 442.005,96.1597 442.014,96.1547 442.023,96.1498 442.033,96.1449 442.042,96.14 442.051,96.1351 442.06,96.1302 442.069,96.1253 442.079,96.1204 442.088,96.1154 442.097,96.1105 442.106,96.1056 442.115,96.1007 442.125,96.0958 442.134,96.0909 442.143,96.086 442.152,96.0811 442.161,96.0762 442.171,96.0713 442.18,96.0664 442.189,96.0615 442.198,96.0566 442.207,96.0517 442.216,96.0468 442.226,96.0418 442.235,96.0369 442.244,96.032 442.253,96.0271 442.262,96.0222 442.272,96.0173 442.281,96.0125 442.29,96.0076 442.299,96.0027 442.308,95.9978 442.318,95.9929 442.327,95.988 442.336,95.9831 442.345,95.9782 442.354,95.9733 442.363,95.9684 442.373,95.9635 442.382,95.9586 442.391,95.9537 442.4,95.9488 442.409,95.9439 442.419,95.9391 442.428,95.9342 442.437,95.9293 442.446,95.9244 442.455,95.9195 442.465,95.9146 442.474,95.9097 442.483,95.9048 442.492,95.9 442.501,95.8951 442.511,95.8902 442.52,95.8853 442.529,95.8804 442.538,95.8755 442.547,95.8707 442.556,95.8658 442.566,95.8609 442.575,95.856 442.584,95.8511 442.593,95.8463 442.602,95.8414 442.612,95.8365 442.621,95.8316 442.63,95.8268 442.639,95.8219 442.648,95.817 442.658,95.8121 442.667,95.8073 442.676,95.8024 442.685,95.7975 442.694,95.7927 442.704,95.7878 442.713,95.7829 442.722,95.778 442.731,95.7732 442.74,95.7683 442.749,95.7634 442.759,95.7586 442.768,95.7537 442.777,95.7488 442.786,95.744 442.795,95.7391 442.805,95.7342 442.814,95.7294 442.823,95.7245 442.832,95.7197 442.841,95.7148 442.851,95.7099 442.86,95.7051 442.869,95.7002 442.878,95.6953 442.887,95.6905 442.896,95.6856 442.906,95.6808 442.915,95.6759 442.924,95.6711 442.933,95.6662 442.942,95.6613 442.952,95.6565 442.961,95.6516 442.97,95.6468 442.979,95.6419 442.988,95.6371 442.998,95.6322 443.007,95.6274 443.016,95.6225 443.025,95.6177 443.034,95.6128 443.044,95.608 443.053,95.6031 443.062,95.5983 443.071,95.5934 443.08,95.5886 443.089,95.5837 443.099,95.5789 443.108,95.5741 443.117,95.5692 443.126,95.5644 443.135,95.5595 443.145,95.5547 443.154,95.5498 443.163,95.545 443.172,95.5402 443.181,95.5353 443.191,95.5305 443.2,95.5256 443.209,95.5208 443.218,95.516 443.227,95.5111 443.236,95.5063 443.246,95.5015 443.255,95.4966 443.264,95.4918 443.273,95.487 443.282,95.4821 443.292,95.4773 443.301,95.4725 443.31,95.4676 443.319,95.4628 443.328,95.458 443.338,95.4531 443.347,95.4483 443.356,95.4435 443.365,95.4386 443.374,95.4338 443.384,95.429 443.393,95.4242 443.402,95.4193 443.411,95.4145 443.42,95.4097 443.429,95.4049 443.439,95.4 443.448,95.3952 443.457,95.3904 443.466,95.3856 443.475,95.3808 443.485,95.3759 443.494,95.3711 443.503,95.3663 443.512,95.3615 443.521,95.3567 443.531,95.3518 443.54,95.347 443.549,95.3422 443.558,95.3374 443.567,95.3326 443.576,95.3278 443.586,95.3229 443.595,95.3181 443.604,95.3133 443.613,95.3085 443.622,95.3037 443.632,95.2989 443.641,95.2941 443.65,95.2893 443.659,95.2845 443.668,95.2796 443.678,95.2748 443.687,95.27 443.696,95.2652 443.705,95.2604 443.714,95.2556 443.724,95.2508 443.733,95.246 443.742,95.2412 443.751,95.2364 443.76,95.2316 443.769,95.2268 443.779,95.222 443.788,95.2172 443.797,95.2124 443.806,95.2076 443.815,95.2028 443.825,95.198 443.834,95.1932 443.843,95.1884 443.852,95.1836 443.861,95.1788 443.871,95.174 443.88,95.1692 443.889,95.1644 443.898,95.1596 443.907,95.1548 443.916,95.15 443.926,95.1452 443.935,95.1404 443.944,95.1357 443.953,95.1309 443.962,95.1261 443.972,95.1213 443.981,95.1165 443.99,95.1117 443.999,95.1069 444.008,95.1021 444.018,95.0973 444.027,95.0926 444.036,95.0878 444.045,95.083 444.054,95.0782 444.064,95.0734 444.073,95.0686 444.082,95.0639 444.091,95.0591 444.1,95.0543 444.109,95.0495 444.119,95.0447 444.128,95.04 444.137,95.0352 444.146,95.0304 444.155,95.0256 444.165,95.0208 444.174,95.0161 444.183,95.0113 444.192,95.0065 444.201,95.0017 444.211,94.997 444.22,94.9922 444.229,94.9874 444.238,94.9826 444.247,94.9779 444.256,94.9731 444.266,94.9683 444.275,94.9636 444.284,94.9588 444.293,94.954 444.302,94.9493 444.312,94.9445 444.321,94.9397 444.33,94.935 444.339,94.9302 444.348,94.9254 444.358,94.9207 444.367,94.9159 444.376,94.9111 444.385,94.9064 444.394,94.9016 444.404,94.8968 444.413,94.8921 444.422,94.8873 444.431,94.8826 444.44,94.8778 444.449,94.873 444.459,94.8683 444.468,94.8635 444.477,94.8588 444.486,94.854 444.495,94.8492 444.505,94.8445 444.514,94.8397 444.523,94.835 444.532,94.8302 444.541,94.8255 444.551,94.8207 444.56,94.816 444.569,94.8112 444.578,94.8065 444.587,94.8017 444.596,94.797 444.606,94.7922 444.615,94.7875 444.624,94.7827 444.633,94.778 444.642,94.7732 444.652,94.7685 444.661,94.7637 444.67,94.759 444.679,94.7542 444.688,94.7495 444.698,94.7448 444.707,94.74 444.716,94.7353 444.725,94.7305 444.734,94.7258 444.744,94.721 444.753,94.7163 444.762,94.7116 444.771,94.7068 444.78,94.7021 444.789,94.6973 444.799,94.6926 444.808,94.6879 444.817,94.6831 444.826,94.6784 444.835,94.6737 444.845,94.6689 444.854,94.6642 444.863,94.6595 444.872,94.6547 444.881,94.65 444.891,94.6453 444.9,94.6405 444.909,94.6358 444.918,94.6311 444.927,94.6263 444.937,94.6216 444.946,94.6169 444.955,94.6122 444.964,94.6074 444.973,94.6027 444.982,94.598 444.992,94.5933 445.001,94.5885 445.01,94.5838 445.019,94.5791 445.028,94.5744 445.038,94.5696 445.047,94.5649 445.056,94.5602 445.065,94.5555 445.074,94.5508 445.084,94.546 445.093,94.5413 445.102,94.5366 445.111,94.5319 445.12,94.5272 445.129,94.5224 445.139,94.5177 445.148,94.513 445.157,94.5083 445.166,94.5036 445.175,94.4989 445.185,94.4942 445.194,94.4894 445.203,94.4847 445.212,94.48 445.221,94.4753 445.231,94.4706 445.24,94.4659 445.249,94.4612 445.258,94.4565 445.267,94.4518 445.277,94.4471 445.286,94.4423 445.295,94.4376 445.304,94.4329 445.313,94.4282 445.322,94.4235 445.332,94.4188 445.341,94.4141 445.35,94.4094 445.359,94.4047 445.368,94.4 445.378,94.3953 445.387,94.3906 445.396,94.3859 445.405,94.3812 445.414,94.3765 445.424,94.3718 445.433,94.3671 445.442,94.3624 445.451,94.3577 445.46,94.353 445.469,94.3483 445.479,94.3436 445.488,94.3389 445.497,94.3342 445.506,94.3296 445.515,94.3249 445.525,94.3202 445.534,94.3155 445.543,94.3108 445.552,94.3061 445.561,94.3014 445.571,94.2967 445.58,94.292 445.589,94.2873 445.598,94.2826 445.607,94.278 445.617,94.2733 445.626,94.2686 445.635,94.2639 445.644,94.2592 445.653,94.2545 445.662,94.2498 445.672,94.2452 445.681,94.2405 445.69,94.2358 445.699,94.2311 445.708,94.2264 445.718,94.2218 445.727,94.2171 445.736,94.2124 445.745,94.2077 445.754,94.203 445.764,94.1984 445.773,94.1937 445.782,94.189 445.791,94.1843 445.8,94.1797 445.809,94.175 445.819,94.1703 445.828,94.1656 445.837,94.161 445.846,94.1563 445.855,94.1516 445.865,94.147 445.874,94.1423 445.883,94.1376 445.892,94.1329 445.901,94.1283 445.911,94.1236 445.92,94.1189 445.929,94.1143 445.938,94.1096 445.947,94.1049 445.957,94.1003 445.966,94.0956 445.975,94.0909 445.984,94.0863 445.993,94.0816 446.002,94.0769 446.012,94.0723 446.021,94.0676 446.03,94.063 446.039,94.0583 446.048,94.0536 446.058,94.049 446.067,94.0443 446.076,94.0397 446.085,94.035 446.094,94.0304 446.104,94.0257 446.113,94.021 446.122,94.0164 446.131,94.0117 446.14,94.0071 446.149,94.0024 446.159,93.9978 446.168,93.9931 446.177,93.9885 446.186,93.9838 446.195,93.9792 446.205,93.9745 446.214,93.9699 446.223,93.9652 446.232,93.9606 446.241,93.9559 446.251,93.9513 446.26,93.9466 446.269,93.942 446.278,93.9373 446.287,93.9327 446.297,93.928 446.306,93.9234 446.315,93.9187 446.324,93.9141 446.333,93.9095 446.342,93.9048 446.352,93.9002 446.361,93.8955 446.37,93.8909 446.379,93.8863 446.388,93.8816 446.398,93.877 446.407,93.8723 446.416,93.8677 446.425,93.8631 446.434,93.8584 446.444,93.8538 446.453,93.8492 446.462,93.8445 446.471,93.8399 446.48,93.8353 446.489,93.8306 446.499,93.826 446.508,93.8214 446.517,93.8167 446.526,93.8121 446.535,93.8075 446.545,93.8028 446.554,93.7982 446.563,93.7936 446.572,93.789 446.581,93.7843 446.591,93.7797 446.6,93.7751 446.609,93.7704 446.618,93.7658 446.627,93.7612 446.637,93.7566 446.646,93.7519 446.655,93.7473 446.664,93.7427 446.673,93.7381 446.682,93.7335 446.692,93.7288 446.701,93.7242 446.71,93.7196 446.719,93.715 446.728,93.7104 446.738,93.7057 446.747,93.7011 446.756,93.6965 446.765,93.6919 446.774,93.6873 446.784,93.6827 446.793,93.678 446.802,93.6734 446.811,93.6688 446.82,93.6642 446.829,93.6596 446.839,93.655 446.848,93.6504 446.857,93.6458 446.866,93.6411 446.875,93.6365 446.885,93.6319 446.894,93.6273 446.903,93.6227 446.912,93.6181 446.921,93.6135 446.931,93.6089 446.94,93.6043 446.949,93.5997 446.958,93.5951 446.967,93.5905 446.977,93.5859 446.986,93.5813 446.995,93.5767 447.004,93.5721 447.013,93.5675 447.022,93.5629 447.032,93.5583 447.041,93.5537 447.05,93.5491 447.059,93.5445 447.068,93.5399 447.078,93.5353 447.087,93.5307 447.096,93.5261 447.105,93.5215 447.114,93.5169 447.124,93.5123 447.133,93.5077 447.142,93.5031 447.151,93.4985 447.16,93.4939 447.169,93.4893 447.179,93.4847 447.188,93.4801 447.197,93.4755 447.206,93.471 447.215,93.4664 447.225,93.4618 447.234,93.4572 447.243,93.4526 447.252,93.448 447.261,93.4434 447.271,93.4388 447.28,93.4343 447.289,93.4297 447.298,93.4251 447.307,93.4205 447.317,93.4159 447.326,93.4113 447.335,93.4068 447.344,93.4022 447.353,93.3976 447.362,93.393 447.372,93.3884 447.381,93.3839 447.39,93.3793 447.399,93.3747 447.408,93.3701 447.418,93.3655 447.427,93.361 447.436,93.3564 447.445,93.3518 447.454,93.3472 447.464,93.3427 447.473,93.3381 447.482,93.3335 447.491,93.329 447.5,93.3244 447.51,93.3198 447.519,93.3152 447.528,93.3107 447.537,93.3061 447.546,93.3015 447.555,93.297 447.565,93.2924 447.574,93.2878 447.583,93.2833 447.592,93.2787 447.601,93.2741 447.611,93.2696 447.62,93.265 447.629,93.2604 447.638,93.2559 447.647,93.2513 447.657,93.2467 447.666,93.2422 447.675,93.2376 447.684,93.2331 447.693,93.2285 447.702,93.2239 447.712,93.2194 447.721,93.2148 447.73,93.2103 447.739,93.2057 447.748,93.2011 447.758,93.1966 447.767,93.192 447.776,93.1875 447.785,93.1829 447.794,93.1784 447.804,93.1738 447.813,93.1693 447.822,93.1647 447.831,93.1602 447.84,93.1556 447.85,93.151 447.859,93.1465 447.868,93.1419 447.877,93.1374 447.886,93.1329 447.895,93.1283 447.905,93.1238 447.914,93.1192 447.923,93.1147 447.932,93.1101 447.941,93.1056 447.951,93.101 447.96,93.0965 447.969,93.0919 447.978,93.0874 447.987,93.0828 447.997,93.0783 448.006,93.0738 448.015,93.0692 448.024,93.0647 448.033,93.0601 448.042,93.0556 448.052,93.0511 448.061,93.0465 448.07,93.042 448.079,93.0374 448.088,93.0329 448.098,93.0284 448.107,93.0238 448.116,93.0193 448.125,93.0148 448.134,93.0102 448.144,93.0057 448.153,93.0012 448.162,92.9966 448.171,92.9921 448.18,92.9876 448.19,92.983 448.199,92.9785 448.208,92.974 448.217,92.9694 448.226,92.9649 448.235,92.9604 448.245,92.9559 448.254,92.9513 448.263,92.9468 448.272,92.9423 448.281,92.9378 448.291,92.9332 448.3,92.9287 448.309,92.9242 448.318,92.9197 448.327,92.9151 448.337,92.9106 448.346,92.9061 448.355,92.9016 448.364,92.8971 448.373,92.8925 448.382,92.888 448.392,92.8835 448.401,92.879 448.41,92.8745 448.419,92.8699 448.428,92.8654 448.438,92.8609 448.447,92.8564 448.456,92.8519 448.465,92.8474 448.474,92.8428 448.484,92.8383 448.493,92.8338 448.502,92.8293 448.511,92.8248 448.52,92.8203 448.53,92.8158 448.539,92.8113 448.548,92.8068 448.557,92.8022 448.566,92.7977 448.575,92.7932 448.585,92.7887 448.594,92.7842 448.603,92.7797 448.612,92.7752 448.621,92.7707 448.631,92.7662 448.64,92.7617 448.649,92.7572 448.658,92.7527 448.667,92.7482 448.677,92.7437 448.686,92.7392 448.695,92.7347 448.704,92.7302 448.713,92.7257 448.722,92.7212 448.732,92.7167 448.741,92.7122 448.75,92.7077 448.759,92.7032 448.768,92.6987 448.778,92.6942 448.787,92.6897 448.796,92.6852 448.805,92.6807 448.814,92.6762 448.824,92.6717 448.833,92.6672 448.842,92.6627 448.851,92.6582 448.86,92.6537 448.87,92.6492 448.879,92.6448 448.888,92.6403 448.897,92.6358 448.906,92.6313 448.915,92.6268 448.925,92.6223 448.934,92.6178 448.943,92.6133 448.952,92.6089 448.961,92.6044 448.971,92.5999 448.98,92.5954 448.989,92.5909 448.998,92.5864 449.007,92.5819 449.017,92.5775 449.026,92.573 449.035,92.5685 449.044,92.564 449.053,92.5595 449.062,92.5551 449.072,92.5506 449.081,92.5461 449.09,92.5416 449.099,92.5372 449.108,92.5327 449.118,92.5282 449.127,92.5237 449.136,92.5192 449.145,92.5148 449.154,92.5103 449.164,92.5058 449.173,92.5013 449.182,92.4969 449.191,92.4924 449.2,92.4879 449.21,92.4835 449.219,92.479 449.228,92.4745 449.237,92.4701 449.246,92.4656 449.255,92.4611 449.265,92.4566 449.274,92.4522 449.283,92.4477 449.292,92.4432 449.301,92.4388 449.311,92.4343 449.32,92.4299 449.329,92.4254 449.338,92.4209 449.347,92.4165 449.357,92.412 449.366,92.4075 449.375,92.4031 449.384,92.3986 449.393,92.3942 449.402,92.3897 449.412,92.3852 449.421,92.3808 449.43,92.3763 449.439,92.3719 449.448,92.3674 449.458,92.3629 449.467,92.3585 449.476,92.354 449.485,92.3496 449.494,92.3451 449.504,92.3407 449.513,92.3362 449.522,92.3318 449.531,92.3273 449.54,92.3229 449.55,92.3184 449.559,92.314 449.568,92.3095 449.577,92.3051 449.586,92.3006 449.595,92.2962 449.605,92.2917 449.614,92.2873 449.623,92.2828 449.632,92.2784 449.641,92.2739 449.651,92.2695 449.66,92.265 449.669,92.2606 449.678,92.2561 449.687,92.2517 449.697,92.2473 449.706,92.2428 449.715,92.2384 449.724,92.2339 449.733,92.2295 449.742,92.2251 449.752,92.2206 449.761,92.2162 449.77,92.2117 449.779,92.2073 449.788,92.2029 449.798,92.1984 449.807,92.194 449.816,92.1896 449.825,92.1851 449.834,92.1807 449.844,92.1762 449.853,92.1718 449.862,92.1674 449.871,92.1629 449.88,92.1585 449.89,92.1541 449.899,92.1497 449.908,92.1452 449.917,92.1408 449.926,92.1364 449.935,92.1319 449.945,92.1275 449.954,92.1231 449.963,92.1186 449.972,92.1142 449.981,92.1098 449.991,92.1054 450,92.1009 450.009,92.0965 450.018,92.0921 450.027,92.0877 450.037,92.0832 450.046,92.0788 450.055,92.0744 450.064,92.07 450.073,92.0656 450.083,92.0611 450.092,92.0567 450.101,92.0523 450.11,92.0479 450.119,92.0435 450.128,92.039 450.138,92.0346 450.147,92.0302 450.156,92.0258 450.165,92.0214 450.174,92.017 450.184,92.0126 450.193,92.0081 450.202,92.0037 450.211,91.9993 450.22,91.9949 450.23,91.9905 450.239,91.9861 450.248,91.9817 450.257,91.9773 450.266,91.9728 450.275,91.9684 450.285,91.964 450.294,91.9596 450.303,91.9552 450.312,91.9508 450.321,91.9464 450.331,91.942 450.34,91.9376 450.349,91.9332 450.358,91.9288 450.367,91.9244 450.377,91.92 450.386,91.9156 450.395,91.9112 450.404,91.9068 450.413,91.9024 450.423,91.898 450.432,91.8936 450.441,91.8892 450.45,91.8848 450.459,91.8804 450.468,91.876 450.478,91.8716 450.487,91.8672 450.496,91.8628 450.505,91.8584 450.514,91.854 450.524,91.8496 450.533,91.8452 450.542,91.8408 450.551,91.8364 450.56,91.832 450.57,91.8276 450.579,91.8232 450.588,91.8188 450.597,91.8144 450.606,91.81 450.615,91.8057 450.625,91.8013 450.634,91.7969 450.643,91.7925 450.652,91.7881 450.661,91.7837 450.671,91.7793 450.68,91.7749 450.689,91.7706 450.698,91.7662 450.707,91.7618 450.717,91.7574 450.726,91.753 450.735,91.7486 450.744,91.7442 450.753,91.7399 450.763,91.7355 450.772,91.7311 450.781,91.7267 450.79,91.7223 450.799,91.718 450.808,91.7136 450.818,91.7092 450.827,91.7048 450.836,91.7004 450.845,91.6961 450.854,91.6917 450.864,91.6873 450.873,91.6829 450.882,91.6786 450.891,91.6742 450.9,91.6698 450.91,91.6654 450.919,91.6611 450.928,91.6567 450.937,91.6523 450.946,91.648 450.955,91.6436 450.965,91.6392 450.974,91.6349 450.983,91.6305 450.992,91.6261 451.001,91.6217 451.011,91.6174 451.02,91.613 451.029,91.6086 451.038,91.6043 451.047,91.5999 451.057,91.5955 451.066,91.5912 451.075,91.5868 451.084,91.5825 451.093,91.5781 451.103,91.5737 451.112,91.5694 451.121,91.565 451.13,91.5606 451.139,91.5563 451.148,91.5519 451.158,91.5476 451.167,91.5432 451.176,91.5389 451.185,91.5345 451.194,91.5301 451.204,91.5258 451.213,91.5214 451.222,91.5171 451.231,91.5127 451.24,91.5084 451.25,91.504 451.259,91.4997 451.268,91.4953 451.277,91.4909 451.286,91.4866 451.295,91.4822 451.305,91.4779 451.314,91.4735 451.323,91.4692 451.332,91.4648 451.341,91.4605 451.351,91.4561 451.36,91.4518 451.369,91.4474 451.378,91.4431 451.387,91.4388 451.397,91.4344 451.406,91.4301 451.415,91.4257 451.424,91.4214 451.433,91.417 451.443,91.4127 451.452,91.4083 451.461,91.404 451.47,91.3997 451.479,91.3953 451.488,91.391 451.498,91.3866 451.507,91.3823 451.516,91.378 451.525,91.3736 451.534,91.3693 451.544,91.3649 451.553,91.3606 451.562,91.3563 451.571,91.3519 451.58,91.3476 451.59,91.3433 451.599,91.3389 451.608,91.3346 451.617,91.3303 451.626,91.3259 451.635,91.3216 451.645,91.3173 451.654,91.3129 451.663,91.3086 451.672,91.3043 451.681,91.3 451.691,91.2956 451.7,91.2913 451.709,91.287 451.718,91.2826 451.727,91.2783 451.737,91.274 451.746,91.2697 451.755,91.2653 451.764,91.261 451.773,91.2567 451.783,91.2524 451.792,91.248 451.801,91.2437 451.81,91.2394 451.819,91.2351 451.828,91.2307 451.838,91.2264 451.847,91.2221 451.856,91.2178 451.865,91.2135 451.874,91.2091 451.884,91.2048 451.893,91.2005 451.902,91.1962 451.911,91.1919 451.92,91.1876 451.93,91.1832 451.939,91.1789 451.948,91.1746 451.957,91.1703 451.966,91.166 451.975,91.1617 451.985,91.1574 451.994,91.153 452.003,91.1487 452.012,91.1444 452.021,91.1401 452.031,91.1358 452.04,91.1315 452.049,91.1272 452.058,91.1229 452.067,91.1186 452.077,91.1143 452.086,91.11 452.095,91.1056 452.104,91.1013 452.113,91.097 452.123,91.0927 452.132,91.0884 452.141,91.0841 452.15,91.0798 452.159,91.0755 452.168,91.0712 452.178,91.0669 452.187,91.0626 452.196,91.0583 452.205,91.054 452.214,91.0497 452.224,91.0454 452.233,91.0411 452.242,91.0368 452.251,91.0325 452.26,91.0282 452.27,91.0239 452.279,91.0196 452.288,91.0153 452.297,91.011 452.306,91.0067 452.316,91.0024 452.325,90.9982 452.334,90.9939 452.343,90.9896 452.352,90.9853 452.361,90.981 452.371,90.9767 452.38,90.9724 452.389,90.9681 452.398,90.9638 452.407,90.9595 452.417,90.9552 452.426,90.951 452.435,90.9467 452.444,90.9424 452.453,90.9381 452.463,90.9338 452.472,90.9295 452.481,90.9252 452.49,90.9209 452.499,90.9167 452.508,90.9124 452.518,90.9081 452.527,90.9038 452.536,90.8995 452.545,90.8953 452.554,90.891 452.564,90.8867 452.573,90.8824 452.582,90.8781 452.591,90.8739 452.6,90.8696 452.61,90.8653 452.619,90.861 452.628,90.8567 452.637,90.8525 452.646,90.8482 452.656,90.8439 452.665,90.8396 452.674,90.8354 452.683,90.8311 452.692,90.8268 452.701,90.8225 452.711,90.8183 452.72,90.814 452.729,90.8097 452.738,90.8055 452.747,90.8012 452.757,90.7969 452.766,90.7926 452.775,90.7884 452.784,90.7841 452.793,90.7798 452.803,90.7756 452.812,90.7713 452.821,90.767 452.83,90.7628 452.839,90.7585 452.848,90.7542 452.858,90.75 452.867,90.7457 452.876,90.7415 452.885,90.7372 452.894,90.7329 452.904,90.7287 452.913,90.7244 452.922,90.7201 452.931,90.7159 452.94,90.7116 452.95,90.7074 452.959,90.7031 452.968,90.6989 452.977,90.6946 452.986,90.6903 452.996,90.6861 453.005,90.6818 453.014,90.6776 453.023,90.6733 453.032,90.6691 453.041,90.6648 453.051,90.6606 453.06,90.6563 453.069,90.652 453.078,90.6478 453.087,90.6435 453.097,90.6393 453.106,90.635 453.115,90.6308 453.124,90.6265 453.133,90.6223 453.143,90.618 453.152,90.6138 453.161,90.6095 453.17,90.6053 453.179,90.6011 453.188,90.5968 453.198,90.5926 453.207,90.5883 453.216,90.5841 453.225,90.5798 453.234,90.5756 453.244,90.5713 453.253,90.5671 453.262,90.5629 453.271,90.5586 453.28,90.5544 453.29,90.5501 453.299,90.5459 453.308,90.5417 453.317,90.5374 453.326,90.5332 453.336,90.5289 453.345,90.5247 453.354,90.5205 453.363,90.5162 453.372,90.512 453.381,90.5078 453.391,90.5035 453.4,90.4993 453.409,90.4951 453.418,90.4908 453.427,90.4866 453.437,90.4824 453.446,90.4781 453.455,90.4739 453.464,90.4697 453.473,90.4654 453.483,90.4612 453.492,90.457 453.501,90.4527 453.51,90.4485 453.519,90.4443 453.528,90.4401 453.538,90.4358 453.547,90.4316 453.556,90.4274 453.565,90.4232 453.574,90.4189 453.584,90.4147 453.593,90.4105 453.602,90.4063 453.611,90.402 453.62,90.3978 453.63,90.3936 453.639,90.3894 453.648,90.3851 453.657,90.3809 453.666,90.3767 453.676,90.3725 453.685,90.3683 453.694,90.364 453.703,90.3598 453.712,90.3556 453.721,90.3514 453.731,90.3472 453.74,90.343 453.749,90.3387 453.758,90.3345 453.767,90.3303 453.777,90.3261 453.786,90.3219 453.795,90.3177 453.804,90.3135 453.813,90.3093 453.823,90.305 453.832,90.3008 453.841,90.2966 453.85,90.2924 453.859,90.2882 453.868,90.284 453.878,90.2798 453.887,90.2756 453.896,90.2714 453.905,90.2672 453.914,90.263 453.924,90.2588 453.933,90.2545 453.942,90.2503 453.951,90.2461 453.96,90.2419 453.97,90.2377 453.979,90.2335 453.988,90.2293 453.997,90.2251 454.006,90.2209 454.016,90.2167 454.025,90.2125 454.034,90.2083 454.043,90.2041 454.052,90.1999 454.061,90.1957 454.071,90.1915 454.08,90.1873 454.089,90.1831 454.098,90.1789 454.107,90.1747 454.117,90.1705 454.126,90.1663 454.135,90.1622 454.144,90.158 454.153,90.1538 454.163,90.1496 454.172,90.1454 454.181,90.1412 454.19,90.137 454.199,90.1328 454.208,90.1286 454.218,90.1244 454.227,90.1202 454.236,90.116 454.245,90.1119 454.254,90.1077 454.264,90.1035 454.273,90.0993 454.282,90.0951 454.291,90.0909 454.3,90.0867 454.31,90.0826 454.319,90.0784 454.328,90.0742 454.337,90.07 454.346,90.0658 454.356,90.0616 454.365,90.0575 454.374,90.0533 454.383,90.0491 454.392,90.0449 454.401,90.0407 454.411,90.0365 454.42,90.0324 454.429,90.0282 454.438,90.024 454.447,90.0198 454.457,90.0157 454.466,90.0115 454.475,90.0073 454.484,90.0031 454.493,89.999 454.503,89.9948 454.512,89.9906 454.521,89.9864 454.53,89.9823 454.539,89.9781 454.548,89.9739 454.558,89.9697 454.567,89.9656 454.576,89.9614 454.585,89.9572 454.594,89.9531 454.604,89.9489 454.613,89.9447 454.622,89.9406 454.631,89.9364 454.64,89.9322 454.65,89.9281 454.659,89.9239 454.668,89.9197 454.677,89.9156 454.686,89.9114 454.696,89.9072 454.705,89.9031 454.714,89.8989 454.723,89.8947 454.732,89.8906 454.741,89.8864 454.751,89.8823 454.76,89.8781 454.769,89.8739 454.778,89.8698 454.787,89.8656 454.797,89.8615 454.806,89.8573 454.815,89.8531 454.824,89.849 454.833,89.8448 454.843,89.8407 454.852,89.8365 454.861,89.8324 454.87,89.8282 454.879,89.824 454.889,89.8199 454.898,89.8157 454.907,89.8116 454.916,89.8074 454.925,89.8033 454.934,89.7991 454.944,89.795 454.953,89.7908 454.962,89.7867 454.971,89.7825 454.98,89.7784 454.99,89.7742 454.999,89.7701 455.008,89.7659 455.017,89.7618 455.026,89.7576 455.036,89.7535 455.045,89.7494 455.054,89.7452 455.063,89.7411 455.072,89.7369 455.081,89.7328 455.091,89.7286 455.1,89.7245 455.109,89.7203 455.118,89.7162 455.127,89.7121 455.137,89.7079 455.146,89.7038 455.155,89.6996 455.164,89.6955 455.173,89.6914 455.183,89.6872 455.192,89.6831 455.201,89.679 455.21,89.6748 455.219,89.6707 455.229,89.6665 455.238,89.6624 455.247,89.6583 455.256,89.6541 455.265,89.65 455.274,89.6459 455.284,89.6417 455.293,89.6376 455.302,89.6335 455.311,89.6293 455.32,89.6252 455.33,89.6211 455.339,89.617 455.348,89.6128 455.357,89.6087 455.366,89.6046 455.376,89.6004 455.385,89.5963 455.394,89.5922 455.403,89.5881 455.412,89.5839 455.421,89.5798 455.431,89.5757 455.44,89.5716 455.449,89.5674 455.458,89.5633 455.467,89.5592 455.477,89.5551 455.486,89.5509 455.495,89.5468 455.504,89.5427 455.513,89.5386 455.523,89.5345 455.532,89.5303 455.541,89.5262 455.55,89.5221 455.559,89.518 455.569,89.5139 455.578,89.5097 455.587,89.5056 455.596,89.5015 455.605,89.4974 455.614,89.4933 455.624,89.4892 455.633,89.4851 455.642,89.4809 455.651,89.4768 455.66,89.4727 455.67,89.4686 455.679,89.4645 455.688,89.4604 455.697,89.4563 455.706,89.4522 455.716,89.448 455.725,89.4439 455.734,89.4398 455.743,89.4357 455.752,89.4316 455.761,89.4275 455.771,89.4234 455.78,89.4193 455.789,89.4152 455.798,89.4111 455.807,89.407 455.817,89.4029 455.826,89.3988 455.835,89.3947 455.844,89.3906 455.853,89.3865 455.863,89.3824 455.872,89.3783 455.881,89.3742 455.89,89.37 455.899,89.3659 455.909,89.3618 455.918,89.3578 455.927,89.3537 455.936,89.3496 455.945,89.3455 455.954,89.3414 455.964,89.3373 455.973,89.3332 455.982,89.3291 455.991,89.325 456,89.3209 456.01,89.3168 456.019,89.3127 456.028,89.3086 456.037,89.3045 456.046,89.3004 456.056,89.2963 456.065,89.2922 456.074,89.2881 456.083,89.284 456.092,89.28 456.101,89.2759 456.111,89.2718 456.12,89.2677 456.129,89.2636 456.138,89.2595 456.147,89.2554 456.157,89.2513 456.166,89.2473 456.175,89.2432 456.184,89.2391 456.193,89.235 456.203,89.2309 456.212,89.2268 456.221,89.2227 456.23,89.2187 456.239,89.2146 456.249,89.2105 456.258,89.2064 456.267,89.2023 456.276,89.1983 456.285,89.1942 456.294,89.1901 456.304,89.186 456.313,89.1819 456.322,89.1779 456.331,89.1738 456.34,89.1697 456.35,89.1656 456.359,89.1616 456.368,89.1575 456.377,89.1534 456.386,89.1493 456.396,89.1453 456.405,89.1412 456.414,89.1371 456.423,89.133 456.432,89.129 456.441,89.1249 456.451,89.1208 456.46,89.1168 456.469,89.1127 456.478,89.1086 456.487,89.1045 456.497,89.1005 456.506,89.0964 456.515,89.0923 456.524,89.0883 456.533,89.0842 456.543,89.0801 456.552,89.0761 456.561,89.072 456.57,89.0679 456.579,89.0639 456.589,89.0598 456.598,89.0557 456.607,89.0517 456.616,89.0476 456.625,89.0436 456.634,89.0395 456.644,89.0354 456.653,89.0314 456.662,89.0273 456.671,89.0233 456.68,89.0192 456.69,89.0151 456.699,89.0111 456.708,89.007 456.717,89.003 456.726,88.9989 456.736,88.9949 456.745,88.9908 456.754,88.9867 456.763,88.9827 456.772,88.9786 456.781,88.9746 456.791,88.9705 456.8,88.9665 456.809,88.9624 456.818,88.9584 456.827,88.9543 456.837,88.9503 456.846,88.9462 456.855,88.9422 456.864,88.9381 456.873,88.9341 456.883,88.93 456.892,88.926 456.901,88.9219 456.91,88.9179 456.919,88.9138 456.929,88.9098 456.938,88.9057 456.947,88.9017 456.956,88.8976 456.965,88.8936 456.974,88.8896 456.984,88.8855 456.993,88.8815 457.002,88.8774 457.011,88.8734 457.02,88.8693 457.03,88.8653 457.039,88.8613 457.048,88.8572 457.057,88.8532 457.066,88.8491 457.076,88.8451 457.085,88.8411 457.094,88.837 457.103,88.833 457.112,88.829 457.121,88.8249 457.131,88.8209 457.14,88.8168 457.149,88.8128 457.158,88.8088 457.167,88.8047 457.177,88.8007 457.186,88.7967 457.195,88.7926 457.204,88.7886 457.213,88.7846 457.223,88.7805 457.232,88.7765 457.241,88.7725 457.25,88.7685 457.259,88.7644 457.269,88.7604 457.278,88.7564 457.287,88.7523 457.296,88.7483 457.305,88.7443 457.314,88.7403 457.324,88.7362 457.333,88.7322 457.342,88.7282 457.351,88.7242 457.36,88.7201 457.37,88.7161 457.379,88.7121 457.388,88.7081 457.397,88.704 457.406,88.7 457.416,88.696 457.425,88.692 457.434,88.688 457.443,88.6839 457.452,88.6799 457.462,88.6759 457.471,88.6719 457.48,88.6679 457.489,88.6639 457.498,88.6598 457.507,88.6558 457.517,88.6518 457.526,88.6478 457.535,88.6438 457.544,88.6398 457.553,88.6357 457.563,88.6317 457.572,88.6277 457.581,88.6237 457.59,88.6197 457.599,88.6157 457.609,88.6117 457.618,88.6077 457.627,88.6037 457.636,88.5996 457.645,88.5956 457.654,88.5916 457.664,88.5876 457.673,88.5836 457.682,88.5796 457.691,88.5756 457.7,88.5716 457.71,88.5676 457.719,88.5636 457.728,88.5596 457.737,88.5556 457.746,88.5516 457.756,88.5476 457.765,88.5436 457.774,88.5396 457.783,88.5356 457.792,88.5315 457.802,88.5275 457.811,88.5235 457.82,88.5195 457.829,88.5155 457.838,88.5115 457.847,88.5075 457.857,88.5035 457.866,88.4996 457.875,88.4956 457.884,88.4916 457.893,88.4876 457.903,88.4836 457.912,88.4796 457.921,88.4756 457.93,88.4716 457.939,88.4676 457.949,88.4636 457.958,88.4596 457.967,88.4556 457.976,88.4516 457.985,88.4476 457.994,88.4436 458.004,88.4396 458.013,88.4356 458.022,88.4317 458.031,88.4277 458.04,88.4237 458.05,88.4197 458.059,88.4157 458.068,88.4117 458.077,88.4077 458.086,88.4037 458.096,88.3998 458.105,88.3958 458.114,88.3918 458.123,88.3878 458.132,88.3838 458.142,88.3798 458.151,88.3758 458.16,88.3719 458.169,88.3679 458.178,88.3639 458.187,88.3599 458.197,88.3559 458.206,88.352 458.215,88.348 458.224,88.344 458.233,88.34 458.243,88.336 458.252,88.3321 458.261,88.3281 458.27,88.3241 458.279,88.3201 458.289,88.3162 458.298,88.3122 458.307,88.3082 458.316,88.3042 458.325,88.3003 458.334,88.2963 458.344,88.2923 458.353,88.2883 458.362,88.2844 458.371,88.2804 458.38,88.2764 458.39,88.2724 458.399,88.2685 458.408,88.2645 458.417,88.2605 458.426,88.2566 458.436,88.2526 458.445,88.2486 458.454,88.2447 458.463,88.2407 458.472,88.2367 458.482,88.2328 458.491,88.2288 458.5,88.2248 458.509,88.2209 458.518,88.2169 458.527,88.2129 458.537,88.209 458.546,88.205 458.555,88.201 458.564,88.1971 458.573,88.1931 458.583,88.1892 458.592,88.1852 458.601,88.1812 458.61,88.1773 458.619,88.1733 458.629,88.1694 458.638,88.1654 458.647,88.1614 458.656,88.1575 458.665,88.1535 458.674,88.1496 458.684,88.1456 458.693,88.1417 458.702,88.1377 458.711,88.1338 458.72,88.1298 458.73,88.1258 458.739,88.1219 458.748,88.1179 458.757,88.114 458.766,88.11 458.776,88.1061 458.785,88.1021 458.794,88.0982 458.803,88.0942 458.812,88.0903 458.822,88.0863 458.831,88.0824 458.84,88.0784 458.849,88.0745 458.858,88.0705 458.867,88.0666 458.877,88.0626 458.886,88.0587 458.895,88.0548 458.904,88.0508 458.913,88.0469 458.923,88.0429 458.932,88.039 458.941,88.035 458.95,88.0311 458.959,88.0271 458.969,88.0232 458.978,88.0193 458.987,88.0153 458.996,88.0114 459.005,88.0074 459.014,88.0035 459.024,87.9996 459.033,87.9956 459.042,87.9917 459.051,87.9878 459.06,87.9838 459.07,87.9799 459.079,87.9759 459.088,87.972 459.097,87.9681 459.106,87.9641 459.116,87.9602 459.125,87.9563 459.134,87.9523 459.143,87.9484 459.152,87.9445 459.162,87.9405 459.171,87.9366 459.18,87.9327 459.189,87.9287 459.198,87.9248 459.207,87.9209 459.217,87.917 459.226,87.913 459.235,87.9091 459.244,87.9052 459.253,87.9012 459.263,87.8973 459.272,87.8934 459.281,87.8895 459.29,87.8855 459.299,87.8816 459.309,87.8777 459.318,87.8738 459.327,87.8698 459.336,87.8659 459.345,87.862 459.354,87.8581 459.364,87.8541 459.373,87.8502 459.382,87.8463 459.391,87.8424 459.4,87.8385 459.41,87.8345 459.419,87.8306 459.428,87.8267 459.437,87.8228 459.446,87.8189 459.456,87.815 459.465,87.811 459.474,87.8071 459.483,87.8032 459.492,87.7993 459.502,87.7954 459.511,87.7915 459.52,87.7875 459.529,87.7836 459.538,87.7797 459.547,87.7758 459.557,87.7719 459.566,87.768 459.575,87.7641 459.584,87.7602 459.593,87.7563 459.603,87.7523 459.612,87.7484 459.621,87.7445 459.63,87.7406 459.639,87.7367 459.649,87.7328 459.658,87.7289 459.667,87.725 459.676,87.7211 459.685,87.7172 459.695,87.7133 459.704,87.7094 459.713,87.7055 459.722,87.7016 459.731,87.6976 459.74,87.6937 459.75,87.6898 459.759,87.6859 459.768,87.682 459.777,87.6781 459.786,87.6742 459.796,87.6703 459.805,87.6664 459.814,87.6625 459.823,87.6586 459.832,87.6547 459.842,87.6508 459.851,87.6469 459.86,87.643 459.869,87.6392 459.878,87.6353 459.887,87.6314 459.897,87.6275 459.906,87.6236 459.915,87.6197 459.924,87.6158 459.933,87.6119 459.943,87.608 459.952,87.6041 459.961,87.6002 459.97,87.5963 459.979,87.5924 459.989,87.5885 459.998,87.5846 460.007,87.5808 460.016,87.5769 460.025,87.573 460.035,87.5691 460.044,87.5652 460.053,87.5613 460.062,87.5574 460.071,87.5535 460.08,87.5497 460.09,87.5458 460.099,87.5419 460.108,87.538 460.117,87.5341 460.126,87.5302 460.136,87.5264 460.145,87.5225 460.154,87.5186 460.163,87.5147 460.172,87.5108 460.182,87.5069 460.191,87.5031 460.2,87.4992 460.209,87.4953 460.218,87.4914 460.227,87.4875 460.237,87.4837 460.246,87.4798 460.255,87.4759 460.264,87.472 460.273,87.4682 460.283,87.4643 460.292,87.4604 460.301,87.4565 460.31,87.4527 460.319,87.4488 460.329,87.4449 460.338,87.441 460.347,87.4372 460.356,87.4333 460.365,87.4294 460.375,87.4255 460.384,87.4217 460.393,87.4178 460.402,87.4139 460.411,87.4101 460.42,87.4062 460.43,87.4023 460.439,87.3985 460.448,87.3946 460.457,87.3907 460.466,87.3869 460.476,87.383 460.485,87.3791 460.494,87.3753 460.503,87.3714 460.512,87.3675 460.522,87.3637 460.531,87.3598 460.54,87.3559 460.549,87.3521 460.558,87.3482 460.567,87.3444 460.577,87.3405 460.586,87.3366 460.595,87.3328 460.604,87.3289 460.613,87.325 460.623,87.3212 460.632,87.3173 460.641,87.3135 460.65,87.3096 460.659,87.3058 460.669,87.3019 460.678,87.298 460.687,87.2942 460.696,87.2903 460.705,87.2865 460.715,87.2826 460.724,87.2788 460.733,87.2749 460.742,87.2711 460.751,87.2672 460.76,87.2634 460.77,87.2595 460.779,87.2557 460.788,87.2518 460.797,87.248 460.806,87.2441 460.816,87.2403 460.825,87.2364 460.834,87.2326 460.843,87.2287 460.852,87.2249 460.862,87.221 460.871,87.2172 460.88,87.2133 460.889,87.2095 460.898,87.2056 460.907,87.2018 460.917,87.1979 460.926,87.1941 460.935,87.1902 460.944,87.1864 460.953,87.1826 460.963,87.1787 460.972,87.1749 460.981,87.171 460.99,87.1672 460.999,87.1634 461.009,87.1595 461.018,87.1557 461.027,87.1518 461.036,87.148 461.045,87.1442 461.055,87.1403 461.064,87.1365 461.073,87.1326 461.082,87.1288 461.091,87.125 461.1,87.1211 461.11,87.1173 461.119,87.1135 461.128,87.1096 461.137,87.1058 461.146,87.102 461.156,87.0981 461.165,87.0943 461.174,87.0905 461.183,87.0866 461.192,87.0828 461.202,87.079 461.211,87.0751 461.22,87.0713 461.229,87.0675 461.238,87.0637 461.247,87.0598 461.257,87.056 461.266,87.0522 461.275,87.0483 461.284,87.0445 461.293,87.0407 461.303,87.0369 461.312,87.033 461.321,87.0292 461.33,87.0254 461.339,87.0216 461.349,87.0177 461.358,87.0139 461.367,87.0101 461.376,87.0063 461.385,87.0025 461.395,86.9986 461.404,86.9948 461.413,86.991 461.422,86.9872 461.431,86.9834 461.44,86.9795 461.45,86.9757 461.459,86.9719 461.468,86.9681 461.477,86.9643 461.486,86.9604 461.496,86.9566 461.505,86.9528 461.514,86.949 461.523,86.9452 461.532,86.9414 461.542,86.9376 461.551,86.9337 461.56,86.9299 461.569,86.9261 461.578,86.9223 461.587,86.9185 461.597,86.9147 461.606,86.9109 461.615,86.9071 461.624,86.9032 461.633,86.8994 461.643,86.8956 461.652,86.8918 461.661,86.888 461.67,86.8842 461.679,86.8804 461.689,86.8766 461.698,86.8728 461.707,86.869 461.716,86.8652 461.725,86.8614 461.735,86.8576 461.744,86.8538 461.753,86.85 461.762,86.8461 461.771,86.8423 461.78,86.8385 461.79,86.8347 461.799,86.8309 461.808,86.8271 461.817,86.8233 461.826,86.8195 461.836,86.8157 461.845,86.8119 461.854,86.8081 461.863,86.8043 461.872,86.8005 461.882,86.7967 461.891,86.7929 461.9,86.7892 461.909,86.7854 461.918,86.7816 461.927,86.7778 461.937,86.774 461.946,86.7702 461.955,86.7664 461.964,86.7626 461.973,86.7588 461.983,86.755 461.992,86.7512 462.001,86.7474 462.01,86.7436 462.019,86.7398 462.029,86.736 462.038,86.7323 462.047,86.7285 462.056,86.7247 462.065,86.7209 462.075,86.7171 462.084,86.7133 462.093,86.7095 462.102,86.7057 462.111,86.702 462.12,86.6982 462.13,86.6944 462.139,86.6906 462.148,86.6868 462.157,86.683 462.166,86.6792 462.176,86.6755 462.185,86.6717 462.194,86.6679 462.203,86.6641 462.212,86.6603 462.222,86.6566 462.231,86.6528 462.24,86.649 462.249,86.6452 462.258,86.6414 462.268,86.6377 462.277,86.6339 462.286,86.6301 462.295,86.6263 462.304,86.6225 462.313,86.6188 462.323,86.615 462.332,86.6112 462.341,86.6074 462.35,86.6037 462.359,86.5999 462.369,86.5961 462.378,86.5923 462.387,86.5886 462.396,86.5848 462.405,86.581 462.415,86.5773 462.424,86.5735 462.433,86.5697 462.442,86.5659 462.451,86.5622 462.46,86.5584 462.47,86.5546 462.479,86.5509 462.488,86.5471 462.497,86.5433 462.506,86.5396 462.516,86.5358 462.525,86.532 462.534,86.5283 462.543,86.5245 462.552,86.5207 462.562,86.517 462.571,86.5132 462.58,86.5094 462.589,86.5057 462.598,86.5019 462.608,86.4981 462.617,86.4944 462.626,86.4906 462.635,86.4869 462.644,86.4831 462.653,86.4793 462.663,86.4756 462.672,86.4718 462.681,86.4681 462.69,86.4643 462.699,86.4605 462.709,86.4568 462.718,86.453 462.727,86.4493 462.736,86.4455 462.745,86.4418 462.755,86.438 462.764,86.4343 462.773,86.4305 462.782,86.4267 462.791,86.423 462.8,86.4192 462.81,86.4155 462.819,86.4117 462.828,86.408 462.837,86.4042 462.846,86.4005 462.856,86.3967 462.865,86.393 462.874,86.3892 462.883,86.3855 462.892,86.3817 462.902,86.378 462.911,86.3742 462.92,86.3705 462.929,86.3667 462.938,86.363 462.948,86.3592 462.957,86.3555 462.966,86.3518 462.975,86.348 462.984,86.3443 462.993,86.3405 463.003,86.3368 463.012,86.333 463.021,86.3293 463.03,86.3255 463.039,86.3218 463.049,86.3181 463.058,86.3143 463.067,86.3106 463.076,86.3068 463.085,86.3031 463.095,86.2994 463.104,86.2956 463.113,86.2919 463.122,86.2882 463.131,86.2844 463.14,86.2807 463.15,86.2769 463.159,86.2732 463.168,86.2695 463.177,86.2657 463.186,86.262 463.196,86.2583 463.205,86.2545 463.214,86.2508 463.223,86.2471 463.232,86.2433 463.242,86.2396 463.251,86.2359 463.26,86.2321 463.269,86.2284 463.278,86.2247 463.288,86.2209 463.297,86.2172 463.306,86.2135 463.315,86.2098 463.324,86.206 463.333,86.2023 463.343,86.1986 463.352,86.1948 463.361,86.1911 463.37,86.1874 463.379,86.1837 463.389,86.1799 463.398,86.1762 463.407,86.1725 463.416,86.1688 463.425,86.165 463.435,86.1613 463.444,86.1576 463.453,86.1539 463.462,86.1502 463.471,86.1464 463.48,86.1427 463.49,86.139 463.499,86.1353 463.508,86.1316 463.517,86.1278 463.526,86.1241 463.536,86.1204 463.545,86.1167 463.554,86.113 463.563,86.1093 463.572,86.1055 463.582,86.1018 463.591,86.0981 463.6,86.0944 463.609,86.0907 463.618,86.087 463.628,86.0832 463.637,86.0795 463.646,86.0758 463.655,86.0721 463.664,86.0684 463.673,86.0647 463.683,86.061 463.692,86.0573 463.701,86.0536 463.71,86.0498 463.719,86.0461 463.729,86.0424 463.738,86.0387 463.747,86.035 463.756,86.0313 463.765,86.0276 463.775,86.0239 463.784,86.0202 463.793,86.0165 463.802,86.0128 463.811,86.0091 463.82,86.0054 463.83,86.0017 463.839,85.998 463.848,85.9942 463.857,85.9905 463.866,85.9868 463.876,85.9831 463.885,85.9794 463.894,85.9757 463.903,85.972 463.912,85.9683 463.922,85.9646 463.931,85.9609 463.94,85.9572 463.949,85.9535 463.958,85.9498 463.968,85.9461 463.977,85.9424 463.986,85.9388 463.995,85.9351 464.004,85.9314 464.013,85.9277 464.023,85.924 464.032,85.9203 464.041,85.9166 464.05,85.9129 464.059,85.9092 464.069,85.9055 464.078,85.9018 464.087,85.8981 464.096,85.8944 464.105,85.8907 464.115,85.887 464.124,85.8834 464.133,85.8797 464.142,85.876 464.151,85.8723 464.16,85.8686 464.17,85.8649 464.179,85.8612 464.188,85.8575 464.197,85.8538 464.206,85.8502 464.216,85.8465 464.225,85.8428 464.234,85.8391 464.243,85.8354 464.252,85.8317 464.262,85.828 464.271,85.8244 464.28,85.8207 464.289,85.817 464.298,85.8133 464.308,85.8096 464.317,85.806 464.326,85.8023 464.335,85.7986 464.344,85.7949 464.353,85.7912 464.363,85.7876 464.372,85.7839 464.381,85.7802 464.39,85.7765 464.399,85.7728 464.409,85.7692 464.418,85.7655 464.427,85.7618 464.436,85.7581 464.445,85.7545 464.455,85.7508 464.464,85.7471 464.473,85.7434 464.482,85.7398 464.491,85.7361 464.5,85.7324 464.51,85.7287 464.519,85.7251 464.528,85.7214 464.537,85.7177 464.546,85.7141 464.556,85.7104 464.565,85.7067 464.574,85.7031 464.583,85.6994 464.592,85.6957 464.602,85.6921 464.611,85.6884 464.62,85.6847 464.629,85.6811 464.638,85.6774 464.648,85.6737 464.657,85.6701 464.666,85.6664 464.675,85.6627 464.684,85.6591 464.693,85.6554 464.703,85.6517 464.712,85.6481 464.721,85.6444 464.73,85.6407 464.739,85.6371 464.749,85.6334 464.758,85.6298 464.767,85.6261 464.776,85.6224 464.785,85.6188 464.795,85.6151 464.804,85.6115 464.813,85.6078 464.822,85.6042 464.831,85.6005 464.841,85.5968 464.85,85.5932 464.859,85.5895 464.868,85.5859 464.877,85.5822 464.886,85.5786 464.896,85.5749 464.905,85.5713 464.914,85.5676 464.923,85.5639 464.932,85.5603 464.942,85.5566 464.951,85.553 464.96,85.5493 464.969,85.5457 464.978,85.542 464.988,85.5384 464.997,85.5347 465.006,85.5311 465.015,85.5274 465.024,85.5238 465.033,85.5201 465.043,85.5165 465.052,85.5129 465.061,85.5092 465.07,85.5056 465.079,85.5019 465.089,85.4983 465.098,85.4946 465.107,85.491 465.116,85.4873 465.125,85.4837 465.135,85.4801 465.144,85.4764 465.153,85.4728 465.162,85.4691 465.171,85.4655 465.181,85.4618 465.19,85.4582 465.199,85.4546 465.208,85.4509 465.217,85.4473 465.226,85.4436 465.236,85.44 465.245,85.4364 465.254,85.4327 465.263,85.4291 465.272,85.4255 465.282,85.4218 465.291,85.4182 465.3,85.4146 465.309,85.4109 465.318,85.4073 465.328,85.4036 465.337,85.4 465.346,85.3964 465.355,85.3927 465.364,85.3891 465.373,85.3855 465.383,85.3819 465.392,85.3782 465.401,85.3746 465.41,85.371 465.419,85.3673 465.429,85.3637 465.438,85.3601 465.447,85.3564 465.456,85.3528 465.465,85.3492 465.475,85.3456 465.484,85.3419 465.493,85.3383 465.502,85.3347 465.511,85.3311 465.521,85.3274 465.53,85.3238 465.539,85.3202 465.548,85.3166 465.557,85.3129 465.566,85.3093 465.576,85.3057 465.585,85.3021 465.594,85.2984 465.603,85.2948 465.612,85.2912 465.622,85.2876 465.631,85.284 465.64,85.2803 465.649,85.2767 465.658,85.2731 465.668,85.2695 465.677,85.2659 465.686,85.2623 465.695,85.2586 465.704,85.255 465.713,85.2514 465.723,85.2478 465.732,85.2442 465.741,85.2406 465.75,85.2369 465.759,85.2333 465.769,85.2297 465.778,85.2261 465.787,85.2225 465.796,85.2189 465.805,85.2153 465.815,85.2117 465.824,85.208 465.833,85.2044 465.842,85.2008 465.851,85.1972 465.861,85.1936 465.87,85.19 465.879,85.1864 465.888,85.1828 465.897,85.1792 465.906,85.1756 465.916,85.172 465.925,85.1684 465.934,85.1647 465.943,85.1611 465.952,85.1575 465.962,85.1539 465.971,85.1503 465.98,85.1467 465.989,85.1431 465.998,85.1395 466.008,85.1359 466.017,85.1323 466.026,85.1287 466.035,85.1251 466.044,85.1215 466.053,85.1179 466.063,85.1143 466.072,85.1107 466.081,85.1071 466.09,85.1035 466.099,85.0999 466.109,85.0963 466.118,85.0927 466.127,85.0891 466.136,85.0855 466.145,85.0819 466.155,85.0783 466.164,85.0747 466.173,85.0711 466.182,85.0675 466.191,85.064 466.201,85.0604 466.21,85.0568 466.219,85.0532 466.228,85.0496 466.237,85.046 466.246,85.0424 466.256,85.0388 466.265,85.0352 466.274,85.0316 466.283,85.028 466.292,85.0244 466.302,85.0209 466.311,85.0173 466.32,85.0137 466.329,85.0101 466.338,85.0065 466.348,85.0029 466.357,84.9993 466.366,84.9957 466.375,84.9922 466.384,84.9886 466.393,84.985 466.403,84.9814 466.412,84.9778 466.421,84.9742 466.43,84.9707 466.439,84.9671 466.449,84.9635 466.458,84.9599 466.467,84.9563 466.476,84.9527 466.485,84.9492 466.495,84.9456 466.504,84.942 466.513,84.9384 466.522,84.9348 466.531,84.9313 466.541,84.9277 466.55,84.9241 466.559,84.9205 466.568,84.917 466.577,84.9134 466.586,84.9098 466.596,84.9062 466.605,84.9027 466.614,84.8991 466.623,84.8955 466.632,84.8919 466.642,84.8884 466.651,84.8848 466.66,84.8812 466.669,84.8776 466.678,84.8741 466.688,84.8705 466.697,84.8669 466.706,84.8634 466.715,84.8598 466.724,84.8562 466.733,84.8526 466.743,84.8491 466.752,84.8455 466.761,84.8419 466.77,84.8384 466.779,84.8348 466.789,84.8312 466.798,84.8277 466.807,84.8241 466.816,84.8205 466.825,84.817 466.835,84.8134 466.844,84.8098 466.853,84.8063 466.862,84.8027 466.871,84.7992 466.881,84.7956 466.89,84.792 466.899,84.7885 466.908,84.7849 466.917,84.7813 466.926,84.7778 466.936,84.7742 466.945,84.7707 466.954,84.7671 466.963,84.7635 466.972,84.76 466.982,84.7564 466.991,84.7529 467,84.7493 467.009,84.7458 467.018,84.7422 467.028,84.7386 467.037,84.7351 467.046,84.7315 467.055,84.728 467.064,84.7244 467.074,84.7209 467.083,84.7173 467.092,84.7138 467.101,84.7102 467.11,84.7067 467.119,84.7031 467.129,84.6996 467.138,84.696 467.147,84.6925 467.156,84.6889 467.165,84.6854 467.175,84.6818 467.184,84.6783 467.193,84.6747 467.202,84.6712 467.211,84.6676 467.221,84.6641 467.23,84.6605 467.239,84.657 467.248,84.6534 467.257,84.6499 467.266,84.6463 467.276,84.6428 467.285,84.6392 467.294,84.6357 467.303,84.6322 467.312,84.6286 467.322,84.6251 467.331,84.6215 467.34,84.618 467.349,84.6144 467.358,84.6109 467.368,84.6074 467.377,84.6038 467.386,84.6003 467.395,84.5967 467.404,84.5932 467.414,84.5897 467.423,84.5861 467.432,84.5826 467.441,84.5791 467.45,84.5755 467.459,84.572 467.469,84.5684 467.478,84.5649 467.487,84.5614 467.496,84.5578 467.505,84.5543 467.515,84.5508 467.524,84.5472 467.533,84.5437 467.542,84.5402 467.551,84.5366 467.561,84.5331 467.57,84.5296 467.579,84.526 467.588,84.5225 467.597,84.519 467.606,84.5155 467.616,84.5119 467.625,84.5084 467.634,84.5049 467.643,84.5013 467.652,84.4978 467.662,84.4943 467.671,84.4908 467.68,84.4872 467.689,84.4837 467.698,84.4802 467.708,84.4767 467.717,84.4731 467.726,84.4696 467.735,84.4661 467.744,84.4626 467.754,84.459 467.763,84.4555 467.772,84.452 467.781,84.4485 467.79,84.445 467.799,84.4414 467.809,84.4379 467.818,84.4344 467.827,84.4309 467.836,84.4273 467.845,84.4238 467.855,84.4203 467.864,84.4168 467.873,84.4133 467.882,84.4098 467.891,84.4062 467.901,84.4027 467.91,84.3992 467.919,84.3957 467.928,84.3922 467.937,84.3887 467.946,84.3851 467.956,84.3816 467.965,84.3781 467.974,84.3746 467.983,84.3711 467.992,84.3676 468.002,84.3641 468.011,84.3606 468.02,84.357 468.029,84.3535 468.038,84.35 468.048,84.3465 468.057,84.343 468.066,84.3395 468.075,84.336 468.084,84.3325 468.094,84.329 468.103,84.3255 468.112,84.322 468.121,84.3185 468.13,84.3149 468.139,84.3114 468.149,84.3079 468.158,84.3044 468.167,84.3009 468.176,84.2974 468.185,84.2939 468.195,84.2904 468.204,84.2869 468.213,84.2834 468.222,84.2799 468.231,84.2764 468.241,84.2729 468.25,84.2694 468.259,84.2659 468.268,84.2624 468.277,84.2589 468.286,84.2554 468.296,84.2519 468.305,84.2484 468.314,84.2449 468.323,84.2414 468.332,84.2379 468.342,84.2344 468.351,84.2309 468.36,84.2274 468.369,84.2239 468.378,84.2204 468.388,84.2169 468.397,84.2134 468.406,84.21 468.415,84.2065 468.424,84.203 468.434,84.1995 468.443,84.196 468.452,84.1925 468.461,84.189 468.47,84.1855 468.479,84.182 468.489,84.1785 468.498,84.175 468.507,84.1715 468.516,84.1681 468.525,84.1646 468.535,84.1611 468.544,84.1576 468.553,84.1541 468.562,84.1506 468.571,84.1471 468.581,84.1436 468.59,84.1402 468.599,84.1367 468.608,84.1332 468.617,84.1297 468.626,84.1262 468.636,84.1227 468.645,84.1193 468.654,84.1158 468.663,84.1123 468.672,84.1088 468.682,84.1053 468.691,84.1018 468.7,84.0984 468.709,84.0949 468.718,84.0914 468.728,84.0879 468.737,84.0844 468.746,84.081 468.755,84.0775 468.764,84.074 468.774,84.0705 468.783,84.0671 468.792,84.0636 468.801,84.0601 468.81,84.0566 468.819,84.0531 468.829,84.0497 468.838,84.0462 468.847,84.0427 468.856,84.0393 468.865,84.0358 468.875,84.0323 468.884,84.0288 468.893,84.0254 468.902,84.0219 468.911,84.0184 468.921,84.0149 468.93,84.0115 468.939,84.008 468.948,84.0045 468.957,84.0011 468.966,83.9976 468.976,83.9941 468.985,83.9907 468.994,83.9872 469.003,83.9837 469.012,83.9803 469.022,83.9768 469.031,83.9733 469.04,83.9699 469.049,83.9664 469.058,83.9629 469.068,83.9595 469.077,83.956 469.086,83.9525 469.095,83.9491 469.104,83.9456 469.114,83.9421 469.123,83.9387 469.132,83.9352 469.141,83.9318 469.15,83.9283 469.159,83.9248 469.169,83.9214 469.178,83.9179 469.187,83.9145 469.196,83.911 469.205,83.9075 469.215,83.9041 469.224,83.9006 469.233,83.8972 469.242,83.8937 469.251,83.8903 469.261,83.8868 469.27,83.8833 469.279,83.8799 469.288,83.8764 469.297,83.873 469.306,83.8695 469.316,83.8661 469.325,83.8626 469.334,83.8592 469.343,83.8557 469.352,83.8523 469.362,83.8488 469.371,83.8454 469.38,83.8419 469.389,83.8385 469.398,83.835 469.408,83.8316 469.417,83.8281 469.426,83.8247 469.435,83.8212 469.444,83.8178 469.454,83.8143 469.463,83.8109 469.472,83.8074 469.481,83.804 469.49,83.8005 469.499,83.7971 469.509,83.7936 469.518,83.7902 469.527,83.7868 469.536,83.7833 469.545,83.7799 469.555,83.7764 469.564,83.773 469.573,83.7695 469.582,83.7661 469.591,83.7627 469.601,83.7592 469.61,83.7558 469.619,83.7523 469.628,83.7489 469.637,83.7455 469.647,83.742 469.656,83.7386 469.665,83.7351 469.674,83.7317 469.683,83.7283 469.692,83.7248 469.702,83.7214 469.711,83.718 469.72,83.7145 469.729,83.7111 469.738,83.7077 469.748,83.7042 469.757,83.7008 469.766,83.6974 469.775,83.6939 469.784,83.6905 469.794,83.6871 469.803,83.6836 469.812,83.6802 469.821,83.6768 469.83,83.6733 469.839,83.6699 469.849,83.6665 469.858,83.663 469.867,83.6596 469.876,83.6562 469.885,83.6527 469.895,83.6493 469.904,83.6459 469.913,83.6425 469.922,83.639 469.931,83.6356 469.941,83.6322 469.95,83.6288 469.959,83.6253 469.968,83.6219 469.977,83.6185 469.987,83.6151 469.996,83.6116 470.005,83.6082 470.014,83.6048 470.023,83.6014 470.032,83.5979 470.042,83.5945 470.051,83.5911 470.06,83.5877 470.069,83.5843 470.078,83.5808 470.088,83.5774 470.097,83.574 470.106,83.5706 470.115,83.5672 470.124,83.5638 470.134,83.5603 470.143,83.5569 470.152,83.5535 470.161,83.5501 470.17,83.5467 470.179,83.5433 470.189,83.5398 470.198,83.5364 470.207,83.533 470.216,83.5296 470.225,83.5262 470.235,83.5228 470.244,83.5194 470.253,83.5159 470.262,83.5125 470.271,83.5091 470.281,83.5057 470.29,83.5023 470.299,83.4989 470.308,83.4955 470.317,83.4921 470.327,83.4887 470.336,83.4852 470.345,83.4818 470.354,83.4784 470.363,83.475 470.372,83.4716 470.382,83.4682 470.391,83.4648 470.4,83.4614 470.409,83.458 470.418,83.4546 470.428,83.4512 470.437,83.4478 470.446,83.4444 470.455,83.441 470.464,83.4376 470.474,83.4342 470.483,83.4308 470.492,83.4274 470.501,83.424 470.51,83.4206 470.519,83.4172 470.529,83.4138 470.538,83.4104 470.547,83.407 470.556,83.4036 470.565,83.4002 470.575,83.3968 470.584,83.3934 470.593,83.39 470.602,83.3866 470.611,83.3832 470.621,83.3798 470.63,83.3764 470.639,83.373 470.648,83.3696 470.657,83.3662 470.667,83.3628 470.676,83.3594 470.685,83.356 470.694,83.3526 470.703,83.3492 470.712,83.3458 470.722,83.3424 470.731,83.339 470.74,83.3357 470.749,83.3323 470.758,83.3289 470.768,83.3255 470.777,83.3221 470.786,83.3187 470.795,83.3153 470.804,83.3119 470.814,83.3085 470.823,83.3052 470.832,83.3018 470.841,83.2984 470.85,83.295 470.859,83.2916 470.869,83.2882 470.878,83.2848 470.887,83.2815 470.896,83.2781 470.905,83.2747 470.915,83.2713 470.924,83.2679 470.933,83.2645 470.942,83.2612 470.951,83.2578 470.961,83.2544 470.97,83.251 470.979,83.2476 470.988,83.2442 470.997,83.2409 471.007,83.2375 471.016,83.2341 471.025,83.2307 471.034,83.2273 471.043,83.224 471.052,83.2206 471.062,83.2172 471.071,83.2138 471.08,83.2105 471.089,83.2071 471.098,83.2037 471.108,83.2003 471.117,83.197 471.126,83.1936 471.135,83.1902 471.144,83.1868 471.154,83.1835 471.163,83.1801 471.172,83.1767 471.181,83.1733 471.19,83.17 471.199,83.1666 471.209,83.1632 471.218,83.1599 471.227,83.1565 471.236,83.1531 471.245,83.1498 471.255,83.1464 471.264,83.143 471.273,83.1396 471.282,83.1363 471.291,83.1329 471.301,83.1295 471.31,83.1262 471.319,83.1228 471.328,83.1194 471.337,83.1161 471.347,83.1127 471.356,83.1094 471.365,83.106 471.374,83.1026 471.383,83.0993 471.392,83.0959 471.402,83.0925 471.411,83.0892 471.42,83.0858 471.429,83.0824 471.438,83.0791 471.448,83.0757 471.457,83.0724 471.466,83.069 471.475,83.0656 471.484,83.0623 471.494,83.0589 471.503,83.0556 471.512,83.0522 471.521,83.0489 471.53,83.0455 471.539,83.0421 471.549,83.0388 471.558,83.0354 471.567,83.0321 471.576,83.0287 471.585,83.0254 471.595,83.022 471.604,83.0187 471.613,83.0153 471.622,83.0119 471.631,83.0086 471.641,83.0052 471.65,83.0019 471.659,82.9985 471.668,82.9952 471.677,82.9918 471.687,82.9885 471.696,82.9851 471.705,82.9818 471.714,82.9784 471.723,82.9751 471.732,82.9717 471.742,82.9684 471.751,82.965 471.76,82.9617 471.769,82.9584 471.778,82.955 471.788,82.9517 471.797,82.9483 471.806,82.945 471.815,82.9416 471.824,82.9383 471.834,82.9349 471.843,82.9316 471.852,82.9282 471.861,82.9249 471.87,82.9216 471.879,82.9182 471.889,82.9149 471.898,82.9115 471.907,82.9082 471.916,82.9049 471.925,82.9015 471.935,82.8982 471.944,82.8948 471.953,82.8915 471.962,82.8882 471.971,82.8848 471.981,82.8815 471.99,82.8781 471.999,82.8748 472.008,82.8715 472.017,82.8681 472.027,82.8648 472.036,82.8615 472.045,82.8581 472.054,82.8548 472.063,82.8515 472.072,82.8481 472.082,82.8448 472.091,82.8415 472.1,82.8381 472.109,82.8348 472.118,82.8315 472.128,82.8281 472.137,82.8248 472.146,82.8215 472.155,82.8181 472.164,82.8148 472.174,82.8115 472.183,82.8082 472.192,82.8048 472.201,82.8015 472.21,82.7982 472.22,82.7948 472.229,82.7915 472.238,82.7882 472.247,82.7849 472.256,82.7815 472.265,82.7782 472.275,82.7749 472.284,82.7716 472.293,82.7682 472.302,82.7649 472.311,82.7616 472.321,82.7583 472.33,82.7549 472.339,82.7516 472.348,82.7483 472.357,82.745 472.367,82.7416 472.376,82.7383 472.385,82.735 472.394,82.7317 472.403,82.7284 472.412,82.725 472.422,82.7217 472.431,82.7184 472.44,82.7151 472.449,82.7118 472.458,82.7085 472.468,82.7051 472.477,82.7018 472.486,82.6985 472.495,82.6952 472.504,82.6919 472.514,82.6886 472.523,82.6852 472.532,82.6819 472.541,82.6786 472.55,82.6753 472.56,82.672 472.569,82.6687 472.578,82.6654 472.587,82.6621 472.596,82.6587 472.605,82.6554 472.615,82.6521 472.624,82.6488 472.633,82.6455 472.642,82.6422 472.651,82.6389 472.661,82.6356 472.67,82.6323 472.679,82.629 472.688,82.6256 472.697,82.6223 472.707,82.619 472.716,82.6157 472.725,82.6124 472.734,82.6091 472.743,82.6058 472.752,82.6025 472.762,82.5992 472.771,82.5959 472.78,82.5926 472.789,82.5893 472.798,82.586 472.808,82.5827 472.817,82.5794 472.826,82.5761 472.835,82.5728 472.844,82.5695 472.854,82.5662 472.863,82.5629 472.872,82.5596 472.881,82.5563 472.89,82.553 472.9,82.5497 472.909,82.5464 472.918,82.5431 472.927,82.5398 472.936,82.5365 472.945,82.5332 472.955,82.5299 472.964,82.5266 472.973,82.5233 472.982,82.52 472.991,82.5167 473.001,82.5134 473.01,82.5101 473.019,82.5068 473.028,82.5035 473.037,82.5002 473.047,82.497 473.056,82.4937 473.065,82.4904 473.074,82.4871 473.083,82.4838 473.092,82.4805 473.102,82.4772 473.111,82.4739 473.12,82.4706 473.129,82.4673 473.138,82.464 473.148,82.4608 473.157,82.4575 473.166,82.4542 473.175,82.4509 473.184,82.4476 473.194,82.4443 473.203,82.441 473.212,82.4378 473.221,82.4345 473.23,82.4312 473.24,82.4279 473.249,82.4246 473.258,82.4213 473.267,82.418 473.276,82.4148 473.285,82.4115 473.295,82.4082 473.304,82.4049 473.313,82.4016 473.322,82.3984 473.331,82.3951 473.341,82.3918 473.35,82.3885 473.359,82.3852 473.368,82.382 473.377,82.3787 473.387,82.3754 473.396,82.3721 473.405,82.3688 473.414,82.3656 473.423,82.3623 473.432,82.359 473.442,82.3557 473.451,82.3525 473.46,82.3492 473.469,82.3459 473.478,82.3426 473.488,82.3394 473.497,82.3361 473.506,82.3328 473.515,82.3295 473.524,82.3263 473.534,82.323 473.543,82.3197 473.552,82.3165 473.561,82.3132 473.57,82.3099 473.58,82.3066 473.589,82.3034 473.598,82.3001 473.607,82.2968 473.616,82.2936 473.625,82.2903 473.635,82.287 473.644,82.2838 473.653,82.2805 473.662,82.2772 473.671,82.274 473.681,82.2707 473.69,82.2674 473.699,82.2642 473.708,82.2609 473.717,82.2576 473.727,82.2544 473.736,82.2511 473.745,82.2478 473.754,82.2446 473.763,82.2413 473.772,82.2381 473.782,82.2348 473.791,82.2315 473.8,82.2283 473.809,82.225 473.818,82.2218 473.828,82.2185 473.837,82.2152 473.846,82.212 473.855,82.2087 473.864,82.2055 473.874,82.2022 473.883,82.1989 473.892,82.1957 473.901,82.1924 473.91,82.1892 473.92,82.1859 473.929,82.1827 473.938,82.1794 473.947,82.1762 473.956,82.1729 473.965,82.1696 473.975,82.1664 473.984,82.1631 473.993,82.1599 474.002,82.1566 474.011,82.1534 474.021,82.1501 474.03,82.1469 474.039,82.1436 474.048,82.1404 474.057,82.1371 474.067,82.1339 474.076,82.1306 474.085,82.1274 474.094,82.1241 474.103,82.1209 474.112,82.1176 474.122,82.1144 474.131,82.1111 474.14,82.1079 474.149,82.1046 474.158,82.1014 474.168,82.0982 474.177,82.0949 474.186,82.0917 474.195,82.0884 474.204,82.0852 474.214,82.0819 474.223,82.0787 474.232,82.0754 474.241,82.0722 474.25,82.069 474.26,82.0657 474.269,82.0625 474.278,82.0592 474.287,82.056 474.296,82.0528 474.305,82.0495 474.315,82.0463 474.324,82.043 474.333,82.0398 474.342,82.0366 474.351,82.0333 474.361,82.0301 474.37,82.0269 474.379,82.0236 474.388,82.0204 474.397,82.0171 474.407,82.0139 474.416,82.0107 474.425,82.0074 474.434,82.0042 474.443,82.001 474.452,81.9977 474.462,81.9945 474.471,81.9913 474.48,81.988 474.489,81.9848 474.498,81.9816 474.508,81.9783 474.517,81.9751 474.526,81.9719 474.535,81.9686 474.544,81.9654 474.554,81.9622 474.563,81.959 474.572,81.9557 474.581,81.9525 474.59,81.9493 474.6,81.946 474.609,81.9428 474.618,81.9396 474.627,81.9364 474.636,81.9331 474.645,81.9299 474.655,81.9267 474.664,81.9235 474.673,81.9202 474.682,81.917 474.691,81.9138 474.701,81.9106 474.71,81.9073 474.719,81.9041 474.728,81.9009 474.737,81.8977 474.747,81.8945 474.756,81.8912 474.765,81.888 474.774,81.8848 474.783,81.8816 474.793,81.8784 474.802,81.8751 474.811,81.8719 474.82,81.8687 474.829,81.8655 474.838,81.8623 474.848,81.859 474.857,81.8558 474.866,81.8526 474.875,81.8494 474.884,81.8462 474.894,81.843 474.903,81.8397 474.912,81.8365 474.921,81.8333 474.93,81.8301 474.94,81.8269 474.949,81.8237 474.958,81.8205 474.967,81.8173 474.976,81.814 474.985,81.8108 474.995,81.8076 475.004,81.8044 475.013,81.8012 475.022,81.798 475.031,81.7948 475.041,81.7916 475.05,81.7884 475.059,81.7851 475.068,81.7819 475.077,81.7787 475.087,81.7755 475.096,81.7723 475.105,81.7691 475.114,81.7659 475.123,81.7627 475.133,81.7595 475.142,81.7563 475.151,81.7531 475.16,81.7499 475.169,81.7467 475.178,81.7435 475.188,81.7403 475.197,81.7371 475.206,81.7339 475.215,81.7307 475.224,81.7275 475.234,81.7243 475.243,81.7211 475.252,81.7179 475.261,81.7147 475.27,81.7115 475.28,81.7083 475.289,81.7051 475.298,81.7019 475.307,81.6987 475.316,81.6955 475.325,81.6923 475.335,81.6891 475.344,81.6859 475.353,81.6827 475.362,81.6795 475.371,81.6763 475.381,81.6731 475.39,81.6699 475.399,81.6667 475.408,81.6635 475.417,81.6603 475.427,81.6571 475.436,81.6539 475.445,81.6507 475.454,81.6475 475.463,81.6443 475.473,81.6412 475.482,81.638 475.491,81.6348 475.5,81.6316 475.509,81.6284 475.518,81.6252 475.528,81.622 475.537,81.6188 475.546,81.6156 475.555,81.6124 475.564,81.6093 475.574,81.6061 475.583,81.6029 475.592,81.5997 475.601,81.5965 475.61,81.5933 475.62,81.5901 475.629,81.587 475.638,81.5838 475.647,81.5806 475.656,81.5774 475.665,81.5742 475.675,81.571 475.684,81.5678 475.693,81.5647 475.702,81.5615 475.711,81.5583 475.721,81.5551 475.73,81.5519 475.739,81.5488 475.748,81.5456 475.757,81.5424 475.767,81.5392 475.776,81.536 475.785,81.5329 475.794,81.5297 475.803,81.5265 475.813,81.5233 475.822,81.5201 475.831,81.517 475.84,81.5138 475.849,81.5106 475.858,81.5074 475.868,81.5043 475.877,81.5011 475.886,81.4979 475.895,81.4947 475.904,81.4916 475.914,81.4884 475.923,81.4852 475.932,81.482 475.941,81.4789 475.95,81.4757 475.96,81.4725 475.969,81.4694 475.978,81.4662 475.987,81.463 475.996,81.4598 476.005,81.4567 476.015,81.4535 476.024,81.4503 476.033,81.4472 476.042,81.444 476.051,81.4408 476.061,81.4377 476.07,81.4345 476.079,81.4313 476.088,81.4282 476.097,81.425 476.107,81.4218 476.116,81.4187 476.125,81.4155 476.134,81.4123 476.143,81.4092 476.153,81.406 476.162,81.4028 476.171,81.3997 476.18,81.3965 476.189,81.3934 476.198,81.3902 476.208,81.387 476.217,81.3839 476.226,81.3807 476.235,81.3776 476.244,81.3744 476.254,81.3712 476.263,81.3681 476.272,81.3649 476.281,81.3618 476.29,81.3586 476.3,81.3554 476.309,81.3523 476.318,81.3491 476.327,81.346 476.336,81.3428 476.345,81.3397 476.355,81.3365 476.364,81.3333 476.373,81.3302 476.382,81.327 476.391,81.3239 476.401,81.3207 476.41,81.3176 476.419,81.3144 476.428,81.3113 476.437,81.3081 476.447,81.305 476.456,81.3018 476.465,81.2987 476.474,81.2955 476.483,81.2924 476.493,81.2892 476.502,81.2861 476.511,81.2829 476.52,81.2798 476.529,81.2766 476.538,81.2735 476.548,81.2703 476.557,81.2672 476.566,81.264 476.575,81.2609 476.584,81.2577 476.594,81.2546 476.603,81.2514 476.612,81.2483 476.621,81.2452 476.63,81.242 476.64,81.2389 476.649,81.2357 476.658,81.2326 476.667,81.2294 476.676,81.2263 476.685,81.2231 476.695,81.22 476.704,81.2169 476.713,81.2137 476.722,81.2106 476.731,81.2074 476.741,81.2043 476.75,81.2012 476.759,81.198 476.768,81.1949 476.777,81.1917 476.787,81.1886 476.796,81.1855 476.805,81.1823 476.814,81.1792 476.823,81.1761 476.833,81.1729 476.842,81.1698 476.851,81.1666 476.86,81.1635 476.869,81.1604 476.878,81.1572 476.888,81.1541 476.897,81.151 476.906,81.1478 476.915,81.1447 476.924,81.1416 476.934,81.1384 476.943,81.1353 476.952,81.1322 476.961,81.1291 476.97,81.1259 476.98,81.1228 476.989,81.1197 476.998,81.1165 477.007,81.1134 477.016,81.1103 477.026,81.1071 477.035,81.104 477.044,81.1009 477.053,81.0978 477.062,81.0946 477.071,81.0915 477.081,81.0884 477.09,81.0853 477.099,81.0821 477.108,81.079 477.117,81.0759 477.127,81.0728 477.136,81.0696 477.145,81.0665 477.154,81.0634 477.163,81.0603 477.173,81.0571 477.182,81.054 477.191,81.0509 477.2,81.0478 477.209,81.0447 477.218,81.0415 477.228,81.0384 477.237,81.0353 477.246,81.0322 477.255,81.0291 477.264,81.0259 477.274,81.0228 477.283,81.0197 477.292,81.0166 477.301,81.0135 477.31,81.0103 477.32,81.0072 477.329,81.0041 477.338,81.001 477.347,80.9979 477.356,80.9948 477.366,80.9916 477.375,80.9885 477.384,80.9854 477.393,80.9823 477.402,80.9792 477.411,80.9761 477.421,80.973 477.43,80.9699 477.439,80.9667 477.448,80.9636 477.457,80.9605 477.467,80.9574 477.476,80.9543 477.485,80.9512 477.494,80.9481 477.503,80.945 477.513,80.9419 477.522,80.9388 477.531,80.9356 477.54,80.9325 477.549,80.9294 477.558,80.9263 477.568,80.9232 477.577,80.9201 477.586,80.917 477.595,80.9139 477.604,80.9108 477.614,80.9077 477.623,80.9046 477.632,80.9015 477.641,80.8984 477.65,80.8953 477.66,80.8922 477.669,80.8891 477.678,80.886 477.687,80.8829 477.696,80.8798 477.706,80.8767 477.715,80.8736 477.724,80.8705 477.733,80.8674 477.742,80.8643 477.751,80.8612 477.761,80.8581 477.77,80.855 477.779,80.8519 477.788,80.8488 477.797,80.8457 477.807,80.8426 477.816,80.8395 477.825,80.8364 477.834,80.8333 477.843,80.8302 477.853,80.8271 477.862,80.824 477.871,80.8209 477.88,80.8178 477.889,80.8147 477.898,80.8116 477.908,80.8085 477.917,80.8054 477.926,80.8023 477.935,80.7992 477.944,80.7962 477.954,80.7931 477.963,80.79 477.972,80.7869 477.981,80.7838 477.99,80.7807 478,80.7776 478.009,80.7745 478.018,80.7714 478.027,80.7683 478.036,80.7653 478.046,80.7622 478.055,80.7591 478.064,80.756 478.073,80.7529 478.082,80.7498 478.091,80.7467 478.101,80.7437 478.11,80.7406 478.119,80.7375 478.128,80.7344 478.137,80.7313 478.147,80.7282 478.156,80.7251 478.165,80.7221 478.174,80.719 478.183,80.7159 478.193,80.7128 478.202,80.7097 478.211,80.7067 478.22,80.7036 478.229,80.7005 478.238,80.6974 478.248,80.6943 478.257,80.6913 478.266,80.6882 478.275,80.6851 478.284,80.682 478.294,80.6789 478.303,80.6759 478.312,80.6728 478.321,80.6697 478.33,80.6666 478.34,80.6636 478.349,80.6605 478.358,80.6574 478.367,80.6543 478.376,80.6513 478.386,80.6482 478.395,80.6451 478.404,80.642 478.413,80.639 478.422,80.6359 478.431,80.6328 478.441,80.6297 478.45,80.6267 478.459,80.6236 478.468,80.6205 478.477,80.6175 478.487,80.6144 478.496,80.6113 478.505,80.6083 478.514,80.6052 478.523,80.6021 478.533,80.599 478.542,80.596 478.551,80.5929 478.56,80.5898 478.569,80.5868 478.578,80.5837 478.588,80.5806 478.597,80.5776 478.606,80.5745 478.615,80.5714 478.624,80.5684 478.634,80.5653 478.643,80.5623 478.652,80.5592 478.661,80.5561 478.67,80.5531 478.68,80.55 478.689,80.5469 478.698,80.5439 478.707,80.5408 478.716,80.5378 478.726,80.5347 478.735,80.5316 478.744,80.5286 478.753,80.5255 478.762,80.5225 478.771,80.5194 478.781,80.5163 478.79,80.5133 478.799,80.5102 478.808,80.5072 478.817,80.5041 478.827,80.5011 478.836,80.498 478.845,80.4949 478.854,80.4919 478.863,80.4888 478.873,80.4858 478.882,80.4827 478.891,80.4797 478.9,80.4766 478.909,80.4736 478.918,80.4705 478.928,80.4675 478.937,80.4644 478.946,80.4613 478.955,80.4583 478.964,80.4552 478.974,80.4522 478.983,80.4491 478.992,80.4461 479.001,80.443 479.01,80.44 479.02,80.4369 479.029,80.4339 479.038,80.4308 479.047,80.4278 479.056,80.4248 479.066,80.4217 479.075,80.4187 479.084,80.4156 479.093,80.4126 479.102,80.4095 479.111,80.4065 479.121,80.4034 479.13,80.4004 479.139,80.3973 479.148,80.3943 479.157,80.3913 479.167,80.3882 479.176,80.3852 479.185,80.3821 479.194,80.3791 479.203,80.376 479.213,80.373 479.222,80.37 479.231,80.3669 479.24,80.3639 479.249,80.3608 479.258,80.3578 479.268,80.3548 479.277,80.3517 479.286,80.3487 479.295,80.3456 479.304,80.3426 479.314,80.3396 479.323,80.3365 479.332,80.3335 479.341,80.3305 479.35,80.3274 479.36,80.3244 479.369,80.3213 479.378,80.3183 479.387,80.3153 479.396,80.3122 479.406,80.3092 479.415,80.3062 479.424,80.3031 479.433,80.3001 479.442,80.2971 479.451,80.294 479.461,80.291 479.47,80.288 479.479,80.285 479.488,80.2819 479.497,80.2789 479.507,80.2759 479.516,80.2728 479.525,80.2698 479.534,80.2668 479.543,80.2637 479.553,80.2607 479.562,80.2577 479.571,80.2547 479.58,80.2516 479.589,80.2486 479.599,80.2456 479.608,80.2426 479.617,80.2395 479.626,80.2365 479.635,80.2335 479.644,80.2305 479.654,80.2274 479.663,80.2244 479.672,80.2214 479.681,80.2184 479.69,80.2153 479.7,80.2123 479.709,80.2093 479.718,80.2063 479.727,80.2033 479.736,80.2002 479.746,80.1972 479.755,80.1942 479.764,80.1912 479.773,80.1881 479.782,80.1851 479.791,80.1821 479.801,80.1791 479.81,80.1761 479.819,80.1731 479.828,80.17 479.837,80.167 479.847,80.164 479.856,80.161 479.865,80.158 479.874,80.155 479.883,80.1519 479.893,80.1489 479.902,80.1459 479.911,80.1429 479.92,80.1399 479.929,80.1369 479.939,80.1339 479.948,80.1308 479.957,80.1278 479.966,80.1248 479.975,80.1218 479.984,80.1188 479.994,80.1158 480.003,80.1128 480.012,80.1098 480.021,80.1068 480.03,80.1037 480.04,80.1007 480.049,80.0977 480.058,80.0947 480.067,80.0917 480.076,80.0887 480.086,80.0857 480.095,80.0827 480.104,80.0797 480.113,80.0767 480.122,80.0737 480.131,80.0707 480.141,80.0677 480.15,80.0647 480.159,80.0617 480.168,80.0586 480.177,80.0556 480.187,80.0526 480.196,80.0496 480.205,80.0466 480.214,80.0436 480.223,80.0406 480.233,80.0376 480.242,80.0346 480.251,80.0316 480.26,80.0286 480.269,80.0256 480.279,80.0226 480.288,80.0196 480.297,80.0166 480.306,80.0136 480.315,80.0106 480.324,80.0076 480.334,80.0046 480.343,80.0016 480.352,79.9986 480.361,79.9956 480.37,79.9926 480.38,79.9897 480.389,79.9867 480.398,79.9837 480.407,79.9807 480.416,79.9777 480.426,79.9747 480.435,79.9717 480.444,79.9687 480.453,79.9657 480.462,79.9627 480.471,79.9597 480.481,79.9567 480.49,79.9537 480.499,79.9507 480.508,79.9477 480.517,79.9448 480.527,79.9418 480.536,79.9388 480.545,79.9358 480.554,79.9328 480.563,79.9298 480.573,79.9268 480.582,79.9238 480.591,79.9208 480.6,79.9179 480.609,79.9149 480.619,79.9119 480.628,79.9089 480.637,79.9059 480.646,79.9029 480.655,79.8999 480.664,79.897 480.674,79.894 480.683,79.891 480.692,79.888 480.701,79.885 480.71,79.882 480.72,79.8791 480.729,79.8761 480.738,79.8731 480.747,79.8701 480.756,79.8671 480.766,79.8641 480.775,79.8612 480.784,79.8582 480.793,79.8552 480.802,79.8522 480.811,79.8492 480.821,79.8463 480.83,79.8433 480.839,79.8403 480.848,79.8373 480.857,79.8344 480.867,79.8314 480.876,79.8284 480.885,79.8254 480.894,79.8224 480.903,79.8195 480.913,79.8165 480.922,79.8135 480.931,79.8105 480.94,79.8076 480.949,79.8046 480.959,79.8016 480.968,79.7987 480.977,79.7957 480.986,79.7927 480.995,79.7897 481.004,79.7868 481.014,79.7838 481.023,79.7808 481.032,79.7779 481.041,79.7749 481.05,79.7719 481.06,79.7689 481.069,79.766 481.078,79.763 481.087,79.76 481.096,79.7571 481.106,79.7541 481.115,79.7511 481.124,79.7482 481.133,79.7452 481.142,79.7422 481.151,79.7393 481.161,79.7363 481.17,79.7333 481.179,79.7304 481.188,79.7274 481.197,79.7244 481.207,79.7215 481.216,79.7185 481.225,79.7155 481.234,79.7126 481.243,79.7096 481.253,79.7067 481.262,79.7037 481.271,79.7007 481.28,79.6978 481.289,79.6948 481.299,79.6919 481.308,79.6889 481.317,79.6859 481.326,79.683 481.335,79.68 481.344,79.6771 481.354,79.6741 481.363,79.6711 481.372,79.6682 481.381,79.6652 481.39,79.6623 481.4,79.6593 481.409,79.6564 481.418,79.6534 481.427,79.6504 481.436,79.6475 481.446,79.6445 481.455,79.6416 481.464,79.6386 481.473,79.6357 481.482,79.6327 481.491,79.6298 481.501,79.6268 481.51,79.6239 481.519,79.6209 481.528,79.618 481.537,79.615 481.547,79.6121 481.556,79.6091 481.565,79.6062 481.574,79.6032 481.583,79.6003 481.593,79.5973 481.602,79.5944 481.611,79.5914 481.62,79.5885 481.629,79.5855 481.639,79.5826 481.648,79.5796 481.657,79.5767 481.666,79.5737 481.675,79.5708 481.684,79.5678 481.694,79.5649 481.703,79.5619 481.712,79.559 481.721,79.5561 481.73,79.5531 481.74,79.5502 481.749,79.5472 481.758,79.5443 481.767,79.5413 481.776,79.5384 481.786,79.5355 481.795,79.5325 481.804,79.5296 481.813,79.5266 481.822,79.5237 481.831,79.5208 481.841,79.5178 481.85,79.5149 481.859,79.5119 481.868,79.509 481.877,79.5061 481.887,79.5031 481.896,79.5002 481.905,79.4972 481.914,79.4943 481.923,79.4914 481.933,79.4884 481.942,79.4855 481.951,79.4826 481.96,79.4796 481.969,79.4767 481.979,79.4738 481.988,79.4708 481.997,79.4679 482.006,79.465 482.015,79.462 482.024,79.4591 482.034,79.4562 482.043,79.4532 482.052,79.4503 482.061,79.4474 482.07,79.4444 482.08,79.4415 482.089,79.4386 482.098,79.4356 482.107,79.4327 482.116,79.4298 482.126,79.4269 482.135,79.4239 482.144,79.421 482.153,79.4181 482.162,79.4151 482.172,79.4122 482.181,79.4093 482.19,79.4064 482.199,79.4034 482.208,79.4005 482.217,79.3976 482.227,79.3947 482.236,79.3917 482.245,79.3888 482.254,79.3859 482.263,79.383 482.273,79.38 482.282,79.3771 482.291,79.3742 482.3,79.3713 482.309,79.3684 482.319,79.3654 482.328,79.3625 482.337,79.3596 482.346,79.3567 482.355,79.3538 482.364,79.3508 482.374,79.3479 482.383,79.345 482.392,79.3421 482.401,79.3392 482.41,79.3362 482.42,79.3333 482.429,79.3304 482.438,79.3275 482.447,79.3246 482.456,79.3217 482.466,79.3187 482.475,79.3158 482.484,79.3129 482.493,79.31 482.502,79.3071 482.512,79.3042 482.521,79.3012 482.53,79.2983 482.539,79.2954 482.548,79.2925 482.557,79.2896 482.567,79.2867 482.576,79.2838 482.585,79.2809 482.594,79.278 482.603,79.275 482.613,79.2721 482.622,79.2692 482.631,79.2663 482.64,79.2634 482.649,79.2605 482.659,79.2576 482.668,79.2547 482.677,79.2518 482.686,79.2489 482.695,79.246 482.704,79.243 482.714,79.2401 482.723,79.2372 482.732,79.2343 482.741,79.2314 482.75,79.2285 482.76,79.2256 482.769,79.2227 482.778,79.2198 482.787,79.2169 482.796,79.214 482.806,79.2111 482.815,79.2082 482.824,79.2053 482.833,79.2024 482.842,79.1995 482.852,79.1966 482.861,79.1937 482.87,79.1908 482.879,79.1879 482.888,79.185 482.897,79.1821 482.907,79.1792 482.916,79.1763 482.925,79.1734 482.934,79.1705 482.943,79.1676 482.953,79.1647 482.962,79.1618 482.971,79.1589 482.98,79.156 482.989,79.1531 482.999,79.1502 483.008,79.1473 483.017,79.1444 483.026,79.1415 483.035,79.1386 483.044,79.1357 483.054,79.1328 483.063,79.13 483.072,79.1271 483.081,79.1242 483.09,79.1213 483.1,79.1184 483.109,79.1155 483.118,79.1126 483.127,79.1097 483.136,79.1068 483.146,79.1039 483.155,79.101 483.164,79.0981 483.173,79.0953 483.182,79.0924 483.192,79.0895 483.201,79.0866 483.21,79.0837 483.219,79.0808 483.228,79.0779 483.237,79.075 483.247,79.0722 483.256,79.0693 483.265,79.0664 483.274,79.0635 483.283,79.0606 483.293,79.0577 483.302,79.0548 483.311,79.052 483.32,79.0491 483.329,79.0462 483.339,79.0433 483.348,79.0404 483.357,79.0375 483.366,79.0347 483.375,79.0318 483.384,79.0289 483.394,79.026 483.403,79.0231 483.412,79.0203 483.421,79.0174 483.43,79.0145 483.44,79.0116 483.449,79.0087 483.458,79.0059 483.467,79.003 483.476,79.0001 483.486,78.9972 483.495,78.9944 483.504,78.9915 483.513,78.9886 483.522,78.9857 483.532,78.9829 483.541,78.98 483.55,78.9771 483.559,78.9742 483.568,78.9714 483.577,78.9685 483.587,78.9656 483.596,78.9627 483.605,78.9599 483.614,78.957 483.623,78.9541 483.633,78.9512 483.642,78.9484 483.651,78.9455 483.66,78.9426 483.669,78.9398 483.679,78.9369 483.688,78.934 483.697,78.9311 483.706,78.9283 483.715,78.9254 483.724,78.9225 483.734,78.9197 483.743,78.9168 483.752,78.9139 483.761,78.9111 483.77,78.9082 483.78,78.9053 483.789,78.9025 483.798,78.8996 483.807,78.8967 483.816,78.8939 483.826,78.891 483.835,78.8881 483.844,78.8853 483.853,78.8824 483.862,78.8796 483.872,78.8767 483.881,78.8738 483.89,78.871 483.899,78.8681 483.908,78.8652 483.917,78.8624 483.927,78.8595 483.936,78.8567 483.945,78.8538 483.954,78.8509 483.963,78.8481 483.973,78.8452 483.982,78.8424 483.991,78.8395 484,78.8366 484.009,78.8338 484.019,78.8309 484.028,78.8281 484.037,78.8252 484.046,78.8224 484.055,78.8195 484.064,78.8166 484.074,78.8138 484.083,78.8109 484.092,78.8081 484.101,78.8052 484.11,78.8024 484.12,78.7995 484.129,78.7967 484.138,78.7938 484.147,78.791 484.156,78.7881 484.166,78.7853 484.175,78.7824 484.184,78.7796 484.193,78.7767 484.202,78.7739 484.212,78.771 484.221,78.7682 484.23,78.7653 484.239,78.7625 484.248,78.7596 484.257,78.7568 484.267,78.7539 484.276,78.7511 484.285,78.7482 484.294,78.7454 484.303,78.7425 484.313,78.7397 484.322,78.7368 484.331,78.734 484.34,78.7311 484.349,78.7283 484.359,78.7254 484.368,78.7226 484.377,78.7198 484.386,78.7169 484.395,78.7141 484.405,78.7112 484.414,78.7084 484.423,78.7055 484.432,78.7027 484.441,78.6999 484.45,78.697 484.46,78.6942 484.469,78.6913 484.478,78.6885 484.487,78.6857 484.496,78.6828 484.506,78.68 484.515,78.6771 484.524,78.6743 484.533,78.6715 484.542,78.6686 484.552,78.6658 484.561,78.6629 484.57,78.6601 484.579,78.6573 484.588,78.6544 484.597,78.6516 484.607,78.6488 484.616,78.6459 484.625,78.6431 484.634,78.6403 484.643,78.6374 484.653,78.6346 484.662,78.6318 484.671,78.6289 484.68,78.6261 484.689,78.6233 484.699,78.6204 484.708,78.6176 484.717,78.6148 484.726,78.6119 484.735,78.6091 484.745,78.6063 484.754,78.6034 484.763,78.6006 484.772,78.5978 484.781,78.595 484.79,78.5921 484.8,78.5893 484.809,78.5865 484.818,78.5836 484.827,78.5808 484.836,78.578 484.846,78.5752 484.855,78.5723 484.864,78.5695 484.873,78.5667 484.882,78.5639 484.892,78.561 484.901,78.5582 484.91,78.5554 484.919,78.5526 484.928,78.5497 484.937,78.5469 484.947,78.5441 484.956,78.5413 484.965,78.5384 484.974,78.5356 484.983,78.5328 484.993,78.53 485.002,78.5272 485.011,78.5243 485.02,78.5215 485.029,78.5187 485.039,78.5159 485.048,78.5131 485.057,78.5102 485.066,78.5074 485.075,78.5046 485.085,78.5018 485.094,78.499 485.103,78.4961 485.112,78.4933 485.121,78.4905 485.13,78.4877 485.14,78.4849 485.149,78.4821 485.158,78.4793 485.167,78.4764 485.176,78.4736 485.186,78.4708 485.195,78.468 485.204,78.4652 485.213,78.4624 485.222,78.4596 485.232,78.4567 485.241,78.4539 485.25,78.4511 485.259,78.4483 485.268,78.4455 485.277,78.4427 485.287,78.4399 485.296,78.4371 485.305,78.4343 485.314,78.4314 485.323,78.4286 485.333,78.4258 485.342,78.423 485.351,78.4202 485.36,78.4174 485.369,78.4146 485.379,78.4118 485.388,78.409 485.397,78.4062 485.406,78.4034 485.415,78.4006 485.425,78.3978 485.434,78.395 485.443,78.3921 485.452,78.3893 485.461,78.3865 485.47,78.3837 485.48,78.3809 485.489,78.3781 485.498,78.3753 485.507,78.3725 485.516,78.3697 485.526,78.3669 485.535,78.3641 485.544,78.3613 485.553,78.3585 485.562,78.3557 485.572,78.3529 485.581,78.3501 485.59,78.3473 485.599,78.3445 485.608,78.3417 485.617,78.3389 485.627,78.3361 485.636,78.3333 485.645,78.3305 485.654,78.3277 485.663,78.3249 485.673,78.3221 485.682,78.3193 485.691,78.3165 485.7,78.3138 485.709,78.311 485.719,78.3082 485.728,78.3054 485.737,78.3026 485.746,78.2998 485.755,78.297 485.765,78.2942 485.774,78.2914 485.783,78.2886 485.792,78.2858 485.801,78.283 485.81,78.2802 485.82,78.2774 485.829,78.2747 485.838,78.2719 485.847,78.2691 485.856,78.2663 485.866,78.2635 485.875,78.2607 485.884,78.2579 485.893,78.2551 485.902,78.2523 485.912,78.2496 485.921,78.2468 485.93,78.244 485.939,78.2412 485.948,78.2384 485.957,78.2356 485.967,78.2328 485.976,78.23 485.985,78.2273 485.994,78.2245 486.003,78.2217 486.013,78.2189 486.022,78.2161 486.031,78.2133 486.04,78.2106 486.049,78.2078 486.059,78.205 486.068,78.2022 486.077,78.1994 486.086,78.1967 486.095,78.1939 486.105,78.1911 486.114,78.1883 486.123,78.1855 486.132,78.1828 486.141,78.18 486.15,78.1772 486.16,78.1744 486.169,78.1716 486.178,78.1689 486.187,78.1661 486.196,78.1633 486.206,78.1605 486.215,78.1578 486.224,78.155 486.233,78.1522 486.242,78.1494 486.252,78.1466 486.261,78.1439 486.27,78.1411 486.279,78.1383 486.288,78.1356 486.297,78.1328 486.307,78.13 486.316,78.1272 486.325,78.1245 486.334,78.1217 486.343,78.1189 486.353,78.1161 486.362,78.1134 486.371,78.1106 486.38,78.1078 486.389,78.1051 486.399,78.1023 486.408,78.0995 486.417,78.0968 486.426,78.094 486.435,78.0912 486.445,78.0884 486.454,78.0857 486.463,78.0829 486.472,78.0801 486.481,78.0774 486.49,78.0746 486.5,78.0718 486.509,78.0691 486.518,78.0663 486.527,78.0636 486.536,78.0608 486.546,78.058 486.555,78.0553 486.564,78.0525 486.573,78.0497 486.582,78.047 486.592,78.0442 486.601,78.0414 486.61,78.0387 486.619,78.0359 486.628,78.0332 486.637,78.0304 486.647,78.0276 486.656,78.0249 486.665,78.0221 486.674,78.0194 486.683,78.0166 486.693,78.0138 486.702,78.0111 486.711,78.0083 486.72,78.0056 486.729,78.0028 486.739,78 486.748,77.9973 486.757,77.9945 486.766,77.9918 486.775,77.989 486.785,77.9863 486.794,77.9835 486.803,77.9808 486.812,77.978 486.821,77.9752 486.83,77.9725 486.84,77.9697 486.849,77.967 486.858,77.9642 486.867,77.9615 486.876,77.9587 486.886,77.956 486.895,77.9532 486.904,77.9505 486.913,77.9477 486.922,77.945 486.932,77.9422 486.941,77.9395 486.95,77.9367 486.959,77.934 486.968,77.9312 486.978,77.9285 486.987,77.9257 486.996,77.923 487.005,77.9202 487.014,77.9175 487.023,77.9147 487.033,77.912 487.042,77.9092 487.051,77.9065 487.06,77.9037 487.069,77.901 487.079,77.8983 487.088,77.8955 487.097,77.8928 487.106,77.89 487.115,77.8873 487.125,77.8845 487.134,77.8818 487.143,77.879 487.152,77.8763 487.161,77.8736 487.17,77.8708 487.18,77.8681 487.189,77.8653 487.198,77.8626 487.207,77.8599 487.216,77.8571 487.226,77.8544 487.235,77.8516 487.244,77.8489 487.253,77.8462 487.262,77.8434 487.272,77.8407 487.281,77.8379 487.29,77.8352 487.299,77.8325 487.308,77.8297 487.318,77.827 487.327,77.8243 487.336,77.8215 487.345,77.8188 487.354,77.8161 487.363,77.8133 487.373,77.8106 487.382,77.8079 487.391,77.8051 487.4,77.8024 487.409,77.7997 487.419,77.7969 487.428,77.7942 487.437,77.7915 487.446,77.7887 487.455,77.786 487.465,77.7833 487.474,77.7805 487.483,77.7778 487.492,77.7751 487.501,77.7723 487.51,77.7696 487.52,77.7669 487.529,77.7641 487.538,77.7614 487.547,77.7587 487.556,77.756 487.566,77.7532 487.575,77.7505 487.584,77.7478 487.593,77.7451 487.602,77.7423 487.612,77.7396 487.621,77.7369 487.63,77.7342 487.639,77.7314 487.648,77.7287 487.658,77.726 487.667,77.7233 487.676,77.7205 487.685,77.7178 487.694,77.7151 487.703,77.7124 487.713,77.7096 487.722,77.7069 487.731,77.7042 487.74,77.7015 487.749,77.6988 487.759,77.696 487.768,77.6933 487.777,77.6906 487.786,77.6879 487.795,77.6852 487.805,77.6824 487.814,77.6797 487.823,77.677 487.832,77.6743 487.841,77.6716 487.85,77.6688 487.86,77.6661 487.869,77.6634 487.878,77.6607 487.887,77.658 487.896,77.6553 487.906,77.6525 487.915,77.6498 487.924,77.6471 487.933,77.6444 487.942,77.6417 487.952,77.639 487.961,77.6363 487.97,77.6335 487.979,77.6308 487.988,77.6281 487.998,77.6254 488.007,77.6227 488.016,77.62 488.025,77.6173 488.034,77.6146 488.043,77.6119 488.053,77.6091 488.062,77.6064 488.071,77.6037 488.08,77.601 488.089,77.5983 488.099,77.5956 488.108,77.5929 488.117,77.5902 488.126,77.5875 488.135,77.5848 488.145,77.5821 488.154,77.5794 488.163,77.5767 488.172,77.5739 488.181,77.5712 488.19,77.5685 488.2,77.5658 488.209,77.5631 488.218,77.5604 488.227,77.5577 488.236,77.555 488.246,77.5523 488.255,77.5496 488.264,77.5469 488.273,77.5442 488.282,77.5415 488.292,77.5388 488.301,77.5361 488.31,77.5334 488.319,77.5307 488.328,77.528 488.338,77.5253 488.347,77.5226 488.356,77.5199 488.365,77.5172 488.374,77.5145 488.383,77.5118 488.393,77.5091 488.402,77.5064 488.411,77.5037 488.42,77.501 488.429,77.4983 488.439,77.4956 488.448,77.4929 488.457,77.4902 488.466,77.4875 488.475,77.4848 488.485,77.4821 488.494,77.4794 488.503,77.4768 488.512,77.4741 488.521,77.4714 488.53,77.4687 488.54,77.466 488.549,77.4633 488.558,77.4606 488.567,77.4579 488.576,77.4552 488.586,77.4525 488.595,77.4498 488.604,77.4471 488.613,77.4444 488.622,77.4418 488.632,77.4391 488.641,77.4364 488.65,77.4337 488.659,77.431 488.668,77.4283 488.678,77.4256 488.687,77.4229 488.696,77.4203 488.705,77.4176 488.714,77.4149 488.723,77.4122 488.733,77.4095 488.742,77.4068 488.751,77.4041 488.76,77.4015 488.769,77.3988 488.779,77.3961 488.788,77.3934 488.797,77.3907 488.806,77.388 488.815,77.3853 488.825,77.3827 488.834,77.38 488.843,77.3773 488.852,77.3746 488.861,77.3719 488.87,77.3693 488.88,77.3666 488.889,77.3639 488.898,77.3612 488.907,77.3585 488.916,77.3559 488.926,77.3532 488.935,77.3505 488.944,77.3478 488.953,77.3451 488.962,77.3425 488.972,77.3398 488.981,77.3371 488.99,77.3344 488.999,77.3318 489.008,77.3291 489.018,77.3264 489.027,77.3237 489.036,77.3211 489.045,77.3184 489.054,77.3157 489.063,77.313 489.073,77.3104 489.082,77.3077 489.091,77.305 489.1,77.3023 489.109,77.2997 489.119,77.297 489.128,77.2943 489.137,77.2917 489.146,77.289 489.155,77.2863 489.165,77.2836 489.174,77.281 489.183,77.2783 489.192,77.2756 489.201,77.273 489.21,77.2703 489.22,77.2676 489.229,77.265 489.238,77.2623 489.247,77.2596 489.256,77.257 489.266,77.2543 489.275,77.2516 489.284,77.249 489.293,77.2463 489.302,77.2436 489.312,77.241 489.321,77.2383 489.33,77.2356 489.339,77.233 489.348,77.2303 489.358,77.2276 489.367,77.225 489.376,77.2223 489.385,77.2196 489.394,77.217 489.403,77.2143 489.413,77.2117 489.422,77.209 489.431,77.2063 489.44,77.2037 489.449,77.201 489.459,77.1984 489.468,77.1957 489.477,77.193 489.486,77.1904 489.495,77.1877 489.505,77.1851 489.514,77.1824 489.523,77.1797 489.532,77.1771 489.541,77.1744 489.551,77.1718 489.56,77.1691 489.569,77.1665 489.578,77.1638 489.587,77.1611 489.596,77.1585 489.606,77.1558 489.615,77.1532 489.624,77.1505 489.633,77.1479 489.642,77.1452 489.652,77.1426 489.661,77.1399 489.67,77.1373 489.679,77.1346 489.688,77.132 489.698,77.1293 489.707,77.1266 489.716,77.124 489.725,77.1213 489.734,77.1187 489.743,77.116 489.753,77.1134 489.762,77.1107 489.771,77.1081 489.78,77.1054 489.789,77.1028 489.799,77.1002 489.808,77.0975 489.817,77.0949 489.826,77.0922 489.835,77.0896 489.845,77.0869 489.854,77.0843 489.863,77.0816 489.872,77.079 489.881,77.0763 489.891,77.0737 489.9,77.071 489.909,77.0684 489.918,77.0658 489.927,77.0631 489.936,77.0605 489.946,77.0578 489.955,77.0552 489.964,77.0525 489.973,77.0499 489.982,77.0473 489.992,77.0446 490.001,77.042 490.01,77.0393 490.019,77.0367 490.028,77.0341 490.038,77.0314 490.047,77.0288 490.056,77.0261 490.065,77.0235 490.074,77.0209 490.083,77.0182 490.093,77.0156 490.102,77.0129 490.111,77.0103 490.12,77.0077 490.129,77.005 490.139,77.0024 490.148,76.9998 490.157,76.9971 490.166,76.9945 490.175,76.9919 490.185,76.9892 490.194,76.9866 490.203,76.9839 490.212,76.9813 490.221,76.9787 490.231,76.976 490.24,76.9734 490.249,76.9708 490.258,76.9682 490.267,76.9655 490.276,76.9629 490.286,76.9603 490.295,76.9576 490.304,76.955 490.313,76.9524 490.322,76.9497 490.332,76.9471 490.341,76.9445 490.35,76.9418 490.359,76.9392 490.368,76.9366 490.378,76.934 490.387,76.9313 490.396,76.9287 490.405,76.9261 490.414,76.9235 490.423,76.9208 490.433,76.9182 490.442,76.9156 490.451,76.913 490.46,76.9103 490.469,76.9077 490.479,76.9051 490.488,76.9025 490.497,76.8998 490.506,76.8972 490.515,76.8946 490.525,76.892 490.534,76.8893 490.543,76.8867 490.552,76.8841 490.561,76.8815 490.571,76.8789 490.58,76.8762 490.589,76.8736 490.598,76.871 490.607,76.8684 490.616,76.8657 490.626,76.8631 490.635,76.8605 490.644,76.8579 490.653,76.8553 490.662,76.8527 490.672,76.85 490.681,76.8474 490.69,76.8448 490.699,76.8422 490.708,76.8396 490.718,76.837 490.727,76.8343 490.736,76.8317 490.745,76.8291 490.754,76.8265 490.763,76.8239 490.773,76.8213 490.782,76.8187 490.791,76.816 490.8,76.8134 490.809,76.8108 490.819,76.8082 490.828,76.8056 490.837,76.803 490.846,76.8004 490.855,76.7978 490.865,76.7951 490.874,76.7925 490.883,76.7899 490.892,76.7873 490.901,76.7847 490.911,76.7821 490.92,76.7795 490.929,76.7769 490.938,76.7743 490.947,76.7717 490.956,76.769 490.966,76.7664 490.975,76.7638 490.984,76.7612 490.993,76.7586 491.002,76.756 491.012,76.7534 491.021,76.7508 491.03,76.7482 491.039,76.7456 491.048,76.743 491.058,76.7404 491.067,76.7378 491.076,76.7352 491.085,76.7326 491.094,76.73 491.103,76.7274 491.113,76.7248 491.122,76.7222 491.131,76.7196 491.14,76.717 491.149,76.7144 491.159,76.7118 491.168,76.7092 491.177,76.7066 491.186,76.704 491.195,76.7014 491.205,76.6988 491.214,76.6962 491.223,76.6936 491.232,76.691 491.241,76.6884 491.251,76.6858 491.26,76.6832 491.269,76.6806 491.278,76.678 491.287,76.6754 491.296,76.6728 491.306,76.6702 491.315,76.6676 491.324,76.665 491.333,76.6624 491.342,76.6598 491.352,76.6572 491.361,76.6546 491.37,76.652 491.379,76.6494 491.388,76.6468 491.398,76.6442 491.407,76.6417 491.416,76.6391 491.425,76.6365 491.434,76.6339 491.443,76.6313 491.453,76.6287 491.462,76.6261 491.471,76.6235 491.48,76.6209 491.489,76.6183 491.499,76.6158 491.508,76.6132 491.517,76.6106 491.526,76.608 491.535,76.6054 491.545,76.6028 491.554,76.6002 491.563,76.5976 491.572,76.5951 491.581,76.5925 491.591,76.5899 491.6,76.5873 491.609,76.5847 491.618,76.5821 491.627,76.5795 491.636,76.577 491.646,76.5744 491.655,76.5718 491.664,76.5692 491.673,76.5666 491.682,76.564 491.692,76.5615 491.701,76.5589 491.71,76.5563 491.719,76.5537 491.728,76.5511 491.738,76.5485 491.747,76.546 491.756,76.5434 491.765,76.5408 491.774,76.5382 491.784,76.5357 491.793,76.5331 491.802,76.5305 491.811,76.5279 491.82,76.5253 491.829,76.5228 491.839,76.5202 491.848,76.5176 491.857,76.515 491.866,76.5125 491.875,76.5099 491.885,76.5073 491.894,76.5047 491.903,76.5022 491.912,76.4996 491.921,76.497 491.931,76.4944 491.94,76.4919 491.949,76.4893 491.958,76.4867 491.967,76.4841 491.976,76.4816 491.986,76.479 491.995,76.4764 492.004,76.4738 492.013,76.4713 492.022,76.4687 492.032,76.4661 492.041,76.4636 492.05,76.461 492.059,76.4584 492.068,76.4559 492.078,76.4533 492.087,76.4507 492.096,76.4481 492.105,76.4456 492.114,76.443 492.124,76.4404 492.133,76.4379 492.142,76.4353 492.151,76.4327 492.16,76.4302 492.169,76.4276 492.179,76.425 492.188,76.4225 492.197,76.4199 492.206,76.4174 492.215,76.4148 492.225,76.4122 492.234,76.4097 492.243,76.4071 492.252,76.4045 492.261,76.402 492.271,76.3994 492.28,76.3968 492.289,76.3943 492.298,76.3917 492.307,76.3892 492.316,76.3866 492.326,76.384 492.335,76.3815 492.344,76.3789 492.353,76.3764 492.362,76.3738 492.372,76.3712 492.381,76.3687 492.39,76.3661 492.399,76.3636 492.408,76.361 492.418,76.3585 492.427,76.3559 492.436,76.3533 492.445,76.3508 492.454,76.3482 492.464,76.3457 492.473,76.3431 492.482,76.3406 492.491,76.338 492.5,76.3354 492.509,76.3329 492.519,76.3303 492.528,76.3278 492.537,76.3252 492.546,76.3227 492.555,76.3201 492.565,76.3176 492.574,76.315 492.583,76.3125 492.592,76.3099 492.601,76.3074 492.611,76.3048 492.62,76.3023 492.629,76.2997 492.638,76.2972 492.647,76.2946 492.656,76.2921 492.666,76.2895 492.675,76.287 492.684,76.2844 492.693,76.2819 492.702,76.2793 492.712,76.2768 492.721,76.2742 492.73,76.2717 492.739,76.2691 492.748,76.2666 492.758,76.264 492.767,76.2615 492.776,76.259 492.785,76.2564 492.794,76.2539 492.804,76.2513 492.813,76.2488 492.822,76.2462 492.831,76.2437 492.84,76.2411 492.849,76.2386 492.859,76.2361 492.868,76.2335 492.877,76.231 492.886,76.2284 492.895,76.2259 492.905,76.2234 492.914,76.2208 492.923,76.2183 492.932,76.2157 492.941,76.2132 492.951,76.2107 492.96,76.2081 492.969,76.2056 492.978,76.203 492.987,76.2005 492.996,76.198 493.006,76.1954 493.015,76.1929 493.024,76.1904 493.033,76.1878 493.042,76.1853 493.052,76.1827 493.061,76.1802 493.07,76.1777 493.079,76.1751 493.088,76.1726 493.098,76.1701 493.107,76.1675 493.116,76.165 493.125,76.1625 493.134,76.1599 493.144,76.1574 493.153,76.1549 493.162,76.1523 493.171,76.1498 493.18,76.1473 493.189,76.1447 493.199,76.1422 493.208,76.1397 493.217,76.1372 493.226,76.1346 493.235,76.1321 493.245,76.1296 493.254,76.127 493.263,76.1245 493.272,76.122 493.281,76.1195 493.291,76.1169 493.3,76.1144 493.309,76.1119 493.318,76.1093 493.327,76.1068 493.336,76.1043 493.346,76.1018 493.355,76.0992 493.364,76.0967 493.373,76.0942 493.382,76.0917 493.392,76.0891 493.401,76.0866 493.41,76.0841 493.419,76.0816 493.428,76.079 493.438,76.0765 493.447,76.074 493.456,76.0715 493.465,76.069 493.474,76.0664 493.484,76.0639 493.493,76.0614 493.502,76.0589 493.511,76.0564 493.52,76.0538 493.529,76.0513 493.539,76.0488 493.548,76.0463 493.557,76.0438 493.566,76.0412 493.575,76.0387 493.585,76.0362 493.594,76.0337 493.603,76.0312 493.612,76.0287 493.621,76.0261 493.631,76.0236 493.64,76.0211 493.649,76.0186 493.658,76.0161 493.667,76.0136 493.676,76.011 493.686,76.0085 493.695,76.006 493.704,76.0035 493.713,76.001 493.722,75.9985 493.732,75.996 493.741,75.9935 493.75,75.9909 493.759,75.9884 493.768,75.9859 493.778,75.9834 493.787,75.9809 493.796,75.9784 493.805,75.9759 493.814,75.9734 493.824,75.9709 493.833,75.9683 493.842,75.9658 493.851,75.9633 493.86,75.9608 493.869,75.9583 493.879,75.9558 493.888,75.9533 493.897,75.9508 493.906,75.9483 493.915,75.9458 493.925,75.9433 493.934,75.9408 493.943,75.9383 493.952,75.9358 493.961,75.9332 493.971,75.9307 493.98,75.9282 493.989,75.9257 493.998,75.9232 494.007,75.9207 494.016,75.9182 494.026,75.9157 494.035,75.9132 494.044,75.9107 494.053,75.9082 494.062,75.9057 494.072,75.9032 494.081,75.9007 494.09,75.8982 494.099,75.8957 494.108,75.8932 494.118,75.8907 494.127,75.8882 494.136,75.8857 494.145,75.8832 494.154,75.8807 494.164,75.8782 494.173,75.8757 494.182,75.8732 494.191,75.8707 494.2,75.8682 494.209,75.8657 494.219,75.8632 494.228,75.8607 494.237,75.8582 494.246,75.8557 494.255,75.8533 494.265,75.8508 494.274,75.8483 494.283,75.8458 494.292,75.8433 494.301,75.8408 494.311,75.8383 494.32,75.8358 494.329,75.8333 494.338,75.8308 494.347,75.8283 494.357,75.8258 494.366,75.8233 494.375,75.8208 494.384,75.8184 494.393,75.8159 494.402,75.8134 494.412,75.8109 494.421,75.8084 494.43,75.8059 494.439,75.8034 494.448,75.8009 494.458,75.7984 494.467,75.796 494.476,75.7935 494.485,75.791 494.494,75.7885 494.504,75.786 494.513,75.7835 494.522,75.781 494.531,75.7785 494.54,75.7761 494.549,75.7736 494.559,75.7711 494.568,75.7686 494.577,75.7661 494.586,75.7636 494.595,75.7612 494.605,75.7587 494.614,75.7562 494.623,75.7537 494.632,75.7512 494.641,75.7487 494.651,75.7463 494.66,75.7438 494.669,75.7413 494.678,75.7388 494.687,75.7363 494.697,75.7339 494.706,75.7314 494.715,75.7289 494.724,75.7264 494.733,75.7239 494.742,75.7215 494.752,75.719 494.761,75.7165 494.77,75.714 494.779,75.7115 494.788,75.7091 494.798,75.7066 494.807,75.7041 494.816,75.7016 494.825,75.6992 494.834,75.6967 494.844,75.6942 494.853,75.6917 494.862,75.6893 494.871,75.6868 494.88,75.6843 494.889,75.6818 494.899,75.6794 494.908,75.6769 494.917,75.6744 494.926,75.6719 494.935,75.6695 494.945,75.667 494.954,75.6645 494.963,75.6621 494.972,75.6596 494.981,75.6571 494.991,75.6546 495,75.6522 495.009,75.6497 495.018,75.6472 495.027,75.6448 495.037,75.6423 495.046,75.6398 495.055,75.6374 495.064,75.6349 495.073,75.6324 495.082,75.63 495.092,75.6275 495.101,75.625 495.11,75.6226 495.119,75.6201 495.128,75.6176 495.138,75.6152 495.147,75.6127 495.156,75.6102 495.165,75.6078 495.174,75.6053 495.184,75.6028 495.193,75.6004 495.202,75.5979 495.211,75.5954 495.22,75.593 495.229,75.5905 495.239,75.5881 495.248,75.5856 495.257,75.5831 495.266,75.5807 495.275,75.5782 495.285,75.5758 495.294,75.5733 495.303,75.5708 495.312,75.5684 495.321,75.5659 495.331,75.5635 495.34,75.561 495.349,75.5585 495.358,75.5561 495.367,75.5536 495.377,75.5512 495.386,75.5487 495.395,75.5462 495.404,75.5438 495.413,75.5413 495.422,75.5389 495.432,75.5364 495.441,75.534 495.45,75.5315 495.459,75.5291 495.468,75.5266 495.478,75.5241 495.487,75.5217 495.496,75.5192 495.505,75.5168 495.514,75.5143 495.524,75.5119 495.533,75.5094 495.542,75.507 495.551,75.5045 495.56,75.5021 495.569,75.4996 495.579,75.4972 495.588,75.4947 495.597,75.4923 495.606,75.4898 495.615,75.4874 495.625,75.4849 495.634,75.4825 495.643,75.48 495.652,75.4776 495.661,75.4751 495.671,75.4727 495.68,75.4702 495.689,75.4678 495.698,75.4653 495.707,75.4629 495.717,75.4604 495.726,75.458 495.735,75.4556 495.744,75.4531 495.753,75.4507 495.762,75.4482 495.772,75.4458 495.781,75.4433 495.79,75.4409 495.799,75.4384 495.808,75.436 495.818,75.4336 495.827,75.4311 495.836,75.4287 495.845,75.4262 495.854,75.4238 495.864,75.4213 495.873,75.4189 495.882,75.4165 495.891,75.414 495.9,75.4116 495.909,75.4091 495.919,75.4067 495.928,75.4043 495.937,75.4018 495.946,75.3994 495.955,75.3969 495.965,75.3945 495.974,75.3921 495.983,75.3896 495.992,75.3872 496.001,75.3848 496.011,75.3823 496.02,75.3799 496.029,75.3775 496.038,75.375 496.047,75.3726 496.057,75.3701 496.066,75.3677 496.075,75.3653 496.084,75.3628 496.093,75.3604 496.102,75.358 496.112,75.3555 496.121,75.3531 496.13,75.3507 496.139,75.3482 496.148,75.3458 496.158,75.3434 496.167,75.341 496.176,75.3385 496.185,75.3361 496.194,75.3337 496.204,75.3312 496.213,75.3288 496.222,75.3264 496.231,75.3239 496.24,75.3215 496.249,75.3191 496.259,75.3167 496.268,75.3142 496.277,75.3118 496.286,75.3094 496.295,75.3069 496.305,75.3045 496.314,75.3021 496.323,75.2997 496.332,75.2972 496.341,75.2948 496.351,75.2924 496.36,75.29 496.369,75.2875 496.378,75.2851 496.387,75.2827 496.397,75.2803 496.406,75.2778 496.415,75.2754 496.424,75.273 496.433,75.2706 496.442,75.2681 496.452,75.2657 496.461,75.2633 496.47,75.2609 496.479,75.2585 496.488,75.256 496.498,75.2536 496.507,75.2512 496.516,75.2488 496.525,75.2464 496.534,75.2439 496.544,75.2415 496.553,75.2391 496.562,75.2367 496.571,75.2343 496.58,75.2319 496.589,75.2294 496.599,75.227 496.608,75.2246 496.617,75.2222 496.626,75.2198 496.635,75.2174 496.645,75.2149 496.654,75.2125 496.663,75.2101 496.672,75.2077 496.681,75.2053 496.691,75.2029 496.7,75.2004 496.709,75.198 496.718,75.1956 496.727,75.1932 496.737,75.1908 496.746,75.1884 496.755,75.186 496.764,75.1836 496.773,75.1811 496.782,75.1787 496.792,75.1763 496.801,75.1739 496.81,75.1715 496.819,75.1691 496.828,75.1667 496.838,75.1643 496.847,75.1619 496.856,75.1595 496.865,75.157 496.874,75.1546 496.884,75.1522 496.893,75.1498 496.902,75.1474 496.911,75.145 496.92,75.1426 496.93,75.1402 496.939,75.1378 496.948,75.1354 496.957,75.133 496.966,75.1306 496.975,75.1282 496.985,75.1258 496.994,75.1234 497.003,75.121 497.012,75.1186 497.021,75.1162 497.031,75.1137 497.04,75.1113 497.049,75.1089 497.058,75.1065 497.067,75.1041 497.077,75.1017 497.086,75.0993 497.095,75.0969 497.104,75.0945 497.113,75.0921 497.122,75.0897 497.132,75.0873 497.141,75.0849 497.15,75.0825 497.159,75.0801 497.168,75.0777 497.178,75.0753 497.187,75.0729 497.196,75.0705 497.205,75.0681 497.214,75.0658 497.224,75.0634 497.233,75.061 497.242,75.0586 497.251,75.0562 497.26,75.0538 497.27,75.0514 497.279,75.049 497.288,75.0466 497.297,75.0442 497.306,75.0418 497.315,75.0394 497.325,75.037 497.334,75.0346 497.343,75.0322 497.352,75.0298 497.361,75.0274 497.371,75.025 497.38,75.0227 497.389,75.0203 497.398,75.0179 497.407,75.0155 497.417,75.0131 497.426,75.0107 497.435,75.0083 497.444,75.0059 497.453,75.0035 497.462,75.0011 497.472,74.9988 497.481,74.9964 497.49,74.994 497.499,74.9916 497.508,74.9892 497.518,74.9868 497.527,74.9844 497.536,74.982 497.545,74.9797 497.554,74.9773 497.564,74.9749 497.573,74.9725 497.582,74.9701 497.591,74.9677 497.6,74.9653 497.61,74.963 497.619,74.9606 497.628,74.9582 497.637,74.9558 497.646,74.9534 497.655,74.951 497.665,74.9487 497.674,74.9463 497.683,74.9439 497.692,74.9415 497.701,74.9391 497.711,74.9368 497.72,74.9344 497.729,74.932 497.738,74.9296 497.747,74.9272 497.757,74.9249 497.766,74.9225 497.775,74.9201 497.784,74.9177 497.793,74.9153 497.802,74.913 497.812,74.9106 497.821,74.9082 497.83,74.9058 497.839,74.9035 497.848,74.9011 497.858,74.8987 497.867,74.8963 497.876,74.894 497.885,74.8916 497.894,74.8892 497.904,74.8868 497.913,74.8845 497.922,74.8821 497.931,74.8797 497.94,74.8773 497.95,74.875 497.959,74.8726 497.968,74.8702 497.977,74.8678 497.986,74.8655 497.995,74.8631 498.005,74.8607 498.014,74.8584 498.023,74.856 498.032,74.8536 498.041,74.8512 498.051,74.8489 498.06,74.8465 498.069,74.8441 498.078,74.8418 498.087,74.8394 498.097,74.837 498.106,74.8347 498.115,74.8323 498.124,74.8299 498.133,74.8276 498.142,74.8252 498.152,74.8228 498.161,74.8205 498.17,74.8181 498.179,74.8157 498.188,74.8134 498.198,74.811 498.207,74.8086 498.216,74.8063 498.225,74.8039 498.234,74.8015 498.244,74.7992 498.253,74.7968 498.262,74.7945 498.271,74.7921 498.28,74.7897 498.29,74.7874 498.299,74.785 498.308,74.7826 498.317,74.7803 498.326,74.7779 498.335,74.7756 498.345,74.7732 498.354,74.7708 498.363,74.7685 498.372,74.7661 498.381,74.7638 498.391,74.7614 498.4,74.759 498.409,74.7567 498.418,74.7543 498.427,74.752 498.437,74.7496 498.446,74.7473 498.455,74.7449 498.464,74.7425 498.473,74.7402 498.482,74.7378 498.492,74.7355 498.501,74.7331 498.51,74.7308 498.519,74.7284 498.528,74.7261 498.538,74.7237 498.547,74.7213 498.556,74.719 498.565,74.7166 498.574,74.7143 498.584,74.7119 498.593,74.7096 498.602,74.7072 498.611,74.7049 498.62,74.7025 498.63,74.7002 498.639,74.6978 498.648,74.6955 498.657,74.6931 498.666,74.6908 498.675,74.6884 498.685,74.6861 498.694,74.6837 498.703,74.6814 498.712,74.679 498.721,74.6767 498.731,74.6743 498.74,74.672 498.749,74.6696 498.758,74.6673 498.767,74.6649 498.777,74.6626 498.786,74.6603 498.795,74.6579 498.804,74.6556 498.813,74.6532 498.822,74.6509 498.832,74.6485 498.841,74.6462 498.85,74.6438 498.859,74.6415 498.868,74.6392 498.878,74.6368 498.887,74.6345 498.896,74.6321 498.905,74.6298 498.914,74.6274 498.924,74.6251 498.933,74.6228 498.942,74.6204 498.951,74.6181 498.96,74.6157 498.97,74.6134 498.979,74.6111 498.988,74.6087 498.997,74.6064 499.006,74.604 499.015,74.6017 499.025,74.5994 499.034,74.597 499.043,74.5947 499.052,74.5923 499.061,74.59 499.071,74.5877 499.08,74.5853 499.089,74.583 499.098,74.5807 499.107,74.5783 499.117,74.576 499.126,74.5737 499.135,74.5713 499.144,74.569 499.153,74.5667 499.163,74.5643 499.172,74.562 499.181,74.5597 499.19,74.5573 499.199,74.555 499.208,74.5527 499.218,74.5503 499.227,74.548 499.236,74.5457 499.245,74.5433 499.254,74.541 499.264,74.5387 499.273,74.5363 499.282,74.534 499.291,74.5317 499.3,74.5293 499.31,74.527 499.319,74.5247 499.328,74.5224 499.337,74.52 499.346,74.5177 499.355,74.5154 499.365,74.513 499.374,74.5107 499.383,74.5084 499.392,74.5061 499.401,74.5037 499.411,74.5014 499.42,74.4991 499.429,74.4968 499.438,74.4944 499.447,74.4921 499.457,74.4898 499.466,74.4875 499.475,74.4851 499.484,74.4828 499.493,74.4805 499.503,74.4782 499.512,74.4759 499.521,74.4735 499.53,74.4712 499.539,74.4689 499.548,74.4666 499.558,74.4642 499.567,74.4619 499.576,74.4596 499.585,74.4573 499.594,74.455 499.604,74.4526 499.613,74.4503 499.622,74.448 499.631,74.4457 499.64,74.4434 499.65,74.441 499.659,74.4387 499.668,74.4364 499.677,74.4341 499.686,74.4318 499.695,74.4295 499.705,74.4271 499.714,74.4248 499.723,74.4225 499.732,74.4202 499.741,74.4179 499.751,74.4156 499.76,74.4132 499.769,74.4109 499.778,74.4086 499.787,74.4063 499.797,74.404 499.806,74.4017 499.815,74.3994 499.824,74.3971 499.833,74.3947 499.843,74.3924 499.852,74.3901 499.861,74.3878 499.87,74.3855 499.879,74.3832 499.888,74.3809 499.898,74.3786 499.907,74.3762 499.916,74.3739 499.925,74.3716 499.934,74.3693 499.944,74.367 499.953,74.3647 499.962,74.3624 499.971,74.3601 499.98,74.3578 499.99,74.3555 499.999,74.3532 500.008,74.3509 500.017,74.3486 500.026,74.3462 500.035,74.3439 500.045,74.3416 500.054,74.3393 500.063,74.337 500.072,74.3347 500.081,74.3324 500.091,74.3301 500.1,74.3278 500.109,74.3255 500.118,74.3232 500.127,74.3209 500.137,74.3186 500.146,74.3163 500.155,74.314 500.164,74.3117 500.173,74.3094 500.183,74.3071 500.192,74.3048 500.201,74.3025 500.21,74.3002 500.219,74.2979 500.228,74.2956 500.238,74.2933 500.247,74.291 500.256,74.2887 500.265,74.2864 500.274,74.2841 500.284,74.2818 500.293,74.2795 500.302,74.2772 500.311,74.2749 500.32,74.2726 500.33,74.2703 500.339,74.268 500.348,74.2657 500.357,74.2634 500.366,74.2611 500.375,74.2588 500.385,74.2565 500.394,74.2542 500.403,74.2519 500.412,74.2496 500.421,74.2473 500.431,74.2451 500.44,74.2428 500.449,74.2405 500.458,74.2382 500.467,74.2359 500.477,74.2336 500.486,74.2313 500.495,74.229 500.504,74.2267 500.513,74.2244 500.523,74.2221 500.532,74.2198 500.541,74.2176 500.55,74.2153 500.559,74.213 500.568,74.2107 500.578,74.2084 500.587,74.2061 500.596,74.2038 500.605,74.2015 500.614,74.1992 500.624,74.197 500.633,74.1947 500.642,74.1924 500.651,74.1901 500.66,74.1878 500.67,74.1855 500.679,74.1832 500.688,74.181 500.697,74.1787 500.706,74.1764 500.715,74.1741 500.725,74.1718 500.734,74.1695 500.743,74.1672 500.752,74.165 500.761,74.1627 500.771,74.1604 500.78,74.1581 500.789,74.1558 500.798,74.1536 500.807,74.1513 500.817,74.149 500.826,74.1467 500.835,74.1444 500.844,74.1421 500.853,74.1399 500.863,74.1376 500.872,74.1353 500.881,74.133 500.89,74.1307 500.899,74.1285 500.908,74.1262 500.918,74.1239 500.927,74.1216 500.936,74.1194 500.945,74.1171 500.954,74.1148 500.964,74.1125 500.973,74.1103 500.982,74.108 500.991,74.1057 501,74.1034 501.01,74.1011 501.019,74.0989 501.028,74.0966 501.037,74.0943 501.046,74.0921 501.055,74.0898 501.065,74.0875 501.074,74.0852 501.083,74.083 501.092,74.0807 501.101,74.0784 501.111,74.0761 501.12,74.0739 501.129,74.0716 501.138,74.0693 501.147,74.0671 501.157,74.0648 501.166,74.0625 501.175,74.0602 501.184,74.058 501.193,74.0557 501.203,74.0534 501.212,74.0512 501.221,74.0489 501.23,74.0466 501.239,74.0444 501.248,74.0421 501.258,74.0398 501.267,74.0376 501.276,74.0353 501.285,74.033 501.294,74.0308 501.304,74.0285 501.313,74.0262 501.322,74.024 501.331,74.0217 501.34,74.0194 501.35,74.0172 501.359,74.0149 501.368,74.0126 501.377,74.0104 501.386,74.0081 501.395,74.0059 501.405,74.0036 501.414,74.0013 501.423,73.9991 501.432,73.9968 501.441,73.9945 501.451,73.9923 501.46,73.99 501.469,73.9878 501.478,73.9855 501.487,73.9832 501.497,73.981 501.506,73.9787 501.515,73.9765 501.524,73.9742 501.533,73.9719 501.543,73.9697 501.552,73.9674 501.561,73.9652 501.57,73.9629 501.579,73.9607 501.588,73.9584 501.598,73.9561 501.607,73.9539 501.616,73.9516 501.625,73.9494 501.634,73.9471 501.644,73.9449 501.653,73.9426 501.662,73.9403 501.671,73.9381 501.68,73.9358 501.69,73.9336 501.699,73.9313 501.708,73.9291 501.717,73.9268 501.726,73.9246 501.736,73.9223 501.745,73.9201 501.754,73.9178 501.763,73.9156 501.772,73.9133 501.781,73.9111 501.791,73.9088 501.8,73.9066 501.809,73.9043 501.818,73.9021 501.827,73.8998 501.837,73.8976 501.846,73.8953 501.855,73.8931 501.864,73.8908 501.873,73.8886 501.883,73.8863 501.892,73.8841 501.901,73.8818 501.91,73.8796 501.919,73.8773 501.928,73.8751 501.938,73.8728 501.947,73.8706 501.956,73.8684 501.965,73.8661 501.974,73.8639 501.984,73.8616 501.993,73.8594 502.002,73.8571 502.011,73.8549 502.02,73.8526 502.03,73.8504 502.039,73.8482 502.048,73.8459 502.057,73.8437 502.066,73.8414 502.076,73.8392 502.085,73.8369 502.094,73.8347 502.103,73.8325 502.112,73.8302 502.121,73.828 502.131,73.8257 502.14,73.8235 502.149,73.8213 502.158,73.819 502.167,73.8168 502.177,73.8145 502.186,73.8123 502.195,73.8101 502.204,73.8078 502.213,73.8056 502.223,73.8034 502.232,73.8011 502.241,73.7989 502.25,73.7966 502.259,73.7944 502.268,73.7922 502.278,73.7899 502.287,73.7877 502.296,73.7855 502.305,73.7832 502.314,73.781 502.324,73.7788 502.333,73.7765 502.342,73.7743 502.351,73.7721 502.36,73.7698 502.37,73.7676 502.379,73.7654 502.388,73.7631 502.397,73.7609 502.406,73.7587 502.416,73.7564 502.425,73.7542 502.434,73.752 502.443,73.7498 502.452,73.7475 502.461,73.7453 502.471,73.7431 502.48,73.7408 502.489,73.7386 502.498,73.7364 502.507,73.7341 502.517,73.7319 502.526,73.7297 502.535,73.7275 502.544,73.7252 502.553,73.723 502.563,73.7208 502.572,73.7186 502.581,73.7163 502.59,73.7141 502.599,73.7119 502.608,73.7097 502.618,73.7074 502.627,73.7052 502.636,73.703 502.645,73.7008 502.654,73.6985 502.664,73.6963 502.673,73.6941 502.682,73.6919 502.691,73.6896 502.7,73.6874 502.71,73.6852 502.719,73.683 502.728,73.6808 502.737,73.6785 502.746,73.6763 502.756,73.6741 502.765,73.6719 502.774,73.6697 502.783,73.6674 502.792,73.6652 502.801,73.663 502.811,73.6608 502.82,73.6586 502.829,73.6563 502.838,73.6541 502.847,73.6519 502.857,73.6497 502.866,73.6475 502.875,73.6452 502.884,73.643 502.893,73.6408 502.903,73.6386 502.912,73.6364 502.921,73.6342 502.93,73.632 502.939,73.6297 502.948,73.6275 502.958,73.6253 502.967,73.6231 502.976,73.6209 502.985,73.6187 502.994,73.6165 503.004,73.6142 503.013,73.612 503.022,73.6098 503.031,73.6076 503.04,73.6054 503.05,73.6032 503.059,73.601 503.068,73.5988 503.077,73.5965 503.086,73.5943 503.096,73.5921 503.105,73.5899 503.114,73.5877 503.123,73.5855 503.132,73.5833 503.141,73.5811 503.151,73.5789 503.16,73.5767 503.169,73.5745 503.178,73.5723 503.187,73.57 503.197,73.5678 503.206,73.5656 503.215,73.5634 503.224,73.5612 503.233,73.559 503.243,73.5568 503.252,73.5546 503.261,73.5524 503.27,73.5502 503.279,73.548 503.288,73.5458 503.298,73.5436 503.307,73.5414 503.316,73.5392 503.325,73.537 503.334,73.5348 503.344,73.5326 503.353,73.5304 503.362,73.5282 503.371,73.526 503.38,73.5238 503.39,73.5216 503.399,73.5194 503.408,73.5172 503.417,73.515 503.426,73.5128 503.436,73.5106 503.445,73.5084 503.454,73.5062 503.463,73.504 503.472,73.5018 503.481,73.4996 503.491,73.4974 503.5,73.4952 503.509,73.493 503.518,73.4908 503.527,73.4886 503.537,73.4864 503.546,73.4842 503.555,73.482 503.564,73.4798 503.573,73.4776 503.583,73.4754 503.592,73.4732 503.601,73.471 503.61,73.4688 503.619,73.4666 503.628,73.4644 503.638,73.4622 503.647,73.46 503.656,73.4579 503.665,73.4557 503.674,73.4535 503.684,73.4513 503.693,73.4491 503.702,73.4469 503.711,73.4447 503.72,73.4425 503.73,73.4403 503.739,73.4381 503.748,73.4359 503.757,73.4338 503.766,73.4316 503.776,73.4294 503.785,73.4272 503.794,73.425 503.803,73.4228 503.812,73.4206 503.821,73.4184 503.831,73.4162 503.84,73.4141 503.849,73.4119 503.858,73.4097 503.867,73.4075 503.877,73.4053 503.886,73.4031 503.895,73.4009 503.904,73.3988 503.913,73.3966 503.923,73.3944 503.932,73.3922 503.941,73.39 503.95,73.3878 503.959,73.3857 503.968,73.3835 503.978,73.3813 503.987,73.3791 503.996,73.3769 504.005,73.3747 504.014,73.3726 504.024,73.3704 504.033,73.3682 504.042,73.366 504.051,73.3638 504.06,73.3617 504.07,73.3595 504.079,73.3573 504.088,73.3551 504.097,73.3529 504.106,73.3508 504.116,73.3486 504.125,73.3464 504.134,73.3442 504.143,73.342 504.152,73.3399 504.161,73.3377 504.171,73.3355 504.18,73.3333 504.189,73.3312 504.198,73.329 504.207,73.3268 504.217,73.3246 504.226,73.3225 504.235,73.3203 504.244,73.3181 504.253,73.3159 504.263,73.3138 504.272,73.3116 504.281,73.3094 504.29,73.3072 504.299,73.3051 504.309,73.3029 504.318,73.3007 504.327,73.2985 504.336,73.2964 504.345,73.2942 504.354,73.292 504.364,73.2899 504.373,73.2877 504.382,73.2855 504.391,73.2833 504.4,73.2812 504.41,73.279 504.419,73.2768 504.428,73.2747 504.437,73.2725 504.446,73.2703 504.456,73.2682 504.465,73.266 504.474,73.2638 504.483,73.2617 504.492,73.2595 504.501,73.2573 504.511,73.2552 504.52,73.253 504.529,73.2508 504.538,73.2487 504.547,73.2465 504.557,73.2443 504.566,73.2422 504.575,73.24 504.584,73.2378 504.593,73.2357 504.603,73.2335 504.612,73.2313 504.621,73.2292 504.63,73.227 504.639,73.2249 504.649,73.2227 504.658,73.2205 504.667,73.2184 504.676,73.2162 504.685,73.214 504.694,73.2119 504.704,73.2097 504.713,73.2076 504.722,73.2054 504.731,73.2032 504.74,73.2011 504.75,73.1989 504.759,73.1968 504.768,73.1946 504.777,73.1925 504.786,73.1903 504.796,73.1881 504.805,73.186 504.814,73.1838 504.823,73.1817 504.832,73.1795 504.841,73.1774 504.851,73.1752 504.86,73.173 504.869,73.1709 504.878,73.1687 504.887,73.1666 504.897,73.1644 504.906,73.1623 504.915,73.1601 504.924,73.158 504.933,73.1558 504.943,73.1536 504.952,73.1515 504.961,73.1493 504.97,73.1472 504.979,73.145 504.989,73.1429 504.998,73.1407 505.007,73.1386 505.016,73.1364 505.025,73.1343 505.034,73.1321 505.044,73.13 505.053,73.1278 505.062,73.1257 505.071,73.1235 505.08,73.1214 505.09,73.1192 505.099,73.1171 505.108,73.1149 505.117,73.1128 505.126,73.1106 505.136,73.1085 505.145,73.1063 505.154,73.1042 505.163,73.1021 505.172,73.0999 505.181,73.0978 505.191,73.0956 505.2,73.0935 505.209,73.0913 505.218,73.0892 505.227,73.087 505.237,73.0849 505.246,73.0827 505.255,73.0806 505.264,73.0785 505.273,73.0763 505.283,73.0742 505.292,73.072 505.301,73.0699 505.31,73.0677 505.319,73.0656 505.329,73.0635 505.338,73.0613 505.347,73.0592 505.356,73.057 505.365,73.0549 505.374,73.0528 505.384,73.0506 505.393,73.0485 505.402,73.0463 505.411,73.0442 505.42,73.0421 505.43,73.0399 505.439,73.0378 505.448,73.0356 505.457,73.0335 505.466,73.0314 505.476,73.0292 505.485,73.0271 505.494,73.025 505.503,73.0228 505.512,73.0207 505.521,73.0185 505.531,73.0164 505.54,73.0143 505.549,73.0121 505.558,73.01 505.567,73.0079 505.577,73.0057 505.586,73.0036 505.595,73.0015 505.604,72.9993 505.613,72.9972 505.623,72.9951 505.632,72.9929 505.641,72.9908 505.65,72.9887 505.659,72.9865 505.669,72.9844 505.678,72.9823 505.687,72.9802 505.696,72.978 505.705,72.9759 505.714,72.9738 505.724,72.9716 505.733,72.9695 505.742,72.9674 505.751,72.9652 505.76,72.9631 505.77,72.961 505.779,72.9589 505.788,72.9567 505.797,72.9546 505.806,72.9525 505.816,72.9503 505.825,72.9482 505.834,72.9461 505.843,72.944 505.852,72.9418 505.861,72.9397 505.871,72.9376 505.88,72.9355 505.889,72.9333 505.898,72.9312 505.907,72.9291 505.917,72.927 505.926,72.9248 505.935,72.9227 505.944,72.9206 505.953,72.9185 505.963,72.9164 505.972,72.9142 505.981,72.9121 505.99,72.91 505.999,72.9079 506.009,72.9057 506.018,72.9036 506.027,72.9015 506.036,72.8994 506.045,72.8973 506.054,72.8951 506.064,72.893 506.073,72.8909 506.082,72.8888 506.091,72.8867 506.1,72.8846 506.11,72.8824 506.119,72.8803 506.128,72.8782 506.137,72.8761 506.146,72.874 506.156,72.8718 506.165,72.8697 506.174,72.8676 506.183,72.8655 506.192,72.8634 506.201,72.8613 506.211,72.8592 506.22,72.857 506.229,72.8549 506.238,72.8528 506.247,72.8507 506.257,72.8486 506.266,72.8465 506.275,72.8444 506.284,72.8422 506.293,72.8401 506.303,72.838 506.312,72.8359 506.321,72.8338 506.33,72.8317 506.339,72.8296 506.349,72.8275 506.358,72.8254 506.367,72.8232 506.376,72.8211 506.385,72.819 506.394,72.8169 506.404,72.8148 506.413,72.8127 506.422,72.8106 506.431,72.8085 506.44,72.8064 506.45,72.8043 506.459,72.8022 506.468,72.8 506.477,72.7979 506.486,72.7958 506.496,72.7937 506.505,72.7916 506.514,72.7895 506.523,72.7874 506.532,72.7853 506.542,72.7832 506.551,72.7811 506.56,72.779 506.569,72.7769 506.578,72.7748 506.587,72.7727 506.597,72.7706 506.606,72.7685 506.615,72.7664 506.624,72.7643 506.633,72.7622 506.643,72.7601 506.652,72.758 506.661,72.7559 506.67,72.7538 506.679,72.7517 506.689,72.7496 506.698,72.7475 506.707,72.7454 506.716,72.7433 506.725,72.7412 506.734,72.7391 506.744,72.737 506.753,72.7349 506.762,72.7328 506.771,72.7307 506.78,72.7286 506.79,72.7265 506.799,72.7244 506.808,72.7223 506.817,72.7202 506.826,72.7181 506.836,72.716 506.845,72.7139 506.854,72.7118 506.863,72.7097 506.872,72.7076 506.882,72.7055 506.891,72.7034 506.9,72.7013 506.909,72.6992 506.918,72.6971 506.927,72.695 506.937,72.6929 506.946,72.6908 506.955,72.6888 506.964,72.6867 506.973,72.6846 506.983,72.6825 506.992,72.6804 507.001,72.6783 507.01,72.6762 507.019,72.6741 507.029,72.672 507.038,72.6699 507.047,72.6678 507.056,72.6658 507.065,72.6637 507.074,72.6616 507.084,72.6595 507.093,72.6574 507.102,72.6553 507.111,72.6532 507.12,72.6511 507.13,72.649 507.139,72.647 507.148,72.6449 507.157,72.6428 507.166,72.6407 507.176,72.6386 507.185,72.6365 507.194,72.6344 507.203,72.6324 507.212,72.6303 507.222,72.6282 507.231,72.6261 507.24,72.624 507.249,72.6219 507.258,72.6198 507.267,72.6178 507.277,72.6157 507.286,72.6136 507.295,72.6115 507.304,72.6094 507.313,72.6074 507.323,72.6053 507.332,72.6032 507.341,72.6011 507.35,72.599 507.359,72.5969 507.369,72.5949 507.378,72.5928 507.387,72.5907 507.396,72.5886 507.405,72.5865 507.414,72.5845 507.424,72.5824 507.433,72.5803 507.442,72.5782 507.451,72.5762 507.46,72.5741 507.47,72.572 507.479,72.5699 507.488,72.5678 507.497,72.5658 507.506,72.5637 507.516,72.5616 507.525,72.5595 507.534,72.5575 507.543,72.5554 507.552,72.5533 507.562,72.5512 507.571,72.5492 507.58,72.5471 507.589,72.545 507.598,72.5429 507.607,72.5409 507.617,72.5388 507.626,72.5367 507.635,72.5347 507.644,72.5326 507.653,72.5305 507.663,72.5284 507.672,72.5264 507.681,72.5243 507.69,72.5222 507.699,72.5202 507.709,72.5181 507.718,72.516 507.727,72.5139 507.736,72.5119 507.745,72.5098 507.754,72.5077 507.764,72.5057 507.773,72.5036 507.782,72.5015 507.791,72.4995 507.8,72.4974 507.81,72.4953 507.819,72.4933 507.828,72.4912 507.837,72.4891 507.846,72.4871 507.856,72.485 507.865,72.4829 507.874,72.4809 507.883,72.4788 507.892,72.4767 507.902,72.4747 507.911,72.4726 507.92,72.4705 507.929,72.4685 507.938,72.4664 507.947,72.4644 507.957,72.4623 507.966,72.4602 507.975,72.4582 507.984,72.4561 507.993,72.454 508.003,72.452 508.012,72.4499 508.021,72.4479 508.03,72.4458 508.039,72.4437 508.049,72.4417 508.058,72.4396 508.067,72.4376 508.076,72.4355 508.085,72.4334 508.094,72.4314 508.104,72.4293 508.113,72.4273 508.122,72.4252 508.131,72.4232 508.14,72.4211 508.15,72.419 508.159,72.417 508.168,72.4149 508.177,72.4129 508.186,72.4108 508.196,72.4088 508.205,72.4067 508.214,72.4046 508.223,72.4026 508.232,72.4005 508.242,72.3985 508.251,72.3964 508.26,72.3944 508.269,72.3923 508.278,72.3903 508.287,72.3882 508.297,72.3862 508.306,72.3841 508.315,72.3821 508.324,72.38 508.333,72.3779 508.343,72.3759 508.352,72.3738 508.361,72.3718 508.37,72.3697 508.379,72.3677 508.389,72.3656 508.398,72.3636 508.407,72.3615 508.416,72.3595 508.425,72.3574 508.434,72.3554 508.444,72.3534 508.453,72.3513 508.462,72.3493 508.471,72.3472 508.48,72.3452 508.49,72.3431 508.499,72.3411 508.508,72.339 508.517,72.337 508.526,72.3349 508.536,72.3329 508.545,72.3308 508.554,72.3288 508.563,72.3267 508.572,72.3247 508.582,72.3227 508.591,72.3206 508.6,72.3186 508.609,72.3165 508.618,72.3145 508.627,72.3124 508.637,72.3104 508.646,72.3084 508.655,72.3063 508.664,72.3043 508.673,72.3022 508.683,72.3002 508.692,72.2981 508.701,72.2961 508.71,72.2941 508.719,72.292 508.729,72.29 508.738,72.2879 508.747,72.2859 508.756,72.2839 508.765,72.2818 508.774,72.2798 508.784,72.2777 508.793,72.2757 508.802,72.2737 508.811,72.2716 508.82,72.2696 508.83,72.2676 508.839,72.2655 508.848,72.2635 508.857,72.2614 508.866,72.2594 508.876,72.2574 508.885,72.2553 508.894,72.2533 508.903,72.2513 508.912,72.2492 508.922,72.2472 508.931,72.2452 508.94,72.2431 508.949,72.2411 508.958,72.2391 508.967,72.237 508.977,72.235 508.986,72.233 508.995,72.2309 509.004,72.2289 509.013,72.2269 509.023,72.2248 509.032,72.2228 509.041,72.2208 509.05,72.2187 509.059,72.2167 509.069,72.2147 509.078,72.2127 509.087,72.2106 509.096,72.2086 509.105,72.2066 509.115,72.2045 509.124,72.2025 509.133,72.2005 509.142,72.1985 509.151,72.1964 509.16,72.1944 509.17,72.1924 509.179,72.1903 509.188,72.1883 509.197,72.1863 509.206,72.1843 509.216,72.1822 509.225,72.1802 509.234,72.1782 509.243,72.1762 509.252,72.1741 509.262,72.1721 509.271,72.1701 509.28,72.1681 509.289,72.166 509.298,72.164 509.307,72.162 509.317,72.16 509.326,72.158 509.335,72.1559 509.344,72.1539 509.353,72.1519 509.363,72.1499 509.372,72.1478 509.381,72.1458 509.39,72.1438 509.399,72.1418 509.409,72.1398 509.418,72.1377 509.427,72.1357 509.436,72.1337 509.445,72.1317 509.455,72.1297 509.464,72.1277 509.473,72.1256 509.482,72.1236 509.491,72.1216 509.5,72.1196 509.51,72.1176 509.519,72.1155 509.528,72.1135 509.537,72.1115 509.546,72.1095 509.556,72.1075 509.565,72.1055 509.574,72.1034 509.583,72.1014 509.592,72.0994 509.602,72.0974 509.611,72.0954 509.62,72.0934 509.629,72.0914 509.638,72.0894 509.647,72.0873 509.657,72.0853 509.666,72.0833 509.675,72.0813 509.684,72.0793 509.693,72.0773 509.703,72.0753 509.712,72.0733 509.721,72.0712 509.73,72.0692 509.739,72.0672 509.749,72.0652 509.758,72.0632 509.767,72.0612 509.776,72.0592 509.785,72.0572 509.795,72.0552 509.804,72.0532 509.813,72.0511 509.822,72.0491 509.831,72.0471 509.84,72.0451 509.85,72.0431 509.859,72.0411 509.868,72.0391 509.877,72.0371 509.886,72.0351 509.896,72.0331 509.905,72.0311 509.914,72.0291 509.923,72.0271 509.932,72.0251 509.942,72.0231 509.951,72.0211 509.96,72.0191 509.969,72.017 509.978,72.015 509.987,72.013 509.997,72.011 510.006,72.009 510.015,72.007 510.024,72.005 510.033,72.003 510.043,72.001 510.052,71.999 510.061,71.997 510.07,71.995 510.079,71.993 510.089,71.991 510.098,71.989 510.107,71.987 510.116,71.985 510.125,71.983 510.135,71.981 510.144,71.979 510.153,71.977 510.162,71.975 510.171,71.973 510.18,71.971 510.19,71.969 510.199,71.967 510.208,71.965 510.217,71.963 510.226,71.961 510.236,71.9591 510.245,71.9571 510.254,71.9551 510.263,71.9531 510.272,71.9511 510.282,71.9491 510.291,71.9471 510.3,71.9451 510.309,71.9431 510.318,71.9411 510.327,71.9391 510.337,71.9371 510.346,71.9351 510.355,71.9331 510.364,71.9311 510.373,71.9291 510.383,71.9272 510.392,71.9252 510.401,71.9232 510.41,71.9212 510.419,71.9192 510.429,71.9172 510.438,71.9152 510.447,71.9132 510.456,71.9112 510.465,71.9092 510.475,71.9073 510.484,71.9053 510.493,71.9033 510.502,71.9013 510.511,71.8993 510.52,71.8973 510.53,71.8953 510.539,71.8933 510.548,71.8913 510.557,71.8894 510.566,71.8874 510.576,71.8854 510.585,71.8834 510.594,71.8814 510.603,71.8794 510.612,71.8774 510.622,71.8755 510.631,71.8735 510.64,71.8715 510.649,71.8695 510.658,71.8675 510.667,71.8655 510.677,71.8636 510.686,71.8616 510.695,71.8596 510.704,71.8576 510.713,71.8556 510.723,71.8536 510.732,71.8517 510.741,71.8497 510.75,71.8477 510.759,71.8457 510.769,71.8437 510.778,71.8418 510.787,71.8398 510.796,71.8378 510.805,71.8358 510.815,71.8338 510.824,71.8319 510.833,71.8299 510.842,71.8279 510.851,71.8259 510.86,71.824 510.87,71.822 510.879,71.82 510.888,71.818 510.897,71.816 510.906,71.8141 510.916,71.8121 510.925,71.8101 510.934,71.8081 510.943,71.8062 510.952,71.8042 510.962,71.8022 510.971,71.8002 510.98,71.7983 510.989,71.7963 510.998,71.7943 511.007,71.7923 511.017,71.7904 511.026,71.7884 511.035,71.7864 511.044,71.7844 511.053,71.7825 511.063,71.7805 511.072,71.7785 511.081,71.7766 511.09,71.7746 511.099,71.7726 511.109,71.7706 511.118,71.7687 511.127,71.7667 511.136,71.7647 511.145,71.7628 511.155,71.7608 511.164,71.7588 511.173,71.7569 511.182,71.7549 511.191,71.7529 511.2,71.751 511.21,71.749 511.219,71.747 511.228,71.7451 511.237,71.7431 511.246,71.7411 511.256,71.7392 511.265,71.7372 511.274,71.7352 511.283,71.7333 511.292,71.7313 511.302,71.7293 511.311,71.7274 511.32,71.7254 511.329,71.7234 511.338,71.7215 511.347,71.7195 511.357,71.7175 511.366,71.7156 511.375,71.7136 511.384,71.7117 511.393,71.7097 511.403,71.7077 511.412,71.7058 511.421,71.7038 511.43,71.7018 511.439,71.6999 511.449,71.6979 511.458,71.696 511.467,71.694 511.476,71.692 511.485,71.6901 511.495,71.6881 511.504,71.6862 511.513,71.6842 511.522,71.6822 511.531,71.6803 511.54,71.6783 511.55,71.6764 511.559,71.6744 511.568,71.6725 511.577,71.6705 511.586,71.6685 511.596,71.6666 511.605,71.6646 511.614,71.6627 511.623,71.6607 511.632,71.6588 511.642,71.6568 511.651,71.6548 511.66,71.6529 511.669,71.6509 511.678,71.649 511.688,71.647 511.697,71.6451 511.706,71.6431 511.715,71.6412 511.724,71.6392 511.733,71.6373 511.743,71.6353 511.752,71.6334 511.761,71.6314 511.77,71.6295 511.779,71.6275 511.789,71.6255 511.798,71.6236 511.807,71.6216 511.816,71.6197 511.825,71.6177 511.835,71.6158 511.844,71.6138 511.853,71.6119 511.862,71.6099 511.871,71.608 511.88,71.6061 511.89,71.6041 511.899,71.6022 511.908,71.6002 511.917,71.5983 511.926,71.5963 511.936,71.5944 511.945,71.5924 511.954,71.5905 511.963,71.5885 511.972,71.5866 511.982,71.5846 511.991,71.5827 512,71.5807 512.009,71.5788 512.018,71.5769 512.028,71.5749 512.037,71.573 512.046,71.571 512.055,71.5691 512.064,71.5671 512.073,71.5652 512.083,71.5633 512.092,71.5613 512.101,71.5594 512.11,71.5574 512.119,71.5555 512.129,71.5535 512.138,71.5516 512.147,71.5497 512.156,71.5477 512.165,71.5458 512.175,71.5438 512.184,71.5419 512.193,71.54 512.202,71.538 512.211,71.5361 512.22,71.5341 512.23,71.5322 512.239,71.5303 512.248,71.5283 512.257,71.5264 512.266,71.5245 512.276,71.5225 512.285,71.5206 512.294,71.5186 512.303,71.5167 512.312,71.5148 512.322,71.5128 512.331,71.5109 512.34,71.509 512.349,71.507 512.358,71.5051 512.368,71.5032 512.377,71.5012 512.386,71.4993 512.395,71.4974 512.404,71.4954 512.413,71.4935 512.423,71.4916 512.432,71.4896 512.441,71.4877 512.45,71.4858 512.459,71.4838 512.469,71.4819 512.478,71.48 512.487,71.478 512.496,71.4761 512.505,71.4742 512.515,71.4722 512.524,71.4703 512.533,71.4684 512.542,71.4664 512.551,71.4645 512.56,71.4626 512.57,71.4607 512.579,71.4587 512.588,71.4568 512.597,71.4549 512.606,71.4529 512.616,71.451 512.625,71.4491 512.634,71.4472 512.643,71.4452 512.652,71.4433 512.662,71.4414 512.671,71.4395 512.68,71.4375 512.689,71.4356 512.698,71.4337 512.708,71.4318 512.717,71.4298 512.726,71.4279 512.735,71.426 512.744,71.4241 512.753,71.4221 512.763,71.4202 512.772,71.4183 512.781,71.4164 512.79,71.4144 512.799,71.4125 512.809,71.4106 512.818,71.4087 512.827,71.4068 512.836,71.4048 512.845,71.4029 512.855,71.401 512.864,71.3991 512.873,71.3972 512.882,71.3952 512.891,71.3933 512.9,71.3914 512.91,71.3895 512.919,71.3876 512.928,71.3856 512.937,71.3837 512.946,71.3818 512.956,71.3799 512.965,71.378 512.974,71.3761 512.983,71.3741 512.992,71.3722 513.002,71.3703 513.011,71.3684 513.02,71.3665 513.029,71.3646 513.038,71.3626 513.048,71.3607 513.057,71.3588 513.066,71.3569 513.075,71.355 513.084,71.3531 513.093,71.3512 513.103,71.3492 513.112,71.3473 513.121,71.3454 513.13,71.3435 513.139,71.3416 513.149,71.3397 513.158,71.3378 513.167,71.3358 513.176,71.3339 513.185,71.332 513.195,71.3301 513.204,71.3282 513.213,71.3263 513.222,71.3244 513.231,71.3225 513.24,71.3206 513.25,71.3187 513.259,71.3167 513.268,71.3148 513.277,71.3129 513.286,71.311 513.296,71.3091 513.305,71.3072 513.314,71.3053 513.323,71.3034 513.332,71.3015 513.342,71.2996 513.351,71.2977 513.36,71.2958 513.369,71.2939 513.378,71.2919 513.388,71.29 513.397,71.2881 513.406,71.2862 513.415,71.2843 513.424,71.2824 513.433,71.2805 513.443,71.2786 513.452,71.2767 513.461,71.2748 513.47,71.2729 513.479,71.271 513.489,71.2691 513.498,71.2672 513.507,71.2653 513.516,71.2634 513.525,71.2615 513.535,71.2596 513.544,71.2577 513.553,71.2558 513.562,71.2539 513.571,71.252 513.58,71.2501 513.59,71.2482 513.599,71.2463 513.608,71.2444 513.617,71.2425 513.626,71.2406 513.636,71.2387 513.645,71.2368 513.654,71.2349 513.663,71.233 513.672,71.2311 513.682,71.2292 513.691,71.2273 513.7,71.2254 513.709,71.2235 513.718,71.2216 513.728,71.2197 513.737,71.2178 513.746,71.2159 513.755,71.214 513.764,71.2121 513.773,71.2102 513.783,71.2083 513.792,71.2065 513.801,71.2046 513.81,71.2027 513.819,71.2008 513.829,71.1989 513.838,71.197 513.847,71.1951 513.856,71.1932 513.865,71.1913 513.875,71.1894 513.884,71.1875 513.893,71.1856 513.902,71.1837 513.911,71.1819 513.921,71.18 513.93,71.1781 513.939,71.1762 513.948,71.1743 513.957,71.1724 513.966,71.1705 513.976,71.1686 513.985,71.1667 513.994,71.1648 514.003,71.163 514.012,71.1611 514.022,71.1592 514.031,71.1573 514.04,71.1554 514.049,71.1535 514.058,71.1516 514.068,71.1497 514.077,71.1479 514.086,71.146 514.095,71.1441 514.104,71.1422 514.113,71.1403 514.123,71.1384 514.132,71.1366 514.141,71.1347 514.15,71.1328 514.159,71.1309 514.169,71.129 514.178,71.1271 514.187,71.1252 514.196,71.1234 514.205,71.1215 514.215,71.1196 514.224,71.1177 514.233,71.1158 514.242,71.114 514.251,71.1121 514.261,71.1102 514.27,71.1083 514.279,71.1064 514.288,71.1046 514.297,71.1027 514.306,71.1008 514.316,71.0989 514.325,71.097 514.334,71.0952 514.343,71.0933 514.352,71.0914 514.362,71.0895 514.371,71.0876 514.38,71.0858 514.389,71.0839 514.398,71.082 514.408,71.0801 514.417,71.0783 514.426,71.0764 514.435,71.0745 514.444,71.0726 514.453,71.0708 514.463,71.0689 514.472,71.067 514.481,71.0651 514.49,71.0633 514.499,71.0614 514.509,71.0595 514.518,71.0576 514.527,71.0558 514.536,71.0539 514.545,71.052 514.555,71.0501 514.564,71.0483 514.573,71.0464 514.582,71.0445 514.591,71.0426 514.601,71.0408 514.61,71.0389 514.619,71.037 514.628,71.0352 514.637,71.0333 514.646,71.0314 514.656,71.0296 514.665,71.0277 514.674,71.0258 514.683,71.0239 514.692,71.0221 514.702,71.0202 514.711,71.0183 514.72,71.0165 514.729,71.0146 514.738,71.0127 514.748,71.0109 514.757,71.009 514.766,71.0071 514.775,71.0053 514.784,71.0034 514.793,71.0015 514.803,70.9997 514.812,70.9978 514.821,70.9959 514.83,70.9941 514.839,70.9922 514.849,70.9903 514.858,70.9885 514.867,70.9866 514.876,70.9848 514.885,70.9829 514.895,70.981 514.904,70.9792 514.913,70.9773 514.922,70.9754 514.931,70.9736 514.941,70.9717 514.95,70.9699 514.959,70.968 514.968,70.9661 514.977,70.9643 514.986,70.9624 514.996,70.9605 515.005,70.9587 515.014,70.9568 515.023,70.955 515.032,70.9531 515.042,70.9513 515.051,70.9494 515.06,70.9475 515.069,70.9457 515.078,70.9438 515.088,70.942 515.097,70.9401 515.106,70.9382 515.115,70.9364 515.124,70.9345 515.133,70.9327 515.143,70.9308 515.152,70.929 515.161,70.9271 515.17,70.9253 515.179,70.9234 515.189,70.9215 515.198,70.9197 515.207,70.9178 515.216,70.916 515.225,70.9141 515.235,70.9123 515.244,70.9104 515.253,70.9086 515.262,70.9067 515.271,70.9049 515.281,70.903 515.29,70.9012 515.299,70.8993 515.308,70.8974 515.317,70.8956 515.326,70.8937 515.336,70.8919 515.345,70.89 515.354,70.8882 515.363,70.8863 515.372,70.8845 515.382,70.8826 515.391,70.8808 515.4,70.8789 515.409,70.8771 515.418,70.8752 515.428,70.8734 515.437,70.8716 515.446,70.8697 515.455,70.8679 515.464,70.866 515.473,70.8642 515.483,70.8623 515.492,70.8605 515.501,70.8586 515.51,70.8568 515.519,70.8549 515.529,70.8531 515.538,70.8512 515.547,70.8494 515.556,70.8476 515.565,70.8457 515.575,70.8439 515.584,70.842 515.593,70.8402 515.602,70.8383 515.611,70.8365 515.621,70.8346 515.63,70.8328 515.639,70.831 515.648,70.8291 515.657,70.8273 515.666,70.8254 515.676,70.8236 515.685,70.8218 515.694,70.8199 515.703,70.8181 515.712,70.8162 515.722,70.8144 515.731,70.8125 515.74,70.8107 515.749,70.8089 515.758,70.807 515.768,70.8052 515.777,70.8034 515.786,70.8015 515.795,70.7997 515.804,70.7978 515.813,70.796 515.823,70.7942 515.832,70.7923 515.841,70.7905 515.85,70.7887 515.859,70.7868 515.869,70.785 515.878,70.7831 515.887,70.7813 515.896,70.7795 515.905,70.7776 515.915,70.7758 515.924,70.774 515.933,70.7721 515.942,70.7703 515.951,70.7685 515.961,70.7666 515.97,70.7648 515.979,70.763 515.988,70.7611 515.997,70.7593 516.006,70.7575 516.016,70.7556 516.025,70.7538 516.034,70.752 516.043,70.7501 516.052,70.7483 516.062,70.7465 516.071,70.7447 516.08,70.7428 516.089,70.741 516.098,70.7392 516.108,70.7373 516.117,70.7355 516.126,70.7337 516.135,70.7318 516.144,70.73 516.153,70.7282 516.163,70.7264 516.172,70.7245 516.181,70.7227 516.19,70.7209 516.199,70.7191 516.209,70.7172 516.218,70.7154 516.227,70.7136 516.236,70.7117 516.245,70.7099 516.255,70.7081 516.264,70.7063 516.273,70.7044 516.282,70.7026 516.291,70.7008 516.301,70.699 516.31,70.6971 516.319,70.6953 516.328,70.6935 516.337,70.6917 516.346,70.6899 516.356,70.688 516.365,70.6862 516.374,70.6844 516.383,70.6826 516.392,70.6807 516.402,70.6789 516.411,70.6771 516.42,70.6753 516.429,70.6735 516.438,70.6716 516.448,70.6698 516.457,70.668 516.466,70.6662 516.475,70.6644 516.484,70.6625 516.494,70.6607 516.503,70.6589 516.512,70.6571 516.521,70.6553 516.53,70.6535 516.539,70.6516 516.549,70.6498 516.558,70.648 516.567,70.6462 516.576,70.6444 516.585,70.6426 516.595,70.6407 516.604,70.6389 516.613,70.6371 516.622,70.6353 516.631,70.6335 516.641,70.6317 516.65,70.6298 516.659,70.628 516.668,70.6262 516.677,70.6244 516.686,70.6226 516.696,70.6208 516.705,70.619 516.714,70.6172 516.723,70.6153 516.732,70.6135 516.742,70.6117 516.751,70.6099 516.76,70.6081 516.769,70.6063 516.778,70.6045 516.788,70.6027 516.797,70.6008 516.806,70.599 516.815,70.5972 516.824,70.5954 516.834,70.5936 516.843,70.5918 516.852,70.59 516.861,70.5882 516.87,70.5864 516.879,70.5846 516.889,70.5828 516.898,70.581 516.907,70.5791 516.916,70.5773 516.925,70.5755 516.935,70.5737 516.944,70.5719 516.953,70.5701 516.962,70.5683 516.971,70.5665 516.981,70.5647 516.99,70.5629 516.999,70.5611 517.008,70.5593 517.017,70.5575 517.026,70.5557 517.036,70.5539 517.045,70.5521 517.054,70.5503 517.063,70.5485 517.072,70.5467 517.082,70.5449 517.091,70.543 517.1,70.5412 517.109,70.5394 517.118,70.5376 517.128,70.5358 517.137,70.534 517.146,70.5322 517.155,70.5304 517.164,70.5286 517.174,70.5268 517.183,70.525 517.192,70.5232 517.201,70.5214 517.21,70.5196 517.219,70.5178 517.229,70.516 517.238,70.5142 517.247,70.5124 517.256,70.5106 517.265,70.5089 517.275,70.5071 517.284,70.5053 517.293,70.5035 517.302,70.5017 517.311,70.4999 517.321,70.4981 517.33,70.4963 517.339,70.4945 517.348,70.4927 517.357,70.4909 517.366,70.4891 517.376,70.4873 517.385,70.4855 517.394,70.4837 517.403,70.4819 517.412,70.4801 517.422,70.4783 517.431,70.4765 517.44,70.4747 517.449,70.473 517.458,70.4712 517.468,70.4694 517.477,70.4676 517.486,70.4658 517.495,70.464 517.504,70.4622 517.514,70.4604 517.523,70.4586 517.532,70.4568 517.541,70.455 517.55,70.4533 517.559,70.4515 517.569,70.4497 517.578,70.4479 517.587,70.4461 517.596,70.4443 517.605,70.4425 517.615,70.4407 517.624,70.4389 517.633,70.4372 517.642,70.4354 517.651,70.4336 517.661,70.4318 517.67,70.43 517.679,70.4282 517.688,70.4264 517.697,70.4247 517.706,70.4229 517.716,70.4211 517.725,70.4193 517.734,70.4175 517.743,70.4157 517.752,70.4139 517.762,70.4122 517.771,70.4104 517.78,70.4086 517.789,70.4068 517.798,70.405 517.808,70.4032 517.817,70.4015 517.826,70.3997 517.835,70.3979 517.844,70.3961 517.854,70.3943 517.863,70.3926 517.872,70.3908 517.881,70.389 517.89,70.3872 517.899,70.3854 517.909,70.3837 517.918,70.3819 517.927,70.3801 517.936,70.3783 517.945,70.3765 517.955,70.3748 517.964,70.373 517.973,70.3712 517.982,70.3694 517.991,70.3676 518.001,70.3659 518.01,70.3641 518.019,70.3623 518.028,70.3605 518.037,70.3588 518.046,70.357 518.056,70.3552 518.065,70.3534 518.074,70.3517 518.083,70.3499 518.092,70.3481 518.102,70.3463 518.111,70.3446 518.12,70.3428 518.129,70.341 518.138,70.3392 518.148,70.3375 518.157,70.3357 518.166,70.3339 518.175,70.3321 518.184,70.3304 518.194,70.3286 518.203,70.3268 518.212,70.3251 518.221,70.3233 518.23,70.3215 518.239,70.3197 518.249,70.318 518.258,70.3162 518.267,70.3144 518.276,70.3127 518.285,70.3109 518.295,70.3091 518.304,70.3074 518.313,70.3056 518.322,70.3038 518.331,70.302 518.341,70.3003 518.35,70.2985 518.359,70.2967 518.368,70.295 518.377,70.2932 518.386,70.2914 518.396,70.2897 518.405,70.2879 518.414,70.2861 518.423,70.2844 518.432,70.2826 518.442,70.2808 518.451,70.2791 518.46,70.2773 518.469,70.2755 518.478,70.2738 518.488,70.272 518.497,70.2703 518.506,70.2685 518.515,70.2667 518.524,70.265 518.534,70.2632 518.543,70.2614 518.552,70.2597 518.561,70.2579 518.57,70.2562 518.579,70.2544 518.589,70.2526 518.598,70.2509 518.607,70.2491 518.616,70.2473 518.625,70.2456 518.635,70.2438 518.644,70.2421 518.653,70.2403 518.662,70.2385 518.671,70.2368 518.681,70.235 518.69,70.2333 518.699,70.2315 518.708,70.2298 518.717,70.228 518.726,70.2262 518.736,70.2245 518.745,70.2227 518.754,70.221 518.763,70.2192 518.772,70.2175 518.782,70.2157 518.791,70.2139 518.8,70.2122 518.809,70.2104 518.818,70.2087 518.828,70.2069 518.837,70.2052 518.846,70.2034 518.855,70.2017 518.864,70.1999 518.874,70.1982 518.883,70.1964 518.892,70.1946 518.901,70.1929 518.91,70.1911 518.919,70.1894 518.929,70.1876 518.938,70.1859 518.947,70.1841 518.956,70.1824 518.965,70.1806 518.975,70.1789 518.984,70.1771 518.993,70.1754 519.002,70.1736 519.011,70.1719 519.021,70.1701 519.03,70.1684 519.039,70.1666 519.048,70.1649 519.057,70.1631 519.067,70.1614 519.076,70.1596 519.085,70.1579 519.094,70.1561 519.103,70.1544 519.112,70.1526 519.122,70.1509 519.131,70.1491 519.14,70.1474 519.149,70.1457 519.158,70.1439 519.168,70.1422 519.177,70.1404 519.186,70.1387 519.195,70.1369 519.204,70.1352 519.214,70.1334 519.223,70.1317 519.232,70.13 519.241,70.1282 519.25,70.1265 519.259,70.1247 519.269,70.123 519.278,70.1212 519.287,70.1195 519.296,70.1177 519.305,70.116 519.315,70.1143 519.324,70.1125 519.333,70.1108 519.342,70.109 519.351,70.1073 519.361,70.1056 519.37,70.1038 519.379,70.1021 519.388,70.1003 519.397,70.0986 519.407,70.0969 519.416,70.0951 519.425,70.0934 519.434,70.0916 519.443,70.0899 519.452,70.0882 519.462,70.0864 519.471,70.0847 519.48,70.083 519.489,70.0812 519.498,70.0795 519.508,70.0777 519.517,70.076 519.526,70.0743 519.535,70.0725 519.544,70.0708 519.554,70.0691 519.563,70.0673 519.572,70.0656 519.581,70.0639 519.59,70.0621 519.599,70.0604 519.609,70.0587 519.618,70.0569 519.627,70.0552 519.636,70.0535 519.645,70.0517 519.655,70.05 519.664,70.0483 519.673,70.0465 519.682,70.0448 519.691,70.0431 519.701,70.0413 519.71,70.0396 519.719,70.0379 519.728,70.0361 519.737,70.0344 519.747,70.0327 519.756,70.031 519.765,70.0292 519.774,70.0275 519.783,70.0258 519.792,70.024 519.802,70.0223 519.811,70.0206 519.82,70.0189 519.829,70.0171 519.838,70.0154 519.848,70.0137 519.857,70.0119 519.866,70.0102 519.875,70.0085 519.884,70.0068 519.894,70.005 519.903,70.0033 519.912,70.0016 519.921,69.9999 519.93,69.9981 519.939,69.9964 519.949,69.9947 519.958,69.993 519.967,69.9912 519.976,69.9895 519.985,69.9878 519.995,69.9861 520.004,69.9843 520.013,69.9826 520.022,69.9809 520.031,69.9792 520.041,69.9775 520.05,69.9757 520.059,69.974 520.068,69.9723 520.077,69.9706 520.087,69.9688 520.096,69.9671 520.105,69.9654 520.114,69.9637 520.123,69.962 520.132,69.9602 520.142,69.9585 520.151,69.9568 520.16,69.9551 520.169,69.9534 520.178,69.9516 520.188,69.9499 520.197,69.9482 520.206,69.9465 520.215,69.9448 520.224,69.9431 520.234,69.9413 520.243,69.9396 520.252,69.9379 520.261,69.9362 520.27,69.9345 520.279,69.9328 520.289,69.931 520.298,69.9293 520.307,69.9276 520.316,69.9259 520.325,69.9242 520.335,69.9225 520.344,69.9208 520.353,69.919 520.362,69.9173 520.371,69.9156 520.381,69.9139 520.39,69.9122 520.399,69.9105 520.408,69.9088 520.417,69.9071 520.427,69.9053 520.436,69.9036 520.445,69.9019 520.454,69.9002 520.463,69.8985 520.472,69.8968 520.482,69.8951 520.491,69.8934 520.5,69.8917 520.509,69.8899 520.518,69.8882 520.528,69.8865 520.537,69.8848 520.546,69.8831 520.555,69.8814 520.564,69.8797 520.574,69.878 520.583,69.8763 520.592,69.8746 520.601,69.8729 520.61,69.8712 520.619,69.8694 520.629,69.8677 520.638,69.866 520.647,69.8643 520.656,69.8626 520.665,69.8609 520.675,69.8592 520.684,69.8575 520.693,69.8558 520.702,69.8541 520.711,69.8524 520.721,69.8507 520.73,69.849 520.739,69.8473 520.748,69.8456 520.757,69.8439 520.767,69.8422 520.776,69.8405 520.785,69.8388 520.794,69.8371 520.803,69.8354 520.812,69.8337 520.822,69.832 520.831,69.8303 520.84,69.8286 520.849,69.8269 520.858,69.8252 520.868,69.8235 520.877,69.8218 520.886,69.8201 520.895,69.8184 520.904,69.8167 520.914,69.815 520.923,69.8133 520.932,69.8116 520.941,69.8099 520.95,69.8082 520.959,69.8065 520.969,69.8048 520.978,69.8031 520.987,69.8014 520.996,69.7997 521.005,69.798 521.015,69.7963 521.024,69.7946 521.033,69.7929 521.042,69.7912 521.051,69.7895 521.061,69.7878 521.07,69.7861 521.079,69.7844 521.088,69.7827 521.097,69.781 521.107,69.7793 521.116,69.7777 521.125,69.776 521.134,69.7743 521.143,69.7726 521.152,69.7709 521.162,69.7692 521.171,69.7675 521.18,69.7658 521.189,69.7641 521.198,69.7624 521.208,69.7607 521.217,69.759 521.226,69.7574 521.235,69.7557 521.244,69.754 521.254,69.7523 521.263,69.7506 521.272,69.7489 521.281,69.7472 521.29,69.7455 521.3,69.7438 521.309,69.7421 521.318,69.7405 521.327,69.7388 521.336,69.7371 521.345,69.7354 521.355,69.7337 521.364,69.732 521.373,69.7303 521.382,69.7286 521.391,69.727 521.401,69.7253 521.41,69.7236 521.419,69.7219 521.428,69.7202 521.437,69.7185 521.447,69.7169 521.456,69.7152 521.465,69.7135 521.474,69.7118 521.483,69.7101 521.492,69.7084 521.502,69.7067 521.511,69.7051 521.52,69.7034 521.529,69.7017 521.538,69.7 521.548,69.6983 521.557,69.6967 521.566,69.695 521.575,69.6933 521.584,69.6916 521.594,69.6899 521.603,69.6883 521.612,69.6866 521.621,69.6849 521.63,69.6832 521.64,69.6815 521.649,69.6799 521.658,69.6782 521.667,69.6765 521.676,69.6748 521.685,69.6731 521.695,69.6715 521.704,69.6698 521.713,69.6681 521.722,69.6664 521.731,69.6648 521.741,69.6631 521.75,69.6614 521.759,69.6597 521.768,69.658 521.777,69.6564 521.787,69.6547 521.796,69.653 521.805,69.6513 521.814,69.6497 521.823,69.648 521.832,69.6463 521.842,69.6446 521.851,69.643 521.86,69.6413 521.869,69.6396 521.878,69.638 521.888,69.6363 521.897,69.6346 521.906,69.6329 521.915,69.6313 521.924,69.6296 521.934,69.6279 521.943,69.6262 521.952,69.6246 521.961,69.6229 521.97,69.6212 521.98,69.6196 521.989,69.6179 521.998,69.6162 522.007,69.6146 522.016,69.6129 522.025,69.6112 522.035,69.6095 522.044,69.6079 522.053,69.6062 522.062,69.6045 522.071,69.6029 522.081,69.6012 522.09,69.5995 522.099,69.5979 522.108,69.5962 522.117,69.5945 522.127,69.5929 522.136,69.5912 522.145,69.5895 522.154,69.5879 522.163,69.5862 522.172,69.5845 522.182,69.5829 522.191,69.5812 522.2,69.5795 522.209,69.5779 522.218,69.5762 522.228,69.5746 522.237,69.5729 522.246,69.5712 522.255,69.5696 522.264,69.5679 522.274,69.5662 522.283,69.5646 522.292,69.5629 522.301,69.5612 522.31,69.5596 522.32,69.5579 522.329,69.5563 522.338,69.5546 522.347,69.5529 522.356,69.5513 522.365,69.5496 522.375,69.548 522.384,69.5463 522.393,69.5446 522.402,69.543 522.411,69.5413 522.421,69.5397 522.43,69.538 522.439,69.5363 522.448,69.5347 522.457,69.533 522.467,69.5314 522.476,69.5297 522.485,69.5281 522.494,69.5264 522.503,69.5247 522.512,69.5231 522.522,69.5214 522.531,69.5198 522.54,69.5181 522.549,69.5165 522.558,69.5148 522.568,69.5132 522.577,69.5115 522.586,69.5098 522.595,69.5082 522.604,69.5065 522.614,69.5049 522.623,69.5032 522.632,69.5016 522.641,69.4999 522.65,69.4983 522.66,69.4966 522.669,69.495 522.678,69.4933 522.687,69.4917 522.696,69.49 522.705,69.4884 522.715,69.4867 522.724,69.4851 522.733,69.4834 522.742,69.4818 522.751,69.4801 522.761,69.4785 522.77,69.4768 522.779,69.4752 522.788,69.4735 522.797,69.4719 522.807,69.4702 522.816,69.4686 522.825,69.4669 522.834,69.4653 522.843,69.4636 522.852,69.462 522.862,69.4603 522.871,69.4587 522.88,69.457 522.889,69.4554 522.898,69.4537 522.908,69.4521 522.917,69.4504 522.926,69.4488 522.935,69.4472 522.944,69.4455 522.954,69.4439 522.963,69.4422 522.972,69.4406 522.981,69.4389 522.99,69.4373 523,69.4356 523.009,69.434 523.018,69.4324 523.027,69.4307 523.036,69.4291 523.045,69.4274 523.055,69.4258 523.064,69.4241 523.073,69.4225 523.082,69.4209 523.091,69.4192 523.101,69.4176 523.11,69.4159 523.119,69.4143 523.128,69.4127 523.137,69.411 523.147,69.4094 523.156,69.4077 523.165,69.4061 523.174,69.4045 523.183,69.4028 523.192,69.4012 523.202,69.3995 523.211,69.3979 523.22,69.3963 523.229,69.3946 523.238,69.393 523.248,69.3914 523.257,69.3897 523.266,69.3881 523.275,69.3865 523.284,69.3848 523.294,69.3832 523.303,69.3815 523.312,69.3799 523.321,69.3783 523.33,69.3766 523.34,69.375 523.349,69.3734 523.358,69.3717 523.367,69.3701 523.376,69.3685 523.385,69.3668 523.395,69.3652 523.404,69.3636 523.413,69.3619 523.422,69.3603 523.431,69.3587 523.441,69.357 523.45,69.3554 523.459,69.3538 523.468,69.3521 523.477,69.3505 523.487,69.3489 523.496,69.3473 523.505,69.3456 523.514,69.344 523.523,69.3424 523.532,69.3407 523.542,69.3391 523.551,69.3375 523.56,69.3358 523.569,69.3342 523.578,69.3326 523.588,69.331 523.597,69.3293 523.606,69.3277 523.615,69.3261 523.624,69.3244 523.634,69.3228 523.643,69.3212 523.652,69.3196 523.661,69.3179 523.67,69.3163 523.68,69.3147 523.689,69.3131 523.698,69.3114 523.707,69.3098 523.716,69.3082 523.725,69.3066 523.735,69.3049 523.744,69.3033 523.753,69.3017 523.762,69.3001 523.771,69.2984 523.781,69.2968 523.79,69.2952 523.799,69.2936 523.808,69.292 523.817,69.2903 523.827,69.2887 523.836,69.2871 523.845,69.2855 523.854,69.2838 523.863,69.2822 523.873,69.2806 523.882,69.279 523.891,69.2774 523.9,69.2757 523.909,69.2741 523.918,69.2725 523.928,69.2709 523.937,69.2693 523.946,69.2676 523.955,69.266 523.964,69.2644 523.974,69.2628 523.983,69.2612 523.992,69.2596 524.001,69.2579 524.01,69.2563 524.02,69.2547 524.029,69.2531 524.038,69.2515 524.047,69.2499 524.056,69.2482 524.065,69.2466 524.075,69.245 524.084,69.2434 524.093,69.2418 524.102,69.2402 524.111,69.2386 524.121,69.2369 524.13,69.2353 524.139,69.2337 524.148,69.2321 524.157,69.2305 524.167,69.2289 524.176,69.2273 524.185,69.2256 524.194,69.224 524.203,69.2224 524.213,69.2208 524.222,69.2192 524.231,69.2176 524.24,69.216 524.249,69.2144 524.258,69.2128 524.268,69.2111 524.277,69.2095 524.286,69.2079 524.295,69.2063 524.304,69.2047 524.314,69.2031 524.323,69.2015 524.332,69.1999 524.341,69.1983 524.35,69.1967 524.36,69.1951 524.369,69.1934 524.378,69.1918 524.387,69.1902 524.396,69.1886 524.405,69.187 524.415,69.1854 524.424,69.1838 524.433,69.1822 524.442,69.1806 524.451,69.179 524.461,69.1774 524.47,69.1758 524.479,69.1742 524.488,69.1726 524.497,69.171 524.507,69.1694 524.516,69.1678 524.525,69.1661 524.534,69.1645 524.543,69.1629 524.553,69.1613 524.562,69.1597 524.571,69.1581 524.58,69.1565 524.589,69.1549 524.598,69.1533 524.608,69.1517 524.617,69.1501 524.626,69.1485 524.635,69.1469 524.644,69.1453 524.654,69.1437 524.663,69.1421 524.672,69.1405 524.681,69.1389 524.69,69.1373 524.7,69.1357 524.709,69.1341 524.718,69.1325 524.727,69.1309 524.736,69.1293 524.745,69.1277 524.755,69.1261 524.764,69.1245 524.773,69.1229 524.782,69.1213 524.791,69.1197 524.801,69.1181 524.81,69.1166 524.819,69.115 524.828,69.1134 524.837,69.1118 524.847,69.1102 524.856,69.1086 524.865,69.107 524.874,69.1054 524.883,69.1038 524.893,69.1022 524.902,69.1006 524.911,69.099 524.92,69.0974 524.929,69.0958 524.938,69.0942 524.948,69.0926 524.957,69.091 524.966,69.0895 524.975,69.0879 524.984,69.0863 524.994,69.0847 525.003,69.0831 525.012,69.0815 525.021,69.0799 525.03,69.0783 525.04,69.0767 525.049,69.0751 525.058,69.0735 525.067,69.072 525.076,69.0704 525.085,69.0688 525.095,69.0672 525.104,69.0656 525.113,69.064 525.122,69.0624 525.131,69.0608 525.141,69.0592 525.15,69.0577 525.159,69.0561 525.168,69.0545 525.177,69.0529 525.187,69.0513 525.196,69.0497 525.205,69.0481 525.214,69.0466 525.223,69.045 525.233,69.0434 525.242,69.0418 525.251,69.0402 525.26,69.0386 525.269,69.037 525.278,69.0355 525.288,69.0339 525.297,69.0323 525.306,69.0307 525.315,69.0291 525.324,69.0275 525.334,69.026 525.343,69.0244 525.352,69.0228 525.361,69.0212 525.37,69.0196 525.38,69.018 525.389,69.0165 525.398,69.0149 525.407,69.0133 525.416,69.0117 525.425,69.0101 525.435,69.0086 525.444,69.007 525.453,69.0054 525.462,69.0038 525.471,69.0022 525.481,69.0007 525.49,68.9991 525.499,68.9975 525.508,68.9959 525.517,68.9944 525.527,68.9928 525.536,68.9912 525.545,68.9896 525.554,68.988 525.563,68.9865 525.573,68.9849 525.582,68.9833 525.591,68.9817 525.6,68.9802 525.609,68.9786 525.618,68.977 525.628,68.9754 525.637,68.9739 525.646,68.9723 525.655,68.9707 525.664,68.9691 525.674,68.9676 525.683,68.966 525.692,68.9644 525.701,68.9628 525.71,68.9613 525.72,68.9597 525.729,68.9581 525.738,68.9566 525.747,68.955 525.756,68.9534 525.765,68.9518 525.775,68.9503 525.784,68.9487 525.793,68.9471 525.802,68.9456 525.811,68.944 525.821,68.9424 525.83,68.9408 525.839,68.9393 525.848,68.9377 525.857,68.9361 525.867,68.9346 525.876,68.933 525.885,68.9314 525.894,68.9299 525.903,68.9283 525.913,68.9267 525.922,68.9252 525.931,68.9236 525.94,68.922 525.949,68.9205 525.958,68.9189 525.968,68.9173 525.977,68.9158 525.986,68.9142 525.995,68.9126 526.004,68.9111 526.014,68.9095 526.023,68.9079 526.032,68.9064 526.041,68.9048 526.05,68.9032 526.06,68.9017 526.069,68.9001 526.078,68.8985 526.087,68.897 526.096,68.8954 526.105,68.8939 526.115,68.8923 526.124,68.8907 526.133,68.8892 526.142,68.8876 526.151,68.886 526.161,68.8845 526.17,68.8829 526.179,68.8814 526.188,68.8798 526.197,68.8782 526.207,68.8767 526.216,68.8751 526.225,68.8736 526.234,68.872 526.243,68.8704 526.253,68.8689 526.262,68.8673 526.271,68.8658 526.28,68.8642 526.289,68.8626 526.298,68.8611 526.308,68.8595 526.317,68.858 526.326,68.8564 526.335,68.8549 526.344,68.8533 526.354,68.8517 526.363,68.8502 526.372,68.8486 526.381,68.8471 526.39,68.8455 526.4,68.844 526.409,68.8424 526.418,68.8409 526.427,68.8393 526.436,68.8378 526.446,68.8362 526.455,68.8346 526.464,68.8331 526.473,68.8315 526.482,68.83 526.491,68.8284 526.501,68.8269 526.51,68.8253 526.519,68.8238 526.528,68.8222 526.537,68.8207 526.547,68.8191 526.556,68.8176 526.565,68.816 526.574,68.8145 526.583,68.8129 526.593,68.8114 526.602,68.8098 526.611,68.8083 526.62,68.8067 526.629,68.8052 526.638,68.8036 526.648,68.8021 526.657,68.8005 526.666,68.799 526.675,68.7974 526.684,68.7959 526.694,68.7943 526.703,68.7928 526.712,68.7912 526.721,68.7897 526.73,68.7881 526.74,68.7866 526.749,68.785 526.758,68.7835 526.767,68.782 526.776,68.7804 526.786,68.7789 526.795,68.7773 526.804,68.7758 526.813,68.7742 526.822,68.7727 526.831,68.7711 526.841,68.7696 526.85,68.7681 526.859,68.7665 526.868,68.765 526.877,68.7634 526.887,68.7619 526.896,68.7603 526.905,68.7588 526.914,68.7573 526.923,68.7557 526.933,68.7542 526.942,68.7526 526.951,68.7511 526.96,68.7495 526.969,68.748 526.978,68.7465 526.988,68.7449 526.997,68.7434 527.006,68.7418 527.015,68.7403 527.024,68.7388 527.034,68.7372 527.043,68.7357 527.052,68.7341 527.061,68.7326 527.07,68.7311 527.08,68.7295 527.089,68.728 527.098,68.7265 527.107,68.7249 527.116,68.7234 527.126,68.7218 527.135,68.7203 527.144,68.7188 527.153,68.7172 527.162,68.7157 527.171,68.7142 527.181,68.7126 527.19,68.7111 527.199,68.7096 527.208,68.708 527.217,68.7065 527.227,68.705 527.236,68.7034 527.245,68.7019 527.254,68.7004 527.263,68.6988 527.273,68.6973 527.282,68.6958 527.291,68.6942 527.3,68.6927 527.309,68.6912 527.318,68.6896 527.328,68.6881 527.337,68.6866 527.346,68.685 527.355,68.6835 527.364,68.682 527.374,68.6804 527.383,68.6789 527.392,68.6774 527.401,68.6759 527.41,68.6743 527.42,68.6728 527.429,68.6713 527.438,68.6697 527.447,68.6682 527.456,68.6667 527.466,68.6652 527.475,68.6636 527.484,68.6621 527.493,68.6606 527.502,68.659 527.511,68.6575 527.521,68.656 527.53,68.6545 527.539,68.6529 527.548,68.6514 527.557,68.6499 527.567,68.6484 527.576,68.6468 527.585,68.6453 527.594,68.6438 527.603,68.6423 527.613,68.6407 527.622,68.6392 527.631,68.6377 527.64,68.6362 527.649,68.6346 527.658,68.6331 527.668,68.6316 527.677,68.6301 527.686,68.6286 527.695,68.627 527.704,68.6255 527.714,68.624 527.723,68.6225 527.732,68.6209 527.741,68.6194 527.75,68.6179 527.76,68.6164 527.769,68.6149 527.778,68.6133 527.787,68.6118 527.796,68.6103 527.806,68.6088 527.815,68.6073 527.824,68.6057 527.833,68.6042 527.842,68.6027 527.851,68.6012 527.861,68.5997 527.87,68.5982 527.879,68.5966 527.888,68.5951 527.897,68.5936 527.907,68.5921 527.916,68.5906 527.925,68.5891 527.934,68.5875 527.943,68.586 527.953,68.5845 527.962,68.583 527.971,68.5815 527.98,68.58 527.989,68.5784 527.998,68.5769 528.008,68.5754 528.017,68.5739 528.026,68.5724 528.035,68.5709 528.044,68.5694 528.054,68.5679 528.063,68.5663 528.072,68.5648 528.081,68.5633 528.09,68.5618 528.1,68.5603 528.109,68.5588 528.118,68.5573 528.127,68.5558 528.136,68.5542 528.146,68.5527 528.155,68.5512 528.164,68.5497 528.173,68.5482 528.182,68.5467 528.191,68.5452 528.201,68.5437 528.21,68.5422 528.219,68.5407 528.228,68.5391 528.237,68.5376 528.247,68.5361 528.256,68.5346 528.265,68.5331 528.274,68.5316 528.283,68.5301 528.293,68.5286 528.302,68.5271 528.311,68.5256 528.32,68.5241 528.329,68.5226 528.338,68.5211 528.348,68.5196 528.357,68.5181 528.366,68.5165 528.375,68.515 528.384,68.5135 528.394,68.512 528.403,68.5105 528.412,68.509 528.421,68.5075 528.43,68.506 528.44,68.5045 528.449,68.503 528.458,68.5015 528.467,68.5 528.476,68.4985 528.486,68.497 528.495,68.4955 528.504,68.494 528.513,68.4925 528.522,68.491 528.531,68.4895 528.541,68.488 528.55,68.4865 528.559,68.485 528.568,68.4835 528.577,68.482 528.587,68.4805 528.596,68.479 528.605,68.4775 528.614,68.476 528.623,68.4745 528.633,68.473 528.642,68.4715 528.651,68.47 528.66,68.4685 528.669,68.467 528.678,68.4655 528.688,68.464 528.697,68.4625 528.706,68.461 528.715,68.4595 528.724,68.458 528.734,68.4565 528.743,68.455 528.752,68.4535 528.761,68.4521 528.77,68.4506 528.78,68.4491 528.789,68.4476 528.798,68.4461 528.807,68.4446 528.816,68.4431 528.826,68.4416 528.835,68.4401 528.844,68.4386 528.853,68.4371 528.862,68.4356 528.871,68.4341 528.881,68.4326 528.89,68.4311 528.899,68.4297 528.908,68.4282 528.917,68.4267 528.927,68.4252 528.936,68.4237 528.945,68.4222 528.954,68.4207 528.963,68.4192 528.973,68.4177 528.982,68.4162 528.991,68.4147 529,68.4133 529.009,68.4118 529.019,68.4103 529.028,68.4088 529.037,68.4073 529.046,68.4058 529.055,68.4043 529.064,68.4028 529.074,68.4014 529.083,68.3999 529.092,68.3984 529.101,68.3969 529.11,68.3954 529.12,68.3939 529.129,68.3924 529.138,68.391 529.147,68.3895 529.156,68.388 529.166,68.3865 529.175,68.385 529.184,68.3835 529.193,68.382 529.202,68.3806 529.211,68.3791 529.221,68.3776 529.23,68.3761 529.239,68.3746 529.248,68.3731 529.257,68.3717 529.267,68.3702 529.276,68.3687 529.285,68.3672 529.294,68.3657 529.303,68.3643 529.313,68.3628 529.322,68.3613 529.331,68.3598 529.34,68.3583 529.349,68.3568 529.359,68.3554 529.368,68.3539 529.377,68.3524 529.386,68.3509 529.395,68.3494 529.404,68.348 529.414,68.3465 529.423,68.345 529.432,68.3435 529.441,68.3421 529.45,68.3406 529.46,68.3391 529.469,68.3376 529.478,68.3361 529.487,68.3347 529.496,68.3332 529.506,68.3317 529.515,68.3302 529.524,68.3288 529.533,68.3273 529.542,68.3258 529.551,68.3243 529.561,68.3229 529.57,68.3214 529.579,68.3199 529.588,68.3184 529.597,68.317 529.607,68.3155 529.616,68.314 529.625,68.3125 529.634,68.3111 529.643,68.3096 529.653,68.3081 529.662,68.3067 529.671,68.3052 529.68,68.3037 529.689,68.3022 529.699,68.3008 529.708,68.2993 529.717,68.2978 529.726,68.2964 529.735,68.2949 529.744,68.2934 529.754,68.2919 529.763,68.2905 529.772,68.289 529.781,68.2875 529.79,68.2861 529.8,68.2846 529.809,68.2831 529.818,68.2817 529.827,68.2802 529.836,68.2787 529.846,68.2773 529.855,68.2758 529.864,68.2743 529.873,68.2729 529.882,68.2714 529.891,68.2699 529.901,68.2685 529.91,68.267 529.919,68.2655 529.928,68.2641 529.937,68.2626 529.947,68.2611 529.956,68.2597 529.965,68.2582 529.974,68.2567 529.983,68.2553 529.993,68.2538 530.002,68.2523 530.011,68.2509 530.02,68.2494 530.029,68.248 530.039,68.2465 530.048,68.245 530.057,68.2436 530.066,68.2421 530.075,68.2406 530.084,68.2392 530.094,68.2377 530.103,68.2363 530.112,68.2348 530.121,68.2333 530.13,68.2319 530.14,68.2304 530.149,68.229 530.158,68.2275 530.167,68.226 530.176,68.2246 530.186,68.2231 530.195,68.2217 530.204,68.2202 530.213,68.2187 530.222,68.2173 530.231,68.2158 530.241,68.2144 530.25,68.2129 530.259,68.2114 530.268,68.21 530.277,68.2085 530.287,68.2071 530.296,68.2056 530.305,68.2042 530.314,68.2027 530.323,68.2013 530.333,68.1998 530.342,68.1983 530.351,68.1969 530.36,68.1954 530.369,68.194 530.379,68.1925 530.388,68.1911 530.397,68.1896 530.406,68.1882 530.415,68.1867 530.424,68.1853 530.434,68.1838 530.443,68.1823 530.452,68.1809 530.461,68.1794 530.47,68.178 530.48,68.1765 530.489,68.1751 530.498,68.1736 530.507,68.1722 530.516,68.1707 530.526,68.1693 530.535,68.1678 530.544,68.1664 530.553,68.1649 530.562,68.1635 530.571,68.162 530.581,68.1606 530.59,68.1591 530.599,68.1577 530.608,68.1562 530.617,68.1548 530.627,68.1533 530.636,68.1519 530.645,68.1504 530.654,68.149 530.663,68.1475 530.673,68.1461 530.682,68.1447 530.691,68.1432 530.7,68.1418 530.709,68.1403 530.719,68.1389 530.728,68.1374 530.737,68.136 530.746,68.1345 530.755,68.1331 530.764,68.1316 530.774,68.1302 530.783,68.1288 530.792,68.1273 530.801,68.1259 530.81,68.1244 530.82,68.123 530.829,68.1215 530.838,68.1201 530.847,68.1187 530.856,68.1172 530.866,68.1158 530.875,68.1143 530.884,68.1129 530.893,68.1114 530.902,68.11 530.911,68.1086 530.921,68.1071 530.93,68.1057 530.939,68.1042 530.948,68.1028 530.957,68.1014 530.967,68.0999 530.976,68.0985 530.985,68.097 530.994,68.0956 531.003,68.0942 531.013,68.0927 531.022,68.0913 531.031,68.0898 531.04,68.0884 531.049,68.087 531.059,68.0855 531.068,68.0841 531.077,68.0827 531.086,68.0812 531.095,68.0798 531.104,68.0783 531.114,68.0769 531.123,68.0755 531.132,68.074 531.141,68.0726 531.15,68.0712 531.16,68.0697 531.169,68.0683 531.178,68.0669 531.187,68.0654 531.196,68.064 531.206,68.0626 531.215,68.0611 531.224,68.0597 531.233,68.0583 531.242,68.0568 531.252,68.0554 531.261,68.054 531.27,68.0525 531.279,68.0511 531.288,68.0497 531.297,68.0482 531.307,68.0468 531.316,68.0454 531.325,68.0439 531.334,68.0425 531.343,68.0411 531.353,68.0397 531.362,68.0382 531.371,68.0368 531.38,68.0354 531.389,68.0339 531.399,68.0325 531.408,68.0311 531.417,68.0297 531.426,68.0282 531.435,68.0268 531.444,68.0254 531.454,68.0239 531.463,68.0225 531.472,68.0211 531.481,68.0197 531.49,68.0182 531.5,68.0168 531.509,68.0154 531.518,68.014 531.527,68.0125 531.536,68.0111 531.546,68.0097 531.555,68.0083 531.564,68.0068 531.573,68.0054 531.582,68.004 531.592,68.0026 531.601,68.0011 531.61,67.9997 531.619,67.9983 531.628,67.9969 531.637,67.9954 531.647,67.994 531.656,67.9926 531.665,67.9912 531.674,67.9897 531.683,67.9883 531.693,67.9869 531.702,67.9855 531.711,67.9841 531.72,67.9826 531.729,67.9812 531.739,67.9798 531.748,67.9784 531.757,67.977 531.766,67.9755 531.775,67.9741 531.784,67.9727 531.794,67.9713 531.803,67.9699 531.812,67.9684 531.821,67.967 531.83,67.9656 531.84,67.9642 531.849,67.9628 531.858,67.9614 531.867,67.9599 531.876,67.9585 531.886,67.9571 531.895,67.9557 531.904,67.9543 531.913,67.9529 531.922,67.9514 531.932,67.95 531.941,67.9486 531.95,67.9472 531.959,67.9458 531.968,67.9444 531.977,67.9429 531.987,67.9415 531.996,67.9401 532.005,67.9387 532.014,67.9373 532.023,67.9359 532.033,67.9345 532.042,67.9331 532.051,67.9316 532.06,67.9302 532.069,67.9288 532.079,67.9274 532.088,67.926 532.097,67.9246 532.106,67.9232 532.115,67.9218 532.124,67.9203 532.134,67.9189 532.143,67.9175 532.152,67.9161 532.161,67.9147 532.17,67.9133 532.18,67.9119 532.189,67.9105 532.198,67.9091 532.207,67.9077 532.216,67.9062 532.226,67.9048 532.235,67.9034 532.244,67.902 532.253,67.9006 532.262,67.8992 532.272,67.8978 532.281,67.8964 532.29,67.895 532.299,67.8936 532.308,67.8922 532.317,67.8908 532.327,67.8894 532.336,67.888 532.345,67.8866 532.354,67.8851 532.363,67.8837 532.373,67.8823 532.382,67.8809 532.391,67.8795 532.4,67.8781 532.409,67.8767 532.419,67.8753 532.428,67.8739 532.437,67.8725 532.446,67.8711 532.455,67.8697 532.464,67.8683 532.474,67.8669 532.483,67.8655 532.492,67.8641 532.501,67.8627 532.51,67.8613 532.52,67.8599 532.529,67.8585 532.538,67.8571 532.547,67.8557 532.556,67.8543 532.566,67.8529 532.575,67.8515 532.584,67.8501 532.593,67.8487 532.602,67.8473 532.612,67.8459 532.621,67.8445 532.63,67.8431 532.639,67.8417 532.648,67.8403 532.657,67.8389 532.667,67.8375 532.676,67.8361 532.685,67.8347 532.694,67.8333 532.703,67.8319 532.713,67.8305 532.722,67.8291 532.731,67.8277 532.74,67.8263 532.749,67.8249 532.759,67.8235 532.768,67.8221 532.777,67.8208 532.786,67.8194 532.795,67.818 532.804,67.8166 532.814,67.8152 532.823,67.8138 532.832,67.8124 532.841,67.811 532.85,67.8096 532.86,67.8082 532.869,67.8068 532.878,67.8054 532.887,67.804 532.896,67.8026 532.906,67.8013 532.915,67.7999 532.924,67.7985 532.933,67.7971 532.942,67.7957 532.952,67.7943 532.961,67.7929 532.97,67.7915 532.979,67.7901 532.988,67.7887 532.997,67.7873 533.007,67.786 533.016,67.7846 533.025,67.7832 533.034,67.7818 533.043,67.7804 533.053,67.779 533.062,67.7776 533.071,67.7762 533.08,67.7749 533.089,67.7735 533.099,67.7721 533.108,67.7707 533.117,67.7693 533.126,67.7679 533.135,67.7665 533.144,67.7651 533.154,67.7638 533.163,67.7624 533.172,67.761 533.181,67.7596 533.19,67.7582 533.2,67.7568 533.209,67.7555 533.218,67.7541 533.227,67.7527 533.236,67.7513 533.246,67.7499 533.255,67.7485 533.264,67.7472 533.273,67.7458 533.282,67.7444 533.292,67.743 533.301,67.7416 533.31,67.7402 533.319,67.7389 533.328,67.7375 533.337,67.7361 533.347,67.7347 533.356,67.7333 533.365,67.732 533.374,67.7306 533.383,67.7292 533.393,67.7278 533.402,67.7264 533.411,67.7251 533.42,67.7237 533.429,67.7223 533.439,67.7209 533.448,67.7195 533.457,67.7182 533.466,67.7168 533.475,67.7154 533.484,67.714 533.494,67.7127 533.503,67.7113 533.512,67.7099 533.521,67.7085 533.53,67.7072 533.54,67.7058 533.549,67.7044 533.558,67.703 533.567,67.7017 533.576,67.7003 533.586,67.6989 533.595,67.6975 533.604,67.6962 533.613,67.6948 533.622,67.6934 533.632,67.692 533.641,67.6907 533.65,67.6893 533.659,67.6879 533.668,67.6865 533.677,67.6852 533.687,67.6838 533.696,67.6824 533.705,67.681 533.714,67.6797 533.723,67.6783 533.733,67.6769 533.742,67.6756 533.751,67.6742 533.76,67.6728 533.769,67.6715 533.779,67.6701 533.788,67.6687 533.797,67.6673 533.806,67.666 533.815,67.6646 533.825,67.6632 533.834,67.6619 533.843,67.6605 533.852,67.6591 533.861,67.6578 533.87,67.6564 533.88,67.655 533.889,67.6537 533.898,67.6523 533.907,67.6509 533.916,67.6496 533.926,67.6482 533.935,67.6468 533.944,67.6455 533.953,67.6441 533.962,67.6427 533.972,67.6414 533.981,67.64 533.99,67.6386 533.999,67.6373 534.008,67.6359 534.017,67.6345 534.027,67.6332 534.036,67.6318 534.045,67.6304 534.054,67.6291 534.063,67.6277 534.073,67.6264 534.082,67.625 534.091,67.6236 534.1,67.6223 534.109,67.6209 534.119,67.6195 534.128,67.6182 534.137,67.6168 534.146,67.6155 534.155,67.6141 534.165,67.6127 534.174,67.6114 534.183,67.61 534.192,67.6087 534.201,67.6073 534.21,67.6059 534.22,67.6046 534.229,67.6032 534.238,67.6019 534.247,67.6005 534.256,67.5991 534.266,67.5978 534.275,67.5964 534.284,67.5951 534.293,67.5937 534.302,67.5924 534.312,67.591 534.321,67.5896 534.33,67.5883 534.339,67.5869 534.348,67.5856 534.357,67.5842 534.367,67.5829 534.376,67.5815 534.385,67.5802 534.394,67.5788 534.403,67.5774 534.413,67.5761 534.422,67.5747 534.431,67.5734 534.44,67.572 534.449,67.5707 534.459,67.5693 534.468,67.568 534.477,67.5666 534.486,67.5653 534.495,67.5639 534.505,67.5626 534.514,67.5612 534.523,67.5599 534.532,67.5585 534.541,67.5571 534.55,67.5558 534.56,67.5544 534.569,67.5531 534.578,67.5517 534.587,67.5504 534.596,67.549 534.606,67.5477 534.615,67.5463 534.624,67.545 534.633,67.5436 534.642,67.5423 534.652,67.5409 534.661,67.5396 534.67,67.5383 534.679,67.5369 534.688,67.5356 534.697,67.5342 534.707,67.5329 534.716,67.5315 534.725,67.5302 534.734,67.5288 534.743,67.5275 534.753,67.5261 534.762,67.5248 534.771,67.5234 534.78,67.5221 534.789,67.5207 534.799,67.5194 534.808,67.5181 534.817,67.5167 534.826,67.5154 534.835,67.514 534.845,67.5127 534.854,67.5113 534.863,67.51 534.872,67.5086 534.881,67.5073 534.89,67.506 534.9,67.5046 534.909,67.5033 534.918,67.5019 534.927,67.5006 534.936,67.4993 534.946,67.4979 534.955,67.4966 534.964,67.4952 534.973,67.4939 534.982,67.4925 534.992,67.4912 535.001,67.4899 535.01,67.4885 535.019,67.4872 535.028,67.4858 535.037,67.4845 535.047,67.4832 535.056,67.4818 535.065,67.4805 535.074,67.4792 535.083,67.4778 535.093,67.4765 535.102,67.4751 535.111,67.4738 535.12,67.4725 535.129,67.4711 535.139,67.4698 535.148,67.4685 535.157,67.4671 535.166,67.4658 535.175,67.4644 535.185,67.4631 535.194,67.4618 535.203,67.4604 535.212,67.4591 535.221,67.4578 535.23,67.4564 535.24,67.4551 535.249,67.4538 535.258,67.4524 535.267,67.4511 535.276,67.4498 535.286,67.4484 535.295,67.4471 535.304,67.4458 535.313,67.4444 535.322,67.4431 535.332,67.4418 535.341,67.4404 535.35,67.4391 535.359,67.4378 535.368,67.4364 535.377,67.4351 535.387,67.4338 535.396,67.4324 535.405,67.4311 535.414,67.4298 535.423,67.4285 535.433,67.4271 535.442,67.4258 535.451,67.4245 535.46,67.4231 535.469,67.4218 535.479,67.4205 535.488,67.4192 535.497,67.4178 535.506,67.4165 535.515,67.4152 535.525,67.4138 535.534,67.4125 535.543,67.4112 535.552,67.4099 535.561,67.4085 535.57,67.4072 535.58,67.4059 535.589,67.4046 535.598,67.4032 535.607,67.4019 535.616,67.4006 535.626,67.3993 535.635,67.3979 535.644,67.3966 535.653,67.3953 535.662,67.394 535.672,67.3926 535.681,67.3913 535.69,67.39 535.699,67.3887 535.708,67.3873 535.717,67.386 535.727,67.3847 535.736,67.3834 535.745,67.3821 535.754,67.3807 535.763,67.3794 535.773,67.3781 535.782,67.3768 535.791,67.3754 535.8,67.3741 535.809,67.3728 535.819,67.3715 535.828,67.3702 535.837,67.3688 535.846,67.3675 535.855,67.3662 535.865,67.3649 535.874,67.3636 535.883,67.3623 535.892,67.3609 535.901,67.3596 535.91,67.3583 535.92,67.357 535.929,67.3557 535.938,67.3543 535.947,67.353 535.956,67.3517 535.966,67.3504 535.975,67.3491 535.984,67.3478 535.993,67.3464 536.002,67.3451 536.012,67.3438 536.021,67.3425 536.03,67.3412 536.039,67.3399 536.048,67.3386 536.057,67.3372 536.067,67.3359 536.076,67.3346 536.085,67.3333 536.094,67.332 536.103,67.3307 536.113,67.3294 536.122,67.328 536.131,67.3267 536.14,67.3254 536.149,67.3241 536.159,67.3228 536.168,67.3215 536.177,67.3202 536.186,67.3189 536.195,67.3175 536.205,67.3162 536.214,67.3149 536.223,67.3136 536.232,67.3123 536.241,67.311 536.25,67.3097 536.26,67.3084 536.269,67.3071 536.278,67.3058 536.287,67.3044 536.296,67.3031 536.306,67.3018 536.315,67.3005 536.324,67.2992 536.333,67.2979 536.342,67.2966 536.352,67.2953 536.361,67.294 536.37,67.2927 536.379,67.2914 536.388,67.2901 536.398,67.2888 536.407,67.2875 536.416,67.2861 536.425,67.2848 536.434,67.2835 536.443,67.2822 536.453,67.2809 536.462,67.2796 536.471,67.2783 536.48,67.277 536.489,67.2757 536.499,67.2744 536.508,67.2731 536.517,67.2718 536.526,67.2705 536.535,67.2692 536.545,67.2679 536.554,67.2666 536.563,67.2653 536.572,67.264 536.581,67.2627 536.59,67.2614 536.6,67.2601 536.609,67.2588 536.618,67.2575 536.627,67.2562 536.636,67.2549 536.646,67.2536 536.655,67.2523 536.664,67.251 536.673,67.2497 536.682,67.2484 536.692,67.2471 536.701,67.2458 536.71,67.2445 536.719,67.2432 536.728,67.2419 536.738,67.2406 536.747,67.2393 536.756,67.238 536.765,67.2367 536.774,67.2354 536.783,67.2341 536.793,67.2328 536.802,67.2315 536.811,67.2302 536.82,67.2289 536.829,67.2276 536.839,67.2263 536.848,67.225 536.857,67.2237 536.866,67.2224 536.875,67.2211 536.885,67.2199 536.894,67.2186 536.903,67.2173 536.912,67.216 536.921,67.2147 536.93,67.2134 536.94,67.2121 536.949,67.2108 536.958,67.2095 536.967,67.2082 536.976,67.2069 536.986,67.2056 536.995,67.2043 537.004,67.203 537.013,67.2018 537.022,67.2005 537.032,67.1992 537.041,67.1979 537.05,67.1966 537.059,67.1953 537.068,67.194 537.078,67.1927 537.087,67.1914 537.096,67.1901 537.105,67.1889 537.114,67.1876 537.123,67.1863 537.133,67.185 537.142,67.1837 537.151,67.1824 537.16,67.1811 537.169,67.1798 537.179,67.1785 537.188,67.1773 537.197,67.176 537.206,67.1747 537.215,67.1734 537.225,67.1721 537.234,67.1708 537.243,67.1695 537.252,67.1683 537.261,67.167 537.27,67.1657 537.28,67.1644 537.289,67.1631 537.298,67.1618 537.307,67.1605 537.316,67.1593 537.326,67.158 537.335,67.1567 537.344,67.1554 537.353,67.1541 537.362,67.1528 537.372,67.1516 537.381,67.1503 537.39,67.149 537.399,67.1477 537.408,67.1464 537.418,67.1452 537.427,67.1439 537.436,67.1426 537.445,67.1413 537.454,67.14 537.463,67.1388 537.473,67.1375 537.482,67.1362 537.491,67.1349 537.5,67.1336 537.509,67.1324 537.519,67.1311 537.528,67.1298 537.537,67.1285 537.546,67.1272 537.555,67.126 537.565,67.1247 537.574,67.1234 537.583,67.1221 537.592,67.1208 537.601,67.1196 537.61,67.1183 537.62,67.117 537.629,67.1157 537.638,67.1145 537.647,67.1132 537.656,67.1119 537.666,67.1106 537.675,67.1094 537.684,67.1081 537.693,67.1068 537.702,67.1055 537.712,67.1043 537.721,67.103 537.73,67.1017 537.739,67.1004 537.748,67.0992 537.758,67.0979 537.767,67.0966 537.776,67.0953 537.785,67.0941 537.794,67.0928 537.803,67.0915 537.813,67.0903 537.822,67.089 537.831,67.0877 537.84,67.0864 537.849,67.0852 537.859,67.0839 537.868,67.0826 537.877,67.0814 537.886,67.0801 537.895,67.0788 537.905,67.0776 537.914,67.0763 537.923,67.075 537.932,67.0737 537.941,67.0725 537.95,67.0712 537.96,67.0699 537.969,67.0687 537.978,67.0674 537.987,67.0661 537.996,67.0649 538.006,67.0636 538.015,67.0623 538.024,67.0611 538.033,67.0598 538.042,67.0585 538.052,67.0573 538.061,67.056 538.07,67.0547 538.079,67.0535 538.088,67.0522 538.098,67.0509 538.107,67.0497 538.116,67.0484 538.125,67.0471 538.134,67.0459 538.143,67.0446 538.153,67.0434 538.162,67.0421 538.171,67.0408 538.18,67.0396 538.189,67.0383 538.199,67.037 538.208,67.0358 538.217,67.0345 538.226,67.0332 538.235,67.032 538.245,67.0307 538.254,67.0295 538.263,67.0282 538.272,67.0269 538.281,67.0257 538.29,67.0244 538.3,67.0232 538.309,67.0219 538.318,67.0206 538.327,67.0194 538.336,67.0181 538.346,67.0169 538.355,67.0156 538.364,67.0143 538.373,67.0131 538.382,67.0118 538.392,67.0106 538.401,67.0093 538.41,67.0081 538.419,67.0068 538.428,67.0055 538.438,67.0043 538.447,67.003 538.456,67.0018 538.465,67.0005 538.474,66.9993 538.483,66.998 538.493,66.9967 538.502,66.9955 538.511,66.9942 538.52,66.993 538.529,66.9917 538.539,66.9905 538.548,66.9892 538.557,66.988 538.566,66.9867 538.575,66.9855 538.585,66.9842 538.594,66.9829 538.603,66.9817 538.612,66.9804 538.621,66.9792 538.631,66.9779 538.64,66.9767 538.649,66.9754 538.658,66.9742 538.667,66.9729 538.676,66.9717 538.686,66.9704 538.695,66.9692 538.704,66.9679 538.713,66.9667 538.722,66.9654 538.732,66.9642 538.741,66.9629 538.75,66.9617 538.759,66.9604 538.768,66.9592 538.778,66.9579 538.787,66.9567 538.796,66.9554 538.805,66.9542 538.814,66.9529 538.823,66.9517 538.833,66.9504 538.842,66.9492 538.851,66.9479 538.86,66.9467 538.869,66.9455 538.879,66.9442 538.888,66.943 538.897,66.9417 538.906,66.9405 538.915,66.9392 538.925,66.938 538.934,66.9367 538.943,66.9355 538.952,66.9342 538.961,66.933 538.971,66.9318 538.98,66.9305 538.989,66.9293 538.998,66.928 539.007,66.9268 539.016,66.9255 539.026,66.9243 539.035,66.9231 539.044,66.9218 539.053,66.9206 539.062,66.9193 539.072,66.9181 539.081,66.9168 539.09,66.9156 539.099,66.9144 539.108,66.9131 539.118,66.9119 539.127,66.9106 539.136,66.9094 539.145,66.9082 539.154,66.9069 539.163,66.9057 539.173,66.9044 539.182,66.9032 539.191,66.902 539.2,66.9007 539.209,66.8995 539.219,66.8982 539.228,66.897 539.237,66.8958 539.246,66.8945 539.255,66.8933 539.265,66.8921 539.274,66.8908 539.283,66.8896 539.292,66.8884 539.301,66.8871 539.311,66.8859 539.32,66.8846 539.329,66.8834 539.338,66.8822 539.347,66.8809 539.356,66.8797 539.366,66.8785 539.375,66.8772 539.384,66.876 539.393,66.8748 539.402,66.8735 539.412,66.8723 539.421,66.8711 539.43,66.8698 539.439,66.8686 539.448,66.8674 539.458,66.8661 539.467,66.8649 539.476,66.8637 539.485,66.8624 539.494,66.8612 539.503,66.86 539.513,66.8587 539.522,66.8575 539.531,66.8563 539.54,66.855 539.549,66.8538 539.559,66.8526 539.568,66.8514 539.577,66.8501 539.586,66.8489 539.595,66.8477 539.605,66.8464 539.614,66.8452 539.623,66.844 539.632,66.8428 539.641,66.8415 539.651,66.8403 539.66,66.8391 539.669,66.8378 539.678,66.8366 539.687,66.8354 539.696,66.8342 539.706,66.8329 539.715,66.8317 539.724,66.8305 539.733,66.8293 539.742,66.828 539.752,66.8268 539.761,66.8256 539.77,66.8244 539.779,66.8231 539.788,66.8219 539.798,66.8207 539.807,66.8195 539.816,66.8182 539.825,66.817 539.834,66.8158 539.843,66.8146 539.853,66.8133 539.862,66.8121 539.871,66.8109 539.88,66.8097 539.889,66.8085 539.899,66.8072 539.908,66.806 539.917,66.8048 539.926,66.8036 539.935,66.8023 539.945,66.8011 539.954,66.7999 539.963,66.7987 539.972,66.7975 539.981,66.7962 539.991,66.795 540,66.7938 540.009,66.7926 540.018,66.7914 540.027,66.7901 540.036,66.7889 540.046,66.7877 540.055,66.7865 540.064,66.7853 540.073,66.7841 540.082,66.7828 540.092,66.7816 540.101,66.7804 540.11,66.7792 540.119,66.778 540.128,66.7768 540.138,66.7755 540.147,66.7743 540.156,66.7731 540.165,66.7719 540.174,66.7707 540.183,66.7695 540.193,66.7682 540.202,66.767 540.211,66.7658 540.22,66.7646 540.229,66.7634 540.239,66.7622 540.248,66.761 540.257,66.7597 540.266,66.7585 540.275,66.7573 540.285,66.7561 540.294,66.7549 540.303,66.7537 540.312,66.7525 540.321,66.7513 540.331,66.75 540.34,66.7488 540.349,66.7476 540.358,66.7464 540.367,66.7452 540.376,66.744 540.386,66.7428 540.395,66.7416 540.404,66.7404 540.413,66.7392 540.422,66.7379 540.432,66.7367 540.441,66.7355 540.45,66.7343 540.459,66.7331 540.468,66.7319 540.478,66.7307 540.487,66.7295 540.496,66.7283 540.505,66.7271 540.514,66.7259 540.523,66.7247 540.533,66.7234 540.542,66.7222 540.551,66.721 540.56,66.7198 540.569,66.7186 540.579,66.7174 540.588,66.7162 540.597,66.715 540.606,66.7138 540.615,66.7126 540.625,66.7114 540.634,66.7102 540.643,66.709 540.652,66.7078 540.661,66.7066 540.671,66.7054 540.68,66.7042 540.689,66.703 540.698,66.7018 540.707,66.7006 540.716,66.6994 540.726,66.6982 540.735,66.697 540.744,66.6958 540.753,66.6945 540.762,66.6933 540.772,66.6921 540.781,66.6909 540.79,66.6897 540.799,66.6885 540.808,66.6873 540.818,66.6861 540.827,66.6849 540.836,66.6837 540.845,66.6825 540.854,66.6813 540.863,66.6801 540.873,66.6789 540.882,66.6777 540.891,66.6766 540.9,66.6754 540.909,66.6742 540.919,66.673 540.928,66.6718 540.937,66.6706 540.946,66.6694 540.955,66.6682 540.965,66.667 540.974,66.6658 540.983,66.6646 540.992,66.6634 541.001,66.6622 541.011,66.661 541.02,66.6598 541.029,66.6586 541.038,66.6574 541.047,66.6562 541.056,66.655 541.066,66.6538 541.075,66.6526 541.084,66.6514 541.093,66.6502 541.102,66.6491 541.112,66.6479 541.121,66.6467 541.13,66.6455 541.139,66.6443 541.148,66.6431 541.158,66.6419 541.167,66.6407 541.176,66.6395 541.185,66.6383 541.194,66.6371 541.204,66.6359 541.213,66.6347 541.222,66.6336 541.231,66.6324 541.24,66.6312 541.249,66.63 541.259,66.6288 541.268,66.6276 541.277,66.6264 541.286,66.6252 541.295,66.624 541.305,66.6229 541.314,66.6217 541.323,66.6205 541.332,66.6193 541.341,66.6181 541.351,66.6169 541.36,66.6157 541.369,66.6145 541.378,66.6134 541.387,66.6122 541.396,66.611 541.406,66.6098 541.415,66.6086 541.424,66.6074 541.433,66.6062 541.442,66.6051 541.452,66.6039 541.461,66.6027 541.47,66.6015 541.479,66.6003 541.488,66.5991 541.498,66.5979 541.507,66.5968 541.516,66.5956 541.525,66.5944 541.534,66.5932 541.544,66.592 541.553,66.5909 541.562,66.5897 541.571,66.5885 541.58,66.5873 541.589,66.5861 541.599,66.5849 541.608,66.5838 541.617,66.5826 541.626,66.5814 541.635,66.5802 541.645,66.579 541.654,66.5779 541.663,66.5767 541.672,66.5755 541.681,66.5743 541.691,66.5731 541.7,66.572 541.709,66.5708 541.718,66.5696 541.727,66.5684 541.736,66.5672 541.746,66.5661 541.755,66.5649 541.764,66.5637 541.773,66.5625 541.782,66.5614 541.792,66.5602 541.801,66.559 541.81,66.5578 541.819,66.5567 541.828,66.5555 541.838,66.5543 541.847,66.5531 541.856,66.5519 541.865,66.5508 541.874,66.5496 541.884,66.5484 541.893,66.5473 541.902,66.5461 541.911,66.5449 541.92,66.5437 541.929,66.5426 541.939,66.5414 541.948,66.5402 541.957,66.539 541.966,66.5379 541.975,66.5367 541.985,66.5355 541.994,66.5343 542.003,66.5332 542.012,66.532 542.021,66.5308 542.031,66.5297 542.04,66.5285 542.049,66.5273 542.058,66.5261 542.067,66.525 542.076,66.5238 542.086,66.5226 542.095,66.5215 542.104,66.5203 542.113,66.5191 542.122,66.518 542.132,66.5168 542.141,66.5156 542.15,66.5145 542.159,66.5133 542.168,66.5121 542.178,66.511 542.187,66.5098 542.196,66.5086 542.205,66.5074 542.214,66.5063 542.224,66.5051 542.233,66.5039 542.242,66.5028 542.251,66.5016 542.26,66.5005 542.269,66.4993 542.279,66.4981 542.288,66.497 542.297,66.4958 542.306,66.4946 542.315,66.4935 542.325,66.4923 542.334,66.4911 542.343,66.49 542.352,66.4888 542.361,66.4876 542.371,66.4865 542.38,66.4853 542.389,66.4842 542.398,66.483 542.407,66.4818 542.416,66.4807 542.426,66.4795 542.435,66.4783 542.444,66.4772 542.453,66.476 542.462,66.4749 542.472,66.4737 542.481,66.4725 542.49,66.4714 542.499,66.4702 542.508,66.4691 542.518,66.4679 542.527,66.4667 542.536,66.4656 542.545,66.4644 542.554,66.4633 542.564,66.4621 542.573,66.4609 542.582,66.4598 542.591,66.4586 542.6,66.4575 542.609,66.4563 542.619,66.4552 542.628,66.454 542.637,66.4528 542.646,66.4517 542.655,66.4505 542.665,66.4494 542.674,66.4482 542.683,66.4471 542.692,66.4459 542.701,66.4448 542.711,66.4436 542.72,66.4424 542.729,66.4413 542.738,66.4401 542.747,66.439 542.756,66.4378 542.766,66.4367 542.775,66.4355 542.784,66.4344 542.793,66.4332 542.802,66.4321 542.812,66.4309 542.821,66.4298 542.83,66.4286 542.839,66.4274 542.848,66.4263 542.858,66.4251 542.867,66.424 542.876,66.4228 542.885,66.4217 542.894,66.4205 542.904,66.4194 542.913,66.4182 542.922,66.4171 542.931,66.4159 542.94,66.4148 542.949,66.4136 542.959,66.4125 542.968,66.4113 542.977,66.4102 542.986,66.409 542.995,66.4079 543.005,66.4068 543.014,66.4056 543.023,66.4045 543.032,66.4033 543.041,66.4022 543.051,66.401 543.06,66.3999 543.069,66.3987 543.078,66.3976 543.087,66.3964 543.096,66.3953 543.106,66.3941 543.115,66.393 543.124,66.3918 543.133,66.3907 543.142,66.3896 543.152,66.3884 543.161,66.3873 543.17,66.3861 543.179,66.385 543.188,66.3838 543.198,66.3827 543.207,66.3815 543.216,66.3804 543.225,66.3793 543.234,66.3781 543.244,66.377 543.253,66.3758 543.262,66.3747 543.271,66.3736 543.28,66.3724 543.289,66.3713 543.299,66.3701 543.308,66.369 543.317,66.3678 543.326,66.3667 543.335,66.3656 543.345,66.3644 543.354,66.3633 543.363,66.3621 543.372,66.361 543.381,66.3599 543.391,66.3587 543.4,66.3576 543.409,66.3564 543.418,66.3553 543.427,66.3542 543.436,66.353 543.446,66.3519 543.455,66.3508 543.464,66.3496 543.473,66.3485 543.482,66.3473 543.492,66.3462 543.501,66.3451 543.51,66.3439 543.519,66.3428 543.528,66.3417 543.538,66.3405 543.547,66.3394 543.556,66.3383 543.565,66.3371 543.574,66.336 543.584,66.3349 543.593,66.3337 543.602,66.3326 543.611,66.3315 543.62,66.3303 543.629,66.3292 543.639,66.3281 543.648,66.3269 543.657,66.3258 543.666,66.3247 543.675,66.3235 543.685,66.3224 543.694,66.3213 543.703,66.3201 543.712,66.319 543.721,66.3179 543.731,66.3167 543.74,66.3156 543.749,66.3145 543.758,66.3133 543.767,66.3122 543.777,66.3111 543.786,66.31 543.795,66.3088 543.804,66.3077 543.813,66.3066 543.822,66.3054 543.832,66.3043 543.841,66.3032 543.85,66.3021 543.859,66.3009 543.868,66.2998 543.878,66.2987 543.887,66.2975 543.896,66.2964 543.905,66.2953 543.914,66.2942 543.924,66.293 543.933,66.2919 543.942,66.2908 543.951,66.2897 543.96,66.2885 543.969,66.2874 543.979,66.2863 543.988,66.2852 543.997,66.284 544.006,66.2829 544.015,66.2818 544.025,66.2807 544.034,66.2795 544.043,66.2784 544.052,66.2773 544.061,66.2762 544.071,66.275 544.08,66.2739 544.089,66.2728 544.098,66.2717 544.107,66.2706 544.117,66.2694 544.126,66.2683 544.135,66.2672 544.144,66.2661 544.153,66.2649 544.162,66.2638 544.172,66.2627 544.181,66.2616 544.19,66.2605 544.199,66.2593 544.208,66.2582 544.218,66.2571 544.227,66.256 544.236,66.2549 544.245,66.2538 544.254,66.2526 544.264,66.2515 544.273,66.2504 544.282,66.2493 544.291,66.2482 544.3,66.247 544.309,66.2459 544.319,66.2448 544.328,66.2437 544.337,66.2426 544.346,66.2415 544.355,66.2403 544.365,66.2392 544.374,66.2381 544.383,66.237 544.392,66.2359 544.401,66.2348 544.411,66.2337 544.42,66.2325 544.429,66.2314 544.438,66.2303 544.447,66.2292 544.457,66.2281 544.466,66.227 544.475,66.2259 544.484,66.2247 544.493,66.2236 544.502,66.2225 544.512,66.2214 544.521,66.2203 544.53,66.2192 544.539,66.2181 544.548,66.217 544.558,66.2158 544.567,66.2147 544.576,66.2136 544.585,66.2125 544.594,66.2114 544.604,66.2103 544.613,66.2092 544.622,66.2081 544.631,66.207 544.64,66.2058 544.649,66.2047 544.659,66.2036 544.668,66.2025 544.677,66.2014 544.686,66.2003 544.695,66.1992 544.705,66.1981 544.714,66.197 544.723,66.1959 544.732,66.1948 544.741,66.1937 544.751,66.1926 544.76,66.1914 544.769,66.1903 544.778,66.1892 544.787,66.1881 544.797,66.187 544.806,66.1859 544.815,66.1848 544.824,66.1837 544.833,66.1826 544.842,66.1815 544.852,66.1804 544.861,66.1793 544.87,66.1782 544.879,66.1771 544.888,66.176 544.898,66.1749 544.907,66.1738 544.916,66.1727 544.925,66.1716 544.934,66.1705 544.944,66.1694 544.953,66.1683 544.962,66.1672 544.971,66.1661 544.98,66.165 544.989,66.1639 544.999,66.1627 545.008,66.1616 545.017,66.1605 545.026,66.1594 545.035,66.1583 545.045,66.1572 545.054,66.1561 545.063,66.155 545.072,66.1539 545.081,66.1529 545.091,66.1518 545.1,66.1507 545.109,66.1496 545.118,66.1485 545.127,66.1474 545.137,66.1463 545.146,66.1452 545.155,66.1441 545.164,66.143 545.173,66.1419 545.182,66.1408 545.192,66.1397 545.201,66.1386 545.21,66.1375 545.219,66.1364 545.228,66.1353 545.238,66.1342 545.247,66.1331 545.256,66.132 545.265,66.1309 545.274,66.1298 545.284,66.1287 545.293,66.1276 545.302,66.1265 545.311,66.1254 545.32,66.1244 545.329,66.1233 545.339,66.1222 545.348,66.1211 545.357,66.12 545.366,66.1189 545.375,66.1178 545.385,66.1167 545.394,66.1156 545.403,66.1145 545.412,66.1134 545.421,66.1123 545.431,66.1112 545.44,66.1102 545.449,66.1091 545.458,66.108 545.467,66.1069 545.477,66.1058 545.486,66.1047 545.495,66.1036 545.504,66.1025 545.513,66.1014 545.522,66.1004 545.532,66.0993 545.541,66.0982 545.55,66.0971 545.559,66.096 545.568,66.0949 545.578,66.0938 545.587,66.0927 545.596,66.0916 545.605,66.0906 545.614,66.0895 545.624,66.0884 545.633,66.0873 545.642,66.0862 545.651,66.0851 545.66,66.084 545.669,66.083 545.679,66.0819 545.688,66.0808 545.697,66.0797 545.706,66.0786 545.715,66.0775 545.725,66.0765 545.734,66.0754 545.743,66.0743 545.752,66.0732 545.761,66.0721 545.771,66.071 545.78,66.07 545.789,66.0689 545.798,66.0678 545.807,66.0667 545.817,66.0656 545.826,66.0645 545.835,66.0635 545.844,66.0624 545.853,66.0613 545.862,66.0602 545.872,66.0591 545.881,66.0581 545.89,66.057 545.899,66.0559 545.908,66.0548 545.918,66.0537 545.927,66.0527 545.936,66.0516 545.945,66.0505 545.954,66.0494 545.964,66.0483 545.973,66.0473 545.982,66.0462 545.991,66.0451 546,66.044 546.01,66.043 546.019,66.0419 546.028,66.0408 546.037,66.0397 546.046,66.0387 546.055,66.0376 546.065,66.0365 546.074,66.0354 546.083,66.0344 546.092,66.0333 546.101,66.0322 546.111,66.0311 546.12,66.0301 546.129,66.029 546.138,66.0279 546.147,66.0268 546.157,66.0258 546.166,66.0247 546.175,66.0236 546.184,66.0225 546.193,66.0215 546.202,66.0204 546.212,66.0193 546.221,66.0182 546.23,66.0172 546.239,66.0161 546.248,66.015 546.258,66.014 546.267,66.0129 546.276,66.0118 546.285,66.0107 546.294,66.0097 546.304,66.0086 546.313,66.0075 546.322,66.0065 546.331,66.0054 546.34,66.0043 546.35,66.0033 546.359,66.0022 546.368,66.0011 546.377,66 546.386,65.999 546.395,65.9979 546.405,65.9968 546.414,65.9958 546.423,65.9947 546.432,65.9936 546.441,65.9926 546.451,65.9915 546.46,65.9904 546.469,65.9894 546.478,65.9883 546.487,65.9872 546.497,65.9862 546.506,65.9851 546.515,65.984 546.524,65.983 546.533,65.9819 546.542,65.9809 546.552,65.9798 546.561,65.9787 546.57,65.9777 546.579,65.9766 546.588,65.9755 546.598,65.9745 546.607,65.9734 546.616,65.9723 546.625,65.9713 546.634,65.9702 546.644,65.9692 546.653,65.9681 546.662,65.967 546.671,65.966 546.68,65.9649 546.69,65.9638 546.699,65.9628 546.708,65.9617 546.717,65.9607 546.726,65.9596 546.735,65.9585 546.745,65.9575 546.754,65.9564 546.763,65.9554 546.772,65.9543 546.781,65.9532 546.791,65.9522 546.8,65.9511 546.809,65.9501 546.818,65.949 546.827,65.948 546.837,65.9469 546.846,65.9458 546.855,65.9448 546.864,65.9437 546.873,65.9427 546.882,65.9416 546.892,65.9406 546.901,65.9395 546.91,65.9384 546.919,65.9374 546.928,65.9363 546.938,65.9353 546.947,65.9342 546.956,65.9332 546.965,65.9321 546.974,65.9311 546.984,65.93 546.993,65.9289 547.002,65.9279 547.011,65.9268 547.02,65.9258 547.03,65.9247 547.039,65.9237 547.048,65.9226 547.057,65.9216 547.066,65.9205 547.075,65.9195 547.085,65.9184 547.094,65.9174 547.103,65.9163 547.112,65.9153 547.121,65.9142 547.131,65.9132 547.14,65.9121 547.149,65.9111 547.158,65.91 547.167,65.909 547.177,65.9079 547.186,65.9069 547.195,65.9058 547.204,65.9048 547.213,65.9037 547.222,65.9027 547.232,65.9016 547.241,65.9006 547.25,65.8995 547.259,65.8985 547.268,65.8974 547.278,65.8964 547.287,65.8953 547.296,65.8943 547.305,65.8932 547.314,65.8922 547.324,65.8911 547.333,65.8901 547.342,65.8891 547.351,65.888 547.36,65.887 547.37,65.8859 547.379,65.8849 547.388,65.8838 547.397,65.8828 547.406,65.8817 547.415,65.8807 547.425,65.8796 547.434,65.8786 547.443,65.8776 547.452,65.8765 547.461,65.8755 547.471,65.8744 547.48,65.8734 547.489,65.8723 547.498,65.8713 547.507,65.8703 547.517,65.8692 547.526,65.8682 547.535,65.8671 547.544,65.8661 547.553,65.8651 547.562,65.864 547.572,65.863 547.581,65.8619 547.59,65.8609 547.599,65.8599 547.608,65.8588 547.618,65.8578 547.627,65.8567 547.636,65.8557 547.645,65.8547 547.654,65.8536 547.664,65.8526 547.673,65.8515 547.682,65.8505 547.691,65.8495 547.7,65.8484 547.71,65.8474 547.719,65.8464 547.728,65.8453 547.737,65.8443 547.746,65.8432 547.755,65.8422 547.765,65.8412 547.774,65.8401 547.783,65.8391 547.792,65.8381 547.801,65.837 547.811,65.836 547.82,65.835 547.829,65.8339 547.838,65.8329 547.847,65.8319 547.857,65.8308 547.866,65.8298 547.875,65.8288 547.884,65.8277 547.893,65.8267 547.902,65.8257 547.912,65.8246 547.921,65.8236 547.93,65.8226 547.939,65.8215 547.948,65.8205 547.958,65.8195 547.967,65.8184 547.976,65.8174 547.985,65.8164 547.994,65.8153 548.004,65.8143 548.013,65.8133 548.022,65.8123 548.031,65.8112 548.04,65.8102 548.05,65.8092 548.059,65.8081 548.068,65.8071 548.077,65.8061 548.086,65.8051 548.095,65.804 548.105,65.803 548.114,65.802 548.123,65.8009 548.132,65.7999 548.141,65.7989 548.151,65.7979 548.16,65.7968 548.169,65.7958 548.178,65.7948 548.187,65.7938 548.197,65.7927 548.206,65.7917 548.215,65.7907 548.224,65.7897 548.233,65.7886 548.242,65.7876 548.252,65.7866 548.261,65.7856 548.27,65.7845 548.279,65.7835 548.288,65.7825 548.298,65.7815 548.307,65.7804 548.316,65.7794 548.325,65.7784 548.334,65.7774 548.344,65.7763 548.353,65.7753 548.362,65.7743 548.371,65.7733 548.38,65.7723 548.39,65.7712 548.399,65.7702 548.408,65.7692 548.417,65.7682 548.426,65.7672 548.435,65.7661 548.445,65.7651 548.454,65.7641 548.463,65.7631 548.472,65.7621 548.481,65.761 548.491,65.76 548.5,65.759 548.509,65.758 548.518,65.757 548.527,65.7559 548.537,65.7549 548.546,65.7539 548.555,65.7529 548.564,65.7519 548.573,65.7509 548.583,65.7498 548.592,65.7488 548.601,65.7478 548.61,65.7468 548.619,65.7458 548.628,65.7448 548.638,65.7437 548.647,65.7427 548.656,65.7417 548.665,65.7407 548.674,65.7397 548.684,65.7387 548.693,65.7377 548.702,65.7366 548.711,65.7356 548.72,65.7346 548.73,65.7336 548.739,65.7326 548.748,65.7316 548.757,65.7306 548.766,65.7296 548.775,65.7285 548.785,65.7275 548.794,65.7265 548.803,65.7255 548.812,65.7245 548.821,65.7235 548.831,65.7225 548.84,65.7215 548.849,65.7204 548.858,65.7194 548.867,65.7184 548.877,65.7174 548.886,65.7164 548.895,65.7154 548.904,65.7144 548.913,65.7134 548.923,65.7124 548.932,65.7114 548.941,65.7104 548.95,65.7093 548.959,65.7083 548.968,65.7073 548.978,65.7063 548.987,65.7053 548.996,65.7043 549.005,65.7033 549.014,65.7023 549.024,65.7013 549.033,65.7003 549.042,65.6993 549.051,65.6983 549.06,65.6973 549.07,65.6963 549.079,65.6953 549.088,65.6943 549.097,65.6932 549.106,65.6922 549.115,65.6912 549.125,65.6902 549.134,65.6892 549.143,65.6882 549.152,65.6872 549.161,65.6862 549.171,65.6852 549.18,65.6842 549.189,65.6832 549.198,65.6822 549.207,65.6812 549.217,65.6802 549.226,65.6792 549.235,65.6782 549.244,65.6772 549.253,65.6762 549.263,65.6752 549.272,65.6742 549.281,65.6732 549.29,65.6722 549.299,65.6712 549.308,65.6702 549.318,65.6692 549.327,65.6682 549.336,65.6672 549.345,65.6662 549.354,65.6652 549.364,65.6642 549.373,65.6632 549.382,65.6622 549.391,65.6612 549.4,65.6602 549.41,65.6592 549.419,65.6582 549.428,65.6572 549.437,65.6562 549.446,65.6552 549.455,65.6542 549.465,65.6532 549.474,65.6522 549.483,65.6512 549.492,65.6503 549.501,65.6493 549.511,65.6483 549.52,65.6473 549.529,65.6463 549.538,65.6453 549.547,65.6443 549.557,65.6433 549.566,65.6423 549.575,65.6413 549.584,65.6403 549.593,65.6393 549.603,65.6383 549.612,65.6373 549.621,65.6363 549.63,65.6353 549.639,65.6344 549.648,65.6334 549.658,65.6324 549.667,65.6314 549.676,65.6304 549.685,65.6294 549.694,65.6284 549.704,65.6274 549.713,65.6264 549.722,65.6254 549.731,65.6244 549.74,65.6235 549.75,65.6225 549.759,65.6215 549.768,65.6205 549.777,65.6195 549.786,65.6185 549.795,65.6175 549.805,65.6165 549.814,65.6155 549.823,65.6146 549.832,65.6136 549.841,65.6126 549.851,65.6116 549.86,65.6106 549.869,65.6096 549.878,65.6086 549.887,65.6077 549.897,65.6067 549.906,65.6057 549.915,65.6047 549.924,65.6037 549.933,65.6027 549.943,65.6017 549.952,65.6008 549.961,65.5998 549.97,65.5988 549.979,65.5978 549.988,65.5968 549.998,65.5958 550.007,65.5949 550.016,65.5939 550.025,65.5929 550.034,65.5919 550.044,65.5909 550.053,65.5899 550.062,65.589 550.071,65.588 550.08,65.587 550.09,65.586 550.099,65.585 550.108,65.5841 550.117,65.5831 550.126,65.5821 550.135,65.5811 550.145,65.5801 550.154,65.5792 550.163,65.5782 550.172,65.5772 550.181,65.5762 550.191,65.5752 550.2,65.5743 550.209,65.5733 550.218,65.5723 550.227,65.5713 550.237,65.5703 550.246,65.5694 550.255,65.5684 550.264,65.5674 550.273,65.5664 550.283,65.5655 550.292,65.5645 550.301,65.5635 550.31,65.5625 550.319,65.5616 550.328,65.5606 550.338,65.5596 550.347,65.5586 550.356,65.5576 550.365,65.5567 550.374,65.5557 550.384,65.5547 550.393,65.5538 550.402,65.5528 550.411,65.5518 550.42,65.5508 550.43,65.5499 550.439,65.5489 550.448,65.5479 550.457,65.5469 550.466,65.546 550.475,65.545 550.485,65.544 550.494,65.543 550.503,65.5421 550.512,65.5411 550.521,65.5401 550.531,65.5392 550.54,65.5382 550.549,65.5372 550.558,65.5363 550.567,65.5353 550.577,65.5343 550.586,65.5333 550.595,65.5324 550.604,65.5314 550.613,65.5304 550.623,65.5295 550.632,65.5285 550.641,65.5275 550.65,65.5266 550.659,65.5256 550.668,65.5246 550.678,65.5237 550.687,65.5227 550.696,65.5217 550.705,65.5208 550.714,65.5198 550.724,65.5188 550.733,65.5179 550.742,65.5169 550.751,65.5159 550.76,65.515 550.77,65.514 550.779,65.513 550.788,65.5121 550.797,65.5111 550.806,65.5101 550.815,65.5092 550.825,65.5082 550.834,65.5072 550.843,65.5063 550.852,65.5053 550.861,65.5044 550.871,65.5034 550.88,65.5024 550.889,65.5015 550.898,65.5005 550.907,65.4995 550.917,65.4986 550.926,65.4976 550.935,65.4967 550.944,65.4957 550.953,65.4947 550.963,65.4938 550.972,65.4928 550.981,65.4918 550.99,65.4909 550.999,65.4899 551.008,65.489 551.018,65.488 551.027,65.487 551.036,65.4861 551.045,65.4851 551.054,65.4842 551.064,65.4832 551.073,65.4823 551.082,65.4813 551.091,65.4803 551.1,65.4794 551.11,65.4784 551.119,65.4775 551.128,65.4765 551.137,65.4756 551.146,65.4746 551.156,65.4736 551.165,65.4727 551.174,65.4717 551.183,65.4708 551.192,65.4698 551.201,65.4689 551.211,65.4679 551.22,65.467 551.229,65.466 551.238,65.465 551.247,65.4641 551.257,65.4631 551.266,65.4622 551.275,65.4612 551.284,65.4603 551.293,65.4593 551.303,65.4584 551.312,65.4574 551.321,65.4565 551.33,65.4555 551.339,65.4546 551.348,65.4536 551.358,65.4527 551.367,65.4517 551.376,65.4508 551.385,65.4498 551.394,65.4489 551.404,65.4479 551.413,65.447 551.422,65.446 551.431,65.4451 551.44,65.4441 551.45,65.4432 551.459,65.4422 551.468,65.4413 551.477,65.4403 551.486,65.4394 551.496,65.4384 551.505,65.4375 551.514,65.4365 551.523,65.4356 551.532,65.4346 551.541,65.4337 551.551,65.4327 551.56,65.4318 551.569,65.4308 551.578,65.4299 551.587,65.4289 551.597,65.428 551.606,65.427 551.615,65.4261 551.624,65.4252 551.633,65.4242 551.643,65.4233 551.652,65.4223 551.661,65.4214 551.67,65.4204 551.679,65.4195 551.688,65.4185 551.698,65.4176 551.707,65.4167 551.716,65.4157 551.725,65.4148 551.734,65.4138 551.744,65.4129 551.753,65.4119 551.762,65.411 551.771,65.4101 551.78,65.4091 551.79,65.4082 551.799,65.4072 551.808,65.4063 551.817,65.4054 551.826,65.4044 551.836,65.4035 551.845,65.4025 551.854,65.4016 551.863,65.4007 551.872,65.3997 551.881,65.3988 551.891,65.3978 551.9,65.3969 551.909,65.396 551.918,65.395 551.927,65.3941 551.937,65.3931 551.946,65.3922 551.955,65.3913 551.964,65.3903 551.973,65.3894 551.983,65.3885 551.992,65.3875 552.001,65.3866 552.01,65.3856 552.019,65.3847 552.028,65.3838 552.038,65.3828 552.047,65.3819 552.056,65.381 552.065,65.38 552.074,65.3791 552.084,65.3782 552.093,65.3772 552.102,65.3763 552.111,65.3754 552.12,65.3744 552.13,65.3735 552.139,65.3726 552.148,65.3716 552.157,65.3707 552.166,65.3698 552.176,65.3688 552.185,65.3679 552.194,65.367 552.203,65.366 552.212,65.3651 552.221,65.3642 552.231,65.3632 552.24,65.3623 552.249,65.3614 552.258,65.3605 552.267,65.3595 552.277,65.3586 552.286,65.3577 552.295,65.3567 552.304,65.3558 552.313,65.3549 552.323,65.3539 552.332,65.353 552.341,65.3521 552.35,65.3512 552.359,65.3502 552.368,65.3493 552.378,65.3484 552.387,65.3475 552.396,65.3465 552.405,65.3456 552.414,65.3447 552.424,65.3437 552.433,65.3428 552.442,65.3419 552.451,65.341 552.46,65.34 552.47,65.3391 552.479,65.3382 552.488,65.3373 552.497,65.3363 552.506,65.3354 552.516,65.3345 552.525,65.3336 552.534,65.3326 552.543,65.3317 552.552,65.3308 552.561,65.3299 552.571,65.329 552.58,65.328 552.589,65.3271 552.598,65.3262 552.607,65.3253 552.617,65.3243 552.626,65.3234 552.635,65.3225 552.644,65.3216 552.653,65.3207 552.663,65.3197 552.672,65.3188 552.681,65.3179 552.69,65.317 552.699,65.3161 552.708,65.3151 552.718,65.3142 552.727,65.3133 552.736,65.3124 552.745,65.3115 552.754,65.3105 552.764,65.3096 552.773,65.3087 552.782,65.3078 552.791,65.3069 552.8,65.3059 552.81,65.305 552.819,65.3041 552.828,65.3032 552.837,65.3023 552.846,65.3014 552.856,65.3004 552.865,65.2995 552.874,65.2986 552.883,65.2977 552.892,65.2968 552.901,65.2959 552.911,65.295 552.92,65.294 552.929,65.2931 552.938,65.2922 552.947,65.2913 552.957,65.2904 552.966,65.2895 552.975,65.2886 552.984,65.2876 552.993,65.2867 553.003,65.2858 553.012,65.2849 553.021,65.284 553.03,65.2831 553.039,65.2822 553.048,65.2813 553.058,65.2803 553.067,65.2794 553.076,65.2785 553.085,65.2776 553.094,65.2767 553.104,65.2758 553.113,65.2749 553.122,65.274 553.131,65.2731 553.14,65.2721 553.15,65.2712 553.159,65.2703 553.168,65.2694 553.177,65.2685 553.186,65.2676 553.196,65.2667 553.205,65.2658 553.214,65.2649 553.223,65.264 553.232,65.2631 553.241,65.2622 553.251,65.2612 553.26,65.2603 553.269,65.2594 553.278,65.2585 553.287,65.2576 553.297,65.2567 553.306,65.2558 553.315,65.2549 553.324,65.254 553.333,65.2531 553.343,65.2522 553.352,65.2513 553.361,65.2504 553.37,65.2495 553.379,65.2486 553.389,65.2477 553.398,65.2468 553.407,65.2459 553.416,65.245 553.425,65.2441 553.434,65.2432 553.444,65.2423 553.453,65.2413 553.462,65.2404 553.471,65.2395 553.48,65.2386 553.49,65.2377 553.499,65.2368 553.508,65.2359 553.517,65.235 553.526,65.2341 553.536,65.2332 553.545,65.2323 553.554,65.2314 553.563,65.2305 553.572,65.2296 553.581,65.2287 553.591,65.2278 553.6,65.2269 553.609,65.226 553.618,65.2251 553.627,65.2242 553.637,65.2234 553.646,65.2225 553.655,65.2216 553.664,65.2207 553.673,65.2198 553.683,65.2189 553.692,65.218 553.701,65.2171 553.71,65.2162 553.719,65.2153 553.729,65.2144 553.738,65.2135 553.747,65.2126 553.756,65.2117 553.765,65.2108 553.774,65.2099 553.784,65.209 553.793,65.2081 553.802,65.2072 553.811,65.2063 553.82,65.2054 553.83,65.2045 553.839,65.2037 553.848,65.2028 553.857,65.2019 553.866,65.201 553.876,65.2001 553.885,65.1992 553.894,65.1983 553.903,65.1974 553.912,65.1965 553.921,65.1956 553.931,65.1947 553.94,65.1938 553.949,65.193 553.958,65.1921 553.967,65.1912 553.977,65.1903 553.986,65.1894 553.995,65.1885 554.004,65.1876 554.013,65.1867 554.023,65.1858 554.032,65.1849 554.041,65.1841 554.05,65.1832 554.059,65.1823 554.069,65.1814 554.078,65.1805 554.087,65.1796 554.096,65.1787 554.105,65.1778 554.114,65.177 554.124,65.1761 554.133,65.1752 554.142,65.1743 554.151,65.1734 554.16,65.1725 554.17,65.1716 554.179,65.1708 554.188,65.1699 554.197,65.169 554.206,65.1681 554.216,65.1672 554.225,65.1663 554.234,65.1655 554.243,65.1646 554.252,65.1637 554.261,65.1628 554.271,65.1619 554.28,65.161 554.289,65.1602 554.298,65.1593 554.307,65.1584 554.317,65.1575 554.326,65.1566 554.335,65.1557 554.344,65.1549 554.353,65.154 554.363,65.1531 554.372,65.1522 554.381,65.1513 554.39,65.1505 554.399,65.1496 554.409,65.1487 554.418,65.1478 554.427,65.1469 554.436,65.1461 554.445,65.1452 554.454,65.1443 554.464,65.1434 554.473,65.1426 554.482,65.1417 554.491,65.1408 554.5,65.1399 554.51,65.139 554.519,65.1382 554.528,65.1373 554.537,65.1364 554.546,65.1355 554.556,65.1347 554.565,65.1338 554.574,65.1329 554.583,65.132 554.592,65.1312 554.601,65.1303 554.611,65.1294 554.62,65.1285 554.629,65.1277 554.638,65.1268 554.647,65.1259 554.657,65.125 554.666,65.1242 554.675,65.1233 554.684,65.1224 554.693,65.1215 554.703,65.1207 554.712,65.1198 554.721,65.1189 554.73,65.1181 554.739,65.1172 554.749,65.1163 554.758,65.1154 554.767,65.1146 554.776,65.1137 554.785,65.1128 554.794,65.112 554.804,65.1111 554.813,65.1102 554.822,65.1093 554.831,65.1085 554.84,65.1076 554.85,65.1067 554.859,65.1059 554.868,65.105 554.877,65.1041 554.886,65.1033 554.896,65.1024 554.905,65.1015 554.914,65.1007 554.923,65.0998 554.932,65.0989 554.941,65.0981 554.951,65.0972 554.96,65.0963 554.969,65.0955 554.978,65.0946 554.987,65.0937 554.997,65.0929 555.006,65.092 555.015,65.0911 555.024,65.0903 555.033,65.0894 555.043,65.0885 555.052,65.0877 555.061,65.0868 555.07,65.0859 555.079,65.0851 555.089,65.0842 555.098,65.0834 555.107,65.0825 555.116,65.0816 555.125,65.0808 555.134,65.0799 555.144,65.079 555.153,65.0782 555.162,65.0773 555.171,65.0765 555.18,65.0756 555.19,65.0747 555.199,65.0739 555.208,65.073 555.217,65.0722 555.226,65.0713 555.236,65.0704 555.245,65.0696 555.254,65.0687 555.263,65.0679 555.272,65.067 555.281,65.0661 555.291,65.0653 555.3,65.0644 555.309,65.0636 555.318,65.0627 555.327,65.0618 555.337,65.061 555.346,65.0601 555.355,65.0593 555.364,65.0584 555.373,65.0576 555.383,65.0567 555.392,65.0558 555.401,65.055 555.41,65.0541 555.419,65.0533 555.429,65.0524 555.438,65.0516 555.447,65.0507 555.456,65.0499 555.465,65.049 555.474,65.0481 555.484,65.0473 555.493,65.0464 555.502,65.0456 555.511,65.0447 555.52,65.0439 555.53,65.043 555.539,65.0422 555.548,65.0413 555.557,65.0405 555.566,65.0396 555.576,65.0388 555.585,65.0379 555.594,65.0371 555.603,65.0362 555.612,65.0354 555.621,65.0345 555.631,65.0337 555.64,65.0328 555.649,65.032 555.658,65.0311 555.667,65.0303 555.677,65.0294 555.686,65.0286 555.695,65.0277 555.704,65.0269 555.713,65.026 555.723,65.0252 555.732,65.0243 555.741,65.0235 555.75,65.0226 555.759,65.0218 555.769,65.0209 555.778,65.0201 555.787,65.0192 555.796,65.0184 555.805,65.0175 555.814,65.0167 555.824,65.0158 555.833,65.015 555.842,65.0142 555.851,65.0133 555.86,65.0125 555.87,65.0116 555.879,65.0108 555.888,65.0099 555.897,65.0091 555.906,65.0082 555.916,65.0074 555.925,65.0066 555.934,65.0057 555.943,65.0049 555.952,65.004 555.962,65.0032 555.971,65.0023 555.98,65.0015 555.989,65.0007 555.998,64.9998 556.007,64.999 556.017,64.9981 556.026,64.9973 556.035,64.9964 556.044,64.9956 556.053,64.9948 556.063,64.9939 556.072,64.9931 556.081,64.9922 556.09,64.9914 556.099,64.9906 556.109,64.9897 556.118,64.9889 556.127,64.988 556.136,64.9872 556.145,64.9864 556.154,64.9855 556.164,64.9847 556.173,64.9839 556.182,64.983 556.191,64.9822 556.2,64.9813 556.21,64.9805 556.219,64.9797 556.228,64.9788 556.237,64.978 556.246,64.9772 556.256,64.9763 556.265,64.9755 556.274,64.9747 556.283,64.9738 556.292,64.973 556.302,64.9722 556.311,64.9713 556.32,64.9705 556.329,64.9696 556.338,64.9688 556.347,64.968 556.357,64.9671 556.366,64.9663 556.375,64.9655 556.384,64.9646 556.393,64.9638 556.403,64.963 556.412,64.9622 556.421,64.9613 556.43,64.9605 556.439,64.9597 556.449,64.9588 556.458,64.958 556.467,64.9572 556.476,64.9563 556.485,64.9555 556.494,64.9547 556.504,64.9538 556.513,64.953 556.522,64.9522 556.531,64.9514 556.54,64.9505 556.55,64.9497 556.559,64.9489 556.568,64.948 556.577,64.9472 556.586,64.9464 556.596,64.9456 556.605,64.9447 556.614,64.9439 556.623,64.9431 556.632,64.9422 556.642,64.9414 556.651,64.9406 556.66,64.9398 556.669,64.9389 556.678,64.9381 556.687,64.9373 556.697,64.9365 556.706,64.9356 556.715,64.9348 556.724,64.934 556.733,64.9332 556.743,64.9323 556.752,64.9315 556.761,64.9307 556.77,64.9299 556.779,64.929 556.789,64.9282 556.798,64.9274 556.807,64.9266 556.816,64.9258 556.825,64.9249 556.834,64.9241 556.844,64.9233 556.853,64.9225 556.862,64.9216 556.871,64.9208 556.88,64.92 556.89,64.9192 556.899,64.9184 556.908,64.9175 556.917,64.9167 556.926,64.9159 556.936,64.9151 556.945,64.9143 556.954,64.9134 556.963,64.9126 556.972,64.9118 556.982,64.911 556.991,64.9102 557,64.9094 557.009,64.9085 557.018,64.9077 557.027,64.9069 557.037,64.9061 557.046,64.9053 557.055,64.9045 557.064,64.9036 557.073,64.9028 557.083,64.902 557.092,64.9012 557.101,64.9004 557.11,64.8996 557.119,64.8987 557.129,64.8979 557.138,64.8971 557.147,64.8963 557.156,64.8955 557.165,64.8947 557.174,64.8939 557.184,64.893 557.193,64.8922 557.202,64.8914 557.211,64.8906 557.22,64.8898 557.23,64.889 557.239,64.8882 557.248,64.8874 557.257,64.8865 557.266,64.8857 557.276,64.8849 557.285,64.8841 557.294,64.8833 557.303,64.8825 557.312,64.8817 557.322,64.8809 557.331,64.8801 557.34,64.8792 557.349,64.8784 557.358,64.8776 557.367,64.8768 557.377,64.876 557.386,64.8752 557.395,64.8744 557.404,64.8736 557.413,64.8728 557.423,64.872 557.432,64.8712 557.441,64.8704 557.45,64.8695 557.459,64.8687 557.469,64.8679 557.478,64.8671 557.487,64.8663 557.496,64.8655 557.505,64.8647 557.514,64.8639 557.524,64.8631 557.533,64.8623 557.542,64.8615 557.551,64.8607 557.56,64.8599 557.57,64.8591 557.579,64.8583 557.588,64.8575 557.597,64.8567 557.606,64.8559 557.616,64.8551 557.625,64.8542 557.634,64.8534 557.643,64.8526 557.652,64.8518 557.662,64.851 557.671,64.8502 557.68,64.8494 557.689,64.8486 557.698,64.8478 557.707,64.847 557.717,64.8462 557.726,64.8454 557.735,64.8446 557.744,64.8438 557.753,64.843 557.763,64.8422 557.772,64.8414 557.781,64.8406 557.79,64.8398 557.799,64.839 557.809,64.8382 557.818,64.8374 557.827,64.8366 557.836,64.8358 557.845,64.835 557.854,64.8342 557.864,64.8334 557.873,64.8326 557.882,64.8319 557.891,64.8311 557.9,64.8303 557.91,64.8295 557.919,64.8287 557.928,64.8279 557.937,64.8271 557.946,64.8263 557.956,64.8255 557.965,64.8247 557.974,64.8239 557.983,64.8231 557.992,64.8223 558.002,64.8215 558.011,64.8207 558.02,64.8199 558.029,64.8191 558.038,64.8183 558.047,64.8175 558.057,64.8168 558.066,64.816 558.075,64.8152 558.084,64.8144 558.093,64.8136 558.103,64.8128 558.112,64.812 558.121,64.8112 558.13,64.8104 558.139,64.8096 558.149,64.8088 558.158,64.808 558.167,64.8073 558.176,64.8065 558.185,64.8057 558.194,64.8049 558.204,64.8041 558.213,64.8033 558.222,64.8025 558.231,64.8017 558.24,64.8009 558.25,64.8002 558.259,64.7994 558.268,64.7986 558.277,64.7978 558.286,64.797 558.296,64.7962 558.305,64.7954 558.314,64.7946 558.323,64.7939 558.332,64.7931 558.342,64.7923 558.351,64.7915 558.36,64.7907 558.369,64.7899 558.378,64.7891 558.387,64.7884 558.397,64.7876 558.406,64.7868 558.415,64.786 558.424,64.7852 558.433,64.7844 558.443,64.7837 558.452,64.7829 558.461,64.7821 558.47,64.7813 558.479,64.7805 558.489,64.7797 558.498,64.779 558.507,64.7782 558.516,64.7774 558.525,64.7766 558.535,64.7758 558.544,64.7751 558.553,64.7743 558.562,64.7735 558.571,64.7727 558.58,64.7719 558.59,64.7712 558.599,64.7704 558.608,64.7696 558.617,64.7688 558.626,64.768 558.636,64.7673 558.645,64.7665 558.654,64.7657 558.663,64.7649 558.672,64.7641 558.682,64.7634 558.691,64.7626 558.7,64.7618 558.709,64.761 558.718,64.7603 558.727,64.7595 558.737,64.7587 558.746,64.7579 558.755,64.7572 558.764,64.7564 558.773,64.7556 558.783,64.7548 558.792,64.7541 558.801,64.7533 558.81,64.7525 558.819,64.7517 558.829,64.751 558.838,64.7502 558.847,64.7494 558.856,64.7486 558.865,64.7479 558.875,64.7471 558.884,64.7463 558.893,64.7455 558.902,64.7448 558.911,64.744 558.92,64.7432 558.93,64.7425 558.939,64.7417 558.948,64.7409 558.957,64.7401 558.966,64.7394 558.976,64.7386 558.985,64.7378 558.994,64.7371 559.003,64.7363 559.012,64.7355 559.022,64.7348 559.031,64.734 559.04,64.7332 559.049,64.7324 559.058,64.7317 559.067,64.7309 559.077,64.7301 559.086,64.7294 559.095,64.7286 559.104,64.7278 559.113,64.7271 559.123,64.7263 559.132,64.7255 559.141,64.7248 559.15,64.724 559.159,64.7232 559.169,64.7225 559.178,64.7217 559.187,64.7209 559.196,64.7202 559.205,64.7194 559.215,64.7186 559.224,64.7179 559.233,64.7171 559.242,64.7164 559.251,64.7156 559.26,64.7148 559.27,64.7141 559.279,64.7133 559.288,64.7125 559.297,64.7118 559.306,64.711 559.316,64.7102 559.325,64.7095 559.334,64.7087 559.343,64.708 559.352,64.7072 559.362,64.7064 559.371,64.7057 559.38,64.7049 559.389,64.7042 559.398,64.7034 559.407,64.7026 559.417,64.7019 559.426,64.7011 559.435,64.7004 559.444,64.6996 559.453,64.6988 559.463,64.6981 559.472,64.6973 559.481,64.6966 559.49,64.6958 559.499,64.695 559.509,64.6943 559.518,64.6935 559.527,64.6928 559.536,64.692 559.545,64.6913 559.555,64.6905 559.564,64.6897 559.573,64.689 559.582,64.6882 559.591,64.6875 559.6,64.6867 559.61,64.686 559.619,64.6852 559.628,64.6845 559.637,64.6837 559.646,64.683 559.656,64.6822 559.665,64.6814 559.674,64.6807 559.683,64.6799 559.692,64.6792 559.702,64.6784 559.711,64.6777 559.72,64.6769 559.729,64.6762 559.738,64.6754 559.747,64.6747 559.757,64.6739 559.766,64.6732 559.775,64.6724 559.784,64.6717 559.793,64.6709 559.803,64.6702 559.812,64.6694 559.821,64.6687 559.83,64.6679 559.839,64.6672 559.849,64.6664 559.858,64.6657 559.867,64.6649 559.876,64.6642 559.885,64.6634 559.895,64.6627 559.904,64.6619 559.913,64.6612 559.922,64.6604 559.931,64.6597 559.94,64.6589 559.95,64.6582 559.959,64.6574 559.968,64.6567 559.977,64.6559 559.986,64.6552 559.996,64.6545 560.005,64.6537 560.014,64.653 560.023,64.6522 560.032,64.6515 560.042,64.6507 560.051,64.65 560.06,64.6492 560.069,64.6485 560.078,64.6478 560.087,64.647 560.097,64.6463 560.106,64.6455 560.115,64.6448 560.124,64.644 560.133,64.6433 560.143,64.6425 560.152,64.6418 560.161,64.6411 560.17,64.6403 560.179,64.6396 560.189,64.6388 560.198,64.6381 560.207,64.6374 560.216,64.6366 560.225,64.6359 560.235,64.6351 560.244,64.6344 560.253,64.6337 560.262,64.6329 560.271,64.6322 560.28,64.6314 560.29,64.6307 560.299,64.63 560.308,64.6292 560.317,64.6285 560.326,64.6278 560.336,64.627 560.345,64.6263 560.354,64.6255 560.363,64.6248 560.372,64.6241 560.382,64.6233 560.391,64.6226 560.4,64.6219 560.409,64.6211 560.418,64.6204 560.427,64.6197 560.437,64.6189 560.446,64.6182 560.455,64.6174 560.464,64.6167 560.473,64.616 560.483,64.6152 560.492,64.6145 560.501,64.6138 560.51,64.613 560.519,64.6123 560.529,64.6116 560.538,64.6108 560.547,64.6101 560.556,64.6094 560.565,64.6086 560.575,64.6079 560.584,64.6072 560.593,64.6065 560.602,64.6057 560.611,64.605 560.62,64.6043 560.63,64.6035 560.639,64.6028 560.648,64.6021 560.657,64.6013 560.666,64.6006 560.676,64.5999 560.685,64.5992 560.694,64.5984 560.703,64.5977 560.712,64.597 560.722,64.5962 560.731,64.5955 560.74,64.5948 560.749,64.5941 560.758,64.5933 560.768,64.5926 560.777,64.5919 560.786,64.5911 560.795,64.5904 560.804,64.5897 560.813,64.589 560.823,64.5882 560.832,64.5875 560.841,64.5868 560.85,64.5861 560.859,64.5853 560.869,64.5846 560.878,64.5839 560.887,64.5832 560.896,64.5824 560.905,64.5817 560.915,64.581 560.924,64.5803 560.933,64.5796 560.942,64.5788 560.951,64.5781 560.96,64.5774 560.97,64.5767 560.979,64.5759 560.988,64.5752 560.997,64.5745 561.006,64.5738 561.016,64.5731 561.025,64.5723 561.034,64.5716 561.043,64.5709 561.052,64.5702 561.062,64.5695 561.071,64.5687 561.08,64.568 561.089,64.5673 561.098,64.5666 561.108,64.5659 561.117,64.5651 561.126,64.5644 561.135,64.5637 561.144,64.563 561.153,64.5623 561.163,64.5616 561.172,64.5608 561.181,64.5601 561.19,64.5594 561.199,64.5587 561.209,64.558 561.218,64.5573 561.227,64.5565 561.236,64.5558 561.245,64.5551 561.255,64.5544 561.264,64.5537 561.273,64.553 561.282,64.5522 561.291,64.5515 561.3,64.5508 561.31,64.5501 561.319,64.5494 561.328,64.5487 561.337,64.548 561.346,64.5473 561.356,64.5465 561.365,64.5458 561.374,64.5451 561.383,64.5444 561.392,64.5437 561.402,64.543 561.411,64.5423 561.42,64.5416 561.429,64.5408 561.438,64.5401 561.448,64.5394 561.457,64.5387 561.466,64.538 561.475,64.5373 561.484,64.5366 561.493,64.5359 561.503,64.5352 561.512,64.5345 561.521,64.5338 561.53,64.533 561.539,64.5323 561.549,64.5316 561.558,64.5309 561.567,64.5302 561.576,64.5295 561.585,64.5288 561.595,64.5281 561.604,64.5274 561.613,64.5267 561.622,64.526 561.631,64.5253 561.64,64.5246 561.65,64.5239 561.659,64.5232 561.668,64.5224 561.677,64.5217 561.686,64.521 561.696,64.5203 561.705,64.5196 561.714,64.5189 561.723,64.5182 561.732,64.5175 561.742,64.5168 561.751,64.5161 561.76,64.5154 561.769,64.5147 561.778,64.514 561.788,64.5133 561.797,64.5126 561.806,64.5119 561.815,64.5112 561.824,64.5105 561.833,64.5098 561.843,64.5091 561.852,64.5084 561.861,64.5077 561.87,64.507 561.879,64.5063 561.889,64.5056 561.898,64.5049 561.907,64.5042 561.916,64.5035 561.925,64.5028 561.935,64.5021 561.944,64.5014 561.953,64.5007 561.962,64.5 561.971,64.4993 561.98,64.4986 561.99,64.4979 561.999,64.4972 562.008,64.4965 562.017,64.4958 562.026,64.4951 562.036,64.4944 562.045,64.4937 562.054,64.493 562.063,64.4924 562.072,64.4917 562.082,64.491 562.091,64.4903 562.1,64.4896 562.109,64.4889 562.118,64.4882 562.128,64.4875 562.137,64.4868 562.146,64.4861 562.155,64.4854 562.164,64.4847 562.173,64.484 562.183,64.4833 562.192,64.4826 562.201,64.482 562.21,64.4813 562.219,64.4806 562.229,64.4799 562.238,64.4792 562.247,64.4785 562.256,64.4778 562.265,64.4771 562.275,64.4764 562.284,64.4757 562.293,64.475 562.302,64.4744 562.311,64.4737 562.32,64.473 562.33,64.4723 562.339,64.4716 562.348,64.4709 562.357,64.4702 562.366,64.4695 562.376,64.4689 562.385,64.4682 562.394,64.4675 562.403,64.4668 562.412,64.4661 562.422,64.4654 562.431,64.4647 562.44,64.464 562.449,64.4634 562.458,64.4627 562.468,64.462 562.477,64.4613 562.486,64.4606 562.495,64.4599 562.504,64.4593 562.513,64.4586 562.523,64.4579 562.532,64.4572 562.541,64.4565 562.55,64.4558 562.559,64.4551 562.569,64.4545 562.578,64.4538 562.587,64.4531 562.596,64.4524 562.605,64.4517 562.615,64.4511 562.624,64.4504 562.633,64.4497 562.642,64.449 562.651,64.4483 562.66,64.4477 562.67,64.447 562.679,64.4463 562.688,64.4456 562.697,64.4449 562.706,64.4443 562.716,64.4436 562.725,64.4429 562.734,64.4422 562.743,64.4415 562.752,64.4409 562.762,64.4402 562.771,64.4395 562.78,64.4388 562.789,64.4382 562.798,64.4375 562.808,64.4368 562.817,64.4361 562.826,64.4354 562.835,64.4348 562.844,64.4341 562.853,64.4334 562.863,64.4327 562.872,64.4321 562.881,64.4314 562.89,64.4307 562.899,64.43 562.909,64.4294 562.918,64.4287 562.927,64.428 562.936,64.4273 562.945,64.4267 562.955,64.426 562.964,64.4253 562.973,64.4247 562.982,64.424 562.991,64.4233 563,64.4226 563.01,64.422 563.019,64.4213 563.028,64.4206 563.037,64.42 563.046,64.4193 563.056,64.4186 563.065,64.4179 563.074,64.4173 563.083,64.4166 563.092,64.4159 563.102,64.4153 563.111,64.4146 563.12,64.4139 563.129,64.4133 563.138,64.4126 563.148,64.4119 563.157,64.4113 563.166,64.4106 563.175,64.4099 563.184,64.4092 563.193,64.4086 563.203,64.4079 563.212,64.4072 563.221,64.4066 563.23,64.4059 563.239,64.4052 563.249,64.4046 563.258,64.4039 563.267,64.4033 563.276,64.4026 563.285,64.4019 563.295,64.4013 563.304,64.4006 563.313,64.3999 563.322,64.3993 563.331,64.3986 563.341,64.3979 563.35,64.3973 563.359,64.3966 563.368,64.396 563.377,64.3953 563.386,64.3946 563.396,64.394 563.405,64.3933 563.414,64.3926 563.423,64.392 563.432,64.3913 563.442,64.3907 563.451,64.39 563.46,64.3893 563.469,64.3887 563.478,64.388 563.488,64.3874 563.497,64.3867 563.506,64.386 563.515,64.3854 563.524,64.3847 563.533,64.3841 563.543,64.3834 563.552,64.3827 563.561,64.3821 563.57,64.3814 563.579,64.3808 563.589,64.3801 563.598,64.3795 563.607,64.3788 563.616,64.3781 563.625,64.3775 563.635,64.3768 563.644,64.3762 563.653,64.3755 563.662,64.3749 563.671,64.3742 563.681,64.3736 563.69,64.3729 563.699,64.3722 563.708,64.3716 563.717,64.3709 563.726,64.3703 563.736,64.3696 563.745,64.369 563.754,64.3683 563.763,64.3677 563.772,64.367 563.782,64.3664 563.791,64.3657 563.8,64.3651 563.809,64.3644 563.818,64.3638 563.828,64.3631 563.837,64.3625 563.846,64.3618 563.855,64.3612 563.864,64.3605 563.873,64.3599 563.883,64.3592 563.892,64.3586 563.901,64.3579 563.91,64.3573 563.919,64.3566 563.929,64.356 563.938,64.3553 563.947,64.3547 563.956,64.354 563.965,64.3534 563.975,64.3527 563.984,64.3521 563.993,64.3514 564.002,64.3508 564.011,64.3501 564.021,64.3495 564.03,64.3488 564.039,64.3482 564.048,64.3475 564.057,64.3469 564.066,64.3463 564.076,64.3456 564.085,64.345 564.094,64.3443 564.103,64.3437 564.112,64.343 564.122,64.3424 564.131,64.3417 564.14,64.3411 564.149,64.3405 564.158,64.3398 564.168,64.3392 564.177,64.3385 564.186,64.3379 564.195,64.3372 564.204,64.3366 564.213,64.336 564.223,64.3353 564.232,64.3347 564.241,64.334 564.25,64.3334 564.259,64.3328 564.269,64.3321 564.278,64.3315 564.287,64.3308 564.296,64.3302 564.305,64.3296 564.315,64.3289 564.324,64.3283 564.333,64.3276 564.342,64.327 564.351,64.3264 564.361,64.3257 564.37,64.3251 564.379,64.3245 564.388,64.3238 564.397,64.3232 564.406,64.3225 564.416,64.3219 564.425,64.3213 564.434,64.3206 564.443,64.32 564.452,64.3194 564.462,64.3187 564.471,64.3181 564.48,64.3175 564.489,64.3168 564.498,64.3162 564.508,64.3156 564.517,64.3149 564.526,64.3143 564.535,64.3137 564.544,64.313 564.553,64.3124 564.563,64.3118 564.572,64.3111 564.581,64.3105 564.59,64.3099 564.599,64.3092 564.609,64.3086 564.618,64.308 564.627,64.3073 564.636,64.3067 564.645,64.3061 564.655,64.3054 564.664,64.3048 564.673,64.3042 564.682,64.3036 564.691,64.3029 564.701,64.3023 564.71,64.3017 564.719,64.301 564.728,64.3004 564.737,64.2998 564.746,64.2992 564.756,64.2985 564.765,64.2979 564.774,64.2973 564.783,64.2966 564.792,64.296 564.802,64.2954 564.811,64.2948 564.82,64.2941 564.829,64.2935 564.838,64.2929 564.848,64.2923 564.857,64.2916 564.866,64.291 564.875,64.2904 564.884,64.2898 564.893,64.2891 564.903,64.2885 564.912,64.2879 564.921,64.2873 564.93,64.2866 564.939,64.286 564.949,64.2854 564.958,64.2848 564.967,64.2841 564.976,64.2835 564.985,64.2829 564.995,64.2823 565.004,64.2817 565.013,64.281 565.022,64.2804 565.031,64.2798 565.041,64.2792 565.05,64.2786 565.059,64.2779 565.068,64.2773 565.077,64.2767 565.086,64.2761 565.096,64.2755 565.105,64.2748 565.114,64.2742 565.123,64.2736 565.132,64.273 565.142,64.2724 565.151,64.2717 565.16,64.2711 565.169,64.2705 565.178,64.2699 565.188,64.2693 565.197,64.2687 565.206,64.268 565.215,64.2674 565.224,64.2668 565.233,64.2662 565.243,64.2656 565.252,64.265 565.261,64.2644 565.27,64.2637 565.279,64.2631 565.289,64.2625 565.298,64.2619 565.307,64.2613 565.316,64.2607 565.325,64.2601 565.335,64.2594 565.344,64.2588 565.353,64.2582 565.362,64.2576 565.371,64.257 565.381,64.2564 565.39,64.2558 565.399,64.2552 565.408,64.2545 565.417,64.2539 565.426,64.2533 565.436,64.2527 565.445,64.2521 565.454,64.2515 565.463,64.2509 565.472,64.2503 565.482,64.2497 565.491,64.2491 565.5,64.2484 565.509,64.2478 565.518,64.2472 565.528,64.2466 565.537,64.246 565.546,64.2454 565.555,64.2448 565.564,64.2442 565.573,64.2436 565.583,64.243 565.592,64.2424 565.601,64.2418 565.61,64.2412 565.619,64.2405 565.629,64.2399 565.638,64.2393 565.647,64.2387 565.656,64.2381 565.665,64.2375 565.675,64.2369 565.684,64.2363 565.693,64.2357 565.702,64.2351 565.711,64.2345 565.721,64.2339 565.73,64.2333 565.739,64.2327 565.748,64.2321 565.757,64.2315 565.766,64.2309 565.776,64.2303 565.785,64.2297 565.794,64.2291 565.803,64.2285 565.812,64.2279 565.822,64.2273 565.831,64.2267 565.84,64.2261 565.849,64.2255 565.858,64.2249 565.868,64.2243 565.877,64.2237 565.886,64.2231 565.895,64.2225 565.904,64.2219 565.914,64.2213 565.923,64.2207 565.932,64.2201 565.941,64.2195 565.95,64.2189 565.959,64.2183 565.969,64.2177 565.978,64.2171 565.987,64.2165 565.996,64.2159 566.005,64.2153 566.015,64.2147 566.024,64.2141 566.033,64.2135 566.042,64.2129 566.051,64.2123 566.061,64.2117 566.07,64.2112 566.079,64.2106 566.088,64.21 566.097,64.2094 566.106,64.2088 566.116,64.2082 566.125,64.2076 566.134,64.207 566.143,64.2064 566.152,64.2058 566.162,64.2052 566.171,64.2046 566.18,64.204 566.189,64.2034 566.198,64.2029 566.208,64.2023 566.217,64.2017 566.226,64.2011 566.235,64.2005 566.244,64.1999 566.254,64.1993 566.263,64.1987 566.272,64.1981 566.281,64.1975 566.29,64.197 566.299,64.1964 566.309,64.1958 566.318,64.1952 566.327,64.1946 566.336,64.194 566.345,64.1934 566.355,64.1928 566.364,64.1923 566.373,64.1917 566.382,64.1911 566.391,64.1905 566.401,64.1899 566.41,64.1893 566.419,64.1887 566.428,64.1882 566.437,64.1876 566.446,64.187 566.456,64.1864 566.465,64.1858 566.474,64.1852 566.483,64.1847 566.492,64.1841 566.502,64.1835 566.511,64.1829 566.52,64.1823 566.529,64.1817 566.538,64.1812 566.548,64.1806 566.557,64.18 566.566,64.1794 566.575,64.1788 566.584,64.1783 566.594,64.1777 566.603,64.1771 566.612,64.1765 566.621,64.1759 566.63,64.1753 566.639,64.1748 566.649,64.1742 566.658,64.1736 566.667,64.173 566.676,64.1725 566.685,64.1719 566.695,64.1713 566.704,64.1707 566.713,64.1701 566.722,64.1696 566.731,64.169 566.741,64.1684 566.75,64.1678 566.759,64.1673 566.768,64.1667 566.777,64.1661 566.786,64.1655 566.796,64.165 566.805,64.1644 566.814,64.1638 566.823,64.1632 566.832,64.1627 566.842,64.1621 566.851,64.1615 566.86,64.1609 566.869,64.1604 566.878,64.1598 566.888,64.1592 566.897,64.1586 566.906,64.1581 566.915,64.1575 566.924,64.1569 566.934,64.1563 566.943,64.1558 566.952,64.1552 566.961,64.1546 566.97,64.1541 566.979,64.1535 566.989,64.1529 566.998,64.1524 567.007,64.1518 567.016,64.1512 567.025,64.1506 567.035,64.1501 567.044,64.1495 567.053,64.1489 567.062,64.1484 567.071,64.1478 567.081,64.1472 567.09,64.1467 567.099,64.1461 567.108,64.1455 567.117,64.145 567.126,64.1444 567.136,64.1438 567.145,64.1433 567.154,64.1427 567.163,64.1421 567.172,64.1416 567.182,64.141 567.191,64.1404 567.2,64.1399 567.209,64.1393 567.218,64.1387 567.228,64.1382 567.237,64.1376 567.246,64.137 567.255,64.1365 567.264,64.1359 567.274,64.1354 567.283,64.1348 567.292,64.1342 567.301,64.1337 567.31,64.1331 567.319,64.1325 567.329,64.132 567.338,64.1314 567.347,64.1309 567.356,64.1303 567.365,64.1297 567.375,64.1292 567.384,64.1286 567.393,64.1281 567.402,64.1275 567.411,64.1269 567.421,64.1264 567.43,64.1258 567.439,64.1253 567.448,64.1247 567.457,64.1241 567.466,64.1236 567.476,64.123 567.485,64.1225 567.494,64.1219 567.503,64.1214 567.512,64.1208 567.522,64.1202 567.531,64.1197 567.54,64.1191 567.549,64.1186 567.558,64.118 567.568,64.1175 567.577,64.1169 567.586,64.1164 567.595,64.1158 567.604,64.1152 567.614,64.1147 567.623,64.1141 567.632,64.1136 567.641,64.113 567.65,64.1125 567.659,64.1119 567.669,64.1114 567.678,64.1108 567.687,64.1103 567.696,64.1097 567.705,64.1092 567.715,64.1086 567.724,64.1081 567.733,64.1075 567.742,64.107 567.751,64.1064 567.761,64.1059 567.77,64.1053 567.779,64.1048 567.788,64.1042 567.797,64.1037 567.806,64.1031 567.816,64.1026 567.825,64.102 567.834,64.1015 567.843,64.1009 567.852,64.1004 567.862,64.0998 567.871,64.0993 567.88,64.0987 567.889,64.0982 567.898,64.0976 567.908,64.0971 567.917,64.0965 567.926,64.096 567.935,64.0954 567.944,64.0949 567.954,64.0944 567.963,64.0938 567.972,64.0933 567.981,64.0927 567.99,64.0922 567.999,64.0916 568.009,64.0911 568.018,64.0905 568.027,64.09 568.036,64.0895 568.045,64.0889 568.055,64.0884 568.064,64.0878 568.073,64.0873 568.082,64.0867 568.091,64.0862 568.101,64.0857 568.11,64.0851 568.119,64.0846 568.128,64.084 568.137,64.0835 568.147,64.083 568.156,64.0824 568.165,64.0819 568.174,64.0813 568.183,64.0808 568.192,64.0803 568.202,64.0797 568.211,64.0792 568.22,64.0786 568.229,64.0781 568.238,64.0776 568.248,64.077 568.257,64.0765 568.266,64.076 568.275,64.0754 568.284,64.0749 568.294,64.0743 568.303,64.0738 568.312,64.0733 568.321,64.0727 568.33,64.0722 568.339,64.0717 568.349,64.0711 568.358,64.0706 568.367,64.0701 568.376,64.0695 568.385,64.069 568.395,64.0685 568.404,64.0679 568.413,64.0674 568.422,64.0669 568.431,64.0663 568.441,64.0658 568.45,64.0653 568.459,64.0647 568.468,64.0642 568.477,64.0637 568.487,64.0631 568.496,64.0626 568.505,64.0621 568.514,64.0616 568.523,64.061 568.532,64.0605 568.542,64.06 568.551,64.0594 568.56,64.0589 568.569,64.0584 568.578,64.0578 568.588,64.0573 568.597,64.0568 568.606,64.0563 568.615,64.0557 568.624,64.0552 568.634,64.0547 568.643,64.0541 568.652,64.0536 568.661,64.0531 568.67,64.0526 568.679,64.052 568.689,64.0515 568.698,64.051 568.707,64.0505 568.716,64.0499 568.725,64.0494 568.735,64.0489 568.744,64.0484 568.753,64.0478 568.762,64.0473 568.771,64.0468 568.781,64.0463 568.79,64.0458 568.799,64.0452 568.808,64.0447 568.817,64.0442 568.827,64.0437 568.836,64.0431 568.845,64.0426 568.854,64.0421 568.863,64.0416 568.872,64.0411 568.882,64.0405 568.891,64.04 568.9,64.0395 568.909,64.039 568.918,64.0385 568.928,64.0379 568.937,64.0374 568.946,64.0369 568.955,64.0364 568.964,64.0359 568.974,64.0353 568.983,64.0348 568.992,64.0343 569.001,64.0338 569.01,64.0333 569.019,64.0328 569.029,64.0322 569.038,64.0317 569.047,64.0312 569.056,64.0307 569.065,64.0302 569.075,64.0297 569.084,64.0291 569.093,64.0286 569.102,64.0281 569.111,64.0276 569.121,64.0271 569.13,64.0266 569.139,64.0261 569.148,64.0255 569.157,64.025 569.167,64.0245 569.176,64.024 569.185,64.0235 569.194,64.023 569.203,64.0225 569.212,64.022 569.222,64.0214 569.231,64.0209 569.24,64.0204 569.249,64.0199 569.258,64.0194 569.268,64.0189 569.277,64.0184 569.286,64.0179 569.295,64.0174 569.304,64.0168 569.314,64.0163 569.323,64.0158 569.332,64.0153 569.341,64.0148 569.35,64.0143 569.359,64.0138 569.369,64.0133 569.378,64.0128 569.387,64.0123 569.396,64.0118 569.405,64.0113 569.415,64.0108 569.424,64.0102 569.433,64.0097 569.442,64.0092 569.451,64.0087 569.461,64.0082 569.47,64.0077 569.479,64.0072 569.488,64.0067 569.497,64.0062 569.507,64.0057 569.516,64.0052 569.525,64.0047 569.534,64.0042 569.543,64.0037 569.552,64.0032 569.562,64.0027 569.571,64.0022 569.58,64.0017 569.589,64.0012 569.598,64.0007 569.608,64.0002 569.617,63.9997 569.626,63.9992 569.635,63.9987 569.644,63.9982 569.654,63.9977 569.663,63.9972 569.672,63.9967 569.681,63.9962 569.69,63.9957 569.699,63.9952 569.709,63.9947 569.718,63.9942 569.727,63.9937 569.736,63.9932 569.745,63.9927 569.755,63.9922 569.764,63.9917 569.773,63.9912 569.782,63.9907 569.791,63.9902 569.801,63.9897 569.81,63.9892 569.819,63.9887 569.828,63.9882 569.837,63.9877 569.847,63.9872 569.856,63.9867 569.865,63.9862 569.874,63.9858 569.883,63.9853 569.892,63.9848 569.902,63.9843 569.911,63.9838 569.92,63.9833 569.929,63.9828 569.938,63.9823 569.948,63.9818 569.957,63.9813 569.966,63.9808 569.975,63.9803 569.984,63.9798 569.994,63.9794 570.003,63.9789 570.012,63.9784 570.021,63.9779 570.03,63.9774 570.039,63.9769 570.049,63.9764 570.058,63.9759 570.067,63.9754 570.076,63.9749 570.085,63.9745 570.095,63.974 570.104,63.9735 570.113,63.973 570.122,63.9725 570.131,63.972 570.141,63.9715 570.15,63.971 570.159,63.9706 570.168,63.9701 570.177,63.9696 570.187,63.9691 570.196,63.9686 570.205,63.9681 570.214,63.9676 570.223,63.9672 570.232,63.9667 570.242,63.9662 570.251,63.9657 570.26,63.9652 570.269,63.9647 570.278,63.9643 570.288,63.9638 570.297,63.9633 570.306,63.9628 570.315,63.9623 570.324,63.9619 570.334,63.9614 570.343,63.9609 570.352,63.9604 570.361,63.9599 570.37,63.9594 570.379,63.959 570.389,63.9585 570.398,63.958 570.407,63.9575 570.416,63.957 570.425,63.9566 570.435,63.9561 570.444,63.9556 570.453,63.9551 570.462,63.9547 570.471,63.9542 570.481,63.9537 570.49,63.9532 570.499,63.9527 570.508,63.9523 570.517,63.9518 570.527,63.9513 570.536,63.9508 570.545,63.9504 570.554,63.9499 570.563,63.9494 570.572,63.9489 570.582,63.9485 570.591,63.948 570.6,63.9475 570.609,63.947 570.618,63.9466 570.628,63.9461 570.637,63.9456 570.646,63.9451 570.655,63.9447 570.664,63.9442 570.674,63.9437 570.683,63.9433 570.692,63.9428 570.701,63.9423 570.71,63.9418 570.72,63.9414 570.729,63.9409 570.738,63.9404 570.747,63.94 570.756,63.9395 570.765,63.939 570.775,63.9386 570.784,63.9381 570.793,63.9376 570.802,63.9371 570.811,63.9367 570.821,63.9362 570.83,63.9357 570.839,63.9353 570.848,63.9348 570.857,63.9343 570.867,63.9339 570.876,63.9334 570.885,63.9329 570.894,63.9325 570.903,63.932 570.912,63.9315 570.922,63.9311 570.931,63.9306 570.94,63.9301 570.949,63.9297 570.958,63.9292 570.968,63.9288 570.977,63.9283 570.986,63.9278 570.995,63.9274 571.004,63.9269 571.014,63.9264 571.023,63.926 571.032,63.9255 571.041,63.925 571.05,63.9246 571.06,63.9241 571.069,63.9237 571.078,63.9232 571.087,63.9227 571.096,63.9223 571.105,63.9218 571.115,63.9214 571.124,63.9209 571.133,63.9204 571.142,63.92 571.151,63.9195 571.161,63.9191 571.17,63.9186 571.179,63.9181 571.188,63.9177 571.197,63.9172 571.207,63.9168 571.216,63.9163 571.225,63.9159 571.234,63.9154 571.243,63.9149 571.252,63.9145 571.262,63.914 571.271,63.9136 571.28,63.9131 571.289,63.9127 571.298,63.9122 571.308,63.9118 571.317,63.9113 571.326,63.9108 571.335,63.9104 571.344,63.9099 571.354,63.9095 571.363,63.909 571.372,63.9086 571.381,63.9081 571.39,63.9077 571.4,63.9072 571.409,63.9068 571.418,63.9063 571.427,63.9059 571.436,63.9054 571.445,63.905 571.455,63.9045 571.464,63.9041 571.473,63.9036 571.482,63.9032 571.491,63.9027 571.501,63.9023 571.51,63.9018 571.519,63.9014 571.528,63.9009 571.537,63.9005 571.547,63.9 571.556,63.8996 571.565,63.8991 571.574,63.8987 571.583,63.8982 571.592,63.8978 571.602,63.8973 571.611,63.8969 571.62,63.8964 571.629,63.896 571.638,63.8956 571.648,63.8951 571.657,63.8947 571.666,63.8942 571.675,63.8938 571.684,63.8933 571.694,63.8929 571.703,63.8924 571.712,63.892 571.721,63.8916 571.73,63.8911 571.74,63.8907 571.749,63.8902 571.758,63.8898 571.767,63.8893 571.776,63.8889 571.785,63.8885 571.795,63.888 571.804,63.8876 571.813,63.8871 571.822,63.8867 571.831,63.8863 571.841,63.8858 571.85,63.8854 571.859,63.8849 571.868,63.8845 571.877,63.8841 571.887,63.8836 571.896,63.8832 571.905,63.8827 571.914,63.8823 571.923,63.8819 571.932,63.8814 571.942,63.881 571.951,63.8806 571.96,63.8801 571.969,63.8797 571.978,63.8793 571.988,63.8788 571.997,63.8784 572.006,63.8779 572.015,63.8775 572.024,63.8771 572.034,63.8766 572.043,63.8762 572.052,63.8758 572.061,63.8753 572.07,63.8749 572.08,63.8745 572.089,63.874 572.098,63.8736 572.107,63.8732 572.116,63.8727 572.125,63.8723 572.135,63.8719 572.144,63.8714 572.153,63.871 572.162,63.8706 572.171,63.8702 572.181,63.8697 572.19,63.8693 572.199,63.8689 572.208,63.8684 572.217,63.868 572.227,63.8676 572.236,63.8671 572.245,63.8667 572.254,63.8663 572.263,63.8659 572.272,63.8654 572.282,63.865 572.291,63.8646 572.3,63.8642 572.309,63.8637 572.318,63.8633 572.328,63.8629 572.337,63.8624 572.346,63.862 572.355,63.8616 572.364,63.8612 572.374,63.8607 572.383,63.8603 572.392,63.8599 572.401,63.8595 572.41,63.859 572.42,63.8586 572.429,63.8582 572.438,63.8578 572.447,63.8574 572.456,63.8569 572.465,63.8565 572.475,63.8561 572.484,63.8557 572.493,63.8552 572.502,63.8548 572.511,63.8544 572.521,63.854 572.53,63.8536 572.539,63.8531 572.548,63.8527 572.557,63.8523 572.567,63.8519 572.576,63.8515 572.585,63.851 572.594,63.8506 572.603,63.8502 572.612,63.8498 572.622,63.8494 572.631,63.849 572.64,63.8485 572.649,63.8481 572.658,63.8477 572.668,63.8473 572.677,63.8469 572.686,63.8465 572.695,63.846 572.704,63.8456 572.714,63.8452 572.723,63.8448 572.732,63.8444 572.741,63.844 572.75,63.8435 572.76,63.8431 572.769,63.8427 572.778,63.8423 572.787,63.8419 572.796,63.8415 572.805,63.8411 572.815,63.8407 572.824,63.8402 572.833,63.8398 572.842,63.8394 572.851,63.839 572.861,63.8386 572.87,63.8382 572.879,63.8378 572.888,63.8374 572.897,63.837 572.907,63.8365 572.916,63.8361 572.925,63.8357 572.934,63.8353 572.943,63.8349 572.952,63.8345 572.962,63.8341 572.971,63.8337 572.98,63.8333 572.989,63.8329 572.998,63.8325 573.008,63.8321 573.017,63.8316 573.026,63.8312 573.035,63.8308 573.044,63.8304 573.054,63.83 573.063,63.8296 573.072,63.8292 573.081,63.8288 573.09,63.8284 573.1,63.828 573.109,63.8276 573.118,63.8272 573.127,63.8268 573.136,63.8264 573.145,63.826 573.155,63.8256 573.164,63.8252 573.173,63.8248 573.182,63.8244 573.191,63.824 573.201,63.8236 573.21,63.8232 573.219,63.8228 573.228,63.8224 573.237,63.822 573.247,63.8216 573.256,63.8212 573.265,63.8208 573.274,63.8204 573.283,63.82 573.293,63.8196 573.302,63.8192 573.311,63.8188 573.32,63.8184 573.329,63.818 573.338,63.8176 573.348,63.8172 573.357,63.8168 573.366,63.8164 573.375,63.816 573.384,63.8156 573.394,63.8152 573.403,63.8148 573.412,63.8144 573.421,63.814 573.43,63.8136 573.44,63.8132 573.449,63.8128 573.458,63.8124 573.467,63.812 573.476,63.8116 573.485,63.8113 573.495,63.8109 573.504,63.8105 573.513,63.8101 573.522,63.8097 573.531,63.8093 573.541,63.8089 573.55,63.8085 573.559,63.8081 573.568,63.8077 573.577,63.8073 573.587,63.8069 573.596,63.8066 573.605,63.8062 573.614,63.8058 573.623,63.8054 573.633,63.805 573.642,63.8046 573.651,63.8042 573.66,63.8038 573.669,63.8034 573.678,63.8031 573.688,63.8027 573.697,63.8023 573.706,63.8019 573.715,63.8015 573.724,63.8011 573.734,63.8007 573.743,63.8003 573.752,63.8 573.761,63.7996 573.77,63.7992 573.78,63.7988 573.789,63.7984 573.798,63.798 573.807,63.7977 573.816,63.7973 573.825,63.7969 573.835,63.7965 573.844,63.7961 573.853,63.7957 573.862,63.7954 573.871,63.795 573.881,63.7946 573.89,63.7942 573.899,63.7938 573.908,63.7935 573.917,63.7931 573.927,63.7927 573.936,63.7923 573.945,63.7919 573.954,63.7915 573.963,63.7912 573.973,63.7908 573.982,63.7904 573.991,63.79 574,63.7897 574.009,63.7893 574.018,63.7889 574.028,63.7885 574.037,63.7881 574.046,63.7878 574.055,63.7874 574.064,63.787 574.074,63.7866 574.083,63.7863 574.092,63.7859 574.101,63.7855 574.11,63.7851 574.12,63.7848 574.129,63.7844 574.138,63.784 574.147,63.7836 574.156,63.7833 574.165,63.7829 574.175,63.7825 574.184,63.7821 574.193,63.7818 574.202,63.7814 574.211,63.781 574.221,63.7807 574.23,63.7803 574.239,63.7799 574.248,63.7795 574.257,63.7792 574.267,63.7788 574.276,63.7784 574.285,63.7781 574.294,63.7777 574.303,63.7773 574.313,63.7769 574.322,63.7766 574.331,63.7762 574.34,63.7758 574.349,63.7755 574.358,63.7751 574.368,63.7747 574.377,63.7744 574.386,63.774 574.395,63.7736 574.404,63.7733 574.414,63.7729 574.423,63.7725 574.432,63.7722 574.441,63.7718 574.45,63.7714 574.46,63.7711 574.469,63.7707 574.478,63.7703 574.487,63.77 574.496,63.7696 574.505,63.7693 574.515,63.7689 574.524,63.7685 574.533,63.7682 574.542,63.7678 574.551,63.7674 574.561,63.7671 574.57,63.7667 574.579,63.7664 574.588,63.766 574.597,63.7656 574.607,63.7653 574.616,63.7649 574.625,63.7646 574.634,63.7642 574.643,63.7638 574.653,63.7635 574.662,63.7631 574.671,63.7628 574.68,63.7624 574.689,63.762 574.698,63.7617 574.708,63.7613 574.717,63.761 574.726,63.7606 574.735,63.7603 574.744,63.7599 574.754,63.7595 574.763,63.7592 574.772,63.7588 574.781,63.7585 574.79,63.7581 574.8,63.7578 574.809,63.7574 574.818,63.7571 574.827,63.7567 574.836,63.7563 574.845,63.756 574.855,63.7556 574.864,63.7553 574.873,63.7549 574.882,63.7546 574.891,63.7542 574.901,63.7539 574.91,63.7535 574.919,63.7532 574.928,63.7528 574.937,63.7525 574.947,63.7521 574.956,63.7518 574.965,63.7514 574.974,63.7511 574.983,63.7507 574.993,63.7504 575.002,63.75 575.011,63.7497 575.02,63.7493 575.029,63.749 575.038,63.7486 575.048,63.7483 575.057,63.7479 575.066,63.7476 575.075,63.7472 575.084,63.7469 575.094,63.7465 575.103,63.7462 575.112,63.7459 575.121,63.7455 575.13,63.7452 575.14,63.7448 575.149,63.7445 575.158,63.7441 575.167,63.7438 575.176,63.7434 575.185,63.7431 575.195,63.7428 575.204,63.7424 575.213,63.7421 575.222,63.7417 575.231,63.7414 575.241,63.741 575.25,63.7407 575.259,63.7404 575.268,63.74 575.277,63.7397 575.287,63.7393 575.296,63.739 575.305,63.7387 575.314,63.7383 575.323,63.738 575.333,63.7376 575.342,63.7373 575.351,63.737 575.36,63.7366 575.369,63.7363 575.378,63.7359 575.388,63.7356 575.397,63.7353 575.406,63.7349 575.415,63.7346 575.424,63.7343 575.434,63.7339 575.443,63.7336 575.452,63.7333 575.461,63.7329 575.47,63.7326 575.48,63.7323 575.489,63.7319 575.498,63.7316 575.507,63.7312 575.516,63.7309 575.526,63.7306 575.535,63.7302 575.544,63.7299 575.553,63.7296 575.562,63.7293 575.571,63.7289 575.581,63.7286 575.59,63.7283 575.599,63.7279 575.608,63.7276 575.617,63.7273 575.627,63.7269 575.636,63.7266 575.645,63.7263 575.654,63.7259 575.663,63.7256 575.673,63.7253 575.682,63.725 575.691,63.7246 575.7,63.7243 575.709,63.724 575.718,63.7236 575.728,63.7233 575.737,63.723 575.746,63.7227 575.755,63.7223 575.764,63.722 575.774,63.7217 575.783,63.7214 575.792,63.721 575.801,63.7207 575.81,63.7204 575.82,63.7201 575.829,63.7197 575.838,63.7194 575.847,63.7191 575.856,63.7188 575.866,63.7184 575.875,63.7181 575.884,63.7178 575.893,63.7175 575.902,63.7171 575.911,63.7168 575.921,63.7165 575.93,63.7162 575.939,63.7159 575.948,63.7155 575.957,63.7152 575.967,63.7149 575.976,63.7146 575.985,63.7143 575.994,63.7139 576.003,63.7136 576.013,63.7133 576.022,63.713 576.031,63.7127 576.04,63.7124 576.049,63.712 576.058,63.7117 576.068,63.7114 576.077,63.7111 576.086,63.7108 576.095,63.7105 576.104,63.7101 576.114,63.7098 576.123,63.7095 576.132,63.7092 576.141,63.7089 576.15,63.7086 576.16,63.7082 576.169,63.7079 576.178,63.7076 576.187,63.7073 576.196,63.707 576.206,63.7067 576.215,63.7064 576.224,63.7061 576.233,63.7057 576.242,63.7054 576.251,63.7051 576.261,63.7048 576.27,63.7045 576.279,63.7042 576.288,63.7039 576.297,63.7036 576.307,63.7033 576.316,63.7029 576.325,63.7026 576.334,63.7023 576.343,63.702 576.353,63.7017 576.362,63.7014 576.371,63.7011 576.38,63.7008 576.389,63.7005 576.398,63.7002 576.408,63.6999 576.417,63.6996 576.426,63.6993 576.435,63.6989 576.444,63.6986 576.454,63.6983 576.463,63.698 576.472,63.6977 576.481,63.6974 576.49,63.6971 576.5,63.6968 576.509,63.6965 576.518,63.6962 576.527,63.6959 576.536,63.6956 576.546,63.6953 576.555,63.695 576.564,63.6947 576.573,63.6944 576.582,63.6941 576.591,63.6938 576.601,63.6935 576.61,63.6932 576.619,63.6929 576.628,63.6926 576.637,63.6923 576.647,63.692 576.656,63.6917 576.665,63.6914 576.674,63.6911 576.683,63.6908 576.693,63.6905 576.702,63.6902 576.711,63.6899 576.72,63.6896 576.729,63.6893 576.738,63.689 576.748,63.6887 576.757,63.6884 576.766,63.6881 576.775,63.6878 576.784,63.6875 576.794,63.6872 576.803,63.6869 576.812,63.6866 576.821,63.6864 576.83,63.6861 576.84,63.6858 576.849,63.6855 576.858,63.6852 576.867,63.6849 576.876,63.6846 576.886,63.6843 576.895,63.684 576.904,63.6837 576.913,63.6834 576.922,63.6831 576.931,63.6828 576.941,63.6826 576.95,63.6823 576.959,63.682 576.968,63.6817 576.977,63.6814 576.987,63.6811 576.996,63.6808 577.005,63.6805 577.014,63.6802 577.023,63.68 577.033,63.6797 577.042,63.6794 577.051,63.6791 577.06,63.6788 577.069,63.6785 577.078,63.6782 577.088,63.678 577.097,63.6777 577.106,63.6774 577.115,63.6771 577.124,63.6768 577.134,63.6765 577.143,63.6762 577.152,63.676 577.161,63.6757 577.17,63.6754 577.18,63.6751 577.189,63.6748 577.198,63.6745 577.207,63.6743 577.216,63.674 577.226,63.6737 577.235,63.6734 577.244,63.6731 577.253,63.6729 577.262,63.6726 577.271,63.6723 577.281,63.672 577.29,63.6717 577.299,63.6715 577.308,63.6712 577.317,63.6709 577.327,63.6706 577.336,63.6703 577.345,63.6701 577.354,63.6698 577.363,63.6695 577.373,63.6692 577.382,63.669 577.391,63.6687 577.4,63.6684 577.409,63.6681 577.418,63.6679 577.428,63.6676 577.437,63.6673 577.446,63.667 577.455,63.6668 577.464,63.6665 577.474,63.6662 577.483,63.6659 577.492,63.6657 577.501,63.6654 577.51,63.6651 577.52,63.6648 577.529,63.6646 577.538,63.6643 577.547,63.664 577.556,63.6638 577.566,63.6635 577.575,63.6632 577.584,63.6629 577.593,63.6627 577.602,63.6624 577.611,63.6621 577.621,63.6619 577.63,63.6616 577.639,63.6613 577.648,63.6611 577.657,63.6608 577.667,63.6605 577.676,63.6603 577.685,63.66 577.694,63.6597 577.703,63.6595 577.713,63.6592 577.722,63.6589 577.731,63.6587 577.74,63.6584 577.749,63.6581 577.758,63.6579 577.768,63.6576 577.777,63.6573 577.786,63.6571 577.795,63.6568 577.804,63.6565 577.814,63.6563 577.823,63.656 577.832,63.6558 577.841,63.6555 577.85,63.6552 577.86,63.655 577.869,63.6547 577.878,63.6544 577.887,63.6542 577.896,63.6539 577.906,63.6537 577.915,63.6534 577.924,63.6531 577.933,63.6529 577.942,63.6526 577.951,63.6524 577.961,63.6521 577.97,63.6518 577.979,63.6516 577.988,63.6513 577.997,63.6511 578.007,63.6508 578.016,63.6506 578.025,63.6503 578.034,63.65 578.043,63.6498 578.053,63.6495 578.062,63.6493 578.071,63.649 578.08,63.6488 578.089,63.6485 578.099,63.6483 578.108,63.648 578.117,63.6478 578.126,63.6475 578.135,63.6472 578.144,63.647 578.154,63.6467 578.163,63.6465 578.172,63.6462 578.181,63.646 578.19,63.6457 578.2,63.6455 578.209,63.6452 578.218,63.645 578.227,63.6447 578.236,63.6445 578.246,63.6442 578.255,63.644 578.264,63.6437 578.273,63.6435 578.282,63.6432 578.291,63.643 578.301,63.6427 578.31,63.6425 578.319,63.6422 578.328,63.642 578.337,63.6418 578.347,63.6415 578.356,63.6413 578.365,63.641 578.374,63.6408 578.383,63.6405 578.393,63.6403 578.402,63.64 578.411,63.6398 578.42,63.6396 578.429,63.6393 578.439,63.6391 578.448,63.6388 578.457,63.6386 578.466,63.6383 578.475,63.6381 578.484,63.6379 578.494,63.6376 578.503,63.6374 578.512,63.6371 578.521,63.6369 578.53,63.6366 578.54,63.6364 578.549,63.6362 578.558,63.6359 578.567,63.6357 578.576,63.6354 578.586,63.6352 578.595,63.635 578.604,63.6347 578.613,63.6345 578.622,63.6343 578.631,63.634 578.641,63.6338 578.65,63.6335 578.659,63.6333 578.668,63.6331 578.677,63.6328 578.687,63.6326 578.696,63.6324 578.705,63.6321 578.714,63.6319 578.723,63.6317 578.733,63.6314 578.742,63.6312 578.751,63.631 578.76,63.6307 578.769,63.6305 578.779,63.6303 578.788,63.63 578.797,63.6298 578.806,63.6296 578.815,63.6293 578.824,63.6291 578.834,63.6289 578.843,63.6286 578.852,63.6284 578.861,63.6282 578.87,63.628 578.88,63.6277 578.889,63.6275 578.898,63.6273 578.907,63.627 578.916,63.6268 578.926,63.6266 578.935,63.6264 578.944,63.6261 578.953,63.6259 578.962,63.6257 578.971,63.6255 578.981,63.6252 578.99,63.625 578.999,63.6248 579.008,63.6246 579.017,63.6243 579.027,63.6241 579.036,63.6239 579.045,63.6237 579.054,63.6234 579.063,63.6232 579.073,63.623 579.082,63.6228 579.091,63.6225 579.1,63.6223 579.109,63.6221 579.119,63.6219 579.128,63.6217 579.137,63.6214 579.146,63.6212 579.155,63.621 579.164,63.6208 579.174,63.6206 579.183,63.6203 579.192,63.6201 579.201,63.6199 579.21,63.6197 579.22,63.6195 579.229,63.6192 579.238,63.619 579.247,63.6188 579.256,63.6186 579.266,63.6184 579.275,63.6182 579.284,63.6179 579.293,63.6177 579.302,63.6175 579.311,63.6173 579.321,63.6171 579.33,63.6169 579.339,63.6167 579.348,63.6164 579.357,63.6162 579.367,63.616 579.376,63.6158 579.385,63.6156 579.394,63.6154 579.403,63.6152 579.413,63.6149 579.422,63.6147 579.431,63.6145 579.44,63.6143 579.449,63.6141 579.459,63.6139 579.468,63.6137 579.477,63.6135 579.486,63.6133 579.495,63.6131 579.504,63.6128 579.514,63.6126 579.523,63.6124 579.532,63.6122 579.541,63.612 579.55,63.6118 579.56,63.6116 579.569,63.6114 579.578,63.6112 579.587,63.611 579.596,63.6108 579.606,63.6106 579.615,63.6104 579.624,63.6102 579.633,63.61 579.642,63.6097 579.651,63.6095 579.661,63.6093 579.67,63.6091 579.679,63.6089 579.688,63.6087 579.697,63.6085 579.707,63.6083 579.716,63.6081 579.725,63.6079 579.734,63.6077 579.743,63.6075 579.753,63.6073 579.762,63.6071 579.771,63.6069 579.78,63.6067 579.789,63.6065 579.799,63.6063 579.808,63.6061 579.817,63.6059 579.826,63.6057 579.835,63.6055 579.844,63.6053 579.854,63.6051 579.863,63.6049 579.872,63.6047 579.881,63.6045 579.89,63.6043 579.9,63.6042 579.909,63.604 579.918,63.6038 579.927,63.6036 579.936,63.6034 579.946,63.6032 579.955,63.603 579.964,63.6028 579.973,63.6026 579.982,63.6024 579.991,63.6022 580.001,63.602 580.01,63.6018 580.019,63.6016 580.028,63.6014 580.037,63.6012 580.047,63.6011 580.056,63.6009 580.065,63.6007 580.074,63.6005 580.083,63.6003 580.093,63.6001 580.102,63.5999 580.111,63.5997 580.12,63.5995 580.129,63.5994 580.139,63.5992 580.148,63.599 580.157,63.5988 580.166,63.5986 580.175,63.5984 580.184,63.5982 580.194,63.598 580.203,63.5979 580.212,63.5977 580.221,63.5975 580.23,63.5973 580.24,63.5971 580.249,63.5969 580.258,63.5967 580.267,63.5966 580.276,63.5964 580.286,63.5962 580.295,63.596 580.304,63.5958 580.313,63.5957 580.322,63.5955 580.331,63.5953 580.341,63.5951 580.35,63.5949 580.359,63.5947 580.368,63.5946 580.377,63.5944 580.387,63.5942 580.396,63.594 580.405,63.5938 580.414,63.5937 580.423,63.5935 580.433,63.5933 580.442,63.5931 580.451,63.593 580.46,63.5928 580.469,63.5926 580.479,63.5924 580.488,63.5923 580.497,63.5921 580.506,63.5919 580.515,63.5917 580.524,63.5915 580.534,63.5914 580.543,63.5912 580.552,63.591 580.561,63.5909 580.57,63.5907 580.58,63.5905 580.589,63.5903 580.598,63.5902 580.607,63.59 580.616,63.5898 580.626,63.5896 580.635,63.5895 580.644,63.5893 580.653,63.5891 580.662,63.589 580.672,63.5888 580.681,63.5886 580.69,63.5885 580.699,63.5883 580.708,63.5881 580.717,63.5879 580.727,63.5878 580.736,63.5876 580.745,63.5874 580.754,63.5873 580.763,63.5871 580.773,63.5869 580.782,63.5868 580.791,63.5866 580.8,63.5864 580.809,63.5863 580.819,63.5861 580.828,63.5859 580.837,63.5858 580.846,63.5856 580.855,63.5855 580.864,63.5853 580.874,63.5851 580.883,63.585 580.892,63.5848 580.901,63.5846 580.91,63.5845 580.92,63.5843 580.929,63.5842 580.938,63.584 580.947,63.5838 580.956,63.5837 580.966,63.5835 580.975,63.5834 580.984,63.5832 580.993,63.583 581.002,63.5829 581.012,63.5827 581.021,63.5826 581.03,63.5824 581.039,63.5822 581.048,63.5821 581.057,63.5819 581.067,63.5818 581.076,63.5816 581.085,63.5815 581.094,63.5813 581.103,63.5811 581.113,63.581 581.122,63.5808 581.131,63.5807 581.14,63.5805 581.149,63.5804 581.159,63.5802 581.168,63.5801 581.177,63.5799 581.186,63.5798 581.195,63.5796 581.204,63.5795 581.214,63.5793 581.223,63.5792 581.232,63.579 581.241,63.5789 581.25,63.5787 581.26,63.5786 581.269,63.5784 581.278,63.5783 581.287,63.5781 581.296,63.578 581.306,63.5778 581.315,63.5777 581.324,63.5775 581.333,63.5774 581.342,63.5772 581.352,63.5771 581.361,63.5769 581.37,63.5768 581.379,63.5766 581.388,63.5765 581.397,63.5763 581.407,63.5762 581.416,63.5761 581.425,63.5759 581.434,63.5758 581.443,63.5756 581.453,63.5755 581.462,63.5753 581.471,63.5752 581.48,63.575 581.489,63.5749 581.499,63.5748 581.508,63.5746 581.517,63.5745 581.526,63.5743 581.535,63.5742 581.544,63.5741 581.554,63.5739 581.563,63.5738 581.572,63.5736 581.581,63.5735 581.59,63.5734 581.6,63.5732 581.609,63.5731 581.618,63.5729 581.627,63.5728 581.636,63.5727 581.646,63.5725 581.655,63.5724 581.664,63.5723 581.673,63.5721 581.682,63.572 581.692,63.5719 581.701,63.5717 581.71,63.5716 581.719,63.5715 581.728,63.5713 581.737,63.5712 581.747,63.5711 581.756,63.5709 581.765,63.5708 581.774,63.5707 581.783,63.5705 581.793,63.5704 581.802,63.5703 581.811,63.5701 581.82,63.57 581.829,63.5699 581.839,63.5697 581.848,63.5696 581.857,63.5695 581.866,63.5693 581.875,63.5692 581.884,63.5691 581.894,63.569 581.903,63.5688 581.912,63.5687 581.921,63.5686 581.93,63.5685 581.94,63.5683 581.949,63.5682 581.958,63.5681 581.967,63.5679 581.976,63.5678 581.986,63.5677 581.995,63.5676 582.004,63.5674 582.013,63.5673 582.022,63.5672 582.032,63.5671 582.041,63.567 582.05,63.5668 582.059,63.5667 582.068,63.5666 582.077,63.5665 582.087,63.5663 582.096,63.5662 582.105,63.5661 582.114,63.566 582.123,63.5659 582.133,63.5657 582.142,63.5656 582.151,63.5655 582.16,63.5654 582.169,63.5653 582.179,63.5651 582.188,63.565 582.197,63.5649 582.206,63.5648 582.215,63.5647 582.224,63.5646 582.234,63.5644 582.243,63.5643 582.252,63.5642 582.261,63.5641 582.27,63.564 582.28,63.5639 582.289,63.5638 582.298,63.5636 582.307,63.5635 582.316,63.5634 582.326,63.5633 582.335,63.5632 582.344,63.5631 582.353,63.563 582.362,63.5629 582.372,63.5627 582.381,63.5626 582.39,63.5625 582.399,63.5624 582.408,63.5623 582.417,63.5622 582.427,63.5621 582.436,63.562 582.445,63.5619 582.454,63.5618 582.463,63.5616 582.473,63.5615 582.482,63.5614 582.491,63.5613 582.5,63.5612 582.509,63.5611 582.519,63.561 582.528,63.5609 582.537,63.5608 582.546,63.5607 582.555,63.5606 582.564,63.5605 582.574,63.5604 582.583,63.5603 582.592,63.5602 582.601,63.5601 582.61,63.56 582.62,63.5599 582.629,63.5598 582.638,63.5596 582.647,63.5595 582.656,63.5594 582.666,63.5593 582.675,63.5592 582.684,63.5591 582.693,63.559 582.702,63.5589 582.712,63.5588 582.721,63.5587 582.73,63.5586 582.739,63.5585 582.748,63.5584 582.757,63.5584 582.767,63.5583 582.776,63.5582 582.785,63.5581 582.794,63.558 582.803,63.5579 582.813,63.5578 582.822,63.5577 582.831,63.5576 582.84,63.5575 582.849,63.5574 582.859,63.5573 582.868,63.5572 582.877,63.5571 582.886,63.557 582.895,63.5569 582.905,63.5568 582.914,63.5567 582.923,63.5566 582.932,63.5566 582.941,63.5565 582.95,63.5564 582.96,63.5563 582.969,63.5562 582.978,63.5561 582.987,63.556 582.996,63.5559 583.006,63.5558 583.015,63.5557 583.024,63.5557 583.033,63.5556 583.042,63.5555 583.052,63.5554 583.061,63.5553 583.07,63.5552 583.079,63.5551 583.088,63.5551 583.097,63.555 583.107,63.5549 583.116,63.5548 583.125,63.5547 583.134,63.5546 583.143,63.5545 583.153,63.5545 583.162,63.5544 583.171,63.5543 583.18,63.5542 583.189,63.5541 583.199,63.554 583.208,63.554 583.217,63.5539 583.226,63.5538 583.235,63.5537 583.245,63.5536 583.254,63.5536 583.263,63.5535 583.272,63.5534 583.281,63.5533 583.29,63.5532 583.3,63.5532 583.309,63.5531 583.318,63.553 583.327,63.5529 583.336,63.5529 583.346,63.5528 583.355,63.5527 583.364,63.5526 583.373,63.5526 583.382,63.5525 583.392,63.5524 583.401,63.5523 583.41,63.5523 583.419,63.5522 583.428,63.5521 583.437,63.552 583.447,63.552 583.456,63.5519 583.465,63.5518 583.474,63.5517 583.483,63.5517 583.493,63.5516 583.502,63.5515 583.511,63.5515 583.52,63.5514 583.529,63.5513 583.539,63.5512 583.548,63.5512 583.557,63.5511 583.566,63.551 583.575,63.551 583.585,63.5509 583.594,63.5508 583.603,63.5508 583.612,63.5507 583.621,63.5506 583.63,63.5506 583.64,63.5505 583.649,63.5504 583.658,63.5504 583.667,63.5503 583.676,63.5502 583.686,63.5502 583.695,63.5501 583.704,63.5501 583.713,63.55 583.722,63.5499 583.732,63.5499 583.741,63.5498 583.75,63.5497 583.759,63.5497 583.768,63.5496 583.777,63.5496 583.787,63.5495 583.796,63.5494 583.805,63.5494 583.814,63.5493 583.823,63.5493 583.833,63.5492 583.842,63.5491 583.851,63.5491 583.86,63.549 583.869,63.549 583.879,63.5489 583.888,63.5488 583.897,63.5488 583.906,63.5487 583.915,63.5487 583.925,63.5486 583.934,63.5486 583.943,63.5485 583.952,63.5485 583.961,63.5484 583.97,63.5484 583.98,63.5483 583.989,63.5482 583.998,63.5482 584.007,63.5481 584.016,63.5481 584.026,63.548 584.035,63.548 584.044,63.5479 584.053,63.5479 584.062,63.5478 584.072,63.5478 584.081,63.5477 584.09,63.5477 584.099,63.5476 584.108,63.5476 584.117,63.5475 584.127,63.5475 584.136,63.5474 584.145,63.5474 584.154,63.5473 584.163,63.5473 584.173,63.5473 584.182,63.5472 584.191,63.5472 584.2,63.5471 584.209,63.5471 584.219,63.547 584.228,63.547 584.237,63.5469 584.246,63.5469 584.255,63.5469 584.265,63.5468 584.274,63.5468 584.283,63.5467 584.292,63.5467 584.301,63.5466 584.31,63.5466 584.32,63.5466 584.329,63.5465 584.338,63.5465 584.347,63.5464 584.356,63.5464 584.366,63.5464 584.375,63.5463 584.384,63.5463 584.393,63.5462 584.402,63.5462 584.412,63.5462 584.421,63.5461 584.43,63.5461 584.439,63.5461 584.448,63.546 584.457,63.546 584.467,63.546 584.476,63.5459 584.485,63.5459 584.494,63.5458 584.503,63.5458 584.513,63.5458 584.522,63.5457 584.531,63.5457 584.54,63.5457 584.549,63.5456 584.559,63.5456 584.568,63.5456 584.577,63.5456 584.586,63.5455 584.595,63.5455 584.605,63.5455 584.614,63.5454 584.623,63.5454 584.632,63.5454 584.641,63.5453 584.65,63.5453 584.66,63.5453 584.669,63.5453 584.678,63.5452 584.687,63.5452 584.696,63.5452 584.706,63.5452 584.715,63.5451 584.724,63.5451 584.733,63.5451 584.742,63.5451 584.752,63.545 584.761,63.545 584.77,63.545 584.779,63.545 584.788,63.5449 584.797,63.5449 584.807,63.5449 584.816,63.5449 584.825,63.5448 584.834,63.5448 584.843,63.5448 584.853,63.5448 584.862,63.5448 584.871,63.5447 584.88,63.5447 584.889,63.5447 584.899,63.5447 584.908,63.5447 584.917,63.5446 584.926,63.5446 584.935,63.5446 584.945,63.5446 584.954,63.5446 584.963,63.5446 584.972,63.5445 584.981,63.5445 584.99,63.5445 585,63.5445 585.009,63.5445 585.018,63.5445 585.027,63.5444 585.036,63.5444 585.046,63.5444 585.055,63.5444 585.064,63.5444 585.073,63.5444 585.082,63.5444 585.092,63.5444 585.101,63.5443 585.11,63.5443 585.119,63.5443 585.128,63.5443 585.137,63.5443 585.147,63.5443 585.156,63.5443 585.165,63.5443 585.174,63.5443 585.183,63.5443 585.193,63.5442 585.202,63.5442 585.211,63.5442 585.22,63.5442 585.229,63.5442 585.239,63.5442 585.248,63.5442 585.257,63.5442 585.266,63.5442 585.275,63.5442 585.285,63.5442 585.294,63.5442 585.303,63.5442 585.312,63.5442 585.321,63.5442 585.33,63.5442 585.34,63.5442 585.349,63.5442 585.358,63.5442 585.367,63.5442 585.376,63.5442 585.386,63.5442 585.395,63.5442 585.404,63.5442 585.413,63.5442 585.422,63.5442 585.432,63.5442 585.441,63.5442 585.45,63.5442 585.459,63.5442 585.468,63.5442 585.478,63.5442 585.487,63.5442 585.496,63.5442 585.505,63.5442 585.514,63.5442 585.523,63.5442 585.533,63.5442 585.542,63.5442 585.551,63.5442 585.56,63.5442 585.569,63.5442 585.579,63.5442 585.588,63.5442 585.597,63.5442 585.606,63.5443 585.615,63.5443 585.625,63.5443 585.634,63.5443 585.643,63.5443 585.652,63.5443 585.661,63.5443 585.67,63.5443 585.68,63.5443 585.689,63.5443 585.698,63.5444 585.707,63.5444 585.716,63.5444 585.726,63.5444 585.735,63.5444 585.744,63.5444 585.753,63.5444 585.762,63.5444 585.772,63.5445 585.781,63.5445 585.79,63.5445 585.799,63.5445 585.808,63.5445 585.818,63.5445 585.827,63.5446 585.836,63.5446 585.845,63.5446 585.854,63.5446 585.863,63.5446 585.873,63.5446 585.882,63.5447 585.891,63.5447 585.9,63.5447 585.909,63.5447 585.919,63.5447 585.928,63.5448 585.937,63.5448 585.946,63.5448 585.955,63.5448 585.965,63.5448 585.974,63.5449 585.983,63.5449 585.992,63.5449 586.001,63.5449 586.01,63.545 586.02,63.545 586.029,63.545 586.038,63.545 586.047,63.5451 586.056,63.5451 586.066,63.5451 586.075,63.5451 586.084,63.5452 586.093,63.5452 586.102,63.5452 586.112,63.5452 586.121,63.5453 586.13,63.5453 586.139,63.5453 586.148,63.5454 586.158,63.5454 586.167,63.5454 586.176,63.5454 586.185,63.5455 586.194,63.5455 586.203,63.5455 586.213,63.5456 586.222,63.5456 586.231,63.5456 586.24,63.5457 586.249,63.5457 586.259,63.5457 586.268,63.5458 586.277,63.5458 586.286,63.5458 586.295,63.5459 586.305,63.5459 586.314,63.5459 586.323,63.546 586.332,63.546 586.341,63.546 586.35,63.5461 586.36,63.5461 586.369,63.5462 586.378,63.5462 586.387,63.5462 586.396,63.5463 586.406,63.5463 586.415,63.5464 586.424,63.5464 586.433,63.5464 586.442,63.5465 586.452,63.5465 586.461,63.5466 586.47,63.5466 586.479,63.5466 586.488,63.5467 586.498,63.5467 586.507,63.5468 586.516,63.5468 586.525,63.5469 586.534,63.5469 586.543,63.5469 586.553,63.547 586.562,63.547 586.571,63.5471 586.58,63.5471 586.589,63.5472 586.599,63.5472 586.608,63.5473 586.617,63.5473 586.626,63.5474 586.635,63.5474 586.645,63.5475 586.654,63.5475 586.663,63.5476 586.672,63.5476 586.681,63.5477 586.69,63.5477 586.7,63.5478 586.709,63.5478 586.718,63.5479 586.727,63.5479 586.736,63.548 586.746,63.548 586.755,63.5481 586.764,63.5481 586.773,63.5482 586.782,63.5482 586.792,63.5483 586.801,63.5483 586.81,63.5484 586.819,63.5485 586.828,63.5485 586.838,63.5486 586.847,63.5486 586.856,63.5487 586.865,63.5487 586.874,63.5488 586.883,63.5489 586.893,63.5489 586.902,63.549 586.911,63.549 586.92,63.5491 586.929,63.5492 586.939,63.5492 586.948,63.5493 586.957,63.5493 586.966,63.5494 586.975,63.5495 586.985,63.5495 586.994,63.5496 587.003,63.5496 587.012,63.5497 587.021,63.5498 587.03,63.5498 587.04,63.5499 587.049,63.55 587.058,63.55 587.067,63.5501 587.076,63.5502 587.086,63.5502 587.095,63.5503 587.104,63.5504 587.113,63.5504 587.122,63.5505 587.132,63.5506 587.141,63.5506 587.15,63.5507 587.159,63.5508 587.168,63.5508 587.178,63.5509 587.187,63.551 587.196,63.5511 587.205,63.5511 587.214,63.5512 587.223,63.5513 587.233,63.5513 587.242,63.5514 587.251,63.5515 587.26,63.5516 587.269,63.5516 587.279,63.5517 587.288,63.5518 587.297,63.5519 587.306,63.5519 587.315,63.552 587.325,63.5521 587.334,63.5522 587.343,63.5522 587.352,63.5523 587.361,63.5524 587.37,63.5525 587.38,63.5526 587.389,63.5526 587.398,63.5527 587.407,63.5528 587.416,63.5529 587.426,63.553 587.435,63.553 587.444,63.5531 587.453,63.5532 587.462,63.5533 587.472,63.5534 587.481,63.5534 587.49,63.5535 587.499,63.5536 587.508,63.5537 587.518,63.5538 587.527,63.5539 587.536,63.5539 587.545,63.554 587.554,63.5541 587.563,63.5542 587.573,63.5543 587.582,63.5544 587.591,63.5545 587.6,63.5546 587.609,63.5546 587.619,63.5547 587.628,63.5548 587.637,63.5549 587.646,63.555 587.655,63.5551 587.665,63.5552 587.674,63.5553 587.683,63.5554 587.692,63.5554 587.701,63.5555 587.71,63.5556 587.72,63.5557 587.729,63.5558 587.738,63.5559 587.747,63.556 587.756,63.5561 587.766,63.5562 587.775,63.5563 587.784,63.5564 587.793,63.5565 587.802,63.5566 587.812,63.5567 587.821,63.5568 587.83,63.5569 587.839,63.557 587.848,63.5571 587.858,63.5572 587.867,63.5572 587.876,63.5573 587.885,63.5574 587.894,63.5575 587.903,63.5576 587.913,63.5577 587.922,63.5578 587.931,63.5579 587.94,63.5581 587.949,63.5582 587.959,63.5583 587.968,63.5584 587.977,63.5585 587.986,63.5586 587.995,63.5587 588.005,63.5588 588.014,63.5589 588.023,63.559 588.032,63.5591 588.041,63.5592 588.051,63.5593 588.06,63.5594 588.069,63.5595 588.078,63.5596 588.087,63.5597 588.096,63.5598 588.106,63.5599 588.115,63.5601 588.124,63.5602 588.133,63.5603 588.142,63.5604 588.152,63.5605 588.161,63.5606 588.17,63.5607 588.179,63.5608 588.188,63.5609 588.198,63.561 588.207,63.5612 588.216,63.5613 588.225,63.5614 588.234,63.5615 588.243,63.5616 588.253,63.5617 588.262,63.5618 588.271,63.562 588.28,63.5621 588.289,63.5622 588.299,63.5623 588.308,63.5624 588.317,63.5625 588.326,63.5627 588.335,63.5628 588.345,63.5629 588.354,63.563 588.363,63.5631 588.372,63.5633 588.381,63.5634 588.391,63.5635 588.4,63.5636 588.409,63.5637 588.418,63.5639 588.427,63.564 588.436,63.5641 588.446,63.5642 588.455,63.5643 588.464,63.5645 588.473,63.5646 588.482,63.5647 588.492,63.5648 588.501,63.565 588.51,63.5651 588.519,63.5652 588.528,63.5653 588.538,63.5655 588.547,63.5656 588.556,63.5657 588.565,63.5659 588.574,63.566 588.583,63.5661 588.593,63.5662 588.602,63.5664 588.611,63.5665 588.62,63.5666 588.629,63.5668 588.639,63.5669 588.648,63.567 588.657,63.5671 588.666,63.5673 588.675,63.5674 588.685,63.5675 588.694,63.5677 588.703,63.5678 588.712,63.5679 588.721,63.5681 588.731,63.5682 588.74,63.5684 588.749,63.5685 588.758,63.5686 588.767,63.5688 588.776,63.5689 588.786,63.569 588.795,63.5692 588.804,63.5693 588.813,63.5694 588.822,63.5696 588.832,63.5697 588.841,63.5699 588.85,63.57 588.859,63.5701 588.868,63.5703 588.878,63.5704 588.887,63.5706 588.896,63.5707 588.905,63.5708 588.914,63.571 588.923,63.5711 588.933,63.5713 588.942,63.5714 588.951,63.5716 588.96,63.5717 588.969,63.5719 588.979,63.572 588.988,63.5721 588.997,63.5723 589.006,63.5724 589.015,63.5726 589.025,63.5727 589.034,63.5729 589.043,63.573 589.052,63.5732 589.061,63.5733 589.071,63.5735 589.08,63.5736 589.089,63.5738 589.098,63.5739 589.107,63.5741 589.116,63.5742 589.126,63.5744 589.135,63.5745 589.144,63.5747 589.153,63.5748 589.162,63.575 589.172,63.5751 589.181,63.5753 589.19,63.5755 589.199,63.5756 589.208,63.5758 589.218,63.5759 589.227,63.5761 589.236,63.5762 589.245,63.5764 589.254,63.5765 589.263,63.5767 589.273,63.5769 589.282,63.577 589.291,63.5772 589.3,63.5773 589.309,63.5775 589.319,63.5777 589.328,63.5778 589.337,63.578 589.346,63.5781 589.355,63.5783 589.365,63.5785 589.374,63.5786 589.383,63.5788 589.392,63.5789 589.401,63.5791 589.411,63.5793 589.42,63.5794 589.429,63.5796 589.438,63.5798 589.447,63.5799 589.456,63.5801 589.466,63.5803 589.475,63.5804 589.484,63.5806 589.493,63.5808 589.502,63.5809 589.512,63.5811 589.521,63.5813 589.53,63.5814 589.539,63.5816 589.548,63.5818 589.558,63.582 589.567,63.5821 589.576,63.5823 589.585,63.5825 589.594,63.5826 589.603,63.5828 589.613,63.583 589.622,63.5832 589.631,63.5833 589.64,63.5835 589.649,63.5837 589.659,63.5839 589.668,63.584 589.677,63.5842 589.686,63.5844 589.695,63.5846 589.705,63.5847 589.714,63.5849 589.723,63.5851 589.732,63.5853 589.741,63.5854 589.751,63.5856 589.76,63.5858 589.769,63.586 589.778,63.5862 589.787,63.5863 589.796,63.5865 589.806,63.5867 589.815,63.5869 589.824,63.5871 589.833,63.5873 589.842,63.5874 589.852,63.5876 589.861,63.5878 589.87,63.588 589.879,63.5882 589.888,63.5884 589.898,63.5885 589.907,63.5887 589.916,63.5889 589.925,63.5891 589.934,63.5893 589.943,63.5895 589.953,63.5897 589.962,63.5899 589.971,63.59 589.98,63.5902 589.989,63.5904 589.999,63.5906 590.008,63.5908 590.017,63.591 590.026,63.5912 590.035,63.5914 590.045,63.5916 590.054,63.5918 590.063,63.592 590.072,63.5921 590.081,63.5923 590.091,63.5925 590.1,63.5927 590.109,63.5929 590.118,63.5931 590.127,63.5933 590.136,63.5935 590.146,63.5937 590.155,63.5939 590.164,63.5941 590.173,63.5943 590.182,63.5945 590.192,63.5947 590.201,63.5949 590.21,63.5951 590.219,63.5953 590.228,63.5955 590.238,63.5957 590.247,63.5959 590.256,63.5961 590.265,63.5963 590.274,63.5965 590.283,63.5967 590.293,63.5969 590.302,63.5971 590.311,63.5973 590.32,63.5975 590.329,63.5977 590.339,63.5979 590.348,63.5981 590.357,63.5983 590.366,63.5985 590.375,63.5987 590.385,63.599 590.394,63.5992 590.403,63.5994 590.412,63.5996 590.421,63.5998 590.431,63.6 590.44,63.6002 590.449,63.6004 590.458,63.6006 590.467,63.6008 590.476,63.601 590.486,63.6013 590.495,63.6015 590.504,63.6017 590.513,63.6019 590.522,63.6021 590.532,63.6023 590.541,63.6025 590.55,63.6028 590.559,63.603 590.568,63.6032 590.578,63.6034 590.587,63.6036 590.596,63.6038 590.605,63.6041 590.614,63.6043 590.624,63.6045 590.633,63.6047 590.642,63.6049 590.651,63.6051 590.66,63.6054 590.669,63.6056 590.679,63.6058 590.688,63.606 590.697,63.6062 590.706,63.6065 590.715,63.6067 590.725,63.6069 590.734,63.6071 590.743,63.6074 590.752,63.6076 590.761,63.6078 590.771,63.608 590.78,63.6083 590.789,63.6085 590.798,63.6087 590.807,63.6089 590.816,63.6092 590.826,63.6094 590.835,63.6096 590.844,63.6098 590.853,63.6101 590.862,63.6103 590.872,63.6105 590.881,63.6108 590.89,63.611 590.899,63.6112 590.908,63.6114 590.918,63.6117 590.927,63.6119 590.936,63.6121 590.945,63.6124 590.954,63.6126 590.964,63.6128 590.973,63.6131 590.982,63.6133 590.991,63.6135 591,63.6138 591.009,63.614 591.019,63.6143 591.028,63.6145 591.037,63.6147 591.046,63.615 591.055,63.6152 591.065,63.6154 591.074,63.6157 591.083,63.6159 591.092,63.6162 591.101,63.6164 591.111,63.6166 591.12,63.6169 591.129,63.6171 591.138,63.6174 591.147,63.6176 591.156,63.6178 591.166,63.6181 591.175,63.6183 591.184,63.6186 591.193,63.6188 591.202,63.6191 591.212,63.6193 591.221,63.6196 591.23,63.6198 591.239,63.62 591.248,63.6203 591.258,63.6205 591.267,63.6208 591.276,63.621 591.285,63.6213 591.294,63.6215 591.304,63.6218 591.313,63.622 591.322,63.6223 591.331,63.6225 591.34,63.6228 591.349,63.623 591.359,63.6233 591.368,63.6235 591.377,63.6238 591.386,63.624 591.395,63.6243 591.405,63.6245 591.414,63.6248 591.423,63.6251 591.432,63.6253 591.441,63.6256 591.451,63.6258 591.46,63.6261 591.469,63.6263 591.478,63.6266 591.487,63.6268 591.496,63.6271 591.506,63.6274 591.515,63.6276 591.524,63.6279 591.533,63.6281 591.542,63.6284 591.552,63.6287 591.561,63.6289 591.57,63.6292 591.579,63.6294 591.588,63.6297 591.598,63.63 591.607,63.6302 591.616,63.6305 591.625,63.6308 591.634,63.631 591.644,63.6313 591.653,63.6316 591.662,63.6318 591.671,63.6321 591.68,63.6324 591.689,63.6326 591.699,63.6329 591.708,63.6332 591.717,63.6334 591.726,63.6337 591.735,63.634 591.745,63.6342 591.754,63.6345 591.763,63.6348 591.772,63.6351 591.781,63.6353 591.791,63.6356 591.8,63.6359 591.809,63.6361 591.818,63.6364 591.827,63.6367 591.836,63.637 591.846,63.6372 591.855,63.6375 591.864,63.6378 591.873,63.6381 591.882,63.6383 591.892,63.6386 591.901,63.6389 591.91,63.6392 591.919,63.6394 591.928,63.6397 591.938,63.64 591.947,63.6403 591.956,63.6406 591.965,63.6408 591.974,63.6411 591.984,63.6414 591.993,63.6417 592.002,63.642 592.011,63.6423 592.02,63.6425 592.029,63.6428 592.039,63.6431 592.048,63.6434 592.057,63.6437 592.066,63.644 592.075,63.6442 592.085,63.6445 592.094,63.6448 592.103,63.6451 592.112,63.6454 592.121,63.6457 592.131,63.646 592.14,63.6462 592.149,63.6465 592.158,63.6468 592.167,63.6471 592.176,63.6474 592.186,63.6477 592.195,63.648 592.204,63.6483 592.213,63.6486 592.222,63.6489 592.232,63.6492 592.241,63.6495 592.25,63.6497 592.259,63.65 592.268,63.6503 592.278,63.6506 592.287,63.6509 592.296,63.6512 592.305,63.6515 592.314,63.6518 592.324,63.6521 592.333,63.6524 592.342,63.6527 592.351,63.653 592.36,63.6533 592.369,63.6536 592.379,63.6539 592.388,63.6542 592.397,63.6545 592.406,63.6548 592.415,63.6551 592.425,63.6554 592.434,63.6557 592.443,63.656 592.452,63.6563 592.461,63.6566 592.471,63.6569 592.48,63.6572 592.489,63.6575 592.498,63.6578 592.507,63.6582 592.516,63.6585 592.526,63.6588 592.535,63.6591 592.544,63.6594 592.553,63.6597 592.562,63.66 592.572,63.6603 592.581,63.6606 592.59,63.6609 592.599,63.6612 592.608,63.6615 592.618,63.6619 592.627,63.6622 592.636,63.6625 592.645,63.6628 592.654,63.6631 592.664,63.6634 592.673,63.6637 592.682,63.6641 592.691,63.6644 592.7,63.6647 592.709,63.665 592.719,63.6653 592.728,63.6656 592.737,63.666 592.746,63.6663 592.755,63.6666 592.765,63.6669 592.774,63.6672 592.783,63.6675 592.792,63.6679 592.801,63.6682 592.811,63.6685 592.82,63.6688 592.829,63.6691 592.838,63.6695 592.847,63.6698 592.857,63.6701 592.866,63.6704 592.875,63.6708 592.884,63.6711 592.893,63.6714 592.902,63.6717 592.912,63.6721 592.921,63.6724 592.93,63.6727 592.939,63.673 592.948,63.6734 592.958,63.6737 592.967,63.674 592.976,63.6744 592.985,63.6747 592.994,63.675 593.004,63.6753 593.013,63.6757 593.022,63.676 593.031,63.6763 593.04,63.6767 593.049,63.677 593.059,63.6773 593.068,63.6777 593.077,63.678 593.086,63.6783 593.095,63.6787 593.105,63.679 593.114,63.6793 593.123,63.6797 593.132,63.68 593.141,63.6804 593.151,63.6807 593.16,63.681 593.169,63.6814 593.178,63.6817 593.187,63.6821 593.197,63.6824 593.206,63.6827 593.215,63.6831 593.224,63.6834 593.233,63.6838 593.242,63.6841 593.252,63.6844 593.261,63.6848 593.27,63.6851 593.279,63.6855 593.288,63.6858 593.298,63.6862 593.307,63.6865 593.316,63.6869 593.325,63.6872 593.334,63.6875 593.344,63.6879 593.353,63.6882 593.362,63.6886 593.371,63.6889 593.38,63.6893 593.389,63.6896 593.399,63.69 593.408,63.6903 593.417,63.6907 593.426,63.691 593.435,63.6914 593.445,63.6917 593.454,63.6921 593.463,63.6924 593.472,63.6928 593.481,63.6932 593.491,63.6935 593.5,63.6939 593.509,63.6942 593.518,63.6946 593.527,63.6949 593.537,63.6953 593.546,63.6956 593.555,63.696 593.564,63.6964 593.573,63.6967 593.582,63.6971 593.592,63.6974 593.601,63.6978 593.61,63.6982 593.619,63.6985 593.628,63.6989 593.638,63.6992 593.647,63.6996 593.656,63.7 593.665,63.7003 593.674,63.7007 593.684,63.7011 593.693,63.7014 593.702,63.7018 593.711,63.7022 593.72,63.7025 593.729,63.7029 593.739,63.7033 593.748,63.7036 593.757,63.704 593.766,63.7044 593.775,63.7047 593.785,63.7051 593.794,63.7055 593.803,63.7058 593.812,63.7062 593.821,63.7066 593.831,63.707 593.84,63.7073 593.849,63.7077 593.858,63.7081 593.867,63.7084 593.877,63.7088 593.886,63.7092 593.895,63.7096 593.904,63.7099 593.913,63.7103 593.922,63.7107 593.932,63.7111 593.941,63.7115 593.95,63.7118 593.959,63.7122 593.968,63.7126 593.978,63.713 593.987,63.7133 593.996,63.7137 594.005,63.7141 594.014,63.7145 594.024,63.7149 594.033,63.7153 594.042,63.7156 594.051,63.716 594.06,63.7164 594.069,63.7168 594.079,63.7172 594.088,63.7176 594.097,63.7179 594.106,63.7183 594.115,63.7187 594.125,63.7191 594.134,63.7195 594.143,63.7199 594.152,63.7203 594.161,63.7207 594.171,63.721 594.18,63.7214 594.189,63.7218 594.198,63.7222 594.207,63.7226 594.217,63.723 594.226,63.7234 594.235,63.7238 594.244,63.7242 594.253,63.7246 594.262,63.725 594.272,63.7254 594.281,63.7257 594.29,63.7261 594.299,63.7265 594.308,63.7269 594.318,63.7273 594.327,63.7277 594.336,63.7281 594.345,63.7285 594.354,63.7289 594.364,63.7293 594.373,63.7297 594.382,63.7301 594.391,63.7305 594.4,63.7309 594.409,63.7313 594.419,63.7317 594.428,63.7321 594.437,63.7325 594.446,63.7329 594.455,63.7333 594.465,63.7337 594.474,63.7341 594.483,63.7346 594.492,63.735 594.501,63.7354 594.511,63.7358 594.52,63.7362 594.529,63.7366 594.538,63.737 594.547,63.7374 594.557,63.7378 594.566,63.7382 594.575,63.7386 594.584,63.739 594.593,63.7395 594.602,63.7399 594.612,63.7403 594.621,63.7407 594.63,63.7411 594.639,63.7415 594.648,63.7419 594.658,63.7423 594.667,63.7428 594.676,63.7432 594.685,63.7436 594.694,63.744 594.704,63.7444 594.713,63.7448 594.722,63.7453 594.731,63.7457 594.74,63.7461 594.749,63.7465 594.759,63.7469 594.768,63.7474 594.777,63.7478 594.786,63.7482 594.795,63.7486 594.805,63.749 594.814,63.7495 594.823,63.7499 594.832,63.7503 594.841,63.7507 594.851,63.7512 594.86,63.7516 594.869,63.752 594.878,63.7524 594.887,63.7529 594.897,63.7533 594.906,63.7537 594.915,63.7541 594.924,63.7546 594.933,63.755 594.942,63.7554 594.952,63.7559 594.961,63.7563 594.97,63.7567 594.979,63.7571 594.988,63.7576 594.998,63.758 595.007,63.7584 595.016,63.7589 595.025,63.7593 595.034,63.7597 595.044,63.7602 595.053,63.7606 595.062,63.7611 595.071,63.7615 595.08,63.7619 595.089,63.7624 595.099,63.7628 595.108,63.7632 595.117,63.7637 595.126,63.7641 595.135,63.7646 595.145,63.765 595.154,63.7654 595.163,63.7659 595.172,63.7663 595.181,63.7668 595.191,63.7672 595.2,63.7676 595.209,63.7681 595.218,63.7685 595.227,63.769 595.237,63.7694 595.246,63.7699 595.255,63.7703 595.264,63.7708 595.273,63.7712 595.282,63.7717 595.292,63.7721 595.301,63.7726 595.31,63.773 595.319,63.7734 595.328,63.7739 595.338,63.7743 595.347,63.7748 595.356,63.7753 595.365,63.7757 595.374,63.7762 595.384,63.7766 595.393,63.7771 595.402,63.7775 595.411,63.778 595.42,63.7784 595.43,63.7789 595.439,63.7793 595.448,63.7798 595.457,63.7802 595.466,63.7807 595.475,63.7812 595.485,63.7816 595.494,63.7821 595.503,63.7825 595.512,63.783 595.521,63.7835 595.531,63.7839 595.54,63.7844 595.549,63.7848 595.558,63.7853 595.567,63.7858 595.577,63.7862 595.586,63.7867 595.595,63.7872 595.604,63.7876 595.613,63.7881 595.622,63.7886 595.632,63.789 595.641,63.7895 595.65,63.79 595.659,63.7904 595.668,63.7909 595.678,63.7914 595.687,63.7918 595.696,63.7923 595.705,63.7928 595.714,63.7932 595.724,63.7937 595.733,63.7942 595.742,63.7947 595.751,63.7951 595.76,63.7956 595.77,63.7961 595.779,63.7965 595.788,63.797 595.797,63.7975 595.806,63.798 595.815,63.7984 595.825,63.7989 595.834,63.7994 595.843,63.7999 595.852,63.8004 595.861,63.8008 595.871,63.8013 595.88,63.8018 595.889,63.8023 595.898,63.8028 595.907,63.8032 595.917,63.8037 595.926,63.8042 595.935,63.8047 595.944,63.8052 595.953,63.8057 595.962,63.8061 595.972,63.8066 595.981,63.8071 595.99,63.8076 595.999,63.8081 596.008,63.8086 596.018,63.8091 596.027,63.8095 596.036,63.81 596.045,63.8105 596.054,63.811 596.064,63.8115 596.073,63.812 596.082,63.8125 596.091,63.813 596.1,63.8135 596.11,63.814 596.119,63.8144 596.128,63.8149 596.137,63.8154 596.146,63.8159 596.155,63.8164 596.165,63.8169 596.174,63.8174 596.183,63.8179 596.192,63.8184 596.201,63.8189 596.211,63.8194 596.22,63.8199 596.229,63.8204 596.238,63.8209 596.247,63.8214 596.257,63.8219 596.266,63.8224 596.275,63.8229 596.284,63.8234 596.293,63.8239 596.302,63.8244 596.312,63.8249 596.321,63.8254 596.33,63.8259 596.339,63.8264 596.348,63.8269 596.358,63.8274 596.367,63.8279 596.376,63.8285 596.385,63.829 596.394,63.8295 596.404,63.83 596.413,63.8305 596.422,63.831 596.431,63.8315 596.44,63.832 596.45,63.8325 596.459,63.833 596.468,63.8336 596.477,63.8341 596.486,63.8346 596.495,63.8351 596.505,63.8356 596.514,63.8361 596.523,63.8366 596.532,63.8372 596.541,63.8377 596.551,63.8382 596.56,63.8387 596.569,63.8392 596.578,63.8397 596.587,63.8403 596.597,63.8408 596.606,63.8413 596.615,63.8418 596.624,63.8423 596.633,63.8429 596.642,63.8434 596.652,63.8439 596.661,63.8444 596.67,63.8449 596.679,63.8455 596.688,63.846 596.698,63.8465 596.707,63.847 596.716,63.8476 596.725,63.8481 596.734,63.8486 596.744,63.8492 596.753,63.8497 596.762,63.8502 596.771,63.8507 596.78,63.8513 596.79,63.8518 596.799,63.8523 596.808,63.8529 596.817,63.8534 596.826,63.8539 596.835,63.8545 596.845,63.855 596.854,63.8555 596.863,63.8561 596.872,63.8566 596.881,63.8571 596.891,63.8577 596.9,63.8582 596.909,63.8587 596.918,63.8593 596.927,63.8598 596.937,63.8604 596.946,63.8609 596.955,63.8614 596.964,63.862 596.973,63.8625 596.982,63.8631 596.992,63.8636 597.001,63.8641 597.01,63.8647 597.019,63.8652 597.028,63.8658 597.038,63.8663 597.047,63.8669 597.056,63.8674 597.065,63.868 597.074,63.8685 597.084,63.869 597.093,63.8696 597.102,63.8701 597.111,63.8707 597.12,63.8712 597.13,63.8718 597.139,63.8723 597.148,63.8729 597.157,63.8734 597.166,63.874 597.175,63.8745 597.185,63.8751 597.194,63.8757 597.203,63.8762 597.212,63.8768 597.221,63.8773 597.231,63.8779 597.24,63.8784 597.249,63.879 597.258,63.8795 597.267,63.8801 597.277,63.8807 597.286,63.8812 597.295,63.8818 597.304,63.8823 597.313,63.8829 597.322,63.8835 597.332,63.884 597.341,63.8846 597.35,63.8851 597.359,63.8857 597.368,63.8863 597.378,63.8868 597.387,63.8874 597.396,63.888 597.405,63.8885 597.414,63.8891 597.424,63.8897 597.433,63.8902 597.442,63.8908 597.451,63.8914 597.46,63.8919 597.47,63.8925 597.479,63.8931 597.488,63.8936 597.497,63.8942 597.506,63.8948 597.515,63.8954 597.525,63.8959 597.534,63.8965 597.543,63.8971 597.552,63.8976 597.561,63.8982 597.571,63.8988 597.58,63.8994 597.589,63.8999 597.598,63.9005 597.607,63.9011 597.617,63.9017 597.626,63.9023 597.635,63.9028 597.644,63.9034 597.653,63.904 597.662,63.9046 597.672,63.9052 597.681,63.9057 597.69,63.9063 597.699,63.9069 597.708,63.9075 597.718,63.9081 597.727,63.9087 597.736,63.9092 597.745,63.9098 597.754,63.9104 597.764,63.911 597.773,63.9116 597.782,63.9122 597.791,63.9128 597.8,63.9134 597.81,63.9139 597.819,63.9145 597.828,63.9151 597.837,63.9157 597.846,63.9163 597.855,63.9169 597.865,63.9175 597.874,63.9181 597.883,63.9187 597.892,63.9193 597.901,63.9199 597.911,63.9205 597.92,63.9211 597.929,63.9216 597.938,63.9222 597.947,63.9228 597.957,63.9234 597.966,63.924 597.975,63.9246 597.984,63.9252 597.993,63.9258 598.003,63.9264 598.012,63.927 598.021,63.9276 598.03,63.9282 598.039,63.9288 598.048,63.9294 598.058,63.9301 598.067,63.9307 598.076,63.9313 598.085,63.9319 598.094,63.9325 598.104,63.9331 598.113,63.9337 598.122,63.9343 598.131,63.9349 598.14,63.9355 598.15,63.9361 598.159,63.9367 598.168,63.9373 598.177,63.938 598.186,63.9386 598.195,63.9392 598.205,63.9398 598.214,63.9404 598.223,63.941 598.232,63.9416 598.241,63.9422 598.251,63.9429 598.26,63.9435 598.269,63.9441 598.278,63.9447 598.287,63.9453 598.297,63.9459 598.306,63.9466 598.315,63.9472 598.324,63.9478 598.333,63.9484 598.343,63.949 598.352,63.9497 598.361,63.9503 598.37,63.9509 598.379,63.9515 598.388,63.9522 598.398,63.9528 598.407,63.9534 598.416,63.954 598.425,63.9547 598.434,63.9553 598.444,63.9559 598.453,63.9565 598.462,63.9572 598.471,63.9578 598.48,63.9584 598.49,63.959 598.499,63.9597 598.508,63.9603 598.517,63.9609 598.526,63.9616 598.535,63.9622 598.545,63.9628 598.554,63.9635 598.563,63.9641 598.572,63.9647 598.581,63.9654 598.591,63.966 598.6,63.9666 598.609,63.9673 598.618,63.9679 598.627,63.9686 598.637,63.9692 598.646,63.9698 598.655,63.9705 598.664,63.9711 598.673,63.9718 598.683,63.9724 598.692,63.973 598.701,63.9737 598.71,63.9743 598.719,63.975 598.728,63.9756 598.738,63.9763 598.747,63.9769 598.756,63.9776 598.765,63.9782 598.774,63.9788 598.784,63.9795 598.793,63.9801 598.802,63.9808 598.811,63.9814 598.82,63.9821 598.83,63.9827 598.839,63.9834 598.848,63.984 598.857,63.9847 598.866,63.9853 598.875,63.986 598.885,63.9867 598.894,63.9873 598.903,63.988 598.912,63.9886 598.921,63.9893 598.931,63.9899 598.94,63.9906 598.949,63.9912 598.958,63.9919 598.967,63.9926 598.977,63.9932 598.986,63.9939 598.995,63.9945 599.004,63.9952 599.013,63.9959 599.023,63.9965 599.032,63.9972 599.041,63.9979 599.05,63.9985 599.059,63.9992 599.068,63.9998 599.078,64.0005 599.087,64.0012 599.096,64.0018 599.105,64.0025 599.114,64.0032 599.124,64.0038 599.133,64.0045 599.142,64.0052 599.151,64.0059 599.16,64.0065 599.17,64.0072 599.179,64.0079 599.188,64.0085 599.197,64.0092 599.206,64.0099 599.215,64.0106 599.225,64.0112 599.234,64.0119 599.243,64.0126 599.252,64.0133 599.261,64.0139 599.271,64.0146 599.28,64.0153 599.289,64.016 599.298,64.0167 599.307,64.0173 599.317,64.018 599.326,64.0187 599.335,64.0194 599.344,64.0201 599.353,64.0207 599.363,64.0214 599.372,64.0221 599.381,64.0228 599.39,64.0235 599.399,64.0242 599.408,64.0249 599.418,64.0255 599.427,64.0262 599.436,64.0269 599.445,64.0276 599.454,64.0283 599.464,64.029 599.473,64.0297 599.482,64.0304 599.491,64.0311 599.5,64.0317 599.51,64.0324 599.519,64.0331 599.528,64.0338 599.537,64.0345 599.546,64.0352 599.555,64.0359 599.565,64.0366 599.574,64.0373 599.583,64.038 599.592,64.0387 599.601,64.0394 599.611,64.0401 599.62,64.0408 599.629,64.0415 599.638,64.0422 599.647,64.0429 599.657,64.0436 599.666,64.0443 599.675,64.045 599.684,64.0457 599.693,64.0464 599.703,64.0471 599.712,64.0478 599.721,64.0485 599.73,64.0492 599.739,64.0499 599.748,64.0506 599.758,64.0514 599.767,64.0521 599.776,64.0528 599.785,64.0535 599.794,64.0542 599.804,64.0549 599.813,64.0556 599.822,64.0563 599.831,64.057 599.84,64.0578 599.85,64.0585 599.859,64.0592 599.868,64.0599 599.877,64.0606 599.886,64.0613 599.895,64.062 599.905,64.0628 599.914,64.0635 599.923,64.0642 599.932,64.0649 599.941,64.0656 599.951,64.0664 599.96,64.0671 599.969,64.0678 599.978,64.0685 599.987,64.0692 599.997,64.07 600.006,64.0707 600.015,64.0714 600.024,64.0721 600.033,64.0729 600.043,64.0736 600.052,64.0743 600.061,64.0751 600.07,64.0758 600.079,64.0765 600.088,64.0772 600.098,64.078 600.107,64.0787 600.116,64.0794 600.125,64.0802 600.134,64.0809 600.144,64.0816 600.153,64.0824 600.162,64.0831 600.171,64.0838 600.18,64.0846 600.19,64.0853 600.199,64.086 600.208,64.0868 600.217,64.0875 600.226,64.0882 600.236,64.089 600.245,64.0897 600.254,64.0905 600.263,64.0912 600.272,64.0919 600.281,64.0927 600.291,64.0934 600.3,64.0942 600.309,64.0949 600.318,64.0957 600.327,64.0964 600.337,64.0972 600.346,64.0979 600.355,64.0986 600.364,64.0994 600.373,64.1001 600.383,64.1009 600.392,64.1016 600.401,64.1024 600.41,64.1031 600.419,64.1039 600.428,64.1046 600.438,64.1054 600.447,64.1061 600.456,64.1069 600.465,64.1076 600.474,64.1084 600.484,64.1092 600.493,64.1099 600.502,64.1107 600.511,64.1114 600.52,64.1122 600.53,64.1129 600.539,64.1137 600.548,64.1145 600.557,64.1152 600.566,64.116 600.576,64.1167 600.585,64.1175 600.594,64.1183 600.603,64.119 600.612,64.1198 600.621,64.1206 600.631,64.1213 600.64,64.1221 600.649,64.1228 600.658,64.1236 600.667,64.1244 600.677,64.1251 600.686,64.1259 600.695,64.1267 600.704,64.1275 600.713,64.1282 600.723,64.129 600.732,64.1298 600.741,64.1305 600.75,64.1313 600.759,64.1321 600.768,64.1329 600.778,64.1336 600.787,64.1344 600.796,64.1352 600.805,64.136 600.814,64.1367 600.824,64.1375 600.833,64.1383 600.842,64.1391 600.851,64.1398 600.86,64.1406 600.87,64.1414 600.879,64.1422 600.888,64.143 600.897,64.1438 600.906,64.1445 600.916,64.1453 600.925,64.1461 600.934,64.1469 600.943,64.1477 600.952,64.1485 600.961,64.1492 600.971,64.15 600.98,64.1508 600.989,64.1516 600.998,64.1524 601.007,64.1532 601.017,64.154 601.026,64.1548 601.035,64.1556 601.044,64.1563 601.053,64.1571 601.063,64.1579 601.072,64.1587 601.081,64.1595 601.09,64.1603 601.099,64.1611 601.108,64.1619 601.118,64.1627 601.127,64.1635 601.136,64.1643 601.145,64.1651 601.154,64.1659 601.164,64.1667 601.173,64.1675 601.182,64.1683 601.191,64.1691 601.2,64.1699 601.21,64.1707 601.219,64.1715 601.228,64.1723 601.237,64.1731 601.246,64.1739 601.256,64.1747 601.265,64.1755 601.274,64.1763 601.283,64.1772 601.292,64.178 601.301,64.1788 601.311,64.1796 601.32,64.1804 601.329,64.1812 601.338,64.182 601.347,64.1828 601.357,64.1836 601.366,64.1845 601.375,64.1853 601.384,64.1861 601.393,64.1869 601.403,64.1877 601.412,64.1885 601.421,64.1893 601.43,64.1902 601.439,64.191 601.448,64.1918 601.458,64.1926 601.467,64.1934 601.476,64.1943 601.485,64.1951 601.494,64.1959 601.504,64.1967 601.513,64.1976 601.522,64.1984 601.531,64.1992 601.54,64.2 601.55,64.2009 601.559,64.2017 601.568,64.2025 601.577,64.2033 601.586,64.2042 601.596,64.205 601.605,64.2058 601.614,64.2067 601.623,64.2075 601.632,64.2083 601.641,64.2091 601.651,64.21 601.66,64.2108 601.669,64.2116 601.678,64.2125 601.687,64.2133 601.697,64.2142 601.706,64.215 601.715,64.2158 601.724,64.2167 601.733,64.2175 601.743,64.2183 601.752,64.2192 601.761,64.22 601.77,64.2209 601.779,64.2217 601.788,64.2225 601.798,64.2234 601.807,64.2242 601.816,64.2251 601.825,64.2259 601.834,64.2268 601.844,64.2276 601.853,64.2285 601.862,64.2293 601.871,64.2302 601.88,64.231 601.89,64.2319 601.899,64.2327 601.908,64.2336 601.917,64.2344 601.926,64.2353 601.936,64.2361 601.945,64.237 601.954,64.2378 601.963,64.2387 601.972,64.2395 601.981,64.2404 601.991,64.2412 602,64.2421 602.009,64.243 602.018,64.2438 602.027,64.2447 602.037,64.2455 602.046,64.2464 602.055,64.2472 602.064,64.2481 602.073,64.249 602.083,64.2498 602.092,64.2507 602.101,64.2516 602.11,64.2524 602.119,64.2533 602.128,64.2542 602.138,64.255 602.147,64.2559 602.156,64.2568 602.165,64.2576 602.174,64.2585 602.184,64.2594 602.193,64.2602 602.202,64.2611 602.211,64.262 602.22,64.2629 602.23,64.2637 602.239,64.2646 602.248,64.2655 602.257,64.2663 602.266,64.2672 602.276,64.2681 602.285,64.269 602.294,64.2699 602.303,64.2707 602.312,64.2716 602.321,64.2725 602.331,64.2734 602.34,64.2742 602.349,64.2751 602.358,64.276 602.367,64.2769 602.377,64.2778 602.386,64.2787 602.395,64.2795 602.404,64.2804 602.413,64.2813 602.423,64.2822 602.432,64.2831 602.441,64.284 602.45,64.2849 602.459,64.2858 602.468,64.2866 602.478,64.2875 602.487,64.2884 602.496,64.2893 602.505,64.2902 602.514,64.2911 602.524,64.292 602.533,64.2929 602.542,64.2938 602.551,64.2947 602.56,64.2956 602.57,64.2965 602.579,64.2974 602.588,64.2983 602.597,64.2992 602.606,64.3001 602.616,64.301 602.625,64.3019 602.634,64.3028 602.643,64.3037 602.652,64.3046 602.661,64.3055 602.671,64.3064 602.68,64.3073 602.689,64.3082 602.698,64.3091 602.707,64.31 602.717,64.3109 602.726,64.3118 602.735,64.3127 602.744,64.3136 602.753,64.3146 602.763,64.3155 602.772,64.3164 602.781,64.3173 602.79,64.3182 602.799,64.3191 602.809,64.32 602.818,64.3209 602.827,64.3219 602.836,64.3228 602.845,64.3237 602.854,64.3246 602.864,64.3255 602.873,64.3264 602.882,64.3274 602.891,64.3283 602.9,64.3292 602.91,64.3301 602.919,64.331 602.928,64.332 602.937,64.3329 602.946,64.3338 602.956,64.3347 602.965,64.3357 602.974,64.3366 602.983,64.3375 602.992,64.3384 603.001,64.3394 603.011,64.3403 603.02,64.3412 603.029,64.3422 603.038,64.3431 603.047,64.344 603.057,64.3449 603.066,64.3459 603.075,64.3468 603.084,64.3477 603.093,64.3487 603.103,64.3496 603.112,64.3506 603.121,64.3515 603.13,64.3524 603.139,64.3534 603.149,64.3543 603.158,64.3552 603.167,64.3562 603.176,64.3571 603.185,64.3581 603.194,64.359 603.204,64.3599 603.213,64.3609 603.222,64.3618 603.231,64.3628 603.24,64.3637 603.25,64.3647 603.259,64.3656 603.268,64.3666 603.277,64.3675 603.286,64.3685 603.296,64.3694 603.305,64.3704 603.314,64.3713 603.323,64.3723 603.332,64.3732 603.341,64.3742 603.351,64.3751 603.36,64.3761 603.369,64.377 603.378,64.378 603.387,64.3789 603.397,64.3799 603.406,64.3809 603.415,64.3818 603.424,64.3828 603.433,64.3837 603.443,64.3847 603.452,64.3856 603.461,64.3866 603.47,64.3876 603.479,64.3885 603.489,64.3895 603.498,64.3905 603.507,64.3914 603.516,64.3924 603.525,64.3934 603.534,64.3943 603.544,64.3953 603.553,64.3963 603.562,64.3972 603.571,64.3982 603.58,64.3992 603.59,64.4001 603.599,64.4011 603.608,64.4021 603.617,64.4031 603.626,64.404 603.636,64.405 603.645,64.406 603.654,64.407 603.663,64.4079 603.672,64.4089 603.681,64.4099 603.691,64.4109 603.7,64.4118 603.709,64.4128 603.718,64.4138 603.727,64.4148 603.737,64.4158 603.746,64.4167 603.755,64.4177 603.764,64.4187 603.773,64.4197 603.783,64.4207 603.792,64.4217 603.801,64.4227 603.81,64.4236 603.819,64.4246 603.829,64.4256 603.838,64.4266 603.847,64.4276 603.856,64.4286 603.865,64.4296 603.874,64.4306 603.884,64.4316 603.893,64.4326 603.902,64.4336 603.911,64.4345 603.92,64.4355 603.93,64.4365 603.939,64.4375 603.948,64.4385 603.957,64.4395 603.966,64.4405 603.976,64.4415 603.985,64.4425 603.994,64.4435 604.003,64.4445 604.012,64.4455 604.021,64.4465 604.031,64.4475 604.04,64.4485 604.049,64.4495 604.058,64.4506 604.067,64.4516 604.077,64.4526 604.086,64.4536 604.095,64.4546 604.104,64.4556 604.113,64.4566 604.123,64.4576 604.132,64.4586 604.141,64.4596 604.15,64.4607 604.159,64.4617 604.169,64.4627 604.178,64.4637 604.187,64.4647 604.196,64.4657 604.205,64.4667 604.214,64.4678 604.224,64.4688 604.233,64.4698 604.242,64.4708 604.251,64.4718 604.26,64.4729 604.27,64.4739 604.279,64.4749 604.288,64.4759 604.297,64.4769 604.306,64.478 604.316,64.479 604.325,64.48 604.334,64.4811 604.343,64.4821 604.352,64.4831 604.361,64.4841 604.371,64.4852 604.38,64.4862 604.389,64.4872 604.398,64.4883 604.407,64.4893 604.417,64.4903 604.426,64.4914 604.435,64.4924 604.444,64.4934 604.453,64.4945 604.463,64.4955 604.472,64.4965 604.481,64.4976 604.49,64.4986 604.499,64.4997 604.509,64.5007 604.518,64.5017 604.527,64.5028 604.536,64.5038 604.545,64.5049 604.554,64.5059 604.564,64.5069 604.573,64.508 604.582,64.509 604.591,64.5101 604.6,64.5111 604.61,64.5122 604.619,64.5132 604.628,64.5143 604.637,64.5153 604.646,64.5164 604.656,64.5174 604.665,64.5185 604.674,64.5195 604.683,64.5206 604.692,64.5216 604.701,64.5227 604.711,64.5238 604.72,64.5248 604.729,64.5259 604.738,64.5269 604.747,64.528 604.757,64.529 604.766,64.5301 604.775,64.5312 604.784,64.5322 604.793,64.5333 604.803,64.5343 604.812,64.5354 604.821,64.5365 604.83,64.5375 604.839,64.5386 604.849,64.5397 604.858,64.5407 604.867,64.5418 604.876,64.5429 604.885,64.5439 604.894,64.545 604.904,64.5461 604.913,64.5472 604.922,64.5482 604.931,64.5493 604.94,64.5504 604.95,64.5514 604.959,64.5525 604.968,64.5536 604.977,64.5547 604.986,64.5558 604.996,64.5568 605.005,64.5579 605.014,64.559 605.023,64.5601 605.032,64.5611 605.041,64.5622 605.051,64.5633 605.06,64.5644 605.069,64.5655 605.078,64.5666 605.087,64.5676 605.097,64.5687 605.106,64.5698 605.115,64.5709 605.124,64.572 605.133,64.5731 605.143,64.5742 605.152,64.5753 605.161,64.5764 605.17,64.5774 605.179,64.5785 605.189,64.5796 605.198,64.5807 605.207,64.5818 605.216,64.5829 605.225,64.584 605.234,64.5851 605.244,64.5862 605.253,64.5873 605.262,64.5884 605.271,64.5895 605.28,64.5906 605.29,64.5917 605.299,64.5928 605.308,64.5939 605.317,64.595 605.326,64.5961 605.336,64.5972 605.345,64.5983 605.354,64.5994 605.363,64.6005 605.372,64.6016 605.382,64.6028 605.391,64.6039 605.4,64.605 605.409,64.6061 605.418,64.6072 605.427,64.6083 605.437,64.6094 605.446,64.6105 605.455,64.6116 605.464,64.6128 605.473,64.6139 605.483,64.615 605.492,64.6161 605.501,64.6172 605.51,64.6183 605.519,64.6195 605.529,64.6206 605.538,64.6217 605.547,64.6228 605.556,64.6239 605.565,64.6251 605.574,64.6262 605.584,64.6273 605.593,64.6284 605.602,64.6296 605.611,64.6307 605.62,64.6318 605.63,64.633 605.639,64.6341 605.648,64.6352 605.657,64.6363 605.666,64.6375 605.676,64.6386 605.685,64.6397 605.694,64.6409 605.703,64.642 605.712,64.6431 605.722,64.6443 605.731,64.6454 605.74,64.6465 605.749,64.6477 605.758,64.6488 605.767,64.65 605.777,64.6511 605.786,64.6522 605.795,64.6534 605.804,64.6545 605.813,64.6557 605.823,64.6568 605.832,64.658 605.841,64.6591 605.85,64.6603 605.859,64.6614 605.869,64.6625 605.878,64.6637 605.887,64.6648 605.896,64.666 605.905,64.6671 605.914,64.6683 605.924,64.6694 605.933,64.6706 605.942,64.6718 605.951,64.6729 605.96,64.6741 605.97,64.6752 605.979,64.6764 605.988,64.6775 605.997,64.6787 606.006,64.6798 606.016,64.681 606.025,64.6822 606.034,64.6833 606.043,64.6845 606.052,64.6857 606.062,64.6868 606.071,64.688 606.08,64.6891 606.089,64.6903 606.098,64.6915 606.107,64.6926 606.117,64.6938 606.126,64.695 606.135,64.6961 606.144,64.6973 606.153,64.6985 606.163,64.6997 606.172,64.7008 606.181,64.702 606.19,64.7032 606.199,64.7044 606.209,64.7055 606.218,64.7067 606.227,64.7079 606.236,64.7091 606.245,64.7102 606.254,64.7114 606.264,64.7126 606.273,64.7138 606.282,64.715 606.291,64.7161 606.3,64.7173 606.31,64.7185 606.319,64.7197 606.328,64.7209 606.337,64.7221 606.346,64.7233 606.356,64.7244 606.365,64.7256 606.374,64.7268 606.383,64.728 606.392,64.7292 606.402,64.7304 606.411,64.7316 606.42,64.7328 606.429,64.734 606.438,64.7352 606.447,64.7364 606.457,64.7376 606.466,64.7387 606.475,64.7399 606.484,64.7411 606.493,64.7423 606.503,64.7435 606.512,64.7447 606.521,64.7459 606.53,64.7471 606.539,64.7483 606.549,64.7496 606.558,64.7508 606.567,64.752 606.576,64.7532 606.585,64.7544 606.594,64.7556 606.604,64.7568 606.613,64.758 606.622,64.7592 606.631,64.7604 606.64,64.7616 606.65,64.7628 606.659,64.7641 606.668,64.7653 606.677,64.7665 606.686,64.7677 606.696,64.7689 606.705,64.7701 606.714,64.7713 606.723,64.7726 606.732,64.7738 606.742,64.775 606.751,64.7762 606.76,64.7774 606.769,64.7787 606.778,64.7799 606.787,64.7811 606.797,64.7823 606.806,64.7836 606.815,64.7848 606.824,64.786 606.833,64.7872 606.843,64.7885 606.852,64.7897 606.861,64.7909 606.87,64.7922 606.879,64.7934 606.889,64.7946 606.898,64.7959 606.907,64.7971 606.916,64.7983 606.925,64.7996 606.934,64.8008 606.944,64.802 606.953,64.8033 606.962,64.8045 606.971,64.8057 606.98,64.807 606.99,64.8082 606.999,64.8095 607.008,64.8107 607.017,64.812 607.026,64.8132 607.036,64.8144 607.045,64.8157 607.054,64.8169 607.063,64.8182 607.072,64.8194 607.082,64.8207 607.091,64.8219 607.1,64.8232 607.109,64.8244 607.118,64.8257 607.127,64.8269 607.137,64.8282 607.146,64.8294 607.155,64.8307 607.164,64.832 607.173,64.8332 607.183,64.8345 607.192,64.8357 607.201,64.837 607.21,64.8382 607.219,64.8395 607.229,64.8408 607.238,64.842 607.247,64.8433 607.256,64.8446 607.265,64.8458 607.274,64.8471 607.284,64.8483 607.293,64.8496 607.302,64.8509 607.311,64.8522 607.32,64.8534 607.33,64.8547 607.339,64.856 607.348,64.8572 607.357,64.8585 607.366,64.8598 607.376,64.8611 607.385,64.8623 607.394,64.8636 607.403,64.8649 607.412,64.8662 607.422,64.8674 607.431,64.8687 607.44,64.87 607.449,64.8713 607.458,64.8726 607.467,64.8738 607.477,64.8751 607.486,64.8764 607.495,64.8777 607.504,64.879 607.513,64.8803 607.523,64.8815 607.532,64.8828 607.541,64.8841 607.55,64.8854 607.559,64.8867 607.569,64.888 607.578,64.8893 607.587,64.8906 607.596,64.8919 607.605,64.8932 607.615,64.8945 607.624,64.8957 607.633,64.897 607.642,64.8983 607.651,64.8996 607.66,64.9009 607.67,64.9022 607.679,64.9035 607.688,64.9048 607.697,64.9061 607.706,64.9074 607.716,64.9087 607.725,64.9101 607.734,64.9114 607.743,64.9127 607.752,64.914 607.762,64.9153 607.771,64.9166 607.78,64.9179 607.789,64.9192 607.798,64.9205 607.807,64.9218 607.817,64.9231 607.826,64.9245 607.835,64.9258 607.844,64.9271 607.853,64.9284 607.863,64.9297 607.872,64.931 607.881,64.9323 607.89,64.9337 607.899,64.935 607.909,64.9363 607.918,64.9376 607.927,64.939 607.936,64.9403 607.945,64.9416 607.955,64.9429 607.964,64.9442 607.973,64.9456 607.982,64.9469 607.991,64.9482 608,64.9496 608.01,64.9509 608.019,64.9522 608.028,64.9535 608.037,64.9549 608.046,64.9562 608.056,64.9575 608.065,64.9589 608.074,64.9602 608.083,64.9616 608.092,64.9629 608.102,64.9642 608.111,64.9656 608.12,64.9669 608.129,64.9682 608.138,64.9696 608.147,64.9709 608.157,64.9723 608.166,64.9736 608.175,64.975 608.184,64.9763 608.193,64.9776 608.203,64.979 608.212,64.9803 608.221,64.9817 608.23,64.983 608.239,64.9844 608.249,64.9857 608.258,64.9871 608.267,64.9884 608.276,64.9898 608.285,64.9912 608.295,64.9925 608.304,64.9939 608.313,64.9952 608.322,64.9966 608.331,64.9979 608.34,64.9993 608.35,65.0007 608.359,65.002 608.368,65.0034 608.377,65.0047 608.386,65.0061 608.396,65.0075 608.405,65.0088 608.414,65.0102 608.423,65.0116 608.432,65.0129 608.442,65.0143 608.451,65.0157 608.46,65.017 608.469,65.0184 608.478,65.0198 608.487,65.0212 608.497,65.0225 608.506,65.0239 608.515,65.0253 608.524,65.0267 608.533,65.028 608.543,65.0294 608.552,65.0308 608.561,65.0322 608.57,65.0335 608.579,65.0349 608.589,65.0363 608.598,65.0377 608.607,65.0391 608.616,65.0405 608.625,65.0418 608.635,65.0432 608.644,65.0446 608.653,65.046 608.662,65.0474 608.671,65.0488 608.68,65.0502 608.69,65.0516 608.699,65.0529 608.708,65.0543 608.717,65.0557 608.726,65.0571 608.736,65.0585 608.745,65.0599 608.754,65.0613 608.763,65.0627 608.772,65.0641 608.782,65.0655 608.791,65.0669 608.8,65.0683 608.809,65.0697 608.818,65.0711 608.827,65.0725 608.837,65.0739 608.846,65.0753 608.855,65.0767 608.864,65.0781 608.873,65.0796 608.883,65.081 608.892,65.0824 608.901,65.0838 608.91,65.0852 608.919,65.0866 608.929,65.088 608.938,65.0894 608.947,65.0908 608.956,65.0923 608.965,65.0937 608.975,65.0951 608.984,65.0965 608.993,65.0979 609.002,65.0993 609.011,65.1008 609.02,65.1022 609.03,65.1036 609.039,65.105 609.048,65.1065 609.057,65.1079 609.066,65.1093 609.076,65.1107 609.085,65.1122 609.094,65.1136 609.103,65.115 609.112,65.1164 609.122,65.1179 609.131,65.1193 609.14,65.1207 609.149,65.1222 609.158,65.1236 609.167,65.125 609.177,65.1265 609.186,65.1279 609.195,65.1294 609.204,65.1308 609.213,65.1322 609.223,65.1337 609.232,65.1351 609.241,65.1366 609.25,65.138 609.259,65.1394 609.269,65.1409 609.278,65.1423 609.287,65.1438 609.296,65.1452 609.305,65.1467 609.315,65.1481 609.324,65.1496 609.333,65.151 609.342,65.1525 609.351,65.1539 609.36,65.1554 609.37,65.1568 609.379,65.1583 609.388,65.1597 609.397,65.1612 609.406,65.1627 609.416,65.1641 609.425,65.1656 609.434,65.167 609.443,65.1685 609.452,65.17 609.462,65.1714 609.471,65.1729 609.48,65.1743 609.489,65.1758 609.498,65.1773 609.507,65.1787 609.517,65.1802 609.526,65.1817 609.535,65.1832 609.544,65.1846 609.553,65.1861 609.563,65.1876 609.572,65.189 609.581,65.1905 609.59,65.192 609.599,65.1935 609.609,65.1949 609.618,65.1964 609.627,65.1979 609.636,65.1994 609.645,65.2009 609.655,65.2023 609.664,65.2038 609.673,65.2053 609.682,65.2068 609.691,65.2083 609.7,65.2098 609.71,65.2112 609.719,65.2127 609.728,65.2142 609.737,65.2157 609.746,65.2172 609.756,65.2187 609.765,65.2202 609.774,65.2217 609.783,65.2232 609.792,65.2247 609.802,65.2261 609.811,65.2276 609.82,65.2291 609.829,65.2306 609.838,65.2321 609.847,65.2336 609.857,65.2351 609.866,65.2366 609.875,65.2381 609.884,65.2396 609.893,65.2411 609.903,65.2427 609.912,65.2442 609.921,65.2457 609.93,65.2472 609.939,65.2487 609.949,65.2502 609.958,65.2517 609.967,65.2532 609.976,65.2547 609.985,65.2562 609.995,65.2577 610.004,65.2593 610.013,65.2608 610.022,65.2623 610.031,65.2638 610.04,65.2653 610.05,65.2668 610.059,65.2684 610.068,65.2699 610.077,65.2714 610.086,65.2729 610.096,65.2745 610.105,65.276 610.114,65.2775 610.123,65.279 610.132,65.2806 610.142,65.2821 610.151,65.2836 610.16,65.2851 610.169,65.2867 610.178,65.2882 610.188,65.2897 610.197,65.2913 610.206,65.2928 610.215,65.2943 610.224,65.2959 610.233,65.2974 610.243,65.2989 610.252,65.3005 610.261,65.302 610.27,65.3036 610.279,65.3051 610.289,65.3067 610.298,65.3082 610.307,65.3097 610.316,65.3113 610.325,65.3128 610.335,65.3144 610.344,65.3159 610.353,65.3175 610.362,65.319 610.371,65.3206 610.38,65.3221 610.39,65.3237 610.399,65.3252 610.408,65.3268 610.417,65.3283 610.426,65.3299 610.436,65.3314 610.445,65.333 610.454,65.3346 610.463,65.3361 610.472,65.3377 610.482,65.3392 610.491,65.3408 610.5,65.3424 610.509,65.3439 610.518,65.3455 610.528,65.3471 610.537,65.3486 610.546,65.3502 610.555,65.3518 610.564,65.3533 610.573,65.3549 610.583,65.3565 610.592,65.358 610.601,65.3596 610.61,65.3612 610.619,65.3628 610.629,65.3643 610.638,65.3659 610.647,65.3675 610.656,65.3691 610.665,65.3707 610.675,65.3722 610.684,65.3738 610.693,65.3754 610.702,65.377 610.711,65.3786 610.72,65.3802 610.73,65.3817 610.739,65.3833 610.748,65.3849 610.757,65.3865 610.766,65.3881 610.776,65.3897 610.785,65.3913 610.794,65.3929 610.803,65.3945 610.812,65.3961 610.822,65.3976 610.831,65.3992 610.84,65.4008 610.849,65.4024 610.858,65.404 610.868,65.4056 610.877,65.4072 610.886,65.4088 610.895,65.4104 610.904,65.412 610.913,65.4136 610.923,65.4153 610.932,65.4169 610.941,65.4185 610.95,65.4201 610.959,65.4217 610.969,65.4233 610.978,65.4249 610.987,65.4265 610.996,65.4281 611.005,65.4297 611.015,65.4314 611.024,65.433 611.033,65.4346 611.042,65.4362 611.051,65.4378 611.06,65.4394 611.07,65.4411 611.079,65.4427 611.088,65.4443 611.097,65.4459 611.106,65.4475 611.116,65.4492 611.125,65.4508 611.134,65.4524 611.143,65.4541 611.152,65.4557 611.162,65.4573 611.171,65.4589 611.18,65.4606 611.189,65.4622 611.198,65.4638 611.208,65.4655 611.217,65.4671 611.226,65.4687 611.235,65.4704 611.244,65.472 611.253,65.4737 611.263,65.4753 611.272,65.4769 611.281,65.4786 611.29,65.4802 611.299,65.4819 611.309,65.4835 611.318,65.4851 611.327,65.4868 611.336,65.4884 611.345,65.4901 611.355,65.4917 611.364,65.4934 611.373,65.495 611.382,65.4967 611.391,65.4983 611.4,65.5 611.41,65.5017 611.419,65.5033 611.428,65.505 611.437,65.5066 611.446,65.5083 611.456,65.5099 611.465,65.5116 611.474,65.5133 611.483,65.5149 611.492,65.5166 611.502,65.5183 611.511,65.5199 611.52,65.5216 611.529,65.5232 611.538,65.5249 611.548,65.5266 611.557,65.5283 611.566,65.5299 611.575,65.5316 611.584,65.5333 611.593,65.5349 611.603,65.5366 611.612,65.5383 611.621,65.54 611.63,65.5416 611.639,65.5433 611.649,65.545 611.658,65.5467 611.667,65.5484 611.676,65.55 611.685,65.5517 611.695,65.5534 611.704,65.5551 611.713,65.5568 611.722,65.5585 611.731,65.5602 611.74,65.5618 611.75,65.5635 611.759,65.5652 611.768,65.5669 611.777,65.5686 611.786,65.5703 611.796,65.572 611.805,65.5737 611.814,65.5754 611.823,65.5771 611.832,65.5788 611.842,65.5805 611.851,65.5822 611.86,65.5839 611.869,65.5856 611.878,65.5873 611.888,65.589 611.897,65.5907 611.906,65.5924 611.915,65.5941 611.924,65.5958 611.933,65.5975 611.943,65.5992 611.952,65.601 611.961,65.6027 611.97,65.6044 611.979,65.6061 611.989,65.6078 611.998,65.6095 612.007,65.6112 612.016,65.613 612.025,65.6147 612.035,65.6164 612.044,65.6181 612.053,65.6198 612.062,65.6216 612.071,65.6233 612.08,65.625 612.09,65.6267 612.099,65.6285 612.108,65.6302 612.117,65.6319 612.126,65.6336 612.136,65.6354 612.145,65.6371 612.154,65.6388 612.163,65.6406 612.172,65.6423 612.182,65.644 612.191,65.6458 612.2,65.6475 612.209,65.6493 612.218,65.651 612.228,65.6527 612.237,65.6545 612.246,65.6562 612.255,65.658 612.264,65.6597 612.273,65.6615 612.283,65.6632 612.292,65.6649 612.301,65.6667 612.31,65.6684 612.319,65.6702 612.329,65.6719 612.338,65.6737 612.347,65.6754 612.356,65.6772 612.365,65.679 612.375,65.6807 612.384,65.6825 612.393,65.6842 612.402,65.686 612.411,65.6877 612.42,65.6895 612.43,65.6913 612.439,65.693 612.448,65.6948 612.457,65.6966 612.466,65.6983 612.476,65.7001 612.485,65.7019 612.494,65.7036 612.503,65.7054 612.512,65.7072 612.522,65.7089 612.531,65.7107 612.54,65.7125 612.549,65.7143 612.558,65.716 612.568,65.7178 612.577,65.7196 612.586,65.7214 612.595,65.7231 612.604,65.7249 612.613,65.7267 612.623,65.7285 612.632,65.7303 612.641,65.7321 612.65,65.7338 612.659,65.7356 612.669,65.7374 612.678,65.7392 612.687,65.741 612.696,65.7428 612.705,65.7446 612.715,65.7464 612.724,65.7482 612.733,65.75 612.742,65.7518 612.751,65.7535 612.761,65.7553 612.77,65.7571 612.779,65.7589 612.788,65.7607 612.797,65.7625 612.806,65.7643 612.816,65.7662 612.825,65.768 612.834,65.7698 612.843,65.7716 612.852,65.7734 612.862,65.7752 612.871,65.777 612.88,65.7788 612.889,65.7806 612.898,65.7824 612.908,65.7842 612.917,65.7861 612.926,65.7879 612.935,65.7897 612.944,65.7915 612.953,65.7933 612.963,65.7951 612.972,65.797 612.981,65.7988 612.99,65.8006 612.999,65.8024 613.009,65.8043 613.018,65.8061 613.027,65.8079 613.036,65.8097 613.045,65.8116 613.055,65.8134 613.064,65.8152 613.073,65.8171 613.082,65.8189 613.091,65.8207 613.101,65.8226 613.11,65.8244 613.119,65.8262 613.128,65.8281 613.137,65.8299 613.146,65.8317 613.156,65.8336 613.165,65.8354 613.174,65.8373 613.183,65.8391 613.192,65.841 613.202,65.8428 613.211,65.8447 613.22,65.8465 613.229,65.8484 613.238,65.8502 613.248,65.8521 613.257,65.8539 613.266,65.8558 613.275,65.8576 613.284,65.8595 613.293,65.8613 613.303,65.8632 613.312,65.865 613.321,65.8669 613.33,65.8688 613.339,65.8706 613.349,65.8725 613.358,65.8743 613.367,65.8762 613.376,65.8781 613.385,65.8799 613.395,65.8818 613.404,65.8837 613.413,65.8855 613.422,65.8874 613.431,65.8893 613.441,65.8912 613.45,65.893 613.459,65.8949 613.468,65.8968 613.477,65.8987 613.486,65.9005 613.496,65.9024 613.505,65.9043 613.514,65.9062 613.523,65.9081 613.532,65.9099 613.542,65.9118 613.551,65.9137 613.56,65.9156 613.569,65.9175 613.578,65.9194 613.588,65.9213 613.597,65.9232 613.606,65.925 613.615,65.9269 613.624,65.9288 613.633,65.9307 613.643,65.9326 613.652,65.9345 613.661,65.9364 613.67,65.9383 613.679,65.9402 613.689,65.9421 613.698,65.944 613.707,65.9459 613.716,65.9478 613.725,65.9497 613.735,65.9516 613.744,65.9535 613.753,65.9554 613.762,65.9574 613.771,65.9593 613.781,65.9612 613.79,65.9631 613.799,65.965 613.808,65.9669 613.817,65.9688 613.826,65.9707 613.836,65.9727 613.845,65.9746 613.854,65.9765 613.863,65.9784 613.872,65.9803 613.882,65.9823 613.891,65.9842 613.9,65.9861 613.909,65.988 613.918,65.99 613.928,65.9919 613.937,65.9938 613.946,65.9957 613.955,65.9977 613.964,65.9996 613.973,66.0015 613.983,66.0035 613.992,66.0054 614.001,66.0074 614.01,66.0093 614.019,66.0112 614.029,66.0132 614.038,66.0151 614.047,66.017 614.056,66.019 614.065,66.0209 614.075,66.0229 614.084,66.0248 614.093,66.0268 614.102,66.0287 614.111,66.0307 614.121,66.0326 614.13,66.0346 614.139,66.0365 614.148,66.0385 614.157,66.0404 614.166,66.0424 614.176,66.0443 614.185,66.0463 614.194,66.0483 614.203,66.0502 614.212,66.0522 614.222,66.0541 614.231,66.0561 614.24,66.0581 614.249,66.06 614.258,66.062 614.268,66.064 614.277,66.0659 614.286,66.0679 614.295,66.0699 614.304,66.0718 614.313,66.0738 614.323,66.0758 614.332,66.0778 614.341,66.0797 614.35,66.0817 614.359,66.0837 614.369,66.0857 614.378,66.0876 614.387,66.0896 614.396,66.0916 614.405,66.0936 614.415,66.0956 614.424,66.0976 614.433,66.0995 614.442,66.1015 614.451,66.1035 614.461,66.1055 614.47,66.1075 614.479,66.1095 614.488,66.1115 614.497,66.1135 614.506,66.1155 614.516,66.1175 614.525,66.1195 614.534,66.1215 614.543,66.1235 614.552,66.1255 614.562,66.1275 614.571,66.1295 614.58,66.1315 614.589,66.1335 614.598,66.1355 614.608,66.1375 614.617,66.1395 614.626,66.1415 614.635,66.1435 614.644,66.1455 614.653,66.1475 614.663,66.1496 614.672,66.1516 614.681,66.1536 614.69,66.1556 614.699,66.1576 614.709,66.1596 614.718,66.1617 614.727,66.1637 614.736,66.1657 614.745,66.1677 614.755,66.1697 614.764,66.1718 614.773,66.1738 614.782,66.1758 614.791,66.1779 614.801,66.1799 614.81,66.1819 614.819,66.1839 614.828,66.186 614.837,66.188 614.846,66.19 614.856,66.1921 614.865,66.1941 614.874,66.1962 614.883,66.1982 614.892,66.2002 614.902,66.2023 614.911,66.2043 614.92,66.2064 614.929,66.2084 614.938,66.2105 614.948,66.2125 614.957,66.2146 614.966,66.2166 614.975,66.2187 614.984,66.2207 614.994,66.2228 615.003,66.2248 615.012,66.2269 615.021,66.2289 615.03,66.231 615.039,66.233 615.049,66.2351 615.058,66.2372 615.067,66.2392 615.076,66.2413 615.085,66.2433 615.095,66.2454 615.104,66.2475 615.113,66.2495 615.122,66.2516 615.131,66.2537 615.141,66.2558 615.15,66.2578 615.159,66.2599 615.168,66.262 615.177,66.264 615.186,66.2661 615.196,66.2682 615.205,66.2703 615.214,66.2724 615.223,66.2744 615.232,66.2765 615.242,66.2786 615.251,66.2807 615.26,66.2828 615.269,66.2849 615.278,66.2869 615.288,66.289 615.297,66.2911 615.306,66.2932 615.315,66.2953 615.324,66.2974 615.334,66.2995 615.343,66.3016 615.352,66.3037 615.361,66.3058 615.37,66.3079 615.379,66.31 615.389,66.3121 615.398,66.3142 615.407,66.3163 615.416,66.3184 615.425,66.3205 615.435,66.3226 615.444,66.3247 615.453,66.3268 615.462,66.3289 615.471,66.331 615.481,66.3331 615.49,66.3352 615.499,66.3374 615.508,66.3395 615.517,66.3416 615.526,66.3437 615.536,66.3458 615.545,66.3479 615.554,66.3501 615.563,66.3522 615.572,66.3543 615.582,66.3564 615.591,66.3586 615.6,66.3607 615.609,66.3628 615.618,66.3649 615.628,66.3671 615.637,66.3692 615.646,66.3713 615.655,66.3735 615.664,66.3756 615.674,66.3777 615.683,66.3799 615.692,66.382 615.701,66.3842 615.71,66.3863 615.719,66.3884 615.729,66.3906 615.738,66.3927 615.747,66.3949 615.756,66.397 615.765,66.3992 615.775,66.4013 615.784,66.4035 615.793,66.4056 615.802,66.4078 615.811,66.4099 615.821,66.4121 615.83,66.4142 615.839,66.4164 615.848,66.4185 615.857,66.4207 615.866,66.4228 615.876,66.425 615.885,66.4272 615.894,66.4293 615.903,66.4315 615.912,66.4337 615.922,66.4358 615.931,66.438 615.94,66.4402 615.949,66.4423 615.958,66.4445 615.968,66.4467 615.977,66.4488 615.986,66.451 615.995,66.4532 616.004,66.4554 616.014,66.4576 616.023,66.4597 616.032,66.4619 616.041,66.4641 616.05,66.4663 616.059,66.4685 616.069,66.4706 616.078,66.4728 616.087,66.475 616.096,66.4772 616.105,66.4794 616.115,66.4816 616.124,66.4838 616.133,66.486 616.142,66.4882 616.151,66.4904 616.161,66.4925 616.17,66.4947 616.179,66.4969 616.188,66.4991 616.197,66.5013 616.206,66.5035 616.216,66.5058 616.225,66.508 616.234,66.5102 616.243,66.5124 616.252,66.5146 616.262,66.5168 616.271,66.519 616.28,66.5212 616.289,66.5234 616.298,66.5256 616.308,66.5278 616.317,66.5301 616.326,66.5323 616.335,66.5345 616.344,66.5367 616.354,66.5389 616.363,66.5412 616.372,66.5434 616.381,66.5456 616.39,66.5478 616.399,66.5501 616.409,66.5523 616.418,66.5545 616.427,66.5567 616.436,66.559 616.445,66.5612 616.455,66.5634 616.464,66.5657 616.473,66.5679 616.482,66.5701 616.491,66.5724 616.501,66.5746 616.51,66.5769 616.519,66.5791 616.528,66.5814 616.537,66.5836 616.546,66.5858 616.556,66.5881 616.565,66.5903 616.574,66.5926 616.583,66.5948 616.592,66.5971 616.602,66.5993 616.611,66.6016 616.62,66.6038 616.629,66.6061 616.638,66.6084 616.648,66.6106 616.657,66.6129 616.666,66.6151 616.675,66.6174 616.684,66.6197 616.694,66.6219 616.703,66.6242 616.712,66.6265 616.721,66.6287 616.73,66.631 616.739,66.6333 616.749,66.6355 616.758,66.6378 616.767,66.6401 616.776,66.6424 616.785,66.6446 616.795,66.6469 616.804,66.6492 616.813,66.6515 616.822,66.6537 616.831,66.656 616.841,66.6583 616.85,66.6606 616.859,66.6629 616.868,66.6652 616.877,66.6675 616.886,66.6697 616.896,66.672 616.905,66.6743 616.914,66.6766 616.923,66.6789 616.932,66.6812 616.942,66.6835 616.951,66.6858 616.96,66.6881 616.969,66.6904 616.978,66.6927 616.988,66.695 616.997,66.6973 617.006,66.6996 617.015,66.7019 617.024,66.7042 617.034,66.7065 617.043,66.7088 617.052,66.7112 617.061,66.7135 617.07,66.7158 617.079,66.7181 617.089,66.7204 617.098,66.7227 617.107,66.725 617.116,66.7274 617.125,66.7297 617.135,66.732 617.144,66.7343 617.153,66.7367 617.162,66.739 617.171,66.7413 617.181,66.7436 617.19,66.746 617.199,66.7483 617.208,66.7506 617.217,66.753 617.226,66.7553 617.236,66.7576 617.245,66.76 617.254,66.7623 617.263,66.7646 617.272,66.767 617.282,66.7693 617.291,66.7717 617.3,66.774 617.309,66.7763 617.318,66.7787 617.328,66.781 617.337,66.7834 617.346,66.7857 617.355,66.7881 617.364,66.7904 617.374,66.7928 617.383,66.7951 617.392,66.7975 617.401,66.7999 617.41,66.8022 617.419,66.8046 617.429,66.8069 617.438,66.8093 617.447,66.8117 617.456,66.814 617.465,66.8164 617.475,66.8188 617.484,66.8211 617.493,66.8235 617.502,66.8259 617.511,66.8282 617.521,66.8306 617.53,66.833 617.539,66.8354 617.548,66.8377 617.557,66.8401 617.567,66.8425 617.576,66.8449 617.585,66.8473 617.594,66.8496 617.603,66.852 617.612,66.8544 617.622,66.8568 617.631,66.8592 617.64,66.8616 617.649,66.864 617.658,66.8664 617.668,66.8687 617.677,66.8711 617.686,66.8735 617.695,66.8759 617.704,66.8783 617.714,66.8807 617.723,66.8831 617.732,66.8855 617.741,66.8879 617.75,66.8903 617.759,66.8927 617.769,66.8951 617.778,66.8975 617.787,66.9 617.796,66.9024 617.805,66.9048 617.815,66.9072 617.824,66.9096 617.833,66.912 617.842,66.9144 617.851,66.9169 617.861,66.9193 617.87,66.9217 617.879,66.9241 617.888,66.9265 617.897,66.929 617.907,66.9314 617.916,66.9338 617.925,66.9362 617.934,66.9387 617.943,66.9411 617.952,66.9435 617.962,66.946 617.971,66.9484 617.98,66.9508 617.989,66.9533 617.998,66.9557 618.008,66.9581 618.017,66.9606 618.026,66.963 618.035,66.9655 618.044,66.9679 618.054,66.9704 618.063,66.9728 618.072,66.9752 618.081,66.9777 618.09,66.9801 618.099,66.9826 618.109,66.985 618.118,66.9875 618.127,66.99 618.136,66.9924 618.145,66.9949 618.155,66.9973 618.164,66.9998 618.173,67.0023 618.182,67.0047 618.191,67.0072 618.201,67.0096 618.21,67.0121 618.219,67.0146 618.228,67.017 618.237,67.0195 618.247,67.022 618.256,67.0245 618.265,67.0269 618.274,67.0294 618.283,67.0319 618.292,67.0344 618.302,67.0368 618.311,67.0393 618.32,67.0418 618.329,67.0443 618.338,67.0468 618.348,67.0493 618.357,67.0517 618.366,67.0542 618.375,67.0567 618.384,67.0592 618.394,67.0617 618.403,67.0642 618.412,67.0667 618.421,67.0692 618.43,67.0717 618.439,67.0742 618.449,67.0767 618.458,67.0792 618.467,67.0817 618.476,67.0842 618.485,67.0867 618.495,67.0892 618.504,67.0917 618.513,67.0942 618.522,67.0967 618.531,67.0992 618.541,67.1017 618.55,67.1043 618.559,67.1068 618.568,67.1093 618.577,67.1118 618.587,67.1143 618.596,67.1168 618.605,67.1194 618.614,67.1219 618.623,67.1244 618.632,67.1269 618.642,67.1295 618.651,67.132 618.66,67.1345 618.669,67.1371 618.678,67.1396 618.688,67.1421 618.697,67.1447 618.706,67.1472 618.715,67.1497 618.724,67.1523 618.734,67.1548 618.743,67.1573 618.752,67.1599 618.761,67.1624 618.77,67.165 618.779,67.1675 618.789,67.1701 618.798,67.1726 618.807,67.1752 618.816,67.1777 618.825,67.1803 618.835,67.1828 618.844,67.1854 618.853,67.1879 618.862,67.1905 618.871,67.1931 618.881,67.1956 618.89,67.1982 618.899,67.2007 618.908,67.2033 618.917,67.2059 618.927,67.2084 618.936,67.211 618.945,67.2136 618.954,67.2161 618.963,67.2187 618.972,67.2213 618.982,67.2239 618.991,67.2264 619,67.229 619.009,67.2316 619.018,67.2342 619.028,67.2368 619.037,67.2393 619.046,67.2419 619.055,67.2445 619.064,67.2471 619.074,67.2497 619.083,67.2523 619.092,67.2549 619.101,67.2574 619.11,67.26 619.119,67.2626 619.129,67.2652 619.138,67.2678 619.147,67.2704 619.156,67.273 619.165,67.2756 619.175,67.2782 619.184,67.2808 619.193,67.2834 619.202,67.286 619.211,67.2887 619.221,67.2913 619.23,67.2939 619.239,67.2965 619.248,67.2991 619.257,67.3017 619.267,67.3043 619.276,67.3069 619.285,67.3096 619.294,67.3122 619.303,67.3148 619.312,67.3174 619.322,67.32 619.331,67.3227 619.34,67.3253 619.349,67.3279 619.358,67.3306 619.368,67.3332 619.377,67.3358 619.386,67.3384 619.395,67.3411 619.404,67.3437 619.414,67.3464 619.423,67.349 619.432,67.3516 619.441,67.3543 619.45,67.3569 619.459,67.3596 619.469,67.3622 619.478,67.3648 619.487,67.3675 619.496,67.3701 619.505,67.3728 619.515,67.3754 619.524,67.3781 619.533,67.3808 619.542,67.3834 619.551,67.3861 619.561,67.3887 619.57,67.3914 619.579,67.394 619.588,67.3967 619.597,67.3994 619.607,67.402 619.616,67.4047 619.625,67.4074 619.634,67.41 619.643,67.4127 619.652,67.4154 619.662,67.4181 619.671,67.4207 619.68,67.4234 619.689,67.4261 619.698,67.4288 619.708,67.4314 619.717,67.4341 619.726,67.4368 619.735,67.4395 619.744,67.4422 619.754,67.4449 619.763,67.4475 619.772,67.4502 619.781,67.4529 619.79,67.4556 619.799,67.4583 619.809,67.461 619.818,67.4637 619.827,67.4664 619.836,67.4691 619.845,67.4718 619.855,67.4745 619.864,67.4772 619.873,67.4799 619.882,67.4826 619.891,67.4853 619.901,67.488 619.91,67.4907 619.919,67.4934 619.928,67.4962 619.937,67.4989 619.947,67.5016 619.956,67.5043 619.965,67.507 619.974,67.5097 619.983,67.5125 619.992,67.5152 620.002,67.5179 620.011,67.5206 620.02,67.5234 620.029,67.5261 620.038,67.5288 620.048,67.5315 620.057,67.5343 620.066,67.537 620.075,67.5397 620.084,67.5425 620.094,67.5452 620.103,67.548 620.112,67.5507 620.121,67.5534 620.13,67.5562 620.14,67.5589 620.149,67.5617 620.158,67.5644 620.167,67.5672 620.176,67.5699 620.185,67.5727 620.195,67.5754 620.204,67.5782 620.213,67.5809 620.222,67.5837 620.231,67.5864 620.241,67.5892 620.25,67.592 620.259,67.5947 620.268,67.5975 620.277,67.6002 620.287,67.603 620.296,67.6058 620.305,67.6085 620.314,67.6113 620.323,67.6141 620.332,67.6169 620.342,67.6196 620.351,67.6224 620.36,67.6252 620.369,67.628 620.378,67.6307 620.388,67.6335 620.397,67.6363 620.406,67.6391 620.415,67.6419 620.424,67.6447 620.434,67.6475 620.443,67.6502 620.452,67.653 620.461,67.6558 620.47,67.6586 620.48,67.6614 620.489,67.6642 620.498,67.667 620.507,67.6698 620.516,67.6726 620.525,67.6754 620.535,67.6782 620.544,67.681 620.553,67.6838 620.562,67.6866 620.571,67.6894 620.581,67.6923 620.59,67.6951 620.599,67.6979 620.608,67.7007 620.617,67.7035 620.627,67.7063 620.636,67.7091 620.645,67.712 620.654,67.7148 620.663,67.7176 620.672,67.7204 620.682,67.7233 620.691,67.7261 620.7,67.7289 620.709,67.7318 620.718,67.7346 620.728,67.7374 620.737,67.7403 620.746,67.7431 620.755,67.7459 620.764,67.7488 620.774,67.7516 620.783,67.7544 620.792,67.7573 620.801,67.7601 620.81,67.763 620.82,67.7658 620.829,67.7687 620.838,67.7715 620.847,67.7744 620.856,67.7772 620.865,67.7801 620.875,67.7829 620.884,67.7858 620.893,67.7887 620.902,67.7915 620.911,67.7944 620.921,67.7972 620.93,67.8001 620.939,67.803 620.948,67.8058 620.957,67.8087 620.967,67.8116 620.976,67.8145 620.985,67.8173 620.994,67.8202 621.003,67.8231 621.012,67.826 621.022,67.8288 621.031,67.8317 621.04,67.8346 621.049,67.8375 621.058,67.8404 621.068,67.8432 621.077,67.8461 621.086,67.849 621.095,67.8519 621.104,67.8548 621.114,67.8577 621.123,67.8606 621.132,67.8635 621.141,67.8664 621.15,67.8693 621.16,67.8722 621.169,67.8751 621.178,67.878 621.187,67.8809 621.196,67.8838 621.205,67.8867 621.215,67.8896 621.224,67.8925 621.233,67.8954 621.242,67.8983 621.251,67.9013 621.261,67.9042 621.27,67.9071 621.279,67.91 621.288,67.9129 621.297,67.9159 621.307,67.9188 621.316,67.9217 621.325,67.9246 621.334,67.9276 621.343,67.9305 621.352,67.9334 621.362,67.9364 621.371,67.9393 621.38,67.9422 621.389,67.9452 621.398,67.9481 621.408,67.951 621.417,67.954 621.426,67.9569 621.435,67.9599 621.444,67.9628 621.454,67.9658 621.463,67.9687 621.472,67.9717 621.481,67.9746 621.49,67.9776 621.5,67.9805 621.509,67.9835 621.518,67.9864 621.527,67.9894 621.536,67.9923 621.545,67.9953 621.555,67.9983 621.564,68.0012 621.573,68.0042 621.582,68.0072 621.591,68.0101 621.601,68.0131 621.61,68.0161 621.619,68.019 621.628,68.022 621.637,68.025 621.647,68.028 621.656,68.0309 621.665,68.0339 621.674,68.0369 621.683,68.0399 621.692,68.0429 621.702,68.0459 621.711,68.0489 621.72,68.0518 621.729,68.0548 621.738,68.0578 621.748,68.0608 621.757,68.0638 621.766,68.0668 621.775,68.0698 621.784,68.0728 621.794,68.0758 621.803,68.0788 621.812,68.0818 621.821,68.0848 621.83,68.0878 621.84,68.0908 621.849,68.0938 621.858,68.0969 621.867,68.0999 621.876,68.1029 621.885,68.1059 621.895,68.1089 621.904,68.1119 621.913,68.115 621.922,68.118 621.931,68.121 621.941,68.124 621.95,68.1271 621.959,68.1301 621.968,68.1331 621.977,68.1361 621.987,68.1392 621.996,68.1422 622.005,68.1452 622.014,68.1483 622.023,68.1513 622.032,68.1544 622.042,68.1574 622.051,68.1604 622.06,68.1635 622.069,68.1665 622.078,68.1696 622.088,68.1726 622.097,68.1757 622.106,68.1787 622.115,68.1818 622.124,68.1848 622.134,68.1879 622.143,68.1909 622.152,68.194 622.161,68.1971 622.17,68.2001 622.18,68.2032 622.189,68.2063 622.198,68.2093 622.207,68.2124 622.216,68.2155 622.225,68.2185 622.235,68.2216 622.244,68.2247 622.253,68.2278 622.262,68.2308 622.271,68.2339 622.281,68.237 622.29,68.2401 622.299,68.2432 622.308,68.2462 622.317,68.2493 622.327,68.2524 622.336,68.2555 622.345,68.2586 622.354,68.2617 622.363,68.2648 622.373,68.2679 622.382,68.271 622.391,68.2741 622.4,68.2772 622.409,68.2803 622.418,68.2834 622.428,68.2865 622.437,68.2896 622.446,68.2927 622.455,68.2958 622.464,68.2989 622.474,68.302 622.483,68.3051 622.492,68.3083 622.501,68.3114 622.51,68.3145 622.52,68.3176 622.529,68.3207 622.538,68.3239 622.547,68.327 622.556,68.3301 622.565,68.3332 622.575,68.3364 622.584,68.3395 622.593,68.3426 622.602,68.3458 622.611,68.3489 622.621,68.352 622.63,68.3552 622.639,68.3583 622.648,68.3614 622.657,68.3646 622.667,68.3677 622.676,68.3709 622.685,68.374 622.694,68.3772 622.703,68.3803 622.713,68.3835 622.722,68.3866 622.731,68.3898 622.74,68.3929 622.749,68.3961 622.758,68.3993 622.768,68.4024 622.777,68.4056 622.786,68.4088 622.795,68.4119 622.804,68.4151 622.814,68.4183 622.823,68.4214 622.832,68.4246 622.841,68.4278 622.85,68.4309 622.86,68.4341 622.869,68.4373 622.878,68.4405 622.887,68.4437 622.896,68.4468 622.905,68.45 622.915,68.4532 622.924,68.4564 622.933,68.4596 622.942,68.4628 622.951,68.466 622.961,68.4692 622.97,68.4724 622.979,68.4756 622.988,68.4788 622.997,68.482 623.007,68.4852 623.016,68.4884 623.025,68.4916 623.034,68.4948 623.043,68.498 623.053,68.5012 623.062,68.5044 623.071,68.5076 623.08,68.5108 623.089,68.514 623.098,68.5173 623.108,68.5205 623.117,68.5237 623.126,68.5269 623.135,68.5301 623.144,68.5334 623.154,68.5366 623.163,68.5398 623.172,68.5431 623.181,68.5463 623.19,68.5495 623.2,68.5528 623.209,68.556 623.218,68.5592 623.227,68.5625 623.236,68.5657 623.245,68.5689 623.255,68.5722 623.264,68.5754 623.273,68.5787 623.282,68.5819 623.291,68.5852 623.301,68.5884 623.31,68.5917 623.319,68.5949 623.328,68.5982 623.337,68.6015 623.347,68.6047 623.356,68.608 623.365,68.6112 623.374,68.6145 623.383,68.6178 623.393,68.621 623.402,68.6243 623.411,68.6276 623.42,68.6309 623.429,68.6341 623.438,68.6374 623.448,68.6407 623.457,68.644 623.466,68.6472 623.475,68.6505 623.484,68.6538 623.494,68.6571 623.503,68.6604 623.512,68.6637 623.521,68.667 623.53,68.6702 623.54,68.6735 623.549,68.6768 623.558,68.6801 623.567,68.6834 623.576,68.6867 623.585,68.69 623.595,68.6933 623.604,68.6966 623.613,68.6999 623.622,68.7033 623.631,68.7066 623.641,68.7099 623.65,68.7132 623.659,68.7165 623.668,68.7198 623.677,68.7231 623.687,68.7264 623.696,68.7298 623.705,68.7331 623.714,68.7364 623.723,68.7397 623.733,68.7431 623.742,68.7464 623.751,68.7497 623.76,68.7531 623.769,68.7564 623.778,68.7597 623.788,68.7631 623.797,68.7664 623.806,68.7697 623.815,68.7731 623.824,68.7764 623.834,68.7798 623.843,68.7831 623.852,68.7865 623.861,68.7898 623.87,68.7932 623.88,68.7965 623.889,68.7999 623.898,68.8032 623.907,68.8066 623.916,68.8099 623.925,68.8133 623.935,68.8167 623.944,68.82 623.953,68.8234 623.962,68.8268 623.971,68.8301 623.981,68.8335 623.99,68.8369 623.999,68.8402 624.008,68.8436 624.017,68.847 624.027,68.8504 624.036,68.8538 624.045,68.8571 624.054,68.8605 624.063,68.8639 624.073,68.8673 624.082,68.8707 624.091,68.8741 624.1,68.8775 624.109,68.8809 624.118,68.8843 624.128,68.8876 624.137,68.891 624.146,68.8944 624.155,68.8978 624.164,68.9013 624.174,68.9047 624.183,68.9081 624.192,68.9115 624.201,68.9149 624.21,68.9183 624.22,68.9217 624.229,68.9251 624.238,68.9285 624.247,68.932 624.256,68.9354 624.265,68.9388 624.275,68.9422 624.284,68.9456 624.293,68.9491 624.302,68.9525 624.311,68.9559 624.321,68.9594 624.33,68.9628 624.339,68.9662 624.348,68.9697 624.357,68.9731 624.367,68.9765 624.376,68.98 624.385,68.9834 624.394,68.9869 624.403,68.9903 624.413,68.9938 624.422,68.9972 624.431,69.0007 624.44,69.0041 624.449,69.0076 624.458,69.011 624.468,69.0145 624.477,69.0179 624.486,69.0214 624.495,69.0249 624.504,69.0283 624.514,69.0318 624.523,69.0353 624.532,69.0387 624.541,69.0422 624.55,69.0457 624.56,69.0491 624.569,69.0526 624.578,69.0561 624.587,69.0596 624.596,69.0631 624.605,69.0665 624.615,69.07 624.624,69.0735 624.633,69.077 624.642,69.0805 624.651,69.084 624.661,69.0875 624.67,69.091 624.679,69.0945 624.688,69.098 624.697,69.1015 624.707,69.105 624.716,69.1085 624.725,69.112 624.734,69.1155 624.743,69.119 624.753,69.1225 624.762,69.126 624.771,69.1295 624.78,69.133 624.789,69.1365 624.798,69.1401 624.808,69.1436 624.817,69.1471 624.826,69.1506 624.835,69.1542 624.844,69.1577 624.854,69.1612 624.863,69.1647 624.872,69.1683 624.881,69.1718 624.89,69.1753 624.9,69.1789 624.909,69.1824 624.918,69.186 624.927,69.1895 624.936,69.193 624.946,69.1966 624.955,69.2001 624.964,69.2037 624.973,69.2072 624.982,69.2108 624.991,69.2143 625.001,69.2179 625.01,69.2214 625.019,69.225 625.028,69.2286 625.037,69.2321 625.047,69.2357 625.056,69.2393 625.065,69.2428 625.074,69.2464 625.083,69.25 625.093,69.2535 625.102,69.2571 625.111,69.2607 625.12,69.2643 625.129,69.2678 625.138,69.2714 625.148,69.275 625.157,69.2786 625.166,69.2822 625.175,69.2858 625.184,69.2893 625.194,69.2929 625.203,69.2965 625.212,69.3001 625.221,69.3037 625.23,69.3073 625.24,69.3109 625.249,69.3145 625.258,69.3181 625.267,69.3217 625.276,69.3253 625.286,69.3289 625.295,69.3326 625.304,69.3362 625.313,69.3398 625.322,69.3434 625.331,69.347 625.341,69.3506 625.35,69.3542 625.359,69.3579 625.368,69.3615 625.377,69.3651 625.387,69.3687 625.396,69.3724 625.405,69.376 625.414,69.3796 625.423,69.3833 625.433,69.3869 625.442,69.3905 625.451,69.3942 625.46,69.3978 625.469,69.4015 625.478,69.4051 625.488,69.4088 625.497,69.4124 625.506,69.4161 625.515,69.4197 625.524,69.4234 625.534,69.427 625.543,69.4307 625.552,69.4343 625.561,69.438 625.57,69.4417 625.58,69.4453 625.589,69.449 625.598,69.4527 625.607,69.4563 625.616,69.46 625.626,69.4637 625.635,69.4673 625.644,69.471 625.653,69.4747 625.662,69.4784 625.671,69.4821 625.681,69.4857 625.69,69.4894 625.699,69.4931 625.708,69.4968 625.717,69.5005 625.727,69.5042 625.736,69.5079 625.745,69.5116 625.754,69.5153 625.763,69.519 625.773,69.5227 625.782,69.5264 625.791,69.5301 625.8,69.5338 625.809,69.5375 625.818,69.5412 625.828,69.5449 625.837,69.5486 625.846,69.5523 625.855,69.556 625.864,69.5598 625.874,69.5635 625.883,69.5672 625.892,69.5709 625.901,69.5746 625.91,69.5784 625.92,69.5821 625.929,69.5858 625.938,69.5896 625.947,69.5933 625.956,69.597 625.966,69.6008 625.975,69.6045 625.984,69.6083 625.993,69.612 626.002,69.6157 626.011,69.6195 626.021,69.6232 626.03,69.627 626.039,69.6307 626.048,69.6345 626.057,69.6382 626.067,69.642 626.076,69.6458 626.085,69.6495 626.094,69.6533 626.103,69.657 626.113,69.6608 626.122,69.6646 626.131,69.6684 626.14,69.6721 626.149,69.6759 626.158,69.6797 626.168,69.6834 626.177,69.6872 626.186,69.691 626.195,69.6948 626.204,69.6986 626.214,69.7024 626.223,69.7061 626.232,69.7099 626.241,69.7137 626.25,69.7175 626.26,69.7213 626.269,69.7251 626.278,69.7289 626.287,69.7327 626.296,69.7365 626.306,69.7403 626.315,69.7441 626.324,69.7479 626.333,69.7517 626.342,69.7555 626.351,69.7594 626.361,69.7632 626.37,69.767 626.379,69.7708 626.388,69.7746 626.397,69.7784 626.407,69.7823 626.416,69.7861 626.425,69.7899 626.434,69.7938 626.443,69.7976 626.453,69.8014 626.462,69.8052 626.471,69.8091 626.48,69.8129 626.489,69.8168 626.498,69.8206 626.508,69.8244 626.517,69.8283 626.526,69.8321 626.535,69.836 626.544,69.8398 626.554,69.8437 626.563,69.8475 626.572,69.8514 626.581,69.8553 626.59,69.8591 626.6,69.863 626.609,69.8668 626.618,69.8707 626.627,69.8746 626.636,69.8784 626.646,69.8823 626.655,69.8862 626.664,69.8901 626.673,69.8939 626.682,69.8978 626.691,69.9017 626.701,69.9056 626.71,69.9095 626.719,69.9133 626.728,69.9172 626.737,69.9211 626.747,69.925 626.756,69.9289 626.765,69.9328 626.774,69.9367 626.783,69.9406 626.793,69.9445 626.802,69.9484 626.811,69.9523 626.82,69.9562 626.829,69.9601 626.838,69.964 626.848,69.9679 626.857,69.9718 626.866,69.9758 626.875,69.9797 626.884,69.9836 626.894,69.9875 626.903,69.9914 626.912,69.9954 626.921,69.9993 626.93,70.0032 626.94,70.0071 626.949,70.0111 626.958,70.015 626.967,70.0189 626.976,70.0229 626.986,70.0268 626.995,70.0308 627.004,70.0347 627.013,70.0386 627.022,70.0426 627.031,70.0465 627.041,70.0505 627.05,70.0544 627.059,70.0584 627.068,70.0623 627.077,70.0663 627.087,70.0703 627.096,70.0742 627.105,70.0782 627.114,70.0821 627.123,70.0861 627.133,70.0901 627.142,70.0941 627.151,70.098 627.16,70.102 627.169,70.106 627.178,70.11 627.188,70.1139 627.197,70.1179 627.206,70.1219 627.215,70.1259 627.224,70.1299 627.234,70.1339 627.243,70.1378 627.252,70.1418 627.261,70.1458 627.27,70.1498 627.28,70.1538 627.289,70.1578 627.298,70.1618 627.307,70.1658 627.316,70.1698 627.326,70.1739 627.335,70.1779 627.344,70.1819 627.353,70.1859 627.362,70.1899 627.371,70.1939 627.381,70.1979 627.39,70.202 627.399,70.206 627.408,70.21 627.417,70.214 627.427,70.2181 627.436,70.2221 627.445,70.2261 627.454,70.2302 627.463,70.2342 627.473,70.2382 627.482,70.2423 627.491,70.2463 627.5,70.2504 627.509,70.2544 627.519,70.2584 627.528,70.2625 627.537,70.2665 627.546,70.2706 627.555,70.2747 627.564,70.2787 627.574,70.2828 627.583,70.2868 627.592,70.2909 627.601,70.295 627.61,70.299 627.62,70.3031 627.629,70.3072 627.638,70.3112 627.647,70.3153 627.656,70.3194 627.666,70.3235 627.675,70.3275 627.684,70.3316 627.693,70.3357 627.702,70.3398 627.711,70.3439 627.721,70.348 627.73,70.3521 627.739,70.3561 627.748,70.3602 627.757,70.3643 627.767,70.3684 627.776,70.3725 627.785,70.3766 627.794,70.3807 627.803,70.3849 627.813,70.389 627.822,70.3931 627.831,70.3972 627.84,70.4013 627.849,70.4054 627.859,70.4095 627.868,70.4137 627.877,70.4178 627.886,70.4219 627.895,70.426 627.904,70.4302 627.914,70.4343 627.923,70.4384 627.932,70.4425 627.941,70.4467 627.95,70.4508 627.96,70.455 627.969,70.4591 627.978,70.4632 627.987,70.4674 627.996,70.4715 628.006,70.4757 628.015,70.4798 628.024,70.484 628.033,70.4881 628.042,70.4923 628.051,70.4965 628.061,70.5006 628.07,70.5048 628.079,70.5089 628.088,70.5131 628.097,70.5173 628.107,70.5214 628.116,70.5256 628.125,70.5298 628.134,70.534 628.143,70.5381 628.153,70.5423 628.162,70.5465 628.171,70.5507 628.18,70.5549 628.189,70.5591 628.199,70.5633 628.208,70.5674 628.217,70.5716 628.226,70.5758 628.235,70.58 628.244,70.5842 628.254,70.5884 628.263,70.5926 628.272,70.5968 628.281,70.601 628.29,70.6053 628.3,70.6095 628.309,70.6137 628.318,70.6179 628.327,70.6221 628.336,70.6263 628.346,70.6305 628.355,70.6348 628.364,70.639 628.373,70.6432 628.382,70.6475 628.391,70.6517 628.401,70.6559 628.41,70.6602 628.419,70.6644 628.428,70.6686 628.437,70.6729 628.447,70.6771 628.456,70.6814 628.465,70.6856 628.474,70.6898 628.483,70.6941 628.493,70.6984 628.502,70.7026 628.511,70.7069 628.52,70.7111 628.529,70.7154 628.539,70.7196 628.548,70.7239 628.557,70.7282 628.566,70.7324 628.575,70.7367 628.584,70.741 628.594,70.7453 628.603,70.7495 628.612,70.7538 628.621,70.7581 628.63,70.7624 628.64,70.7667 628.649,70.7709 628.658,70.7752 628.667,70.7795 628.676,70.7838 628.686,70.7881 628.695,70.7924 628.704,70.7967 628.713,70.801 628.722,70.8053 628.731,70.8096 628.741,70.8139 628.75,70.8182 628.759,70.8225 628.768,70.8268 628.777,70.8312 628.787,70.8355 628.796,70.8398 628.805,70.8441 628.814,70.8484 628.823,70.8528 628.833,70.8571 628.842,70.8614 628.851,70.8657 628.86,70.8701 628.869,70.8744 628.879,70.8787 628.888,70.8831 628.897,70.8874 628.906,70.8918 628.915,70.8961 628.924,70.9005 628.934,70.9048 628.943,70.9091 628.952,70.9135 628.961,70.9179 628.97,70.9222 628.98,70.9266 628.989,70.9309 628.998,70.9353 629.007,70.9397 629.016,70.944 629.026,70.9484 629.035,70.9528 629.044,70.9571 629.053,70.9615 629.062,70.9659 629.071,70.9703 629.081,70.9746 629.09,70.979 629.099,70.9834 629.108,70.9878 629.117,70.9922 629.127,70.9966 629.136,71.001 629.145,71.0054 629.154,71.0098 629.163,71.0142 629.173,71.0186 629.182,71.023 629.191,71.0274 629.2,71.0318 629.209,71.0362 629.219,71.0406 629.228,71.045 629.237,71.0494 629.246,71.0538 629.255,71.0583 629.264,71.0627 629.274,71.0671 629.283,71.0715 629.292,71.076 629.301,71.0804 629.31,71.0848 629.32,71.0892 629.329,71.0937 629.338,71.0981 629.347,71.1026 629.356,71.107 629.366,71.1114 629.375,71.1159 629.384,71.1203 629.393,71.1248 629.402,71.1292 629.411,71.1337 629.421,71.1381 629.43,71.1426 629.439,71.1471 629.448,71.1515 629.457,71.156 629.467,71.1605 629.476,71.1649 629.485,71.1694 629.494,71.1739 629.503,71.1783 629.513,71.1828 629.522,71.1873 629.531,71.1918 629.54,71.1963 629.549,71.2007 629.559,71.2052 629.568,71.2097 629.577,71.2142 629.586,71.2187 629.595,71.2232 629.604,71.2277 629.614,71.2322 629.623,71.2367 629.632,71.2412 629.641,71.2457 629.65,71.2502 629.66,71.2547 629.669,71.2592 629.678,71.2637 629.687,71.2683 629.696,71.2728 629.706,71.2773 629.715,71.2818 629.724,71.2863 629.733,71.2909 629.742,71.2954 629.752,71.2999 629.761,71.3045 629.77,71.309 629.779,71.3135 629.788,71.3181 629.797,71.3226 629.807,71.3272 629.816,71.3317 629.825,71.3362 629.834,71.3408 629.843,71.3453 629.853,71.3499 629.862,71.3545 629.871,71.359 629.88,71.3636 629.889,71.3681 629.899,71.3727 629.908,71.3773 629.917,71.3818 629.926,71.3864 629.935,71.391 629.944,71.3955 629.954,71.4001 629.963,71.4047 629.972,71.4093 629.981,71.4139 629.99,71.4185 630,71.423 630.009,71.4276 630.018,71.4322 630.027,71.4368 630.036,71.4414 630.046,71.446 630.055,71.4506 630.064,71.4552 630.073,71.4598 630.082,71.4644 630.092,71.469 630.101,71.4736 630.11,71.4782 630.119,71.4829 630.128,71.4875 630.137,71.4921 630.147,71.4967 630.156,71.5013 630.165,71.506 630.174,71.5106 630.183,71.5152 630.193,71.5199 630.202,71.5245 630.211,71.5291 630.22,71.5338 630.229,71.5384 630.239,71.543 630.248,71.5477 630.257,71.5523 630.266,71.557 630.275,71.5616 630.284,71.5663 630.294,71.5709 630.303,71.5756 630.312,71.5803 630.321,71.5849 630.33,71.5896 630.34,71.5942 630.349,71.5989 630.358,71.6036 630.367,71.6082 630.376,71.6129 630.386,71.6176 630.395,71.6223 630.404,71.627 630.413,71.6316 630.422,71.6363 630.432,71.641 630.441,71.6457 630.45,71.6504 630.459,71.6551 630.468,71.6598 630.477,71.6645 630.487,71.6692 630.496,71.6739 630.505,71.6786 630.514,71.6833 630.523,71.688 630.533,71.6927 630.542,71.6974 630.551,71.7021 630.56,71.7069 630.569,71.7116 630.579,71.7163 630.588,71.721 630.597,71.7257 630.606,71.7305 630.615,71.7352 630.624,71.7399 630.634,71.7447 630.643,71.7494 630.652,71.7541 630.661,71.7589 630.67,71.7636 630.68,71.7684 630.689,71.7731 630.698,71.7779 630.707,71.7826 630.716,71.7874 630.726,71.7921 630.735,71.7969 630.744,71.8016 630.753,71.8064 630.762,71.8112 630.772,71.8159 630.781,71.8207 630.79,71.8255 630.799,71.8302 630.808,71.835 630.817,71.8398 630.827,71.8446 630.836,71.8494 630.845,71.8541 630.854,71.8589 630.863,71.8637 630.873,71.8685 630.882,71.8733 630.891,71.8781 630.9,71.8829 630.909,71.8877 630.919,71.8925 630.928,71.8973 630.937,71.9021 630.946,71.9069 630.955,71.9117 630.964,71.9165 630.974,71.9214 630.983,71.9262 630.992,71.931 631.001,71.9358 631.01,71.9406 631.02,71.9455 631.029,71.9503 631.038,71.9551 631.047,71.96 631.056,71.9648 631.066,71.9696 631.075,71.9745 631.084,71.9793 631.093,71.9841 631.102,71.989 631.112,71.9938 631.121,71.9987 631.13,72.0035 631.139,72.0084 631.148,72.0133 631.157,72.0181 631.167,72.023 631.176,72.0278 631.185,72.0327 631.194,72.0376 631.203,72.0424 631.213,72.0473 631.222,72.0522 631.231,72.0571 631.24,72.0619 631.249,72.0668 631.259,72.0717 631.268,72.0766 631.277,72.0815 631.286,72.0864 631.295,72.0913 631.304,72.0962 631.314,72.101 631.323,72.1059 631.332,72.1108 631.341,72.1158 631.35,72.1207 631.36,72.1256 631.369,72.1305 631.378,72.1354 631.387,72.1403 631.396,72.1452 631.406,72.1501 631.415,72.1551 631.424,72.16 631.433,72.1649 631.442,72.1698 631.452,72.1748 631.461,72.1797 631.47,72.1846 631.479,72.1896 631.488,72.1945 631.497,72.1994 631.507,72.2044 631.516,72.2093 631.525,72.2143 631.534,72.2192 631.543,72.2242 631.553,72.2291 631.562,72.2341 631.571,72.2391 631.58,72.244 631.589,72.249 631.599,72.2539 631.608,72.2589 631.617,72.2639 631.626,72.2689 631.635,72.2738 631.644,72.2788 631.654,72.2838 631.663,72.2888 631.672,72.2938 631.681,72.2987 631.69,72.3037 631.7,72.3087 631.709,72.3137 631.718,72.3187 631.727,72.3237 631.736,72.3287 631.746,72.3337 631.755,72.3387 631.764,72.3437 631.773,72.3487 631.782,72.3537 631.792,72.3588 631.801,72.3638 631.81,72.3688 631.819,72.3738 631.828,72.3788 631.837,72.3839 631.847,72.3889 631.856,72.3939 631.865,72.3989 631.874,72.404 631.883,72.409 631.893,72.4141 631.902,72.4191 631.911,72.4241 631.92,72.4292 631.929,72.4342 631.939,72.4393 631.948,72.4443 631.957,72.4494 631.966,72.4544 631.975,72.4595 631.984,72.4646 631.994,72.4696 632.003,72.4747 632.012,72.4798 632.021,72.4848 632.03,72.4899 632.04,72.495 632.049,72.5001 632.058,72.5051 632.067,72.5102 632.076,72.5153 632.086,72.5204 632.095,72.5255 632.104,72.5306 632.113,72.5357 632.122,72.5408 632.132,72.5459 632.141,72.551 632.15,72.5561 632.159,72.5612 632.168,72.5663 632.177,72.5714 632.187,72.5765 632.196,72.5816 632.205,72.5867 632.214,72.5918 632.223,72.597 632.233,72.6021 632.242,72.6072 632.251,72.6123 632.26,72.6175 632.269,72.6226 632.279,72.6277 632.288,72.6329 632.297,72.638 632.306,72.6432 632.315,72.6483 632.325,72.6534 632.334,72.6586 632.343,72.6637 632.352,72.6689 632.361,72.6741 632.37,72.6792 632.38,72.6844 632.389,72.6895 632.398,72.6947 632.407,72.6999 632.416,72.705 632.426,72.7102 632.435,72.7154 632.444,72.7206 632.453,72.7257 632.462,72.7309 632.472,72.7361 632.481,72.7413 632.49,72.7465 632.499,72.7517 632.508,72.7569 632.517,72.7621 632.527,72.7673 632.536,72.7725 632.545,72.7777 632.554,72.7829 632.563,72.7881 632.573,72.7933 632.582,72.7985 632.591,72.8037 632.6,72.8089 632.609,72.8141 632.619,72.8194 632.628,72.8246 632.637,72.8298 632.646,72.835 632.655,72.8403 632.665,72.8455 632.674,72.8507 632.683,72.856 632.692,72.8612 632.701,72.8665 632.71,72.8717 632.72,72.877 632.729,72.8822 632.738,72.8875 632.747,72.8927 632.756,72.898 632.766,72.9032 632.775,72.9085 632.784,72.9138 632.793,72.919 632.802,72.9243 632.812,72.9296 632.821,72.9348 632.83,72.9401 632.839,72.9454 632.848,72.9507 632.857,72.956 632.867,72.9612 632.876,72.9665 632.885,72.9718 632.894,72.9771 632.903,72.9824 632.913,72.9877 632.922,72.993 632.931,72.9983 632.94,73.0036 632.949,73.0089 632.959,73.0142 632.968,73.0195 632.977,73.0248 632.986,73.0302 632.995,73.0355 633.005,73.0408 633.014,73.0461 633.023,73.0514 633.032,73.0568 633.041,73.0621 633.05,73.0674 633.06,73.0728 633.069,73.0781 633.078,73.0835 633.087,73.0888 633.096,73.0941 633.106,73.0995 633.115,73.1048 633.124,73.1102 633.133,73.1155 633.142,73.1209 633.152,73.1263 633.161,73.1316 633.17,73.137 633.179,73.1424 633.188,73.1477 633.197,73.1531 633.207,73.1585 633.216,73.1638 633.225,73.1692 633.234,73.1746 633.243,73.18 633.253,73.1854 633.262,73.1908 633.271,73.1961 633.28,73.2015 633.289,73.2069 633.299,73.2123 633.308,73.2177 633.317,73.2231 633.326,73.2285 633.335,73.234 633.345,73.2394 633.354,73.2448 633.363,73.2502 633.372,73.2556 633.381,73.261 633.39,73.2664 633.4,73.2719 633.409,73.2773 633.418,73.2827 633.427,73.2882 633.436,73.2936 633.446,73.299 633.455,73.3045 633.464,73.3099 633.473,73.3154 633.482,73.3208 633.492,73.3262 633.501,73.3317 633.51,73.3372 633.519,73.3426 633.528,73.3481 633.537,73.3535 633.547,73.359 633.556,73.3645 633.565,73.3699 633.574,73.3754 633.583,73.3809 633.593,73.3863 633.602,73.3918 633.611,73.3973 633.62,73.4028 633.629,73.4083 633.639,73.4138 633.648,73.4193 633.657,73.4247 633.666,73.4302 633.675,73.4357 633.685,73.4412 633.694,73.4467 633.703,73.4522 633.712,73.4578 633.721,73.4633 633.73,73.4688 633.74,73.4743 633.749,73.4798 633.758,73.4853 633.767,73.4909 633.776,73.4964 633.786,73.5019 633.795,73.5074 633.804,73.513 633.813,73.5185 633.822,73.524 633.832,73.5296 633.841,73.5351 633.85,73.5407 633.859,73.5462 633.868,73.5518 633.877,73.5573 633.887,73.5629 633.896,73.5684 633.905,73.574 633.914,73.5795 633.923,73.5851 633.933,73.5907 633.942,73.5962 633.951,73.6018 633.96,73.6074 633.969,73.613 633.979,73.6185 633.988,73.6241 633.997,73.6297 634.006,73.6353 634.015,73.6409 634.025,73.6465 634.034,73.6521 634.043,73.6577 634.052,73.6633 634.061,73.6689 634.07,73.6745 634.08,73.6801 634.089,73.6857 634.098,73.6913 634.107,73.6969 634.116,73.7025 634.126,73.7082 634.135,73.7138 634.144,73.7194 634.153,73.725 634.162,73.7307 634.172,73.7363 634.181,73.7419 634.19,73.7476 634.199,73.7532 634.208,73.7588 634.217,73.7645 634.227,73.7701 634.236,73.7758 634.245,73.7814 634.254,73.7871 634.263,73.7927 634.273,73.7984 634.282,73.8041 634.291,73.8097 634.3,73.8154 634.309,73.8211 634.319,73.8267 634.328,73.8324 634.337,73.8381 634.346,73.8438 634.355,73.8495 634.365,73.8551 634.374,73.8608 634.383,73.8665 634.392,73.8722 634.401,73.8779 634.41,73.8836 634.42,73.8893 634.429,73.895 634.438,73.9007 634.447,73.9064 634.456,73.9121 634.466,73.9178 634.475,73.9235 634.484,73.9293 634.493,73.935 634.502,73.9407 634.512,73.9464 634.521,73.9522 634.53,73.9579 634.539,73.9636 634.548,73.9694 634.557,73.9751 634.567,73.9808 634.576,73.9866 634.585,73.9923 634.594,73.9981 634.603,74.0038 634.613,74.0096 634.622,74.0153 634.631,74.0211 634.64,74.0269 634.649,74.0326 634.659,74.0384 634.668,74.0442 634.677,74.0499 634.686,74.0557 634.695,74.0615 634.705,74.0673 634.714,74.073 634.723,74.0788 634.732,74.0846 634.741,74.0904 634.75,74.0962 634.76,74.102 634.769,74.1078 634.778,74.1136 634.787,74.1194 634.796,74.1252 634.806,74.131 634.815,74.1368 634.824,74.1426 634.833,74.1484 634.842,74.1542 634.852,74.1601 634.861,74.1659 634.87,74.1717 634.879,74.1775 634.888,74.1834 634.898,74.1892 634.907,74.195 634.916,74.2009 634.925,74.2067 634.934,74.2126 634.943,74.2184 634.953,74.2243 634.962,74.2301 634.971,74.236 634.98,74.2418 634.989,74.2477 634.999,74.2535 635.008,74.2594 635.017,74.2653 635.026,74.2711 635.035,74.277 635.045,74.2829 635.054,74.2888 635.063,74.2946 635.072,74.3005 635.081,74.3064 635.09,74.3123 635.1,74.3182 635.109,74.3241 635.118,74.33 635.127,74.3359 635.136,74.3418 635.146,74.3477 635.155,74.3536 635.164,74.3595 635.173,74.3654 635.182,74.3713 635.192,74.3772 635.201,74.3831 635.21,74.3891 635.219,74.395 635.228,74.4009 635.238,74.4068 635.247,74.4128 635.256,74.4187 635.265,74.4246 635.274,74.4306 635.283,74.4365 635.293,74.4425 635.302,74.4484 635.311,74.4544 635.32,74.4603 635.329,74.4663 635.339,74.4722 635.348,74.4782 635.357,74.4842 635.366,74.4901 635.375,74.4961 635.385,74.5021 635.394,74.508 635.403,74.514 635.412,74.52 635.421,74.526 635.43,74.532 635.44,74.5379 635.449,74.5439 635.458,74.5499 635.467,74.5559 635.476,74.5619 635.486,74.5679 635.495,74.5739 635.504,74.5799 635.513,74.5859 635.522,74.5919 635.532,74.598 635.541,74.604 635.55,74.61 635.559,74.616 635.568,74.622 635.578,74.6281 635.587,74.6341 635.596,74.6401 635.605,74.6462 635.614,74.6522 635.623,74.6582 635.633,74.6643 635.642,74.6703 635.651,74.6764 635.66,74.6824 635.669,74.6885 635.679,74.6945 635.688,74.7006 635.697,74.7067 635.706,74.7127 635.715,74.7188 635.725,74.7249 635.734,74.7309 635.743,74.737 635.752,74.7431 635.761,74.7492 635.77,74.7552 635.78,74.7613 635.789,74.7674 635.798,74.7735 635.807,74.7796 635.816,74.7857 635.826,74.7918 635.835,74.7979 635.844,74.804 635.853,74.8101 635.862,74.8162 635.872,74.8223 635.881,74.8284 635.89,74.8346 635.899,74.8407 635.908,74.8468 635.918,74.8529 635.927,74.8591 635.936,74.8652 635.945,74.8713 635.954,74.8775 635.963,74.8836 635.973,74.8897 635.982,74.8959 635.991,74.902 636,74.9082 636.009,74.9143 636.019,74.9205 636.028,74.9266 636.037,74.9328 636.046,74.939 636.055,74.9451 636.065,74.9513 636.074,74.9575 636.083,74.9637 636.092,74.9698 636.101,74.976 636.11,74.9822 636.12,74.9884 636.129,74.9946 636.138,75.0008 636.147,75.0069 636.156,75.0131 636.166,75.0193 636.175,75.0255 636.184,75.0318 636.193,75.038 636.202,75.0442 636.212,75.0504 636.221,75.0566 636.23,75.0628 636.239,75.069 636.248,75.0753 636.258,75.0815 636.267,75.0877 636.276,75.0939 636.285,75.1002 636.294,75.1064 636.303,75.1127 636.313,75.1189 636.322,75.1251 636.331,75.1314 636.34,75.1376 636.349,75.1439 636.359,75.1501 636.368,75.1564 636.377,75.1627 636.386,75.1689 636.395,75.1752 636.405,75.1815 636.414,75.1877 636.423,75.194 636.432,75.2003 636.441,75.2066 636.45,75.2129 636.46,75.2191 636.469,75.2254 636.478,75.2317 636.487,75.238 636.496,75.2443 636.506,75.2506 636.515,75.2569 636.524,75.2632 636.533,75.2695 636.542,75.2758 636.552,75.2822 636.561,75.2885 636.57,75.2948 636.579,75.3011 636.588,75.3074 636.598,75.3138 636.607,75.3201 636.616,75.3264 636.625,75.3328 636.634,75.3391 636.643,75.3455 636.653,75.3518 636.662,75.3581 636.671,75.3645 636.68,75.3708 636.689,75.3772 636.699,75.3836 636.708,75.3899 636.717,75.3963 636.726,75.4027 636.735,75.409 636.745,75.4154 636.754,75.4218 636.763,75.4281 636.772,75.4345 636.781,75.4409 636.79,75.4473 636.8,75.4537 636.809,75.4601 636.818,75.4665 636.827,75.4729 636.836,75.4793 636.846,75.4857 636.855,75.4921 636.864,75.4985 636.873,75.5049 636.882,75.5113 636.892,75.5177 636.901,75.5242 636.91,75.5306 636.919,75.537 636.928,75.5434 636.938,75.5499 636.947,75.5563 636.956,75.5627 636.965,75.5692 636.974,75.5756 636.983,75.5821 636.993,75.5885 637.002,75.595 637.011,75.6014 637.02,75.6079 637.029,75.6143 637.039,75.6208 637.048,75.6272 637.057,75.6337 637.066,75.6402 637.075,75.6467 637.085,75.6531 637.094,75.6596 637.103,75.6661 637.112,75.6726 637.121,75.6791 637.131,75.6856 637.14,75.6921 637.149,75.6985 637.158,75.705 637.167,75.7115 637.176,75.7181 637.186,75.7246 637.195,75.7311 637.204,75.7376 637.213,75.7441 637.222,75.7506 637.232,75.7571 637.241,75.7637 637.25,75.7702 637.259,75.7767 637.268,75.7832 637.278,75.7898 637.287,75.7963 637.296,75.8029 637.305,75.8094 637.314,75.816 637.323,75.8225 637.333,75.8291 637.342,75.8356 637.351,75.8422 637.36,75.8487 637.369,75.8553 637.379,75.8619 637.388,75.8684 637.397,75.875 637.406,75.8816 637.415,75.8882 637.425,75.8947 637.434,75.9013 637.443,75.9079 637.452,75.9145 637.461,75.9211 637.471,75.9277 637.48,75.9343 637.489,75.9409 637.498,75.9475 637.507,75.9541 637.516,75.9607 637.526,75.9673 637.535,75.9739 637.544,75.9806 637.553,75.9872 637.562,75.9938 637.572,76.0004 637.581,76.0071 637.59,76.0137 637.599,76.0203 637.608,76.027 637.618,76.0336 637.627,76.0403 637.636,76.0469 637.645,76.0536 637.654,76.0602 637.663,76.0669 637.673,76.0735 637.682,76.0802 637.691,76.0868 637.7,76.0935 637.709,76.1002 637.719,76.1069 637.728,76.1135 637.737,76.1202 637.746,76.1269 637.755,76.1336 637.765,76.1403 637.774,76.147 637.783,76.1537 637.792,76.1603 637.801,76.167 637.811,76.1738 637.82,76.1805 637.829,76.1872 637.838,76.1939 637.847,76.2006 637.856,76.2073 637.866,76.214 637.875,76.2207 637.884,76.2275 637.893,76.2342 637.902,76.2409 637.912,76.2477 637.921,76.2544 637.93,76.2611 637.939,76.2679 637.948,76.2746 637.958,76.2814 637.967,76.2881 637.976,76.2949 637.985,76.3017 637.994,76.3084 638.003,76.3152 638.013,76.3219 638.022,76.3287 638.031,76.3355 638.04,76.3423 638.049,76.349 638.059,76.3558 638.068,76.3626 638.077,76.3694 638.086,76.3762 638.095,76.383 638.105,76.3898 638.114,76.3966 638.123,76.4034 638.132,76.4102 638.141,76.417 638.151,76.4238 638.16,76.4306 638.169,76.4374 638.178,76.4442 638.187,76.4511 638.196,76.4579 638.206,76.4647 638.215,76.4716 638.224,76.4784 638.233,76.4852 638.242,76.4921 638.252,76.4989 638.261,76.5058 638.27,76.5126 638.279,76.5195 638.288,76.5263 638.298,76.5332 638.307,76.54 638.316,76.5469 638.325,76.5538 638.334,76.5606 638.343,76.5675 638.353,76.5744 638.362,76.5813 638.371,76.5881 638.38,76.595 638.389,76.6019 638.399,76.6088 638.408,76.6157 638.417,76.6226 638.426,76.6295 638.435,76.6364 638.445,76.6433 638.454,76.6502 638.463,76.6571 638.472,76.664 638.481,76.671 638.491,76.6779 638.5,76.6848 638.509,76.6917 638.518,76.6987 638.527,76.7056 638.536,76.7125 638.546,76.7195 638.555,76.7264 638.564,76.7333 638.573,76.7403 638.582,76.7472 638.592,76.7542 638.601,76.7612 638.61,76.7681 638.619,76.7751 638.628,76.782 638.638,76.789 638.647,76.796 638.656,76.803 638.665,76.8099 638.674,76.8169 638.683,76.8239 638.693,76.8309 638.702,76.8379 638.711,76.8449 638.72,76.8519 638.729,76.8589 638.739,76.8659 638.748,76.8729 638.757,76.8799 638.766,76.8869 638.775,76.8939 638.785,76.9009 638.794,76.9079 638.803,76.915 638.812,76.922 638.821,76.929 638.831,76.936 638.84,76.9431 638.849,76.9501 638.858,76.9572 638.867,76.9642 638.876,76.9712 638.886,76.9783 638.895,76.9854 638.904,76.9924 638.913,76.9995 638.922,77.0065 638.932,77.0136 638.941,77.0207 638.95,77.0277 638.959,77.0348 638.968,77.0419 638.978,77.049 638.987,77.0561 638.996,77.0631 639.005,77.0702 639.014,77.0773 639.023,77.0844 639.033,77.0915 639.042,77.0986 639.051,77.1057 639.06,77.1128 639.069,77.1199 639.079,77.1271 639.088,77.1342 639.097,77.1413 639.106,77.1484 639.115,77.1555 639.125,77.1627 639.134,77.1698 639.143,77.1769 639.152,77.1841 639.161,77.1912 639.171,77.1984 639.18,77.2055 639.189,77.2127 639.198,77.2198 639.207,77.227 639.216,77.2341 639.226,77.2413 639.235,77.2485 639.244,77.2556 639.253,77.2628 639.262,77.27 639.272,77.2772 639.281,77.2843 639.29,77.2915 639.299,77.2987 639.308,77.3059 639.318,77.3131 639.327,77.3203 639.336,77.3275 639.345,77.3347 639.354,77.3419 639.363,77.3491 639.373,77.3563 639.382,77.3635 639.391,77.3708 639.4,77.378 639.409,77.3852 639.419,77.3924 639.428,77.3997 639.437,77.4069 639.446,77.4141 639.455,77.4214 639.465,77.4286 639.474,77.4359 639.483,77.4431 639.492,77.4504 639.501,77.4576 639.511,77.4649 639.52,77.4721 639.529,77.4794 639.538,77.4867 639.547,77.494 639.556,77.5012 639.566,77.5085 639.575,77.5158 639.584,77.5231 639.593,77.5304 639.602,77.5376 639.612,77.5449 639.621,77.5522 639.63,77.5595 639.639,77.5668 639.648,77.5741 639.658,77.5815 639.667,77.5888 639.676,77.5961 639.685,77.6034 639.694,77.6107 639.704,77.618 639.713,77.6254 639.722,77.6327 639.731,77.64 639.74,77.6474 639.749,77.6547 639.759,77.6621 639.768,77.6694 639.777,77.6768 639.786,77.6841 639.795,77.6915 639.805,77.6988 639.814,77.7062 639.823,77.7136 639.832,77.7209 639.841,77.7283 639.851,77.7357 639.86,77.743 639.869,77.7504 639.878,77.7578 639.887,77.7652 639.896,77.7726 639.906,77.78 639.915,77.7874 639.924,77.7948 639.933,77.8022 639.942,77.8096 639.952,77.817 639.961,77.8244 639.97,77.8318 639.979,77.8393 639.988,77.8467 639.998,77.8541 640.007,77.8615 640.016,77.869 640.025,77.8764 640.034,77.8838 640.044,77.8913 640.053,77.8987 640.062,77.9062 640.071,77.9136 640.08,77.9211 640.089,77.9285 640.099,77.936 640.108,77.9435 640.117,77.9509 640.126,77.9584 640.135,77.9659 640.145,77.9733 640.154,77.9808 640.163,77.9883 640.172,77.9958 640.181,78.0033 640.191,78.0108 640.2,78.0183 640.209,78.0258 640.218,78.0333 640.227,78.0408 640.236,78.0483 640.246,78.0558 640.255,78.0633 640.264,78.0708 640.273,78.0783 640.282,78.0859 640.292,78.0934 640.301,78.1009 640.31,78.1085 640.319,78.116 640.328,78.1235 640.338,78.1311 640.347,78.1386 640.356,78.1462 640.365,78.1537 640.374,78.1613 640.384,78.1689 640.393,78.1764 640.402,78.184 640.411,78.1916 640.42,78.1991 640.429,78.2067 640.439,78.2143 640.448,78.2219 640.457,78.2295 640.466,78.237 640.475,78.2446 640.485,78.2522 640.494,78.2598 640.503,78.2674 640.512,78.275 640.521,78.2826 640.531,78.2903 640.54,78.2979 640.549,78.3055 640.558,78.3131 640.567,78.3207 640.576,78.3284 640.586,78.336 640.595,78.3436 640.604,78.3513 640.613,78.3589 640.622,78.3665 640.632,78.3742 640.641,78.3818 640.65,78.3895 640.659,78.3972 640.668,78.4048 640.678,78.4125 640.687,78.4201 640.696,78.4278 640.705,78.4355 640.714,78.4432 640.724,78.4508 640.733,78.4585 640.742,78.4662 640.751,78.4739 640.76,78.4816 640.769,78.4893 640.779,78.497 640.788,78.5047 640.797,78.5124 640.806,78.5201 640.815,78.5278 640.825,78.5355 640.834,78.5433 640.843,78.551 640.852,78.5587 640.861,78.5664 640.871,78.5742 640.88,78.5819 640.889,78.5896 640.898,78.5974 640.907,78.6051 640.916,78.6129 640.926,78.6206 640.935,78.6284 640.944,78.6361 640.953,78.6439 640.962,78.6517 640.972,78.6594 640.981,78.6672 640.99,78.675 640.999,78.6828 641.008,78.6905 641.018,78.6983 641.027,78.7061 641.036,78.7139 641.045,78.7217 641.054,78.7295 641.064,78.7373 641.073,78.7451 641.082,78.7529 641.091,78.7607 641.1,78.7685 641.109,78.7764 641.119,78.7842 641.128,78.792 641.137,78.7998 641.146,78.8077 641.155,78.8155 641.165,78.8233 641.174,78.8312 641.183,78.839 641.192,78.8469 641.201,78.8547 641.211,78.8626 641.22,78.8704 641.229,78.8783 641.238,78.8862 641.247,78.894 641.256,78.9019 641.266,78.9098 641.275,78.9176 641.284,78.9255 641.293,78.9334 641.302,78.9413 641.312,78.9492 641.321,78.9571 641.33,78.965 641.339,78.9729 641.348,78.9808 641.358,78.9887 641.367,78.9966 641.376,79.0045 641.385,79.0124 641.394,79.0204 641.404,79.0283 641.413,79.0362 641.422,79.0441 641.431,79.0521 641.44,79.06 641.449,79.068 641.459,79.0759 641.468,79.0839 641.477,79.0918 641.486,79.0998 641.495,79.1077 641.505,79.1157 641.514,79.1236 641.523,79.1316 641.532,79.1396 641.541,79.1476 641.551,79.1555 641.56,79.1635 641.569,79.1715 641.578,79.1795 641.587,79.1875 641.596,79.1955 641.606,79.2035 641.615,79.2115 641.624,79.2195 641.633,79.2275 641.642,79.2355 641.652,79.2435 641.661,79.2515 641.67,79.2596 641.679,79.2676 641.688,79.2756 641.698,79.2837 641.707,79.2917 641.716,79.2997 641.725,79.3078 641.734,79.3158 641.744,79.3239 641.753,79.3319 641.762,79.34 641.771,79.348 641.78,79.3561 641.789,79.3642 641.799,79.3722 641.808,79.3803 641.817,79.3884 641.826,79.3965 641.835,79.4045 641.845,79.4126 641.854,79.4207 641.863,79.4288 641.872,79.4369 641.881,79.445 641.891,79.4531 641.9,79.4612 641.909,79.4693 641.918,79.4774 641.927,79.4856 641.936,79.4937 641.946,79.5018 641.955,79.5099 641.964,79.5181 641.973,79.5262 641.982,79.5343 641.992,79.5425 642.001,79.5506 642.01,79.5588 642.019,79.5669 642.028,79.5751 642.038,79.5832 642.047,79.5914 642.056,79.5996 642.065,79.6077 642.074,79.6159 642.084,79.6241 642.093,79.6323 642.102,79.6405 642.111,79.6486 642.12,79.6568 642.129,79.665 642.139,79.6732 642.148,79.6814 642.157,79.6896 642.166,79.6978 642.175,79.706 642.185,79.7143 642.194,79.7225 642.203,79.7307 642.212,79.7389 642.221,79.7471 642.231,79.7554 642.24,79.7636 642.249,79.7718 642.258,79.7801 642.267,79.7883 642.277,79.7966 642.286,79.8048 642.295,79.8131 642.304,79.8213 642.313,79.8296 642.322,79.8379 642.332,79.8461 642.341,79.8544 642.35,79.8627 642.359,79.871 642.368,79.8793 642.378,79.8875 642.387,79.8958 642.396,79.9041 642.405,79.9124 642.414,79.9207 642.424,79.929 642.433,79.9373 642.442,79.9456 642.451,79.954 642.46,79.9623 642.469,79.9706 642.479,79.9789 642.488,79.9872 642.497,79.9956 642.506,80.0039 642.515,80.0123 642.525,80.0206 642.534,80.0289 642.543,80.0373 642.552,80.0456 642.561,80.054 642.571,80.0624 642.58,80.0707 642.589,80.0791 642.598,80.0875 642.607,80.0958 642.617,80.1042 642.626,80.1126 642.635,80.121 642.644,80.1294 642.653,80.1378 642.662,80.1462 642.672,80.1546 642.681,80.163 642.69,80.1714 642.699,80.1798 642.708,80.1882 642.718,80.1966 642.727,80.205 642.736,80.2134 642.745,80.2219 642.754,80.2303 642.764,80.2387 642.773,80.2472 642.782,80.2556 642.791,80.2641 642.8,80.2725 642.809,80.281 642.819,80.2894 642.828,80.2979 642.837,80.3063 642.846,80.3148 642.855,80.3233 642.865,80.3317 642.874,80.3402 642.883,80.3487 642.892,80.3572 642.901,80.3657 642.911,80.3742 642.92,80.3826 642.929,80.3911 642.938,80.3996 642.947,80.4082 642.957,80.4167 642.966,80.4252 642.975,80.4337 642.984,80.4422 642.993,80.4507 643.002,80.4593 643.012,80.4678 643.021,80.4763 643.03,80.4849 643.039,80.4934 643.048,80.5019 643.058,80.5105 643.067,80.519 643.076,80.5276 643.085,80.5361 643.094,80.5447 643.104,80.5533 643.113,80.5618 643.122,80.5704 643.131,80.579 643.14,80.5876 643.149,80.5962 643.159,80.6047 643.168,80.6133 643.177,80.6219 643.186,80.6305 643.195,80.6391 643.205,80.6477 643.214,80.6563 643.223,80.6649 643.232,80.6736 643.241,80.6822 643.251,80.6908 643.26,80.6994 643.269,80.7081 643.278,80.7167 643.287,80.7253 643.297,80.734 643.306,80.7426 643.315,80.7513 643.324,80.7599 643.333,80.7686 643.342,80.7772 643.352,80.7859 643.361,80.7946 643.37,80.8032 643.379,80.8119 643.388,80.8206 643.398,80.8293 643.407,80.8379 643.416,80.8466 643.425,80.8553 643.434,80.864 643.444,80.8727 643.453,80.8814 643.462,80.8901 643.471,80.8988 643.48,80.9075 643.489,80.9163 643.499,80.925 643.508,80.9337 643.517,80.9424 643.526,80.9512 643.535,80.9599 643.545,80.9686 643.554,80.9774 643.563,80.9861 643.572,80.9949 643.581,81.0036 643.591,81.0124 643.6,81.0211 643.609,81.0299 643.618,81.0387 643.627,81.0474 643.637,81.0562 643.646,81.065 643.655,81.0738 643.664,81.0826 643.673,81.0914 643.682,81.1002 643.692,81.1089 643.701,81.1178 643.71,81.1266 643.719,81.1354 643.728,81.1442 643.738,81.153 643.747,81.1618 643.756,81.1706 643.765,81.1795 643.774,81.1883 643.784,81.1971 643.793,81.206 643.802,81.2148 643.811,81.2236 643.82,81.2325 643.829,81.2413 643.839,81.2502 643.848,81.2591 643.857,81.2679 643.866,81.2768 643.875,81.2857 643.885,81.2945 643.894,81.3034 643.903,81.3123 643.912,81.3212 643.921,81.3301 643.931,81.339 643.94,81.3479 643.949,81.3568 643.958,81.3657 643.967,81.3746 643.977,81.3835 643.986,81.3924 643.995,81.4013 644.004,81.4102 644.013,81.4192 644.022,81.4281 644.032,81.437 644.041,81.446 644.05,81.4549 644.059,81.4638 644.068,81.4728 644.078,81.4817 644.087,81.4907 644.096,81.4996 644.105,81.5086 644.114,81.5176 644.124,81.5265 644.133,81.5355 644.142,81.5445 644.151,81.5535 644.16,81.5625 644.169,81.5715 644.179,81.5804 644.188,81.5894 644.197,81.5984 644.206,81.6074 644.215,81.6165 644.225,81.6255 644.234,81.6345 644.243,81.6435 644.252,81.6525 644.261,81.6615 644.271,81.6706 644.28,81.6796 644.289,81.6886 644.298,81.6977 644.307,81.7067 644.317,81.7158 644.326,81.7248 644.335,81.7339 644.344,81.7429 644.353,81.752 644.362,81.7611 644.372,81.7702 644.381,81.7792 644.39,81.7883 644.399,81.7974 644.408,81.8065 644.418,81.8156 644.427,81.8247 644.436,81.8338 644.445,81.8429 644.454,81.852 644.464,81.8611 644.473,81.8702 644.482,81.8793 644.491,81.8884 644.5,81.8975 644.509,81.9067 644.519,81.9158 644.528,81.9249 644.537,81.9341 644.546,81.9432 644.555,81.9524 644.565,81.9615 644.574,81.9707 644.583,81.9798 644.592,81.989 644.601,81.9981 644.611,82.0073 644.62,82.0165 644.629,82.0257 644.638,82.0348 644.647,82.044 644.657,82.0532 644.666,82.0624 644.675,82.0716 644.684,82.0808 644.693,82.09 644.702,82.0992 644.712,82.1084 644.721,82.1176 644.73,82.1269 644.739,82.1361 644.748,82.1453 644.758,82.1545 644.767,82.1638 644.776,82.173 644.785,82.1822 644.794,82.1915 644.804,82.2007 644.813,82.21 644.822,82.2193 644.831,82.2285 644.84,82.2378 644.85,82.247 644.859,82.2563 644.868,82.2656 644.877,82.2749 644.886,82.2842 644.895,82.2934 644.905,82.3027 644.914,82.312 644.923,82.3213 644.932,82.3306 644.941,82.3399 644.951,82.3492 644.96,82.3586 644.969,82.3679 644.978,82.3772 644.987,82.3865 644.997,82.3958 645.006,82.4052 645.015,82.4145 645.024,82.4239 645.033,82.4332 645.042,82.4426 645.052,82.4519 645.061,82.4613 645.07,82.4706 645.079,82.48 645.088,82.4894 645.098,82.4987 645.107,82.5081 645.116,82.5175 645.125,82.5269 645.134,82.5362 645.144,82.5456 645.153,82.555 645.162,82.5644 645.171,82.5738 645.18,82.5832 645.19,82.5927 645.199,82.6021 645.208,82.6115 645.217,82.6209 645.226,82.6303 645.235,82.6398 645.245,82.6492 645.254,82.6586 645.263,82.6681 645.272,82.6775 645.281,82.687 645.291,82.6964 645.3,82.7059 645.309,82.7153 645.318,82.7248 645.327,82.7343 645.337,82.7437 645.346,82.7532 645.355,82.7627 645.364,82.7722 645.373,82.7817 645.382,82.7912 645.392,82.8007 645.401,82.8102 645.41,82.8197 645.419,82.8292 645.428,82.8387 645.438,82.8482 645.447,82.8577 645.456,82.8672 645.465,82.8768 645.474,82.8863 645.484,82.8958 645.493,82.9054 645.502,82.9149 645.511,82.9244 645.52,82.934 645.53,82.9436 645.539,82.9531 645.548,82.9627 645.557,82.9722 645.566,82.9818 645.575,82.9914 645.585,83.001 645.594,83.0105 645.603,83.0201 645.612,83.0297 645.621,83.0393 645.631,83.0489 645.64,83.0585 645.649,83.0681 645.658,83.0777 645.667,83.0873 645.677,83.097 645.686,83.1066 645.695,83.1162 645.704,83.1258 645.713,83.1355 645.722,83.1451 645.732,83.1547 645.741,83.1644 645.75,83.174 645.759,83.1837 645.768,83.1933 645.778,83.203 645.787,83.2127 645.796,83.2223 645.805,83.232 645.814,83.2417 645.824,83.2514 645.833,83.261 645.842,83.2707 645.851,83.2804 645.86,83.2901 645.87,83.2998 645.879,83.3095 645.888,83.3192 645.897,83.3289 645.906,83.3387 645.915,83.3484 645.925,83.3581 645.934,83.3678 645.943,83.3776 645.952,83.3873 645.961,83.397 645.971,83.4068 645.98,83.4165 645.989,83.4263 645.998,83.436 646.007,83.4458 646.017,83.4556 646.026,83.4653 646.035,83.4751 646.044,83.4849 646.053,83.4947 646.062,83.5044 646.072,83.5142 646.081,83.524 646.09,83.5338 646.099,83.5436 646.108,83.5534 646.118,83.5632 646.127,83.573 646.136,83.5829 646.145,83.5927 646.154,83.6025 646.164,83.6123 646.173,83.6222 646.182,83.632 646.191,83.6418 646.2,83.6517 646.21,83.6615 646.219,83.6714 646.228,83.6812 646.237,83.6911 646.246,83.701 646.255,83.7108 646.265,83.7207 646.274,83.7306 646.283,83.7404 646.292,83.7503 646.301,83.7602 646.311,83.7701 646.32,83.78 646.329,83.7899 646.338,83.7998 646.347,83.8097 646.357,83.8196 646.366,83.8295 646.375,83.8395 646.384,83.8494 646.393,83.8593 646.402,83.8692 646.412,83.8792 646.421,83.8891 646.43,83.8991 646.439,83.909 646.448,83.919 646.458,83.9289 646.467,83.9389 646.476,83.9489 646.485,83.9588 646.494,83.9688 646.504,83.9788 646.513,83.9888 646.522,83.9987 646.531,84.0087 646.54,84.0187 646.55,84.0287 646.559,84.0387 646.568,84.0487 646.577,84.0587 646.586,84.0687 646.595,84.0788 646.605,84.0888 646.614,84.0988 646.623,84.1088 646.632,84.1189 646.641,84.1289 646.651,84.139 646.66,84.149 646.669,84.1591 646.678,84.1691 646.687,84.1792 646.697,84.1892 646.706,84.1993 646.715,84.2094 646.724,84.2194 646.733,84.2295 646.742,84.2396 646.752,84.2497 646.761,84.2598 646.77,84.2699 646.779,84.28 646.788,84.2901 646.798,84.3002 646.807,84.3103 646.816,84.3204 646.825,84.3305 646.834,84.3407 646.844,84.3508 646.853,84.3609 646.862,84.371 646.871,84.3812 646.88,84.3913 646.89,84.4015 646.899,84.4116 646.908,84.4218 646.917,84.432 646.926,84.4421 646.935,84.4523 646.945,84.4625 646.954,84.4726 646.963,84.4828 646.972,84.493 646.981,84.5032 646.991,84.5134 647,84.5236 647.009,84.5338 647.018,84.544 647.027,84.5542 647.037,84.5644 647.046,84.5746 647.055,84.5849 647.064,84.5951 647.073,84.6053 647.083,84.6156 647.092,84.6258 647.101,84.636 647.11,84.6463 647.119,84.6565 647.128,84.6668 647.138,84.6771 647.147,84.6873 647.156,84.6976 647.165,84.7079 647.174,84.7181 647.184,84.7284 647.193,84.7387 647.202,84.749 647.211,84.7593 647.22,84.7696 647.23,84.7799 647.239,84.7902 647.248,84.8005 647.257,84.8108 647.266,84.8211 647.275,84.8315 647.285,84.8418 647.294,84.8521 647.303,84.8624 647.312,84.8728 647.321,84.8831 647.331,84.8935 647.34,84.9038 647.349,84.9142 647.358,84.9245 647.367,84.9349 647.377,84.9453 647.386,84.9557 647.395,84.966 647.404,84.9764 647.413,84.9868 647.423,84.9972 647.432,85.0076 647.441,85.018 647.45,85.0284 647.459,85.0388 647.468,85.0492 647.478,85.0596 647.487,85.07 647.496,85.0805 647.505,85.0909 647.514,85.1013 647.524,85.1117 647.533,85.1222 647.542,85.1326 647.551,85.1431 647.56,85.1535 647.57,85.164 647.579,85.1745 647.588,85.1849 647.597,85.1954 647.606,85.2059 647.615,85.2163 647.625,85.2268 647.634,85.2373 647.643,85.2478 647.652,85.2583 647.661,85.2688 647.671,85.2793 647.68,85.2898 647.689,85.3003 647.698,85.3108 647.707,85.3213 647.717,85.3319 647.726,85.3424 647.735,85.3529 647.744,85.3635 647.753,85.374 647.763,85.3846 647.772,85.3951 647.781,85.4057 647.79,85.4162 647.799,85.4268 647.808,85.4374 647.818,85.4479 647.827,85.4585 647.836,85.4691 647.845,85.4797 647.854,85.4903 647.864,85.5008 647.873,85.5114 647.882,85.522 647.891,85.5326 647.9,85.5433 647.91,85.5539 647.919,85.5645 647.928,85.5751 647.937,85.5857 647.946,85.5964 647.955,85.607 647.965,85.6176 647.974,85.6283 647.983,85.6389 647.992,85.6496 648.001,85.6602 648.011,85.6709 648.02,85.6816 648.029,85.6922 648.038,85.7029 648.047,85.7136 648.057,85.7243 648.066,85.735 648.075,85.7457 648.084,85.7563 648.093,85.767 648.103,85.7778 648.112,85.7885 648.121,85.7992 648.13,85.8099 648.139,85.8206 648.148,85.8313 648.158,85.8421 648.167,85.8528 648.176,85.8635 648.185,85.8743 648.194,85.885 648.204,85.8958 648.213,85.9065 648.222,85.9173 648.231,85.9281 648.24,85.9388 648.25,85.9496 648.259,85.9604 648.268,85.9712 648.277,85.9819 648.286,85.9927 648.295,86.0035 648.305,86.0143 648.314,86.0251 648.323,86.0359 648.332,86.0468 648.341,86.0576 648.351,86.0684 648.36,86.0792 648.369,86.09 648.378,86.1009 648.387,86.1117 648.397,86.1226 648.406,86.1334 648.415,86.1443 648.424,86.1551 648.433,86.166 648.443,86.1768 648.452,86.1877 648.461,86.1986 648.47,86.2094 648.479,86.2203 648.488,86.2312 648.498,86.2421 648.507,86.253 648.516,86.2639 648.525,86.2748 648.534,86.2857 648.544,86.2966 648.553,86.3075 648.562,86.3185 648.571,86.3294 648.58,86.3403 648.59,86.3512 648.599,86.3622 648.608,86.3731 648.617,86.3841 648.626,86.395 648.635,86.406 648.645,86.4169 648.654,86.4279 648.663,86.4389 648.672,86.4499 648.681,86.4609 648.691,86.4719 648.7,86.4829 648.709,86.4939 648.718,86.5049 648.727,86.5159 648.737,86.527 648.746,86.538 648.755,86.5491 648.764,86.5601 648.773,86.5712 648.783,86.5823 648.792,86.5933 648.801,86.6044 648.81,86.6155 648.819,86.6266 648.828,86.6377 648.838,86.6488 648.847,86.66 648.856,86.6711 648.865,86.6822 648.874,86.6934 648.884,86.7045 648.893,86.7157 648.902,86.7269 648.911,86.738 648.92,86.7492 648.93,86.7604 648.939,86.7716 648.948,86.7828 648.957,86.794 648.966,86.8052 648.975,86.8165 648.985,86.8277 648.994,86.8389 649.003,86.8502 649.012,86.8614 649.021,86.8727 649.031,86.884 649.04,86.8952 649.049,86.9065 649.058,86.9178 649.067,86.9291 649.077,86.9404 649.086,86.9517 649.095,86.9631 649.104,86.9744 649.113,86.9857 649.123,86.9971 649.132,87.0084 649.141,87.0198 649.15,87.0311 649.159,87.0425 649.168,87.0539 649.178,87.0653 649.187,87.0767 649.196,87.0881 649.205,87.0995 649.214,87.1109 649.224,87.1223 649.233,87.1337 649.242,87.1452 649.251,87.1566 649.26,87.1681 649.27,87.1795 649.279,87.191 649.288,87.2025 649.297,87.214 649.306,87.2255 649.315,87.237 649.325,87.2485 649.334,87.26 649.343,87.2715 649.352,87.283 649.361,87.2946 649.371,87.3061 649.38,87.3177 649.389,87.3292 649.398,87.3408 649.407,87.3524 649.417,87.3639 649.426,87.3755 649.435,87.3871 649.444,87.3987 649.453,87.4103 649.463,87.4219 649.472,87.4336 649.481,87.4452 649.49,87.4568 649.499,87.4685 649.508,87.4801 649.518,87.4918 649.527,87.5035 649.536,87.5151 649.545,87.5268 649.554,87.5385 649.564,87.5502 649.573,87.5619 649.582,87.5736 649.591,87.5854 649.6,87.5971 649.61,87.6088 649.619,87.6206 649.628,87.6323 649.637,87.6441 649.646,87.6558 649.656,87.6676 649.665,87.6794 649.674,87.6912 649.683,87.703 649.692,87.7148 649.701,87.7266 649.711,87.7384 649.72,87.7502 649.729,87.7621 649.738,87.7739 649.747,87.7858 649.757,87.7976 649.766,87.8095 649.775,87.8214 649.784,87.8332 649.793,87.8451 649.803,87.857 649.812,87.8689 649.821,87.8808 649.83,87.8927 649.839,87.9047 649.848,87.9166 649.858,87.9285 649.867,87.9405 649.876,87.9524 649.885,87.9644 649.894,87.9764 649.904,87.9884 649.913,88.0003 649.922,88.0123 649.931,88.0243 649.94,88.0363 649.95,88.0484 649.959,88.0604 649.968,88.0724 649.977,88.0844 649.986,88.0965 649.996,88.1085 650.005,88.1206 650.014,88.1327 650.023,88.1447 650.032,88.1568 650.041,88.1689 650.051,88.181 650.06,88.1931 650.069,88.2052 650.078,88.2174 650.087,88.2295 650.097,88.2416 650.106,88.2538 650.115,88.2659 650.124,88.2781 650.133,88.2902 650.143,88.3024 650.152,88.3146 650.161,88.3268 650.17,88.339 650.179,88.3512 650.188,88.3634 650.198,88.3756 650.207,88.3878 650.216,88.4001 650.225,88.4123 650.234,88.4246 650.244,88.4368 650.253,88.4491 650.262,88.4614 650.271,88.4737 650.28,88.4859 650.29,88.4982 650.299,88.5105 650.308,88.5229 650.317,88.5352 650.326,88.5475 650.336,88.5598 650.345,88.5722 650.354,88.5845 650.363,88.5969 650.372,88.6093 650.381,88.6216 650.391,88.634 650.4,88.6464 650.409,88.6588 650.418,88.6712 650.427,88.6836 650.437,88.696 650.446,88.7085 650.455,88.7209 650.464,88.7333 650.473,88.7458 650.483,88.7582 650.492,88.7707 650.501,88.7832 650.51,88.7957 650.519,88.8081 650.528,88.8206 650.538,88.8331 650.547,88.8457 650.556,88.8582 650.565,88.8707 650.574,88.8832 650.584,88.8958 650.593,88.9083 650.602,88.9209 650.611,88.9335 650.62,88.946 650.63,88.9586 650.639,88.9712 650.648,88.9838 650.657,88.9964 650.666,89.009 650.676,89.0216 650.685,89.0343 650.694,89.0469 650.703,89.0595 650.712,89.0722 650.721,89.0848 650.731,89.0975 650.74,89.1102 650.749,89.1229 650.758,89.1356 650.767,89.1483 650.777,89.161 650.786,89.1737 650.795,89.1864 650.804,89.1991 650.813,89.2119 650.823,89.2246 650.832,89.2374 650.841,89.2501 650.85,89.2629 650.859,89.2757 650.868,89.2884 650.878,89.3012 650.887,89.314 650.896,89.3268 650.905,89.3396 650.914,89.3525 650.924,89.3653 650.933,89.3781 650.942,89.391 650.951,89.4038 650.96,89.4167 650.97,89.4296 650.979,89.4424 650.988,89.4553 650.997,89.4682 651.006,89.4811 651.016,89.494 651.025,89.5069 651.034,89.5199 651.043,89.5328 651.052,89.5457 651.061,89.5587 651.071,89.5716 651.08,89.5846 651.089,89.5976 651.098,89.6106 651.107,89.6235 651.117,89.6365 651.126,89.6495 651.135,89.6626 651.144,89.6756 651.153,89.6886 651.163,89.7016 651.172,89.7147 651.181,89.7277 651.19,89.7408 651.199,89.7538 651.208,89.7669 651.218,89.78 651.227,89.7931 651.236,89.8062 651.245,89.8193 651.254,89.8324 651.264,89.8455 651.273,89.8586 651.282,89.8718 651.291,89.8849 651.3,89.8981 651.31,89.9112 651.319,89.9244 651.328,89.9376 651.337,89.9508 651.346,89.964 651.356,89.9772 651.365,89.9904 651.374,90.0036 651.383,90.0168 651.392,90.03 651.401,90.0433 651.411,90.0565 651.42,90.0698 651.429,90.083 651.438,90.0963 651.447,90.1096 651.457,90.1229 651.466,90.1362 651.475,90.1495 651.484,90.1628 651.493,90.1761 651.503,90.1894 651.512,90.2028 651.521,90.2161 651.53,90.2295 651.539,90.2428 651.548,90.2562 651.558,90.2696 651.567,90.2829 651.576,90.2963 651.585,90.3097 651.594,90.3231 651.604,90.3366 651.613,90.35 651.622,90.3634 651.631,90.3768 651.64,90.3903 651.65,90.4037 651.659,90.4172 651.668,90.4307 651.677,90.4442 651.686,90.4576 651.696,90.4711 651.705,90.4846 651.714,90.4981 651.723,90.5117 651.732,90.5252 651.741,90.5387 651.751,90.5523 651.76,90.5658 651.769,90.5794 651.778,90.5929 651.787,90.6065 651.797,90.6201 651.806,90.6337 651.815,90.6473 651.824,90.6609 651.833,90.6745 651.843,90.6881 651.852,90.7018 651.861,90.7154 651.87,90.729 651.879,90.7427 651.888,90.7564 651.898,90.77 651.907,90.7837 651.916,90.7974 651.925,90.8111 651.934,90.8248 651.944,90.8385 651.953,90.8522 651.962,90.866 651.971,90.8797 651.98,90.8934 651.99,90.9072 651.999,90.9209 652.008,90.9347 652.017,90.9485 652.026,90.9623 652.036,90.9761 652.045,90.9899 652.054,91.0037 652.063,91.0175 652.072,91.0313 652.081,91.0452 652.091,91.059 652.1,91.0728 652.109,91.0867 652.118,91.1006 652.127,91.1144 652.137,91.1283 652.146,91.1422 652.155,91.1561 652.164,91.17 652.173,91.1839 652.183,91.1978 652.192,91.2118 652.201,91.2257 652.21,91.2397 652.219,91.2536 652.229,91.2676 652.238,91.2815 652.247,91.2955 652.256,91.3095 652.265,91.3235 652.274,91.3375 652.284,91.3515 652.293,91.3655 652.302,91.3796 652.311,91.3936 652.32,91.4076 652.33,91.4217 652.339,91.4358 652.348,91.4498 652.357,91.4639 652.366,91.478 652.376,91.4921 652.385,91.5062 652.394,91.5203 652.403,91.5344 652.412,91.5485 652.421,91.5627 652.431,91.5768 652.44,91.591 652.449,91.6051 652.458,91.6193 652.467,91.6335 652.477,91.6476 652.486,91.6618 652.495,91.676 652.504,91.6902 652.513,91.7045 652.523,91.7187 652.532,91.7329 652.541,91.7472 652.55,91.7614 652.559,91.7757 652.569,91.7899 652.578,91.8042 652.587,91.8185 652.596,91.8328 652.605,91.8471 652.614,91.8614 652.624,91.8757 652.633,91.89 652.642,91.9043 652.651,91.9187 652.66,91.933 652.67,91.9474 652.679,91.9617 652.688,91.9761 652.697,91.9905 652.706,92.0049 652.716,92.0193 652.725,92.0337 652.734,92.0481 652.743,92.0625 652.752,92.077 652.761,92.0914 652.771,92.1058 652.78,92.1203 652.789,92.1348 652.798,92.1492 652.807,92.1637 652.817,92.1782 652.826,92.1927 652.835,92.2072 652.844,92.2217 652.853,92.2362 652.863,92.2508 652.872,92.2653 652.881,92.2798 652.89,92.2944 652.899,92.309 652.909,92.3235 652.918,92.3381 652.927,92.3527 652.936,92.3673 652.945,92.3819 652.954,92.3965 652.964,92.4111 652.973,92.4258 652.982,92.4404 652.991,92.4551 653,92.4697 653.01,92.4844 653.019,92.499 653.028,92.5137 653.037,92.5284 653.046,92.5431 653.056,92.5578 653.065,92.5725 653.074,92.5872 653.083,92.602 653.092,92.6167 653.101,92.6315 653.111,92.6462 653.12,92.661 653.129,92.6757 653.138,92.6905 653.147,92.7053 653.157,92.7201 653.166,92.7349 653.175,92.7497 653.184,92.7645 653.193,92.7794 653.203,92.7942 653.212,92.8091 653.221,92.8239 653.23,92.8388 653.239,92.8536 653.249,92.8685 653.258,92.8834 653.267,92.8983 653.276,92.9132 653.285,92.9281 653.294,92.9431 653.304,92.958 653.313,92.9729 653.322,92.9879 653.331,93.0028 653.34,93.0178 653.35,93.0328 653.359,93.0477 653.368,93.0627 653.377,93.0777 653.386,93.0927 653.396,93.1078 653.405,93.1228 653.414,93.1378 653.423,93.1528 653.432,93.1679 653.441,93.183 653.451,93.198 653.46,93.2131 653.469,93.2282 653.478,93.2433 653.487,93.2584 653.497,93.2735 653.506,93.2886 653.515,93.3037 653.524,93.3188 653.533,93.334 653.543,93.3491 653.552,93.3643 653.561,93.3795 653.57,93.3946 653.579,93.4098 653.589,93.425 653.598,93.4402 653.607,93.4554 653.616,93.4706 653.625,93.4859 653.634,93.5011 653.644,93.5163 653.653,93.5316 653.662,93.5469 653.671,93.5621 653.68,93.5774 653.69,93.5927 653.699,93.608 653.708,93.6233 653.717,93.6386 653.726,93.6539 653.736,93.6692 653.745,93.6846 653.754,93.6999 653.763,93.7153 653.772,93.7306 653.781,93.746 653.791,93.7614 653.8,93.7768 653.809,93.7922 653.818,93.8076 653.827,93.823 653.837,93.8384 653.846,93.8539 653.855,93.8693 653.864,93.8847 653.873,93.9002 653.883,93.9157 653.892,93.9311 653.901,93.9466 653.91,93.9621 653.919,93.9776 653.929,93.9931 653.938,94.0086 653.947,94.0242 653.956,94.0397 653.965,94.0552 653.974,94.0708 653.984,94.0863 653.993,94.1019 654.002,94.1175 654.011,94.1331 654.02,94.1487 654.03,94.1643 654.039,94.1799 654.048,94.1955 654.057,94.2111 654.066,94.2268 654.076,94.2424 654.085,94.2581 654.094,94.2737 654.103,94.2894 654.112,94.3051 654.121,94.3208 654.131,94.3365 654.14,94.3522 654.149,94.3679 654.158,94.3836 654.167,94.3993 654.177,94.4151 654.186,94.4308 654.195,94.4466 654.204,94.4623 654.213,94.4781 654.223,94.4939 654.232,94.5097 654.241,94.5255 654.25,94.5413 654.259,94.5571 654.269,94.5729 654.278,94.5888 654.287,94.6046 654.296,94.6205 654.305,94.6363 654.314,94.6522 654.324,94.6681 654.333,94.684 654.342,94.6999 654.351,94.7158 654.36,94.7317 654.37,94.7476 654.379,94.7635 654.388,94.7795 654.397,94.7954 654.406,94.8114 654.416,94.8273 654.425,94.8433 654.434,94.8593 654.443,94.8753 654.452,94.8913 654.462,94.9073 654.471,94.9233 654.48,94.9393 654.489,94.9554 654.498,94.9714 654.507,94.9875 654.517,95.0035 654.526,95.0196 654.535,95.0357 654.544,95.0518 654.553,95.0679 654.563,95.084 654.572,95.1001 654.581,95.1162 654.59,95.1323 654.599,95.1485 654.609,95.1646 654.618,95.1808 654.627,95.1969 654.636,95.2131 654.645,95.2293 654.654,95.2455 654.664,95.2617 654.673,95.2779 654.682,95.2941 654.691,95.3103 654.7,95.3266 654.71,95.3428 654.719,95.3591 654.728,95.3753 654.737,95.3916 654.746,95.4079 654.756,95.4242 654.765,95.4405 654.774,95.4568 654.783,95.4731 654.792,95.4894 654.802,95.5057 654.811,95.5221 654.82,95.5384 654.829,95.5548 654.838,95.5712 654.847,95.5875 654.857,95.6039 654.866,95.6203 654.875,95.6367 654.884,95.6531 654.893,95.6695 654.903,95.686 654.912,95.7024 654.921,95.7189 654.93,95.7353 654.939,95.7518 654.949,95.7682 654.958,95.7847 654.967,95.8012 654.976,95.8177 654.985,95.8342 654.994,95.8507 655.004,95.8673 655.013,95.8838 655.022,95.9003 655.031,95.9169 655.04,95.9335 655.05,95.95 655.059,95.9666 655.068,95.9832 655.077,95.9998 655.086,96.0164 655.096,96.033 655.105,96.0496 655.114,96.0663 655.123,96.0829 655.132,96.0996 655.142,96.1162 655.151,96.1329 655.16,96.1496 655.169,96.1662 655.178,96.1829 655.187,96.1996 655.197,96.2164 655.206,96.2331 655.215,96.2498 655.224,96.2665 655.233,96.2833 655.243,96.3 655.252,96.3168 655.261,96.3336 655.27,96.3504 655.279,96.3672 655.289,96.384 655.298,96.4008 655.307,96.4176 655.316,96.4344 655.325,96.4513 655.334,96.4681 655.344,96.485 655.353,96.5018 655.362,96.5187 655.371,96.5356 655.38,96.5525 655.39,96.5694 655.399,96.5863 655.408,96.6032 655.417,96.6201 655.426,96.637 655.436,96.654 655.445,96.6709 655.454,96.6879 655.463,96.7049 655.472,96.7218 655.482,96.7388 655.491,96.7558 655.5,96.7728 655.509,96.7899 655.518,96.8069 655.527,96.8239 655.537,96.841 655.546,96.858 655.555,96.8751 655.564,96.8921 655.573,96.9092 655.583,96.9263 655.592,96.9434 655.601,96.9605 655.61,96.9776 655.619,96.9947 655.629,97.0119 655.638,97.029 655.647,97.0462 655.656,97.0633 655.665,97.0805 655.674,97.0977 655.684,97.1148 655.693,97.132 655.702,97.1492 655.711,97.1665 655.72,97.1837 655.73,97.2009 655.739,97.2182 655.748,97.2354 655.757,97.2527 655.766,97.2699 655.776,97.2872 655.785,97.3045 655.794,97.3218 655.803,97.3391 655.812,97.3564 655.822,97.3737 655.831,97.391 655.84,97.4084 655.849,97.4257 655.858,97.4431 655.867,97.4605 655.877,97.4778 655.886,97.4952 655.895,97.5126 655.904,97.53 655.913,97.5474 655.923,97.5648 655.932,97.5823 655.941,97.5997 655.95,97.6172 655.959,97.6346 655.969,97.6521 655.978,97.6696 655.987,97.687 655.996,97.7045 656.005,97.722 656.014,97.7396 656.024,97.7571 656.033,97.7746 656.042,97.7921 656.051,97.8097 656.06,97.8272 656.07,97.8448 656.079,97.8624 656.088,97.88 656.097,97.8976 656.106,97.9152 656.116,97.9328 656.125,97.9504 656.134,97.968 656.143,97.9857 656.152,98.0033 656.162,98.021 656.171,98.0386 656.18,98.0563 656.189,98.074 656.198,98.0917 656.207,98.1094 656.217,98.1271 656.226,98.1448 656.235,98.1626 656.244,98.1803 656.253,98.198 656.263,98.2158 656.272,98.2336 656.281,98.2513 656.29,98.2691 656.299,98.2869 656.309,98.3047 656.318,98.3225 656.327,98.3404 656.336,98.3582 656.345,98.376 656.354,98.3939 656.364,98.4117 656.373,98.4296 656.382,98.4475 656.391,98.4654 656.4,98.4833 656.41,98.5012 656.419,98.5191 656.428,98.537 656.437,98.5549 656.446,98.5729 656.456,98.5908 656.465,98.6088 656.474,98.6268 656.483,98.6447 656.492,98.6627 656.502,98.6807 656.511,98.6987 656.52,98.7167 656.529,98.7348 656.538,98.7528 656.547,98.7708 656.557,98.7889 656.566,98.807 656.575,98.825 656.584,98.8431 656.593,98.8612 656.603,98.8793 656.612,98.8974 656.621,98.9155 656.63,98.9336 656.639,98.9518 656.649,98.9699 656.658,98.9881 656.667,99.0062 656.676,99.0244 656.685,99.0426 656.694,99.0608 656.704,99.079 656.713,99.0972 656.722,99.1154 656.731,99.1336 656.74,99.1519 656.75,99.1701 656.759,99.1884 656.768,99.2066 656.777,99.2249 656.786,99.2432 656.796,99.2615 656.805,99.2798 656.814,99.2981 656.823,99.3164 656.832,99.3347 656.842,99.3531 656.851,99.3714 656.86,99.3898 656.869,99.4081 656.878,99.4265 656.887,99.4449 656.897,99.4633 656.906,99.4817 656.915,99.5001 656.924,99.5185 656.933,99.537 656.943,99.5554 656.952,99.5739 656.961,99.5923 656.97,99.6108 656.979,99.6293 656.989,99.6478 656.998,99.6663 657.007,99.6848 657.016,99.7033 657.025,99.7218 657.035,99.7403 657.044,99.7589 657.053,99.7774 657.062,99.796 657.071,99.8146 657.08,99.8331 657.09,99.8517 657.099,99.8703 657.108,99.8889 657.117,99.9076 657.126,99.9262 657.136,99.9448 657.145,99.9635 657.154,99.9821 657.163,100.001 657.172,100.019 657.182,100.038 657.191,100.057 657.2,100.076 657.209,100.094 657.218,100.113 657.227,100.132 657.237,100.15 657.246,100.169 657.255,100.188 657.264,100.207 657.273,100.225 657.283,100.244 657.292,100.263 657.301,100.282 657.31,100.301 657.319,100.32 657.329,100.338 657.338,100.357 657.347,100.376 657.356,100.395 657.365,100.414 657.375,100.433 657.384,100.452 657.393,100.47 657.402,100.489 657.411,100.508 657.42,100.527 657.43,100.546 657.439,100.565 657.448,100.584 657.457,100.603 657.466,100.622 657.476,100.641 657.485,100.66 657.494,100.679 657.503,100.698 657.512,100.717 657.522,100.736 657.531,100.755 657.54,100.774 657.549,100.793 657.558,100.812 657.567,100.831 657.577,100.85 657.586,100.87 657.595,100.889 657.604,100.908 657.613,100.927 657.623,100.946 657.632,100.965 657.641,100.984 657.65,101.003 657.659,101.023 657.669,101.042 657.678,101.061 657.687,101.08 657.696,101.099 657.705,101.119 657.715,101.138 657.724,101.157 657.733,101.176 657.742,101.196 657.751,101.215 657.76,101.234 657.77,101.253 657.779,101.273 657.788,101.292 657.797,101.311 657.806,101.331 657.816,101.35 657.825,101.369 657.834,101.389 657.843,101.408 657.852,101.428 657.862,101.447 657.871,101.466 657.88,101.486 657.889,101.505 657.898,101.525 657.907,101.544 657.917,101.563 657.926,101.583 657.935,101.602 657.944,101.622 657.953,101.641 657.963,101.661 657.972,101.68 657.981,101.7 657.99,101.719 657.999,101.739 658.009,101.758 658.018,101.778 658.027,101.797 658.036,101.817 658.045,101.837 658.055,101.856 658.064,101.876 658.073,101.895 658.082,101.915 658.091,101.935 658.1,101.954 658.11,101.974 658.119,101.994 658.128,102.013 658.137,102.033 658.146,102.053 658.156,102.072 658.165,102.092 658.174,102.112 658.183,102.131 658.192,102.151 658.202,102.171 658.211,102.191 658.22,102.21 658.229,102.23 658.238,102.25 658.247,102.27 658.257,102.289 658.266,102.309 658.275,102.329 658.284,102.349 658.293,102.369 658.303,102.389 658.312,102.408 658.321,102.428 658.33,102.448 658.339,102.468 658.349,102.488 658.358,102.508 658.367,102.528 658.376,102.548 658.385,102.568 658.395,102.588 658.404,102.607 658.413,102.627 658.422,102.647 658.431,102.667 658.44,102.687 658.45,102.707 658.459,102.727 658.468,102.747 658.477,102.767 658.486,102.787 658.496,102.808 658.505,102.828 658.514,102.848 658.523,102.868 658.532,102.888 658.542,102.908 658.551,102.928 658.56,102.948 658.569,102.968 658.578,102.988 658.587,103.008 658.597,103.029 658.606,103.049 658.615,103.069 658.624,103.089 658.633,103.109 658.643,103.13 658.652,103.15 658.661,103.17 658.67,103.19 658.679,103.21 658.689,103.231 658.698,103.251 658.707,103.271 658.716,103.292 658.725,103.312 658.735,103.332 658.744,103.352 658.753,103.373 658.762,103.393 658.771,103.413 658.78,103.434 658.79,103.454 658.799,103.474 658.808,103.495 658.817,103.515 658.826,103.536 658.836,103.556 658.845,103.576 658.854,103.597 658.863,103.617 658.872,103.638 658.882,103.658 658.891,103.679 658.9,103.699 658.909,103.72 658.918,103.74 658.927,103.761 658.937,103.781 658.946,103.802 658.955,103.822 658.964,103.843 658.973,103.863 658.983,103.884 658.992,103.904 659.001,103.925 659.01,103.946 659.019,103.966 659.029,103.987 659.038,104.007 659.047,104.028 659.056,104.049 659.065,104.069 659.075,104.09 659.084,104.111 659.093,104.131 659.102,104.152 659.111,104.173 659.12,104.194 659.13,104.214 659.139,104.235 659.148,104.256 659.157,104.276 659.166,104.297 659.176,104.318 659.185,104.339 659.194,104.36 659.203,104.38 659.212,104.401 659.222,104.422 659.231,104.443 659.24,104.464 659.249,104.484 659.258,104.505 659.267,104.526 659.277,104.547 659.286,104.568 659.295,104.589 659.304,104.61 659.313,104.631 659.323,104.652 659.332,104.673 659.341,104.694 659.35,104.714 659.359,104.735 659.369,104.756 659.378,104.777 659.387,104.798 659.396,104.819 659.405,104.84 659.415,104.861 659.424,104.882 659.433,104.904 659.442,104.925 659.451,104.946 659.46,104.967 659.47,104.988 659.479,105.009 659.488,105.03 659.497,105.051 659.506,105.072 659.516,105.093 659.525,105.115 659.534,105.136 659.543,105.157 659.552,105.178 659.562,105.199 659.571,105.22 659.58,105.242 659.589,105.263 659.598,105.284 659.608,105.305 659.617,105.327 659.626,105.348 659.635,105.369 659.644,105.39 659.653,105.412 659.663,105.433 659.672,105.454 659.681,105.476 659.69,105.497 659.699,105.518 659.709,105.54 659.718,105.561 659.727,105.582 659.736,105.604 659.745,105.625 659.755,105.646 659.764,105.668 659.773,105.689 659.782,105.711 659.791,105.732 659.8,105.754 659.81,105.775 659.819,105.796 659.828,105.818 659.837,105.839 659.846,105.861 659.856,105.882 659.865,105.904 659.874,105.925 659.883,105.947 659.892,105.968 659.902,105.99 659.911,106.012 659.92,106.033 659.929,106.055 659.938,106.076 659.948,106.098 659.957,106.12 659.966,106.141 659.975,106.163 659.984,106.184 659.993,106.206 660.003,106.228 660.012,106.249 660.021,106.271 660.03,106.293 660.039,106.315 660.049,106.336 660.058,106.358 660.067,106.38 660.076,106.401 660.085,106.423 660.095,106.445 660.104,106.467 660.113,106.489 660.122,106.51 660.131,106.532 660.14,106.554 660.15,106.576 660.159,106.598 660.168,106.619 660.177,106.641 660.186,106.663 660.196,106.685 660.205,106.707 660.214,106.729 660.223,106.751 660.232,106.773 660.242,106.795 660.251,106.817 660.26,106.838 660.269,106.86 660.278,106.882 660.288,106.904 660.297,106.926 660.306,106.948 660.315,106.97 660.324,106.992 660.333,107.014 660.343,107.036 660.352,107.058 660.361,107.081 660.37,107.103 660.379,107.125 660.389,107.147 660.398,107.169 660.407,107.191 660.416,107.213 660.425,107.235 660.435,107.257 660.444,107.28 660.453,107.302 660.462,107.324 660.471,107.346 660.48,107.368 660.49,107.39 660.499,107.413 660.508,107.435 660.517,107.457 660.526,107.479 660.536,107.502 660.545,107.524 660.554,107.546 660.563,107.568 660.572,107.591 660.582,107.613 660.591,107.635 660.6,107.658 660.609,107.68 660.618,107.702 660.628,107.725 660.637,107.747 660.646,107.769 660.655,107.792 660.664,107.814 660.673,107.837 660.683,107.859 660.692,107.881 660.701,107.904 660.71,107.926 660.719,107.949 660.729,107.971 660.738,107.994 660.747,108.016 660.756,108.039 660.765,108.061 660.775,108.084 660.784,108.106 660.793,108.129 660.802,108.151 660.811,108.174 660.82,108.196 660.83,108.219 660.839,108.242 660.848,108.264 660.857,108.287 660.866,108.309 660.876,108.332 660.885,108.355 660.894,108.377 660.903,108.4 660.912,108.423 660.922,108.445 660.931,108.468 660.94,108.491 660.949,108.513 660.958,108.536 660.968,108.559 660.977,108.582 660.986,108.604 660.995,108.627 661.004,108.65 661.013,108.673 661.023,108.695 661.032,108.718 661.041,108.741 661.05,108.764 661.059,108.787 661.069,108.809 661.078,108.832 661.087,108.855 661.096,108.878 661.105,108.901 661.115,108.924 661.124,108.947 661.133,108.97 661.142,108.993 661.151,109.016 661.16,109.038 661.17,109.061 661.179,109.084 661.188,109.107 661.197,109.13 661.206,109.153 661.216,109.176 661.225,109.199 661.234,109.222 661.243,109.245 661.252,109.268 661.262,109.292 661.271,109.315 661.28,109.338 661.289,109.361 661.298,109.384 661.308,109.407 661.317,109.43 661.326,109.453 661.335,109.476 661.344,109.5 661.353,109.523 661.363,109.546 661.372,109.569 661.381,109.592 661.39,109.615 661.399,109.639 661.409,109.662 661.418,109.685 661.427,109.708 661.436,109.732 661.445,109.755 661.455,109.778 661.464,109.801 661.473,109.825 661.482,109.848 661.491,109.871 661.5,109.895 661.51,109.918 661.519,109.941 661.528,109.965 661.537,109.988 661.546,110.011 661.556,110.035 661.565,110.058 661.574,110.082 661.583,110.105 661.592,110.129 661.602,110.152 661.611,110.175 661.62,110.199 661.629,110.222 661.638,110.246 661.648,110.269 661.657,110.293 661.666,110.316 661.675,110.34 661.684,110.363 661.693,110.387 661.703,110.411 661.712,110.434 661.721,110.458 661.73,110.481 661.739,110.505 661.749,110.528 661.758,110.552 661.767,110.576 661.776,110.599 661.785,110.623 661.795,110.647 661.804,110.67 661.813,110.694 661.822,110.718 661.831,110.741 661.841,110.765 661.85,110.789 661.859,110.813 661.868,110.836 661.877,110.86 661.886,110.884 661.896,110.908 661.905,110.931 661.914,110.955 661.923,110.979 661.932,111.003 661.942,111.027 661.951,111.05 661.96,111.074 661.969,111.098 661.978,111.122 661.988,111.146 661.997,111.17 662.006,111.194 662.015,111.218 662.024,111.242 662.033,111.265 662.043,111.289 662.052,111.313 662.061,111.337 662.07,111.361 662.079,111.385 662.089,111.409 662.098,111.433 662.107,111.457 662.116,111.481 662.125,111.505 662.135,111.529 662.144,111.553 662.153,111.578 662.162,111.602 662.171,111.626 662.181,111.65 662.19,111.674 662.199,111.698 662.208,111.722 662.217,111.746 662.226,111.77 662.236,111.795 662.245,111.819 662.254,111.843 662.263,111.867 662.272,111.891 662.282,111.916 662.291,111.94 662.3,111.964 662.309,111.988 662.318,112.013 662.328,112.037 662.337,112.061 662.346,112.085 662.355,112.11 662.364,112.134 662.373,112.158 662.383,112.183 662.392,112.207 662.401,112.231 662.41,112.256 662.419,112.28 662.429,112.304 662.438,112.329 662.447,112.353 662.456,112.378 662.465,112.402 662.475,112.427 662.484,112.451 662.493,112.475 662.502,112.5 662.511,112.524 662.521,112.549 662.53,112.573 662.539,112.598 662.548,112.622 662.557,112.647 662.566,112.671 662.576,112.696 662.585,112.721 662.594,112.745 662.603,112.77 662.612,112.794 662.622,112.819 662.631,112.844 662.64,112.868 662.649,112.893 662.658,112.918 662.668,112.942 662.677,112.967 662.686,112.992 662.695,113.016 662.704,113.041 662.713,113.066 662.723,113.09 662.732,113.115 662.741,113.14 662.75,113.165 662.759,113.189 662.769,113.214 662.778,113.239 662.787,113.264 662.796,113.289 662.805,113.313 662.815,113.338 662.824,113.363 662.833,113.388 662.842,113.413 662.851,113.438 662.861,113.462 662.87,113.487 662.879,113.512 662.888,113.537 662.897,113.562 662.906,113.587 662.916,113.612 662.925,113.637 662.934,113.662 662.943,113.687 662.952,113.712 662.962,113.737 662.971,113.762 662.98,113.787 662.989,113.812 662.998,113.837 663.008,113.862 663.017,113.887 663.026,113.912 663.035,113.937 663.044,113.962 663.053,113.987 663.063,114.013 663.072,114.038 663.081,114.063 663.09,114.088 663.099,114.113 663.109,114.138 663.118,114.163 663.127,114.189 663.136,114.214 663.145,114.239 663.155,114.264 663.164,114.29 663.173,114.315 663.182,114.34 663.191,114.365 663.201,114.391 663.21,114.416 663.219,114.441 663.228,114.467 663.237,114.492 663.246,114.517 663.256,114.542 663.265,114.568 663.274,114.593 663.283,114.619 663.292,114.644 663.302,114.669 663.311,114.695 663.32,114.72 663.329,114.746 663.338,114.771 663.348,114.797 663.357,114.822 663.366,114.847 663.375,114.873 663.384,114.898 663.393,114.924 663.403,114.949 663.412,114.975 663.421,115 663.43,115.026 663.439,115.052 663.449,115.077 663.458,115.103 663.467,115.128 663.476,115.154 663.485,115.18 663.495,115.205 663.504,115.231 663.513,115.256 663.522,115.282 663.531,115.308 663.541,115.333 663.55,115.359 663.559,115.385 663.568,115.411 663.577,115.436 663.586,115.462 663.596,115.488 663.605,115.513 663.614,115.539 663.623,115.565 663.632,115.591 663.642,115.617 663.651,115.642 663.66,115.668 663.669,115.694 663.678,115.72 663.688,115.746 663.697,115.772 663.706,115.797 663.715,115.823 663.724,115.849 663.733,115.875 663.743,115.901 663.752,115.927 663.761,115.953 663.77,115.979 663.779,116.005 663.789,116.031 663.798,116.057 663.807,116.083 663.816,116.109 663.825,116.135 663.835,116.161 663.844,116.187 663.853,116.213 663.862,116.239 663.871,116.265 663.881,116.291 663.89,116.317 663.899,116.343 663.908,116.369 663.917,116.395 663.926,116.422 663.936,116.448 663.945,116.474 663.954,116.5 663.963,116.526 663.972,116.552 663.982,116.579 663.991,116.605 664,116.631 664.009,116.657 664.018,116.683 664.028,116.71 664.037,116.736 664.046,116.762 664.055,116.788 664.064,116.815 664.073,116.841 664.083,116.867 664.092,116.894 664.101,116.92 664.11,116.946 664.119,116.973 664.129,116.999 664.138,117.026 664.147,117.052 664.156,117.078 664.165,117.105 664.175,117.131 664.184,117.158 664.193,117.184 664.202,117.21 664.211,117.237 664.221,117.263 664.23,117.29 664.239,117.316 664.248,117.343 664.257,117.369 664.266,117.396 664.276,117.423 664.285,117.449 664.294,117.476 664.303,117.502 664.312,117.529 664.322,117.555 664.331,117.582 664.34,117.609 664.349,117.635 664.358,117.662 664.368,117.689 664.377,117.715 664.386,117.742 664.395,117.769 664.404,117.795 664.414,117.822 664.423,117.849 664.432,117.875 664.441,117.902 664.45,117.929 664.459,117.956 664.469,117.982 664.478,118.009 664.487,118.036 664.496,118.063 664.505,118.09 664.515,118.116 664.524,118.143 664.533,118.17 664.542,118.197 664.551,118.224 664.561,118.251 664.57,118.278 664.579,118.305 664.588,118.331 664.597,118.358 664.606,118.385 664.616,118.412 664.625,118.439 664.634,118.466 664.643,118.493 664.652,118.52 664.662,118.547 664.671,118.574 664.68,118.601 664.689,118.628 664.698,118.655 664.708,118.682 664.717,118.709 664.726,118.737 664.735,118.764 664.744,118.791 664.754,118.818 664.763,118.845 664.772,118.872 664.781,118.899 664.79,118.926 664.799,118.954 664.809,118.981 664.818,119.008 664.827,119.035 664.836,119.062 664.845,119.09 664.855,119.117 664.864,119.144 664.873,119.171 664.882,119.199 664.891,119.226 664.901,119.253 664.91,119.28 664.919,119.308 664.928,119.335 664.937,119.362 664.946,119.39 664.956,119.417 664.965,119.444 664.974,119.472 664.983,119.499 664.992,119.527 665.002,119.554 665.011,119.581 665.02,119.609 665.029,119.636 665.038,119.664 665.048,119.691 665.057,119.719 665.066,119.746 665.075,119.774 665.084,119.801 665.094,119.829 665.103,119.856 665.112,119.884 665.121,119.911 665.13,119.939 665.139,119.967 665.149,119.994 665.158,120.022 665.167,120.049 665.176,120.077 665.185,120.105 665.195,120.132 665.204,120.16 665.213,120.188 665.222,120.215 665.231,120.243 665.241,120.271 665.25,120.298 665.259,120.326 665.268,120.354 665.277,120.382 665.286,120.409 665.296,120.437 665.305,120.465 665.314,120.493 665.323,120.52 665.332,120.548 665.342,120.576 665.351,120.604 665.36,120.632 665.369,120.66 665.378,120.687 665.388,120.715 665.397,120.743 665.406,120.771 665.415,120.799 665.424,120.827 665.434,120.855 665.443,120.883 665.452,120.911 665.461,120.939 665.47,120.967 665.479,120.995 665.489,121.023 665.498,121.051 665.507,121.079 665.516,121.107 665.525,121.135 665.535,121.163 665.544,121.191 665.553,121.219 665.562,121.247 665.571,121.275 665.581,121.303 665.59,121.331 665.599,121.36 665.608,121.388 665.617,121.416 665.626,121.444 665.636,121.472 665.645,121.5 665.654,121.529 665.663,121.557 665.672,121.585 665.682,121.613 665.691,121.641 665.7,121.67 665.709,121.698 665.718,121.726 665.728,121.755 665.737,121.783 665.746,121.811 665.755,121.839 665.764,121.868 665.774,121.896 665.783,121.924 665.792,121.953 665.801,121.981 665.81,122.01 665.819,122.038 665.829,122.066 665.838,122.095 665.847,122.123 665.856,122.152 665.865,122.18 665.875,122.209 665.884,122.237 665.893,122.266 665.902,122.294 665.911,122.323 665.921,122.351 665.93,122.38 665.939,122.408 665.948,122.437 665.957,122.465 665.966,122.494 665.976,122.523 665.985,122.551 665.994,122.58 666.003,122.608 666.012,122.637 666.022,122.666 666.031,122.694 666.04,122.723 666.049,122.752 666.058,122.78 666.068,122.809 666.077,122.838 666.086,122.866 666.095,122.895 666.104,122.924 666.114,122.953 666.123,122.981 666.132,123.01 666.141,123.039 666.15,123.068 666.159,123.097 666.169,123.126 666.178,123.154 666.187,123.183 666.196,123.212 666.205,123.241 666.215,123.27 666.224,123.299 666.233,123.328 666.242,123.357 666.251,123.385 666.261,123.414 666.27,123.443 666.279,123.472 666.288,123.501 666.297,123.53 666.306,123.559 666.316,123.588 666.325,123.617 666.334,123.646 666.343,123.675 666.352,123.704 666.362,123.733 666.371,123.763 666.38,123.792 666.389,123.821 666.398,123.85 666.408,123.879 666.417,123.908 666.426,123.937 666.435,123.966 666.444,123.996 666.454,124.025 666.463,124.054 666.472,124.083 666.481,124.112 666.49,124.141 666.499,124.171 666.509,124.2 666.518,124.229 666.527,124.258 666.536,124.288 666.545,124.317 666.555,124.346 666.564,124.376 666.573,124.405 666.582,124.434 666.591,124.464 666.601,124.493 666.61,124.522 666.619,124.552 666.628,124.581 666.637,124.611 666.646,124.64 666.656,124.669 666.665,124.699 666.674,124.728 666.683,124.758 666.692,124.787 666.702,124.817 666.711,124.846 666.72,124.876 666.729,124.905 666.738,124.935 666.748,124.964 666.757,124.994 666.766,125.023 666.775,125.053 666.784,125.082 666.794,125.112 666.803,125.142 666.812,125.171 666.821,125.201 666.83,125.231 666.839,125.26 666.849,125.29 666.858,125.32 666.867,125.349 666.876,125.379 666.885,125.409 666.895,125.438 666.904,125.468 666.913,125.498 666.922,125.528 666.931,125.557 666.941,125.587 666.95,125.617 666.959,125.647 666.968,125.676 666.977,125.706 666.987,125.736 666.996,125.766 667.005,125.796 667.014,125.826 667.023,125.856 667.032,125.885 667.042,125.915 667.051,125.945 667.06,125.975 667.069,126.005 667.078,126.035 667.088,126.065 667.097,126.095 667.106,126.125 667.115,126.155 667.124,126.185 667.134,126.215 667.143,126.245 667.152,126.275 667.161,126.305 667.17,126.335 667.179,126.365 667.189,126.395 667.198,126.425 667.207,126.455 667.216,126.486 667.225,126.516 667.235,126.546 667.244,126.576 667.253,126.606 667.262,126.636 667.271,126.667 667.281,126.697 667.29,126.727 667.299,126.757 667.308,126.787 667.317,126.818 667.327,126.848 667.336,126.878 667.345,126.908 667.354,126.939 667.363,126.969 667.372,126.999 667.382,127.03 667.391,127.06 667.4,127.09 667.409,127.121 667.418,127.151 667.428,127.181 667.437,127.212 667.446,127.242 667.455,127.273 667.464,127.303 667.474,127.333 667.483,127.364 667.492,127.394 667.501,127.425 667.51,127.455 667.519,127.486 667.529,127.516 667.538,127.547 667.547,127.577 667.556,127.608 667.565,127.638 667.575,127.669 667.584,127.7 667.593,127.73 667.602,127.761 667.611,127.791 667.621,127.822 667.63,127.853 667.639,127.883 667.648,127.914 667.657,127.945 667.667,127.975 667.676,128.006 667.685,128.037 667.694,128.067 667.703,128.098 667.712,128.129 667.722,128.16 667.731,128.19 667.74,128.221 667.749,128.252 667.758,128.283 667.768,128.313 667.777,128.344 667.786,128.375 667.795,128.406 667.804,128.437 667.814,128.468 667.823,128.498 667.832,128.529 667.841,128.56 667.85,128.591 667.859,128.622 667.869,128.653 667.878,128.684 667.887,128.715 667.896,128.746 667.905,128.777 667.915,128.808 667.924,128.839 667.933,128.87 667.942,128.901 667.951,128.932 667.961,128.963 667.97,128.994 667.979,129.025 667.988,129.056 667.997,129.087 668.007,129.118 668.016,129.149 668.025,129.18 668.034,129.212 668.043,129.243 668.052,129.274 668.062,129.305 668.071,129.336 668.08,129.367 668.089,129.399 668.098,129.43 668.108,129.461 668.117,129.492 668.126,129.524 668.135,129.555 668.144,129.586 668.154,129.617 668.163,129.649 668.172,129.68 668.181,129.711 668.19,129.743 668.199,129.774 668.209,129.805 668.218,129.837 668.227,129.868 668.236,129.899 668.245,129.931 668.255,129.962 668.264,129.994 668.273,130.025 668.282,130.057 668.291,130.088 668.301,130.119 668.31,130.151 668.319,130.182 668.328,130.214 668.337,130.245 668.347,130.277 668.356,130.309 668.365,130.34 668.374,130.372 668.383,130.403 668.392,130.435 668.402,130.466 668.411,130.498 668.42,130.53 668.429,130.561 668.438,130.593 668.448,130.625 668.457,130.656 668.466,130.688 668.475,130.72 668.484,130.751 668.494,130.783 668.503,130.815 668.512,130.846 668.521,130.878 668.53,130.91 668.539,130.942 668.549,130.973 668.558,131.005 668.567,131.037 668.576,131.069 668.585,131.101 668.595,131.133 668.604,131.164 668.613,131.196 668.622,131.228 668.631,131.26 668.641,131.292 668.65,131.324 668.659,131.356 668.668,131.388 668.677,131.42 668.687,131.451 668.696,131.483 668.705,131.515 668.714,131.547 668.723,131.579 668.732,131.611 668.742,131.643 668.751,131.675 668.76,131.708 668.769,131.74 668.778,131.772 668.788,131.804 668.797,131.836 668.806,131.868 668.815,131.9 668.824,131.932 668.834,131.964 668.843,131.996 668.852,132.029 668.861,132.061 668.87,132.093 668.879,132.125 668.889,132.157 668.898,132.19 668.907,132.222 668.916,132.254 668.925,132.286 668.935,132.319 668.944,132.351 668.953,132.383 668.962,132.415 668.971,132.448 668.981,132.48 668.99,132.512 668.999,132.545 669.008,132.577 669.017,132.609 669.027,132.642 669.036,132.674 669.045,132.707 669.054,132.739 669.063,132.771 669.072,132.804 669.082,132.836 669.091,132.869 669.1,132.901 669.109,132.934 669.118,132.966 669.128,132.999 669.137,133.031 669.146,133.064 669.155,133.096 669.164,133.129 669.174,133.162 669.183,133.194 669.192,133.227 669.201,133.259 669.21,133.292 669.22,133.325 669.229,133.357 669.238,133.39 669.247,133.422 669.256,133.455 669.265,133.488 669.275,133.521 669.284,133.553 669.293,133.586 669.302,133.619 669.311,133.651 669.321,133.684 669.33,133.717 669.339,133.75 669.348,133.782 669.357,133.815 669.367,133.848 669.376,133.881 669.385,133.914 669.394,133.947 669.403,133.979 669.412,134.012 669.422,134.045 669.431,134.078 669.44,134.111 669.449,134.144 669.458,134.177 669.468,134.21 669.477,134.243 669.486,134.276 669.495,134.309 669.504,134.342 669.514,134.375 669.523,134.408 669.532,134.441 669.541,134.474 669.55,134.507 669.56,134.54 669.569,134.573 669.578,134.606 669.587,134.639 669.596,134.672 669.605,134.705 669.615,134.738 669.624,134.771 669.633,134.805 669.642,134.838 669.651,134.871 669.661,134.904 669.67,134.937 669.679,134.971 669.688,135.004 669.697,135.037 669.707,135.07 669.716,135.103 669.725,135.137 669.734,135.17 669.743,135.203 669.752,135.237 669.762,135.27 669.771,135.303 669.78,135.337 669.789,135.37 669.798,135.403 669.808,135.437 669.817,135.47 669.826,135.503 669.835,135.537 669.844,135.57 669.854,135.604 669.863,135.637 669.872,135.671 669.881,135.704 669.89,135.738 669.9,135.771 669.909,135.804 669.918,135.838 669.927,135.872 669.936,135.905 669.945,135.939 669.955,135.972 669.964,136.006 669.973,136.039 669.982,136.073 669.991,136.107 670.001,136.14 670.01,136.174 670.019,136.207 670.028,136.241 670.037,136.275 670.047,136.308 670.056,136.342 670.065,136.376 670.074,136.409 670.083,136.443 670.092,136.477 670.102,136.511 670.111,136.544 670.12,136.578 670.129,136.612 670.138,136.646 670.148,136.68 670.157,136.713 670.166,136.747 670.175,136.781 670.184,136.815 670.194,136.849 670.203,136.883 670.212,136.916 670.221,136.95 670.23,136.984 670.24,137.018 670.249,137.052 670.258,137.086 670.267,137.12 670.276,137.154 670.285,137.188 670.295,137.222 670.304,137.256 670.313,137.29 670.322,137.324 670.331,137.358 670.341,137.392 670.35,137.426 670.359,137.46 670.368,137.494 670.377,137.528 670.387,137.562 670.396,137.597 670.405,137.631 670.414,137.665 670.423,137.699 670.432,137.733 670.442,137.767 670.451,137.802 670.46,137.836 670.469,137.87 670.478,137.904 670.488,137.938 670.497,137.973 670.506,138.007 670.515,138.041 670.524,138.075 670.534,138.11 670.543,138.144 670.552,138.178 670.561,138.213 670.57,138.247 670.58,138.281 670.589,138.316 670.598,138.35 670.607,138.385 670.616,138.419 670.625,138.453 670.635,138.488 670.644,138.522 670.653,138.557 670.662,138.591 670.671,138.626 670.681,138.66 670.69,138.695 670.699,138.729 670.708,138.764 670.717,138.798 670.727,138.833 670.736,138.867 670.745,138.902 670.754,138.936 670.763,138.971 670.772,139.006 670.782,139.04 670.791,139.075 670.8,139.109 670.809,139.144 670.818,139.179 670.828,139.213 670.837,139.248 670.846,139.283 670.855,139.317 670.864,139.352 670.874,139.387 670.883,139.422 670.892,139.456 670.901,139.491 670.91,139.526 670.92,139.561 670.929,139.596 670.938,139.63 670.947,139.665 670.956,139.7 670.965,139.735 670.975,139.77 670.984,139.805 670.993,139.839 671.002,139.874 671.011,139.909 671.021,139.944 671.03,139.979 671.039,140.014 671.048,140.049 671.057,140.084 671.067,140.119 671.076,140.154 671.085,140.189 671.094,140.224 671.103,140.259 671.112,140.294 671.122,140.329 671.131,140.364 671.14,140.399 671.149,140.434 671.158,140.469 671.168,140.504 671.177,140.54 671.186,140.575 671.195,140.61 671.204,140.645 671.214,140.68 671.223,140.715 671.232,140.75 671.241,140.786 671.25,140.821 671.26,140.856 671.269,140.891 671.278,140.927 671.287,140.962 671.296,140.997 671.305,141.032 671.315,141.068 671.324,141.103 671.333,141.138 671.342,141.174 671.351,141.209 671.361,141.244 671.37,141.28 671.379,141.315 671.388,141.35 671.397,141.386 671.407,141.421 671.416,141.457 671.425,141.492 671.434,141.528 671.443,141.563 671.452,141.598 671.462,141.634 671.471,141.669 671.48,141.705 671.489,141.74 671.498,141.776 671.508,141.812 671.517,141.847 671.526,141.883 671.535,141.918 671.544,141.954 671.554,141.989 671.563,142.025 671.572,142.061 671.581,142.096 671.59,142.132 671.6,142.168 671.609,142.203 671.618,142.239 671.627,142.275 671.636,142.31 671.645,142.346 671.655,142.382 671.664,142.417 671.673,142.453 671.682,142.489 671.691,142.525 671.701,142.561 671.71,142.596 671.719,142.632 671.728,142.668 671.737,142.704 671.747,142.74 671.756,142.776 671.765,142.811 671.774,142.847 671.783,142.883 671.793,142.919 671.802,142.955 671.811,142.991 671.82,143.027 671.829,143.063 671.838,143.099 671.848,143.135 671.857,143.171 671.866,143.207 671.875,143.243 671.884,143.279 671.894,143.315 671.903,143.351 671.912,143.387 671.921,143.423 671.93,143.459 671.94,143.495 671.949,143.531 671.958,143.567 671.967,143.604 671.976,143.64 671.985,143.676 671.995,143.712 672.004,143.748 672.013,143.784 672.022,143.821 672.031,143.857 672.041,143.893 672.05,143.929 672.059,143.965 672.068,144.002 672.077,144.038 672.087,144.074 672.096,144.111 672.105,144.147 672.114,144.183 672.123,144.22 672.133,144.256 672.142,144.292 672.151,144.329 672.16,144.365 672.169,144.401 672.178,144.438 672.188,144.474 672.197,144.511 672.206,144.547 672.215,144.583 672.224,144.62 672.234,144.656 672.243,144.693 672.252,144.729 672.261,144.766 672.27,144.802 672.28,144.839 672.289,144.875 672.298,144.912 672.307,144.949 672.316,144.985 672.325,145.022 672.335,145.058 672.344,145.095 672.353,145.132 672.362,145.168 672.371,145.205 672.381,145.242 672.39,145.278 672.399,145.315 672.408,145.352 672.417,145.388 672.427,145.425 672.436,145.462 672.445,145.499 672.454,145.535 672.463,145.572 672.473,145.609 672.482,145.646 672.491,145.682 672.5,145.719 672.509,145.756 672.518,145.793 672.528,145.83 672.537,145.867 672.546,145.903 672.555,145.94 672.564,145.977 672.574,146.014 672.583,146.051 672.592,146.088 672.601,146.125 672.61,146.162 672.62,146.199 672.629,146.236 672.638,146.273 672.647,146.31 672.656,146.347 672.665,146.384 672.675,146.421 672.684,146.458 672.693,146.495 672.702,146.532 672.711,146.569 672.721,146.606 672.73,146.643 672.739,146.681 672.748,146.718 672.757,146.755 672.767,146.792 672.776,146.829 672.785,146.866 672.794,146.903 672.803,146.941 672.813,146.978 672.822,147.015 672.831,147.052 672.84,147.09 672.849,147.127 672.858,147.164 672.868,147.201 672.877,147.239 672.886,147.276 672.895,147.313 672.904,147.351 672.914,147.388 672.923,147.425 672.932,147.463 672.941,147.5 672.95,147.538 672.96,147.575 672.969,147.612 672.978,147.65 672.987,147.687 672.996,147.725 673.005,147.762 673.015,147.8 673.024,147.837 673.033,147.875 673.042,147.912 673.051,147.95 673.061,147.987 673.07,148.025 673.079,148.062 673.088,148.1 673.097,148.137 673.107,148.175 673.116,148.213 673.125,148.25 673.134,148.288 673.143,148.326 673.153,148.363 673.162,148.401 673.171,148.439 673.18,148.476 673.189,148.514 673.198,148.552 673.208,148.589 673.217,148.627 673.226,148.665 673.235,148.703 673.244,148.74 673.254,148.778 673.263,148.816 673.272,148.854 673.281,148.892 673.29,148.929 673.3,148.967 673.309,149.005 673.318,149.043 673.327,149.081 673.336,149.119 673.345,149.157 673.355,149.195 673.364,149.232 673.373,149.27 673.382,149.308 673.391,149.346 673.401,149.384 673.41,149.422 673.419,149.46 673.428,149.498 673.437,149.536 673.447,149.574 673.456,149.612 673.465,149.65 673.474,149.688 673.483,149.727 673.493,149.765 673.502,149.803 673.511,149.841 673.52,149.879 673.529,149.917 673.538,149.955 673.548,149.993 673.557,150.032 673.566,150.07 673.575,150.108 673.584,150.146 673.594,150.184 673.603,150.223 673.612,150.261 673.621,150.299 673.63,150.337 673.64,150.376 673.649,150.414 673.658,150.452 673.667,150.491 673.676,150.529 673.685,150.567 673.695,150.606 673.704,150.644 673.713,150.682 673.722,150.721 673.731,150.759 673.741,150.798 673.75,150.836 673.759,150.874 673.768,150.913 673.777,150.951 673.787,150.99 673.796,151.028 673.805,151.067 673.814,151.105 673.823,151.144 673.833,151.182 673.842,151.221 673.851,151.259 673.86,151.298 673.869,151.336 673.878,151.375 673.888,151.414 673.897,151.452 673.906,151.491 673.915,151.53 673.924,151.568 673.934,151.607 673.943,151.646 673.952,151.684 673.961,151.723 673.97,151.762 673.98,151.8 673.989,151.839 673.998,151.878 674.007,151.917 674.016,151.955 674.025,151.994 674.035,152.033 674.044,152.072 674.053,152.11 674.062,152.149 674.071,152.188 674.081,152.227 674.09,152.266 674.099,152.305 674.108,152.344 674.117,152.382 674.127,152.421 674.136,152.46 674.145,152.499 674.154,152.538 674.163,152.577 674.173,152.616 674.182,152.655 674.191,152.694 674.2,152.733 674.209,152.772 674.218,152.811 674.228,152.85 674.237,152.889 674.246,152.928 674.255,152.967 674.264,153.006 674.274,153.045 674.283,153.085 674.292,153.124 674.301,153.163 674.31,153.202 674.32,153.241 674.329,153.28 674.338,153.319 674.347,153.359 674.356,153.398 674.366,153.437 674.375,153.476 674.384,153.516 674.393,153.555 674.402,153.594 674.411,153.633 674.421,153.673 674.43,153.712 674.439,153.751 674.448,153.79 674.457,153.83 674.467,153.869 674.476,153.909 674.485,153.948 674.494,153.987 674.503,154.027 674.513,154.066 674.522,154.105 674.531,154.145 674.54,154.184 674.549,154.224 674.558,154.263 674.568,154.303 674.577,154.342 674.586,154.382 674.595,154.421 674.604,154.461 674.614,154.5 674.623,154.54 674.632,154.579 674.641,154.619 674.65,154.658 674.66,154.698 674.669,154.738 674.678,154.777 674.687,154.817 674.696,154.857 674.706,154.896 674.715,154.936 674.724,154.976 674.733,155.015 674.742,155.055 674.751,155.095 674.761,155.134 674.77,155.174 674.779,155.214 674.788,155.254 674.797,155.293 674.807,155.333 674.816,155.373 674.825,155.413 674.834,155.452 674.843,155.492 674.853,155.532 674.862,155.572 674.871,155.612 674.88,155.652 674.889,155.692 674.898,155.732 674.908,155.771 674.917,155.811 674.926,155.851 674.935,155.891 674.944,155.931 674.954,155.971 674.963,156.011 674.972,156.051 674.981,156.091 674.99,156.131 675,156.171 675.009,156.211 675.018,156.251 675.027,156.291 675.036,156.331 675.046,156.371 675.055,156.412 675.064,156.452 675.073,156.492 675.082,156.532 675.091,156.572 675.101,156.612 675.11,156.652 675.119,156.693 675.128,156.733 675.137,156.773 675.147,156.813 675.156,156.853 675.165,156.894 675.174,156.934 675.183,156.974 675.193,157.014 675.202,157.055 675.211,157.095 675.22,157.135 675.229,157.176 675.238,157.216 675.248,157.256 675.257,157.297 675.266,157.337 675.275,157.377 675.284,157.418 675.294,157.458 675.303,157.499 675.312,157.539 675.321,157.579 675.33,157.62 675.34,157.66 675.349,157.701 675.358,157.741 675.367,157.782 675.376,157.822 675.386,157.863 675.395,157.903 675.404,157.944 675.413,157.984 675.422,158.025 675.431,158.066 675.441,158.106 675.45,158.147 675.459,158.187 675.468,158.228 675.477,158.269 675.487,158.309 675.496,158.35 675.505,158.391 675.514,158.431 675.523,158.472 675.533,158.513 675.542,158.553 675.551,158.594 675.56,158.635 675.569,158.676 675.578,158.716 675.588,158.757 675.597,158.798 675.606,158.839 675.615,158.88 675.624,158.92 675.634,158.961 675.643,159.002 675.652,159.043 675.661,159.084 675.67,159.125 675.68,159.166 675.689,159.207 675.698,159.247 675.707,159.288 675.716,159.329 675.726,159.37 675.735,159.411 675.744,159.452 675.753,159.493 675.762,159.534 675.771,159.575 675.781,159.616 675.79,159.657 675.799,159.698 675.808,159.739 675.817,159.78 675.827,159.822 675.836,159.863 675.845,159.904 675.854,159.945 675.863,159.986 675.873,160.027 675.882,160.068 675.891,160.109 675.9,160.151 675.909,160.192 675.918,160.233 675.928,160.274 675.937,160.315 675.946,160.357 675.955,160.398 675.964,160.439 675.974,160.48 675.983,160.522 675.992,160.563 676.001,160.604 676.01,160.646 676.02,160.687 676.029,160.728 676.038,160.77 676.047,160.811 676.056,160.852 676.066,160.894 676.075,160.935 676.084,160.977 676.093,161.018 676.102,161.059 676.111,161.101 676.121,161.142 676.13,161.184 676.139,161.225 676.148,161.267 676.157,161.308 676.167,161.35 676.176,161.391 676.185,161.433 676.194,161.474 676.203,161.516 676.213,161.558 676.222,161.599 676.231,161.641 676.24,161.682 676.249,161.724 676.258,161.766 676.268,161.807 676.277,161.849 676.286,161.891 676.295,161.932 676.304,161.974 676.314,162.016 676.323,162.057 676.332,162.099 676.341,162.141 676.35,162.183 676.36,162.224 676.369,162.266 676.378,162.308 676.387,162.35 676.396,162.392 676.406,162.433 676.415,162.475 676.424,162.517 676.433,162.559 676.442,162.601 676.451,162.643 676.461,162.685 676.47,162.726 676.479,162.768 676.488,162.81 676.497,162.852 676.507,162.894 676.516,162.936 676.525,162.978 676.534,163.02 676.543,163.062 676.553,163.104 676.562,163.146 676.571,163.188 676.58,163.23 676.589,163.272 676.599,163.314 676.608,163.356 676.617,163.398 676.626,163.441 676.635,163.483 676.644,163.525 676.654,163.567 676.663,163.609 676.672,163.651 676.681,163.693 676.69,163.736 676.7,163.778 676.709,163.82 676.718,163.862 676.727,163.904 676.736,163.947 676.746,163.989 676.755,164.031 676.764,164.073 676.773,164.116 676.782,164.158 676.791,164.2 676.801,164.243 676.81,164.285 676.819,164.327 676.828,164.37 676.837,164.412 676.847,164.454 676.856,164.497 676.865,164.539 676.874,164.582 676.883,164.624 676.893,164.666 676.902,164.709 676.911,164.751 676.92,164.794 676.929,164.836 676.939,164.879 676.948,164.921 676.957,164.964 676.966,165.006 676.975,165.049 676.984,165.091 676.994,165.134 677.003,165.177 677.012,165.219 677.021,165.262 677.03,165.304 677.04,165.347 677.049,165.39 677.058,165.432 677.067,165.475 677.076,165.518 677.086,165.56 677.095,165.603 677.104,165.646 677.113,165.688 677.122,165.731 677.131,165.774 677.141,165.817 677.15,165.859 677.159,165.902 677.168,165.945 677.177,165.988 677.187,166.031 677.196,166.073 677.205,166.116 677.214,166.159 677.223,166.202 677.233,166.245 677.242,166.288 677.251,166.331 677.26,166.373 677.269,166.416 677.279,166.459 677.288,166.502 677.297,166.545 677.306,166.588 677.315,166.631 677.324,166.674 677.334,166.717 677.343,166.76 677.352,166.803 677.361,166.846 677.37,166.889 677.38,166.932 677.389,166.975 677.398,167.018 677.407,167.061 677.416,167.105 677.426,167.148 677.435,167.191 677.444,167.234 677.453,167.277 677.462,167.32 677.471,167.363 677.481,167.407 677.49,167.45 677.499,167.493 677.508,167.536 677.517,167.579 677.527,167.623 677.536,167.666 677.545,167.709 677.554,167.752 677.563,167.796 677.573,167.839 677.582,167.882 677.591,167.926 677.6,167.969 677.609,168.012 677.619,168.056 677.628,168.099 677.637,168.142 677.646,168.186 677.655,168.229 677.664,168.273 677.674,168.316 677.683,168.359 677.692,168.403 677.701,168.446 677.71,168.49 677.72,168.533 677.729,168.577 677.738,168.62 677.747,168.664 677.756,168.707 677.766,168.751 677.775,168.794 677.784,168.838 677.793,168.882 677.802,168.925 677.811,168.969 677.821,169.012 677.83,169.056 677.839,169.1 677.848,169.143 677.857,169.187 677.867,169.231 677.876,169.274 677.885,169.318 677.894,169.362 677.903,169.405 677.913,169.449 677.922,169.493 677.931,169.536 677.94,169.58 677.949,169.624 677.959,169.668 677.968,169.712 677.977,169.755 677.986,169.799 677.995,169.843 678.004,169.887 678.014,169.931 678.023,169.975 678.032,170.018 678.041,170.062 678.05,170.106 678.06,170.15 678.069,170.194 678.078,170.238 678.087,170.282 678.096,170.326 678.106,170.37 678.115,170.414 678.124,170.458 678.133,170.502 678.142,170.546 678.151,170.59 678.161,170.634 678.17,170.678 678.179,170.722 678.188,170.766 678.197,170.81 678.207,170.854 678.216,170.898 678.225,170.942 678.234,170.986 678.243,171.031 678.253,171.075 678.262,171.119 678.271,171.163 678.28,171.207 678.289,171.251 678.299,171.296 678.308,171.34 678.317,171.384 678.326,171.428 678.335,171.473 678.344,171.517 678.354,171.561 678.363,171.605 678.372,171.65 678.381,171.694 678.39,171.738 678.4,171.783 678.409,171.827 678.418,171.871 678.427,171.916 678.436,171.96 678.446,172.004 678.455,172.049 678.464,172.093 678.473,172.138 678.482,172.182 678.491,172.227 678.501,172.271 678.51,172.315 678.519,172.36 678.528,172.404 678.537,172.449 678.547,172.493 678.556,172.538 678.565,172.582 678.574,172.627 678.583,172.672 678.593,172.716 678.602,172.761 678.611,172.805 678.62,172.85 678.629,172.895 678.639,172.939 678.648,172.984 678.657,173.028 678.666,173.073 678.675,173.118 678.684,173.162 678.694,173.207 678.703,173.252 678.712,173.297 678.721,173.341 678.73,173.386 678.74,173.431 678.749,173.476 678.758,173.52 678.767,173.565 678.776,173.61 678.786,173.655 678.795,173.7 678.804,173.744 678.813,173.789 678.822,173.834 678.831,173.879 678.841,173.924 678.85,173.969 678.859,174.014 678.868,174.058 678.877,174.103 678.887,174.148 678.896,174.193 678.905,174.238 678.914,174.283 678.923,174.328 678.933,174.373 678.942,174.418 678.951,174.463 678.96,174.508 678.969,174.553 678.979,174.598 678.988,174.643 678.997,174.688 679.006,174.733 679.015,174.779 679.024,174.824 679.034,174.869 679.043,174.914 679.052,174.959 679.061,175.004 679.07,175.049 679.08,175.095 679.089,175.14 679.098,175.185 679.107,175.23 679.116,175.275 679.126,175.321 679.135,175.366 679.144,175.411 679.153,175.456 679.162,175.502 679.172,175.547 679.181,175.592 679.19,175.637 679.199,175.683 679.208,175.728 679.217,175.773 679.227,175.819 679.236,175.864 679.245,175.91 679.254,175.955 679.263,176 679.273,176.046 679.282,176.091 679.291,176.137 679.3,176.182 679.309,176.227 679.319,176.273 679.328,176.318 679.337,176.364 679.346,176.409 679.355,176.455 679.364,176.5 679.374,176.546 679.383,176.591 679.392,176.637 679.401,176.683 679.41,176.728 679.42,176.774 679.429,176.819 679.438,176.865 679.447,176.911 679.456,176.956 679.466,177.002 679.475,177.048 679.484,177.093 679.493,177.139 679.502,177.185 679.512,177.23 679.521,177.276 679.53,177.322 679.539,177.367 679.548,177.413 679.557,177.459 679.567,177.505 679.576,177.55 679.585,177.596 679.594,177.642 679.603,177.688 679.613,177.734 679.622,177.78 679.631,177.825 679.64,177.871 679.649,177.917 679.659,177.963 679.668,178.009 679.677,178.055 679.686,178.101 679.695,178.147 679.704,178.193 679.714,178.238 679.723,178.284 679.732,178.33 679.741,178.376 679.75,178.422 679.76,178.468 679.769,178.514 679.778,178.56 679.787,178.606 679.796,178.653 679.806,178.699 679.815,178.745 679.824,178.791 679.833,178.837 679.842,178.883 679.852,178.929 679.861,178.975 679.87,179.021 679.879,179.067 679.888,179.114 679.897,179.16 679.907,179.206 679.916,179.252 679.925,179.298 679.934,179.345 679.943,179.391 679.953,179.437 679.962,179.483 679.971,179.53 679.98,179.576 679.989,179.622 679.999,179.668 680.008,179.715 680.017,179.761 680.026,179.807 680.035,179.854 680.044,179.9 680.054,179.946 680.063,179.993 680.072,180.039 680.081,180.086 680.09,180.132 680.1,180.178 680.109,180.225 680.118,180.271 680.127,180.318 680.136,180.364 680.146,180.411 680.155,180.457 680.164,180.504 680.173,180.55 680.182,180.597 680.192,180.643 680.201,180.69 680.21,180.736 680.219,180.783 680.228,180.829 680.237,180.876 680.247,180.922 680.256,180.969 680.265,181.016 680.274,181.062 680.283,181.109 680.293,181.156 680.302,181.202 680.311,181.249 680.32,181.296 680.329,181.342 680.339,181.389 680.348,181.436 680.357,181.482 680.366,181.529 680.375,181.576 680.384,181.623 680.394,181.669 680.403,181.716 680.412,181.763 680.421,181.81 680.43,181.857 680.44,181.903 680.449,181.95 680.458,181.997 680.467,182.044 680.476,182.091 680.486,182.138 680.495,182.185 680.504,182.232 680.513,182.278 680.522,182.325 680.532,182.372 680.541,182.419 680.55,182.466 680.559,182.513 680.568,182.56 680.577,182.607 680.587,182.654 680.596,182.701 680.605,182.748 680.614,182.795 680.623,182.842 680.633,182.889 680.642,182.936 680.651,182.984 680.66,183.031 680.669,183.078 680.679,183.125 680.688,183.172 680.697,183.219 680.706,183.266 680.715,183.313 680.724,183.361 680.734,183.408 680.743,183.455 680.752,183.502 680.761,183.549 680.77,183.597 680.78,183.644 680.789,183.691 680.798,183.738 680.807,183.786 680.816,183.833 680.826,183.88 680.835,183.927 680.844,183.975 680.853,184.022 680.862,184.069 680.872,184.117 680.881,184.164 680.89,184.211 680.899,184.259 680.908,184.306 680.917,184.354 680.927,184.401 680.936,184.448 680.945,184.496 680.954,184.543 680.963,184.591 680.973,184.638 680.982,184.686 680.991,184.733 681,184.781 681.009,184.828 681.019,184.876 681.028,184.923 681.037,184.971 681.046,185.018 681.055,185.066 681.064,185.113 681.074,185.161 681.083,185.209 681.092,185.256 681.101,185.304 681.11,185.351 681.12,185.399 681.129,185.447 681.138,185.494 681.147,185.542 681.156,185.59 681.166,185.637 681.175,185.685 681.184,185.733 681.193,185.781 681.202,185.828 681.212,185.876 681.221,185.924 681.23,185.972 681.239,186.019 681.248,186.067 681.257,186.115 681.267,186.163 681.276,186.211 681.285,186.258 681.294,186.306 681.303,186.354 681.313,186.402 681.322,186.45 681.331,186.498 681.34,186.546 681.349,186.593 681.359,186.641 681.368,186.689 681.377,186.737 681.386,186.785 681.395,186.833 681.404,186.881 681.414,186.929 681.423,186.977 681.432,187.025 681.441,187.073 681.45,187.121 681.46,187.169 681.469,187.217 681.478,187.265 681.487,187.313 681.496,187.361 681.506,187.41 681.515,187.458 681.524,187.506 681.533,187.554 681.542,187.602 681.552,187.65 681.561,187.698 681.57,187.747 681.579,187.795 681.588,187.843 681.597,187.891 681.607,187.939 681.616,187.988 681.625,188.036 681.634,188.084 681.643,188.132 681.653,188.181 681.662,188.229 681.671,188.277 681.68,188.325 681.689,188.374 681.699,188.422 681.708,188.47 681.717,188.519 681.726,188.567 681.735,188.615 681.745,188.664 681.754,188.712 681.763,188.761 681.772,188.809 681.781,188.857 681.79,188.906 681.8,188.954 681.809,189.003 681.818,189.051 681.827,189.1 681.836,189.148 681.846,189.197 681.855,189.245 681.864,189.294 681.873,189.342 681.882,189.391 681.892,189.439 681.901,189.488 681.91,189.536 681.919,189.585 681.928,189.633 681.937,189.682 681.947,189.731 681.956,189.779 681.965,189.828 681.974,189.877 681.983,189.925 681.993,189.974 682.002,190.022 682.011,190.071 682.02,190.12 682.029,190.169 682.039,190.217 682.048,190.266 682.057,190.315 682.066,190.363 682.075,190.412 682.085,190.461 682.094,190.51 682.103,190.559 682.112,190.607 682.121,190.656 682.13,190.705 682.14,190.754 682.149,190.803 682.158,190.852 682.167,190.9 682.176,190.949 682.186,190.998 682.195,191.047 682.204,191.096 682.213,191.145 682.222,191.194 682.232,191.243 682.241,191.292 682.25,191.341 682.259,191.39 682.268,191.439 682.277,191.488 682.287,191.537 682.296,191.586 682.305,191.635 682.314,191.684 682.323,191.733 682.333,191.782 682.342,191.831 682.351,191.88 682.36,191.929 682.369,191.978 682.379,192.027 682.388,192.076 682.397,192.125 682.406,192.175 682.415,192.224 682.425,192.273 682.434,192.322 682.443,192.371 682.452,192.42 682.461,192.47 682.47,192.519 682.48,192.568 682.489,192.617 682.498,192.666 682.507,192.716 682.516,192.765 682.526,192.814 682.535,192.864 682.544,192.913 682.553,192.962 682.562,193.011 682.572,193.061 682.581,193.11 682.59,193.159 682.599,193.209 682.608,193.258 682.617,193.308 682.627,193.357 682.636,193.406 682.645,193.456 682.654,193.505 682.663,193.555 682.673,193.604 682.682,193.654 682.691,193.703 682.7,193.752 682.709,193.802 682.719,193.851 682.728,193.901 682.737,193.95 682.746,194 682.755,194.05 682.765,194.099 682.774,194.149 682.783,194.198 682.792,194.248 682.801,194.297 682.81,194.347 682.82,194.397 682.829,194.446 682.838,194.496 682.847,194.545 682.856,194.595 682.866,194.645 682.875,194.694 682.884,194.744 682.893,194.794 682.902,194.844 682.912,194.893 682.921,194.943 682.93,194.993 682.939,195.042 682.948,195.092 682.957,195.142 682.967,195.192 682.976,195.242 682.985,195.291 682.994,195.341 683.003,195.391 683.013,195.441 683.022,195.491 683.031,195.54 683.04,195.59 683.049,195.64 683.059,195.69 683.068,195.74 683.077,195.79 683.086,195.84 683.095,195.89 683.105,195.94 683.114,195.99 683.123,196.039 683.132,196.089 683.141,196.139 683.15,196.189 683.16,196.239 683.169,196.289 683.178,196.339 683.187,196.389 683.196,196.439 683.206,196.49 683.215,196.54 683.224,196.59 683.233,196.64 683.242,196.69 683.252,196.74 683.261,196.79 683.27,196.84 683.279,196.89 683.288,196.94 683.297,196.991 683.307,197.041 683.316,197.091 683.325,197.141 683.334,197.191 683.343,197.241 683.353,197.292 683.362,197.342 683.371,197.392 683.38,197.442 683.389,197.493 683.399,197.543 683.408,197.593 683.417,197.643 683.426,197.694 683.435,197.744 683.445,197.794 683.454,197.845 683.463,197.895 683.472,197.945 683.481,197.996 683.49,198.046 683.5,198.096 683.509,198.147 683.518,198.197 683.527,198.248 683.536,198.298 683.546,198.348 683.555,198.399 683.564,198.449 683.573,198.5 683.582,198.55 683.592,198.601 683.601,198.651 683.61,198.702 683.619,198.752 683.628,198.803 683.637,198.853 683.647,198.904 683.656,198.954 683.665,199.005 683.674,199.055 683.683,199.106 683.693,199.157 683.702,199.207 683.711,199.258 683.72,199.308 683.729,199.359 683.739,199.41 683.748,199.46 683.757,199.511 683.766,199.562 683.775,199.612 683.785,199.663 683.794,199.714 683.803,199.764 683.812,199.815 683.821,199.866 683.83,199.917 683.84,199.967 683.849,200.018 683.858,200.069 683.867,200.12 683.876,200.17 683.886,200.221 683.895,200.272 683.904,200.323 683.913,200.374 683.922,200.424 683.932,200.475 683.941,200.526 683.95,200.577 683.959,200.628 683.968,200.679 683.978,200.73 683.987,200.781 683.996,200.832 684.005,200.882 684.014,200.933 684.023,200.984 684.033,201.035 684.042,201.086 684.051,201.137 684.06,201.188 684.069,201.239 684.079,201.29 684.088,201.341 684.097,201.392 684.106,201.443 684.115,201.494 684.125,201.545 684.134,201.597 684.143,201.648 684.152,201.699 684.161,201.75 684.17,201.801 684.18,201.852 684.189,201.903 684.198,201.954 684.207,202.005 684.216,202.057 684.226,202.108 684.235,202.159 684.244,202.21 684.253,202.261 684.262,202.313 684.272,202.364 684.281,202.415 684.29,202.466 684.299,202.517 684.308,202.569 684.318,202.62 684.327,202.671 684.336,202.723 684.345,202.774 684.354,202.825 684.363,202.876 684.373,202.928 684.382,202.979 684.391,203.03 684.4,203.082 684.409,203.133 684.419,203.185 684.428,203.236 684.437,203.287 684.446,203.339 684.455,203.39 684.465,203.442 684.474,203.493 684.483,203.545 684.492,203.596 684.501,203.647 684.51,203.699 684.52,203.75 684.529,203.802 684.538,203.853 684.547,203.905 684.556,203.956 684.566,204.008 684.575,204.06 684.584,204.111 684.593,204.163 684.602,204.214 684.612,204.266 684.621,204.317 684.63,204.369 684.639,204.421 684.648,204.472 684.658,204.524 684.667,204.576 684.676,204.627 684.685,204.679 684.694,204.731 684.703,204.782 684.713,204.834 684.722,204.886 684.731,204.937 684.74,204.989 684.749,205.041 684.759,205.093 684.768,205.144 684.777,205.196 684.786,205.248 684.795,205.3 684.805,205.351 684.814,205.403 684.823,205.455 684.832,205.507 684.841,205.559 684.85,205.61 684.86,205.662 684.869,205.714 684.878,205.766 684.887,205.818 684.896,205.87 684.906,205.922 684.915,205.974 684.924,206.026 684.933,206.077 684.942,206.129 684.952,206.181 684.961,206.233 684.97,206.285 684.979,206.337 684.988,206.389 684.998,206.441 685.007,206.493 685.016,206.545 685.025,206.597 685.034,206.649 685.043,206.701 685.053,206.753 685.062,206.805 685.071,206.858 685.08,206.91 685.089,206.962 685.099,207.014 685.108,207.066 685.117,207.118 685.126,207.17 685.135,207.222 685.145,207.274 685.154,207.327 685.163,207.379 685.172,207.431 685.181,207.483 685.19,207.535 685.2,207.588 685.209,207.64 685.218,207.692 685.227,207.744 685.236,207.796 685.246,207.849 685.255,207.901 685.264,207.953 685.273,208.006 685.282,208.058 685.292,208.11 685.301,208.162 685.31,208.215 685.319,208.267 685.328,208.319 685.338,208.372 685.347,208.424 685.356,208.477 685.365,208.529 685.374,208.581 685.383,208.634 685.393,208.686 685.402,208.739 685.411,208.791 685.42,208.843 685.429,208.896 685.439,208.948 685.448,209.001 685.457,209.053 685.466,209.106 685.475,209.158 685.485,209.211 685.494,209.263 685.503,209.316 685.512,209.368 685.521,209.421 685.53,209.473 685.54,209.526 685.549,209.578 685.558,209.631 685.567,209.684 685.576,209.736 685.586,209.789 685.595,209.841 685.604,209.894 685.613,209.947 685.622,209.999 685.632,210.052 685.641,210.105 685.65,210.157 685.659,210.21 685.668,210.263 685.678,210.315 685.687,210.368 685.696,210.421 685.705,210.474 685.714,210.526 685.723,210.579 685.733,210.632 685.742,210.685 685.751,210.737 685.76,210.79 685.769,210.843 685.779,210.896 685.788,210.949 685.797,211.001 685.806,211.054 685.815,211.107 685.825,211.16 685.834,211.213 685.843,211.266 685.852,211.319 685.861,211.371 685.87,211.424 685.88,211.477 685.889,211.53 685.898,211.583 685.907,211.636 685.916,211.689 685.926,211.742 685.935,211.795 685.944,211.848 685.953,211.901 685.962,211.954 685.972,212.007 685.981,212.06 685.99,212.113 685.999,212.166 686.008,212.219 686.018,212.272 686.027,212.325 686.036,212.378 686.045,212.431 686.054,212.484 686.063,212.537 686.073,212.59 686.082,212.644 686.091,212.697 686.1,212.75 686.109,212.803 686.119,212.856 686.128,212.909 686.137,212.962 686.146,213.016 686.155,213.069 686.165,213.122 686.174,213.175 686.183,213.228 686.192,213.282 686.201,213.335 686.21,213.388 686.22,213.441 686.229,213.495 686.238,213.548 686.247,213.601 686.256,213.655 686.266,213.708 686.275,213.761 686.284,213.814 686.293,213.868 686.302,213.921 686.312,213.974 686.321,214.028 686.33,214.081 686.339,214.135 686.348,214.188 686.358,214.241 686.367,214.295 686.376,214.348 686.385,214.402 686.394,214.455 686.403,214.508 686.413,214.562 686.422,214.615 686.431,214.669 686.44,214.722 686.449,214.776 686.459,214.829 686.468,214.883 686.477,214.936 686.486,214.99 686.495,215.043 686.505,215.097 686.514,215.15 686.523,215.204 686.532,215.257 686.541,215.311 686.551,215.365 686.56,215.418 686.569,215.472 686.578,215.525 686.587,215.579 686.596,215.633 686.606,215.686 686.615,215.74 686.624,215.794 686.633,215.847 686.642,215.901 686.652,215.955 686.661,216.008 686.67,216.062 686.679,216.116 686.688,216.169 686.698,216.223 686.707,216.277 686.716,216.331 686.725,216.384 686.734,216.438 686.743,216.492 686.753,216.546 686.762,216.599 686.771,216.653 686.78,216.707 686.789,216.761 686.799,216.815 686.808,216.868 686.817,216.922 686.826,216.976 686.835,217.03 686.845,217.084 686.854,217.138 686.863,217.192 686.872,217.246 686.881,217.299 686.891,217.353 686.9,217.407 686.909,217.461 686.918,217.515 686.927,217.569 686.936,217.623 686.946,217.677 686.955,217.731 686.964,217.785 686.973,217.839 686.982,217.893 686.992,217.947 687.001,218.001 687.01,218.055 687.019,218.109 687.028,218.163 687.038,218.217 687.047,218.271 687.056,218.325 687.065,218.379 687.074,218.434 687.083,218.488 687.093,218.542 687.102,218.596 687.111,218.65 687.12,218.704 687.129,218.758 687.139,218.812 687.148,218.867 687.157,218.921 687.166,218.975 687.175,219.029 687.185,219.083 687.194,219.137 687.203,219.192 687.212,219.246 687.221,219.3 687.231,219.354 687.24,219.409 687.249,219.463 687.258,219.517 687.267,219.571 687.276,219.626 687.286,219.68 687.295,219.734 687.304,219.789 687.313,219.843 687.322,219.897 687.332,219.952 687.341,220.006 687.35,220.06 687.359,220.115 687.368,220.169 687.378,220.223 687.387,220.278 687.396,220.332 687.405,220.387 687.414,220.441 687.423,220.495 687.433,220.55 687.442,220.604 687.451,220.659 687.46,220.713 687.469,220.768 687.479,220.822 687.488,220.877 687.497,220.931 687.506,220.986 687.515,221.04 687.525,221.095 687.534,221.149 687.543,221.204 687.552,221.258 687.561,221.313 687.571,221.367 687.58,221.422 687.589,221.477 687.598,221.531 687.607,221.586 687.616,221.64 687.626,221.695 687.635,221.75 687.644,221.804 687.653,221.859 687.662,221.914 687.672,221.968 687.681,222.023 687.69,222.078 687.699,222.132 687.708,222.187 687.718,222.242 687.727,222.296 687.736,222.351 687.745,222.406 687.754,222.46 687.763,222.515 687.773,222.57 687.782,222.625 687.791,222.68 687.8,222.734 687.809,222.789 687.819,222.844 687.828,222.899 687.837,222.953 687.846,223.008 687.855,223.063 687.865,223.118 687.874,223.173 687.883,223.228 687.892,223.283 687.901,223.337 687.911,223.392 687.92,223.447 687.929,223.502 687.938,223.557 687.947,223.612 687.956,223.667 687.966,223.722 687.975,223.777 687.984,223.832 687.993,223.887 688.002,223.942 688.012,223.997 688.021,224.051 688.03,224.106 688.039,224.161 688.048,224.216 688.058,224.271 688.067,224.327 688.076,224.382 688.085,224.437 688.094,224.492 688.103,224.547 688.113,224.602 688.122,224.657 688.131,224.712 688.14,224.767 688.149,224.822 688.159,224.877 688.168,224.932 688.177,224.987 688.186,225.043 688.195,225.098 688.205,225.153 688.214,225.208 688.223,225.263 688.232,225.318 688.241,225.374 688.251,225.429 688.26,225.484 688.269,225.539 688.278,225.594 688.287,225.65 688.296,225.705 688.306,225.76 688.315,225.815 688.324,225.871 688.333,225.926 688.342,225.981 688.352,226.036 688.361,226.092 688.37,226.147 688.379,226.202 688.388,226.258 688.398,226.313 688.407,226.368 688.416,226.424 688.425,226.479 688.434,226.534 688.443,226.59 688.453,226.645 688.462,226.7 688.471,226.756 688.48,226.811 688.489,226.867 688.499,226.922 688.508,226.977 688.517,227.033 688.526,227.088 688.535,227.144 688.545,227.199 688.554,227.255 688.563,227.31 688.572,227.366 688.581,227.421 688.591,227.476 688.6,227.532 688.609,227.588 688.618,227.643 688.627,227.699 688.636,227.754 688.646,227.81 688.655,227.865 688.664,227.921 688.673,227.976 688.682,228.032 688.692,228.087 688.701,228.143 688.71,228.199 688.719,228.254 688.728,228.31 688.738,228.365 688.747,228.421 688.756,228.477 688.765,228.532 688.774,228.588 688.783,228.644 688.793,228.699 688.802,228.755 688.811,228.811 688.82,228.866 688.829,228.922 688.839,228.978 688.848,229.034 688.857,229.089 688.866,229.145 688.875,229.201 688.885,229.257 688.894,229.312 688.903,229.368 688.912,229.424 688.921,229.48 688.931,229.535 688.94,229.591 688.949,229.647 688.958,229.703 688.967,229.759 688.976,229.815 688.986,229.87 688.995,229.926 689.004,229.982 689.013,230.038 689.022,230.094 689.032,230.15 689.041,230.206 689.05,230.261 689.059,230.317 689.068,230.373 689.078,230.429 689.087,230.485 689.096,230.541 689.105,230.597 689.114,230.653 689.124,230.709 689.133,230.765 689.142,230.821 689.151,230.877 689.16,230.933 689.169,230.989 689.179,231.045 689.188,231.101 689.197,231.157 689.206,231.213 689.215,231.269 689.225,231.325 689.234,231.381 689.243,231.437 689.252,231.493 689.261,231.549 689.271,231.605 689.28,231.661 689.289,231.717 689.298,231.774 689.307,231.83 689.316,231.886 689.326,231.942 689.335,231.998 689.344,232.054 689.353,232.11 689.362,232.167 689.372,232.223 689.381,232.279 689.39,232.335 689.399,232.391 689.408,232.447 689.418,232.504 689.427,232.56 689.436,232.616 689.445,232.672 689.454,232.729 689.464,232.785 689.473,232.841 689.482,232.897 689.491,232.954 689.5,233.01 689.509,233.066 689.519,233.122 689.528,233.179 689.537,233.235 689.546,233.291 689.555,233.348 689.565,233.404 689.574,233.46 689.583,233.517 689.592,233.573 689.601,233.629 689.611,233.686 689.62,233.742 689.629,233.799 689.638,233.855 689.647,233.911 689.656,233.968 689.666,234.024 689.675,234.081 689.684,234.137 689.693,234.193 689.702,234.25 689.712,234.306 689.721,234.363 689.73,234.419 689.739,234.476 689.748,234.532 689.758,234.589 689.767,234.645 689.776,234.702 689.785,234.758 689.794,234.815 689.804,234.871 689.813,234.928 689.822,234.984 689.831,235.041 689.84,235.098 689.849,235.154 689.859,235.211 689.868,235.267 689.877,235.324 689.886,235.38 689.895,235.437 689.905,235.494 689.914,235.55 689.923,235.607 689.932,235.664 689.941,235.72 689.951,235.777 689.96,235.833 689.969,235.89 689.978,235.947 689.987,236.003 689.996,236.06 690.006,236.117 690.015,236.174 690.024,236.23 690.033,236.287 690.042,236.344 690.052,236.4 690.061,236.457 690.07,236.514 690.079,236.571 690.088,236.627 690.098,236.684 690.107,236.741 690.116,236.798 690.125,236.855 690.134,236.911 690.144,236.968 690.153,237.025 690.162,237.082 690.171,237.139 690.18,237.195 690.189,237.252 690.199,237.309 690.208,237.366 690.217,237.423 690.226,237.48 690.235,237.537 690.245,237.593 690.254,237.65 690.263,237.707 690.272,237.764 690.281,237.821 690.291,237.878 690.3,237.935 690.309,237.992 690.318,238.049 690.327,238.106 690.336,238.163 690.346,238.22 690.355,238.277 690.364,238.334 690.373,238.391 690.382,238.448 690.392,238.505 690.401,238.562 690.41,238.619 690.419,238.676 690.428,238.733 690.438,238.79 690.447,238.847 690.456,238.904 690.465,238.961 690.474,239.018 690.484,239.075 690.493,239.132 690.502,239.189 690.511,239.246 690.52,239.303 690.529,239.361 690.539,239.418 690.548,239.475 690.557,239.532 690.566,239.589 690.575,239.646 690.585,239.703 690.594,239.76 690.603,239.818 690.612,239.875 690.621,239.932 690.631,239.989 690.64,240.046 690.649,240.104 690.658,240.161 690.667,240.218 690.676,240.275 690.686,240.332 690.695,240.39 690.704,240.447 690.713,240.504 690.722,240.561 690.732,240.619 690.741,240.676 690.75,240.733 690.759,240.791 690.768,240.848 690.778,240.905 690.787,240.962 690.796,241.02 690.805,241.077 690.814,241.134 690.824,241.192 690.833,241.249 690.842,241.306 690.851,241.364 690.86,241.421 690.869,241.479 690.879,241.536 690.888,241.593 690.897,241.651 690.906,241.708 690.915,241.766 690.925,241.823 690.934,241.88 690.943,241.938 690.952,241.995 690.961,242.053 690.971,242.11 690.98,242.168 690.989,242.225 690.998,242.282 691.007,242.34 691.016,242.397 691.026,242.455 691.035,242.512 691.044,242.57 691.053,242.627 691.062,242.685 691.072,242.742 691.081,242.8 691.09,242.858 691.099,242.915 691.108,242.973 691.118,243.03 691.127,243.088 691.136,243.145 691.145,243.203 691.154,243.26 691.164,243.318 691.173,243.376 691.182,243.433 691.191,243.491 691.2,243.548 691.209,243.606 691.219,243.664 691.228,243.721 691.237,243.779 691.246,243.837 691.255,243.894 691.265,243.952 691.274,244.01 691.283,244.067 691.292,244.125 691.301,244.183 691.311,244.24 691.32,244.298 691.329,244.356 691.338,244.414 691.347,244.471 691.357,244.529 691.366,244.587 691.375,244.645 691.384,244.702 691.393,244.76 691.402,244.818 691.412,244.876 691.421,244.933 691.43,244.991 691.439,245.049 691.448,245.107 691.458,245.165 691.467,245.222 691.476,245.28 691.485,245.338 691.494,245.396 691.504,245.454 691.513,245.512 691.522,245.569 691.531,245.627 691.54,245.685 691.549,245.743 691.559,245.801 691.568,245.859 691.577,245.917 691.586,245.975 691.595,246.032 691.605,246.09 691.614,246.148 691.623,246.206 691.632,246.264 691.641,246.322 691.651,246.38 691.66,246.438 691.669,246.496 691.678,246.554 691.687,246.612 691.697,246.67 691.706,246.728 691.715,246.786 691.724,246.844 691.733,246.902 691.742,246.96 691.752,247.018 691.761,247.076 691.77,247.134 691.779,247.192 691.788,247.25 691.798,247.308 691.807,247.366 691.816,247.424 691.825,247.482 691.834,247.54 691.844,247.598 691.853,247.656 691.862,247.715 691.871,247.773 691.88,247.831 691.889,247.889 691.899,247.947 691.908,248.005 691.917,248.063 691.926,248.121 691.935,248.18 691.945,248.238 691.954,248.296 691.963,248.354 691.972,248.412 691.981,248.47 691.991,248.529 692,248.587 692.009,248.645 692.018,248.703 692.027,248.761 692.037,248.82 692.046,248.878 692.055,248.936 692.064,248.994 692.073,249.052 692.082,249.111 692.092,249.169 692.101,249.227 692.11,249.285 692.119,249.344 692.128,249.402 692.138,249.46 692.147,249.519 692.156,249.577 692.165,249.635 692.174,249.694 692.184,249.752 692.193,249.81 692.202,249.869 692.211,249.927 692.22,249.985 692.229,250.044 692.239,250.102 692.248,250.16 692.257,250.219 692.266,250.277 692.275,250.335 692.285,250.394 692.294,250.452 692.303,250.511 692.312,250.569 692.321,250.627 692.331,250.686 692.34,250.744 692.349,250.803 692.358,250.861 692.367,250.919 692.377,250.978 692.386,251.036 692.395,251.095 692.404,251.153 692.413,251.212 692.422,251.27 692.432,251.329 692.441,251.387 692.45,251.446 692.459,251.504 692.468,251.563 692.478,251.621 692.487,251.68 692.496,251.738 692.505,251.797 692.514,251.855 692.524,251.914 692.533,251.972 692.542,252.031 692.551,252.09 692.56,252.148 692.569,252.207 692.579,252.265 692.588,252.324 692.597,252.382 692.606,252.441 692.615,252.5 692.625,252.558 692.634,252.617 692.643,252.675 692.652,252.734 692.661,252.793 692.671,252.851 692.68,252.91 692.689,252.969 692.698,253.027 692.707,253.086 692.717,253.145 692.726,253.203 692.735,253.262 692.744,253.321 692.753,253.379 692.762,253.438 692.772,253.497 692.781,253.556 692.79,253.614 692.799,253.673 692.808,253.732 692.818,253.79 692.827,253.849 692.836,253.908 692.845,253.967 692.854,254.025 692.864,254.084 692.873,254.143 692.882,254.202 692.891,254.26 692.9,254.319 692.909,254.378 692.919,254.437 692.928,254.496 692.937,254.554 692.946,254.613 692.955,254.672 692.965,254.731 692.974,254.79 692.983,254.849 692.992,254.907 693.001,254.966 693.011,255.025 693.02,255.084 693.029,255.143 693.038,255.202 693.047,255.261 693.057,255.32 693.066,255.378 693.075,255.437 693.084,255.496 693.093,255.555 693.102,255.614 693.112,255.673 693.121,255.732 693.13,255.791 693.139,255.85 693.148,255.909 693.158,255.968 693.167,256.027 693.176,256.086 693.185,256.145 693.194,256.203 693.204,256.262 693.213,256.321 693.222,256.38 693.231,256.439 693.24,256.498 693.249,256.557 693.259,256.616 693.268,256.675 693.277,256.734 693.286,256.793 693.295,256.853 693.305,256.912 693.314,256.971 693.323,257.03 693.332,257.089 693.341,257.148 693.351,257.207 693.36,257.266 693.369,257.325 693.378,257.384 693.387,257.443 693.397,257.502 693.406,257.561 693.415,257.62 693.424,257.68 693.433,257.739 693.442,257.798 693.452,257.857 693.461,257.916 693.47,257.975 693.479,258.034 693.488,258.093 693.498,258.153 693.507,258.212 693.516,258.271 693.525,258.33 693.534,258.389 693.544,258.448 693.553,258.508 693.562,258.567 693.571,258.626 693.58,258.685 693.589,258.744 693.599,258.804 693.608,258.863 693.617,258.922 693.626,258.981 693.635,259.041 693.645,259.1 693.654,259.159 693.663,259.218 693.672,259.278 693.681,259.337 693.691,259.396 693.7,259.455 693.709,259.515 693.718,259.574 693.727,259.633 693.737,259.693 693.746,259.752 693.755,259.811 693.764,259.87 693.773,259.93 693.782,259.989 693.792,260.048 693.801,260.108 693.81,260.167 693.819,260.226 693.828,260.286 693.838,260.345 693.847,260.404 693.856,260.464 693.865,260.523 693.874,260.583 693.884,260.642 693.893,260.701 693.902,260.761 693.911,260.82 693.92,260.88 693.93,260.939 693.939,260.998 693.948,261.058 693.957,261.117 693.966,261.177 693.975,261.236 693.985,261.295 693.994,261.355 694.003,261.414 694.012,261.474 694.021,261.533 694.031,261.593 694.04,261.652 694.049,261.712 694.058,261.771 694.067,261.831 694.077,261.89 694.086,261.95 694.095,262.009 694.104,262.069 694.113,262.128 694.122,262.188 694.132,262.247 694.141,262.307 694.15,262.366 694.159,262.426 694.168,262.485 694.178,262.545 694.187,262.604 694.196,262.664 694.205,262.723 694.214,262.783 694.224,262.843 694.233,262.902 694.242,262.962 694.251,263.021 694.26,263.081 694.27,263.14 694.279,263.2 694.288,263.26 694.297,263.319 694.306,263.379 694.315,263.439 694.325,263.498 694.334,263.558 694.343,263.617 694.352,263.677 694.361,263.737 694.371,263.796 694.38,263.856 694.389,263.916 694.398,263.975 694.407,264.035 694.417,264.095 694.426,264.154 694.435,264.214 694.444,264.274 694.453,264.333 694.462,264.393 694.472,264.453 694.481,264.513 694.49,264.572 694.499,264.632 694.508,264.692 694.518,264.751 694.527,264.811 694.536,264.871 694.545,264.931 694.554,264.99 694.564,265.05 694.573,265.11 694.582,265.17 694.591,265.229 694.6,265.289 694.61,265.349 694.619,265.409 694.628,265.468 694.637,265.528 694.646,265.588 694.655,265.648 694.665,265.708 694.674,265.767 694.683,265.827 694.692,265.887 694.701,265.947 694.711,266.007 694.72,266.067 694.729,266.126 694.738,266.186 694.747,266.246 694.757,266.306 694.766,266.366 694.775,266.426 694.784,266.486 694.793,266.545 694.802,266.605 694.812,266.665 694.821,266.725 694.83,266.785 694.839,266.845 694.848,266.905 694.858,266.965 694.867,267.025 694.876,267.084 694.885,267.144 694.894,267.204 694.904,267.264 694.913,267.324 694.922,267.384 694.931,267.444 694.94,267.504 694.95,267.564 694.959,267.624 694.968,267.684 694.977,267.744 694.986,267.804 694.995,267.864 695.005,267.924 695.014,267.984 695.023,268.044 695.032,268.104 695.041,268.164 695.051,268.224 695.06,268.284 695.069,268.344 695.078,268.404 695.087,268.464 695.097,268.524 695.106,268.584 695.115,268.644 695.124,268.704 695.133,268.764 695.142,268.824 695.152,268.884 695.161,268.944 695.17,269.004 695.179,269.064 695.188,269.124 695.198,269.184 695.207,269.244 695.216,269.304 695.225,269.364 695.234,269.425 695.244,269.485 695.253,269.545 695.262,269.605 695.271,269.665 695.28,269.725 695.29,269.785 695.299,269.845 695.308,269.905 695.317,269.965 695.326,270.026 695.335,270.086 695.345,270.146 695.354,270.206 695.363,270.266 695.372,270.326 695.381,270.387 695.391,270.447 695.4,270.507 695.409,270.567 695.418,270.627 695.427,270.687 695.437,270.748 695.446,270.808 695.455,270.868 695.464,270.928 695.473,270.988 695.482,271.049 695.492,271.109 695.501,271.169 695.51,271.229 695.519,271.289 695.528,271.35 695.538,271.41 695.547,271.47 695.556,271.53 695.565,271.591 695.574,271.651 695.584,271.711 695.593,271.771 695.602,271.832 695.611,271.892 695.62,271.952 695.63,272.012 695.639,272.073 695.648,272.133 695.657,272.193 695.666,272.253 695.675,272.314 695.685,272.374 695.694,272.434 695.703,272.495 695.712,272.555 695.721,272.615 695.731,272.676 695.74,272.736 695.749,272.796 695.758,272.857 695.767,272.917 695.777,272.977 695.786,273.038 695.795,273.098 695.804,273.158 695.813,273.219 695.822,273.279 695.832,273.339 695.841,273.4 695.85,273.46 695.859,273.52 695.868,273.581 695.878,273.641 695.887,273.702 695.896,273.762 695.905,273.822 695.914,273.883 695.924,273.943 695.933,274.004 695.942,274.064 695.951,274.124 695.96,274.185 695.97,274.245 695.979,274.306 695.988,274.366 695.997,274.427 696.006,274.487 696.015,274.547 696.025,274.608 696.034,274.668 696.043,274.729 696.052,274.789 696.061,274.85 696.071,274.91 696.08,274.971 696.089,275.031 696.098,275.092 696.107,275.152 696.117,275.213 696.126,275.273 696.135,275.334 696.144,275.394 696.153,275.454 696.162,275.515 696.172,275.576 696.181,275.636 696.19,275.697 696.199,275.757 696.208,275.818 696.218,275.878 696.227,275.939 696.236,275.999 696.245,276.06 696.254,276.12 696.264,276.181 696.273,276.241 696.282,276.302 696.291,276.362 696.3,276.423 696.31,276.484 696.319,276.544 696.328,276.605 696.337,276.665 696.346,276.726 696.355,276.786 696.365,276.847 696.374,276.908 696.383,276.968 696.392,277.029 696.401,277.089 696.411,277.15 696.42,277.211 696.429,277.271 696.438,277.332 696.447,277.392 696.457,277.453 696.466,277.514 696.475,277.574 696.484,277.635 696.493,277.696 696.503,277.756 696.512,277.817 696.521,277.878 696.53,277.938 696.539,277.999 696.548,278.059 696.558,278.12 696.567,278.181 696.576,278.241 696.585,278.302 696.594,278.363 696.604,278.423 696.613,278.484 696.622,278.545 696.631,278.606 696.64,278.666 696.65,278.727 696.659,278.788 696.668,278.848 696.677,278.909 696.686,278.97 696.695,279.03 696.705,279.091 696.714,279.152 696.723,279.213 696.732,279.273 696.741,279.334 696.751,279.395 696.76,279.456 696.769,279.516 696.778,279.577 696.787,279.638 696.797,279.699 696.806,279.759 696.815,279.82 696.824,279.881 696.833,279.942 696.843,280.002 696.852,280.063 696.861,280.124 696.87,280.185 696.879,280.245 696.888,280.306 696.898,280.367 696.907,280.428 696.916,280.489 696.925,280.549 696.934,280.61 696.944,280.671 696.953,280.732 696.962,280.793 696.971,280.853 696.98,280.914 696.99,280.975 696.999,281.036 697.008,281.097 697.017,281.158 697.026,281.218 697.035,281.279 697.045,281.34 697.054,281.401 697.063,281.462 697.072,281.523 697.081,281.584 697.091,281.644 697.1,281.705 697.109,281.766 697.118,281.827 697.127,281.888 697.137,281.949 697.146,282.01 697.155,282.07 697.164,282.131 697.173,282.192 697.183,282.253 697.192,282.314 697.201,282.375 697.21,282.436 697.219,282.497 697.228,282.558 697.238,282.619 697.247,282.679 697.256,282.74 697.265,282.801 697.274,282.862 697.284,282.923 697.293,282.984 697.302,283.045 697.311,283.106 697.32,283.167 697.33,283.228 697.339,283.289 697.348,283.35 697.357,283.411 697.366,283.472 697.375,283.533 697.385,283.593 697.394,283.654 697.403,283.715 697.412,283.776 697.421,283.837 697.431,283.898 697.44,283.959 697.449,284.02 697.458,284.081 697.467,284.142 697.477,284.203 697.486,284.264 697.495,284.325 697.504,284.386 697.513,284.447 697.523,284.508 697.532,284.569 697.541,284.63 697.55,284.691 697.559,284.752 697.568,284.813 697.578,284.874 697.587,284.935 697.596,284.996 697.605,285.057 697.614,285.118 697.624,285.179 697.633,285.24 697.642,285.302 697.651,285.363 697.66,285.424 697.67,285.485 697.679,285.546 697.688,285.607 697.697,285.668 697.706,285.729 697.715,285.79 697.725,285.851 697.734,285.912 697.743,285.973 697.752,286.034 697.761,286.095 697.771,286.156 697.78,286.217 697.789,286.279 697.798,286.34 697.807,286.401 697.817,286.462 697.826,286.523 697.835,286.584 697.844,286.645 697.853,286.706 697.863,286.767 697.872,286.828 697.881,286.89 697.89,286.951 697.899,287.012 697.908,287.073 697.918,287.134 697.927,287.195 697.936,287.256 697.945,287.317 697.954,287.379 697.964,287.44 697.973,287.501 697.982,287.562 697.991,287.623 698,287.684 698.01,287.745 698.019,287.807 698.028,287.868 698.037,287.929 698.046,287.99 698.055,288.051 698.065,288.112 698.074,288.174 698.083,288.235 698.092,288.296 698.101,288.357 698.111,288.418 698.12,288.479 698.129,288.541 698.138,288.602 698.147,288.663 698.157,288.724 698.166,288.785 698.175,288.847 698.184,288.908 698.193,288.969 698.203,289.03 698.212,289.091 698.221,289.153 698.23,289.214 698.239,289.275 698.248,289.336 698.258,289.397 698.267,289.459 698.276,289.52 698.285,289.581 698.294,289.642 698.304,289.704 698.313,289.765 698.322,289.826 698.331,289.887 698.34,289.949 698.35,290.01 698.359,290.071 698.368,290.132 698.377,290.193 698.386,290.255 698.395,290.316 698.405,290.377 698.414,290.439 698.423,290.5 698.432,290.561 698.441,290.622 698.451,290.684 698.46,290.745 698.469,290.806 698.478,290.867 698.487,290.929 698.497,290.99 698.506,291.051 698.515,291.113 698.524,291.174 698.533,291.235 698.543,291.296 698.552,291.358 698.561,291.419 698.57,291.48 698.579,291.542 698.588,291.603 698.598,291.664 698.607,291.725 698.616,291.787 698.625,291.848 698.634,291.909 698.644,291.971 698.653,292.032 698.662,292.093 698.671,292.155 698.68,292.216 698.69,292.277 698.699,292.339 698.708,292.4 698.717,292.461 698.726,292.523 698.736,292.584 698.745,292.645 698.754,292.707 698.763,292.768 698.772,292.829 698.781,292.891 698.791,292.952 698.8,293.013 698.809,293.075 698.818,293.136 698.827,293.198 698.837,293.259 698.846,293.32 698.855,293.382 698.864,293.443 698.873,293.504 698.883,293.566 698.892,293.627 698.901,293.688 698.91,293.75 698.919,293.811 698.928,293.873 698.938,293.934 698.947,293.995 698.956,294.057 698.965,294.118 698.974,294.18 698.984,294.241 698.993,294.302 699.002,294.364 699.011,294.425 699.02,294.487 699.03,294.548 699.039,294.609 699.048,294.671 699.057,294.732 699.066,294.794 699.076,294.855 699.085,294.916 699.094,294.978 699.103,295.039 699.112,295.101 699.121,295.162 699.131,295.224 699.14,295.285 699.149,295.346 699.158,295.408 699.167,295.469 699.177,295.531 699.186,295.592 699.195,295.654 699.204,295.715 699.213,295.776 699.223,295.838 699.232,295.899 699.241,295.961 699.25,296.022 699.259,296.084 699.268,296.145 699.278,296.207 699.287,296.268 699.296,296.329 699.305,296.391 699.314,296.452 699.324,296.514 699.333,296.575 699.342,296.637 699.351,296.698 699.36,296.76 699.37,296.821 699.379,296.883 699.388,296.944 699.397,297.006 699.406,297.067 699.416,297.129 699.425,297.19 699.434,297.252 699.443,297.313 699.452,297.375 699.461,297.436 699.471,297.498 699.48,297.559 699.489,297.62 699.498,297.682 699.507,297.743 699.517,297.805 699.526,297.866 699.535,297.928 699.544,297.989 699.553,298.051 699.563,298.113 699.572,298.174 699.581,298.236 699.59,298.297 699.599,298.359 699.608,298.42 699.618,298.482 699.627,298.543 699.636,298.605 699.645,298.666 699.654,298.728 699.664,298.789 699.673,298.851 699.682,298.912 699.691,298.974 699.7,299.035 699.71,299.097 699.719,299.158 699.728,299.22 699.737,299.281 699.746,299.343 699.756,299.405 699.765,299.466 699.774,299.528 699.783,299.589 699.792,299.651 699.801,299.712 699.811,299.774 699.82,299.835 699.829,299.897 699.838,299.958 699.847,300.02 699.857,300.082 699.866,300.143 699.875,300.205 699.884,300.266 699.893,300.328 699.903,300.389 699.912,300.451 699.921,300.512 699.93,300.574 699.939,300.636 699.948,300.697 699.958,300.759 699.967,300.82 699.976,300.882 699.985,300.943 699.994,301.005 700.004,301.067 700.013,301.128 700.022,301.19 700.031,301.251 700.04,301.313 700.05,301.374 700.059,301.436 700.068,301.498 700.077,301.559 700.086,301.621 700.096,301.682 700.105,301.744 700.114,301.806 700.123,301.867 700.132,301.929 700.141,301.99 700.151,302.052 700.16,302.114 700.169,302.175 700.178,302.237 700.187,302.298 700.197,302.36 700.206,302.422 700.215,302.483 700.224,302.545 700.233,302.606 700.243,302.668 700.252,302.73 700.261,302.791 700.27,302.853 700.279,302.914 700.288,302.976 700.298,303.038 700.307,303.099 700.316,303.161 700.325,303.223 700.334,303.284 700.344,303.346 700.353,303.407 700.362,303.469 700.371,303.531 700.38,303.592 700.39,303.654 700.399,303.716 700.408,303.777 700.417,303.839 700.426,303.9 700.436,303.962 700.445,304.024 700.454,304.085 700.463,304.147 700.472,304.209 700.481,304.27 700.491,304.332 700.5,304.394 700.509,304.455 700.518,304.517 700.527,304.578 700.537,304.64 700.546,304.702 700.555,304.763 700.564,304.825 700.573,304.887 700.583,304.948 700.592,305.01 700.601,305.072 700.61,305.133 700.619,305.195 700.628,305.257 700.638,305.318 700.647,305.38 700.656,305.442 700.665,305.503 700.674,305.565 700.684,305.626 700.693,305.688 700.702,305.75 700.711,305.811 700.72,305.873 700.73,305.935 700.739,305.996 700.748,306.058 700.757,306.12 700.766,306.181 700.776,306.243 700.785,306.305 700.794,306.366 700.803,306.428 700.812,306.49 700.821,306.551 700.831,306.613 700.84,306.675 700.849,306.736 700.858,306.798 700.867,306.86 700.877,306.921 700.886,306.983 700.895,307.045 700.904,307.106 700.913,307.168 700.923,307.23 700.932,307.292 700.941,307.353 700.95,307.415 700.959,307.477 700.968,307.538 700.978,307.6 700.987,307.662 700.996,307.723 701.005,307.785 701.014,307.847 701.024,307.908 701.033,307.97 701.042,308.032 701.051,308.093 701.06,308.155 701.07,308.217 701.079,308.278 701.088,308.34 701.097,308.402 701.106,308.464 701.116,308.525 701.125,308.587 701.134,308.649 701.143,308.71 701.152,308.772 701.161,308.834 701.171,308.895 701.18,308.957 701.189,309.019 701.198,309.08 701.207,309.142 701.217,309.204 701.226,309.266 701.235,309.327 701.244,309.389 701.253,309.451 701.263,309.512 701.272,309.574 701.281,309.636 701.29,309.697 701.299,309.759 701.309,309.821 701.318,309.883 701.327,309.944 701.336,310.006 701.345,310.068 701.354,310.129 701.364,310.191 701.373,310.253 701.382,310.314 701.391,310.376 701.4,310.438 701.41,310.5 701.419,310.561 701.428,310.623 701.437,310.685 701.446,310.746 701.456,310.808 701.465,310.87 701.474,310.932 701.483,310.993 701.492,311.055 701.501,311.117 701.511,311.178 701.52,311.24 701.529,311.302 701.538,311.363 701.547,311.425 701.557,311.487 701.566,311.549 701.575,311.61 701.584,311.672 701.593,311.734 701.603,311.795 701.612,311.857 701.621,311.919 701.63,311.981 701.639,312.042 701.649,312.104 701.658,312.166 701.667,312.227 701.676,312.289 701.685,312.351 701.694,312.413 701.704,312.474 701.713,312.536 701.722,312.598 701.731,312.659 701.74,312.721 701.75,312.783 701.759,312.845 701.768,312.906 701.777,312.968 701.786,313.03 701.796,313.091 701.805,313.153 701.814,313.215 701.823,313.277 701.832,313.338 701.841,313.4 701.851,313.462 701.86,313.523 701.869,313.585 701.878,313.647 701.887,313.709 701.897,313.77 701.906,313.832 701.915,313.894 701.924,313.956 701.933,314.017 701.943,314.079 701.952,314.141 701.961,314.202 701.97,314.264 701.979,314.326 701.989,314.388 701.998,314.449 702.007,314.511 702.016,314.573 702.025,314.634 702.034,314.696 702.044,314.758 702.053,314.82 702.062,314.881 702.071,314.943 702.08,315.005 702.09,315.066 702.099,315.128 702.108,315.19 702.117,315.252 702.126,315.313 702.136,315.375 702.145,315.437 702.154,315.498 702.163,315.56 702.172,315.622 702.181,315.684 702.191,315.745 702.2,315.807 702.209,315.869 702.218,315.93 702.227,315.992 702.237,316.054 702.246,316.116 702.255,316.177 702.264,316.239 702.273,316.301 702.283,316.362 702.292,316.424 702.301,316.486 702.31,316.548 702.319,316.609 702.329,316.671 702.338,316.733 702.347,316.794 702.356,316.856 702.365,316.918 702.374,316.98 702.384,317.041 702.393,317.103 702.402,317.165 702.411,317.226 702.42,317.288 702.43,317.35 702.439,317.412 702.448,317.473 702.457,317.535 702.466,317.597 702.476,317.658 702.485,317.72 702.494,317.782 702.503,317.844 702.512,317.905 702.521,317.967 702.531,318.029 702.54,318.09 702.549,318.152 702.558,318.214 702.567,318.276 702.577,318.337 702.586,318.399 702.595,318.461 702.604,318.522 702.613,318.584 702.623,318.646 702.632,318.707 702.641,318.769 702.65,318.831 702.659,318.893 702.669,318.954 702.678,319.016 702.687,319.078 702.696,319.139 702.705,319.201 702.714,319.263 702.724,319.324 702.733,319.386 702.742,319.448 702.751,319.51 702.76,319.571 702.77,319.633 702.779,319.695 702.788,319.756 702.797,319.818 702.806,319.88 702.816,319.941 702.825,320.003 702.834,320.065 702.843,320.127 702.852,320.188 702.861,320.25 702.871,320.312 702.88,320.373 702.889,320.435 702.898,320.497 702.907,320.558 702.917,320.62 702.926,320.682 702.935,320.743 702.944,320.805 702.953,320.867 702.963,320.928 702.972,320.99 702.981,321.052 702.99,321.113 702.999,321.175 703.009,321.237 703.018,321.299 703.027,321.36 703.036,321.422 703.045,321.484 703.054,321.545 703.064,321.607 703.073,321.669 703.082,321.73 703.091,321.792 703.1,321.854 703.11,321.915 703.119,321.977 703.128,322.039 703.137,322.1 703.146,322.162 703.156,322.224 703.165,322.285 703.174,322.347 703.183,322.409 703.192,322.47 703.201,322.532 703.211,322.594 703.22,322.655 703.229,322.717 703.238,322.779 703.247,322.84 703.257,322.902 703.266,322.964 703.275,323.025 703.284,323.087 703.293,323.149 703.303,323.21 703.312,323.272 703.321,323.334 703.33,323.395 703.339,323.457 703.349,323.519 703.358,323.58 703.367,323.642 703.376,323.703 703.385,323.765 703.394,323.827 703.404,323.888 703.413,323.95 703.422,324.012 703.431,324.073 703.44,324.135 703.45,324.197 703.459,324.258 703.468,324.32 703.477,324.382 703.486,324.443 703.496,324.505 703.505,324.566 703.514,324.628 703.523,324.69 703.532,324.751 703.541,324.813 703.551,324.875 703.56,324.936 703.569,324.998 703.578,325.06 703.587,325.121 703.597,325.183 703.606,325.244 703.615,325.306 703.624,325.368 703.633,325.429 703.643,325.491 703.652,325.553 703.661,325.614 703.67,325.676 703.679,325.737 703.689,325.799 703.698,325.861 703.707,325.922 703.716,325.984 703.725,326.045 703.734,326.107 703.744,326.169 703.753,326.23 703.762,326.292 703.771,326.354 703.78,326.415 703.79,326.477 703.799,326.538 703.808,326.6 703.817,326.662 703.826,326.723 703.836,326.785 703.845,326.846 703.854,326.908 703.863,326.97 703.872,327.031 703.882,327.093 703.891,327.154 703.9,327.216 703.909,327.277 703.918,327.339 703.927,327.401 703.937,327.462 703.946,327.524 703.955,327.585 703.964,327.647 703.973,327.709 703.983,327.77 703.992,327.832 704.001,327.893 704.01,327.955 704.019,328.016 704.029,328.078 704.038,328.14 704.047,328.201 704.056,328.263 704.065,328.324 704.074,328.386 704.084,328.447 704.093,328.509 704.102,328.57 704.111,328.632 704.12,328.694 704.13,328.755 704.139,328.817 704.148,328.878 704.157,328.94 704.166,329.001 704.176,329.063 704.185,329.124 704.194,329.186 704.203,329.248 704.212,329.309 704.222,329.371 704.231,329.432 704.24,329.494 704.249,329.555 704.258,329.617 704.267,329.678 704.277,329.74 704.286,329.801 704.295,329.863 704.304,329.924 704.313,329.986 704.323,330.048 704.332,330.109 704.341,330.171 704.35,330.232 704.359,330.294 704.369,330.355 704.378,330.417 704.387,330.478 704.396,330.54 704.405,330.601 704.414,330.663 704.424,330.724 704.433,330.786 704.442,330.847 704.451,330.909 704.46,330.97 704.47,331.032 704.479,331.093 704.488,331.155 704.497,331.216 704.506,331.278 704.516,331.339 704.525,331.401 704.534,331.462 704.543,331.524 704.552,331.585 704.562,331.647 704.571,331.708 704.58,331.77 704.589,331.831 704.598,331.893 704.607,331.954 704.617,332.016 704.626,332.077 704.635,332.138 704.644,332.2 704.653,332.261 704.663,332.323 704.672,332.384 704.681,332.446 704.69,332.507 704.699,332.569 704.709,332.63 704.718,332.692 704.727,332.753 704.736,332.815 704.745,332.876 704.754,332.937 704.764,332.999 704.773,333.06 704.782,333.122 704.791,333.183 704.8,333.245 704.81,333.306 704.819,333.368 704.828,333.429 704.837,333.49 704.846,333.552 704.856,333.613 704.865,333.675 704.874,333.736 704.883,333.798 704.892,333.859 704.902,333.92 704.911,333.982 704.92,334.043 704.929,334.105 704.938,334.166 704.947,334.227 704.957,334.289 704.966,334.35 704.975,334.412 704.984,334.473 704.993,334.534 705.003,334.596 705.012,334.657 705.021,334.719 705.03,334.78 705.039,334.841 705.049,334.903 705.058,334.964 705.067,335.026 705.076,335.087 705.085,335.148 705.094,335.21 705.104,335.271 705.113,335.333 705.122,335.394 705.131,335.455 705.14,335.517 705.15,335.578 705.159,335.639 705.168,335.701 705.177,335.762 705.186,335.823 705.196,335.885 705.205,335.946 705.214,336.007 705.223,336.069 705.232,336.13 705.242,336.192 705.251,336.253 705.26,336.314 705.269,336.376 705.278,336.437 705.287,336.498 705.297,336.56 705.306,336.621 705.315,336.682 705.324,336.744 705.333,336.805 705.343,336.866 705.352,336.928 705.361,336.989 705.37,337.05 705.379,337.111 705.389,337.173 705.398,337.234 705.407,337.295 705.416,337.357 705.425,337.418 705.434,337.479 705.444,337.541 705.453,337.602 705.462,337.663 705.471,337.725 705.48,337.786 705.49,337.847 705.499,337.908 705.508,337.97 705.517,338.031 705.526,338.092 705.536,338.153 705.545,338.215 705.554,338.276 705.563,338.337 705.572,338.399 705.582,338.46 705.591,338.521 705.6,338.582 705.609,338.644 705.618,338.705 705.627,338.766 705.637,338.827 705.646,338.889 705.655,338.95 705.664,339.011 705.673,339.072 705.683,339.134 705.692,339.195 705.701,339.256 705.71,339.317 705.719,339.379 705.729,339.44 705.738,339.501 705.747,339.562 705.756,339.623 705.765,339.685 705.774,339.746 705.784,339.807 705.793,339.868 705.802,339.93 705.811,339.991 705.82,340.052 705.83,340.113 705.839,340.174 705.848,340.236 705.857,340.297 705.866,340.358 705.876,340.419 705.885,340.48 705.894,340.541 705.903,340.603 705.912,340.664 705.922,340.725 705.931,340.786 705.94,340.847 705.949,340.909 705.958,340.97 705.967,341.031 705.977,341.092 705.986,341.153 705.995,341.214 706.004,341.275 706.013,341.337 706.023,341.398 706.032,341.459 706.041,341.52 706.05,341.581 706.059,341.642 706.069,341.703 706.078,341.765 706.087,341.826 706.096,341.887 706.105,341.948 706.114,342.009 706.124,342.07 706.133,342.131 706.142,342.192 706.151,342.254 706.16,342.315 706.17,342.376 706.179,342.437 706.188,342.498 706.197,342.559 706.206,342.62 706.216,342.681 706.225,342.742 706.234,342.803 706.243,342.865 706.252,342.926 706.262,342.987 706.271,343.048 706.28,343.109 706.289,343.17 706.298,343.231 706.307,343.292 706.317,343.353 706.326,343.414 706.335,343.475 706.344,343.536 706.353,343.597 706.363,343.658 706.372,343.719 706.381,343.781 706.39,343.842 706.399,343.903 706.409,343.964 706.418,344.025 706.427,344.086 706.436,344.147 706.445,344.208 706.455,344.269 706.464,344.33 706.473,344.391 706.482,344.452 706.491,344.513 706.5,344.574 706.51,344.635 706.519,344.696 706.528,344.757 706.537,344.818 706.546,344.879 706.556,344.94 706.565,345.001 706.574,345.062 706.583,345.123 706.592,345.184 706.602,345.245 706.611,345.306 706.62,345.367 706.629,345.428 706.638,345.489 706.647,345.55 706.657,345.611 706.666,345.672 706.675,345.732 706.684,345.793 706.693,345.854 706.703,345.915 706.712,345.976 706.721,346.037 706.73,346.098 706.739,346.159 706.749,346.22 706.758,346.281 706.767,346.342 706.776,346.403 706.785,346.464 706.795,346.525 706.804,346.585 706.813,346.646 706.822,346.707 706.831,346.768 706.84,346.829 706.85,346.89 706.859,346.951 706.868,347.012 706.877,347.073 706.886,347.134 706.896,347.194 706.905,347.255 706.914,347.316 706.923,347.377 706.932,347.438 706.942,347.499 706.951,347.56 706.96,347.621 706.969,347.681 706.978,347.742 706.987,347.803 706.997,347.864 707.006,347.925 707.015,347.986 707.024,348.046 707.033,348.107 707.043,348.168 707.052,348.229 707.061,348.29 707.07,348.351 707.079,348.411 707.089,348.472 707.098,348.533 707.107,348.594 707.116,348.655 707.125,348.715 707.135,348.776 707.144,348.837 707.153,348.898 707.162,348.959 707.171,349.019 707.18,349.08 707.19,349.141 707.199,349.202 707.208,349.262 707.217,349.323 707.226,349.384 707.236,349.445 707.245,349.506 707.254,349.566 707.263,349.627 707.272,349.688 707.282,349.749 707.291,349.809 707.3,349.87 707.309,349.931 707.318,349.991 707.327,350.052 707.337,350.113 707.346,350.174 707.355,350.234 707.364,350.295 707.373,350.356 707.383,350.417 707.392,350.477 707.401,350.538 707.41,350.599 707.419,350.659 707.429,350.72 707.438,350.781 707.447,350.841 707.456,350.902 707.465,350.963 707.475,351.023 707.484,351.084 707.493,351.145 707.502,351.205 707.511,351.266 707.52,351.327 707.53,351.387 707.539,351.448 707.548,351.509 707.557,351.569 707.566,351.63 707.576,351.691 707.585,351.751 707.594,351.812 707.603,351.873 707.612,351.933 707.622,351.994 707.631,352.054 707.64,352.115 707.649,352.176 707.658,352.236 707.667,352.297 707.677,352.357 707.686,352.418 707.695,352.479 707.704,352.539 707.713,352.6 707.723,352.66 707.732,352.721 707.741,352.781 707.75,352.842 707.759,352.903 707.769,352.963 707.778,353.024 707.787,353.084 707.796,353.145 707.805,353.205 707.815,353.266 707.824,353.326 707.833,353.387 707.842,353.448 707.851,353.508 707.86,353.569 707.87,353.629 707.879,353.69 707.888,353.75 707.897,353.811 707.906,353.871 707.916,353.932 707.925,353.992 707.934,354.053 707.943,354.113 707.952,354.174 707.962,354.234 707.971,354.295 707.98,354.355 707.989,354.416 707.998,354.476 708.007,354.537 708.017,354.597 708.026,354.657 708.035,354.718 708.044,354.778 708.053,354.839 708.063,354.899 708.072,354.96 708.081,355.02 708.09,355.081 708.099,355.141 708.109,355.201 708.118,355.262 708.127,355.322 708.136,355.383 708.145,355.443 708.155,355.503 708.164,355.564 708.173,355.624 708.182,355.685 708.191,355.745 708.2,355.805 708.21,355.866 708.219,355.926 708.228,355.987 708.237,356.047 708.246,356.107 708.256,356.168 708.265,356.228 708.274,356.288 708.283,356.349 708.292,356.409 708.302,356.469 708.311,356.53 708.32,356.59 708.329,356.65 708.338,356.711 708.347,356.771 708.357,356.831 708.366,356.892 708.375,356.952 708.384,357.012 708.393,357.073 708.403,357.133 708.412,357.193 708.421,357.254 708.43,357.314 708.439,357.374 708.449,357.434 708.458,357.495 708.467,357.555 708.476,357.615 708.485,357.676 708.495,357.736 708.504,357.796 708.513,357.856 708.522,357.917 708.531,357.977 708.54,358.037 708.55,358.097 708.559,358.157 708.568,358.218 708.577,358.278 708.586,358.338 708.596,358.398 708.605,358.459 708.614,358.519 708.623,358.579 708.632,358.639 708.642,358.699 708.651,358.76 708.66,358.82 708.669,358.88 708.678,358.94 708.688,359 708.697,359.061 708.706,359.121 708.715,359.181 708.724,359.241 708.733,359.301 708.743,359.361 708.752,359.421 708.761,359.482 708.77,359.542 708.779,359.602 708.789,359.662 708.798,359.722 708.807,359.782 708.816,359.842 708.825,359.902 708.835,359.963 708.844,360.023 708.853,360.083 708.862,360.143 708.871,360.203 708.88,360.263 708.89,360.323 708.899,360.383 708.908,360.443 708.917,360.503 708.926,360.563 708.936,360.623 708.945,360.684 708.954,360.744 708.963,360.804 708.972,360.864 708.982,360.924 708.991,360.984 709,361.044 709.009,361.104 709.018,361.164 709.028,361.224 709.037,361.284 709.046,361.344 709.055,361.404 709.064,361.464 709.073,361.524 709.083,361.584 709.092,361.644 709.101,361.704 709.11,361.764 709.119,361.824 709.129,361.884 709.138,361.944 709.147,362.004 709.156,362.064 709.165,362.124 709.175,362.184 709.184,362.244 709.193,362.303 709.202,362.363 709.211,362.423 709.22,362.483 709.23,362.543 709.239,362.603 709.248,362.663 709.257,362.723 709.266,362.783 709.276,362.843 709.285,362.903 709.294,362.963 709.303,363.022 709.312,363.082 709.322,363.142 709.331,363.202 709.34,363.262 709.349,363.322 709.358,363.382 709.368,363.442 709.377,363.501 709.386,363.561 709.395,363.621 709.404,363.681 709.413,363.741 709.423,363.801 709.432,363.86 709.441,363.92 709.45,363.98 709.459,364.04 709.469,364.1 709.478,364.159 709.487,364.219 709.496,364.279 709.505,364.339 709.515,364.399 709.524,364.458 709.533,364.518 709.542,364.578 709.551,364.638 709.56,364.697 709.57,364.757 709.579,364.817 709.588,364.877 709.597,364.936 709.606,364.996 709.616,365.056 709.625,365.116 709.634,365.175 709.643,365.235 709.652,365.295 709.662,365.355 709.671,365.414 709.68,365.474 709.689,365.534 709.698,365.593 709.708,365.653 709.717,365.713 709.726,365.772 709.735,365.832 709.744,365.892 709.753,365.951 709.763,366.011 709.772,366.071 709.781,366.13 709.79,366.19 709.799,366.25 709.809,366.309 709.818,366.369 709.827,366.429 709.836,366.488 709.845,366.548 709.855,366.607 709.864,366.667 709.873,366.727 709.882,366.786 709.891,366.846 709.9,366.905 709.91,366.965 709.919,367.025 709.928,367.084 709.937,367.144 709.946,367.203 709.956,367.263 709.965,367.322 709.974,367.382 709.983,367.441 709.992,367.501 710.002,367.56 710.011,367.62 710.02,367.68 710.029,367.739 710.038,367.799 710.048,367.858 710.057,367.918 710.066,367.977 710.075,368.037 710.084,368.096 710.093,368.156 710.103,368.215 710.112,368.275 710.121,368.334 710.13,368.393 710.139,368.453 710.149,368.512 710.158,368.572 710.167,368.631 710.176,368.691 710.185,368.75 710.195,368.81 710.204,368.869 710.213,368.928 710.222,368.988 710.231,369.047 710.24,369.107 710.25,369.166 710.259,369.225 710.268,369.285 710.277,369.344 710.286,369.404 710.296,369.463 710.305,369.522 710.314,369.582 710.323,369.641 710.332,369.7 710.342,369.76 710.351,369.819 710.36,369.878 710.369,369.938 710.378,369.997 710.388,370.056 710.397,370.116 710.406,370.175 710.415,370.234 710.424,370.294 710.433,370.353 710.443,370.412 710.452,370.472 710.461,370.531 710.47,370.59 710.479,370.649 710.489,370.709 710.498,370.768 710.507,370.827 710.516,370.887 710.525,370.946 710.535,371.005 710.544,371.064 710.553,371.124 710.562,371.183 710.571,371.242 710.58,371.301 710.59,371.36 710.599,371.42 710.608,371.479 710.617,371.538 710.626,371.597 710.636,371.656 710.645,371.716 710.654,371.775 710.663,371.834 710.672,371.893 710.682,371.952 710.691,372.011 710.7,372.071 710.709,372.13 710.718,372.189 710.728,372.248 710.737,372.307 710.746,372.366 710.755,372.425 710.764,372.484 710.773,372.544 710.783,372.603 710.792,372.662 710.801,372.721 710.81,372.78 710.819,372.839 710.829,372.898 710.838,372.957 710.847,373.016 710.856,373.075 710.865,373.134 710.875,373.193 710.884,373.253 710.893,373.312 710.902,373.371 710.911,373.43 710.92,373.489 710.93,373.548 710.939,373.607 710.948,373.666 710.957,373.725 710.966,373.784 710.976,373.843 710.985,373.902 710.994,373.961 711.003,374.02 711.012,374.079 711.022,374.138 711.031,374.197 711.04,374.256 711.049,374.314 711.058,374.373 711.068,374.432 711.077,374.491 711.086,374.55 711.095,374.609 711.104,374.668 711.113,374.727 711.123,374.786 711.132,374.845 711.141,374.904 711.15,374.963 711.159,375.021 711.169,375.08 711.178,375.139 711.187,375.198 711.196,375.257 711.205,375.316 711.215,375.375 711.224,375.434 711.233,375.492 711.242,375.551 711.251,375.61 711.261,375.669 711.27,375.728 711.279,375.786 711.288,375.845 711.297,375.904 711.306,375.963 711.316,376.022 711.325,376.08 711.334,376.139 711.343,376.198 711.352,376.257 711.362,376.316 711.371,376.374 711.38,376.433 711.389,376.492 711.398,376.551 711.408,376.609 711.417,376.668 711.426,376.727 711.435,376.785 711.444,376.844 711.453,376.903 711.463,376.962 711.472,377.02 711.481,377.079 711.49,377.138 711.499,377.196 711.509,377.255 711.518,377.314 711.527,377.372 711.536,377.431 711.545,377.49 711.555,377.548 711.564,377.607 711.573,377.666 711.582,377.724 711.591,377.783 711.601,377.842 711.61,377.9 711.619,377.959 711.628,378.017 711.637,378.076 711.646,378.135 711.656,378.193 711.665,378.252 711.674,378.31 711.683,378.369 711.692,378.427 711.702,378.486 711.711,378.545 711.72,378.603 711.729,378.662 711.738,378.72 711.748,378.779 711.757,378.837 711.766,378.896 711.775,378.954 711.784,379.013 711.793,379.071 711.803,379.13 711.812,379.188 711.821,379.247 711.83,379.305 711.839,379.364 711.849,379.422 711.858,379.481 711.867,379.539 711.876,379.597 711.885,379.656 711.895,379.714 711.904,379.773 711.913,379.831 711.922,379.89 711.931,379.948 711.941,380.006 711.95,380.065 711.959,380.123 711.968,380.182 711.977,380.24 711.986,380.298 711.996,380.357 712.005,380.415 712.014,380.473 712.023,380.532 712.032,380.59 712.042,380.649 712.051,380.707 712.06,380.765 712.069,380.824 712.078,380.882 712.088,380.94 712.097,380.998 712.106,381.057 712.115,381.115 712.124,381.173 712.133,381.232 712.143,381.29 712.152,381.348 712.161,381.406 712.17,381.465 712.179,381.523 712.189,381.581 712.198,381.639 712.207,381.698 712.216,381.756 712.225,381.814 712.235,381.872 712.244,381.931 712.253,381.989 712.262,382.047 712.271,382.105 712.281,382.163 712.29,382.222 712.299,382.28 712.308,382.338 712.317,382.396 712.326,382.454 712.336,382.512 712.345,382.571 712.354,382.629 712.363,382.687 712.372,382.745 712.382,382.803 712.391,382.861 712.4,382.919 712.409,382.977 712.418,383.036 712.428,383.094 712.437,383.152 712.446,383.21 712.455,383.268 712.464,383.326 712.473,383.384 712.483,383.442 712.492,383.5 712.501,383.558 712.51,383.616 712.519,383.674 712.529,383.732 712.538,383.79 712.547,383.848 712.556,383.906 712.565,383.964 712.575,384.022 712.584,384.08 712.593,384.138 712.602,384.196 712.611,384.254 712.621,384.312 712.63,384.37 712.639,384.428 712.648,384.486 712.657,384.544 712.666,384.602 712.676,384.66 712.685,384.718 712.694,384.776 712.703,384.834 712.712,384.891 712.722,384.949 712.731,385.007 712.74,385.065 712.749,385.123 712.758,385.181 712.768,385.239 712.777,385.297 712.786,385.354 712.795,385.412 712.804,385.47 712.813,385.528 712.823,385.586 712.832,385.644 712.841,385.701 712.85,385.759 712.859,385.817 712.869,385.875 712.878,385.933 712.887,385.99 712.896,386.048 712.905,386.106 712.915,386.164 712.924,386.222 712.933,386.279 712.942,386.337 712.951,386.395 712.961,386.453 712.97,386.51 712.979,386.568 712.988,386.626 712.997,386.683 713.006,386.741 713.016,386.799 713.025,386.857 713.034,386.914 713.043,386.972 713.052,387.03 713.062,387.087 713.071,387.145 713.08,387.203 713.089,387.26 713.098,387.318 713.108,387.375 713.117,387.433 713.126,387.491 713.135,387.548 713.144,387.606 713.153,387.664 713.163,387.721 713.172,387.779 713.181,387.836 713.19,387.894 713.199,387.951 713.209,388.009 713.218,388.067 713.227,388.124 713.236,388.182 713.245,388.239 713.255,388.297 713.264,388.354 713.273,388.412 713.282,388.469 713.291,388.527 713.301,388.584 713.31,388.642 713.319,388.699 713.328,388.757 713.337,388.814 713.346,388.872 713.356,388.929 713.365,388.987 713.374,389.044 713.383,389.101 713.392,389.159 713.402,389.216 713.411,389.274 713.42,389.331 713.429,389.389 713.438,389.446 713.448,389.503 713.457,389.561 713.466,389.618 713.475,389.676 713.484,389.733 713.493,389.79 713.503,389.848 713.512,389.905 713.521,389.962 713.53,390.02 713.539,390.077 713.549,390.134 713.558,390.192 713.567,390.249 713.576,390.306 713.585,390.364 713.595,390.421 713.604,390.478 713.613,390.535 713.622,390.593 713.631,390.65 713.641,390.707 713.65,390.764 713.659,390.822 713.668,390.879 713.677,390.936 713.686,390.993 713.696,391.051 713.705,391.108 713.714,391.165 713.723,391.222 713.732,391.279 713.742,391.337 713.751,391.394 713.76,391.451 713.769,391.508 713.778,391.565 713.788,391.622 713.797,391.68 713.806,391.737 713.815,391.794 713.824,391.851 713.834,391.908 713.843,391.965 713.852,392.022 713.861,392.079 713.87,392.136 713.879,392.194 713.889,392.251 713.898,392.308 713.907,392.365 713.916,392.422 713.925,392.479 713.935,392.536 713.944,392.593 713.953,392.65 713.962,392.707 713.971,392.764 713.981,392.821 713.99,392.878 713.999,392.935 714.008,392.992 714.017,393.049 714.026,393.106 714.036,393.163 714.045,393.22 714.054,393.277 714.063,393.334 714.072,393.391 714.082,393.448 714.091,393.505 714.1,393.562 714.109,393.619 714.118,393.675 714.128,393.732 714.137,393.789 714.146,393.846 714.155,393.903 714.164,393.96 714.174,394.017 714.183,394.074 714.192,394.13 714.201,394.187 714.21,394.244 714.219,394.301 714.229,394.358 714.238,394.415 714.247,394.471 714.256,394.528 714.265,394.585 714.275,394.642 714.284,394.699 714.293,394.755 714.302,394.812 714.311,394.869 714.321,394.926 714.33,394.982 714.339,395.039 714.348,395.096 714.357,395.153 714.366,395.209 714.376,395.266 714.385,395.323 714.394,395.38 714.403,395.436 714.412,395.493 714.422,395.55 714.431,395.606 714.44,395.663 714.449,395.72 714.458,395.776 714.468,395.833 714.477,395.89 714.486,395.946 714.495,396.003 714.504,396.059 714.514,396.116 714.523,396.173 714.532,396.229 714.541,396.286 714.55,396.342 714.559,396.399 714.569,396.456 714.578,396.512 714.587,396.569 714.596,396.625 714.605,396.682 714.615,396.738 714.624,396.795 714.633,396.851 714.642,396.908 714.651,396.964 714.661,397.021 714.67,397.077 714.679,397.134 714.688,397.19 714.697,397.247 714.706,397.303 714.716,397.36 714.725,397.416 714.734,397.473 714.743,397.529 714.752,397.586 714.762,397.642 714.771,397.698 714.78,397.755 714.789,397.811 714.798,397.868 714.808,397.924 714.817,397.98 714.826,398.037 714.835,398.093 714.844,398.15 714.854,398.206 714.863,398.262 714.872,398.319 714.881,398.375 714.89,398.431 714.899,398.488 714.909,398.544 714.918,398.6 714.927,398.656 714.936,398.713 714.945,398.769 714.955,398.825 714.964,398.882 714.973,398.938 714.982,398.994 714.991,399.05 715.001,399.107 715.01,399.163 715.019,399.219 715.028,399.275 715.037,399.331 715.046,399.388 715.056,399.444 715.065,399.5 715.074,399.556 715.083,399.612 715.092,399.669 715.102,399.725 715.111,399.781 715.12,399.837 715.129,399.893 715.138,399.949 715.148,400.005 715.157,400.062 715.166,400.118 715.175,400.174 715.184,400.23 715.194,400.286 715.203,400.342 715.212,400.398 715.221,400.454 715.23,400.51 715.239,400.566 715.249,400.622 715.258,400.678 715.267,400.734 715.276,400.79 715.285,400.846 715.295,400.902 715.304,400.958 715.313,401.014 715.322,401.07 715.331,401.126 715.341,401.182 715.35,401.238 715.359,401.294 715.368,401.35 715.377,401.406 715.386,401.462 715.396,401.518 715.405,401.574 715.414,401.63 715.423,401.686 715.432,401.742 715.442,401.798 715.451,401.853 715.46,401.909 715.469,401.965 715.478,402.021 715.488,402.077 715.497,402.133 715.506,402.189 715.515,402.244 715.524,402.3 715.534,402.356 715.543,402.412 715.552,402.468 715.561,402.524 715.57,402.579 715.579,402.635 715.589,402.691 715.598,402.747 715.607,402.802 715.616,402.858 715.625,402.914 715.635,402.97 715.644,403.025 715.653,403.081 715.662,403.137 715.671,403.192 715.681,403.248 715.69,403.304 715.699,403.36 715.708,403.415 715.717,403.471 715.726,403.527 715.736,403.582 715.745,403.638 715.754,403.694 715.763,403.749 715.772,403.805 715.782,403.86 715.791,403.916 715.8,403.972 715.809,404.027 715.818,404.083 715.828,404.138 715.837,404.194 715.846,404.25 715.855,404.305 715.864,404.361 715.874,404.416 715.883,404.472 715.892,404.527 715.901,404.583 715.91,404.638 715.919,404.694 715.929,404.749 715.938,404.805 715.947,404.86 715.956,404.916 715.965,404.971 715.975,405.027 715.984,405.082 715.993,405.138 716.002,405.193 716.011,405.248 716.021,405.304 716.03,405.359 716.039,405.415 716.048,405.47 716.057,405.525 716.067,405.581 716.076,405.636 716.085,405.692 716.094,405.747 716.103,405.802 716.112,405.858 716.122,405.913 716.131,405.968 716.14,406.024 716.149,406.079 716.158,406.134 716.168,406.19 716.177,406.245 716.186,406.3 716.195,406.355 716.204,406.411 716.214,406.466 716.223,406.521 716.232,406.577 716.241,406.632 716.25,406.687 716.259,406.742 716.269,406.797 716.278,406.853 716.287,406.908 716.296,406.963 716.305,407.018 716.315,407.073 716.324,407.129 716.333,407.184 716.342,407.239 716.351,407.294 716.361,407.349 716.37,407.404 716.379,407.459 716.388,407.515 716.397,407.57 716.407,407.625 716.416,407.68 716.425,407.735 716.434,407.79 716.443,407.845 716.452,407.9 716.462,407.955 716.471,408.01 716.48,408.065 716.489,408.12 716.498,408.175 716.508,408.23 716.517,408.285 716.526,408.34 716.535,408.395 716.544,408.45 716.554,408.505 716.563,408.56 716.572,408.615 716.581,408.67 716.59,408.725 716.599,408.78 716.609,408.835 716.618,408.89 716.627,408.945 716.636,409 716.645,409.055 716.655,409.11 716.664,409.165 716.673,409.219 716.682,409.274 716.691,409.329 716.701,409.384 716.71,409.439 716.719,409.494 716.728,409.549 716.737,409.603 716.747,409.658 716.756,409.713 716.765,409.768 716.774,409.823 716.783,409.877 716.792,409.932 716.802,409.987 716.811,410.042 716.82,410.096 716.829,410.151 716.838,410.206 716.848,410.261 716.857,410.315 716.866,410.37 716.875,410.425 716.884,410.48 716.894,410.534 716.903,410.589 716.912,410.644 716.921,410.698 716.93,410.753 716.939,410.808 716.949,410.862 716.958,410.917 716.967,410.971 716.976,411.026 716.985,411.081 716.995,411.135 717.004,411.19 717.013,411.245 717.022,411.299 717.031,411.354 717.041,411.408 717.05,411.463 717.059,411.517 717.068,411.572 717.077,411.626 717.087,411.681 717.096,411.735 717.105,411.79 717.114,411.844 717.123,411.899 717.132,411.953 717.142,412.008 717.151,412.062 717.16,412.117 717.169,412.171 717.178,412.226 717.188,412.28 717.197,412.335 717.206,412.389 717.215,412.443 717.224,412.498 717.234,412.552 717.243,412.607 717.252,412.661 717.261,412.715 717.27,412.77 717.279,412.824 717.289,412.879 717.298,412.933 717.307,412.987 717.316,413.042 717.325,413.096 717.335,413.15 717.344,413.204 717.353,413.259 717.362,413.313 717.371,413.367 717.381,413.422 717.39,413.476 717.399,413.53 717.408,413.584 717.417,413.639 717.427,413.693 717.436,413.747 717.445,413.801 717.454,413.855 717.463,413.91 717.472,413.964 717.482,414.018 717.491,414.072 717.5,414.126 717.509,414.181 717.518,414.235 717.528,414.289 717.537,414.343 717.546,414.397 717.555,414.451 717.564,414.505 717.574,414.559 717.583,414.614 717.592,414.668 717.601,414.722 717.61,414.776 717.619,414.83 717.629,414.884 717.638,414.938 717.647,414.992 717.656,415.046 717.665,415.1 717.675,415.154 717.684,415.208 717.693,415.262 717.702,415.316 717.711,415.37 717.721,415.424 717.73,415.478 717.739,415.532 717.748,415.586 717.757,415.64 717.767,415.694 717.776,415.748 717.785,415.802 717.794,415.856 717.803,415.909 717.812,415.963 717.822,416.017 717.831,416.071 717.84,416.125 717.849,416.179 717.858,416.233 717.868,416.286 717.877,416.34 717.886,416.394 717.895,416.448 717.904,416.502 717.914,416.556 717.923,416.609 717.932,416.663 717.941,416.717 717.95,416.771 717.959,416.824 717.969,416.878 717.978,416.932 717.987,416.986 717.996,417.039 718.005,417.093 718.015,417.147 718.024,417.201 718.033,417.254 718.042,417.308 718.051,417.362 718.061,417.415 718.07,417.469 718.079,417.523 718.088,417.576 718.097,417.63 718.107,417.684 718.116,417.737 718.125,417.791 718.134,417.844 718.143,417.898 718.152,417.952 718.162,418.005 718.171,418.059 718.18,418.112 718.189,418.166 718.198,418.219 718.208,418.273 718.217,418.326 718.226,418.38 718.235,418.433 718.244,418.487 718.254,418.54 718.263,418.594 718.272,418.647 718.281,418.701 718.29,418.754 718.299,418.808 718.309,418.861 718.318,418.915 718.327,418.968 718.336,419.022 718.345,419.075 718.355,419.128 718.364,419.182 718.373,419.235 718.382,419.289 718.391,419.342 718.401,419.395 718.41,419.449 718.419,419.502 718.428,419.555 718.437,419.609 718.447,419.662 718.456,419.715 718.465,419.769 718.474,419.822 718.483,419.875 718.492,419.929 718.502,419.982 718.511,420.035 718.52,420.088 718.529,420.142 718.538,420.195 718.548,420.248 718.557,420.301 718.566,420.354 718.575,420.408 718.584,420.461 718.594,420.514 718.603,420.567 718.612,420.62 718.621,420.674 718.63,420.727 718.64,420.78 718.649,420.833 718.658,420.886 718.667,420.939 718.676,420.992 718.685,421.046 718.695,421.099 718.704,421.152 718.713,421.205 718.722,421.258 718.731,421.311 718.741,421.364 718.75,421.417 718.759,421.47 718.768,421.523 718.777,421.576 718.787,421.629 718.796,421.682 718.805,421.735 718.814,421.788 718.823,421.841 718.832,421.894 718.842,421.947 718.851,422 718.86,422.053 718.869,422.106 718.878,422.159 718.888,422.212 718.897,422.265 718.906,422.318 718.915,422.37 718.924,422.423 718.934,422.476 718.943,422.529 718.952,422.582 718.961,422.635 718.97,422.688 718.98,422.74 718.989,422.793 718.998,422.846 719.007,422.899 719.016,422.952 719.025,423.005 719.035,423.057 719.044,423.11 719.053,423.163 719.062,423.216 719.071,423.268 719.081,423.321 719.09,423.374 719.099,423.427 719.108,423.479 719.117,423.532 719.127,423.585 719.136,423.637 719.145,423.69 719.154,423.743 719.163,423.795 719.172,423.848 719.182,423.901 719.191,423.953 719.2,424.006 719.209,424.059 719.218,424.111 719.228,424.164 719.237,424.216 719.246,424.269 719.255,424.322 719.264,424.374 719.274,424.427 719.283,424.479 719.292,424.532 719.301,424.584 719.31,424.637 719.32,424.689 719.329,424.742 719.338,424.794 719.347,424.847 719.356,424.899 719.365,424.952 719.375,425.004 719.384,425.057 719.393,425.109 719.402,425.162 719.411,425.214 719.421,425.267 719.43,425.319 719.439,425.371 719.448,425.424 719.457,425.476 719.467,425.529 719.476,425.581 719.485,425.633 719.494,425.686 719.503,425.738 719.512,425.79 719.522,425.843 719.531,425.895 719.54,425.947 719.549,426 719.558,426.052 719.568,426.104 719.577,426.156 719.586,426.209 719.595,426.261 719.604,426.313 719.614,426.365 719.623,426.418 719.632,426.47 719.641,426.522 719.65,426.574 719.66,426.627 719.669,426.679 719.678,426.731 719.687,426.783 719.696,426.835 719.705,426.887 719.715,426.94 719.724,426.992 719.733,427.044 719.742,427.096 719.751,427.148 719.761,427.2 719.77,427.252 719.779,427.304 719.788,427.356 719.797,427.409 719.807,427.461 719.816,427.513 719.825,427.565 719.834,427.617 719.843,427.669 719.852,427.721 719.862,427.773 719.871,427.825 719.88,427.877 719.889,427.929 719.898,427.981 719.908,428.033 719.917,428.085 719.926,428.137 719.935,428.189 719.944,428.24 719.954,428.292 719.963,428.344 719.972,428.396 719.981,428.448 719.99,428.5 720,428.552 720.009,428.604 720.018,428.656 720.027,428.707 720.036,428.759 720.045,428.811 720.055,428.863 720.064,428.915 720.073,428.967 720.082,429.018 720.091,429.07 720.101,429.122 720.11,429.174 720.119,429.226 720.128,429.277 720.137,429.329 720.147,429.381 720.156,429.432 720.165,429.484 720.174,429.536 720.183,429.588 720.192,429.639 720.202,429.691 720.211,429.743 720.22,429.794 720.229,429.846 720.238,429.898 720.248,429.949 720.257,430.001 720.266,430.053 720.275,430.104 720.284,430.156 720.294,430.207 720.303,430.259 720.312,430.311 720.321,430.362 720.33,430.414 720.34,430.465 720.349,430.517 720.358,430.568 720.367,430.62 720.376,430.671 720.385,430.723 720.395,430.774 720.404,430.826 720.413,430.877 720.422,430.929 720.431,430.98 720.441,431.032 720.45,431.083 720.459,431.135 720.468,431.186 720.477,431.237 720.487,431.289 720.496,431.34 720.505,431.392 720.514,431.443 720.523,431.494 720.532,431.546 720.542,431.597 720.551,431.649 720.56,431.7 720.569,431.751 720.578,431.803 720.588,431.854 720.597,431.905 720.606,431.956 720.615,432.008 720.624,432.059 720.634,432.11 720.643,432.162 720.652,432.213 720.661,432.264 720.67,432.315 720.68,432.366 720.689,432.418 720.698,432.469 720.707,432.52 720.716,432.571 720.725,432.622 720.735,432.674 720.744,432.725 720.753,432.776 720.762,432.827 720.771,432.878 720.781,432.929 720.79,432.98 720.799,433.032 720.808,433.083 720.817,433.134 720.827,433.185 720.836,433.236 720.845,433.287 720.854,433.338 720.863,433.389 720.872,433.44 720.882,433.491 720.891,433.542 720.9,433.593 720.909,433.644 720.918,433.695 720.928,433.746 720.937,433.797 720.946,433.848 720.955,433.899 720.964,433.95 720.974,434.001 720.983,434.052 720.992,434.103 721.001,434.154 721.01,434.205 721.02,434.256 721.029,434.306 721.038,434.357 721.047,434.408 721.056,434.459 721.065,434.51 721.075,434.561 721.084,434.612 721.093,434.662 721.102,434.713 721.111,434.764 721.121,434.815 721.13,434.866 721.139,434.916 721.148,434.967 721.157,435.018 721.167,435.069 721.176,435.119 721.185,435.17 721.194,435.221 721.203,435.272 721.213,435.322 721.222,435.373 721.231,435.424 721.24,435.474 721.249,435.525 721.258,435.576 721.268,435.626 721.277,435.677 721.286,435.728 721.295,435.778 721.304,435.829 721.314,435.879 721.323,435.93 721.332,435.981 721.341,436.031 721.35,436.082 721.36,436.132 721.369,436.183 721.378,436.233 721.387,436.284 721.396,436.334 721.405,436.385 721.415,436.435 721.424,436.486 721.433,436.536 721.442,436.587 721.451,436.637 721.461,436.688 721.47,436.738 721.479,436.789 721.488,436.839 721.497,436.89 721.507,436.94 721.516,436.99 721.525,437.041 721.534,437.091 721.543,437.142 721.553,437.192 721.562,437.242 721.571,437.293 721.58,437.343 721.589,437.393 721.598,437.444 721.608,437.494 721.617,437.544 721.626,437.595 721.635,437.645 721.644,437.695 721.654,437.745 721.663,437.796 721.672,437.846 721.681,437.896 721.69,437.946 721.7,437.997 721.709,438.047 721.718,438.097 721.727,438.147 721.736,438.197 721.745,438.248 721.755,438.298 721.764,438.348 721.773,438.398 721.782,438.448 721.791,438.498 721.801,438.548 721.81,438.599 721.819,438.649 721.828,438.699 721.837,438.749 721.847,438.799 721.856,438.849 721.865,438.899 721.874,438.949 721.883,438.999 721.893,439.049 721.902,439.099 721.911,439.149 721.92,439.199 721.929,439.249 721.938,439.299 721.948,439.349 721.957,439.399 721.966,439.449 721.975,439.499 721.984,439.549 721.994,439.599 722.003,439.649 722.012,439.699 722.021,439.749 722.03,439.799 722.04,439.848 722.049,439.898 722.058,439.948 722.067,439.998 722.076,440.048 722.085,440.098 722.095,440.148 722.104,440.197 722.113,440.247 722.122,440.297 722.131,440.347 722.141,440.397 722.15,440.446 722.159,440.496 722.168,440.546 722.177,440.596 722.187,440.645 722.196,440.695 722.205,440.745 722.214,440.795 722.223,440.844 722.233,440.894 722.242,440.944 722.251,440.993 722.26,441.043 722.269,441.093 722.278,441.142 722.288,441.192 722.297,441.242 722.306,441.291 722.315,441.341 722.324,441.39 722.334,441.44 722.343,441.49 722.352,441.539 722.361,441.589 722.37,441.638 722.38,441.688 722.389,441.737 722.398,441.787 722.407,441.836 722.416,441.886 722.425,441.935 722.435,441.985 722.444,442.034 722.453,442.084 722.462,442.133 722.471,442.183 722.481,442.232 722.49,442.282 722.499,442.331 722.508,442.38 722.517,442.43 722.527,442.479 722.536,442.529 722.545,442.578 722.554,442.627 722.563,442.677 722.573,442.726 722.582,442.775 722.591,442.825 722.6,442.874 722.609,442.923 722.618,442.973 722.628,443.022 722.637,443.071 722.646,443.121 722.655,443.17 722.664,443.219 722.674,443.268 722.683,443.318 722.692,443.367 722.701,443.416 722.71,443.465 722.72,443.514 722.729,443.564 722.738,443.613 722.747,443.662 722.756,443.711 722.765,443.76 722.775,443.809 722.784,443.859 722.793,443.908 722.802,443.957 722.811,444.006 722.821,444.055 722.83,444.104 722.839,444.153 722.848,444.202 722.857,444.251 722.867,444.3 722.876,444.349 722.885,444.398 722.894,444.447 722.903,444.496 722.913,444.545 722.922,444.594 722.931,444.643 722.94,444.692 722.949,444.741 722.958,444.79 722.968,444.839 722.977,444.888 722.986,444.937 722.995,444.986 723.004,445.035 723.014,445.084 723.023,445.133 723.032,445.182 723.041,445.231 723.05,445.279 723.06,445.328 723.069,445.377 723.078,445.426 723.087,445.475 723.096,445.524 723.105,445.572 723.115,445.621 723.124,445.67 723.133,445.719 723.142,445.768 723.151,445.816 723.161,445.865 723.17,445.914 723.179,445.963 723.188,446.011 723.197,446.06 723.207,446.109 723.216,446.157 723.225,446.206 723.234,446.255 723.243,446.303 723.253,446.352 723.262,446.401 723.271,446.449 723.28,446.498 723.289,446.547 723.298,446.595 723.308,446.644 723.317,446.692 723.326,446.741 723.335,446.79 723.344,446.838 723.354,446.887 723.363,446.935 723.372,446.984 723.381,447.032 723.39,447.081 723.4,447.129 723.409,447.178 723.418,447.226 723.427,447.275 723.436,447.323 723.446,447.372 723.455,447.42 723.464,447.469 723.473,447.517 723.482,447.565 723.491,447.614 723.501,447.662 723.51,447.711 723.519,447.759 723.528,447.807 723.537,447.856 723.547,447.904 723.556,447.953 723.565,448.001 723.574,448.049 723.583,448.098 723.593,448.146 723.602,448.194 723.611,448.242 723.62,448.291 723.629,448.339 723.638,448.387 723.648,448.435 723.657,448.484 723.666,448.532 723.675,448.58 723.684,448.628 723.694,448.677 723.703,448.725 723.712,448.773 723.721,448.821 723.73,448.869 723.74,448.918 723.749,448.966 723.758,449.014 723.767,449.062 723.776,449.11 723.786,449.158 723.795,449.206 723.804,449.254 723.813,449.302 723.822,449.351 723.831,449.399 723.841,449.447 723.85,449.495 723.859,449.543 723.868,449.591 723.877,449.639 723.887,449.687 723.896,449.735 723.905,449.783 723.914,449.831 723.923,449.879 723.933,449.927 723.942,449.975 723.951,450.023 723.96,450.07 723.969,450.118 723.978,450.166 723.988,450.214 723.997,450.262 724.006,450.31 724.015,450.358 724.024,450.406 724.034,450.454 724.043,450.501 724.052,450.549 724.061,450.597 724.07,450.645 724.08,450.693 724.089,450.741 724.098,450.788 724.107,450.836 724.116,450.884 724.126,450.932 724.135,450.979 724.144,451.027 724.153,451.075 724.162,451.123 724.171,451.17 724.181,451.218 724.19,451.266 724.199,451.313 724.208,451.361 724.217,451.409 724.227,451.456 724.236,451.504 724.245,451.552 724.254,451.599 724.263,451.647 724.273,451.694 724.282,451.742 724.291,451.79 724.3,451.837 724.309,451.885 724.318,451.932 724.328,451.98 724.337,452.027 724.346,452.075 724.355,452.123 724.364,452.17 724.374,452.218 724.383,452.265 724.392,452.313 724.401,452.36 724.41,452.407 724.42,452.455 724.429,452.502 724.438,452.55 724.447,452.597 724.456,452.645 724.466,452.692 724.475,452.739 724.484,452.787 724.493,452.834 724.502,452.882 724.511,452.929 724.521,452.976 724.53,453.024 724.539,453.071 724.548,453.118 724.557,453.166 724.567,453.213 724.576,453.26 724.585,453.307 724.594,453.355 724.603,453.402 724.613,453.449 724.622,453.497 724.631,453.544 724.64,453.591 724.649,453.638 724.658,453.685 724.668,453.733 724.677,453.78 724.686,453.827 724.695,453.874 724.704,453.921 724.714,453.968 724.723,454.016 724.732,454.063 724.741,454.11 724.75,454.157 724.76,454.204 724.769,454.251 724.778,454.298 724.787,454.345 724.796,454.392 724.806,454.439 724.815,454.486 724.824,454.534 724.833,454.581 724.842,454.628 724.851,454.675 724.861,454.722 724.87,454.769 724.879,454.816 724.888,454.862 724.897,454.909 724.907,454.956 724.916,455.003 724.925,455.05 724.934,455.097 724.943,455.144 724.953,455.191 724.962,455.238 724.971,455.285 724.98,455.332 724.989,455.378 724.998,455.425 725.008,455.472 725.017,455.519 725.026,455.566 725.035,455.613 725.044,455.659 725.054,455.706 725.063,455.753 725.072,455.8 725.081,455.847 725.09,455.893 725.1,455.94 725.109,455.987 725.118,456.034 725.127,456.08 725.136,456.127 725.146,456.174 725.155,456.22 725.164,456.267 725.173,456.314 725.182,456.36 725.191,456.407 725.201,456.454 725.21,456.5 725.219,456.547 725.228,456.594 725.237,456.64 725.247,456.687 725.256,456.733 725.265,456.78 725.274,456.826 725.283,456.873 725.293,456.92 725.302,456.966 725.311,457.013 725.32,457.059 725.329,457.106 725.338,457.152 725.348,457.199 725.357,457.245 725.366,457.292 725.375,457.338 725.384,457.384 725.394,457.431 725.403,457.477 725.412,457.524 725.421,457.57 725.43,457.617 725.44,457.663 725.449,457.709 725.458,457.756 725.467,457.802 725.476,457.848 725.486,457.895 725.495,457.941 725.504,457.987 725.513,458.034 725.522,458.08 725.531,458.126 725.541,458.173 725.55,458.219 725.559,458.265 725.568,458.311 725.577,458.358 725.587,458.404 725.596,458.45 725.605,458.496 725.614,458.542 725.623,458.589 725.633,458.635 725.642,458.681 725.651,458.727 725.66,458.773 725.669,458.82 725.678,458.866 725.688,458.912 725.697,458.958 725.706,459.004 725.715,459.05 725.724,459.096 725.734,459.142 725.743,459.188 725.752,459.234 725.761,459.28 725.77,459.326 725.78,459.373 725.789,459.419 725.798,459.465 725.807,459.511 725.816,459.557 725.826,459.603 725.835,459.649 725.844,459.694 725.853,459.74 725.862,459.786 725.871,459.832 725.881,459.878 725.89,459.924 725.899,459.97 725.908,460.016 725.917,460.062 725.927,460.108 725.936,460.154 725.945,460.199 725.954,460.245 725.963,460.291 725.973,460.337 725.982,460.383 725.991,460.429 726,460.474 726.009,460.52 726.019,460.566 726.028,460.612 726.037,460.657 726.046,460.703 726.055,460.749 726.064,460.795 726.074,460.84 726.083,460.886 726.092,460.932 726.101,460.978 726.11,461.023 726.12,461.069 726.129,461.115 726.138,461.16 726.147,461.206 726.156,461.251 726.166,461.297 726.175,461.343 726.184,461.388 726.193,461.434 726.202,461.479 726.211,461.525 726.221,461.571 726.23,461.616 726.239,461.662 726.248,461.707 726.257,461.753 726.267,461.798 726.276,461.844 726.285,461.889 726.294,461.935 726.303,461.98 726.313,462.026 726.322,462.071 726.331,462.117 726.34,462.162 726.349,462.208 726.359,462.253 726.368,462.298 726.377,462.344 726.386,462.389 726.395,462.435 726.404,462.48 726.414,462.525 726.423,462.571 726.432,462.616 726.441,462.661 726.45,462.707 726.46,462.752 726.469,462.797 726.478,462.843 726.487,462.888 726.496,462.933 726.506,462.978 726.515,463.024 726.524,463.069 726.533,463.114 726.542,463.159 726.551,463.205 726.561,463.25 726.57,463.295 726.579,463.34 726.588,463.385 726.597,463.43 726.607,463.476 726.616,463.521 726.625,463.566 726.634,463.611 726.643,463.656 726.653,463.701 726.662,463.746 726.671,463.791 726.68,463.837 726.689,463.882 726.699,463.927 726.708,463.972 726.717,464.017 726.726,464.062 726.735,464.107 726.744,464.152 726.754,464.197 726.763,464.242 726.772,464.287 726.781,464.332 726.79,464.377 726.8,464.422 726.809,464.467 726.818,464.512 726.827,464.556 726.836,464.601 726.846,464.646 726.855,464.691 726.864,464.736 726.873,464.781 726.882,464.826 726.891,464.871 726.901,464.915 726.91,464.96 726.919,465.005 726.928,465.05 726.937,465.095 726.947,465.14 726.956,465.184 726.965,465.229 726.974,465.274 726.983,465.319 726.993,465.363 727.002,465.408 727.011,465.453 727.02,465.498 727.029,465.542 727.039,465.587 727.048,465.632 727.057,465.676 727.066,465.721 727.075,465.766 727.084,465.81 727.094,465.855 727.103,465.9 727.112,465.944 727.121,465.989 727.13,466.033 727.14,466.078 727.149,466.123 727.158,466.167 727.167,466.212 727.176,466.256 727.186,466.301 727.195,466.345 727.204,466.39 727.213,466.434 727.222,466.479 727.231,466.523 727.241,466.568 727.25,466.612 727.259,466.657 727.268,466.701 727.277,466.746 727.287,466.79 727.296,466.835 727.305,466.879 727.314,466.923 727.323,466.968 727.333,467.012 727.342,467.057 727.351,467.101 727.36,467.145 727.369,467.19 727.379,467.234 727.388,467.278 727.397,467.323 727.406,467.367 727.415,467.411 727.424,467.455 727.434,467.5 727.443,467.544 727.452,467.588 727.461,467.633 727.47,467.677 727.48,467.721 727.489,467.765 727.498,467.809 727.507,467.854 727.516,467.898 727.526,467.942 727.535,467.986 727.544,468.03 727.553,468.074 727.562,468.119 727.571,468.163 727.581,468.207 727.59,468.251 727.599,468.295 727.608,468.339 727.617,468.383 727.627,468.427 727.636,468.471 727.645,468.515 727.654,468.559 727.663,468.604 727.673,468.648 727.682,468.692 727.691,468.736 727.7,468.78 727.709,468.824 727.719,468.868 727.728,468.911 727.737,468.955 727.746,468.999 727.755,469.043 727.764,469.087 727.774,469.131 727.783,469.175 727.792,469.219 727.801,469.263 727.81,469.307 727.82,469.351 727.829,469.394 727.838,469.438 727.847,469.482 727.856,469.526 727.866,469.57 727.875,469.614 727.884,469.657 727.893,469.701 727.902,469.745 727.911,469.789 727.921,469.832 727.93,469.876 727.939,469.92 727.948,469.964 727.957,470.007 727.967,470.051 727.976,470.095 727.985,470.138 727.994,470.182 728.003,470.226 728.013,470.269 728.022,470.313 728.031,470.357 728.04,470.4 728.049,470.444 728.059,470.488 728.068,470.531 728.077,470.575 728.086,470.618 728.095,470.662 728.104,470.706 728.114,470.749 728.123,470.793 728.132,470.836 728.141,470.88 728.15,470.923 728.16,470.967 728.169,471.01 728.178,471.054 728.187,471.097 728.196,471.141 728.206,471.184 728.215,471.228 728.224,471.271 728.233,471.314 728.242,471.358 728.251,471.401 728.261,471.445 728.27,471.488 728.279,471.531 728.288,471.575 728.297,471.618 728.307,471.661 728.316,471.705 728.325,471.748 728.334,471.791 728.343,471.835 728.353,471.878 728.362,471.921 728.371,471.965 728.38,472.008 728.389,472.051 728.399,472.094 728.408,472.138 728.417,472.181 728.426,472.224 728.435,472.267 728.444,472.31 728.454,472.354 728.463,472.397 728.472,472.44 728.481,472.483 728.49,472.526 728.5,472.569 728.509,472.613 728.518,472.656 728.527,472.699 728.536,472.742 728.546,472.785 728.555,472.828 728.564,472.871 728.573,472.914 728.582,472.957 728.592,473 728.601,473.043 728.61,473.086 728.619,473.129 728.628,473.172 728.637,473.215 728.647,473.258 728.656,473.301 728.665,473.344 728.674,473.387 728.683,473.43 728.693,473.473 728.702,473.516 728.711,473.559 728.72,473.602 728.729,473.645 728.739,473.688 728.748,473.73 728.757,473.773 728.766,473.816 728.775,473.859 728.784,473.902 728.794,473.945 728.803,473.988 728.812,474.03 728.821,474.073 728.83,474.116 728.84,474.159 728.849,474.201 728.858,474.244 728.867,474.287 728.876,474.33 728.886,474.372 728.895,474.415 728.904,474.458 728.913,474.501 728.922,474.543 728.932,474.586 728.941,474.629 728.95,474.671 728.959,474.714 728.968,474.757 728.977,474.799 728.987,474.842 728.996,474.884 729.005,474.927 729.014,474.97 729.023,475.012 729.033,475.055 729.042,475.097 729.051,475.14 729.06,475.182 729.069,475.225 729.079,475.267 729.088,475.31 729.097,475.352 729.106,475.395 729.115,475.437 729.124,475.48 729.134,475.522 729.143,475.565 729.152,475.607 729.161,475.65 729.17,475.692 729.18,475.734 729.189,475.777 729.198,475.819 729.207,475.862 729.216,475.904 729.226,475.946 729.235,475.989 729.244,476.031 729.253,476.073 729.262,476.116 729.272,476.158 729.281,476.2 729.29,476.243 729.299,476.285 729.308,476.327 729.317,476.369 729.327,476.412 729.336,476.454 729.345,476.496 729.354,476.538 729.363,476.581 729.373,476.623 729.382,476.665 729.391,476.707 729.4,476.749 729.409,476.792 729.419,476.834 729.428,476.876 729.437,476.918 729.446,476.96 729.455,477.002 729.464,477.044 729.474,477.086 729.483,477.129 729.492,477.171 729.501,477.213 729.51,477.255 729.52,477.297 729.529,477.339 729.538,477.381 729.547,477.423 729.556,477.465 729.566,477.507 729.575,477.549 729.584,477.591 729.593,477.633 729.602,477.675 729.612,477.717 729.621,477.759 729.63,477.801 729.639,477.843 729.648,477.884 729.657,477.926 729.667,477.968 729.676,478.01 729.685,478.052 729.694,478.094 729.703,478.136 729.713,478.178 729.722,478.219 729.731,478.261 729.74,478.303 729.749,478.345 729.759,478.387 729.768,478.428 729.777,478.47 729.786,478.512 729.795,478.554 729.804,478.595 729.814,478.637 729.823,478.679 729.832,478.721 729.841,478.762 729.85,478.804 729.86,478.846 729.869,478.887 729.878,478.929 729.887,478.971 729.896,479.012 729.906,479.054 729.915,479.096 729.924,479.137 729.933,479.179 729.942,479.22 729.952,479.262 729.961,479.304 729.97,479.345 729.979,479.387 729.988,479.428 729.997,479.47 730.007,479.511 730.016,479.553 730.025,479.594 730.034,479.636 730.043,479.677 730.053,479.719 730.062,479.76 730.071,479.802 730.08,479.843 730.089,479.885 730.099,479.926 730.108,479.967 730.117,480.009 730.126,480.05 730.135,480.092 730.144,480.133 730.154,480.174 730.163,480.216 730.172,480.257 730.181,480.298 730.19,480.34 730.2,480.381 730.209,480.422 730.218,480.464 730.227,480.505 730.236,480.546 730.246,480.588 730.255,480.629 730.264,480.67 730.273,480.711 730.282,480.753 730.292,480.794 730.301,480.835 730.31,480.876 730.319,480.917 730.328,480.959 730.337,481 730.347,481.041 730.356,481.082 730.365,481.123 730.374,481.164 730.383,481.205 730.393,481.247 730.402,481.288 730.411,481.329 730.42,481.37 730.429,481.411 730.439,481.452 730.448,481.493 730.457,481.534 730.466,481.575 730.475,481.616 730.484,481.657 730.494,481.698 730.503,481.739 730.512,481.78 730.521,481.821 730.53,481.862 730.54,481.903 730.549,481.944 730.558,481.985 730.567,482.026 730.576,482.067 730.586,482.108 730.595,482.149 730.604,482.19 730.613,482.23 730.622,482.271 730.632,482.312 730.641,482.353 730.65,482.394 730.659,482.435 730.668,482.475 730.677,482.516 730.687,482.557 730.696,482.598 730.705,482.639 730.714,482.679 730.723,482.72 730.733,482.761 730.742,482.802 730.751,482.842 730.76,482.883 730.769,482.924 730.779,482.965 730.788,483.005 730.797,483.046 730.806,483.087 730.815,483.127 730.825,483.168 730.834,483.209 730.843,483.249 730.852,483.29 730.861,483.33 730.87,483.371 730.88,483.412 730.889,483.452 730.898,483.493 730.907,483.533 730.916,483.574 730.926,483.614 730.935,483.655 730.944,483.695 730.953,483.736 730.962,483.777 730.972,483.817 730.981,483.857 730.99,483.898 730.999,483.938 731.008,483.979 731.017,484.019 731.027,484.06 731.036,484.1 731.045,484.141 731.054,484.181 731.063,484.221 731.073,484.262 731.082,484.302 731.091,484.343 731.1,484.383 731.109,484.423 731.119,484.464 731.128,484.504 731.137,484.544 731.146,484.585 731.155,484.625 731.165,484.665 731.174,484.705 731.183,484.746 731.192,484.786 731.201,484.826 731.21,484.866 731.22,484.907 731.229,484.947 731.238,484.987 731.247,485.027 731.256,485.068 731.266,485.108 731.275,485.148 731.284,485.188 731.293,485.228 731.302,485.268 731.312,485.308 731.321,485.349 731.33,485.389 731.339,485.429 731.348,485.469 731.357,485.509 731.367,485.549 731.376,485.589 731.385,485.629 731.394,485.669 731.403,485.709 731.413,485.749 731.422,485.789 731.431,485.829 731.44,485.869 731.449,485.909 731.459,485.949 731.468,485.989 731.477,486.029 731.486,486.069 731.495,486.109 731.505,486.149 731.514,486.189 731.523,486.229 731.532,486.269 731.541,486.309 731.55,486.349 731.56,486.388 731.569,486.428 731.578,486.468 731.587,486.508 731.596,486.548 731.606,486.588 731.615,486.627 731.624,486.667 731.633,486.707 731.642,486.747 731.652,486.787 731.661,486.826 731.67,486.866 731.679,486.906 731.688,486.946 731.697,486.985 731.707,487.025 731.716,487.065 731.725,487.104 731.734,487.144 731.743,487.184 731.753,487.223 731.762,487.263 731.771,487.303 731.78,487.342 731.789,487.382 731.799,487.422 731.808,487.461 731.817,487.501 731.826,487.54 731.835,487.58 731.845,487.619 731.854,487.659 731.863,487.699 731.872,487.738 731.881,487.778 731.89,487.817 731.9,487.857 731.909,487.896 731.918,487.936 731.927,487.975 731.936,488.015 731.946,488.054 731.955,488.093 731.964,488.133 731.973,488.172 731.982,488.212 731.992,488.251 732.001,488.291 732.01,488.33 732.019,488.369 732.028,488.409 732.037,488.448 732.047,488.487 732.056,488.527 732.065,488.566 732.074,488.605 732.083,488.645 732.093,488.684 732.102,488.723 732.111,488.763 732.12,488.802 732.129,488.841 732.139,488.88 732.148,488.92 732.157,488.959 732.166,488.998 732.175,489.037 732.185,489.077 732.194,489.116 732.203,489.155 732.212,489.194 732.221,489.233 732.23,489.272 732.24,489.312 732.249,489.351 732.258,489.39 732.267,489.429 732.276,489.468 732.286,489.507 732.295,489.546 732.304,489.585 732.313,489.624 732.322,489.663 732.332,489.702 732.341,489.741 732.35,489.781 732.359,489.82 732.368,489.859 732.377,489.898 732.387,489.937 732.396,489.976 732.405,490.014 732.414,490.053 732.423,490.092 732.433,490.131 732.442,490.17 732.451,490.209 732.46,490.248 732.469,490.287 732.479,490.326 732.488,490.365 732.497,490.404 732.506,490.443 732.515,490.481 732.525,490.52 732.534,490.559 732.543,490.598 732.552,490.637 732.561,490.675 732.57,490.714 732.58,490.753 732.589,490.792 732.598,490.831 732.607,490.869 732.616,490.908 732.626,490.947 732.635,490.986 732.644,491.024 732.653,491.063 732.662,491.102 732.672,491.14 732.681,491.179 732.69,491.218 732.699,491.256 732.708,491.295 732.717,491.334 732.727,491.372 732.736,491.411 732.745,491.45 732.754,491.488 732.763,491.527 732.773,491.565 732.782,491.604 732.791,491.642 732.8,491.681 732.809,491.72 732.819,491.758 732.828,491.797 732.837,491.835 732.846,491.874 732.855,491.912 732.865,491.951 732.874,491.989 732.883,492.028 732.892,492.066 732.901,492.104 732.91,492.143 732.92,492.181 732.929,492.22 732.938,492.258 732.947,492.297 732.956,492.335 732.966,492.373 732.975,492.412 732.984,492.45 732.993,492.488 733.002,492.527 733.012,492.565 733.021,492.603 733.03,492.642 733.039,492.68 733.048,492.718 733.057,492.756 733.067,492.795 733.076,492.833 733.085,492.871 733.094,492.91 733.103,492.948 733.113,492.986 733.122,493.024 733.131,493.062 733.14,493.101 733.149,493.139 733.159,493.177 733.168,493.215 733.177,493.253 733.186,493.291 733.195,493.33 733.205,493.368 733.214,493.406 733.223,493.444 733.232,493.482 733.241,493.52 733.25,493.558 733.26,493.596 733.269,493.634 733.278,493.672 733.287,493.71 733.296,493.748 733.306,493.786 733.315,493.824 733.324,493.862 733.333,493.9 733.342,493.938 733.352,493.976 733.361,494.014 733.37,494.052 733.379,494.09 733.388,494.128 733.398,494.166 733.407,494.204 733.416,494.242 733.425,494.28 733.434,494.318 733.443,494.355 733.453,494.393 733.462,494.431 733.471,494.469 733.48,494.507 733.489,494.545 733.499,494.583 733.508,494.62 733.517,494.658 733.526,494.696 733.535,494.734 733.545,494.771 733.554,494.809 733.563,494.847 733.572,494.885 733.581,494.922 733.59,494.96 733.6,494.998 733.609,495.036 733.618,495.073 733.627,495.111 733.636,495.149 733.646,495.186 733.655,495.224 733.664,495.262 733.673,495.299 733.682,495.337 733.692,495.374 733.701,495.412 733.71,495.45 733.719,495.487 733.728,495.525 733.738,495.562 733.747,495.6 733.756,495.637 733.765,495.675 733.774,495.712 733.783,495.75 733.793,495.787 733.802,495.825 733.811,495.862 733.82,495.9 733.829,495.937 733.839,495.975 733.848,496.012 733.857,496.05 733.866,496.087 733.875,496.125 733.885,496.162 733.894,496.199 733.903,496.237 733.912,496.274 733.921,496.312 733.93,496.349 733.94,496.386 733.949,496.424 733.958,496.461 733.967,496.498 733.976,496.536 733.986,496.573 733.995,496.61 734.004,496.647 734.013,496.685 734.022,496.722 734.032,496.759 734.041,496.796 734.05,496.834 734.059,496.871 734.068,496.908 734.078,496.945 734.087,496.983 734.096,497.02 734.105,497.057 734.114,497.094 734.123,497.131 734.133,497.168 734.142,497.206 734.151,497.243 734.16,497.28 734.169,497.317 734.179,497.354 734.188,497.391 734.197,497.428 734.206,497.465 734.215,497.502 734.225,497.539 734.234,497.576 734.243,497.613 734.252,497.65 734.261,497.687 734.27,497.724 734.28,497.761 734.289,497.798 734.298,497.835 734.307,497.872 734.316,497.909 734.326,497.946 734.335,497.983 734.344,498.02 734.353,498.057 734.362,498.094 734.372,498.131 734.381,498.168 734.39,498.205 734.399,498.242 734.408,498.278 734.418,498.315 734.427,498.352 734.436,498.389 734.445,498.426 734.454,498.463 734.463,498.499 734.473,498.536 734.482,498.573 734.491,498.61 734.5,498.646 734.509,498.683 734.519,498.72 734.528,498.757 734.537,498.793 734.546,498.83 734.555,498.867 734.565,498.904 734.574,498.94 734.583,498.977 734.592,499.014 734.601,499.05 734.61,499.087 734.62,499.124 734.629,499.16 734.638,499.197 734.647,499.233 734.656,499.27 734.666,499.307 734.675,499.343 734.684,499.38 734.693,499.416 734.702,499.453 734.712,499.489 734.721,499.526 734.73,499.562 734.739,499.599 734.748,499.635 734.758,499.672 734.767,499.708 734.776,499.745 734.785,499.781 734.794,499.818 734.803,499.854 734.813,499.891 734.822,499.927 734.831,499.964 734.84,500 734.849,500.036 734.859,500.073 734.868,500.109 734.877,500.146 734.886,500.182 734.895,500.218 734.905,500.255 734.914,500.291 734.923,500.327 734.932,500.364 734.941,500.4 734.95,500.436 734.96,500.472 734.969,500.509 734.978,500.545 734.987,500.581 734.996,500.618 735.006,500.654 735.015,500.69 735.024,500.726 735.033,500.762 735.042,500.799 735.052,500.835 735.061,500.871 735.07,500.907 735.079,500.943 735.088,500.979 735.098,501.016 735.107,501.052 735.116,501.088 735.125,501.124 735.134,501.16 735.143,501.196 735.153,501.232 735.162,501.268 735.171,501.304 735.18,501.34 735.189,501.377 735.199,501.413 735.208,501.449 735.217,501.485 735.226,501.521 735.235,501.557 735.245,501.593 735.254,501.629 735.263,501.665 735.272,501.701 735.281,501.736 735.29,501.772 735.3,501.808 735.309,501.844 735.318,501.88 735.327,501.916 735.336,501.952 735.346,501.988 735.355,502.024 735.364,502.06 735.373,502.095 735.382,502.131 735.392,502.167 735.401,502.203 735.41,502.239 735.419,502.275 735.428,502.31 735.438,502.346 735.447,502.382 735.456,502.418 735.465,502.454 735.474,502.489 735.483,502.525 735.493,502.561 735.502,502.597 735.511,502.632 735.52,502.668 735.529,502.704 735.539,502.739 735.548,502.775 735.557,502.811 735.566,502.846 735.575,502.882 735.585,502.918 735.594,502.953 735.603,502.989 735.612,503.024 735.621,503.06 735.63,503.096 735.64,503.131 735.649,503.167 735.658,503.202 735.667,503.238 735.676,503.273 735.686,503.309 735.695,503.345 735.704,503.38 735.713,503.416 735.722,503.451 735.732,503.487 735.741,503.522 735.75,503.557 735.759,503.593 735.768,503.628 735.778,503.664 735.787,503.699 735.796,503.735 735.805,503.77 735.814,503.805 735.823,503.841 735.833,503.876 735.842,503.912 735.851,503.947 735.86,503.982 735.869,504.018 735.879,504.053 735.888,504.088 735.897,504.124 735.906,504.159 735.915,504.194 735.925,504.23 735.934,504.265 735.943,504.3 735.952,504.335 735.961,504.371 735.971,504.406 735.98,504.441 735.989,504.476 735.998,504.512 736.007,504.547 736.016,504.582 736.026,504.617 736.035,504.652 736.044,504.687 736.053,504.723 736.062,504.758 736.072,504.793 736.081,504.828 736.09,504.863 736.099,504.898 736.108,504.933 736.118,504.968 736.127,505.004 736.136,505.039 736.145,505.074 736.154,505.109 736.163,505.144 736.173,505.179 736.182,505.214 736.191,505.249 736.2,505.284 736.209,505.319 736.219,505.354 736.228,505.389 736.237,505.424 736.246,505.459 736.255,505.494 736.265,505.529 736.274,505.564 736.283,505.598 736.292,505.633 736.301,505.668 736.311,505.703 736.32,505.738 736.329,505.773 736.338,505.808 736.347,505.843 736.356,505.878 736.366,505.912 736.375,505.947 736.384,505.982 736.393,506.017 736.402,506.052 736.412,506.086 736.421,506.121 736.43,506.156 736.439,506.191 736.448,506.225 736.458,506.26 736.467,506.295 736.476,506.33 736.485,506.364 736.494,506.399 736.503,506.434 736.513,506.468 736.522,506.503 736.531,506.538 736.54,506.572 736.549,506.607 736.559,506.642 736.568,506.676 736.577,506.711 736.586,506.746 736.595,506.78 736.605,506.815 736.614,506.849 736.623,506.884 736.632,506.919 736.641,506.953 736.651,506.988 736.66,507.022 736.669,507.057 736.678,507.091 736.687,507.126 736.696,507.16 736.706,507.195 736.715,507.229 736.724,507.264 736.733,507.298 736.742,507.333 736.752,507.367 736.761,507.401 736.77,507.436 736.779,507.47 736.788,507.505 736.798,507.539 736.807,507.573 736.816,507.608 736.825,507.642 736.834,507.677 736.843,507.711 736.853,507.745 736.862,507.78 736.871,507.814 736.88,507.848 736.889,507.883 736.899,507.917 736.908,507.951 736.917,507.985 736.926,508.02 736.935,508.054 736.945,508.088 736.954,508.122 736.963,508.157 736.972,508.191 736.981,508.225 736.991,508.259 737,508.293 737.009,508.328 737.018,508.362 737.027,508.396 737.036,508.43 737.046,508.464 737.055,508.498 737.064,508.532 737.073,508.567 737.082,508.601 737.092,508.635 737.101,508.669 737.11,508.703 737.119,508.737 737.128,508.771 737.138,508.805 737.147,508.839 737.156,508.873 737.165,508.907 737.174,508.941 737.183,508.975 737.193,509.009 737.202,509.043 737.211,509.077 737.22,509.111 737.229,509.145 737.239,509.179 737.248,509.213 737.257,509.247 737.266,509.281 737.275,509.315 737.285,509.349 737.294,509.383 737.303,509.416 737.312,509.45 737.321,509.484 737.331,509.518 737.34,509.552 737.349,509.586 737.358,509.62 737.367,509.653 737.376,509.687 737.386,509.721 737.395,509.755 737.404,509.789 737.413,509.822 737.422,509.856 737.432,509.89 737.441,509.924 737.45,509.957 737.459,509.991 737.468,510.025 737.478,510.058 737.487,510.092 737.496,510.126 737.505,510.16 737.514,510.193 737.523,510.227 737.533,510.261 737.542,510.294 737.551,510.328 737.56,510.361 737.569,510.395 737.579,510.429 737.588,510.462 737.597,510.496 737.606,510.529 737.615,510.563 737.625,510.597 737.634,510.63 737.643,510.664 737.652,510.697 737.661,510.731 737.671,510.764 737.68,510.798 737.689,510.831 737.698,510.865 737.707,510.898 737.716,510.932 737.726,510.965 737.735,510.999 737.744,511.032 737.753,511.065 737.762,511.099 737.772,511.132 737.781,511.166 737.79,511.199 737.799,511.232 737.808,511.266 737.818,511.299 737.827,511.332 737.836,511.366 737.845,511.399 737.854,511.433 737.863,511.466 737.873,511.499 737.882,511.532 737.891,511.566 737.9,511.599 737.909,511.632 737.919,511.666 737.928,511.699 737.937,511.732 737.946,511.765 737.955,511.799 737.965,511.832 737.974,511.865 737.983,511.898 737.992,511.931 738.001,511.965 738.011,511.998 738.02,512.031 738.029,512.064 738.038,512.097 738.047,512.13 738.056,512.163 738.066,512.197 738.075,512.23 738.084,512.263 738.093,512.296 738.102,512.329 738.112,512.362 738.121,512.395 738.13,512.428 738.139,512.461 738.148,512.494 738.158,512.527 738.167,512.56 738.176,512.593 738.185,512.626 738.194,512.659 738.204,512.692 738.213,512.725 738.222,512.758 738.231,512.791 738.24,512.824 738.249,512.857 738.259,512.89 738.268,512.923 738.277,512.956 738.286,512.989 738.295,513.021 738.305,513.054 738.314,513.087 738.323,513.12 738.332,513.153 738.341,513.186 738.351,513.219 738.36,513.251 738.369,513.284 738.378,513.317 738.387,513.35 738.396,513.383 738.406,513.415 738.415,513.448 738.424,513.481 738.433,513.514 738.442,513.546 738.452,513.579 738.461,513.612 738.47,513.645 738.479,513.677 738.488,513.71 738.498,513.743 738.507,513.775 738.516,513.808 738.525,513.841 738.534,513.873 738.544,513.906 738.553,513.939 738.562,513.971 738.571,514.004 738.58,514.036 738.589,514.069 738.599,514.102 738.608,514.134 738.617,514.167 738.626,514.199 738.635,514.232 738.645,514.264 738.654,514.297 738.663,514.329 738.672,514.362 738.681,514.394 738.691,514.427 738.7,514.459 738.709,514.492 738.718,514.524 738.727,514.557 738.736,514.589 738.746,514.622 738.755,514.654 738.764,514.687 738.773,514.719 738.782,514.751 738.792,514.784 738.801,514.816 738.81,514.849 738.819,514.881 738.828,514.913 738.838,514.946 738.847,514.978 738.856,515.01 738.865,515.043 738.874,515.075 738.884,515.107 738.893,515.14 738.902,515.172 738.911,515.204 738.92,515.236 738.929,515.269 738.939,515.301 738.948,515.333 738.957,515.365 738.966,515.398 738.975,515.43 738.985,515.462 738.994,515.494 739.003,515.526 739.012,515.559 739.021,515.591 739.031,515.623 739.04,515.655 739.049,515.687 739.058,515.719 739.067,515.751 739.076,515.784 739.086,515.816 739.095,515.848 739.104,515.88 739.113,515.912 739.122,515.944 739.132,515.976 739.141,516.008 739.15,516.04 739.159,516.072 739.168,516.104 739.178,516.136 739.187,516.168 739.196,516.2 739.205,516.232 739.214,516.264 739.224,516.296 739.233,516.328 739.242,516.36 739.251,516.392 739.26,516.424 739.269,516.456 739.279,516.488 739.288,516.52 739.297,516.552 739.306,516.583 739.315,516.615 739.325,516.647 739.334,516.679 739.343,516.711 739.352,516.743 739.361,516.775 739.371,516.806 739.38,516.838 739.389,516.87 739.398,516.902 739.407,516.934 739.416,516.965 739.426,516.997 739.435,517.029 739.444,517.061 739.453,517.092 739.462,517.124 739.472,517.156 739.481,517.188 739.49,517.219 739.499,517.251 739.508,517.283 739.518,517.314 739.527,517.346 739.536,517.378 739.545,517.409 739.554,517.441 739.564,517.473 739.573,517.504 739.582,517.536 739.591,517.568 739.6,517.599 739.609,517.631 739.619,517.662 739.628,517.694 739.637,517.725 739.646,517.757 739.655,517.789 739.665,517.82 739.674,517.852 739.683,517.883 739.692,517.915 739.701,517.946 739.711,517.978 739.72,518.009 739.729,518.041 739.738,518.072 739.747,518.103 739.756,518.135 739.766,518.166 739.775,518.198 739.784,518.229 739.793,518.261 739.802,518.292 739.812,518.323 739.821,518.355 739.83,518.386 739.839,518.418 739.848,518.449 739.858,518.48 739.867,518.512 739.876,518.543 739.885,518.574 739.894,518.606 739.904,518.637 739.913,518.668 739.922,518.699 739.931,518.731 739.94,518.762 739.949,518.793 739.959,518.825 739.968,518.856 739.977,518.887 739.986,518.918 739.995,518.949 740.005,518.981 740.014,519.012 740.023,519.043 740.032,519.074 740.041,519.105 740.051,519.137 740.06,519.168 740.069,519.199 740.078,519.23 740.087,519.261 740.096,519.292 740.106,519.323 740.115,519.354 740.124,519.386 740.133,519.417 740.142,519.448 740.152,519.479 740.161,519.51 740.17,519.541 740.179,519.572 740.188,519.603 740.198,519.634 740.207,519.665 740.216,519.696 740.225,519.727 740.234,519.758 740.244,519.789 740.253,519.82 740.262,519.851 740.271,519.882 740.28,519.913 740.289,519.944 740.299,519.975 740.308,520.006 740.317,520.036 740.326,520.067 740.335,520.098 740.345,520.129 740.354,520.16 740.363,520.191 740.372,520.222 740.381,520.252 740.391,520.283 740.4,520.314 740.409,520.345 740.418,520.376 740.427,520.407 740.436,520.437 740.446,520.468 740.455,520.499 740.464,520.53 740.473,520.56 740.482,520.591 740.492,520.622 740.501,520.653 740.51,520.683 740.519,520.714 740.528,520.745 740.538,520.775 740.547,520.806 740.556,520.837 740.565,520.867 740.574,520.898 740.584,520.929 740.593,520.959 740.602,520.99 740.611,521.021 740.62,521.051 740.629,521.082 740.639,521.113 740.648,521.143 740.657,521.174 740.666,521.204 740.675,521.235 740.685,521.265 740.694,521.296 740.703,521.326 740.712,521.357 740.721,521.387 740.731,521.418 740.74,521.448 740.749,521.479 740.758,521.509 740.767,521.54 740.777,521.57 740.786,521.601 740.795,521.631 740.804,521.662 740.813,521.692 740.822,521.723 740.832,521.753 740.841,521.783 740.85,521.814 740.859,521.844 740.868,521.875 740.878,521.905 740.887,521.935 740.896,521.966 740.905,521.996 740.914,522.026 740.924,522.057 740.933,522.087 740.942,522.117 740.951,522.148 740.96,522.178 740.969,522.208 740.979,522.238 740.988,522.269 740.997,522.299 741.006,522.329 741.015,522.359 741.025,522.39 741.034,522.42 741.043,522.45 741.052,522.48 741.061,522.51 741.071,522.541 741.08,522.571 741.089,522.601 741.098,522.631 741.107,522.661 741.117,522.691 741.126,522.722 741.135,522.752 741.144,522.782 741.153,522.812 741.162,522.842 741.172,522.872 741.181,522.902 741.19,522.932 741.199,522.962 741.208,522.992 741.218,523.022 741.227,523.052 741.236,523.082 741.245,523.112 741.254,523.142 741.264,523.172 741.273,523.202 741.282,523.232 741.291,523.262 741.3,523.292 741.309,523.322 741.319,523.352 741.328,523.382 741.337,523.412 741.346,523.442 741.355,523.472 741.365,523.502 741.374,523.532 741.383,523.562 741.392,523.591 741.401,523.621 741.411,523.651 741.42,523.681 741.429,523.711 741.438,523.741 741.447,523.771 741.457,523.8 741.466,523.83 741.475,523.86 741.484,523.89 741.493,523.92 741.502,523.949 741.512,523.979 741.521,524.009 741.53,524.039 741.539,524.068 741.548,524.098 741.558,524.128 741.567,524.158 741.576,524.187 741.585,524.217 741.594,524.247 741.604,524.276 741.613,524.306 741.622,524.336 741.631,524.365 741.64,524.395 741.649,524.425 741.659,524.454 741.668,524.484 741.677,524.513 741.686,524.543 741.695,524.573 741.705,524.602 741.714,524.632 741.723,524.661 741.732,524.691 741.741,524.72 741.751,524.75 741.76,524.78 741.769,524.809 741.778,524.839 741.787,524.868 741.797,524.898 741.806,524.927 741.815,524.957 741.824,524.986 741.833,525.015 741.842,525.045 741.852,525.074 741.861,525.104 741.87,525.133 741.879,525.163 741.888,525.192 741.898,525.221 741.907,525.251 741.916,525.28 741.925,525.31 741.934,525.339 741.944,525.368 741.953,525.398 741.962,525.427 741.971,525.456 741.98,525.486 741.989,525.515 741.999,525.544 742.008,525.574 742.017,525.603 742.026,525.632 742.035,525.661 742.045,525.691 742.054,525.72 742.063,525.749 742.072,525.778 742.081,525.808 742.091,525.837 742.1,525.866 742.109,525.895 742.118,525.925 742.127,525.954 742.137,525.983 742.146,526.012 742.155,526.041 742.164,526.07 742.173,526.1 742.182,526.129 742.192,526.158 742.201,526.187 742.21,526.216 742.219,526.245 742.228,526.274 742.238,526.303 742.247,526.332 742.256,526.361 742.265,526.39 742.274,526.42 742.284,526.449 742.293,526.478 742.302,526.507 742.311,526.536 742.32,526.565 742.329,526.594 742.339,526.623 742.348,526.652 742.357,526.681 742.366,526.71 742.375,526.739 742.385,526.767 742.394,526.796 742.403,526.825 742.412,526.854 742.421,526.883 742.431,526.912 742.44,526.941 742.449,526.97 742.458,526.999 742.467,527.028 742.477,527.056 742.486,527.085 742.495,527.114 742.504,527.143 742.513,527.172 742.522,527.201 742.532,527.229 742.541,527.258 742.55,527.287 742.559,527.316 742.568,527.345 742.578,527.373 742.587,527.402 742.596,527.431 742.605,527.46 742.614,527.488 742.624,527.517 742.633,527.546 742.642,527.575 742.651,527.603 742.66,527.632 742.669,527.661 742.679,527.689 742.688,527.718 742.697,527.747 742.706,527.775 742.715,527.804 742.725,527.833 742.734,527.861 742.743,527.89 742.752,527.918 742.761,527.947 742.771,527.976 742.78,528.004 742.789,528.033 742.798,528.061 742.807,528.09 742.817,528.118 742.826,528.147 742.835,528.176 742.844,528.204 742.853,528.233 742.862,528.261 742.872,528.29 742.881,528.318 742.89,528.347 742.899,528.375 742.908,528.403 742.918,528.432 742.927,528.46 742.936,528.489 742.945,528.517 742.954,528.546 742.964,528.574 742.973,528.602 742.982,528.631 742.991,528.659 743,528.688 743.009,528.716 743.019,528.744 743.028,528.773 743.037,528.801 743.046,528.829 743.055,528.858 743.065,528.886 743.074,528.914 743.083,528.943 743.092,528.971 743.101,528.999 743.111,529.028 743.12,529.056 743.129,529.084 743.138,529.112 743.147,529.141 743.157,529.169 743.166,529.197 743.175,529.225 743.184,529.254 743.193,529.282 743.202,529.31 743.212,529.338 743.221,529.366 743.23,529.394 743.239,529.423 743.248,529.451 743.258,529.479 743.267,529.507 743.276,529.535 743.285,529.563 743.294,529.591 743.304,529.62 743.313,529.648 743.322,529.676 743.331,529.704 743.34,529.732 743.35,529.76 743.359,529.788 743.368,529.816 743.377,529.844 743.386,529.872 743.395,529.9 743.405,529.928 743.414,529.956 743.423,529.984 743.432,530.012 743.441,530.04 743.451,530.068 743.46,530.096 743.469,530.124 743.478,530.152 743.487,530.18 743.497,530.208 743.506,530.236 743.515,530.264 743.524,530.291 743.533,530.319 743.542,530.347 743.552,530.375 743.561,530.403 743.57,530.431 743.579,530.459 743.588,530.487 743.598,530.514 743.607,530.542 743.616,530.57 743.625,530.598 743.634,530.626 743.644,530.653 743.653,530.681 743.662,530.709 743.671,530.737 743.68,530.765 743.69,530.792 743.699,530.82 743.708,530.848 743.717,530.876 743.726,530.903 743.735,530.931 743.745,530.959 743.754,530.986 743.763,531.014 743.772,531.042 743.781,531.069 743.791,531.097 743.8,531.125 743.809,531.152 743.818,531.18 743.827,531.208 743.837,531.235 743.846,531.263 743.855,531.29 743.864,531.318 743.873,531.346 743.882,531.373 743.892,531.401 743.901,531.428 743.91,531.456 743.919,531.483 743.928,531.511 743.938,531.539 743.947,531.566 743.956,531.594 743.965,531.621 743.974,531.649 743.984,531.676 743.993,531.704 744.002,531.731 744.011,531.758 744.02,531.786 744.03,531.813 744.039,531.841 744.048,531.868 744.057,531.896 744.066,531.923 744.075,531.95 744.085,531.978 744.094,532.005 744.103,532.033 744.112,532.06 744.121,532.087 744.131,532.115 744.14,532.142 744.149,532.169 744.158,532.197 744.167,532.224 744.177,532.251 744.186,532.279 744.195,532.306 744.204,532.333 744.213,532.361 744.222,532.388 744.232,532.415 744.241,532.442 744.25,532.47 744.259,532.497 744.268,532.524 744.278,532.551 744.287,532.579 744.296,532.606 744.305,532.633 744.314,532.66 744.324,532.687 744.333,532.714 744.342,532.742 744.351,532.769 744.36,532.796 744.37,532.823 744.379,532.85 744.388,532.877 744.397,532.904 744.406,532.932 744.415,532.959 744.425,532.986 744.434,533.013 744.443,533.04 744.452,533.067 744.461,533.094 744.471,533.121 744.48,533.148 744.489,533.175 744.498,533.202 744.507,533.229 744.517,533.256 744.526,533.283 744.535,533.31 744.544,533.337 744.553,533.364 744.562,533.391 744.572,533.418 744.581,533.445 744.59,533.472 744.599,533.499 744.608,533.526 744.618,533.553 744.627,533.58 744.636,533.607 744.645,533.634 744.654,533.661 744.664,533.687 744.673,533.714 744.682,533.741 744.691,533.768 744.7,533.795 744.71,533.822 744.719,533.849 744.728,533.875 744.737,533.902 744.746,533.929 744.755,533.956 744.765,533.983 744.774,534.009 744.783,534.036 744.792,534.063 744.801,534.09 744.811,534.116 744.82,534.143 744.829,534.17 744.838,534.197 744.847,534.223 744.857,534.25 744.866,534.277 744.875,534.303 744.884,534.33 744.893,534.357 744.902,534.383 744.912,534.41 744.921,534.437 744.93,534.463 744.939,534.49 744.948,534.517 744.958,534.543 744.967,534.57 744.976,534.597 744.985,534.623 744.994,534.65 745.004,534.676 745.013,534.703 745.022,534.729 745.031,534.756 745.04,534.783 745.05,534.809 745.059,534.836 745.068,534.862 745.077,534.889 745.086,534.915 745.095,534.942 745.105,534.968 745.114,534.995 745.123,535.021 745.132,535.048 745.141,535.074 745.151,535.101 745.16,535.127 745.169,535.153 745.178,535.18 745.187,535.206 745.197,535.233 745.206,535.259 745.215,535.286 745.224,535.312 745.233,535.338 745.242,535.365 745.252,535.391 745.261,535.417 745.27,535.444 745.279,535.47 745.288,535.496 745.298,535.523 745.307,535.549 745.316,535.575 745.325,535.602 745.334,535.628 745.344,535.654 745.353,535.681 745.362,535.707 745.371,535.733 745.38,535.759 745.39,535.786 745.399,535.812 745.408,535.838 745.417,535.864 745.426,535.89 745.435,535.917 745.445,535.943 745.454,535.969 745.463,535.995 745.472,536.021 745.481,536.048 745.491,536.074 745.5,536.1 745.509,536.126 745.518,536.152 745.527,536.178 745.537,536.204 745.546,536.23 745.555,536.257 745.564,536.283 745.573,536.309 745.583,536.335 745.592,536.361 745.601,536.387 745.61,536.413 745.619,536.439 745.628,536.465 745.638,536.491 745.647,536.517 745.656,536.543 745.665,536.569 745.674,536.595 745.684,536.621 745.693,536.647 745.702,536.673 745.711,536.699 745.72,536.725 745.73,536.751 745.739,536.777 745.748,536.803 745.757,536.829 745.766,536.855 745.775,536.881 745.785,536.907 745.794,536.932 745.803,536.958 745.812,536.984 745.821,537.01 745.831,537.036 745.84,537.062 745.849,537.088 745.858,537.113 745.867,537.139 745.877,537.165 745.886,537.191 745.895,537.217 745.904,537.243 745.913,537.268 745.923,537.294 745.932,537.32 745.941,537.346 745.95,537.371 745.959,537.397 745.968,537.423 745.978,537.449 745.987,537.474 745.996,537.5 746.005,537.526 746.014,537.552 746.024,537.577 746.033,537.603 746.042,537.629 746.051,537.654 746.06,537.68 746.07,537.706 746.079,537.731 746.088,537.757 746.097,537.783 746.106,537.808 746.115,537.834 746.125,537.859 746.134,537.885 746.143,537.911 746.152,537.936 746.161,537.962 746.171,537.987 746.18,538.013 746.189,538.038 746.198,538.064 746.207,538.09 746.217,538.115 746.226,538.141 746.235,538.166 746.244,538.192 746.253,538.217 746.263,538.243 746.272,538.268 746.281,538.294 746.29,538.319 746.299,538.344 746.308,538.37 746.318,538.395 746.327,538.421 746.336,538.446 746.345,538.472 746.354,538.497 746.364,538.522 746.373,538.548 746.382,538.573 746.391,538.599 746.4,538.624 746.41,538.649 746.419,538.675 746.428,538.7 746.437,538.725 746.446,538.751 746.455,538.776 746.465,538.801 746.474,538.827 746.483,538.852 746.492,538.877 746.501,538.903 746.511,538.928 746.52,538.953 746.529,538.978 746.538,539.004 746.547,539.029 746.557,539.054 746.566,539.079 746.575,539.105 746.584,539.13 746.593,539.155 746.603,539.18 746.612,539.206 746.621,539.231 746.63,539.256 746.639,539.281 746.648,539.306 746.658,539.331 746.667,539.357 746.676,539.382 746.685,539.407 746.694,539.432 746.704,539.457 746.713,539.482 746.722,539.507 746.731,539.532 746.74,539.557 746.75,539.583 746.759,539.608 746.768,539.633 746.777,539.658 746.786,539.683 746.795,539.708 746.805,539.733 746.814,539.758 746.823,539.783 746.832,539.808 746.841,539.833 746.851,539.858 746.86,539.883 746.869,539.908 746.878,539.933 746.887,539.958 746.897,539.983 746.906,540.008 746.915,540.033 746.924,540.058 746.933,540.083 746.943,540.107 746.952,540.132 746.961,540.157 746.97,540.182 746.979,540.207 746.988,540.232 746.998,540.257 747.007,540.282 747.016,540.306 747.025,540.331 747.034,540.356 747.044,540.381 747.053,540.406 747.062,540.431 747.071,540.455 747.08,540.48 747.09,540.505 747.099,540.53 747.108,540.555 747.117,540.579 747.126,540.604 747.135,540.629 747.145,540.654 747.154,540.678 747.163,540.703 747.172,540.728 747.181,540.753 747.191,540.777 747.2,540.802 747.209,540.827 747.218,540.851 747.227,540.876 747.237,540.901 747.246,540.925 747.255,540.95 747.264,540.975 747.273,540.999 747.283,541.024 747.292,541.049 747.301,541.073 747.31,541.098 747.319,541.122 747.328,541.147 747.338,541.172 747.347,541.196 747.356,541.221 747.365,541.245 747.374,541.27 747.384,541.294 747.393,541.319 747.402,541.344 747.411,541.368 747.42,541.393 747.43,541.417 747.439,541.442 747.448,541.466 747.457,541.491 747.466,541.515 747.475,541.539 747.485,541.564 747.494,541.588 747.503,541.613 747.512,541.637 747.521,541.662 747.531,541.686 747.54,541.711 747.549,541.735 747.558,541.759 747.567,541.784 747.577,541.808 747.586,541.833 747.595,541.857 747.604,541.881 747.613,541.906 747.623,541.93 747.632,541.954 747.641,541.979 747.65,542.003 747.659,542.027 747.668,542.052 747.678,542.076 747.687,542.1 747.696,542.125 747.705,542.149 747.714,542.173 747.724,542.197 747.733,542.222 747.742,542.246 747.751,542.27 747.76,542.294 747.77,542.319 747.779,542.343 747.788,542.367 747.797,542.391 747.806,542.415 747.815,542.44 747.825,542.464 747.834,542.488 747.843,542.512 747.852,542.536 747.861,542.561 747.871,542.585 747.88,542.609 747.889,542.633 747.898,542.657 747.907,542.681 747.917,542.705 747.926,542.729 747.935,542.753 747.944,542.778 747.953,542.802 747.963,542.826 747.972,542.85 747.981,542.874 747.99,542.898 747.999,542.922 748.008,542.946 748.018,542.97 748.027,542.994 748.036,543.018 748.045,543.042 748.054,543.066 748.064,543.09 748.073,543.114 748.082,543.138 748.091,543.162 748.1,543.186 748.11,543.21 748.119,543.234 748.128,543.258 748.137,543.282 748.146,543.306 748.156,543.329 748.165,543.353 748.174,543.377 748.183,543.401 748.192,543.425 748.201,543.449 748.211,543.473 748.22,543.497 748.229,543.521 748.238,543.544 748.247,543.568 748.257,543.592 748.266,543.616 748.275,543.64 748.284,543.664 748.293,543.687 748.303,543.711 748.312,543.735 748.321,543.759 748.33,543.782 748.339,543.806 748.348,543.83 748.358,543.854 748.367,543.877 748.376,543.901 748.385,543.925 748.394,543.949 748.404,543.972 748.413,543.996 748.422,544.02 748.431,544.043 748.44,544.067 748.45,544.091 748.459,544.114 748.468,544.138 748.477,544.162 748.486,544.185 748.496,544.209 748.505,544.233 748.514,544.256 748.523,544.28 748.532,544.304 748.541,544.327 748.551,544.351 748.56,544.374 748.569,544.398 748.578,544.421 748.587,544.445 748.597,544.469 748.606,544.492 748.615,544.516 748.624,544.539 748.633,544.563 748.643,544.586 748.652,544.61 748.661,544.633 748.67,544.657 748.679,544.68 748.688,544.704 748.698,544.727 748.707,544.751 748.716,544.774 748.725,544.798 748.734,544.821 748.744,544.845 748.753,544.868 748.762,544.891 748.771,544.915 748.78,544.938 748.79,544.962 748.799,544.985 748.808,545.008 748.817,545.032 748.826,545.055 748.836,545.078 748.845,545.102 748.854,545.125 748.863,545.149 748.872,545.172 748.881,545.195 748.891,545.219 748.9,545.242 748.909,545.265 748.918,545.288 748.927,545.312 748.937,545.335 748.946,545.358 748.955,545.382 748.964,545.405 748.973,545.428 748.983,545.451 748.992,545.475 749.001,545.498 749.01,545.521 749.019,545.544 749.028,545.567 749.038,545.591 749.047,545.614 749.056,545.637 749.065,545.66 749.074,545.683 749.084,545.707 749.093,545.73 749.102,545.753 749.111,545.776 749.12,545.799 749.13,545.822 749.139,545.845 749.148,545.869 749.157,545.892 749.166,545.915 749.176,545.938 749.185,545.961 749.194,545.984 749.203,546.007 749.212,546.03 749.221,546.053 749.231,546.076 749.24,546.099 749.249,546.122 749.258,546.145 749.267,546.168 749.277,546.191 749.286,546.214 749.295,546.237 749.304,546.26 749.313,546.283 749.323,546.306 749.332,546.329 749.341,546.352 749.35,546.375 749.359,546.398 749.368,546.421 749.378,546.444 749.387,546.467 749.396,546.49 749.405,546.513 749.414,546.536 749.424,546.559 749.433,546.582 749.442,546.604 749.451,546.627 749.46,546.65 749.47,546.673 749.479,546.696 749.488,546.719 749.497,546.742 749.506,546.764 749.516,546.787 749.525,546.81 749.534,546.833 749.543,546.856 749.552,546.878 749.561,546.901 749.571,546.924 749.58,546.947 749.589,546.97 749.598,546.992 749.607,547.015 749.617,547.038 749.626,547.061 749.635,547.083 749.644,547.106 749.653,547.129 749.663,547.151 749.672,547.174 749.681,547.197 749.69,547.22 749.699,547.242 749.708,547.265 749.718,547.288 749.727,547.31 749.736,547.333 749.745,547.355 749.754,547.378 749.764,547.401 749.773,547.423 749.782,547.446 749.791,547.469 749.8,547.491 749.81,547.514 749.819,547.536 749.828,547.559 749.837,547.582 749.846,547.604 749.856,547.627 749.865,547.649 749.874,547.672 749.883,547.694 749.892,547.717 749.901,547.739 749.911,547.762 749.92,547.784 749.929,547.807 749.938,547.829 749.947,547.852 749.957,547.874 749.966,547.897 749.975,547.919 749.984,547.942 749.993,547.964 750.003,547.987 750.012,548.009 750.021,548.032 750.03,548.054 750.039,548.076 750.048,548.099 750.058,548.121 750.067,548.144 750.076,548.166 750.085,548.188 750.094,548.211 750.104,548.233 750.113,548.255 750.122,548.278 750.131,548.3 750.14,548.322 750.15,548.345 750.159,548.367 750.168,548.389 750.177,548.412 750.186,548.434 750.196,548.456 750.205,548.479 750.214,548.501 750.223,548.523 750.232,548.545 750.241,548.568 750.251,548.59 750.26,548.612 750.269,548.634 750.278,548.657 750.287,548.679 750.297,548.701 750.306,548.723 750.315,548.746 750.324,548.768 750.333,548.79 750.343,548.812 750.352,548.834 750.361,548.856 750.37,548.879 750.379,548.901 750.388,548.923 750.398,548.945 750.407,548.967 750.416,548.989 750.425,549.011 750.434,549.034 750.444,549.056 750.453,549.078 750.462,549.1 750.471,549.122 750.48,549.144 750.49,549.166 750.499,549.188 750.508,549.21 750.517,549.232 750.526,549.254 750.536,549.276 750.545,549.298 750.554,549.32 750.563,549.342 750.572,549.364 750.581,549.386 750.591,549.408 750.6,549.43 750.609,549.452 750.618,549.474 750.627,549.496 750.637,549.518 750.646,549.54 750.655,549.562 750.664,549.584 750.673,549.606 750.683,549.628 750.692,549.65 750.701,549.672 750.71,549.694 750.719,549.715 750.729,549.737 750.738,549.759 750.747,549.781 750.756,549.803 750.765,549.825 750.774,549.847 750.784,549.869 750.793,549.89 750.802,549.912 750.811,549.934 750.82,549.956 750.83,549.978 750.839,549.999 750.848,550.021 750.857,550.043 750.866,550.065 750.876,550.087 750.885,550.108 750.894,550.13 750.903,550.152 750.912,550.174 750.921,550.195 750.931,550.217 750.94,550.239 750.949,550.261 750.958,550.282 750.967,550.304 750.977,550.326 750.986,550.347 750.995,550.369 751.004,550.391 751.013,550.412 751.023,550.434 751.032,550.456 751.041,550.477 751.05,550.499 751.059,550.521 751.069,550.542 751.078,550.564 751.087,550.585 751.096,550.607 751.105,550.629 751.114,550.65 751.124,550.672 751.133,550.693 751.142,550.715 751.151,550.737 751.16,550.758 751.17,550.78 751.179,550.801 751.188,550.823 751.197,550.844 751.206,550.866 751.216,550.887 751.225,550.909 751.234,550.93 751.243,550.952 751.252,550.973 751.261,550.995 751.271,551.016 751.28,551.038 751.289,551.059 751.298,551.081 751.307,551.102 751.317,551.124 751.326,551.145 751.335,551.166 751.344,551.188 751.353,551.209 751.363,551.231 751.372,551.252 751.381,551.273 751.39,551.295 751.399,551.316 751.409,551.338 751.418,551.359 751.427,551.38 751.436,551.402 751.445,551.423 751.454,551.444 751.464,551.466 751.473,551.487 751.482,551.508 751.491,551.53 751.5,551.551 751.51,551.572 751.519,551.594 751.528,551.615 751.537,551.636 751.546,551.657 751.556,551.679 751.565,551.7 751.574,551.721 751.583,551.742 751.592,551.764 751.601,551.785 751.611,551.806 751.62,551.827 751.629,551.849 751.638,551.87 751.647,551.891 751.657,551.912 751.666,551.933 751.675,551.954 751.684,551.976 751.693,551.997 751.703,552.018 751.712,552.039 751.721,552.06 751.73,552.081 751.739,552.102 751.749,552.124 751.758,552.145 751.767,552.166 751.776,552.187 751.785,552.208 751.794,552.229 751.804,552.25 751.813,552.271 751.822,552.292 751.831,552.313 751.84,552.334 751.85,552.355 751.859,552.376 751.868,552.398 751.877,552.419 751.886,552.44 751.896,552.461 751.905,552.482 751.914,552.503 751.923,552.524 751.932,552.545 751.941,552.566 751.951,552.587 751.96,552.607 751.969,552.628 751.978,552.649 751.987,552.67 751.997,552.691 752.006,552.712 752.015,552.733 752.024,552.754 752.033,552.775 752.043,552.796 752.052,552.817 752.061,552.838 752.07,552.859 752.079,552.879 752.089,552.9 752.098,552.921 752.107,552.942 752.116,552.963 752.125,552.984 752.134,553.004 752.144,553.025 752.153,553.046 752.162,553.067 752.171,553.088 752.18,553.109 752.19,553.129 752.199,553.15 752.208,553.171 752.217,553.192 752.226,553.212 752.236,553.233 752.245,553.254 752.254,553.275 752.263,553.295 752.272,553.316 752.281,553.337 752.291,553.358 752.3,553.378 752.309,553.399 752.318,553.42 752.327,553.44 752.337,553.461 752.346,553.482 752.355,553.503 752.364,553.523 752.373,553.544 752.383,553.565 752.392,553.585 752.401,553.606 752.41,553.626 752.419,553.647 752.429,553.668 752.438,553.688 752.447,553.709 752.456,553.73 752.465,553.75 752.474,553.771 752.484,553.791 752.493,553.812 752.502,553.832 752.511,553.853 752.52,553.874 752.53,553.894 752.539,553.915 752.548,553.935 752.557,553.956 752.566,553.976 752.576,553.997 752.585,554.017 752.594,554.038 752.603,554.058 752.612,554.079 752.621,554.099 752.631,554.12 752.64,554.14 752.649,554.161 752.658,554.181 752.667,554.201 752.677,554.222 752.686,554.242 752.695,554.263 752.704,554.283 752.713,554.304 752.723,554.324 752.732,554.344 752.741,554.365 752.75,554.385 752.759,554.406 752.769,554.426 752.778,554.446 752.787,554.467 752.796,554.487 752.805,554.507 752.814,554.528 752.824,554.548 752.833,554.568 752.842,554.589 752.851,554.609 752.86,554.629 752.87,554.65 752.879,554.67 752.888,554.69 752.897,554.711 752.906,554.731 752.916,554.751 752.925,554.771 752.934,554.792 752.943,554.812 752.952,554.832 752.962,554.852 752.971,554.873 752.98,554.893 752.989,554.913 752.998,554.933 753.007,554.953 753.017,554.974 753.026,554.994 753.035,555.014 753.044,555.034 753.053,555.054 753.063,555.074 753.072,555.095 753.081,555.115 753.09,555.135 753.099,555.155 753.109,555.175 753.118,555.195 753.127,555.215 753.136,555.236 753.145,555.256 753.154,555.276 753.164,555.296 753.173,555.316 753.182,555.336 753.191,555.356 753.2,555.376 753.21,555.396 753.219,555.416 753.228,555.436 753.237,555.456 753.246,555.476 753.256,555.496 753.265,555.516 753.274,555.536 753.283,555.556 753.292,555.576 753.302,555.596 753.311,555.616 753.32,555.636 753.329,555.656 753.338,555.676 753.347,555.696 753.357,555.716 753.366,555.736 753.375,555.756 753.384,555.776 753.393,555.796 753.403,555.816 753.412,555.836 753.421,555.856 753.43,555.876 753.439,555.896 753.449,555.915 753.458,555.935 753.467,555.955 753.476,555.975 753.485,555.995 753.494,556.015 753.504,556.035 753.513,556.055 753.522,556.074 753.531,556.094 753.54,556.114 753.55,556.134 753.559,556.154 753.568,556.173 753.577,556.193 753.586,556.213 753.596,556.233 753.605,556.253 753.614,556.272 753.623,556.292 753.632,556.312 753.642,556.332 753.651,556.351 753.66,556.371 753.669,556.391 753.678,556.411 753.687,556.43 753.697,556.45 753.706,556.47 753.715,556.489 753.724,556.509 753.733,556.529 753.743,556.549 753.752,556.568 753.761,556.588 753.77,556.608 753.779,556.627 753.789,556.647 753.798,556.667 753.807,556.686 753.816,556.706 753.825,556.725 753.834,556.745 753.844,556.765 753.853,556.784 753.862,556.804 753.871,556.823 753.88,556.843 753.89,556.863 753.899,556.882 753.908,556.902 753.917,556.921 753.926,556.941 753.936,556.96 753.945,556.98 753.954,556.999 753.963,557.019 753.972,557.039 753.982,557.058 753.991,557.078 754,557.097 754.009,557.117 754.018,557.136 754.027,557.156 754.037,557.175 754.046,557.194 754.055,557.214 754.064,557.233 754.073,557.253 754.083,557.272 754.092,557.292 754.101,557.311 754.11,557.331 754.119,557.35 754.129,557.369 754.138,557.389 754.147,557.408 754.156,557.428 754.165,557.447 754.174,557.466 754.184,557.486 754.193,557.505 754.202,557.525 754.211,557.544 754.22,557.563 754.23,557.583 754.239,557.602 754.248,557.621 754.257,557.641 754.266,557.66 754.276,557.679 754.285,557.699 754.294,557.718 754.303,557.737 754.312,557.756 754.322,557.776 754.331,557.795 754.34,557.814 754.349,557.834 754.358,557.853 754.367,557.872 754.377,557.891 754.386,557.91 754.395,557.93 754.404,557.949 754.413,557.968 754.423,557.987 754.432,558.007 754.441,558.026 754.45,558.045 754.459,558.064 754.469,558.083 754.478,558.103 754.487,558.122 754.496,558.141 754.505,558.16 754.514,558.179 754.524,558.198 754.533,558.217 754.542,558.237 754.551,558.256 754.56,558.275 754.57,558.294 754.579,558.313 754.588,558.332 754.597,558.351 754.606,558.37 754.616,558.389 754.625,558.408 754.634,558.428 754.643,558.447 754.652,558.466 754.662,558.485 754.671,558.504 754.68,558.523 754.689,558.542 754.698,558.561 754.707,558.58 754.717,558.599 754.726,558.618 754.735,558.637 754.744,558.656 754.753,558.675 754.763,558.694 754.772,558.713 754.781,558.732 754.79,558.751 754.799,558.77 754.809,558.789 754.818,558.808 754.827,558.826 754.836,558.845 754.845,558.864 754.854,558.883 754.864,558.902 754.873,558.921 754.882,558.94 754.891,558.959 754.9,558.978 754.91,558.997 754.919,559.016 754.928,559.034 754.937,559.053 754.946,559.072 754.956,559.091 754.965,559.11 754.974,559.129 754.983,559.147 754.992,559.166 755.002,559.185 755.011,559.204 755.02,559.223 755.029,559.242 755.038,559.26 755.047,559.279 755.057,559.298 755.066,559.317 755.075,559.335 755.084,559.354 755.093,559.373 755.103,559.392 755.112,559.41 755.121,559.429 755.13,559.448 755.139,559.467 755.149,559.485 755.158,559.504 755.167,559.523 755.176,559.541 755.185,559.56 755.194,559.579 755.204,559.598 755.213,559.616 755.222,559.635 755.231,559.654 755.24,559.672 755.25,559.691 755.259,559.71 755.268,559.728 755.277,559.747 755.286,559.765 755.296,559.784 755.305,559.803 755.314,559.821 755.323,559.84 755.332,559.858 755.342,559.877 755.351,559.896 755.36,559.914 755.369,559.933 755.378,559.951 755.387,559.97 755.397,559.988 755.406,560.007 755.415,560.026 755.424,560.044 755.433,560.063 755.443,560.081 755.452,560.1 755.461,560.118 755.47,560.137 755.479,560.155 755.489,560.174 755.498,560.192 755.507,560.211 755.516,560.229 755.525,560.248 755.535,560.266 755.544,560.284 755.553,560.303 755.562,560.321 755.571,560.34 755.58,560.358 755.59,560.377 755.599,560.395 755.608,560.413 755.617,560.432 755.626,560.45 755.636,560.469 755.645,560.487 755.654,560.505 755.663,560.524 755.672,560.542 755.682,560.561 755.691,560.579 755.7,560.597 755.709,560.616 755.718,560.634 755.727,560.652 755.737,560.671 755.746,560.689 755.755,560.707 755.764,560.726 755.773,560.744 755.783,560.762 755.792,560.78 755.801,560.799 755.81,560.817 755.819,560.835 755.829,560.854 755.838,560.872 755.847,560.89 755.856,560.908 755.865,560.927 755.875,560.945 755.884,560.963 755.893,560.981 755.902,560.999 755.911,561.018 755.92,561.036 755.93,561.054 755.939,561.072 755.948,561.09 755.957,561.109 755.966,561.127 755.976,561.145 755.985,561.163 755.994,561.181 756.003,561.199 756.012,561.218 756.022,561.236 756.031,561.254 756.04,561.272 756.049,561.29 756.058,561.308 756.067,561.326 756.077,561.345 756.086,561.363 756.095,561.381 756.104,561.399 756.113,561.417 756.123,561.435 756.132,561.453 756.141,561.471 756.15,561.489 756.159,561.507 756.169,561.525 756.178,561.543 756.187,561.561 756.196,561.579 756.205,561.597 756.215,561.615 756.224,561.633 756.233,561.651 756.242,561.669 756.251,561.687 756.26,561.705 756.27,561.723 756.279,561.741 756.288,561.759 756.297,561.777 756.306,561.795 756.316,561.813 756.325,561.831 756.334,561.849 756.343,561.867 756.352,561.885 756.362,561.903 756.371,561.921 756.38,561.939 756.389,561.956 756.398,561.974 756.407,561.992 756.417,562.01 756.426,562.028 756.435,562.046 756.444,562.064 756.453,562.082 756.463,562.099 756.472,562.117 756.481,562.135 756.49,562.153 756.499,562.171 756.509,562.189 756.518,562.206 756.527,562.224 756.536,562.242 756.545,562.26 756.555,562.278 756.564,562.295 756.573,562.313 756.582,562.331 756.591,562.349 756.6,562.367 756.61,562.384 756.619,562.402 756.628,562.42 756.637,562.438 756.646,562.455 756.656,562.473 756.665,562.491 756.674,562.508 756.683,562.526 756.692,562.544 756.702,562.562 756.711,562.579 756.72,562.597 756.729,562.615 756.738,562.632 756.747,562.65 756.757,562.668 756.766,562.685 756.775,562.703 756.784,562.721 756.793,562.738 756.803,562.756 756.812,562.774 756.821,562.791 756.83,562.809 756.839,562.826 756.849,562.844 756.858,562.862 756.867,562.879 756.876,562.897 756.885,562.914 756.895,562.932 756.904,562.95 756.913,562.967 756.922,562.985 756.931,563.002 756.94,563.02 756.95,563.037 756.959,563.055 756.968,563.072 756.977,563.09 756.986,563.107 756.996,563.125 757.005,563.142 757.014,563.16 757.023,563.177 757.032,563.195 757.042,563.212 757.051,563.23 757.06,563.247 757.069,563.265 757.078,563.282 757.087,563.3 757.097,563.317 757.106,563.335 757.115,563.352 757.124,563.369 757.133,563.387 757.143,563.404 757.152,563.422 757.161,563.439 757.17,563.457 757.179,563.474 757.189,563.491 757.198,563.509 757.207,563.526 757.216,563.543 757.225,563.561 757.235,563.578 757.244,563.596 757.253,563.613 757.262,563.63 757.271,563.648 757.28,563.665 757.29,563.682 757.299,563.7 757.308,563.717 757.317,563.734 757.326,563.752 757.336,563.769 757.345,563.786 757.354,563.803 757.363,563.821 757.372,563.838 757.382,563.855 757.391,563.872 757.4,563.89 757.409,563.907 757.418,563.924 757.427,563.941 757.437,563.959 757.446,563.976 757.455,563.993 757.464,564.01 757.473,564.028 757.483,564.045 757.492,564.062 757.501,564.079 757.51,564.096 757.519,564.114 757.529,564.131 757.538,564.148 757.547,564.165 757.556,564.182 757.565,564.199 757.575,564.217 757.584,564.234 757.593,564.251 757.602,564.268 757.611,564.285 757.62,564.302 757.63,564.319 757.639,564.336 757.648,564.354 757.657,564.371 757.666,564.388 757.676,564.405 757.685,564.422 757.694,564.439 757.703,564.456 757.712,564.473 757.722,564.49 757.731,564.507 757.74,564.524 757.749,564.541 757.758,564.558 757.767,564.575 757.777,564.592 757.786,564.609 757.795,564.626 757.804,564.643 757.813,564.66 757.823,564.677 757.832,564.694 757.841,564.711 757.85,564.728 757.859,564.745 757.869,564.762 757.878,564.779 757.887,564.796 757.896,564.813 757.905,564.83 757.915,564.847 757.924,564.864 757.933,564.881 757.942,564.898 757.951,564.915 757.96,564.932 757.97,564.949 757.979,564.965 757.988,564.982 757.997,564.999 758.006,565.016 758.016,565.033 758.025,565.05 758.034,565.067 758.043,565.084 758.052,565.1 758.062,565.117 758.071,565.134 758.08,565.151 758.089,565.168 758.098,565.185 758.108,565.201 758.117,565.218 758.126,565.235 758.135,565.252 758.144,565.269 758.153,565.285 758.163,565.302 758.172,565.319 758.181,565.336 758.19,565.352 758.199,565.369 758.209,565.386 758.218,565.403 758.227,565.42 758.236,565.436 758.245,565.453 758.255,565.47 758.264,565.486 758.273,565.503 758.282,565.52 758.291,565.537 758.3,565.553 758.31,565.57 758.319,565.587 758.328,565.603 758.337,565.62 758.346,565.637 758.356,565.653 758.365,565.67 758.374,565.687 758.383,565.703 758.392,565.72 758.402,565.737 758.411,565.753 758.42,565.77 758.429,565.786 758.438,565.803 758.448,565.82 758.457,565.836 758.466,565.853 758.475,565.87 758.484,565.886 758.493,565.903 758.503,565.919 758.512,565.936 758.521,565.952 758.53,565.969 758.539,565.986 758.549,566.002 758.558,566.019 758.567,566.035 758.576,566.052 758.585,566.068 758.595,566.085 758.604,566.101 758.613,566.118 758.622,566.134 758.631,566.151 758.64,566.167 758.65,566.184 758.659,566.2 758.668,566.217 758.677,566.233 758.686,566.25 758.696,566.266 758.705,566.283 758.714,566.299 758.723,566.315 758.732,566.332 758.742,566.348 758.751,566.365 758.76,566.381 758.769,566.398 758.778,566.414 758.788,566.43 758.797,566.447 758.806,566.463 758.815,566.48 758.824,566.496 758.833,566.512 758.843,566.529 758.852,566.545 758.861,566.561 758.87,566.578 758.879,566.594 758.889,566.611 758.898,566.627 758.907,566.643 758.916,566.66 758.925,566.676 758.935,566.692 758.944,566.708 758.953,566.725 758.962,566.741 758.971,566.757 758.98,566.774 758.99,566.79 758.999,566.806 759.008,566.823 759.017,566.839 759.026,566.855 759.036,566.871 759.045,566.888 759.054,566.904 759.063,566.92 759.072,566.936 759.082,566.953 759.091,566.969 759.1,566.985 759.109,567.001 759.118,567.017 759.128,567.034 759.137,567.05 759.146,567.066 759.155,567.082 759.164,567.098 759.173,567.115 759.183,567.131 759.192,567.147 759.201,567.163 759.21,567.179 759.219,567.195 759.229,567.211 759.238,567.228 759.247,567.244 759.256,567.26 759.265,567.276 759.275,567.292 759.284,567.308 759.293,567.324 759.302,567.34 759.311,567.357 759.32,567.373 759.33,567.389 759.339,567.405 759.348,567.421 759.357,567.437 759.366,567.453 759.376,567.469 759.385,567.485 759.394,567.501 759.403,567.517 759.412,567.533 759.422,567.549 759.431,567.565 759.44,567.581 759.449,567.597 759.458,567.613 759.468,567.629 759.477,567.645 759.486,567.661 759.495,567.677 759.504,567.693 759.513,567.709 759.523,567.725 759.532,567.741 759.541,567.757 759.55,567.773 759.559,567.789 759.569,567.805 759.578,567.821 759.587,567.837 759.596,567.853 759.605,567.869 759.615,567.885 759.624,567.9 759.633,567.916 759.642,567.932 759.651,567.948 759.66,567.964 759.67,567.98 759.679,567.996 759.688,568.012 759.697,568.028 759.706,568.043 759.716,568.059 759.725,568.075 759.734,568.091 759.743,568.107 759.752,568.123 759.762,568.139 759.771,568.154 759.78,568.17 759.789,568.186 759.798,568.202 759.808,568.218 759.817,568.233 759.826,568.249 759.835,568.265 759.844,568.281 759.853,568.297 759.863,568.312 759.872,568.328 759.881,568.344 759.89,568.36 759.899,568.375 759.909,568.391 759.918,568.407 759.927,568.423 759.936,568.438 759.945,568.454 759.955,568.47 759.964,568.485 759.973,568.501 759.982,568.517 759.991,568.533 760,568.548 760.01,568.564 760.019,568.58 760.028,568.595 760.037,568.611 760.046,568.627 760.056,568.642 760.065,568.658 760.074,568.674 760.083,568.689 760.092,568.705 760.102,568.72 760.111,568.736 760.12,568.752 760.129,568.767 760.138,568.783 760.148,568.799 760.157,568.814 760.166,568.83 760.175,568.845 760.184,568.861 760.193,568.877 760.203,568.892 760.212,568.908 760.221,568.923 760.23,568.939 760.239,568.954 760.249,568.97 760.258,568.985 760.267,569.001 760.276,569.017 760.285,569.032 760.295,569.048 760.304,569.063 760.313,569.079 760.322,569.094 760.331,569.11 760.34,569.125 760.35,569.141 760.359,569.156 760.368,569.172 760.377,569.187 760.386,569.203 760.396,569.218 760.405,569.233 760.414,569.249 760.423,569.264 760.432,569.28 760.442,569.295 760.451,569.311 760.46,569.326 760.469,569.342 760.478,569.357 760.488,569.372 760.497,569.388 760.506,569.403 760.515,569.419 760.524,569.434 760.533,569.449 760.543,569.465 760.552,569.48 760.561,569.495 760.57,569.511 760.579,569.526 760.589,569.542 760.598,569.557 760.607,569.572 760.616,569.588 760.625,569.603 760.635,569.618 760.644,569.634 760.653,569.649 760.662,569.664 760.671,569.679 760.681,569.695 760.69,569.71 760.699,569.725 760.708,569.741 760.717,569.756 760.726,569.771 760.736,569.787 760.745,569.802 760.754,569.817 760.763,569.832 760.772,569.848 760.782,569.863 760.791,569.878 760.8,569.893 760.809,569.909 760.818,569.924 760.828,569.939 760.837,569.954 760.846,569.969 760.855,569.985 760.864,570 760.873,570.015 760.883,570.03 760.892,570.045 760.901,570.061 760.91,570.076 760.919,570.091 760.929,570.106 760.938,570.121 760.947,570.136 760.956,570.151 760.965,570.167 760.975,570.182 760.984,570.197 760.993,570.212 761.002,570.227 761.011,570.242 761.021,570.257 761.03,570.272 761.039,570.288 761.048,570.303 761.057,570.318 761.066,570.333 761.076,570.348 761.085,570.363 761.094,570.378 761.103,570.393 761.112,570.408 761.122,570.423 761.131,570.438 761.14,570.453 761.149,570.468 761.158,570.483 761.168,570.498 761.177,570.514 761.186,570.529 761.195,570.544 761.204,570.559 761.213,570.574 761.223,570.589 761.232,570.604 761.241,570.619 761.25,570.634 761.259,570.649 761.269,570.663 761.278,570.678 761.287,570.693 761.296,570.708 761.305,570.723 761.315,570.738 761.324,570.753 761.333,570.768 761.342,570.783 761.351,570.798 761.361,570.813 761.37,570.828 761.379,570.843 761.388,570.858 761.397,570.873 761.406,570.887 761.416,570.902 761.425,570.917 761.434,570.932 761.443,570.947 761.452,570.962 761.462,570.977 761.471,570.992 761.48,571.006 761.489,571.021 761.498,571.036 761.508,571.051 761.517,571.066 761.526,571.081 761.535,571.096 761.544,571.11 761.553,571.125 761.563,571.14 761.572,571.155 761.581,571.17 761.59,571.184 761.599,571.199 761.609,571.214 761.618,571.229 761.627,571.244 761.636,571.258 761.645,571.273 761.655,571.288 761.664,571.303 761.673,571.317 761.682,571.332 761.691,571.347 761.701,571.362 761.71,571.376 761.719,571.391 761.728,571.406 761.737,571.42 761.746,571.435 761.756,571.45 761.765,571.465 761.774,571.479 761.783,571.494 761.792,571.509 761.802,571.523 761.811,571.538 761.82,571.553 761.829,571.567 761.838,571.582 761.848,571.597 761.857,571.611 761.866,571.626 761.875,571.641 761.884,571.655 761.893,571.67 761.903,571.685 761.912,571.699 761.921,571.714 761.93,571.728 761.939,571.743 761.949,571.758 761.958,571.772 761.967,571.787 761.976,571.801 761.985,571.816 761.995,571.83 762.004,571.845 762.013,571.86 762.022,571.874 762.031,571.889 762.041,571.903 762.05,571.918 762.059,571.932 762.068,571.947 762.077,571.961 762.086,571.976 762.096,571.991 762.105,572.005 762.114,572.02 762.123,572.034 762.132,572.049 762.142,572.063 762.151,572.078 762.16,572.092 762.169,572.107 762.178,572.121 762.188,572.135 762.197,572.15 762.206,572.164 762.215,572.179 762.224,572.193 762.233,572.208 762.243,572.222 762.252,572.237 762.261,572.251 762.27,572.265 762.279,572.28 762.289,572.294 762.298,572.309 762.307,572.323 762.316,572.338 762.325,572.352 762.335,572.366 762.344,572.381 762.353,572.395 762.362,572.41 762.371,572.424 762.381,572.438 762.39,572.453 762.399,572.467 762.408,572.481 762.417,572.496 762.426,572.51 762.436,572.524 762.445,572.539 762.454,572.553 762.463,572.567 762.472,572.582 762.482,572.596 762.491,572.61 762.5,572.625 762.509,572.639 762.518,572.653 762.528,572.667 762.537,572.682 762.546,572.696 762.555,572.71 762.564,572.725 762.573,572.739 762.583,572.753 762.592,572.767 762.601,572.782 762.61,572.796 762.619,572.81 762.629,572.824 762.638,572.839 762.647,572.853 762.656,572.867 762.665,572.881 762.675,572.895 762.684,572.91 762.693,572.924 762.702,572.938 762.711,572.952 762.721,572.966 762.73,572.981 762.739,572.995 762.748,573.009 762.757,573.023 762.766,573.037 762.776,573.052 762.785,573.066 762.794,573.08 762.803,573.094 762.812,573.108 762.822,573.122 762.831,573.136 762.84,573.15 762.849,573.165 762.858,573.179 762.868,573.193 762.877,573.207 762.886,573.221 762.895,573.235 762.904,573.249 762.914,573.263 762.923,573.277 762.932,573.291 762.941,573.306 762.95,573.32 762.959,573.334 762.969,573.348 762.978,573.362 762.987,573.376 762.996,573.39 763.005,573.404 763.015,573.418 763.024,573.432 763.033,573.446 763.042,573.46 763.051,573.474 763.061,573.488 763.07,573.502 763.079,573.516 763.088,573.53 763.097,573.544 763.106,573.558 763.116,573.572 763.125,573.586 763.134,573.6 763.143,573.614 763.152,573.628 763.162,573.642 763.171,573.656 763.18,573.67 763.189,573.684 763.198,573.698 763.208,573.712 763.217,573.726 763.226,573.739 763.235,573.753 763.244,573.767 763.254,573.781 763.263,573.795 763.272,573.809 763.281,573.823 763.29,573.837 763.299,573.851 763.309,573.865 763.318,573.878 763.327,573.892 763.336,573.906 763.345,573.92 763.355,573.934 763.364,573.948 763.373,573.962 763.382,573.975 763.391,573.989 763.401,574.003 763.41,574.017 763.419,574.031 763.428,574.045 763.437,574.058 763.446,574.072 763.456,574.086 763.465,574.1 763.474,574.114 763.483,574.127 763.492,574.141 763.502,574.155 763.511,574.169 763.52,574.182 763.529,574.196 763.538,574.21 763.548,574.224 763.557,574.238 763.566,574.251 763.575,574.265 763.584,574.279 763.594,574.292 763.603,574.306 763.612,574.32 763.621,574.334 763.63,574.347 763.639,574.361 763.649,574.375 763.658,574.389 763.667,574.402 763.676,574.416 763.685,574.43 763.695,574.443 763.704,574.457 763.713,574.471 763.722,574.484 763.731,574.498 763.741,574.512 763.75,574.525 763.759,574.539 763.768,574.553 763.777,574.566 763.786,574.58 763.796,574.593 763.805,574.607 763.814,574.621 763.823,574.634 763.832,574.648 763.842,574.662 763.851,574.675 763.86,574.689 763.869,574.702 763.878,574.716 763.888,574.73 763.897,574.743 763.906,574.757 763.915,574.77 763.924,574.784 763.934,574.797 763.943,574.811 763.952,574.824 763.961,574.838 763.97,574.852 763.979,574.865 763.989,574.879 763.998,574.892 764.007,574.906 764.016,574.919 764.025,574.933 764.035,574.946 764.044,574.96 764.053,574.973 764.062,574.987 764.071,575 764.081,575.014 764.09,575.027 764.099,575.041 764.108,575.054 764.117,575.068 764.126,575.081 764.136,575.095 764.145,575.108 764.154,575.121 764.163,575.135 764.172,575.148 764.182,575.162 764.191,575.175 764.2,575.189 764.209,575.202 764.218,575.215 764.228,575.229 764.237,575.242 764.246,575.256 764.255,575.269 764.264,575.282 764.274,575.296 764.283,575.309 764.292,575.323 764.301,575.336 764.31,575.349 764.319,575.363 764.329,575.376 764.338,575.389 764.347,575.403 764.356,575.416 764.365,575.43 764.375,575.443 764.384,575.456 764.393,575.47 764.402,575.483 764.411,575.496 764.421,575.509 764.43,575.523 764.439,575.536 764.448,575.549 764.457,575.563 764.466,575.576 764.476,575.589 764.485,575.603 764.494,575.616 764.503,575.629 764.512,575.642 764.522,575.656 764.531,575.669 764.54,575.682 764.549,575.695 764.558,575.709 764.568,575.722 764.577,575.735 764.586,575.748 764.595,575.762 764.604,575.775 764.614,575.788 764.623,575.801 764.632,575.814 764.641,575.828 764.65,575.841 764.659,575.854 764.669,575.867 764.678,575.88 764.687,575.894 764.696,575.907 764.705,575.92 764.715,575.933 764.724,575.946 764.733,575.96 764.742,575.973 764.751,575.986 764.761,575.999 764.77,576.012 764.779,576.025 764.788,576.038 764.797,576.052 764.806,576.065 764.816,576.078 764.825,576.091 764.834,576.104 764.843,576.117 764.852,576.13 764.862,576.143 764.871,576.156 764.88,576.169 764.889,576.183 764.898,576.196 764.908,576.209 764.917,576.222 764.926,576.235 764.935,576.248 764.944,576.261 764.954,576.274 764.963,576.287 764.972,576.3 764.981,576.313 764.99,576.326 764.999,576.339 765.009,576.352 765.018,576.365 765.027,576.378 765.036,576.391 765.045,576.404 765.055,576.417 765.064,576.43 765.073,576.443 765.082,576.456 765.091,576.469 765.101,576.482 765.11,576.495 765.119,576.508 765.128,576.521 765.137,576.534 765.146,576.547 765.156,576.56 765.165,576.573 765.174,576.586 765.183,576.599 765.192,576.612 765.202,576.625 765.211,576.638 765.22,576.651 765.229,576.664 765.238,576.676 765.248,576.689 765.257,576.702 765.266,576.715 765.275,576.728 765.284,576.741 765.294,576.754 765.303,576.767 765.312,576.78 765.321,576.792 765.33,576.805 765.339,576.818 765.349,576.831 765.358,576.844 765.367,576.857 765.376,576.87 765.385,576.882 765.395,576.895 765.404,576.908 765.413,576.921 765.422,576.934 765.431,576.947 765.441,576.959 765.45,576.972 765.459,576.985 765.468,576.998 765.477,577.011 765.487,577.023 765.496,577.036 765.505,577.049 765.514,577.062 765.523,577.075 765.532,577.087 765.542,577.1 765.551,577.113 765.56,577.126 765.569,577.138 765.578,577.151 765.588,577.164 765.597,577.177 765.606,577.189 765.615,577.202 765.624,577.215 765.634,577.228 765.643,577.24 765.652,577.253 765.661,577.266 765.67,577.278 765.679,577.291 765.689,577.304 765.698,577.316 765.707,577.329 765.716,577.342 765.725,577.355 765.735,577.367 765.744,577.38 765.753,577.393 765.762,577.405 765.771,577.418 765.781,577.431 765.79,577.443 765.799,577.456 765.808,577.468 765.817,577.481 765.827,577.494 765.836,577.506 765.845,577.519 765.854,577.532 765.863,577.544 765.872,577.557 765.882,577.569 765.891,577.582 765.9,577.595 765.909,577.607 765.918,577.62 765.928,577.632 765.937,577.645 765.946,577.658 765.955,577.67 765.964,577.683 765.974,577.695 765.983,577.708 765.992,577.72 766.001,577.733 766.01,577.745 766.019,577.758 766.029,577.771 766.038,577.783 766.047,577.796 766.056,577.808 766.065,577.821 766.075,577.833 766.084,577.846 766.093,577.858 766.102,577.871 766.111,577.883 766.121,577.896 766.13,577.908 766.139,577.921 766.148,577.933 766.157,577.946 766.167,577.958 766.176,577.971 766.185,577.983 766.194,577.995 766.203,578.008 766.212,578.02 766.222,578.033 766.231,578.045 766.24,578.058 766.249,578.07 766.258,578.083 766.268,578.095 766.277,578.107 766.286,578.12 766.295,578.132 766.304,578.145 766.314,578.157 766.323,578.169 766.332,578.182 766.341,578.194 766.35,578.207 766.359,578.219 766.369,578.231 766.378,578.244 766.387,578.256 766.396,578.268 766.405,578.281 766.415,578.293 766.424,578.305 766.433,578.318 766.442,578.33 766.451,578.343 766.461,578.355 766.47,578.367 766.479,578.38 766.488,578.392 766.497,578.404 766.507,578.416 766.516,578.429 766.525,578.441 766.534,578.453 766.543,578.466 766.552,578.478 766.562,578.49 766.571,578.503 766.58,578.515 766.589,578.527 766.598,578.539 766.608,578.552 766.617,578.564 766.626,578.576 766.635,578.588 766.644,578.601 766.654,578.613 766.663,578.625 766.672,578.637 766.681,578.65 766.69,578.662 766.699,578.674 766.709,578.686 766.718,578.698 766.727,578.711 766.736,578.723 766.745,578.735 766.755,578.747 766.764,578.759 766.773,578.772 766.782,578.784 766.791,578.796 766.801,578.808 766.81,578.82 766.819,578.833 766.828,578.845 766.837,578.857 766.847,578.869 766.856,578.881 766.865,578.893 766.874,578.905 766.883,578.918 766.892,578.93 766.902,578.942 766.911,578.954 766.92,578.966 766.929,578.978 766.938,578.99 766.948,579.002 766.957,579.015 766.966,579.027 766.975,579.039 766.984,579.051 766.994,579.063 767.003,579.075 767.012,579.087 767.021,579.099 767.03,579.111 767.039,579.123 767.049,579.135 767.058,579.147 767.067,579.16 767.076,579.172 767.085,579.184 767.095,579.196 767.104,579.208 767.113,579.22 767.122,579.232 767.131,579.244 767.141,579.256 767.15,579.268 767.159,579.28 767.168,579.292 767.177,579.304 767.187,579.316 767.196,579.328 767.205,579.34 767.214,579.352 767.223,579.364 767.232,579.376 767.242,579.388 767.251,579.4 767.26,579.412 767.269,579.424 767.278,579.436 767.288,579.448 767.297,579.46 767.306,579.471 767.315,579.483 767.324,579.495 767.334,579.507 767.343,579.519 767.352,579.531 767.361,579.543 767.37,579.555 767.379,579.567 767.389,579.579 767.398,579.591 767.407,579.603 767.416,579.614 767.425,579.626 767.435,579.638 767.444,579.65 767.453,579.662 767.462,579.674 767.471,579.686 767.481,579.698 767.49,579.71 767.499,579.721 767.508,579.733 767.517,579.745 767.527,579.757 767.536,579.769 767.545,579.781 767.554,579.792 767.563,579.804 767.572,579.816 767.582,579.828 767.591,579.84 767.6,579.852 767.609,579.863 767.618,579.875 767.628,579.887 767.637,579.899 767.646,579.911 767.655,579.922 767.664,579.934 767.674,579.946 767.683,579.958 767.692,579.969 767.701,579.981 767.71,579.993 767.719,580.005 767.729,580.017 767.738,580.028 767.747,580.04 767.756,580.052 767.765,580.064 767.775,580.075 767.784,580.087 767.793,580.099 767.802,580.11 767.811,580.122 767.821,580.134 767.83,580.146 767.839,580.157 767.848,580.169 767.857,580.181 767.867,580.192 767.876,580.204 767.885,580.216 767.894,580.227 767.903,580.239 767.912,580.251 767.922,580.262 767.931,580.274 767.94,580.286 767.949,580.297 767.958,580.309 767.968,580.321 767.977,580.332 767.986,580.344 767.995,580.356 768.004,580.367 768.014,580.379 768.023,580.391 768.032,580.402 768.041,580.414 768.05,580.425 768.06,580.437 768.069,580.449 768.078,580.46 768.087,580.472 768.096,580.483 768.105,580.495 768.115,580.507 768.124,580.518 768.133,580.53 768.142,580.541 768.151,580.553 768.161,580.565 768.17,580.576 768.179,580.588 768.188,580.599 768.197,580.611 768.207,580.622 768.216,580.634 768.225,580.645 768.234,580.657 768.243,580.668 768.252,580.68 768.262,580.691 768.271,580.703 768.28,580.715 768.289,580.726 768.298,580.738 768.308,580.749 768.317,580.761 768.326,580.772 768.335,580.784 768.344,580.795 768.354,580.806 768.363,580.818 768.372,580.829 768.381,580.841 768.39,580.852 768.4,580.864 768.409,580.875 768.418,580.887 768.427,580.898 768.436,580.91 768.445,580.921 768.455,580.933 768.464,580.944 768.473,580.955 768.482,580.967 768.491,580.978 768.501,580.99 768.51,581.001 768.519,581.012 768.528,581.024 768.537,581.035 768.547,581.047 768.556,581.058 768.565,581.069 768.574,581.081 768.583,581.092 768.592,581.104 768.602,581.115 768.611,581.126 768.62,581.138 768.629,581.149 768.638,581.16 768.648,581.172 768.657,581.183 768.666,581.195 768.675,581.206 768.684,581.217 768.694,581.229 768.703,581.24 768.712,581.251 768.721,581.263 768.73,581.274 768.74,581.285 768.749,581.296 768.758,581.308 768.767,581.319 768.776,581.33 768.785,581.342 768.795,581.353 768.804,581.364 768.813,581.376 768.822,581.387 768.831,581.398 768.841,581.409 768.85,581.421 768.859,581.432 768.868,581.443 768.877,581.454 768.887,581.466 768.896,581.477 768.905,581.488 768.914,581.499 768.923,581.511 768.932,581.522 768.942,581.533 768.951,581.544 768.96,581.556 768.969,581.567 768.978,581.578 768.988,581.589 768.997,581.6 769.006,581.612 769.015,581.623 769.024,581.634 769.034,581.645 769.043,581.656 769.052,581.668 769.061,581.679 769.07,581.69 769.08,581.701 769.089,581.712 769.098,581.723 769.107,581.735 769.116,581.746 769.125,581.757 769.135,581.768 769.144,581.779 769.153,581.79 769.162,581.801 769.171,581.813 769.181,581.824 769.19,581.835 769.199,581.846 769.208,581.857 769.217,581.868 769.227,581.879 769.236,581.89 769.245,581.901 769.254,581.913 769.263,581.924 769.272,581.935 769.282,581.946 769.291,581.957 769.3,581.968 769.309,581.979 769.318,581.99 769.328,582.001 769.337,582.012 769.346,582.023 769.355,582.034 769.364,582.045 769.374,582.056 769.383,582.068 769.392,582.079 769.401,582.09 769.41,582.101 769.42,582.112 769.429,582.123 769.438,582.134 769.447,582.145 769.456,582.156 769.465,582.167 769.475,582.178 769.484,582.189 769.493,582.2 769.502,582.211 769.511,582.222 769.521,582.233 769.53,582.244 769.539,582.255 769.548,582.266 769.557,582.277 769.567,582.288 769.576,582.299 769.585,582.309 769.594,582.32 769.603,582.331 769.612,582.342 769.622,582.353 769.631,582.364 769.64,582.375 769.649,582.386 769.658,582.397 769.668,582.408 769.677,582.419 769.686,582.43 769.695,582.441 769.704,582.452 769.714,582.462 769.723,582.473 769.732,582.484 769.741,582.495 769.75,582.506 769.76,582.517 769.769,582.528 769.778,582.539 769.787,582.55 769.796,582.56 769.805,582.571 769.815,582.582 769.824,582.593 769.833,582.604 769.842,582.615 769.851,582.626 769.861,582.636 769.87,582.647 769.879,582.658 769.888,582.669 769.897,582.68 769.907,582.691 769.916,582.701 769.925,582.712 769.934,582.723 769.943,582.734 769.952,582.745 769.962,582.755 769.971,582.766 769.98,582.777 769.989,582.788 769.998,582.799 770.008,582.809 770.017,582.82 770.026,582.831 770.035,582.842 770.044,582.853 770.054,582.863 770.063,582.874 770.072,582.885 770.081,582.896 770.09,582.906 770.1,582.917 770.109,582.928 770.118,582.939 770.127,582.949 770.136,582.96 770.145,582.971 770.155,582.981 770.164,582.992 770.173,583.003 770.182,583.014 770.191,583.024 770.201,583.035 770.21,583.046 770.219,583.056 770.228,583.067 770.237,583.078 770.247,583.088 770.256,583.099 770.265,583.11 770.274,583.121 770.283,583.131 770.293,583.142 770.302,583.153 770.311,583.163 770.32,583.174 770.329,583.184 770.338,583.195 770.348,583.206 770.357,583.216 770.366,583.227 770.375,583.238 770.384,583.248 770.394,583.259 770.403,583.27 770.412,583.28 770.421,583.291 770.43,583.301 770.44,583.312 770.449,583.323 770.458,583.333 770.467,583.344 770.476,583.354 770.485,583.365 770.495,583.376 770.504,583.386 770.513,583.397 770.522,583.407 770.531,583.418 770.541,583.428 770.55,583.439 770.559,583.45 770.568,583.46 770.577,583.471 770.587,583.481 770.596,583.492 770.605,583.502 770.614,583.513 770.623,583.523 770.633,583.534 770.642,583.544 770.651,583.555 770.66,583.565 770.669,583.576 770.678,583.587 770.688,583.597 770.697,583.608 770.706,583.618 770.715,583.629 770.724,583.639 770.734,583.649 770.743,583.66 770.752,583.67 770.761,583.681 770.77,583.691 770.78,583.702 770.789,583.712 770.798,583.723 770.807,583.733 770.816,583.744 770.825,583.754 770.835,583.765 770.844,583.775 770.853,583.786 770.862,583.796 770.871,583.806 770.881,583.817 770.89,583.827 770.899,583.838 770.908,583.848 770.917,583.859 770.927,583.869 770.936,583.879 770.945,583.89 770.954,583.9 770.963,583.911 770.973,583.921 770.982,583.931 770.991,583.942 771,583.952 771.009,583.962 771.018,583.973 771.028,583.983 771.037,583.994 771.046,584.004 771.055,584.014 771.064,584.025 771.074,584.035 771.083,584.045 771.092,584.056 771.101,584.066 771.11,584.076 771.12,584.087 771.129,584.097 771.138,584.107 771.147,584.118 771.156,584.128 771.165,584.138 771.175,584.149 771.184,584.159 771.193,584.169 771.202,584.18 771.211,584.19 771.221,584.2 771.23,584.211 771.239,584.221 771.248,584.231 771.257,584.241 771.267,584.252 771.276,584.262 771.285,584.272 771.294,584.282 771.303,584.293 771.313,584.303 771.322,584.313 771.331,584.323 771.34,584.334 771.349,584.344 771.358,584.354 771.368,584.364 771.377,584.375 771.386,584.385 771.395,584.395 771.404,584.405 771.414,584.415 771.423,584.425 771.432,584.436 771.441,584.446 771.45,584.456 771.46,584.466 771.469,584.476 771.478,584.486 771.487,584.497 771.496,584.507 771.505,584.517 771.515,584.527 771.524,584.537 771.533,584.547 771.542,584.557 771.551,584.568 771.561,584.578 771.57,584.588 771.579,584.598 771.588,584.608 771.597,584.618 771.607,584.628 771.616,584.638 771.625,584.648 771.634,584.658 771.643,584.668 771.653,584.678 771.662,584.688 771.671,584.699 771.68,584.709 771.689,584.719 771.698,584.729 771.708,584.739 771.717,584.749 771.726,584.759 771.735,584.769 771.744,584.779 771.754,584.789 771.763,584.799 771.772,584.809 771.781,584.819 771.79,584.829 771.8,584.839 771.809,584.849 771.818,584.859 771.827,584.869 771.836,584.878 771.845,584.888 771.855,584.898 771.864,584.908 771.873,584.918 771.882,584.928 771.891,584.938 771.901,584.948 771.91,584.958 771.919,584.968 771.928,584.978 771.937,584.988 771.947,584.998 771.956,585.007 771.965,585.017 771.974,585.027 771.983,585.037 771.993,585.047 772.002,585.057 772.011,585.067 772.02,585.077 772.029,585.086 772.038,585.096 772.048,585.106 772.057,585.116 772.066,585.126 772.075,585.136 772.084,585.145 772.094,585.155 772.103,585.165 772.112,585.175 772.121,585.185 772.13,585.194 772.14,585.204 772.149,585.214 772.158,585.224 772.167,585.234 772.176,585.243 772.185,585.253 772.195,585.263 772.204,585.273 772.213,585.282 772.222,585.292 772.231,585.302 772.241,585.312 772.25,585.321 772.259,585.331 772.268,585.341 772.277,585.35 772.287,585.36 772.296,585.37 772.305,585.38 772.314,585.389 772.323,585.399 772.333,585.409 772.342,585.418 772.351,585.428 772.36,585.438 772.369,585.447 772.378,585.457 772.388,585.467 772.397,585.476 772.406,585.486 772.415,585.496 772.424,585.505 772.434,585.515 772.443,585.525 772.452,585.534 772.461,585.544 772.47,585.553 772.48,585.563 772.489,585.573 772.498,585.582 772.507,585.592 772.516,585.601 772.525,585.611 772.535,585.621 772.544,585.63 772.553,585.64 772.562,585.649 772.571,585.659 772.581,585.668 772.59,585.678 772.599,585.688 772.608,585.697 772.617,585.707 772.627,585.716 772.636,585.726 772.645,585.735 772.654,585.745 772.663,585.754 772.673,585.764 772.682,585.773 772.691,585.783 772.7,585.792 772.709,585.802 772.718,585.811 772.728,585.821 772.737,585.83 772.746,585.84 772.755,585.849 772.764,585.859 772.774,585.868 772.783,585.877 772.792,585.887 772.801,585.896 772.81,585.906 772.82,585.915 772.829,585.925 772.838,585.934 772.847,585.943 772.856,585.953 772.866,585.962 772.875,585.972 772.884,585.981 772.893,585.991 772.902,586 772.911,586.009 772.921,586.019 772.93,586.028 772.939,586.037 772.948,586.047 772.957,586.056 772.967,586.066 772.976,586.075 772.985,586.084 772.994,586.094 773.003,586.103 773.013,586.112 773.022,586.122 773.031,586.131 773.04,586.14 773.049,586.15 773.058,586.159 773.068,586.168 773.077,586.177 773.086,586.187 773.095,586.196 773.104,586.205 773.114,586.215 773.123,586.224 773.132,586.233 773.141,586.242 773.15,586.252 773.16,586.261 773.169,586.27 773.178,586.28 773.187,586.289 773.196,586.298 773.206,586.307 773.215,586.316 773.224,586.326 773.233,586.335 773.242,586.344 773.251,586.353 773.261,586.363 773.27,586.372 773.279,586.381 773.288,586.39 773.297,586.399 773.307,586.409 773.316,586.418 773.325,586.427 773.334,586.436 773.343,586.445 773.353,586.454 773.362,586.464 773.371,586.473 773.38,586.482 773.389,586.491 773.398,586.5 773.408,586.509 773.417,586.518 773.426,586.528 773.435,586.537 773.444,586.546 773.454,586.555 773.463,586.564 773.472,586.573 773.481,586.582 773.49,586.591 773.5,586.601 773.509,586.61 773.518,586.619 773.527,586.628 773.536,586.637 773.546,586.646 773.555,586.655 773.564,586.664 773.573,586.673 773.582,586.682 773.591,586.691 773.601,586.7 773.61,586.709 773.619,586.718 773.628,586.727 773.637,586.736 773.647,586.745 773.656,586.754 773.665,586.763 773.674,586.772 773.683,586.781 773.693,586.79 773.702,586.799 773.711,586.808 773.72,586.817 773.729,586.826 773.738,586.835 773.748,586.844 773.757,586.853 773.766,586.862 773.775,586.871 773.784,586.88 773.794,586.889 773.803,586.898 773.812,586.907 773.821,586.916 773.83,586.925 773.84,586.934 773.849,586.943 773.858,586.952 773.867,586.961 773.876,586.97 773.886,586.978 773.895,586.987 773.904,586.996 773.913,587.005 773.922,587.014 773.931,587.023 773.941,587.032 773.95,587.041 773.959,587.05 773.968,587.058 773.977,587.067 773.987,587.076 773.996,587.085 774.005,587.094 774.014,587.103 774.023,587.112 774.033,587.12 774.042,587.129 774.051,587.138 774.06,587.147 774.069,587.156 774.078,587.165 774.088,587.173 774.097,587.182 774.106,587.191 774.115,587.2 774.124,587.209 774.134,587.217 774.143,587.226 774.152,587.235 774.161,587.244 774.17,587.252 774.18,587.261 774.189,587.27 774.198,587.279 774.207,587.288 774.216,587.296 774.226,587.305 774.235,587.314 774.244,587.323 774.253,587.331 774.262,587.34 774.271,587.349 774.281,587.357 774.29,587.366 774.299,587.375 774.308,587.384 774.317,587.392 774.327,587.401 774.336,587.41 774.345,587.418 774.354,587.427 774.363,587.436 774.373,587.444 774.382,587.453 774.391,587.462 774.4,587.47 774.409,587.479 774.418,587.488 774.428,587.496 774.437,587.505 774.446,587.514 774.455,587.522 774.464,587.531 774.474,587.54 774.483,587.548 774.492,587.557 774.501,587.566 774.51,587.574 774.52,587.583 774.529,587.591 774.538,587.6 774.547,587.609 774.556,587.617 774.566,587.626 774.575,587.634 774.584,587.643 774.593,587.652 774.602,587.66 774.611,587.669 774.621,587.677 774.63,587.686 774.639,587.694 774.648,587.703 774.657,587.711 774.667,587.72 774.676,587.729 774.685,587.737 774.694,587.746 774.703,587.754 774.713,587.763 774.722,587.771 774.731,587.78 774.74,587.788 774.749,587.797 774.758,587.805 774.768,587.814 774.777,587.822 774.786,587.831 774.795,587.839 774.804,587.848 774.814,587.856 774.823,587.865 774.832,587.873 774.841,587.882 774.85,587.89 774.86,587.899 774.869,587.907 774.878,587.915 774.887,587.924 774.896,587.932 774.906,587.941 774.915,587.949 774.924,587.958 774.933,587.966 774.942,587.975 774.951,587.983 774.961,587.991 774.97,588 774.979,588.008 774.988,588.017 774.997,588.025 775.007,588.033 775.016,588.042 775.025,588.05 775.034,588.059 775.043,588.067 775.053,588.075 775.062,588.084 775.071,588.092 775.08,588.1 775.089,588.109 775.098,588.117 775.108,588.125 775.117,588.134 775.126,588.142 775.135,588.15 775.144,588.159 775.154,588.167 775.163,588.175 775.172,588.184 775.181,588.192 775.19,588.2 775.2,588.209 775.209,588.217 775.218,588.225 775.227,588.234 775.236,588.242 775.246,588.25 775.255,588.259 775.264,588.267 775.273,588.275 775.282,588.283 775.291,588.292 775.301,588.3 775.31,588.308 775.319,588.316 775.328,588.325 775.337,588.333 775.347,588.341 775.356,588.349 775.365,588.358 775.374,588.366 775.383,588.374 775.393,588.382 775.402,588.391 775.411,588.399 775.42,588.407 775.429,588.415 775.439,588.423 775.448,588.432 775.457,588.44 775.466,588.448 775.475,588.456 775.484,588.464 775.494,588.473 775.503,588.481 775.512,588.489 775.521,588.497 775.53,588.505 775.54,588.513 775.549,588.522 775.558,588.53 775.567,588.538 775.576,588.546 775.586,588.554 775.595,588.562 775.604,588.571 775.613,588.579 775.622,588.587 775.631,588.595 775.641,588.603 775.65,588.611 775.659,588.619 775.668,588.627 775.677,588.636 775.687,588.644 775.696,588.652 775.705,588.66 775.714,588.668 775.723,588.676 775.733,588.684 775.742,588.692 775.751,588.7 775.76,588.708 775.769,588.716 775.779,588.724 775.788,588.732 775.797,588.741 775.806,588.749 775.815,588.757 775.824,588.765 775.834,588.773 775.843,588.781 775.852,588.789 775.861,588.797 775.87,588.805 775.88,588.813 775.889,588.821 775.898,588.829 775.907,588.837 775.916,588.845 775.926,588.853 775.935,588.861 775.944,588.869 775.953,588.877 775.962,588.885 775.971,588.893 775.981,588.901 775.99,588.909 775.999,588.917 776.008,588.925 776.017,588.933 776.027,588.941 776.036,588.949 776.045,588.957 776.054,588.965 776.063,588.973 776.073,588.98 776.082,588.988 776.091,588.996 776.1,589.004 776.109,589.012 776.119,589.02 776.128,589.028 776.137,589.036 776.146,589.044 776.155,589.052 776.164,589.06 776.174,589.068 776.183,589.076 776.192,589.083 776.201,589.091 776.21,589.099 776.22,589.107 776.229,589.115 776.238,589.123 776.247,589.131 776.256,589.139 776.266,589.146 776.275,589.154 776.284,589.162 776.293,589.17 776.302,589.178 776.311,589.186 776.321,589.194 776.33,589.201 776.339,589.209 776.348,589.217 776.357,589.225 776.367,589.233 776.376,589.24 776.385,589.248 776.394,589.256 776.403,589.264 776.413,589.272 776.422,589.28 776.431,589.287 776.44,589.295 776.449,589.303 776.459,589.311 776.468,589.318 776.477,589.326 776.486,589.334 776.495,589.342 776.504,589.35 776.514,589.357 776.523,589.365 776.532,589.373 776.541,589.381 776.55,589.388 776.56,589.396 776.569,589.404 776.578,589.412 776.587,589.419 776.596,589.427 776.606,589.435 776.615,589.443 776.624,589.45 776.633,589.458 776.642,589.466 776.651,589.473 776.661,589.481 776.67,589.489 776.679,589.496 776.688,589.504 776.697,589.512 776.707,589.52 776.716,589.527 776.725,589.535 776.734,589.543 776.743,589.55 776.753,589.558 776.762,589.566 776.771,589.573 776.78,589.581 776.789,589.589 776.799,589.596 776.808,589.604 776.817,589.612 776.826,589.619 776.835,589.627 776.844,589.634 776.854,589.642 776.863,589.65 776.872,589.657 776.881,589.665 776.89,589.673 776.9,589.68 776.909,589.688 776.918,589.695 776.927,589.703 776.936,589.711 776.946,589.718 776.955,589.726 776.964,589.733 776.973,589.741 776.982,589.749 776.991,589.756 777.001,589.764 777.01,589.771 777.019,589.779 777.028,589.786 777.037,589.794 777.047,589.802 777.056,589.809 777.065,589.817 777.074,589.824 777.083,589.832 777.093,589.839 777.102,589.847 777.111,589.854 777.12,589.862 777.129,589.869 777.139,589.877 777.148,589.884 777.157,589.892 777.166,589.899 777.175,589.907 777.184,589.914 777.194,589.922 777.203,589.929 777.212,589.937 777.221,589.944 777.23,589.952 777.24,589.959 777.249,589.967 777.258,589.974 777.267,589.982 777.276,589.989 777.286,589.997 777.295,590.004 777.304,590.012 777.313,590.019 777.322,590.027 777.331,590.034 777.341,590.041 777.35,590.049 777.359,590.056 777.368,590.064 777.377,590.071 777.387,590.079 777.396,590.086 777.405,590.093 777.414,590.101 777.423,590.108 777.433,590.116 777.442,590.123 777.451,590.131 777.46,590.138 777.469,590.145 777.479,590.153 777.488,590.16 777.497,590.167 777.506,590.175 777.515,590.182 777.524,590.19 777.534,590.197 777.543,590.204 777.552,590.212 777.561,590.219 777.57,590.226 777.58,590.234 777.589,590.241 777.598,590.248 777.607,590.256 777.616,590.263 777.626,590.27 777.635,590.278 777.644,590.285 777.653,590.292 777.662,590.3 777.672,590.307 777.681,590.314 777.69,590.322 777.699,590.329 777.708,590.336 777.717,590.344 777.727,590.351 777.736,590.358 777.745,590.366 777.754,590.373 777.763,590.38 777.773,590.387 777.782,590.395 777.791,590.402 777.8,590.409 777.809,590.417 777.819,590.424 777.828,590.431 777.837,590.438 777.846,590.446 777.855,590.453 777.864,590.46 777.874,590.467 777.883,590.475 777.892,590.482 777.901,590.489 777.91,590.496 777.92,590.503 777.929,590.511 777.938,590.518 777.947,590.525 777.956,590.532 777.966,590.54 777.975,590.547 777.984,590.554 777.993,590.561 778.002,590.568 778.012,590.576 778.021,590.583 778.03,590.59 778.039,590.597 778.048,590.604 778.057,590.612 778.067,590.619 778.076,590.626 778.085,590.633 778.094,590.64 778.103,590.647 778.113,590.655 778.122,590.662 778.131,590.669 778.14,590.676 778.149,590.683 778.159,590.69 778.168,590.697 778.177,590.705 778.186,590.712 778.195,590.719 778.204,590.726 778.214,590.733 778.223,590.74 778.232,590.747 778.241,590.754 778.25,590.762 778.26,590.769 778.269,590.776 778.278,590.783 778.287,590.79 778.296,590.797 778.306,590.804 778.315,590.811 778.324,590.818 778.333,590.825 778.342,590.832 778.352,590.84 778.361,590.847 778.37,590.854 778.379,590.861 778.388,590.868 778.397,590.875 778.407,590.882 778.416,590.889 778.425,590.896 778.434,590.903 778.443,590.91 778.453,590.917 778.462,590.924 778.471,590.931 778.48,590.938 778.489,590.945 778.499,590.952 778.508,590.959 778.517,590.966 778.526,590.973 778.535,590.98 778.544,590.987 778.554,590.994 778.563,591.001 778.572,591.008 778.581,591.015 778.59,591.022 778.6,591.029 778.609,591.036 778.618,591.043 778.627,591.05 778.636,591.057 778.646,591.064 778.655,591.071 778.664,591.078 778.673,591.085 778.682,591.092 778.692,591.099 778.701,591.106 778.71,591.113 778.719,591.12 778.728,591.127 778.737,591.134 778.747,591.141 778.756,591.148 778.765,591.155 778.774,591.161 778.783,591.168 778.793,591.175 778.802,591.182 778.811,591.189 778.82,591.196 778.829,591.203 778.839,591.21 778.848,591.217 778.857,591.224 778.866,591.231 778.875,591.237 778.884,591.244 778.894,591.251 778.903,591.258 778.912,591.265 778.921,591.272 778.93,591.279 778.94,591.286 778.949,591.292 778.958,591.299 778.967,591.306 778.976,591.313 778.986,591.32 778.995,591.327 779.004,591.334 779.013,591.34 779.022,591.347 779.032,591.354 779.041,591.361 779.05,591.368 779.059,591.375 779.068,591.381 779.077,591.388 779.087,591.395 779.096,591.402 779.105,591.409 779.114,591.416 779.123,591.422 779.133,591.429 779.142,591.436 779.151,591.443 779.16,591.45 779.169,591.456 779.179,591.463 779.188,591.47 779.197,591.477 779.206,591.483 779.215,591.49 779.224,591.497 779.234,591.504 779.243,591.511 779.252,591.517 779.261,591.524 779.27,591.531 779.28,591.538 779.289,591.544 779.298,591.551 779.307,591.558 779.316,591.565 779.326,591.571 779.335,591.578 779.344,591.585 779.353,591.592 779.362,591.598 779.372,591.605 779.381,591.612 779.39,591.618 779.399,591.625 779.408,591.632 779.417,591.639 779.427,591.645 779.436,591.652 779.445,591.659 779.454,591.665 779.463,591.672 779.473,591.679 779.482,591.685 779.491,591.692 779.5,591.699 779.509,591.705 779.519,591.712 779.528,591.719 779.537,591.725 779.546,591.732 779.555,591.739 779.564,591.745 779.574,591.752 779.583,591.759 779.592,591.765 779.601,591.772 779.61,591.779 779.62,591.785 779.629,591.792 779.638,591.799 779.647,591.805 779.656,591.812 779.666,591.819 779.675,591.825 779.684,591.832 779.693,591.838 779.702,591.845 779.712,591.852 779.721,591.858 779.73,591.865 779.739,591.871 779.748,591.878 779.757,591.885 779.767,591.891 779.776,591.898 779.785,591.904 779.794,591.911 779.803,591.918 779.813,591.924 779.822,591.931 779.831,591.937 779.84,591.944 779.849,591.95 779.859,591.957 779.868,591.964 779.877,591.97 779.886,591.977 779.895,591.983 779.904,591.99 779.914,591.996 779.923,592.003 779.932,592.009 779.941,592.016 779.95,592.023 779.96,592.029 779.969,592.036 779.978,592.042 779.987,592.049 779.996,592.055 780.006,592.062 780.015,592.068 780.024,592.075 780.033,592.081 780.042,592.088 780.052,592.094 780.061,592.101 780.07,592.107 780.079,592.114 780.088,592.12 780.097,592.127 780.107,592.133 780.116,592.14 780.125,592.146 780.134,592.153 780.143,592.159 780.153,592.166 780.162,592.172 780.171,592.178 780.18,592.185 780.189,592.191 780.199,592.198 780.208,592.204 780.217,592.211 780.226,592.217 780.235,592.224 780.245,592.23 780.254,592.237 780.263,592.243 780.272,592.249 780.281,592.256 780.29,592.262 780.3,592.269 780.309,592.275 780.318,592.282 780.327,592.288 780.336,592.294 780.346,592.301 780.355,592.307 780.364,592.314 780.373,592.32 780.382,592.326 780.392,592.333 780.401,592.339 780.41,592.346 780.419,592.352 780.428,592.358 780.437,592.365 780.447,592.371 780.456,592.377 780.465,592.384 780.474,592.39 780.483,592.397 780.493,592.403 780.502,592.409 780.511,592.416 780.52,592.422 780.529,592.428 780.539,592.435 780.548,592.441 780.557,592.447 780.566,592.454 780.575,592.46 780.585,592.466 780.594,592.473 780.603,592.479 780.612,592.485 780.621,592.492 780.63,592.498 780.64,592.504 780.649,592.511 780.658,592.517 780.667,592.523 780.676,592.53 780.686,592.536 780.695,592.542 780.704,592.549 780.713,592.555 780.722,592.561 780.732,592.567 780.741,592.574 780.75,592.58 780.759,592.586 780.768,592.593 780.777,592.599 780.787,592.605 780.796,592.611 780.805,592.618 780.814,592.624 780.823,592.63 780.833,592.636 780.842,592.643 780.851,592.649 780.86,592.655 780.869,592.661 780.879,592.668 780.888,592.674 780.897,592.68 780.906,592.686 780.915,592.693 780.925,592.699 780.934,592.705 780.943,592.711 780.952,592.718 780.961,592.724 780.97,592.73 780.98,592.736 780.989,592.742 780.998,592.749 781.007,592.755 781.016,592.761 781.026,592.767 781.035,592.773 781.044,592.78 781.053,592.786 781.062,592.792 781.072,592.798 781.081,592.804 781.09,592.811 781.099,592.817 781.108,592.823 781.117,592.829 781.127,592.835 781.136,592.841 781.145,592.848 781.154,592.854 781.163,592.86 781.173,592.866 781.182,592.872 781.191,592.878 781.2,592.885 781.209,592.891 781.219,592.897 781.228,592.903 781.237,592.909 781.246,592.915 781.255,592.921 781.265,592.927 781.274,592.934 781.283,592.94 781.292,592.946 781.301,592.952 781.31,592.958 781.32,592.964 781.329,592.97 781.338,592.976 781.347,592.983 781.356,592.989 781.366,592.995 781.375,593.001 781.384,593.007 781.393,593.013 781.402,593.019 781.412,593.025 781.421,593.031 781.43,593.037 781.439,593.043 781.448,593.05 781.457,593.056 781.467,593.062 781.476,593.068 781.485,593.074 781.494,593.08 781.503,593.086 781.513,593.092 781.522,593.098 781.531,593.104 781.54,593.11 781.549,593.116 781.559,593.122 781.568,593.128 781.577,593.134 781.586,593.14 781.595,593.146 781.605,593.152 781.614,593.158 781.623,593.164 781.632,593.17 781.641,593.176 781.65,593.183 781.66,593.189 781.669,593.195 781.678,593.201 781.687,593.207 781.696,593.213 781.706,593.219 781.715,593.225 781.724,593.231 781.733,593.237 781.742,593.243 781.752,593.249 781.761,593.255 781.77,593.26 781.779,593.266 781.788,593.272 781.797,593.278 781.807,593.284 781.816,593.29 781.825,593.296 781.834,593.302 781.843,593.308 781.853,593.314 781.862,593.32 781.871,593.326 781.88,593.332 781.889,593.338 781.899,593.344 781.908,593.35 781.917,593.356 781.926,593.362 781.935,593.368 781.945,593.374 781.954,593.38 781.963,593.386 781.972,593.391 781.981,593.397 781.99,593.403 782,593.409 782.009,593.415 782.018,593.421 782.027,593.427 782.036,593.433 782.046,593.439 782.055,593.445 782.064,593.451 782.073,593.456 782.082,593.462 782.092,593.468 782.101,593.474 782.11,593.48 782.119,593.486 782.128,593.492 782.137,593.498 782.147,593.504 782.156,593.509 782.165,593.515 782.174,593.521 782.183,593.527 782.193,593.533 782.202,593.539 782.211,593.545 782.22,593.55 782.229,593.556 782.239,593.562 782.248,593.568 782.257,593.574 782.266,593.58 782.275,593.585 782.285,593.591 782.294,593.597 782.303,593.603 782.312,593.609 782.321,593.615 782.33,593.62 782.34,593.626 782.349,593.632 782.358,593.638 782.367,593.644 782.376,593.65 782.386,593.655 782.395,593.661 782.404,593.667 782.413,593.673 782.422,593.679 782.432,593.684 782.441,593.69 782.45,593.696 782.459,593.702 782.468,593.708 782.477,593.713 782.487,593.719 782.496,593.725 782.505,593.731 782.514,593.736 782.523,593.742 782.533,593.748 782.542,593.754 782.551,593.759 782.56,593.765 782.569,593.771 782.579,593.777 782.588,593.783 782.597,593.788 782.606,593.794 782.615,593.8 782.625,593.805 782.634,593.811 782.643,593.817 782.652,593.823 782.661,593.828 782.67,593.834 782.68,593.84 782.689,593.846 782.698,593.851 782.707,593.857 782.716,593.863 782.726,593.868 782.735,593.874 782.744,593.88 782.753,593.886 782.762,593.891 782.772,593.897 782.781,593.903 782.79,593.908 782.799,593.914 782.808,593.92 782.818,593.926 782.827,593.931 782.836,593.937 782.845,593.943 782.854,593.948 782.863,593.954 782.873,593.96 782.882,593.965 782.891,593.971 782.9,593.977 782.909,593.982 782.919,593.988 782.928,593.994 782.937,593.999 782.946,594.005 782.955,594.011 782.965,594.016 782.974,594.022 782.983,594.028 782.992,594.033 783.001,594.039 783.01,594.044 783.02,594.05 783.029,594.056 783.038,594.061 783.047,594.067 783.056,594.073 783.066,594.078 783.075,594.084 783.084,594.089 783.093,594.095 783.102,594.101 783.112,594.106 783.121,594.112 783.13,594.118 783.139,594.123 783.148,594.129 783.158,594.134 783.167,594.14 783.176,594.146 783.185,594.151 783.194,594.157 783.203,594.162 783.213,594.168 783.222,594.173 783.231,594.179 783.24,594.185 783.249,594.19 783.259,594.196 783.268,594.201 783.277,594.207 783.286,594.212 783.295,594.218 783.305,594.224 783.314,594.229 783.323,594.235 783.332,594.24 783.341,594.246 783.35,594.251 783.36,594.257 783.369,594.262 783.378,594.268 783.387,594.274 783.396,594.279 783.406,594.285 783.415,594.29 783.424,594.296 783.433,594.301 783.442,594.307 783.452,594.312 783.461,594.318 783.47,594.323 783.479,594.329 783.488,594.334 783.498,594.34 783.507,594.345 783.516,594.351 783.525,594.356 783.534,594.362 783.543,594.367 783.553,594.373 783.562,594.378 783.571,594.384 783.58,594.389 783.589,594.395 783.599,594.4 783.608,594.406 783.617,594.411 783.626,594.417 783.635,594.422 783.645,594.428 783.654,594.433 783.663,594.439 783.672,594.444 783.681,594.449 783.69,594.455 783.7,594.46 783.709,594.466 783.718,594.471 783.727,594.477 783.736,594.482 783.746,594.488 783.755,594.493 783.764,594.499 783.773,594.504 783.782,594.509 783.792,594.515 783.801,594.52 783.81,594.526 783.819,594.531 783.828,594.537 783.838,594.542 783.847,594.547 783.856,594.553 783.865,594.558 783.874,594.564 783.883,594.569 783.893,594.574 783.902,594.58 783.911,594.585 783.92,594.591 783.929,594.596 783.939,594.601 783.948,594.607 783.957,594.612 783.966,594.618 783.975,594.623 783.985,594.628 783.994,594.634 784.003,594.639 784.012,594.645 784.021,594.65 784.03,594.655 784.04,594.661 784.049,594.666 784.058,594.671 784.067,594.677 784.076,594.682 784.086,594.687 784.095,594.693 784.104,594.698 784.113,594.704 784.122,594.709 784.132,594.714 784.141,594.72 784.15,594.725 784.159,594.73 784.168,594.736 784.178,594.741 784.187,594.746 784.196,594.752 784.205,594.757 784.214,594.762 784.223,594.768 784.233,594.773 784.242,594.778 784.251,594.784 784.26,594.789 784.269,594.794 784.279,594.799 784.288,594.805 784.297,594.81 784.306,594.815 784.315,594.821 784.325,594.826 784.334,594.831 784.343,594.837 784.352,594.842 784.361,594.847 784.37,594.852 784.38,594.858 784.389,594.863 784.398,594.868 784.407,594.874 784.416,594.879 784.426,594.884 784.435,594.889 784.444,594.895 784.453,594.9 784.462,594.905 784.472,594.91 784.481,594.916 784.49,594.921 784.499,594.926 784.508,594.932 784.518,594.937 784.527,594.942 784.536,594.947 784.545,594.953 784.554,594.958 784.563,594.963 784.573,594.968 784.582,594.973 784.591,594.979 784.6,594.984 784.609,594.989 784.619,594.994 784.628,595 784.637,595.005 784.646,595.01 784.655,595.015 784.665,595.02 784.674,595.026 784.683,595.031 784.692,595.036 784.701,595.041 784.71,595.047 784.72,595.052 784.729,595.057 784.738,595.062 784.747,595.067 784.756,595.073 784.766,595.078 784.775,595.083 784.784,595.088 784.793,595.093 784.802,595.098 784.812,595.104 784.821,595.109 784.83,595.114 784.839,595.119 784.848,595.124 784.858,595.13 784.867,595.135 784.876,595.14 784.885,595.145 784.894,595.15 784.903,595.155 784.913,595.16 784.922,595.166 784.931,595.171 784.94,595.176 784.949,595.181 784.959,595.186 784.968,595.191 784.977,595.197 784.986,595.202 784.995,595.207 785.005,595.212 785.014,595.217 785.023,595.222 785.032,595.227 785.041,595.232 785.051,595.238 785.06,595.243 785.069,595.248 785.078,595.253 785.087,595.258 785.096,595.263 785.106,595.268 785.115,595.273 785.124,595.278 785.133,595.284 785.142,595.289 785.152,595.294 785.161,595.299 785.17,595.304 785.179,595.309 785.188,595.314 785.198,595.319 785.207,595.324 785.216,595.329 785.225,595.334 785.234,595.34 785.243,595.345 785.253,595.35 785.262,595.355 785.271,595.36 785.28,595.365 785.289,595.37 785.299,595.375 785.308,595.38 785.317,595.385 785.326,595.39 785.335,595.395 785.345,595.4 785.354,595.405 785.363,595.41 785.372,595.415 785.381,595.421 785.391,595.426 785.4,595.431 785.409,595.436 785.418,595.441 785.427,595.446 785.436,595.451 785.446,595.456 785.455,595.461 785.464,595.466 785.473,595.471 785.482,595.476 785.492,595.481 785.501,595.486 785.51,595.491 785.519,595.496 785.528,595.501 785.538,595.506 785.547,595.511 785.556,595.516 785.565,595.521 785.574,595.526 785.583,595.531 785.593,595.536 785.602,595.541 785.611,595.546 785.62,595.551 785.629,595.556 785.639,595.561 785.648,595.566 785.657,595.571 785.666,595.576 785.675,595.581 785.685,595.586 785.694,595.591 785.703,595.596 785.712,595.601 785.721,595.606 785.731,595.611 785.74,595.616 785.749,595.621 785.758,595.625 785.767,595.63 785.776,595.635 785.786,595.64 785.795,595.645 785.804,595.65 785.813,595.655 785.822,595.66 785.832,595.665 785.841,595.67 785.85,595.675 785.859,595.68 785.868,595.685 785.878,595.69 785.887,595.695 785.896,595.7 785.905,595.705 785.914,595.709 785.923,595.714 785.933,595.719 785.942,595.724 785.951,595.729 785.96,595.734 785.969,595.739 785.979,595.744 785.988,595.749 785.997,595.754 786.006,595.759 786.015,595.763 786.025,595.768 786.034,595.773 786.043,595.778 786.052,595.783 786.061,595.788 786.071,595.793 786.08,595.798 786.089,595.803 786.098,595.807 786.107,595.812 786.116,595.817 786.126,595.822 786.135,595.827 786.144,595.832 786.153,595.837 786.162,595.842 786.172,595.846 786.181,595.851 786.19,595.856 786.199,595.861 786.208,595.866 786.218,595.871 786.227,595.876 786.236,595.88 786.245,595.885 786.254,595.89 786.263,595.895 786.273,595.9 786.282,595.905 786.291,595.909 786.3,595.914 786.309,595.919 786.319,595.924 786.328,595.929 786.337,595.934 786.346,595.938 786.355,595.943 786.365,595.948 786.374,595.953 786.383,595.958 786.392,595.962 786.401,595.967 786.411,595.972 786.42,595.977 786.429,595.982 786.438,595.987 786.447,595.991 786.456,595.996 786.466,596.001 786.475,596.006 786.484,596.011 786.493,596.015 786.502,596.02 786.512,596.025 786.521,596.03 786.53,596.034 786.539,596.039 786.548,596.044 786.558,596.049 786.567,596.054 786.576,596.058 786.585,596.063 786.594,596.068 786.603,596.073 786.613,596.077 786.622,596.082 786.631,596.087 786.64,596.092 786.649,596.096 786.659,596.101 786.668,596.106 786.677,596.111 786.686,596.115 786.695,596.12 786.705,596.125 786.714,596.13 786.723,596.134 786.732,596.139 786.741,596.144 786.751,596.149 786.76,596.153 786.769,596.158 786.778,596.163 786.787,596.168 786.796,596.172 786.806,596.177 786.815,596.182 786.824,596.186 786.833,596.191 786.842,596.196 786.852,596.201 786.861,596.205 786.87,596.21 786.879,596.215 786.888,596.219 786.898,596.224 786.907,596.229 786.916,596.234 786.925,596.238 786.934,596.243 786.943,596.248 786.953,596.252 786.962,596.257 786.971,596.262 786.98,596.266 786.989,596.271 786.999,596.276 787.008,596.28 787.017,596.285 787.026,596.29 787.035,596.294 787.045,596.299 787.054,596.304 787.063,596.308 787.072,596.313 787.081,596.318 787.091,596.322 787.1,596.327 787.109,596.332 787.118,596.336 787.127,596.341 787.136,596.346 787.146,596.35 787.155,596.355 787.164,596.36 787.173,596.364 787.182,596.369 787.192,596.374 787.201,596.378 787.21,596.383 787.219,596.388 787.228,596.392 787.238,596.397 787.247,596.401 787.256,596.406 787.265,596.411 787.274,596.415 787.283,596.42 787.293,596.425 787.302,596.429 787.311,596.434 787.32,596.438 787.329,596.443 787.339,596.448 787.348,596.452 787.357,596.457 787.366,596.461 787.375,596.466 787.385,596.471 787.394,596.475 787.403,596.48 787.412,596.484 787.421,596.489 787.431,596.494 787.44,596.498 787.449,596.503 787.458,596.507 787.467,596.512 787.476,596.517 787.486,596.521 787.495,596.526 787.504,596.53 787.513,596.535 787.522,596.539 787.532,596.544 787.541,596.549 787.55,596.553 787.559,596.558 787.568,596.562 787.578,596.567 787.587,596.571 787.596,596.576 787.605,596.58 787.614,596.585 787.624,596.59 787.633,596.594 787.642,596.599 787.651,596.603 787.66,596.608 787.669,596.612 787.679,596.617 787.688,596.621 787.697,596.626 787.706,596.63 787.715,596.635 787.725,596.639 787.734,596.644 787.743,596.649 787.752,596.653 787.761,596.658 787.771,596.662 787.78,596.667 787.789,596.671 787.798,596.676 787.807,596.68 787.816,596.685 787.826,596.689 787.835,596.694 787.844,596.698 787.853,596.703 787.862,596.707 787.872,596.712 787.881,596.716 787.89,596.721 787.899,596.725 787.908,596.73 787.918,596.734 787.927,596.739 787.936,596.743 787.945,596.748 787.954,596.752 787.964,596.757 787.973,596.761 787.982,596.766 787.991,596.77 788,596.774 788.009,596.779 788.019,596.783 788.028,596.788 788.037,596.792 788.046,596.797 788.055,596.801 788.065,596.806 788.074,596.81 788.083,596.815 788.092,596.819 788.101,596.824 788.111,596.828 788.12,596.832 788.129,596.837 788.138,596.841 788.147,596.846 788.156,596.85 788.166,596.855 788.175,596.859 788.184,596.864 788.193,596.868 788.202,596.872 788.212,596.877 788.221,596.881 788.23,596.886 788.239,596.89 788.248,596.895 788.258,596.899 788.267,596.903 788.276,596.908 788.285,596.912 788.294,596.917 788.304,596.921 788.313,596.925 788.322,596.93 788.331,596.934 788.34,596.939 788.349,596.943 788.359,596.947 788.368,596.952 788.377,596.956 788.386,596.961 788.395,596.965 788.405,596.969 788.414,596.974 788.423,596.978 788.432,596.983 788.441,596.987 788.451,596.991 788.46,596.996 788.469,597 788.478,597.004 788.487,597.009 788.496,597.013 788.506,597.018 788.515,597.022 788.524,597.026 788.533,597.031 788.542,597.035 788.552,597.039 788.561,597.044 788.57,597.048 788.579,597.052 788.588,597.057 788.598,597.061 788.607,597.066 788.616,597.07 788.625,597.074 788.634,597.079 788.644,597.083 788.653,597.087 788.662,597.092 788.671,597.096 788.68,597.1 788.689,597.105 788.699,597.109 788.708,597.113 788.717,597.118 788.726,597.122 788.735,597.126 788.745,597.131 788.754,597.135 788.763,597.139 788.772,597.144 788.781,597.148 788.791,597.152 788.8,597.156 788.809,597.161 788.818,597.165 788.827,597.169 788.836,597.174 788.846,597.178 788.855,597.182 788.864,597.187 788.873,597.191 788.882,597.195 788.892,597.2 788.901,597.204 788.91,597.208 788.919,597.212 788.928,597.217 788.938,597.221 788.947,597.225 788.956,597.23 788.965,597.234 788.974,597.238 788.984,597.242 788.993,597.247 789.002,597.251 789.011,597.255 789.02,597.259 789.029,597.264 789.039,597.268 789.048,597.272 789.057,597.277 789.066,597.281 789.075,597.285 789.085,597.289 789.094,597.294 789.103,597.298 789.112,597.302 789.121,597.306 789.131,597.311 789.14,597.315 789.149,597.319 789.158,597.323 789.167,597.328 789.176,597.332 789.186,597.336 789.195,597.34 789.204,597.345 789.213,597.349 789.222,597.353 789.232,597.357 789.241,597.361 789.25,597.366 789.259,597.37 789.268,597.374 789.278,597.378 789.287,597.383 789.296,597.387 789.305,597.391 789.314,597.395 789.324,597.399 789.333,597.404 789.342,597.408 789.351,597.412 789.36,597.416 789.369,597.42 789.379,597.425 789.388,597.429 789.397,597.433 789.406,597.437 789.415,597.441 789.425,597.446 789.434,597.45 789.443,597.454 789.452,597.458 789.461,597.462 789.471,597.467 789.48,597.471 789.489,597.475 789.498,597.479 789.507,597.483 789.516,597.487 789.526,597.492 789.535,597.496 789.544,597.5 789.553,597.504 789.562,597.508 789.572,597.512 789.581,597.517 789.59,597.521 789.599,597.525 789.608,597.529 789.618,597.533 789.627,597.537 789.636,597.542 789.645,597.546 789.654,597.55 789.664,597.554 789.673,597.558 789.682,597.562 789.691,597.566 789.7,597.571 789.709,597.575 789.719,597.579 789.728,597.583 789.737,597.587 789.746,597.591 789.755,597.595 789.765,597.6 789.774,597.604 789.783,597.608 789.792,597.612 789.801,597.616 789.811,597.62 789.82,597.624 789.829,597.628 789.838,597.633 789.847,597.637 789.856,597.641 789.866,597.645 789.875,597.649 789.884,597.653 789.893,597.657 789.902,597.661 789.912,597.665 789.921,597.669 789.93,597.674 789.939,597.678 789.948,597.682 789.958,597.686 789.967,597.69 789.976,597.694 789.985,597.698 789.994,597.702 790.004,597.706 790.013,597.71 790.022,597.714 790.031,597.719 790.04,597.723 790.049,597.727 790.059,597.731 790.068,597.735 790.077,597.739 790.086,597.743 790.095,597.747 790.105,597.751 790.114,597.755 790.123,597.759 790.132,597.763 790.141,597.767 790.151,597.771 790.16,597.775 790.169,597.78 790.178,597.784 790.187,597.788 790.197,597.792 790.206,597.796 790.215,597.8 790.224,597.804 790.233,597.808 790.242,597.812 790.252,597.816 790.261,597.82 790.27,597.824 790.279,597.828 790.288,597.832 790.298,597.836 790.307,597.84 790.316,597.844 790.325,597.848 790.334,597.852 790.344,597.856 790.353,597.86 790.362,597.864 790.371,597.868 790.38,597.872 790.389,597.876 790.399,597.88 790.408,597.884 790.417,597.888 790.426,597.892 790.435,597.896 790.445,597.9 790.454,597.904 790.463,597.908 790.472,597.912 790.481,597.916 790.491,597.92 790.5,597.924 790.509,597.928 790.518,597.932 790.527,597.936 790.537,597.94 790.546,597.944 790.555,597.948 790.564,597.952 790.573,597.956 790.582,597.96 790.592,597.964 790.601,597.968 790.61,597.972 790.619,597.976 790.628,597.98 790.638,597.984 790.647,597.988 790.656,597.992 790.665,597.996 790.674,598 790.684,598.004 790.693,598.008 790.702,598.012 790.711,598.016 790.72,598.02 790.729,598.024 790.739,598.028 790.748,598.032 790.757,598.036 790.766,598.04 790.775,598.043 790.785,598.047 790.794,598.051 790.803,598.055 790.812,598.059 790.821,598.063 790.831,598.067 790.84,598.071 790.849,598.075 790.858,598.079 790.867,598.083 790.877,598.087 790.886,598.091 790.895,598.095 790.904,598.099 790.913,598.102 790.922,598.106 790.932,598.11 790.941,598.114 790.95,598.118 790.959,598.122 790.968,598.126 790.978,598.13 790.987,598.134 790.996,598.138 791.005,598.142 791.014,598.146 791.024,598.149 791.033,598.153 791.042,598.157 791.051,598.161 791.06,598.165 791.069,598.169 791.079,598.173 791.088,598.177 791.097,598.181 791.106,598.184 791.115,598.188 791.125,598.192 791.134,598.196 791.143,598.2 791.152,598.204 791.161,598.208 791.171,598.212 791.18,598.216 791.189,598.219 791.198,598.223 791.207,598.227 791.217,598.231 791.226,598.235 791.235,598.239 791.244,598.243 791.253,598.246 791.262,598.25 791.272,598.254 791.281,598.258 791.29,598.262 791.299,598.266 791.308,598.27 791.318,598.273 791.327,598.277 791.336,598.281 791.345,598.285 791.354,598.289 791.364,598.293 791.373,598.297 791.382,598.3 791.391,598.304 791.4,598.308 791.409,598.312 791.419,598.316 791.428,598.32 791.437,598.323 791.446,598.327 791.455,598.331 791.465,598.335 791.474,598.339 791.483,598.343 791.492,598.346 791.501,598.35 791.511,598.354 791.52,598.358 791.529,598.362 791.538,598.365 791.547,598.369 791.557,598.373 791.566,598.377 791.575,598.381 791.584,598.384 791.593,598.388 791.602,598.392 791.612,598.396 791.621,598.4 791.63,598.403 791.639,598.407 791.648,598.411 791.658,598.415 791.667,598.419 791.676,598.422 791.685,598.426 791.694,598.43 791.704,598.434 791.713,598.438 791.722,598.441 791.731,598.445 791.74,598.449 791.749,598.453 791.759,598.456 791.768,598.46 791.777,598.464 791.786,598.468 791.795,598.472 791.805,598.475 791.814,598.479 791.823,598.483 791.832,598.487 791.841,598.49 791.851,598.494 791.86,598.498 791.869,598.502 791.878,598.505 791.887,598.509 791.897,598.513 791.906,598.517 791.915,598.52 791.924,598.524 791.933,598.528 791.942,598.532 791.952,598.535 791.961,598.539 791.97,598.543 791.979,598.547 791.988,598.55 791.998,598.554 792.007,598.558 792.016,598.562 792.025,598.565 792.034,598.569 792.044,598.573 792.053,598.576 792.062,598.58 792.071,598.584 792.08,598.588 792.089,598.591 792.099,598.595 792.108,598.599 792.117,598.603 792.126,598.606 792.135,598.61 792.145,598.614 792.154,598.617 792.163,598.621 792.172,598.625 792.181,598.629 792.191,598.632 792.2,598.636 792.209,598.64 792.218,598.643 792.227,598.647 792.237,598.651 792.246,598.654 792.255,598.658 792.264,598.662 792.273,598.665 792.282,598.669 792.292,598.673 792.301,598.677 792.31,598.68 792.319,598.684 792.328,598.688 792.338,598.691 792.347,598.695 792.356,598.699 792.365,598.702 792.374,598.706 792.384,598.71 792.393,598.713 792.402,598.717 792.411,598.721 792.42,598.724 792.43,598.728 792.439,598.732 792.448,598.735 792.457,598.739 792.466,598.743 792.475,598.746 792.485,598.75 792.494,598.754 792.503,598.757 792.512,598.761 792.521,598.765 792.531,598.768 792.54,598.772 792.549,598.776 792.558,598.779 792.567,598.783 792.577,598.786 792.586,598.79 792.595,598.794 792.604,598.797 792.613,598.801 792.622,598.805 792.632,598.808 792.641,598.812 792.65,598.816 792.659,598.819 792.668,598.823 792.678,598.826 792.687,598.83 792.696,598.834 792.705,598.837 792.714,598.841 792.724,598.845 792.733,598.848 792.742,598.852 792.751,598.855 792.76,598.859 792.77,598.863 792.779,598.866 792.788,598.87 792.797,598.873 792.806,598.877 792.815,598.881 792.825,598.884 792.834,598.888 792.843,598.891 792.852,598.895 792.861,598.899 792.871,598.902 792.88,598.906 792.889,598.909 792.898,598.913 792.907,598.917 792.917,598.92 792.926,598.924 792.935,598.927 792.944,598.931 792.953,598.934 792.962,598.938 792.972,598.942 792.981,598.945 792.99,598.949 792.999,598.952 793.008,598.956 793.018,598.96 793.027,598.963 793.036,598.967 793.045,598.97 793.054,598.974 793.064,598.977 793.073,598.981 793.082,598.984 793.091,598.988 793.1,598.992 793.11,598.995 793.119,598.999 793.128,599.002 793.137,599.006 793.146,599.009 793.155,599.013 793.165,599.016 793.174,599.02 793.183,599.024 793.192,599.027 793.201,599.031 793.211,599.034 793.22,599.038 793.229,599.041 793.238,599.045 793.247,599.048 793.257,599.052 793.266,599.055 793.275,599.059 793.284,599.062 793.293,599.066 793.302,599.069 793.312,599.073 793.321,599.077 793.33,599.08 793.339,599.084 793.348,599.087 793.358,599.091 793.367,599.094 793.376,599.098 793.385,599.101 793.394,599.105 793.404,599.108 793.413,599.112 793.422,599.115 793.431,599.119 793.44,599.122 793.45,599.126 793.459,599.129 793.468,599.133 793.477,599.136 793.486,599.14 793.495,599.143 793.505,599.147 793.514,599.15 793.523,599.154 793.532,599.157 793.541,599.161 793.551,599.164 793.56,599.168 793.569,599.171 793.578,599.175 793.587,599.178 793.597,599.182 793.606,599.185 793.615,599.189 793.624,599.192 793.633,599.195 793.642,599.199 793.652,599.202 793.661,599.206 793.67,599.209 793.679,599.213 793.688,599.216 793.698,599.22 793.707,599.223 793.716,599.227 793.725,599.23 793.734,599.234 793.744,599.237 793.753,599.241 793.762,599.244 793.771,599.247 793.78,599.251 793.79,599.254 793.799,599.258 793.808,599.261 793.817,599.265 793.826,599.268 793.835,599.272 793.845,599.275 793.854,599.278 793.863,599.282 793.872,599.285 793.881,599.289 793.891,599.292 793.9,599.296 793.909,599.299 793.918,599.303 793.927,599.306 793.937,599.309 793.946,599.313 793.955,599.316 793.964,599.32 793.973,599.323 793.982,599.326 793.992,599.33 794.001,599.333 794.01,599.337 794.019,599.34 794.028,599.344 794.038,599.347 794.047,599.35 794.056,599.354 794.065,599.357 794.074,599.361 794.084,599.364 794.093,599.367 794.102,599.371 794.111,599.374 794.12,599.378 794.13,599.381 794.139,599.384 794.148,599.388 794.157,599.391 794.166,599.395 794.175,599.398 794.185,599.401 794.194,599.405 794.203,599.408 794.212,599.412 794.221,599.415 794.231,599.418 794.24,599.422 794.249,599.425 794.258,599.428 794.267,599.432 794.277,599.435 794.286,599.439 794.295,599.442 794.304,599.445 794.313,599.449 794.322,599.452 794.332,599.455 794.341,599.459 794.35,599.462 794.359,599.466 794.368,599.469 794.378,599.472 794.387,599.476 794.396,599.479 794.405,599.482 794.414,599.486 794.424,599.489 794.433,599.492 794.442,599.496 794.451,599.499 794.46,599.503 794.47,599.506 794.479,599.509 794.488,599.513 794.497,599.516 794.506,599.519 794.515,599.523 794.525,599.526 794.534,599.529 794.543,599.533 794.552,599.536 794.561,599.539 794.571,599.543 794.58,599.546 794.589,599.549 794.598,599.553 794.607,599.556 794.617,599.559 794.626,599.563 794.635,599.566 794.644,599.569 794.653,599.573 794.662,599.576 794.672,599.579 794.681,599.583 794.69,599.586 794.699,599.589 794.708,599.592 794.718,599.596 794.727,599.599 794.736,599.602 794.745,599.606 794.754,599.609 794.764,599.612 794.773,599.616 794.782,599.619 794.791,599.622 794.8,599.626 794.81,599.629 794.819,599.632 794.828,599.635 794.837,599.639 794.846,599.642 794.855,599.645 794.865,599.649 794.874,599.652 794.883,599.655 794.892,599.658 794.901,599.662 794.911,599.665 794.92,599.668 794.929,599.672 794.938,599.675 794.947,599.678 794.957,599.681 794.966,599.685 794.975,599.688 794.984,599.691 794.993,599.695 795.003,599.698 795.012,599.701 795.021,599.704 795.03,599.708 795.039,599.711 795.048,599.714 795.058,599.717 795.067,599.721 795.076,599.724 795.085,599.727 795.094,599.73 795.104,599.734 795.113,599.737 795.122,599.74 795.131,599.743 795.14,599.747 795.15,599.75 795.159,599.753 795.168,599.756 795.177,599.76 795.186,599.763 795.195,599.766 795.205,599.769 795.214,599.773 795.223,599.776 795.232,599.779 795.241,599.782 795.251,599.786 795.26,599.789 795.269,599.792 795.278,599.795 795.287,599.799 795.297,599.802 795.306,599.805 795.315,599.808 795.324,599.811 795.333,599.815 795.343,599.818 795.352,599.821 795.361,599.824 795.37,599.828 795.379,599.831 795.388,599.834 795.398,599.837 795.407,599.84 795.416,599.844 795.425,599.847 795.434,599.85 795.444,599.853 795.453,599.856 795.462,599.86 795.471,599.863 795.48,599.866 795.49,599.869 795.499,599.872 795.508,599.876 795.517,599.879 795.526,599.882 795.535,599.885 795.545,599.888 795.554,599.892 795.563,599.895 795.572,599.898 795.581,599.901 795.591,599.904 795.6,599.908 795.609,599.911 795.618,599.914 795.627,599.917 795.637,599.92 795.646,599.924 795.655,599.927 795.664,599.93 795.673,599.933 795.683,599.936 795.692,599.939 795.701,599.943 795.71,599.946 795.719,599.949 795.728,599.952 795.738,599.955 795.747,599.958 795.756,599.962 795.765,599.965 795.774,599.968 795.784,599.971 795.793,599.974 795.802,599.977 795.811,599.981 795.82,599.984 795.83,599.987 795.839,599.99 795.848,599.993 795.857,599.996 795.866,599.999 795.875,600.003 795.885,600.006 795.894,600.009 795.903,600.012 795.912,600.015 795.921,600.018 795.931,600.021 795.94,600.025 795.949,600.028 795.958,600.031 795.967,600.034 795.977,600.037 795.986,600.04 795.995,600.043 796.004,600.047 796.013,600.05 796.023,600.053 796.032,600.056 796.041,600.059 796.05,600.062 796.059,600.065 796.068,600.068 796.078,600.072 796.087,600.075 796.096,600.078 796.105,600.081 796.114,600.084 796.124,600.087 796.133,600.09 796.142,600.093 796.151,600.096 796.16,600.1 796.17,600.103 796.179,600.106 796.188,600.109 796.197,600.112 796.206,600.115 796.215,600.118 796.225,600.121 796.234,600.124 796.243,600.127 796.252,600.131 796.261,600.134 796.271,600.137 796.28,600.14 796.289,600.143 796.298,600.146 796.307,600.149 796.317,600.152 796.326,600.155 796.335,600.158 796.344,600.161 796.353,600.165 796.363,600.168 796.372,600.171 796.381,600.174 796.39,600.177 796.399,600.18 796.408,600.183 796.418,600.186 796.427,600.189 796.436,600.192 796.445,600.195 796.454,600.198 796.464,600.201 796.473,600.204 796.482,600.208 796.491,600.211 796.5,600.214 796.51,600.217 796.519,600.22 796.528,600.223 796.537,600.226 796.546,600.229 796.555,600.232 796.565,600.235 796.574,600.238 796.583,600.241 796.592,600.244 796.601,600.247 796.611,600.25 796.62,600.253 796.629,600.256 796.638,600.259 796.647,600.263 796.657,600.266 796.666,600.269 796.675,600.272 796.684,600.275 796.693,600.278 796.703,600.281 796.712,600.284 796.721,600.287 796.73,600.29 796.739,600.293 796.748,600.296 796.758,600.299 796.767,600.302 796.776,600.305 796.785,600.308 796.794,600.311 796.804,600.314 796.813,600.317 796.822,600.32 796.831,600.323 796.84,600.326 796.85,600.329 796.859,600.332 796.868,600.335 796.877,600.338 796.886,600.341 796.895,600.344 796.905,600.347 796.914,600.35 796.923,600.353 796.932,600.356 796.941,600.359 796.951,600.362 796.96,600.365 796.969,600.368 796.978,600.371 796.987,600.374 796.997,600.377 797.006,600.38 797.015,600.383 797.024,600.386 797.033,600.389 797.043,600.392 797.052,600.395 797.061,600.398 797.07,600.401 797.079,600.404 797.088,600.407 797.098,600.41 797.107,600.413 797.116,600.416 797.125,600.419 797.134,600.422 797.144,600.425 797.153,600.428 797.162,600.431 797.171,600.434 797.18,600.437 797.19,600.44 797.199,600.443 797.208,600.446 797.217,600.449 797.226,600.452 797.235,600.455 797.245,600.458 797.254,600.461 797.263,600.464 797.272,600.467 797.281,600.47 797.291,600.473 797.3,600.475 797.309,600.478 797.318,600.481 797.327,600.484 797.337,600.487 797.346,600.49 797.355,600.493 797.364,600.496 797.373,600.499 797.383,600.502 797.392,600.505 797.401,600.508 797.41,600.511 797.419,600.514 797.428,600.517 797.438,600.52 797.447,600.523 797.456,600.526 797.465,600.528 797.474,600.531 797.484,600.534 797.493,600.537 797.502,600.54 797.511,600.543 797.52,600.546 797.53,600.549 797.539,600.552 797.548,600.555 797.557,600.558 797.566,600.561 797.576,600.564 797.585,600.567 797.594,600.569 797.603,600.572 797.612,600.575 797.621,600.578 797.631,600.581 797.64,600.584 797.649,600.587 797.658,600.59 797.667,600.593 797.677,600.596 797.686,600.599 797.695,600.602 797.704,600.604 797.713,600.607 797.723,600.61 797.732,600.613 797.741,600.616 797.75,600.619 797.759,600.622 797.768,600.625 797.778,600.628 797.787,600.631 797.796,600.633 797.805,600.636 797.814,600.639 797.824,600.642 797.833,600.645 797.842,600.648 797.851,600.651 797.86,600.654 797.87,600.657 797.879,600.659 797.888,600.662 797.897,600.665 797.906,600.668 797.916,600.671 797.925,600.674 797.934,600.677 797.943,600.68 797.952,600.682 797.961,600.685 797.971,600.688 797.98,600.691 797.989,600.694 797.998,600.697 798.007,600.7 798.017,600.702 798.026,600.705 798.035,600.708 798.044,600.711 798.053,600.714 798.063,600.717 798.072,600.72 798.081,600.723 798.09,600.725 798.099,600.728 798.108,600.731 798.118,600.734 798.127,600.737 798.136,600.74 798.145,600.742 798.154,600.745 798.164,600.748 798.173,600.751 798.182,600.754 798.191,600.757 798.2,600.76 798.21,600.762 798.219,600.765 798.228,600.768 798.237,600.771 798.246,600.774 798.256,600.777 798.265,600.779 798.274,600.782 798.283,600.785 798.292,600.788 798.301,600.791 798.311,600.794 798.32,600.796 798.329,600.799 798.338,600.802 798.347,600.805 798.357,600.808 798.366,600.811 798.375,600.813 798.384,600.816 798.393,600.819 798.403,600.822 798.412,600.825 798.421,600.827 798.43,600.83 798.439,600.833 798.448,600.836 798.458,600.839 798.467,600.842 798.476,600.844 798.485,600.847 798.494,600.85 798.504,600.853 798.513,600.856 798.522,600.858 798.531,600.861 798.54,600.864 798.55,600.867 798.559,600.87 798.568,600.872 798.577,600.875 798.586,600.878 798.596,600.881 798.605,600.884 798.614,600.886 798.623,600.889 798.632,600.892 798.641,600.895 798.651,600.897 798.66,600.9 798.669,600.903 798.678,600.906 798.687,600.909 798.697,600.911 798.706,600.914 798.715,600.917 798.724,600.92 798.733,600.922 798.743,600.925 798.752,600.928 798.761,600.931 798.77,600.934 798.779,600.936 798.788,600.939 798.798,600.942 798.807,600.945 798.816,600.947 798.825,600.95 798.834,600.953 798.844,600.956 798.853,600.958 798.862,600.961 798.871,600.964 798.88,600.967 798.89,600.97 798.899,600.972 798.908,600.975 798.917,600.978 798.926,600.981 798.936,600.983 798.945,600.986 798.954,600.989 798.963,600.992 798.972,600.994 798.981,600.997 798.991,601 799,601.003 799.009,601.005 799.018,601.008 799.027,601.011 799.037,601.014 799.046,601.016 799.055,601.019 799.064,601.022 799.073,601.024 799.083,601.027 799.092,601.03 799.101,601.033 799.11,601.035 799.119,601.038 799.128,601.041 799.138,601.044 799.147,601.046 799.156,601.049 799.165,601.052 799.174,601.054 799.184,601.057 799.193,601.06 799.202,601.063 799.211,601.065 799.22,601.068 799.23,601.071 799.239,601.074 799.248,601.076 799.257,601.079 799.266,601.082 799.276,601.084 799.285,601.087 799.294,601.09 799.303,601.093 799.312,601.095 799.321,601.098 799.331,601.101 799.34,601.103 799.349,601.106 799.358,601.109 799.367,601.111 799.377,601.114 799.386,601.117 799.395,601.12 799.404,601.122 799.413,601.125 799.423,601.128 799.432,601.13 799.441,601.133 799.45,601.136 799.459,601.138 799.468,601.141 799.478,601.144 799.487,601.146 799.496,601.149 799.505,601.152 799.514,601.155 799.524,601.157 799.533,601.16 799.542,601.163 799.551,601.165 799.56,601.168 799.57,601.171 799.579,601.173 799.588,601.176 799.597,601.179 799.606,601.181 799.616,601.184 799.625,601.187 799.634,601.189 799.643,601.192 799.652,601.195 799.661,601.197 799.671,601.2 799.68,601.203 799.689,601.205 799.698,601.208 799.707,601.211 799.717,601.213 799.726,601.216 799.735,601.219 799.744,601.221 799.753,601.224 799.763,601.227 799.772,601.229 799.781,601.232 799.79,601.235 799.799,601.237 799.809,601.24 799.818,601.242 799.827,601.245 799.836,601.248 799.845,601.25 799.854,601.253 799.864,601.256 799.873,601.258 799.882,601.261 799.891,601.264 799.9,601.266 799.91,601.269 799.919,601.272 799.928,601.274 799.937,601.277 799.946,601.279 799.956,601.282 799.965,601.285 799.974,601.287 799.983,601.29 799.992,601.293 800.001,601.295 800.011,601.298 800.02,601.3 800.029,601.303 800.038,601.306 800.047,601.308 800.057,601.311 800.066,601.314 800.075,601.316 800.084,601.319 800.093,601.321 800.103,601.324 800.112,601.327 800.121,601.329 800.13,601.332 800.139,601.335 800.149,601.337 800.158,601.34 800.167,601.342 800.176,601.345 800.185,601.348 800.194,601.35 800.204,601.353 800.213,601.355 800.222,601.358 800.231,601.361 800.24,601.363 800.25,601.366 800.259,601.368 800.268,601.371 800.277,601.374 800.286,601.376 800.296,601.379 800.305,601.381 800.314,601.384 800.323,601.387 800.332,601.389 800.341,601.392 800.351,601.394 800.36,601.397 800.369,601.399 800.378,601.402 800.387,601.405 800.397,601.407 800.406,601.41 800.415,601.412 800.424,601.415 800.433,601.418 800.443,601.42 800.452,601.423 800.461,601.425 800.47,601.428 800.479,601.43 800.489,601.433 800.498,601.436 800.507,601.438 800.516,601.441 800.525,601.443 800.534,601.446 800.544,601.448 800.553,601.451 800.562,601.453 800.571,601.456 800.58,601.459 800.59,601.461 800.599,601.464 800.608,601.466 800.617,601.469 800.626,601.471 800.636,601.474 800.645,601.477 800.654,601.479 800.663,601.482 800.672,601.484 800.681,601.487 800.691,601.489 800.7,601.492 800.709,601.494 800.718,601.497 800.727,601.499 800.737,601.502 800.746,601.505 800.755,601.507 800.764,601.51 800.773,601.512 800.783,601.515 800.792,601.517 800.801,601.52 800.81,601.522 800.819,601.525 800.829,601.527 800.838,601.53 800.847,601.532 800.856,601.535 800.865,601.538 800.874,601.54 800.884,601.543 800.893,601.545 800.902,601.548 800.911,601.55 800.92,601.553 800.93,601.555 800.939,601.558 800.948,601.56 800.957,601.563 800.966,601.565 800.976,601.568 800.985,601.57 800.994,601.573 801.003,601.575 801.012,601.578 801.021,601.58 801.031,601.583 801.04,601.585 801.049,601.588 801.058,601.59 801.067,601.593 801.077,601.595 801.086,601.598 801.095,601.6 801.104,601.603 801.113,601.605 801.123,601.608 801.132,601.61 801.141,601.613 801.15,601.615 801.159,601.618 801.169,601.62 801.178,601.623 801.187,601.625 801.196,601.628 801.205,601.63 801.214,601.633 801.224,601.635 801.233,601.638 801.242,601.64 801.251,601.643 801.26,601.645 801.27,601.648 801.279,601.65 801.288,601.653 801.297,601.655 801.306,601.658 801.316,601.66 801.325,601.663 801.334,601.665 801.343,601.668 801.352,601.67 801.361,601.673 801.371,601.675 801.38,601.678 801.389,601.68 801.398,601.683 801.407,601.685 801.417,601.687 801.426,601.69 801.435,601.692 801.444,601.695 801.453,601.697 801.463,601.7 801.472,601.702 801.481,601.705 801.49,601.707 801.499,601.71 801.509,601.712 801.518,601.715 801.527,601.717 801.536,601.719 801.545,601.722 801.554,601.724 801.564,601.727 801.573,601.729 801.582,601.732 801.591,601.734 801.6,601.737 801.61,601.739 801.619,601.742 801.628,601.744 801.637,601.746 801.646,601.749 801.656,601.751 801.665,601.754 801.674,601.756 801.683,601.759 801.692,601.761 801.701,601.764 801.711,601.766 801.72,601.768 801.729,601.771 801.738,601.773 801.747,601.776 801.757,601.778 801.766,601.781 801.775,601.783 801.784,601.785 801.793,601.788 801.803,601.79 801.812,601.793 801.821,601.795 801.83,601.798 801.839,601.8 801.849,601.802 801.858,601.805 801.867,601.807 801.876,601.81 801.885,601.812 801.894,601.815 801.904,601.817 801.913,601.819 801.922,601.822 801.931,601.824 801.94,601.827 801.95,601.829 801.959,601.831 801.968,601.834 801.977,601.836 801.986,601.839 801.996,601.841 802.005,601.843 802.014,601.846 802.023,601.848 802.032,601.851 802.041,601.853 802.051,601.855 802.06,601.858 802.069,601.86 802.078,601.863 802.087,601.865 802.097,601.867 802.106,601.87 802.115,601.872 802.124,601.875 802.133,601.877 802.143,601.879 802.152,601.882 802.161,601.884 802.17,601.887 802.179,601.889 802.189,601.891 802.198,601.894 802.207,601.896 802.216,601.899 802.225,601.901 802.234,601.903 802.244,601.906 802.253,601.908 802.262,601.91 802.271,601.913 802.28,601.915 802.29,601.918 802.299,601.92 802.308,601.922 802.317,601.925 802.326,601.927 802.336,601.929 802.345,601.932 802.354,601.934 802.363,601.937 802.372,601.939 802.382,601.941 802.391,601.944 802.4,601.946 802.409,601.948 802.418,601.951 802.427,601.953 802.437,601.955 802.446,601.958 802.455,601.96 802.464,601.963 802.473,601.965 802.483,601.967 802.492,601.97 802.501,601.972 802.51,601.974 802.519,601.977 802.529,601.979 802.538,601.981 802.547,601.984 802.556,601.986 802.565,601.988 802.574,601.991 802.584,601.993 802.593,601.995 802.602,601.998 802.611,602 802.62,602.003 802.63,602.005 802.639,602.007 802.648,602.01 802.657,602.012 802.666,602.014 802.676,602.017 802.685,602.019 802.694,602.021 802.703,602.024 802.712,602.026 802.722,602.028 802.731,602.031 802.74,602.033 802.749,602.035 802.758,602.038 802.767,602.04 802.777,602.042 802.786,602.045 802.795,602.047 802.804,602.049 802.813,602.051 802.823,602.054 802.832,602.056 802.841,602.058 802.85,602.061 802.859,602.063 802.869,602.065 802.878,602.068 802.887,602.07 802.896,602.072 802.905,602.075 802.914,602.077 802.924,602.079 802.933,602.082 802.942,602.084 802.951,602.086 802.96,602.089 802.97,602.091 802.979,602.093 802.988,602.095 802.997,602.098 803.006,602.1 803.016,602.102 803.025,602.105 803.034,602.107 803.043,602.109 803.052,602.112 803.062,602.114 803.071,602.116 803.08,602.118 803.089,602.121 803.098,602.123 803.107,602.125 803.117,602.128 803.126,602.13 803.135,602.132 803.144,602.134 803.153,602.137 803.163,602.139 803.172,602.141 803.181,602.144 803.19,602.146 803.199,602.148 803.209,602.15 803.218,602.153 803.227,602.155 803.236,602.157 803.245,602.16 803.254,602.162 803.264,602.164 803.273,602.166 803.282,602.169 803.291,602.171 803.3,602.173 803.31,602.176 803.319,602.178 803.328,602.18 803.337,602.182 803.346,602.185 803.356,602.187 803.365,602.189 803.374,602.191 803.383,602.194 803.392,602.196 803.402,602.198 803.411,602.2 803.42,602.203 803.429,602.205 803.438,602.207 803.447,602.21 803.457,602.212 803.466,602.214 803.475,602.216 803.484,602.219 803.493,602.221 803.503,602.223 803.512,602.225 803.521,602.228 803.53,602.23 803.539,602.232 803.549,602.234 803.558,602.237 803.567,602.239 803.576,602.241 803.585,602.243 803.594,602.246 803.604,602.248 803.613,602.25 803.622,602.252 803.631,602.254 803.64,602.257 803.65,602.259 803.659,602.261 803.668,602.263 803.677,602.266 803.686,602.268 803.696,602.27 803.705,602.272 803.714,602.275 803.723,602.277 803.732,602.279 803.742,602.281 803.751,602.284 803.76,602.286 803.769,602.288 803.778,602.29 803.787,602.292 803.797,602.295 803.806,602.297 803.815,602.299 803.824,602.301 803.833,602.304 803.843,602.306 803.852,602.308 803.861,602.31 803.87,602.312 803.879,602.315 803.889,602.317 803.898,602.319 803.907,602.321 803.916,602.324 803.925,602.326 803.934,602.328 803.944,602.33 803.953,602.332 803.962,602.335 803.971,602.337 803.98,602.339 803.99,602.341 803.999,602.343 804.008,602.346 804.017,602.348 804.026,602.35 804.036,602.352 804.045,602.354 804.054,602.357 804.063,602.359 804.072,602.361 804.082,602.363 804.091,602.365 804.1,602.368 804.109,602.37 804.118,602.372 804.127,602.374 804.137,602.376 804.146,602.379 804.155,602.381 804.164,602.383 804.173,602.385 804.183,602.387 804.192,602.389 804.201,602.392 804.21,602.394 804.219,602.396 804.229,602.398 804.238,602.4 804.247,602.403 804.256,602.405 804.265,602.407 804.274,602.409 804.284,602.411 804.293,602.413 804.302,602.416 804.311,602.418 804.32,602.42 804.33,602.422 804.339,602.424 804.348,602.427 804.357,602.429 804.366,602.431 804.376,602.433 804.385,602.435 804.394,602.437 804.403,602.44 804.412,602.442 804.422,602.444 804.431,602.446 804.44,602.448 804.449,602.45 804.458,602.453 804.467,602.455 804.477,602.457 804.486,602.459 804.495,602.461 804.504,602.463 804.513,602.465 804.523,602.468 804.532,602.47 804.541,602.472 804.55,602.474 804.559,602.476 804.569,602.478 804.578,602.481 804.587,602.483 804.596,602.485 804.605,602.487 804.614,602.489 804.624,602.491 804.633,602.493 804.642,602.496 804.651,602.498 804.66,602.5 804.67,602.502 804.679,602.504 804.688,602.506 804.697,602.508 804.706,602.511 804.716,602.513 804.725,602.515 804.734,602.517 804.743,602.519 804.752,602.521 804.762,602.523 804.771,602.525 804.78,602.528 804.789,602.53 804.798,602.532 804.807,602.534 804.817,602.536 804.826,602.538 804.835,602.54 804.844,602.542 804.853,602.545 804.863,602.547 804.872,602.549 804.881,602.551 804.89,602.553 804.899,602.555 804.909,602.557 804.918,602.559 804.927,602.562 804.936,602.564 804.945,602.566 804.955,602.568 804.964,602.57 804.973,602.572 804.982,602.574 804.991,602.576 805,602.578 805.01,602.581 805.019,602.583 805.028,602.585 805.037,602.587 805.046,602.589 805.056,602.591 805.065,602.593 805.074,602.595 805.083,602.597 805.092,602.6 805.102,602.602 805.111,602.604 805.12,602.606 805.129,602.608 805.138,602.61 805.147,602.612 805.157,602.614 805.166,602.616 805.175,602.618 805.184,602.621 805.193,602.623 805.203,602.625 805.212,602.627 805.221,602.629 805.23,602.631 805.239,602.633 805.249,602.635 805.258,602.637 805.267,602.639 805.276,602.641 805.285,602.643 805.295,602.646 805.304,602.648 805.313,602.65 805.322,602.652 805.331,602.654 805.34,602.656 805.35,602.658 805.359,602.66 805.368,602.662 805.377,602.664 805.386,602.666 805.396,602.668 805.405,602.67 805.414,602.673 805.423,602.675 805.432,602.677 805.442,602.679 805.451,602.681 805.46,602.683 805.469,602.685 805.478,602.687 805.487,602.689 805.497,602.691 805.506,602.693 805.515,602.695 805.524,602.697 805.533,602.699 805.543,602.701 805.552,602.704 805.561,602.706 805.57,602.708 805.579,602.71 805.589,602.712 805.598,602.714 805.607,602.716 805.616,602.718 805.625,602.72 805.635,602.722 805.644,602.724 805.653,602.726 805.662,602.728 805.671,602.73 805.68,602.732 805.69,602.734 805.699,602.736 805.708,602.738 805.717,602.74 805.726,602.742 805.736,602.745 805.745,602.747 805.754,602.749 805.763,602.751 805.772,602.753 805.782,602.755 805.791,602.757 805.8,602.759 805.809,602.761 805.818,602.763 805.827,602.765 805.837,602.767 805.846,602.769 805.855,602.771 805.864,602.773 805.873,602.775 805.883,602.777 805.892,602.779 805.901,602.781 805.91,602.783 805.919,602.785 805.929,602.787 805.938,602.789 805.947,602.791 805.956,602.793 805.965,602.795 805.975,602.797 805.984,602.799 805.993,602.801 806.002,602.803 806.011,602.805 806.02,602.807 806.03,602.809 806.039,602.811 806.048,602.813 806.057,602.816 806.066,602.818 806.076,602.82 806.085,602.822 806.094,602.824 806.103,602.826 806.112,602.828 806.122,602.83 806.131,602.832 806.14,602.834 806.149,602.836 806.158,602.838 806.167,602.84 806.177,602.842 806.186,602.844 806.195,602.846 806.204,602.848 806.213,602.85 806.223,602.852 806.232,602.854 806.241,602.856 806.25,602.858 806.259,602.86 806.269,602.862 806.278,602.864 806.287,602.866 806.296,602.868 806.305,602.87 806.315,602.872 806.324,602.874 806.333,602.876 806.342,602.878 806.351,602.88 806.36,602.882 806.37,602.884 806.379,602.885 806.388,602.887 806.397,602.889 806.406,602.891 806.416,602.893 806.425,602.895 806.434,602.897 806.443,602.899 806.452,602.901 806.462,602.903 806.471,602.905 806.48,602.907 806.489,602.909 806.498,602.911 806.507,602.913 806.517,602.915 806.526,602.917 806.535,602.919 806.544,602.921 806.553,602.923 806.563,602.925 806.572,602.927 806.581,602.929 806.59,602.931 806.599,602.933 806.609,602.935 806.618,602.937 806.627,602.939 806.636,602.941 806.645,602.943 806.655,602.945 806.664,602.947 806.673,602.949 806.682,602.951 806.691,602.953 806.7,602.954 806.71,602.956 806.719,602.958 806.728,602.96 806.737,602.962 806.746,602.964 806.756,602.966 806.765,602.968 806.774,602.97 806.783,602.972 806.792,602.974 806.802,602.976 806.811,602.978 806.82,602.98 806.829,602.982 806.838,602.984 806.847,602.986 806.857,602.988 806.866,602.99 806.875,602.992 806.884,602.993 806.893,602.995 806.903,602.997 806.912,602.999 806.921,603.001 806.93,603.003 806.939,603.005 806.949,603.007 806.958,603.009 806.967,603.011 806.976,603.013 806.985,603.015 806.995,603.017 807.004,603.019 807.013,603.021 807.022,603.022 807.031,603.024 807.04,603.026 807.05,603.028 807.059,603.03 807.068,603.032 807.077,603.034 807.086,603.036 807.096,603.038 807.105,603.04 807.114,603.042 807.123,603.044 807.132,603.046 807.142,603.047 807.151,603.049 807.16,603.051 807.169,603.053 807.178,603.055 807.188,603.057 807.197,603.059 807.206,603.061 807.215,603.063 807.224,603.065 807.233,603.067 807.243,603.069 807.252,603.07 807.261,603.072 807.27,603.074 807.279,603.076 807.289,603.078 807.298,603.08 807.307,603.082 807.316,603.084 807.325,603.086 807.335,603.088 807.344,603.09 807.353,603.091 807.362,603.093 807.371,603.095 807.38,603.097 807.39,603.099 807.399,603.101 807.408,603.103 807.417,603.105 807.426,603.107 807.436,603.109 807.445,603.11 807.454,603.112 807.463,603.114 807.472,603.116 807.482,603.118 807.491,603.12 807.5,603.122 807.509,603.124 807.518,603.126 807.528,603.127 807.537,603.129 807.546,603.131 807.555,603.133 807.564,603.135 807.573,603.137 807.583,603.139 807.592,603.141 807.601,603.142 807.61,603.144 807.619,603.146 807.629,603.148 807.638,603.15 807.647,603.152 807.656,603.154 807.665,603.156 807.675,603.157 807.684,603.159 807.693,603.161 807.702,603.163 807.711,603.165 807.72,603.167 807.73,603.169 807.739,603.171 807.748,603.172 807.757,603.174 807.766,603.176 807.776,603.178 807.785,603.18 807.794,603.182 807.803,603.184 807.812,603.186 807.822,603.187 807.831,603.189 807.84,603.191 807.849,603.193 807.858,603.195 807.868,603.197 807.877,603.199 807.886,603.2 807.895,603.202 807.904,603.204 807.913,603.206 807.923,603.208 807.932,603.21 807.941,603.212 807.95,603.213 807.959,603.215 807.969,603.217 807.978,603.219 807.987,603.221 807.996,603.223 808.005,603.224 808.015,603.226 808.024,603.228 808.033,603.23 808.042,603.232 808.051,603.234 808.06,603.236 808.07,603.237 808.079,603.239 808.088,603.241 808.097,603.243 808.106,603.245 808.116,603.247 808.125,603.248 808.134,603.25 808.143,603.252 808.152,603.254 808.162,603.256 808.171,603.258 808.18,603.259 808.189,603.261 808.198,603.263 808.208,603.265 808.217,603.267 808.226,603.269 808.235,603.27 808.244,603.272 808.253,603.274 808.263,603.276 808.272,603.278 808.281,603.28 808.29,603.281 808.299,603.283 808.309,603.285 808.318,603.287 808.327,603.289 808.336,603.29 808.345,603.292 808.355,603.294 808.364,603.296 808.373,603.298 808.382,603.3 808.391,603.301 808.4,603.303 808.41,603.305 808.419,603.307 808.428,603.309 808.437,603.31 808.446,603.312 808.456,603.314 808.465,603.316 808.474,603.318 808.483,603.32 808.492,603.321 808.502,603.323 808.511,603.325 808.52,603.327 808.529,603.329 808.538,603.33 808.548,603.332 808.557,603.334 808.566,603.336 808.575,603.338 808.584,603.339 808.593,603.341 808.603,603.343 808.612,603.345 808.621,603.347 808.63,603.348 808.639,603.35 808.649,603.352 808.658,603.354 808.667,603.356 808.676,603.357 808.685,603.359 808.695,603.361 808.704,603.363 808.713,603.364 808.722,603.366 808.731,603.368 808.74,603.37 808.75,603.372 808.759,603.373 808.768,603.375 808.777,603.377 808.786,603.379 808.796,603.381 808.805,603.382 808.814,603.384 808.823,603.386 808.832,603.388 808.842,603.389 808.851,603.391 808.86,603.393 808.869,603.395 808.878,603.397 808.888,603.398 808.897,603.4 808.906,603.402 808.915,603.404 808.924,603.405 808.933,603.407 808.943,603.409 808.952,603.411 808.961,603.413 808.97,603.414 808.979,603.416 808.989,603.418 808.998,603.42 809.007,603.421 809.016,603.423 809.025,603.425 809.035,603.427 809.044,603.428 809.053,603.43 809.062,603.432 809.071,603.434 809.08,603.435 809.09,603.437 809.099,603.439 809.108,603.441 809.117,603.443 809.126,603.444 809.136,603.446 809.145,603.448 809.154,603.45 809.163,603.451 809.172,603.453 809.182,603.455 809.191,603.457 809.2,603.458 809.209,603.46 809.218,603.462 809.228,603.464 809.237,603.465 809.246,603.467 809.255,603.469 809.264,603.471 809.273,603.472 809.283,603.474 809.292,603.476 809.301,603.478 809.31,603.479 809.319,603.481 809.329,603.483 809.338,603.484 809.347,603.486 809.356,603.488 809.365,603.49 809.375,603.491 809.384,603.493 809.393,603.495 809.402,603.497 809.411,603.498 809.42,603.5 809.43,603.502 809.439,603.504 809.448,603.505 809.457,603.507 809.466,603.509 809.476,603.511 809.485,603.512 809.494,603.514 809.503,603.516 809.512,603.517 809.522,603.519 809.531,603.521 809.54,603.523 809.549,603.524 809.558,603.526 809.568,603.528 809.577,603.529 809.586,603.531 809.595,603.533 809.604,603.535 809.613,603.536 809.623,603.538 809.632,603.54 809.641,603.542 809.65,603.543 809.659,603.545 809.669,603.547 809.678,603.548 809.687,603.55 809.696,603.552 809.705,603.554 809.715,603.555 809.724,603.557 809.733,603.559 809.742,603.56 809.751,603.562 809.761,603.564 809.77,603.565 809.779,603.567 809.788,603.569 809.797,603.571 809.806,603.572 809.816,603.574 809.825,603.576 809.834,603.577 809.843,603.579 809.852,603.581 809.862,603.583 809.871,603.584 809.88,603.586 809.889,603.588 809.898,603.589 809.908,603.591 809.917,603.593 809.926,603.594 809.935,603.596 809.944,603.598 809.953,603.599 809.963,603.601 809.972,603.603 809.981,603.605 809.99,603.606 809.999,603.608 810.009,603.61 810.018,603.611 810.027,603.613 810.036,603.615 810.045,603.616 810.055,603.618 810.064,603.62 810.073,603.621 810.082,603.623 810.091,603.625 810.101,603.626 810.11,603.628 810.119,603.63 810.128,603.632 810.137,603.633 810.146,603.635 810.156,603.637 810.165,603.638 810.174,603.64 810.183,603.642 810.192,603.643 810.202,603.645 810.211,603.647 810.22,603.648 810.229,603.65 810.238,603.652 810.248,603.653 810.257,603.655 810.266,603.657 810.275,603.658 810.284,603.66 810.293,603.662 810.303,603.663 810.312,603.665 810.321,603.667 810.33,603.668 810.339,603.67 810.349,603.672 810.358,603.673 810.367,603.675 810.376,603.677 810.385,603.678 810.395,603.68 810.404,603.682 810.413,603.683 810.422,603.685 810.431,603.687 810.441,603.688 810.45,603.69 810.459,603.692 810.468,603.693 810.477,603.695 810.486,603.697 810.496,603.698 810.505,603.7 810.514,603.701 810.523,603.703 810.532,603.705 810.542,603.706 810.551,603.708 810.56,603.71 810.569,603.711 810.578,603.713 810.588,603.715 810.597,603.716 810.606,603.718 810.615,603.72 810.624,603.721 810.633,603.723 810.643,603.725 810.652,603.726 810.661,603.728 810.67,603.729 810.679,603.731 810.689,603.733 810.698,603.734 810.707,603.736 810.716,603.738 810.725,603.739 810.735,603.741 810.744,603.743 810.753,603.744 810.762,603.746 810.771,603.747 810.781,603.749 810.79,603.751 810.799,603.752 810.808,603.754 810.817,603.756 810.826,603.757 810.836,603.759 810.845,603.76 810.854,603.762 810.863,603.764 810.872,603.765 810.882,603.767 810.891,603.769 810.9,603.77 810.909,603.772 810.918,603.773 810.928,603.775 810.937,603.777 810.946,603.778 810.955,603.78 810.964,603.782 810.973,603.783 810.983,603.785 810.992,603.786 811.001,603.788 811.01,603.79 811.019,603.791 811.029,603.793 811.038,603.794 811.047,603.796 811.056,603.798 811.065,603.799 811.075,603.801 811.084,603.803 811.093,603.804 811.102,603.806 811.111,603.807 811.121,603.809 811.13,603.811 811.139,603.812 811.148,603.814 811.157,603.815 811.166,603.817 811.176,603.819 811.185,603.82 811.194,603.822 811.203,603.823 811.212,603.825 811.222,603.827 811.231,603.828 811.24,603.83 811.249,603.831 811.258,603.833 811.268,603.835 811.277,603.836 811.286,603.838 811.295,603.839 811.304,603.841 811.313,603.843 811.323,603.844 811.332,603.846 811.341,603.847 811.35,603.849 811.359,603.851 811.369,603.852 811.378,603.854 811.387,603.855 811.396,603.857 811.405,603.858 811.415,603.86 811.424,603.862 811.433,603.863 811.442,603.865 811.451,603.866 811.461,603.868 811.47,603.87 811.479,603.871 811.488,603.873 811.497,603.874 811.506,603.876 811.516,603.877 811.525,603.879 811.534,603.881 811.543,603.882 811.552,603.884 811.562,603.885 811.571,603.887 811.58,603.888 811.589,603.89 811.598,603.892 811.608,603.893 811.617,603.895 811.626,603.896 811.635,603.898 811.644,603.899 811.653,603.901 811.663,603.903 811.672,603.904 811.681,603.906 811.69,603.907 811.699,603.909 811.709,603.91 811.718,603.912 811.727,603.914 811.736,603.915 811.745,603.917 811.755,603.918 811.764,603.92 811.773,603.921 811.782,603.923 811.791,603.924 811.801,603.926 811.81,603.928 811.819,603.929 811.828,603.931 811.837,603.932 811.846,603.934 811.856,603.935 811.865,603.937 811.874,603.938 811.883,603.94 811.892,603.942 811.902,603.943 811.911,603.945 811.92,603.946 811.929,603.948 811.938,603.949 811.948,603.951 811.957,603.952 811.966,603.954 811.975,603.956 811.984,603.957 811.993,603.959 812.003,603.96 812.012,603.962 812.021,603.963 812.03,603.965 812.039,603.966 812.049,603.968 812.058,603.969 812.067,603.971 812.076,603.972 812.085,603.974 812.095,603.976 812.104,603.977 812.113,603.979 812.122,603.98 812.131,603.982 812.141,603.983 812.15,603.985 812.159,603.986 812.168,603.988 812.177,603.989 812.186,603.991 812.196,603.992 812.205,603.994 812.214,603.995 812.223,603.997 812.232,603.999 812.242,604 812.251,604.002 812.26,604.003 812.269,604.005 812.278,604.006 812.288,604.008 812.297,604.009 812.306,604.011 812.315,604.012 812.324,604.014 812.334,604.015 812.343,604.017 812.352,604.018 812.361,604.02 812.37,604.021 812.379,604.023 812.389,604.024 812.398,604.026 812.407,604.027 812.416,604.029 812.425,604.03 812.435,604.032 812.444,604.034 812.453,604.035 812.462,604.037 812.471,604.038 812.481,604.04 812.49,604.041 812.499,604.043 812.508,604.044 812.517,604.046 812.526,604.047 812.536,604.049 812.545,604.05 812.554,604.052 812.563,604.053 812.572,604.055 812.582,604.056 812.591,604.058 812.6,604.059 812.609,604.061 812.618,604.062 812.628,604.064 812.637,604.065 812.646,604.067 812.655,604.068 812.664,604.07 812.674,604.071 812.683,604.073 812.692,604.074 812.701,604.076 812.71,604.077 812.719,604.079 812.729,604.08 812.738,604.082 812.747,604.083 812.756,604.085 812.765,604.086 812.775,604.088 812.784,604.089 812.793,604.091 812.802,604.092 812.811,604.094 812.821,604.095 812.83,604.096 812.839,604.098 812.848,604.099 812.857,604.101 812.866,604.102 812.876,604.104 812.885,604.105 812.894,604.107 812.903,604.108 812.912,604.11 812.922,604.111 812.931,604.113 812.94,604.114 812.949,604.116 812.958,604.117 812.968,604.119 812.977,604.12 812.986,604.122 812.995,604.123 813.004,604.125 813.014,604.126 813.023,604.128 813.032,604.129 813.041,604.131 813.05,604.132 813.059,604.133 813.069,604.135 813.078,604.136 813.087,604.138 813.096,604.139 813.105,604.141 813.115,604.142 813.124,604.144 813.133,604.145 813.142,604.147 813.151,604.148 813.161,604.15 813.17,604.151 813.179,604.153 813.188,604.154 813.197,604.155 813.206,604.157 813.216,604.158 813.225,604.16 813.234,604.161 813.243,604.163 813.252,604.164 813.262,604.166 813.271,604.167 813.28,604.169 813.289,604.17 813.298,604.172 813.308,604.173 813.317,604.174 813.326,604.176 813.335,604.177 813.344,604.179 813.354,604.18 813.363,604.182 813.372,604.183 813.381,604.185 813.39,604.186 813.399,604.187 813.409,604.189 813.418,604.19 813.427,604.192 813.436,604.193 813.445,604.195 813.455,604.196 813.464,604.198 813.473,604.199 813.482,604.2 813.491,604.202 813.501,604.203 813.51,604.205 813.519,604.206 813.528,604.208 813.537,604.209 813.546,604.211 813.556,604.212 813.565,604.213 813.574,604.215 813.583,604.216 813.592,604.218 813.602,604.219 813.611,604.221 813.62,604.222 813.629,604.223 813.638,604.225 813.648,604.226 813.657,604.228 813.666,604.229 813.675,604.231 813.684,604.232 813.694,604.234 813.703,604.235 813.712,604.236 813.721,604.238 813.73,604.239 813.739,604.241 813.749,604.242 813.758,604.244 813.767,604.245 813.776,604.246 813.785,604.248 813.795,604.249 813.804,604.251 813.813,604.252 813.822,604.253 813.831,604.255 813.841,604.256 813.85,604.258 813.859,604.259 813.868,604.261 813.877,604.262 813.886,604.263 813.896,604.265 813.905,604.266 813.914,604.268 813.923,604.269 813.932,604.27 813.942,604.272 813.951,604.273 813.96,604.275 813.969,604.276 813.978,604.278 813.988,604.279 813.997,604.28 814.006,604.282 814.015,604.283 814.024,604.285 814.034,604.286 814.043,604.287 814.052,604.289 814.061,604.29 814.07,604.292 814.079,604.293 814.089,604.294 814.098,604.296 814.107,604.297 814.116,604.299 814.125,604.3 814.135,604.301 814.144,604.303 814.153,604.304 814.162,604.306 814.171,604.307 814.181,604.308 814.19,604.31 814.199,604.311 814.208,604.313 814.217,604.314 814.226,604.315 814.236,604.317 814.245,604.318 814.254,604.32 814.263,604.321 814.272,604.322 814.282,604.324 814.291,604.325 814.3,604.327 814.309,604.328 814.318,604.329 814.328,604.331 814.337,604.332 814.346,604.333 814.355,604.335 814.364,604.336 814.374,604.338 814.383,604.339 814.392,604.34 814.401,604.342 814.41,604.343 814.419,604.345 814.429,604.346 814.438,604.347 814.447,604.349 814.456,604.35 814.465,604.351 814.475,604.353 814.484,604.354 814.493,604.356 814.502,604.357 814.511,604.358 814.521,604.36 814.53,604.361 814.539,604.362 814.548,604.364 814.557,604.365 814.566,604.367 814.576,604.368 814.585,604.369 814.594,604.371 814.603,604.372 814.612,604.373 814.622,604.375 814.631,604.376 814.64,604.378 814.649,604.379 814.658,604.38 814.668,604.382 814.677,604.383 814.686,604.384 814.695,604.386 814.704,604.387 814.714,604.388 814.723,604.39 814.732,604.391 814.741,604.393 814.75,604.394 814.759,604.395 814.769,604.397 814.778,604.398 814.787,604.399 814.796,604.401 814.805,604.402 814.815,604.403 814.824,604.405 814.833,604.406 814.842,604.408 814.851,604.409 814.861,604.41 814.87,604.412 814.879,604.413 814.888,604.414 814.897,604.416 814.907,604.417 814.916,604.418 814.925,604.42 814.934,604.421 814.943,604.422 814.952,604.424 814.962,604.425 814.971,604.426 814.98,604.428 814.989,604.429 814.998,604.43 815.008,604.432 815.017,604.433 815.026,604.435 815.035,604.436 815.044,604.437 815.054,604.439 815.063,604.44 815.072,604.441 815.081,604.443 815.09,604.444 815.099,604.445 815.109,604.447 815.118,604.448 815.127,604.449 815.136,604.451 815.145,604.452 815.155,604.453 815.164,604.455 815.173,604.456 815.182,604.457 815.191,604.459 815.201,604.46 815.21,604.461 815.219,604.463 815.228,604.464 815.237,604.465 815.247,604.467 815.256,604.468 815.265,604.469 815.274,604.471 815.283,604.472 815.292,604.473 815.302,604.475 815.311,604.476 815.32,604.477 815.329,604.479 815.338,604.48 815.348,604.481 815.357,604.483 815.366,604.484 815.375,604.485 815.384,604.486 815.394,604.488 815.403,604.489 815.412,604.49 815.421,604.492 815.43,604.493 815.439,604.494 815.449,604.496 815.458,604.497 815.467,604.498 815.476,604.5 815.485,604.501 815.495,604.502 815.504,604.504 815.513,604.505 815.522,604.506 815.531,604.508 815.541,604.509 815.55,604.51 815.559,604.512 815.568,604.513 815.577,604.514 815.587,604.515 815.596,604.517 815.605,604.518 815.614,604.519 815.623,604.521 815.632,604.522 815.642,604.523 815.651,604.525 815.66,604.526 815.669,604.527 815.678,604.529 815.688,604.53 815.697,604.531 815.706,604.532 815.715,604.534 815.724,604.535 815.734,604.536 815.743,604.538 815.752,604.539 815.761,604.54 815.77,604.542 815.779,604.543 815.789,604.544 815.798,604.545 815.807,604.547 815.816,604.548 815.825,604.549 815.835,604.551 815.844,604.552 815.853,604.553 815.862,604.554 815.871,604.556 815.881,604.557 815.89,604.558 815.899,604.56 815.908,604.561 815.917,604.562 815.927,604.564 815.936,604.565 815.945,604.566 815.954,604.567 815.963,604.569 815.972,604.57 815.982,604.571 815.991,604.573 816,604.574 816.009,604.575 816.018,604.576 816.028,604.578 816.037,604.579 816.046,604.58 816.055,604.582 816.064,604.583 816.074,604.584 816.083,604.585 816.092,604.587 816.101,604.588 816.11,604.589 816.119,604.59 816.129,604.592 816.138,604.593 816.147,604.594 816.156,604.596 816.165,604.597 816.175,604.598 816.184,604.599 816.193,604.601 816.202,604.602 816.211,604.603 816.221,604.604 816.23,604.606 816.239,604.607 816.248,604.608 816.257,604.61 816.267,604.611 816.276,604.612 816.285,604.613 816.294,604.615 816.303,604.616 816.312,604.617 816.322,604.618 816.331,604.62 816.34,604.621 816.349,604.622 816.358,604.623 816.368,604.625 816.377,604.626 816.386,604.627 816.395,604.629 816.404,604.63 816.414,604.631 816.423,604.632 816.432,604.634 816.441,604.635 816.45,604.636 816.459,604.637 816.469,604.639 816.478,604.64 816.487,604.641 816.496,604.642 816.505,604.644 816.515,604.645 816.524,604.646 816.533,604.647 816.542,604.649 816.551,604.65 816.561,604.651 816.57,604.652 816.579,604.654 816.588,604.655 816.597,604.656 816.607,604.657 816.616,604.659 816.625,604.66 816.634,604.661 816.643,604.662 816.652,604.664 816.662,604.665 816.671,604.666 816.68,604.667 816.689,604.669 816.698,604.67 816.708,604.671 816.717,604.672 816.726,604.674 816.735,604.675 816.744,604.676 816.754,604.677 816.763,604.679 816.772,604.68 816.781,604.681 816.79,604.682 816.799,604.684 816.809,604.685 816.818,604.686 816.827,604.687 816.836,604.688 816.845,604.69 816.855,604.691 816.864,604.692 816.873,604.693 816.882,604.695 816.891,604.696 816.901,604.697 816.91,604.698 816.919,604.7 816.928,604.701 816.937,604.702 816.947,604.703 816.956,604.704 816.965,604.706 816.974,604.707 816.983,604.708 816.992,604.709 817.002,604.711 817.011,604.712 817.02,604.713 817.029,604.714 817.038,604.716 817.048,604.717 817.057,604.718 817.066,604.719 817.075,604.72 817.084,604.722 817.094,604.723 817.103,604.724 817.112,604.725 817.121,604.726 817.13,604.728 817.14,604.729 817.149,604.73 817.158,604.731 817.167,604.733 817.176,604.734 817.185,604.735 817.195,604.736 817.204,604.737 817.213,604.739 817.222,604.74 817.231,604.741 817.241,604.742 817.25,604.744 817.259,604.745 817.268,604.746 817.277,604.747 817.287,604.748 817.296,604.75 817.305,604.751 817.314,604.752 817.323,604.753 817.332,604.754 817.342,604.756 817.351,604.757 817.36,604.758 817.369,604.759 817.378,604.76 817.388,604.762 817.397,604.763 817.406,604.764 817.415,604.765 817.424,604.766 817.434,604.768 817.443,604.769 817.452,604.77 817.461,604.771 817.47,604.772 817.48,604.774 817.489,604.775 817.498,604.776 817.507,604.777 817.516,604.778 817.525,604.78 817.535,604.781 817.544,604.782 817.553,604.783 817.562,604.784 817.571,604.786 817.581,604.787 817.59,604.788 817.599,604.789 817.608,604.79 817.617,604.792 817.627,604.793 817.636,604.794 817.645,604.795 817.654,604.796 817.663,604.798 817.672,604.799 817.682,604.8 817.691,604.801 817.7,604.802 817.709,604.803 817.718,604.805 817.728,604.806 817.737,604.807 817.746,604.808 817.755,604.809 817.764,604.811 817.774,604.812 817.783,604.813 817.792,604.814 817.801,604.815 817.81,604.816 817.82,604.818 817.829,604.819 817.838,604.82 817.847,604.821 817.856,604.822 817.865,604.824 817.875,604.825 817.884,604.826 817.893,604.827 817.902,604.828 817.911,604.829 817.921,604.831 817.93,604.832 817.939,604.833 817.948,604.834 817.957,604.835 817.967,604.836 817.976,604.838 817.985,604.839 817.994,604.84 818.003,604.841 818.012,604.842 818.022,604.843 818.031,604.845 818.04,604.846 818.049,604.847 818.058,604.848 818.068,604.849 818.077,604.85 818.086,604.852 818.095,604.853 818.104,604.854 818.114,604.855 818.123,604.856 818.132,604.857 818.141,604.859 818.15,604.86 818.16,604.861 818.169,604.862 818.178,604.863 818.187,604.864 818.196,604.866 818.205,604.867 818.215,604.868 818.224,604.869 818.233,604.87 818.242,604.871 818.251,604.873 818.261,604.874 818.27,604.875 818.279,604.876 818.288,604.877 818.297,604.878 818.307,604.879 818.316,604.881 818.325,604.882 818.334,604.883 818.343,604.884 818.352,604.885 818.362,604.886 818.371,604.887 818.38,604.889 818.389,604.89 818.398,604.891 818.408,604.892 818.417,604.893 818.426,604.894 818.435,604.896 818.444,604.897 818.454,604.898 818.463,604.899 818.472,604.9 818.481,604.901 818.49,604.902 818.5,604.904 818.509,604.905 818.518,604.906 818.527,604.907 818.536,604.908 818.545,604.909 818.555,604.91 818.564,604.912 818.573,604.913 818.582,604.914 818.591,604.915 818.601,604.916 818.61,604.917 818.619,604.918 818.628,604.919 818.637,604.921 818.647,604.922 818.656,604.923 818.665,604.924 818.674,604.925 818.683,604.926 818.692,604.927 818.702,604.929 818.711,604.93 818.72,604.931 818.729,604.932 818.738,604.933 818.748,604.934 818.757,604.935 818.766,604.936 818.775,604.938 818.784,604.939 818.794,604.94 818.803,604.941 818.812,604.942 818.821,604.943 818.83,604.944 818.84,604.945 818.849,604.947 818.858,604.948 818.867,604.949 818.876,604.95 818.885,604.951 818.895,604.952 818.904,604.953 818.913,604.954 818.922,604.956 818.931,604.957 818.941,604.958 818.95,604.959 818.959,604.96 818.968,604.961 818.977,604.962 818.987,604.963 818.996,604.964 819.005,604.966 819.014,604.967 819.023,604.968 819.032,604.969 819.042,604.97 819.051,604.971 819.06,604.972 819.069,604.973 819.078,604.974 819.088,604.976 819.097,604.977 819.106,604.978 819.115,604.979 819.124,604.98 819.134,604.981 819.143,604.982 819.152,604.983 819.161,604.984 819.17,604.986 819.18,604.987 819.189,604.988 819.198,604.989 819.207,604.99 819.216,604.991 819.225,604.992 819.235,604.993 819.244,604.994 819.253,604.996 819.262,604.997 819.271,604.998 819.281,604.999 819.29,605 819.299,605.001 819.308,605.002 819.317,605.003 819.327,605.004 819.336,605.005 819.345,605.006 819.354,605.008 819.363,605.009 819.372,605.01 819.382,605.011 819.391,605.012 819.4,605.013 819.409,605.014 819.418,605.015 819.428,605.016 819.437,605.017 819.446,605.019 819.455,605.02 819.464,605.021 819.474,605.022 819.483,605.023 819.492,605.024 819.501,605.025 819.51,605.026 819.52,605.027 819.529,605.028 819.538,605.029 819.547,605.031 819.556,605.032 819.565,605.033 819.575,605.034 819.584,605.035 819.593,605.036 819.602,605.037 819.611,605.038 819.621,605.039 819.63,605.04 819.639,605.041 819.648,605.042 819.657,605.044 819.667,605.045 819.676,605.046 819.685,605.047 819.694,605.048 819.703,605.049 819.713,605.05 819.722,605.051 819.731,605.052 819.74,605.053 819.749,605.054 819.758,605.055 819.768,605.056 819.777,605.058 819.786,605.059 819.795,605.06 819.804,605.061 819.814,605.062 819.823,605.063 819.832,605.064 819.841,605.065 819.85,605.066 819.86,605.067 819.869,605.068 819.878,605.069 819.887,605.07 819.896,605.071 819.905,605.073 819.915,605.074 819.924,605.075 819.933,605.076 819.942,605.077 819.951,605.078 819.961,605.079 819.97,605.08 819.979,605.081 819.988,605.082 819.997,605.083 820.007,605.084 820.016,605.085 820.025,605.086 820.034,605.087 820.043,605.088 820.053,605.09 820.062,605.091 820.071,605.092 820.08,605.093 820.089,605.094 820.098,605.095 820.108,605.096 820.117,605.097 820.126,605.098 820.135,605.099 820.144,605.1 820.154,605.101 820.163,605.102 820.172,605.103 820.181,605.104 820.19,605.105 820.2,605.106 820.209,605.107 820.218,605.109 820.227,605.11 820.236,605.111 820.245,605.112 820.255,605.113 820.264,605.114 820.273,605.115 820.282,605.116 820.291,605.117 820.301,605.118 820.31,605.119 820.319,605.12 820.328,605.121 820.337,605.122 820.347,605.123 820.356,605.124 820.365,605.125 820.374,605.126 820.383,605.127 820.393,605.128 820.402,605.129 820.411,605.131 820.42,605.132 820.429,605.133 820.438,605.134 820.448,605.135 820.457,605.136 820.466,605.137 820.475,605.138 820.484,605.139 820.494,605.14 820.503,605.141 820.512,605.142 820.521,605.143 820.53,605.144 820.54,605.145 820.549,605.146 820.558,605.147 820.567,605.148 820.576,605.149 820.585,605.15 820.595,605.151 820.604,605.152 820.613,605.153 820.622,605.154 820.631,605.155 820.641,605.156 820.65,605.157 820.659,605.158 820.668,605.16 820.677,605.161 820.687,605.162 820.696,605.163 820.705,605.164 820.714,605.165 820.723,605.166 820.733,605.167 820.742,605.168 820.751,605.169 820.76,605.17 820.769,605.171 820.778,605.172 820.788,605.173 820.797,605.174 820.806,605.175 820.815,605.176 820.824,605.177 820.834,605.178 820.843,605.179 820.852,605.18 820.861,605.181 820.87,605.182 820.88,605.183 820.889,605.184 820.898,605.185 820.907,605.186 820.916,605.187 820.925,605.188 820.935,605.189 820.944,605.19 820.953,605.191 820.962,605.192 820.971,605.193 820.981,605.194 820.99,605.195 820.999,605.196 821.008,605.197 821.017,605.198 821.027,605.199 821.036,605.2 821.045,605.201 821.054,605.202 821.063,605.203 821.073,605.204 821.082,605.205 821.091,605.206 821.1,605.207 821.109,605.208 821.118,605.209 821.128,605.21 821.137,605.211 821.146,605.212 821.155,605.213 821.164,605.214 821.174,605.215 821.183,605.216 821.192,605.217 821.201,605.218 821.21,605.219 821.22,605.22 821.229,605.221 821.238,605.222 821.247,605.223 821.256,605.224 821.265,605.225 821.275,605.226 821.284,605.227 821.293,605.228 821.302,605.229 821.311,605.23 821.321,605.231 821.33,605.232 821.339,605.233 821.348,605.234 821.357,605.235 821.367,605.236 821.376,605.237 821.385,605.238 821.394,605.239 821.403,605.24 821.413,605.241 821.422,605.242 821.431,605.243 821.44,605.244 821.449,605.245 821.458,605.246 821.468,605.247 821.477,605.248 821.486,605.249 821.495,605.25 821.504,605.251 821.514,605.252 821.523,605.253 821.532,605.254 821.541,605.255 821.55,605.256 821.56,605.257 821.569,605.258 821.578,605.259 821.587,605.26 821.596,605.261 821.605,605.262 821.615,605.263 821.624,605.264 821.633,605.265 821.642,605.266 821.651,605.267 821.661,605.268 821.67,605.269 821.679,605.27 821.688,605.271 821.697,605.272 821.707,605.273 821.716,605.274 821.725,605.275 821.734,605.276 821.743,605.277 821.753,605.278 821.762,605.279 821.771,605.28 821.78,605.281 821.789,605.282 821.798,605.283 821.808,605.284 821.817,605.285 821.826,605.286 821.835,605.287 821.844,605.288 821.854,605.288 821.863,605.289 821.872,605.29 821.881,605.291 821.89,605.292 821.9,605.293 821.909,605.294 821.918,605.295 821.927,605.296 821.936,605.297 821.945,605.298 821.955,605.299 821.964,605.3 821.973,605.301 821.982,605.302 821.991,605.303 822.001,605.304 822.01,605.305 822.019,605.306 822.028,605.307 822.037,605.308 822.047,605.309 822.056,605.31 822.065,605.311 822.074,605.312 822.083,605.313 822.093,605.314 822.102,605.315 822.111,605.316 822.12,605.316 822.129,605.317 822.138,605.318 822.148,605.319 822.157,605.32 822.166,605.321 822.175,605.322 822.184,605.323 822.194,605.324 822.203,605.325 822.212,605.326 822.221,605.327 822.23,605.328 822.24,605.329 822.249,605.33 822.258,605.331 822.267,605.332 822.276,605.333 822.286,605.334 822.295,605.335 822.304,605.336 822.313,605.337 822.322,605.337 822.331,605.338 822.341,605.339 822.35,605.34 822.359,605.341 822.368,605.342 822.377,605.343 822.387,605.344 822.396,605.345 822.405,605.346 822.414,605.347 822.423,605.348 822.433,605.349 822.442,605.35 822.451,605.351 822.46,605.352 822.469,605.353 822.478,605.354 822.488,605.354 822.497,605.355 822.506,605.356 822.515,605.357 822.524,605.358 822.534,605.359 822.543,605.36 822.552,605.361 822.561,605.362 822.57,605.363 822.58,605.364 822.589,605.365 822.598,605.366 822.607,605.367 822.616,605.368 822.626,605.369 822.635,605.369 822.644,605.37 822.653,605.371 822.662,605.372 822.671,605.373 822.681,605.374 822.69,605.375 822.699,605.376 822.708,605.377 822.717,605.378 822.727,605.379 822.736,605.38 822.745,605.381 822.754,605.382 822.763,605.383 822.773,605.383 822.782,605.384 822.791,605.385 822.8,605.386 822.809,605.387 822.818,605.388 822.828,605.389 822.837,605.39 822.846,605.391 822.855,605.392 822.864,605.393 822.874,605.394 822.883,605.395 822.892,605.395 822.901,605.396 822.91,605.397 822.92,605.398 822.929,605.399 822.938,605.4 822.947,605.401 822.956,605.402 822.966,605.403 822.975,605.404 822.984,605.405 822.993,605.406 823.002,605.407 823.011,605.407 823.021,605.408 823.03,605.409 823.039,605.41 823.048,605.411 823.057,605.412 823.067,605.413 823.076,605.414 823.085,605.415 823.094,605.416 823.103,605.417 823.113,605.417 823.122,605.418 823.131,605.419 823.14,605.42 823.149,605.421 823.158,605.422 823.168,605.423 823.177,605.424 823.186,605.425 823.195,605.426 823.204,605.427 823.214,605.427 823.223,605.428 823.232,605.429 823.241,605.43 823.25,605.431 823.26,605.432 823.269,605.433 823.278,605.434 823.287,605.435 823.296,605.436 823.306,605.437 823.315,605.437 823.324,605.438 823.333,605.439 823.342,605.44 823.351,605.441 823.361,605.442 823.37,605.443 823.379,605.444 823.388,605.445 823.397,605.446 823.407,605.446 823.416,605.447 823.425,605.448 823.434,605.449 823.443,605.45 823.453,605.451 823.462,605.452 823.471,605.453 823.48,605.454 823.489,605.455 823.498,605.455 823.508,605.456 823.517,605.457 823.526,605.458 823.535,605.459 823.544,605.46 823.554,605.461 823.563,605.462 823.572,605.463 823.581,605.463 823.59,605.464 823.6,605.465 823.609,605.466 823.618,605.467 823.627,605.468 823.636,605.469 823.646,605.47 823.655,605.471 823.664,605.471 823.673,605.472 823.682,605.473 823.691,605.474 823.701,605.475 823.71,605.476 823.719,605.477 823.728,605.478 823.737,605.479 823.747,605.479 823.756,605.48 823.765,605.481 823.774,605.482 823.783,605.483 823.793,605.484 823.802,605.485 823.811,605.486 823.82,605.487 823.829,605.487 823.838,605.488 823.848,605.489 823.857,605.49 823.866,605.491 823.875,605.492 823.884,605.493 823.894,605.494 823.903,605.494 823.912,605.495 823.921,605.496 823.93,605.497 823.94,605.498 823.949,605.499 823.958,605.5 823.967,605.501 823.976,605.501 823.986,605.502 823.995,605.503 824.004,605.504 824.013,605.505 824.022,605.506 824.031,605.507 824.041,605.508 824.05,605.508 824.059,605.509 824.068,605.51 824.077,605.511 824.087,605.512 824.096,605.513 824.105,605.514 824.114,605.514 824.123,605.515 824.133,605.516 824.142,605.517 824.151,605.518 824.16,605.519 824.169,605.52 824.178,605.521 824.188,605.521 824.197,605.522 824.206,605.523 824.215,605.524 824.224,605.525 824.234,605.526 824.243,605.527 824.252,605.527 824.261,605.528 824.27,605.529 824.28,605.53 824.289,605.531 824.298,605.532 824.307,605.533 824.316,605.533 824.326,605.534 824.335,605.535 824.344,605.536 824.353,605.537 824.362,605.538 824.371,605.539 824.381,605.539 824.39,605.54 824.399,605.541 824.408,605.542 824.417,605.543 824.427,605.544 824.436,605.545 824.445,605.545 824.454,605.546 824.463,605.547 824.473,605.548 824.482,605.549 824.491,605.55 824.5,605.551 824.509,605.551 824.519,605.552 824.528,605.553 824.537,605.554 824.546,605.555 824.555,605.556 824.564,605.557 824.574,605.557 824.583,605.558 824.592,605.559 824.601,605.56 824.61,605.561 824.62,605.562 824.629,605.562 824.638,605.563 824.647,605.564 824.656,605.565 824.666,605.566 824.675,605.567 824.684,605.568 824.693,605.568 824.702,605.569 824.711,605.57 824.721,605.571 824.73,605.572 824.739,605.573 824.748,605.573 824.757,605.574 824.767,605.575 824.776,605.576 824.785,605.577 824.794,605.578 824.803,605.578 824.813,605.579 824.822,605.58 824.831,605.581 824.84,605.582 824.849,605.583 824.859,605.583 824.868,605.584 824.877,605.585 824.886,605.586 824.895,605.587 824.904,605.588 824.914,605.588 824.923,605.589 824.932,605.59 824.941,605.591 824.95,605.592 824.96,605.593 824.969,605.593 824.978,605.594 824.987,605.595 824.996,605.596 825.006,605.597 825.015,605.598 825.024,605.598 825.033,605.599 825.042,605.6 825.051,605.601 825.061,605.602 825.07,605.603 825.079,605.603 825.088,605.604 825.097,605.605 825.107,605.606 825.116,605.607 825.125,605.608 825.134,605.608 825.143,605.609 825.153,605.61 825.162,605.611 825.171,605.612 825.18,605.612 825.189,605.613 825.199,605.614 825.208,605.615 825.217,605.616 825.226,605.617 825.235,605.617 825.244,605.618 825.254,605.619 825.263,605.62 825.272,605.621 825.281,605.621 825.29,605.622 825.3,605.623 825.309,605.624 825.318,605.625 825.327,605.626 825.336,605.626 825.346,605.627 825.355,605.628 825.364,605.629 825.373,605.63 825.382,605.63 825.391,605.631 825.401,605.632 825.41,605.633 825.419,605.634 825.428,605.635 825.437,605.635 825.447,605.636 825.456,605.637 825.465,605.638 825.474,605.639 825.483,605.639 825.493,605.64 825.502,605.641 825.511,605.642 825.52,605.643 825.529,605.643 825.539,605.644 825.548,605.645 825.557,605.646 825.566,605.647 825.575,605.647 825.584,605.648 825.594,605.649 825.603,605.65 825.612,605.651 825.621,605.651 825.63,605.652 825.64,605.653 825.649,605.654 825.658,605.655 825.667,605.656 825.676,605.656 825.686,605.657 825.695,605.658 825.704,605.659 825.713,605.66 825.722,605.66 825.731,605.661 825.741,605.662 825.75,605.663 825.759,605.663 825.768,605.664 825.777,605.665 825.787,605.666 825.796,605.667 825.805,605.667 825.814,605.668 825.823,605.669 825.833,605.67 825.842,605.671 825.851,605.671 825.86,605.672 825.869,605.673 825.879,605.674 825.888,605.675 825.897,605.675 825.906,605.676 825.915,605.677 825.924,605.678 825.934,605.679 825.943,605.679 825.952,605.68 825.961,605.681 825.97,605.682 825.98,605.683 825.989,605.683 825.998,605.684 826.007,605.685 826.016,605.686 826.026,605.686 826.035,605.687 826.044,605.688 826.053,605.689 826.062,605.69 826.071,605.69 826.081,605.691 826.09,605.692 826.099,605.693 826.108,605.694 826.117,605.694 826.127,605.695 826.136,605.696 826.145,605.697 826.154,605.697 826.163,605.698 826.173,605.699 826.182,605.7 826.191,605.701 826.2,605.701 826.209,605.702 826.219,605.703 826.228,605.704 826.237,605.704 826.246,605.705 826.255,605.706 826.264,605.707 826.274,605.708 826.283,605.708 826.292,605.709 826.301,605.71 826.31,605.711 826.32,605.711 826.329,605.712 826.338,605.713 826.347,605.714 826.356,605.715 826.366,605.715 826.375,605.716 826.384,605.717 826.393,605.718 826.402,605.718 826.411,605.719 826.421,605.72 826.43,605.721 826.439,605.722 826.448,605.722 826.457,605.723 826.467,605.724 826.476,605.725 826.485,605.725 826.494,605.726 826.503,605.727 826.513,605.728 826.522,605.728 826.531,605.729 826.54,605.73 826.549,605.731 826.559,605.732 826.568,605.732 826.577,605.733 826.586,605.734 826.595,605.735 826.604,605.735 826.614,605.736 826.623,605.737 826.632,605.738 826.641,605.738 826.65,605.739 826.66,605.74 826.669,605.741 826.678,605.741 826.687,605.742 826.696,605.743 826.706,605.744 826.715,605.744 826.724,605.745 826.733,605.746 826.742,605.747 826.751,605.748 826.761,605.748 826.77,605.749 826.779,605.75 826.788,605.751 826.797,605.751 826.807,605.752 826.816,605.753 826.825,605.754 826.834,605.754 826.843,605.755 826.853,605.756 826.862,605.757 826.871,605.757 826.88,605.758 826.889,605.759 826.899,605.76 826.908,605.76 826.917,605.761 826.926,605.762 826.935,605.763 826.944,605.763 826.954,605.764 826.963,605.765 826.972,605.766 826.981,605.766 826.99,605.767 827,605.768 827.009,605.769 827.018,605.769 827.027,605.77 827.036,605.771 827.046,605.772 827.055,605.772 827.064,605.773 827.073,605.774 827.082,605.775 827.092,605.775 827.101,605.776 827.11,605.777 827.119,605.778 827.128,605.778 827.137,605.779 827.147,605.78 827.156,605.781 827.165,605.781 827.174,605.782 827.183,605.783 827.193,605.783 827.202,605.784 827.211,605.785 827.22,605.786 827.229,605.786 827.239,605.787 827.248,605.788 827.257,605.789 827.266,605.789 827.275,605.79 827.284,605.791 827.294,605.792 827.303,605.792 827.312,605.793 827.321,605.794 827.33,605.795 827.34,605.795 827.349,605.796 827.358,605.797 827.367,605.797 827.376,605.798 827.386,605.799 827.395,605.8 827.404,605.8 827.413,605.801 827.422,605.802 827.432,605.803 827.441,605.803 827.45,605.804 827.459,605.805 827.468,605.806 827.477,605.806 827.487,605.807 827.496,605.808 827.505,605.808 827.514,605.809 827.523,605.81 827.533,605.811 827.542,605.811 827.551,605.812 827.56,605.813 827.569,605.814 827.579,605.814 827.588,605.815 827.597,605.816 827.606,605.816 827.615,605.817 827.624,605.818 827.634,605.819 827.643,605.819 827.652,605.82 827.661,605.821 827.67,605.821 827.68,605.822 827.689,605.823 827.698,605.824 827.707,605.824 827.716,605.825 827.726,605.826 827.735,605.827 827.744,605.827 827.753,605.828 827.762,605.829 827.772,605.829 827.781,605.83 827.79,605.831 827.799,605.832 827.808,605.832 827.817,605.833 827.827,605.834 827.836,605.834 827.845,605.835 827.854,605.836 827.863,605.837 827.873,605.837 827.882,605.838 827.891,605.839 827.9,605.839 827.909,605.84 827.919,605.841 827.928,605.842 827.937,605.842 827.946,605.843 827.955,605.844 827.964,605.844 827.974,605.845 827.983,605.846 827.992,605.847 828.001,605.847 828.01,605.848 828.02,605.849 828.029,605.849 828.038,605.85 828.047,605.851 828.056,605.852 828.066,605.852 828.075,605.853 828.084,605.854 828.093,605.854 828.102,605.855 828.112,605.856 828.121,605.856 828.13,605.857 828.139,605.858 828.148,605.859 828.157,605.859 828.167,605.86 828.176,605.861 828.185,605.861 828.194,605.862 828.203,605.863 828.213,605.864 828.222,605.864 828.231,605.865 828.24,605.866 828.249,605.866 828.259,605.867 828.268,605.868 828.277,605.868 828.286,605.869 828.295,605.87 828.304,605.871 828.314,605.871 828.323,605.872 828.332,605.873 828.341,605.873 828.35,605.874 828.36,605.875 828.369,605.875 828.378,605.876 828.387,605.877 828.396,605.877 828.406,605.878 828.415,605.879 828.424,605.88 828.433,605.88 828.442,605.881 828.452,605.882 828.461,605.882 828.47,605.883 828.479,605.884 828.488,605.884 828.497,605.885 828.507,605.886 828.516,605.886 828.525,605.887 828.534,605.888 828.543,605.889 828.553,605.889 828.562,605.89 828.571,605.891 828.58,605.891 828.589,605.892 828.599,605.893 828.608,605.893 828.617,605.894 828.626,605.895 828.635,605.895 828.644,605.896 828.654,605.897 828.663,605.897 828.672,605.898 828.681,605.899 828.69,605.9 828.7,605.9 828.709,605.901 828.718,605.902 828.727,605.902 828.736,605.903 828.746,605.904 828.755,605.904 828.764,605.905 828.773,605.906 828.782,605.906 828.792,605.907 828.801,605.908 828.81,605.908 828.819,605.909 828.828,605.91 828.837,605.91 828.847,605.911 828.856,605.912 828.865,605.912 828.874,605.913 828.883,605.914 828.893,605.914 828.902,605.915 828.911,605.916 828.92,605.917 828.929,605.917 828.939,605.918 828.948,605.919 828.957,605.919 828.966,605.92 828.975,605.921 828.984,605.921 828.994,605.922 829.003,605.923 829.012,605.923 829.021,605.924 829.03,605.925 829.04,605.925 829.049,605.926 829.058,605.927 829.067,605.927 829.076,605.928 829.086,605.929 829.095,605.929 829.104,605.93 829.113,605.931 829.122,605.931 829.132,605.932 829.141,605.933 829.15,605.933 829.159,605.934 829.168,605.935 829.177,605.935 829.187,605.936 829.196,605.937 829.205,605.937 829.214,605.938 829.223,605.939 829.233,605.939 829.242,605.94 829.251,605.941 829.26,605.941 829.269,605.942 829.279,605.943 829.288,605.943 829.297,605.944 829.306,605.945 829.315,605.945 829.324,605.946 829.334,605.947 829.343,605.947 829.352,605.948 829.361,605.949 829.37,605.949 829.38,605.95 829.389,605.951 829.398,605.951 829.407,605.952 829.416,605.953 829.426,605.953 829.435,605.954 829.444,605.954 829.453,605.955 829.462,605.956 829.472,605.956 829.481,605.957 829.49,605.958 829.499,605.958 829.508,605.959 829.517,605.96 829.527,605.96 829.536,605.961 829.545,605.962 829.554,605.962 829.563,605.963 829.573,605.964 829.582,605.964 829.591,605.965 829.6,605.966 829.609,605.966 829.619,605.967 829.628,605.968 829.637,605.968 829.646,605.969 829.655,605.97 829.665,605.97 829.674,605.971 829.683,605.971 829.692,605.972 829.701,605.973 829.71,605.973 829.72,605.974 829.729,605.975 829.738,605.975 829.747,605.976 829.756,605.977 829.766,605.977 829.775,605.978 829.784,605.979 829.793,605.979 829.802,605.98 829.812,605.981 829.821,605.981 829.83,605.982 829.839,605.982 829.848,605.983 829.857,605.984 829.867,605.984 829.876,605.985 829.885,605.986 829.894,605.986 829.903,605.987 829.913,605.988 829.922,605.988 829.931,605.989 829.94,605.989 829.949,605.99 829.959,605.991 829.968,605.991 829.977,605.992 829.986,605.993 829.995,605.993 830.005,605.994 830.014,605.995 830.023,605.995 830.032,605.996 830.041,605.996 830.05,605.997 830.06,605.998 830.069,605.998 830.078,605.999 830.087,606 830.096,606 830.106,606.001 830.115,606.002 830.124,606.002 830.133,606.003 830.142,606.003 830.152,606.004 830.161,606.005 830.17,606.005 830.179,606.006 830.188,606.007 830.197,606.007 830.207,606.008 830.216,606.009 830.225,606.009 830.234,606.01 830.243,606.01 830.253,606.011 830.262,606.012 830.271,606.012 830.28,606.013 830.289,606.014 830.299,606.014 830.308,606.015 830.317,606.015 830.326,606.016 830.335,606.017 830.345,606.017 830.354,606.018 830.363,606.019 830.372,606.019 830.381,606.02 830.39,606.02 830.4,606.021 830.409,606.022 830.418,606.022 830.427,606.023 830.436,606.024 830.446,606.024 830.455,606.025 830.464,606.025 830.473,606.026 830.482,606.027 830.492,606.027 830.501,606.028 830.51,606.028 830.519,606.029 830.528,606.03 830.537,606.03 830.547,606.031 830.556,606.032 830.565,606.032 830.574,606.033 830.583,606.033 830.593,606.034 830.602,606.035 830.611,606.035 830.62,606.036 830.629,606.037 830.639,606.037 830.648,606.038 830.657,606.038 830.666,606.039 830.675,606.04 830.685,606.04 830.694,606.041 830.703,606.041 830.712,606.042 830.721,606.043 830.73,606.043 830.74,606.044 830.749,606.044 830.758,606.045 830.767,606.046 830.776,606.046 830.786,606.047 830.795,606.048 830.804,606.048 830.813,606.049 830.822,606.049 830.832,606.05 830.841,606.051 830.85,606.051 830.859,606.052 830.868,606.052 830.877,606.053 830.887,606.054 830.896,606.054 830.905,606.055 830.914,606.055 830.923,606.056 830.933,606.057 830.942,606.057 830.951,606.058 830.96,606.058 830.969,606.059 830.979,606.06 830.988,606.06 830.997,606.061 831.006,606.061 831.015,606.062 831.025,606.063 831.034,606.063 831.043,606.064 831.052,606.065 831.061,606.065 831.07,606.066 831.08,606.066 831.089,606.067 831.098,606.068 831.107,606.068 831.116,606.069 831.126,606.069 831.135,606.07 831.144,606.07 831.153,606.071 831.162,606.072 831.172,606.072 831.181,606.073 831.19,606.073 831.199,606.074 831.208,606.075 831.217,606.075 831.227,606.076 831.236,606.076 831.245,606.077 831.254,606.078 831.263,606.078 831.273,606.079 831.282,606.079 831.291,606.08 831.3,606.081 831.309,606.081 831.319,606.082 831.328,606.082 831.337,606.083 831.346,606.084 831.355,606.084 831.365,606.085 831.374,606.085 831.383,606.086 831.392,606.087 831.401,606.087 831.41,606.088 831.42,606.088 831.429,606.089 831.438,606.089 831.447,606.09 831.456,606.091 831.466,606.091 831.475,606.092 831.484,606.092 831.493,606.093 831.502,606.094 831.512,606.094 831.521,606.095 831.53,606.095 831.539,606.096 831.548,606.097 831.557,606.097 831.567,606.098 831.576,606.098 831.585,606.099 831.594,606.099 831.603,606.1 831.613,606.101 831.622,606.101 831.631,606.102 831.64,606.102 831.649,606.103 831.659,606.104 831.668,606.104 831.677,606.105 831.686,606.105 831.695,606.106 831.705,606.106 831.714,606.107 831.723,606.108 831.732,606.108 831.741,606.109 831.75,606.109 831.76,606.11 831.769,606.11 831.778,606.111 831.787,606.112 831.796,606.112 831.806,606.113 831.815,606.113 831.824,606.114 831.833,606.114 831.842,606.115 831.852,606.116 831.861,606.116 831.87,606.117 831.879,606.117 831.888,606.118 831.898,606.119 831.907,606.119 831.916,606.12 831.925,606.12 831.934,606.121 831.943,606.121 831.953,606.122 831.962,606.123 831.971,606.123 831.98,606.124 831.989,606.124 831.999,606.125 832.008,606.125 832.017,606.126 832.026,606.127 832.035,606.127 832.045,606.128 832.054,606.128 832.063,606.129 832.072,606.129 832.081,606.13 832.09,606.13 832.1,606.131 832.109,606.132 832.118,606.132 832.127,606.133 832.136,606.133 832.146,606.134 832.155,606.134 832.164,606.135 832.173,606.136 832.182,606.136 832.192,606.137 832.201,606.137 832.21,606.138 832.219,606.138 832.228,606.139 832.238,606.14 832.247,606.14 832.256,606.141 832.265,606.141 832.274,606.142 832.283,606.142 832.293,606.143 832.302,606.143 832.311,606.144 832.32,606.145 832.329,606.145 832.339,606.146 832.348,606.146 832.357,606.147 832.366,606.147 832.375,606.148 832.385,606.148 832.394,606.149 832.403,606.15 832.412,606.15 832.421,606.151 832.43,606.151 832.44,606.152 832.449,606.152 832.458,606.153 832.467,606.153 832.476,606.154 832.486,606.155 832.495,606.155 832.504,606.156 832.513,606.156 832.522,606.157 832.532,606.157 832.541,606.158 832.55,606.158 832.559,606.159 832.568,606.16 832.578,606.16 832.587,606.161 832.596,606.161 832.605,606.162 832.614,606.162 832.623,606.163 832.633,606.163 832.642,606.164 832.651,606.165 832.66,606.165 832.669,606.166 832.679,606.166 832.688,606.167 832.697,606.167 832.706,606.168 832.715,606.168 832.725,606.169 832.734,606.169 832.743,606.17 832.752,606.171 832.761,606.171 832.77,606.172 832.78,606.172 832.789,606.173 832.798,606.173 832.807,606.174 832.816,606.174 832.826,606.175 832.835,606.175 832.844,606.176 832.853,606.177 832.862,606.177 832.872,606.178 832.881,606.178 832.89,606.179 832.899,606.179 832.908,606.18 832.918,606.18 832.927,606.181 832.936,606.181 832.945,606.182 832.954,606.182 832.963,606.183 832.973,606.184 832.982,606.184 832.991,606.185 833,606.185 833.009,606.186 833.019,606.186 833.028,606.187 833.037,606.187 833.046,606.188 833.055,606.188 833.065,606.189 833.074,606.189 833.083,606.19 833.092,606.191 833.101,606.191 833.11,606.192 833.12,606.192 833.129,606.193 833.138,606.193 833.147,606.194 833.156,606.194 833.166,606.195 833.175,606.195 833.184,606.196 833.193,606.196 833.202,606.197 833.212,606.197 833.221,606.198 833.23,606.199 833.239,606.199 833.248,606.2 833.258,606.2 833.267,606.201 833.276,606.201 833.285,606.202 833.294,606.202 833.303,606.203 833.313,606.203 833.322,606.204 833.331,606.204 833.34,606.205 833.349,606.205 833.359,606.206 833.368,606.206 833.377,606.207 833.386,606.208 833.395,606.208 833.405,606.209 833.414,606.209 833.423,606.21 833.432,606.21 833.441,606.211 833.45,606.211 833.46,606.212 833.469,606.212 833.478,606.213 833.487,606.213 833.496,606.214 833.506,606.214 833.515,606.215 833.524,606.215 833.533,606.216 833.542,606.216 833.552,606.217 833.561,606.217 833.57,606.218 833.579,606.219 833.588,606.219 833.598,606.22 833.607,606.22 833.616,606.221 833.625,606.221 833.634,606.222 833.643,606.222 833.653,606.223 833.662,606.223 833.671,606.224 833.68,606.224 833.689,606.225 833.699,606.225 833.708,606.226 833.717,606.226 833.726,606.227 833.735,606.227 833.745,606.228 833.754,606.228 833.763,606.229 833.772,606.229 833.781,606.23 833.79,606.23 833.8,606.231 833.809,606.231 833.818,606.232 833.827,606.232 833.836,606.233 833.846,606.234 833.855,606.234 833.864,606.235 833.873,606.235 833.882,606.236 833.892,606.236 833.901,606.237 833.91,606.237 833.919,606.238 833.928,606.238 833.938,606.239 833.947,606.239 833.956,606.24 833.965,606.24 833.974,606.241 833.983,606.241 833.993,606.242 834.002,606.242 834.011,606.243 834.02,606.243 834.029,606.244 834.039,606.244 834.048,606.245 834.057,606.245 834.066,606.246 834.075,606.246 834.085,606.247 834.094,606.247 834.103,606.248 834.112,606.248 834.121,606.249 834.13,606.249 834.14,606.25 834.149,606.25 834.158,606.251 834.167,606.251 834.176,606.252 834.186,606.252 834.195,606.253 834.204,606.253 834.213,606.254 834.222,606.254 834.232,606.255 834.241,606.255 834.25,606.256 834.259,606.256 834.268,606.257 834.278,606.257 834.287,606.258 834.296,606.258 834.305,606.259 834.314,606.259 834.323,606.26 834.333,606.26 834.342,606.261 834.351,606.261 834.36,606.262 834.369,606.262 834.379,606.263 834.388,606.263 834.397,606.264 834.406,606.264 834.415,606.265 834.425,606.265 834.434,606.266 834.443,606.266 834.452,606.267 834.461,606.267 834.471,606.268 834.48,606.268 834.489,606.269 834.498,606.269 834.507,606.27 834.516,606.27 834.526,606.271 834.535,606.271 834.544,606.272 834.553,606.272 834.562,606.273 834.572,606.273 834.581,606.274 834.59,606.274 834.599,606.275 834.608,606.275 834.618,606.276 834.627,606.276 834.636,606.277 834.645,606.277 834.654,606.278 834.663,606.278 834.673,606.279 834.682,606.279 834.691,606.279 834.7,606.28 834.709,606.28 834.719,606.281 834.728,606.281 834.737,606.282 834.746,606.282 834.755,606.283 834.765,606.283 834.774,606.284 834.783,606.284 834.792,606.285 834.801,606.285 834.811,606.286 834.82,606.286 834.829,606.287 834.838,606.287 834.847,606.288 834.856,606.288 834.866,606.289 834.875,606.289 834.884,606.29 834.893,606.29 834.902,606.291 834.912,606.291 834.921,606.292 834.93,606.292 834.939,606.293 834.948,606.293 834.958,606.294 834.967,606.294 834.976,606.294 834.985,606.295 834.994,606.295 835.003,606.296 835.013,606.296 835.022,606.297 835.031,606.297 835.04,606.298 835.049,606.298 835.059,606.299 835.068,606.299 835.077,606.3 835.086,606.3 835.095,606.301 835.105,606.301 835.114,606.302 835.123,606.302 835.132,606.303 835.141,606.303 835.151,606.304 835.16,606.304 835.169,606.304 835.178,606.305 835.187,606.305 835.196,606.306 835.206,606.306 835.215,606.307 835.224,606.307 835.233,606.308 835.242,606.308 835.252,606.309 835.261,606.309 835.27,606.31 835.279,606.31 835.288,606.311 835.298,606.311 835.307,606.312 835.316,606.312 835.325,606.312 835.334,606.313 835.343,606.313 835.353,606.314 835.362,606.314 835.371,606.315 835.38,606.315 835.389,606.316 835.399,606.316 835.408,606.317 835.417,606.317 835.426,606.318 835.435,606.318 835.445,606.319 835.454,606.319 835.463,606.319 835.472,606.32 835.481,606.32 835.491,606.321 835.5,606.321 835.509,606.322 835.518,606.322 835.527,606.323 835.536,606.323 835.546,606.324 835.555,606.324 835.564,606.325 835.573,606.325 835.582,606.326 835.592,606.326 835.601,606.326 835.61,606.327 835.619,606.327 835.628,606.328 835.638,606.328 835.647,606.329 835.656,606.329 835.665,606.33 835.674,606.33 835.683,606.331 835.693,606.331 835.702,606.331 835.711,606.332 835.72,606.332 835.729,606.333 835.739,606.333 835.748,606.334 835.757,606.334 835.766,606.335 835.775,606.335 835.785,606.336 835.794,606.336 835.803,606.337 835.812,606.337 835.821,606.337 835.831,606.338 835.84,606.338 835.849,606.339 835.858,606.339 835.867,606.34 835.876,606.34 835.886,606.341 835.895,606.341 835.904,606.342 835.913,606.342 835.922,606.342 835.932,606.343 835.941,606.343 835.95,606.344 835.959,606.344 835.968,606.345 835.978,606.345 835.987,606.346 835.996,606.346 836.005,606.346 836.014,606.347 836.023,606.347 836.033,606.348 836.042,606.348 836.051,606.349 836.06,606.349 836.069,606.35 836.079,606.35 836.088,606.351 836.097,606.351 836.106,606.351 836.115,606.352 836.125,606.352 836.134,606.353 836.143,606.353 836.152,606.354 836.161,606.354 836.171,606.355 836.18,606.355 836.189,606.355 836.198,606.356 836.207,606.356 836.216,606.357 836.226,606.357 836.235,606.358 836.244,606.358 836.253,606.359 836.262,606.359 836.272,606.359 836.281,606.36 836.29,606.36 836.299,606.361 836.308,606.361 836.318,606.362 836.327,606.362 836.336,606.363 836.345,606.363 836.354,606.363 836.363,606.364 836.373,606.364 836.382,606.365 836.391,606.365 836.4,606.366 836.409,606.366 836.419,606.366 836.428,606.367 836.437,606.367 836.446,606.368 836.455,606.368 836.465,606.369 836.474,606.369 836.483,606.37 836.492,606.37 836.501,606.37 836.511,606.371 836.52,606.371 836.529,606.372 836.538,606.372 836.547,606.373 836.556,606.373 836.566,606.373 836.575,606.374 836.584,606.374 836.593,606.375 836.602,606.375 836.612,606.376 836.621,606.376 836.63,606.376 836.639,606.377 836.648,606.377 836.658,606.378 836.667,606.378 836.676,606.379 836.685,606.379 836.694,606.38 836.703,606.38 836.713,606.38 836.722,606.381 836.731,606.381 836.74,606.382 836.749,606.382 836.759,606.383 836.768,606.383 836.777,606.383 836.786,606.384 836.795,606.384 836.805,606.385 836.814,606.385 836.823,606.386 836.832,606.386 836.841,606.386 836.851,606.387 836.86,606.387 836.869,606.388 836.878,606.388 836.887,606.389 836.896,606.389 836.906,606.389 836.915,606.39 836.924,606.39 836.933,606.391 836.942,606.391 836.952,606.391 836.961,606.392 836.97,606.392 836.979,606.393 836.988,606.393 836.998,606.394 837.007,606.394 837.016,606.394 837.025,606.395 837.034,606.395 837.044,606.396 837.053,606.396 837.062,606.397 837.071,606.397 837.08,606.397 837.089,606.398 837.099,606.398 837.108,606.399 837.117,606.399 837.126,606.4 837.135,606.4 837.145,606.4 837.154,606.401 837.163,606.401 837.172,606.402 837.181,606.402 837.191,606.402 837.2,606.403 837.209,606.403 837.218,606.404 837.227,606.404 837.236,606.405 837.246,606.405 837.255,606.405 837.264,606.406 837.273,606.406 837.282,606.407 837.292,606.407 837.301,606.407 837.31,606.408 837.319,606.408 837.328,606.409 837.338,606.409 837.347,606.41 837.356,606.41 837.365,606.41 837.374,606.411 837.384,606.411 837.393,606.412 837.402,606.412 837.411,606.412 837.42,606.413 837.429,606.413 837.439,606.414 837.448,606.414 837.457,606.414 837.466,606.415 837.475,606.415 837.485,606.416 837.494,606.416 837.503,606.417 837.512,606.417 837.521,606.417 837.531,606.418 837.54,606.418 837.549,606.419 837.558,606.419 837.567,606.419 837.576,606.42 837.586,606.42 837.595,606.421 837.604,606.421 837.613,606.421 837.622,606.422 837.632,606.422 837.641,606.423 837.65,606.423 837.659,606.423 837.668,606.424 837.678,606.424 837.687,606.425 837.696,606.425 837.705,606.425 837.714,606.426 837.724,606.426 837.733,606.427 837.742,606.427 837.751,606.427 837.76,606.428 837.769,606.428 837.779,606.429 837.788,606.429 837.797,606.43 837.806,606.43 837.815,606.43 837.825,606.431 837.834,606.431 837.843,606.432 837.852,606.432 837.861,606.432 837.871,606.433 837.88,606.433 837.889,606.434 837.898,606.434 837.907,606.434 837.916,606.435 837.926,606.435 837.935,606.436 837.944,606.436 837.953,606.436 837.962,606.437 837.972,606.437 837.981,606.438 837.99,606.438 837.999,606.438 838.008,606.439 838.018,606.439 838.027,606.439 838.036,606.44 838.045,606.44 838.054,606.441 838.064,606.441 838.073,606.441 838.082,606.442 838.091,606.442 838.1,606.443 838.109,606.443 838.119,606.443 838.128,606.444 838.137,606.444 838.146,606.445 838.155,606.445 838.165,606.445 838.174,606.446 838.183,606.446 838.192,606.447 838.201,606.447 838.211,606.447 838.22,606.448 838.229,606.448 838.238,606.449 838.247,606.449 838.256,606.449 838.266,606.45 838.275,606.45 838.284,606.45 838.293,606.451 838.302,606.451 838.312,606.452 838.321,606.452 838.33,606.452 838.339,606.453 838.348,606.453 838.358,606.454 838.367,606.454 838.376,606.454 838.385,606.455 838.394,606.455 838.404,606.456 838.413,606.456 838.422,606.456 838.431,606.457 838.44,606.457 838.449,606.457 838.459,606.458 838.468,606.458 838.477,606.459 838.486,606.459 838.495,606.459 838.505,606.46 838.514,606.46 838.523,606.461 838.532,606.461 838.541,606.461 838.551,606.462 838.56,606.462 838.569,606.462 838.578,606.463 838.587,606.463 838.596,606.464 838.606,606.464 838.615,606.464 838.624,606.465 838.633,606.465 838.642,606.466 838.652,606.466 838.661,606.466 838.67,606.467 838.679,606.467 838.688,606.467 838.698,606.468 838.707,606.468 838.716,606.469 838.725,606.469 838.734,606.469 838.744,606.47 838.753,606.47 838.762,606.47 838.771,606.471 838.78,606.471 838.789,606.472 838.799,606.472 838.808,606.472 838.817,606.473 838.826,606.473 838.835,606.473 838.845,606.474 838.854,606.474 838.863,606.475 838.872,606.475 838.881,606.475 838.891,606.476 838.9,606.476 838.909,606.476 838.918,606.477 838.927,606.477 838.936,606.478 838.946,606.478 838.955,606.478 838.964,606.479 838.973,606.479 838.982,606.479 838.992,606.48 839.001,606.48 839.01,606.481 839.019,606.481 839.028,606.481 839.038,606.482 839.047,606.482 839.056,606.482 839.065,606.483 839.074,606.483 839.084,606.484 839.093,606.484 839.102,606.484 839.111,606.485 839.12,606.485 839.129,606.485 839.139,606.486 839.148,606.486 839.157,606.486 839.166,606.487 839.175,606.487 839.185,606.488 839.194,606.488 839.203,606.488 839.212,606.489 839.221,606.489 839.231,606.489 839.24,606.49 839.249,606.49 839.258,606.491 839.267,606.491 839.277,606.491 839.286,606.492 839.295,606.492 839.304,606.492 839.313,606.493 839.322,606.493 839.332,606.493 839.341,606.494 839.35,606.494 839.359,606.495 839.368,606.495 839.378,606.495 839.387,606.496 839.396,606.496 839.405,606.496 839.414,606.497 839.424,606.497 839.433,606.497 839.442,606.498 839.451,606.498 839.46,606.499 839.469,606.499 839.479,606.499 839.488,606.5 839.497,606.5 839.506,606.5 839.515,606.501 839.525,606.501 839.534,606.501 839.543,606.502 839.552,606.502 839.561,606.502 839.571,606.503 839.58,606.503 839.589,606.504 839.598,606.504 839.607,606.504 839.617,606.505 839.626,606.505 839.635,606.505 839.644,606.506 839.653,606.506 839.662,606.506 839.672,606.507 839.681,606.507 839.69,606.507 839.699,606.508 839.708,606.508 839.718,606.509 839.727,606.509 839.736,606.509 839.745,606.51 839.754,606.51 839.764,606.51 839.773,606.511 839.782,606.511 839.791,606.511 839.8,606.512 839.809,606.512 839.819,606.512 839.828,606.513 839.837,606.513 839.846,606.513 839.855,606.514 839.865,606.514 839.874,606.515 839.883,606.515 839.892,606.515 839.901,606.516 839.911,606.516 839.92,606.516 839.929,606.517 839.938,606.517 839.947,606.517 839.957,606.518 839.966,606.518 839.975,606.518 839.984,606.519 839.993,606.519 840.002,606.519 840.012,606.52 840.021,606.52 840.03,606.52 840.039,606.521 840.048,606.521 840.058,606.521 840.067,606.522 840.076,606.522 840.085,606.523 840.094,606.523 840.104,606.523 840.113,606.524 840.122,606.524 840.131,606.524 840.14,606.525 840.149,606.525 840.159,606.525 840.168,606.526 840.177,606.526 840.186,606.526 840.195,606.527 840.205,606.527 840.214,606.527 840.223,606.528 840.232,606.528 840.241,606.528 840.251,606.529 840.26,606.529 840.269,606.529 840.278,606.53 840.287,606.53 840.297,606.53 840.306,606.531 840.315,606.531 840.324,606.531 840.333,606.532 840.342,606.532 840.352,606.532 840.361,606.533 840.37,606.533 840.379,606.533 840.388,606.534 840.398,606.534 840.407,606.534 840.416,606.535 840.425,606.535 840.434,606.535 840.444,606.536 840.453,606.536 840.462,606.537 840.471,606.537 840.48,606.537 840.489,606.538 840.499,606.538 840.508,606.538 840.517,606.539 840.526,606.539 840.535,606.539 840.545,606.54 840.554,606.54 840.563,606.54 840.572,606.541 840.581,606.541 840.591,606.541 840.6,606.542 840.609,606.542 840.618,606.542 840.627,606.543 840.637,606.543 840.646,606.543 840.655,606.544 840.664,606.544 840.673,606.544 840.682,606.545 840.692,606.545 840.701,606.545 840.71,606.546 840.719,606.546 840.728,606.546 840.738,606.547 840.747,606.547 840.756,606.547 840.765,606.548 840.774,606.548 840.784,606.548 840.793,606.549 840.802,606.549 840.811,606.549 840.82,606.549 840.829,606.55 840.839,606.55 840.848,606.55 840.857,606.551 840.866,606.551 840.875,606.551 840.885,606.552 840.894,606.552 840.903,606.552 840.912,606.553 840.921,606.553 840.931,606.553 840.94,606.554 840.949,606.554 840.958,606.554 840.967,606.555 840.977,606.555 840.986,606.555 840.995,606.556 841.004,606.556 841.013,606.556 841.022,606.557 841.032,606.557 841.041,606.557 841.05,606.558 841.059,606.558 841.068,606.558 841.078,606.559 841.087,606.559 841.096,606.559 841.105,606.56 841.114,606.56 841.124,606.56 841.133,606.561 841.142,606.561 841.151,606.561 841.16,606.562 841.169,606.562 841.179,606.562 841.188,606.562 841.197,606.563 841.206,606.563 841.215,606.563 841.225,606.564 841.234,606.564 841.243,606.564 841.252,606.565 841.261,606.565 841.271,606.565 841.28,606.566 841.289,606.566 841.298,606.566 841.307,606.567 841.317,606.567 841.326,606.567 841.335,606.568 841.344,606.568 841.353,606.568 841.362,606.569 841.372,606.569 841.381,606.569 841.39,606.569 841.399,606.57 841.408,606.57 841.418,606.57 841.427,606.571 841.436,606.571 841.445,606.571 841.454,606.572 841.464,606.572 841.473,606.572 841.482,606.573 841.491,606.573 841.5,606.573 841.509,606.574 841.519,606.574 841.528,606.574 841.537,606.574 841.546,606.575 841.555,606.575 841.565,606.575 841.574,606.576 841.583,606.576 841.592,606.576 841.601,606.577 841.611,606.577 841.62,606.577 841.629,606.578 841.638,606.578 841.647,606.578 841.657,606.579 841.666,606.579 841.675,606.579 841.684,606.579 841.693,606.58 841.702,606.58 841.712,606.58 841.721,606.581 841.73,606.581 841.739,606.581 841.748,606.582 841.758,606.582 841.767,606.582 841.776,606.583 841.785,606.583 841.794,606.583 841.804,606.583 841.813,606.584 841.822,606.584 841.831,606.584 841.84,606.585 841.85,606.585 841.859,606.585 841.868,606.586 841.877,606.586 841.886,606.586 841.895,606.587 841.905,606.587 841.914,606.587 841.923,606.587 841.932,606.588 841.941,606.588 841.951,606.588 841.96,606.589 841.969,606.589 841.978,606.589 841.987,606.59 841.997,606.59 842.006,606.59 842.015,606.59 842.024,606.591 842.033,606.591 842.042,606.591 842.052,606.592 842.061,606.592 842.07,606.592 842.079,606.593 842.088,606.593 842.098,606.593 842.107,606.593 842.116,606.594 842.125,606.594 842.134,606.594 842.144,606.595 842.153,606.595 842.162,606.595 842.171,606.596 842.18,606.596 842.19,606.596 842.199,606.596 842.208,606.597 842.217,606.597 842.226,606.597 842.235,606.598 842.245,606.598 842.254,606.598 842.263,606.599 842.272,606.599 842.281,606.599 842.291,606.599 842.3,606.6 842.309,606.6 842.318,606.6 842.327,606.601 842.337,606.601 842.346,606.601 842.355,606.602 842.364,606.602 842.373,606.602 842.382,606.602 842.392,606.603 842.401,606.603 842.41,606.603 842.419,606.604 842.428,606.604 842.438,606.604 842.447,606.604 842.456,606.605 842.465,606.605 842.474,606.605 842.484,606.606 842.493,606.606 842.502,606.606 842.511,606.606 842.52,606.607 842.53,606.607 842.539,606.607 842.548,606.608 842.557,606.608 842.566,606.608 842.575,606.609 842.585,606.609 842.594,606.609 842.603,606.609 842.612,606.61 842.621,606.61 842.631,606.61 842.64,606.611 842.649,606.611 842.658,606.611 842.667,606.611 842.677,606.612 842.686,606.612 842.695,606.612 842.704,606.613 842.713,606.613 842.722,606.613 842.732,606.613 842.741,606.614 842.75,606.614 842.759,606.614 842.768,606.615 842.778,606.615 842.787,606.615 842.796,606.615 842.805,606.616 842.814,606.616 842.824,606.616 842.833,606.617 842.842,606.617 842.851,606.617 842.86,606.617 842.87,606.618 842.879,606.618 842.888,606.618 842.897,606.619 842.906,606.619 842.915,606.619 842.925,606.619 842.934,606.62 842.943,606.62 842.952,606.62 842.961,606.621 842.971,606.621 842.98,606.621 842.989,606.621 842.998,606.622 843.007,606.622 843.017,606.622 843.026,606.622 843.035,606.623 843.044,606.623 843.053,606.623 843.062,606.624 843.072,606.624 843.081,606.624 843.09,606.624 843.099,606.625 843.108,606.625 843.118,606.625 843.127,606.626 843.136,606.626 843.145,606.626 843.154,606.626 843.164,606.627 843.173,606.627 843.182,606.627 843.191,606.628 843.2,606.628 843.21,606.628 843.219,606.628 843.228,606.629 843.237,606.629 843.246,606.629 843.255,606.629 843.265,606.63 843.274,606.63 843.283,606.63 843.292,606.631 843.301,606.631 843.311,606.631 843.32,606.631 843.329,606.632 843.338,606.632 843.347,606.632 843.357,606.632 843.366,606.633 843.375,606.633 843.384,606.633 843.393,606.634 843.402,606.634 843.412,606.634 843.421,606.634 843.43,606.635 843.439,606.635 843.448,606.635 843.458,606.635 843.467,606.636 843.476,606.636 843.485,606.636 843.494,606.637 843.504,606.637 843.513,606.637 843.522,606.637 843.531,606.638 843.54,606.638 843.55,606.638 843.559,606.638 843.568,606.639 843.577,606.639 843.586,606.639 843.595,606.64 843.605,606.64 843.614,606.64 843.623,606.64 843.632,606.641 843.641,606.641 843.651,606.641 843.66,606.641 843.669,606.642 843.678,606.642 843.687,606.642 843.697,606.642 843.706,606.643 843.715,606.643 843.724,606.643 843.733,606.644 843.742,606.644 843.752,606.644 843.761,606.644 843.77,606.645 843.779,606.645 843.788,606.645 843.798,606.645 843.807,606.646 843.816,606.646 843.825,606.646 843.834,606.646 843.844,606.647 843.853,606.647 843.862,606.647 843.871,606.647 843.88,606.648 843.89,606.648 843.899,606.648 843.908,606.649 843.917,606.649 843.926,606.649 843.935,606.649 843.945,606.65 843.954,606.65 843.963,606.65 843.972,606.65 843.981,606.651 843.991,606.651 844,606.651 844.009,606.651 844.018,606.652 844.027,606.652 844.037,606.652 844.046,606.652 844.055,606.653 844.064,606.653 844.073,606.653 844.082,606.653 844.092,606.654 844.101,606.654 844.11,606.654 844.119,606.655 844.128,606.655 844.138,606.655 844.147,606.655 844.156,606.656 844.165,606.656 844.174,606.656 844.184,606.656 844.193,606.657 844.202,606.657 844.211,606.657 844.22,606.657 844.23,606.658 844.239,606.658 844.248,606.658 844.257,606.658 844.266,606.659 844.275,606.659 844.285,606.659 844.294,606.659 844.303,606.66 844.312,606.66 844.321,606.66 844.331,606.66 844.34,606.661 844.349,606.661 844.358,606.661 844.367,606.661 844.377,606.662 844.386,606.662 844.395,606.662 844.404,606.662 844.413,606.663 844.423,606.663 844.432,606.663 844.441,606.663 844.45,606.664 844.459,606.664 844.468,606.664 844.478,606.664 844.487,606.665 844.496,606.665 844.505,606.665 844.514,606.665 844.524,606.666 844.533,606.666 844.542,606.666 844.551,606.666 844.56,606.667 844.57,606.667 844.579,606.667 844.588,606.667 844.597,606.668 844.606,606.668 844.615,606.668 844.625,606.668 844.634,606.669 844.643,606.669 844.652,606.669 844.661,606.669 844.671,606.67 844.68,606.67 844.689,606.67 844.698,606.67 844.707,606.671 844.717,606.671 844.726,606.671 844.735,606.671 844.744,606.672 844.753,606.672 844.763,606.672 844.772,606.672 844.781,606.673 844.79,606.673 844.799,606.673 844.808,606.673 844.818,606.674 844.827,606.674 844.836,606.674 844.845,606.674 844.854,606.675 844.864,606.675 844.873,606.675 844.882,606.675 844.891,606.676 844.9,606.676 844.91,606.676 844.919,606.676 844.928,606.677 844.937,606.677 844.946,606.677 844.955,606.677 844.965,606.677 844.974,606.678 844.983,606.678 844.992,606.678 845.001,606.678 845.011,606.679 845.02,606.679 845.029,606.679 845.038,606.679 845.047,606.68 845.057,606.68 845.066,606.68 845.075,606.68 845.084,606.681 845.093,606.681 845.103,606.681 845.112,606.681 845.121,606.682 845.13,606.682 845.139,606.682 845.148,606.682 845.158,606.682 845.167,606.683 845.176,606.683 845.185,606.683 845.194,606.683 845.204,606.684 845.213,606.684 845.222,606.684 845.231,606.684 845.24,606.685 845.25,606.685 845.259,606.685 845.268,606.685 845.277,606.686 845.286,606.686 845.295,606.686 845.305,606.686 845.314,606.687 845.323,606.687 845.332,606.687 845.341,606.687 845.351,606.687 845.36,606.688 845.369,606.688 845.378,606.688 845.387,606.688 845.397,606.689 845.406,606.689 845.415,606.689 845.424,606.689 845.433,606.69 845.443,606.69 845.452,606.69 845.461,606.69 845.47,606.69 845.479,606.691 845.488,606.691 845.498,606.691 845.507,606.691 845.516,606.692 845.525,606.692 845.534,606.692 845.544,606.692 845.553,606.693 845.562,606.693 845.571,606.693 845.58,606.693 845.59,606.693 845.599,606.694 845.608,606.694 845.617,606.694 845.626,606.694 845.635,606.695 845.645,606.695 845.654,606.695 845.663,606.695 845.672,606.696 845.681,606.696 845.691,606.696 845.7,606.696 845.709,606.696 845.718,606.697 845.727,606.697 845.737,606.697 845.746,606.697 845.755,606.698 845.764,606.698 845.773,606.698 845.783,606.698 845.792,606.698 845.801,606.699 845.81,606.699 845.819,606.699 845.828,606.699 845.838,606.7 845.847,606.7 845.856,606.7 845.865,606.7 845.874,606.7 845.884,606.701 845.893,606.701 845.902,606.701 845.911,606.701 845.92,606.702 845.93,606.702 845.939,606.702 845.948,606.702 845.957,606.703 845.966,606.703 845.975,606.703 845.985,606.703 845.994,606.703 846.003,606.704 846.012,606.704 846.021,606.704 846.031,606.704 846.04,606.704 846.049,606.705 846.058,606.705 846.067,606.705 846.077,606.705 846.086,606.706 846.095,606.706 846.104,606.706 846.113,606.706 846.123,606.706 846.132,606.707 846.141,606.707 846.15,606.707 846.159,606.707 846.168,606.708 846.178,606.708 846.187,606.708 846.196,606.708 846.205,606.708 846.214,606.709 846.224,606.709 846.233,606.709 846.242,606.709 846.251,606.71 846.26,606.71 846.27,606.71 846.279,606.71 846.288,606.71 846.297,606.711 846.306,606.711 846.315,606.711 846.325,606.711 846.334,606.711 846.343,606.712 846.352,606.712 846.361,606.712 846.371,606.712 846.38,606.713 846.389,606.713 846.398,606.713 846.407,606.713 846.417,606.713 846.426,606.714 846.435,606.714 846.444,606.714 846.453,606.714 846.463,606.714 846.472,606.715 846.481,606.715 846.49,606.715 846.499,606.715 846.508,606.716 846.518,606.716 846.527,606.716 846.536,606.716 846.545,606.716 846.554,606.717 846.564,606.717 846.573,606.717 846.582,606.717 846.591,606.717 846.6,606.718 846.61,606.718 846.619,606.718 846.628,606.718 846.637,606.718 846.646,606.719 846.656,606.719 846.665,606.719 846.674,606.719 846.683,606.72 846.692,606.72 846.701,606.72 846.711,606.72 846.72,606.72 846.729,606.721 846.738,606.721 846.747,606.721 846.757,606.721 846.766,606.721 846.775,606.722 846.784,606.722 846.793,606.722 846.803,606.722 846.812,606.722 846.821,606.723 846.83,606.723 846.839,606.723 846.848,606.723 846.858,606.723 846.867,606.724 846.876,606.724 846.885,606.724 846.894,606.724 846.904,606.725 846.913,606.725 846.922,606.725 846.931,606.725 846.94,606.725 846.95,606.726 846.959,606.726 846.968,606.726 846.977,606.726 846.986,606.726 846.996,606.727 847.005,606.727 847.014,606.727 847.023,606.727 847.032,606.727 847.041,606.728 847.051,606.728 847.06,606.728 847.069,606.728 847.078,606.728 847.087,606.729 847.097,606.729 847.106,606.729 847.115,606.729 847.124,606.729 847.133,606.73 847.143,606.73 847.152,606.73 847.161,606.73 847.17,606.73 847.179,606.731 847.188,606.731 847.198,606.731 847.207,606.731 847.216,606.731 847.225,606.732 847.234,606.732 847.244,606.732 847.253,606.732 847.262,606.732 847.271,606.733 847.28,606.733 847.29,606.733 847.299,606.733 847.308,606.733 847.317,606.734 847.326,606.734 847.336,606.734 847.345,606.734 847.354,606.734 847.363,606.735 847.372,606.735 847.381,606.735 847.391,606.735 847.4,606.735 847.409,606.736 847.418,606.736 847.427,606.736 847.437,606.736 847.446,606.736 847.455,606.737 847.464,606.737 847.473,606.737 847.483,606.737 847.492,606.737 847.501,606.738 847.51,606.738 847.519,606.738 847.528,606.738 847.538,606.738 847.547,606.738 847.556,606.739 847.565,606.739 847.574,606.739 847.584,606.739 847.593,606.739 847.602,606.74 847.611,606.74 847.62,606.74 847.63,606.74 847.639,606.74 847.648,606.741 847.657,606.741 847.666,606.741 847.676,606.741 847.685,606.741 847.694,606.742 847.703,606.742 847.712,606.742 847.721,606.742 847.731,606.742 847.74,606.743 847.749,606.743 847.758,606.743 847.767,606.743 847.777,606.743 847.786,606.743 847.795,606.744 847.804,606.744 847.813,606.744 847.823,606.744 847.832,606.744 847.841,606.745 847.85,606.745 847.859,606.745 847.868,606.745 847.878,606.745 847.887,606.746 847.896,606.746 847.905,606.746 847.914,606.746 847.924,606.746 847.933,606.746 847.942,606.747 847.951,606.747 847.96,606.747 847.97,606.747 847.979,606.747 847.988,606.748 847.997,606.748 848.006,606.748 848.016,606.748 848.025,606.748 848.034,606.749 848.043,606.749 848.052,606.749 848.061,606.749 848.071,606.749 848.08,606.749 848.089,606.75 848.098,606.75 848.107,606.75 848.117,606.75 848.126,606.75 848.135,606.751 848.144,606.751 848.153,606.751 848.163,606.751 848.172,606.751 848.181,606.751 848.19,606.752 848.199,606.752 848.208,606.752 848.218,606.752 848.227,606.752 848.236,606.753 848.245,606.753 848.254,606.753 848.264,606.753 848.273,606.753 848.282,606.753 848.291,606.754 848.3,606.754 848.31,606.754 848.319,606.754 848.328,606.754 848.337,606.755 848.346,606.755 848.356,606.755 848.365,606.755 848.374,606.755 848.383,606.755 848.392,606.756 848.401,606.756 848.411,606.756 848.42,606.756 848.429,606.756 848.438,606.757 848.447,606.757 848.457,606.757 848.466,606.757 848.475,606.757 848.484,606.757 848.493,606.758 848.503,606.758 848.512,606.758 848.521,606.758 848.53,606.758 848.539,606.758 848.548,606.759 848.558,606.759 848.567,606.759 848.576,606.759 848.585,606.759 848.594,606.76 848.604,606.76 848.613,606.76 848.622,606.76 848.631,606.76 848.64,606.76 848.65,606.761 848.659,606.761 848.668,606.761 848.677,606.761 848.686,606.761 848.696,606.761 848.705,606.762 848.714,606.762 848.723,606.762 848.732,606.762 848.741,606.762 848.751,606.763 848.76,606.763 848.769,606.763 848.778,606.763 848.787,606.763 848.797,606.763 848.806,606.764 848.815,606.764 848.824,606.764 848.833,606.764 848.843,606.764 848.852,606.764 848.861,606.765 848.87,606.765 848.879,606.765 848.888,606.765 848.898,606.765 848.907,606.765 848.916,606.766 848.925,606.766 848.934,606.766 848.944,606.766 848.953,606.766 848.962,606.766 848.971,606.767 848.98,606.767 848.99,606.767 848.999,606.767 849.008,606.767 849.017,606.767 849.026,606.768 849.036,606.768 849.045,606.768 849.054,606.768 849.063,606.768 849.072,606.768 849.081,606.769 849.091,606.769 849.1,606.769 849.109,606.769 849.118,606.769 849.127,606.769 849.137,606.77 849.146,606.77 849.155,606.77 849.164,606.77 849.173,606.77 849.183,606.77 849.192,606.771 849.201,606.771 849.21,606.771 849.219,606.771 849.229,606.771 849.238,606.771 849.247,606.772 849.256,606.772 849.265,606.772 849.274,606.772 849.284,606.772 849.293,606.772 849.302,606.773 849.311,606.773 849.32,606.773 849.33,606.773 849.339,606.773 849.348,606.773 849.357,606.774 849.366,606.774 849.376,606.774 849.385,606.774 849.394,606.774 849.403,606.774 849.412,606.775 849.421,606.775 849.431,606.775 849.44,606.775 849.449,606.775 849.458,606.775 849.467,606.776 849.477,606.776 849.486,606.776 849.495,606.776 849.504,606.776 849.513,606.776 849.523,606.777 849.532,606.777 849.541,606.777 849.55,606.777 849.559,606.777 849.569,606.777 849.578,606.777 849.587,606.778 849.596,606.778 849.605,606.778 849.614,606.778 849.624,606.778 849.633,606.778 849.642,606.779 849.651,606.779 849.66,606.779 849.67,606.779 849.679,606.779 849.688,606.779 849.697,606.78 849.706,606.78 849.716,606.78 849.725,606.78 849.734,606.78 849.743,606.78 849.752,606.781 849.761,606.781 849.771,606.781 849.78,606.781 849.789,606.781 849.798,606.781 849.807,606.781 849.817,606.782 849.826,606.782 849.835,606.782 849.844,606.782 849.853,606.782 849.863,606.782 849.872,606.783 849.881,606.783 849.89,606.783 849.899,606.783 849.909,606.783 849.918,606.783 849.927,606.783 849.936,606.784 849.945,606.784 849.954,606.784 849.964,606.784 849.973,606.784 849.982,606.784 849.991,606.785 850,606.785 850.01,606.785 850.019,606.785 850.028,606.785 850.037,606.785 850.046,606.785 850.056,606.786 850.065,606.786 850.074,606.786 850.083,606.786 850.092,606.786 850.101,606.786 850.111,606.787 850.12,606.787 850.129,606.787 850.138,606.787 850.147,606.787 850.157,606.787 850.166,606.787 850.175,606.788 850.184,606.788 850.193,606.788 850.203,606.788 850.212,606.788 850.221,606.788 850.23,606.788 850.239,606.789 850.249,606.789 850.258,606.789 850.267,606.789 850.276,606.789 850.285,606.789 850.294,606.79 850.304,606.79 850.313,606.79 850.322,606.79 850.331,606.79 850.34,606.79 850.35,606.79 850.359,606.791 850.368,606.791 850.377,606.791 850.386,606.791 850.396,606.791 850.405,606.791 850.414,606.791 850.423,606.792 850.432,606.792 850.441,606.792 850.451,606.792 850.46,606.792 850.469,606.792 850.478,606.792 850.487,606.793 850.497,606.793 850.506,606.793 850.515,606.793 850.524,606.793 850.533,606.793 850.543,606.793 850.552,606.794 850.561,606.794 850.57,606.794 850.579,606.794 850.589,606.794 850.598,606.794 850.607,606.794 850.616,606.795 850.625,606.795 850.634,606.795 850.644,606.795 850.653,606.795 850.662,606.795 850.671,606.795 850.68,606.796 850.69,606.796 850.699,606.796 850.708,606.796 850.717,606.796 850.726,606.796 850.736,606.796 850.745,606.797 850.754,606.797 850.763,606.797 850.772,606.797 850.781,606.797 850.791,606.797 850.8,606.797 850.809,606.798 850.818,606.798 850.827,606.798 850.837,606.798 850.846,606.798 850.855,606.798 850.864,606.798 850.873,606.799 850.883,606.799 850.892,606.799 850.901,606.799 850.91,606.799 850.919,606.799 850.929,606.799 850.938,606.8 850.947,606.8 850.956,606.8 850.965,606.8 850.974,606.8 850.984,606.8 850.993,606.8 851.002,606.801 851.011,606.801 851.02,606.801 851.03,606.801 851.039,606.801 851.048,606.801 851.057,606.801 851.066,606.801 851.076,606.802 851.085,606.802 851.094,606.802 851.103,606.802 851.112,606.802 851.121,606.802 851.131,606.802 851.14,606.803 851.149,606.803 851.158,606.803 851.167,606.803 851.177,606.803 851.186,606.803 851.195,606.803 851.204,606.804 851.213,606.804 851.223,606.804 851.232,606.804 851.241,606.804 851.25,606.804 851.259,606.804 851.269,606.804 851.278,606.805 851.287,606.805 851.296,606.805 851.305,606.805 851.314,606.805 851.324,606.805 851.333,606.805 851.342,606.806 851.351,606.806 851.36,606.806 851.37,606.806 851.379,606.806 851.388,606.806 851.397,606.806 851.406,606.806 851.416,606.807 851.425,606.807 851.434,606.807 851.443,606.807 851.452,606.807 851.461,606.807 851.471,606.807 851.48,606.808 851.489,606.808 851.498,606.808 851.507,606.808 851.517,606.808 851.526,606.808 851.535,606.808 851.544,606.808 851.553,606.809 851.563,606.809 851.572,606.809 851.581,606.809 851.59,606.809 851.599,606.809 851.609,606.809 851.618,606.809 851.627,606.81 851.636,606.81 851.645,606.81 851.654,606.81 851.664,606.81 851.673,606.81 851.682,606.81 851.691,606.81 851.7,606.811 851.71,606.811 851.719,606.811 851.728,606.811 851.737,606.811 851.746,606.811 851.756,606.811 851.765,606.811 851.774,606.812 851.783,606.812 851.792,606.812 851.802,606.812 851.811,606.812 851.82,606.812 851.829,606.812 851.838,606.812 851.847,606.813 851.857,606.813 851.866,606.813 851.875,606.813 851.884,606.813 851.893,606.813 851.903,606.813 851.912,606.813 851.921,606.814 851.93,606.814 851.939,606.814 851.949,606.814 851.958,606.814 851.967,606.814 851.976,606.814 851.985,606.814 851.994,606.815 852.004,606.815 852.013,606.815 852.022,606.815 852.031,606.815 852.04,606.815 852.05,606.815 852.059,606.815 852.068,606.816 852.077,606.816 852.086,606.816 852.096,606.816 852.105,606.816 852.114,606.816 852.123,606.816 852.132,606.816 852.142,606.817 852.151,606.817 852.16,606.817 852.169,606.817 852.178,606.817 852.187,606.817 852.197,606.817 852.206,606.817 852.215,606.818 852.224,606.818 852.233,606.818 852.243,606.818 852.252,606.818 852.261,606.818 852.27,606.818 852.279,606.818 852.289,606.818 852.298,606.819 852.307,606.819 852.316,606.819 852.325,606.819 852.334,606.819 852.344,606.819 852.353,606.819 852.362,606.819 852.371,606.82 852.38,606.82 852.39,606.82 852.399,606.82 852.408,606.82 852.417,606.82 852.426,606.82 852.436,606.82 852.445,606.82 852.454,606.821 852.463,606.821 852.472,606.821 852.482,606.821 852.491,606.821 852.5,606.821 852.509,606.821 852.518,606.821 852.527,606.822 852.537,606.822 852.546,606.822 852.555,606.822 852.564,606.822 852.573,606.822 852.583,606.822 852.592,606.822 852.601,606.822 852.61,606.823 852.619,606.823 852.629,606.823 852.638,606.823 852.647,606.823 852.656,606.823 852.665,606.823 852.674,606.823 852.684,606.823 852.693,606.824 852.702,606.824 852.711,606.824 852.72,606.824 852.73,606.824 852.739,606.824 852.748,606.824 852.757,606.824 852.766,606.824 852.776,606.825 852.785,606.825 852.794,606.825 852.803,606.825 852.812,606.825 852.822,606.825 852.831,606.825 852.84,606.825 852.849,606.825 852.858,606.826 852.867,606.826 852.877,606.826 852.886,606.826 852.895,606.826 852.904,606.826 852.913,606.826 852.923,606.826 852.932,606.826 852.941,606.827 852.95,606.827 852.959,606.827 852.969,606.827 852.978,606.827 852.987,606.827 852.996,606.827 853.005,606.827 853.014,606.827 853.024,606.828 853.033,606.828 853.042,606.828 853.051,606.828 853.06,606.828 853.07,606.828 853.079,606.828 853.088,606.828 853.097,606.828 853.106,606.829 853.116,606.829 853.125,606.829 853.134,606.829 853.143,606.829 853.152,606.829 853.162,606.829 853.171,606.829 853.18,606.829 853.189,606.829 853.198,606.83 853.207,606.83 853.217,606.83 853.226,606.83 853.235,606.83 853.244,606.83 853.253,606.83 853.263,606.83 853.272,606.83 853.281,606.831 853.29,606.831 853.299,606.831 853.309,606.831 853.318,606.831 853.327,606.831 853.336,606.831 853.345,606.831 853.354,606.831 853.364,606.831 853.373,606.832 853.382,606.832 853.391,606.832 853.4,606.832 853.41,606.832 853.419,606.832 853.428,606.832 853.437,606.832 853.446,606.832 853.456,606.832 853.465,606.833 853.474,606.833 853.483,606.833 853.492,606.833 853.502,606.833 853.511,606.833 853.52,606.833 853.529,606.833 853.538,606.833 853.547,606.834 853.557,606.834 853.566,606.834 853.575,606.834 853.584,606.834 853.593,606.834 853.603,606.834 853.612,606.834 853.621,606.834 853.63,606.834 853.639,606.835 853.649,606.835 853.658,606.835 853.667,606.835 853.676,606.835 853.685,606.835 853.694,606.835 853.704,606.835 853.713,606.835 853.722,606.835 853.731,606.836 853.74,606.836 853.75,606.836 853.759,606.836 853.768,606.836 853.777,606.836 853.786,606.836 853.796,606.836 853.805,606.836 853.814,606.836 853.823,606.836 853.832,606.837 853.842,606.837 853.851,606.837 853.86,606.837 853.869,606.837 853.878,606.837 853.887,606.837 853.897,606.837 853.906,606.837 853.915,606.837 853.924,606.838 853.933,606.838 853.943,606.838 853.952,606.838 853.961,606.838 853.97,606.838 853.979,606.838 853.989,606.838 853.998,606.838 854.007,606.838 854.016,606.839 854.025,606.839 854.035,606.839 854.044,606.839 854.053,606.839 854.062,606.839 854.071,606.839 854.08,606.839 854.09,606.839 854.099,606.839 854.108,606.839 854.117,606.84 854.126,606.84 854.136,606.84 854.145,606.84 854.154,606.84 854.163,606.84 854.172,606.84 854.182,606.84 854.191,606.84 854.2,606.84 854.209,606.84 854.218,606.841 854.227,606.841 854.237,606.841 854.246,606.841 854.255,606.841 854.264,606.841 854.273,606.841 854.283,606.841 854.292,606.841 854.301,606.841 854.31,606.841 854.319,606.842 854.329,606.842 854.338,606.842 854.347,606.842 854.356,606.842 854.365,606.842 854.375,606.842 854.384,606.842 854.393,606.842 854.402,606.842 854.411,606.842 854.42,606.843 854.43,606.843 854.439,606.843 854.448,606.843 854.457,606.843 854.466,606.843 854.476,606.843 854.485,606.843 854.494,606.843 854.503,606.843 854.512,606.843 854.522,606.844 854.531,606.844 854.54,606.844 854.549,606.844 854.558,606.844 854.567,606.844 854.577,606.844 854.586,606.844 854.595,606.844 854.604,606.844 854.613,606.844 854.623,606.845 854.632,606.845 854.641,606.845 854.65,606.845 854.659,606.845 854.669,606.845 854.678,606.845 854.687,606.845 854.696,606.845 854.705,606.845 854.715,606.845 854.724,606.845 854.733,606.846 854.742,606.846 854.751,606.846 854.76,606.846 854.77,606.846 854.779,606.846 854.788,606.846 854.797,606.846 854.806,606.846 854.816,606.846 854.825,606.846 854.834,606.846 854.843,606.847 854.852,606.847 854.862,606.847 854.871,606.847 854.88,606.847 854.889,606.847 854.898,606.847 854.907,606.847 854.917,606.847 854.926,606.847 854.935,606.847 854.944,606.847 854.953,606.848 854.963,606.848 854.972,606.848 854.981,606.848 854.99,606.848 854.999,606.848 855.009,606.848 855.018,606.848 855.027,606.848 855.036,606.848 855.045,606.848 855.055,606.848 855.064,606.849 855.073,606.849 855.082,606.849 855.091,606.849 855.1,606.849 855.11,606.849 855.119,606.849 855.128,606.849 855.137,606.849 855.146,606.849 855.156,606.849 855.165,606.849 855.174,606.85 855.183,606.85 855.192,606.85 855.202,606.85 855.211,606.85 855.22,606.85 855.229,606.85 855.238,606.85 855.247,606.85 855.257,606.85 855.266,606.85 855.275,606.85 855.284,606.85 855.293,606.851 855.303,606.851 855.312,606.851 855.321,606.851 855.33,606.851 855.339,606.851 855.349,606.851 855.358,606.851 855.367,606.851 855.376,606.851 855.385,606.851 855.395,606.851 855.404,606.851 855.413,606.852 855.422,606.852 855.431,606.852 855.44,606.852 855.45,606.852 855.459,606.852 855.468,606.852 855.477,606.852 855.486,606.852 855.496,606.852 855.505,606.852 855.514,606.852 855.523,606.852 855.532,606.853 855.542,606.853 855.551,606.853 855.56,606.853 855.569,606.853 855.578,606.853 855.587,606.853 855.597,606.853 855.606,606.853 855.615,606.853 855.624,606.853 855.633,606.853 855.643,606.853 855.652,606.853 855.661,606.854 855.67,606.854 855.679,606.854 855.689,606.854 855.698,606.854 855.707,606.854 855.716,606.854 855.725,606.854 855.735,606.854 855.744,606.854 855.753,606.854 855.762,606.854 855.771,606.854 855.78,606.855 855.79,606.855 855.799,606.855 855.808,606.855 855.817,606.855 855.826,606.855 855.836,606.855 855.845,606.855 855.854,606.855 855.863,606.855 855.872,606.855 855.882,606.855 855.891,606.855 855.9,606.855 855.909,606.856 855.918,606.856 855.927,606.856 855.937,606.856 855.946,606.856 855.955,606.856 855.964,606.856 855.973,606.856 855.983,606.856 855.992,606.856 856.001,606.856 856.01,606.856 856.019,606.856 856.029,606.856 856.038,606.856 856.047,606.857 856.056,606.857 856.065,606.857 856.075,606.857 856.084,606.857 856.093,606.857 856.102,606.857 856.111,606.857 856.12,606.857 856.13,606.857 856.139,606.857 856.148,606.857 856.157,606.857 856.166,606.857 856.176,606.858 856.185,606.858 856.194,606.858 856.203,606.858 856.212,606.858 856.222,606.858 856.231,606.858 856.24,606.858 856.249,606.858 856.258,606.858 856.267,606.858 856.277,606.858 856.286,606.858 856.295,606.858 856.304,606.858 856.313,606.859 856.323,606.859 856.332,606.859 856.341,606.859 856.35,606.859 856.359,606.859 856.369,606.859 856.378,606.859 856.387,606.859 856.396,606.859 856.405,606.859 856.415,606.859 856.424,606.859 856.433,606.859 856.442,606.859 856.451,606.859 856.46,606.86 856.47,606.86 856.479,606.86 856.488,606.86 856.497,606.86 856.506,606.86 856.516,606.86 856.525,606.86 856.534,606.86 856.543,606.86 856.552,606.86 856.562,606.86 856.571,606.86 856.58,606.86 856.589,606.86 856.598,606.861 856.608,606.861 856.617,606.861 856.626,606.861 856.635,606.861 856.644,606.861 856.653,606.861 856.663,606.861 856.672,606.861 856.681,606.861 856.69,606.861 856.699,606.861 856.709,606.861 856.718,606.861 856.727,606.861 856.736,606.861 856.745,606.861 856.755,606.862 856.764,606.862 856.773,606.862 856.782,606.862 856.791,606.862 856.8,606.862 856.81,606.862 856.819,606.862 856.828,606.862 856.837,606.862 856.846,606.862 856.856,606.862 856.865,606.862 856.874,606.862 856.883,606.862 856.892,606.862 856.902,606.862 856.911,606.863 856.92,606.863 856.929,606.863 856.938,606.863 856.948,606.863 856.957,606.863 856.966,606.863 856.975,606.863 856.984,606.863 856.993,606.863 857.003,606.863 857.012,606.863 857.021,606.863 857.03,606.863 857.039,606.863 857.049,606.863 857.058,606.863 857.067,606.864 857.076,606.864 857.085,606.864 857.095,606.864 857.104,606.864 857.113,606.864 857.122,606.864 857.131,606.864 857.14,606.864 857.15,606.864 857.159,606.864 857.168,606.864 857.177,606.864 857.186,606.864 857.196,606.864 857.205,606.864 857.214,606.864 857.223,606.864 857.232,606.865 857.242,606.865 857.251,606.865 857.26,606.865 857.269,606.865 857.278,606.865 857.288,606.865 857.297,606.865 857.306,606.865 857.315,606.865 857.324,606.865 857.333,606.865 857.343,606.865 857.352,606.865 857.361,606.865 857.37,606.865 857.379,606.865 857.389,606.865 857.398,606.866 857.407,606.866 857.416,606.866 857.425,606.866 857.435,606.866 857.444,606.866 857.453,606.866 857.462,606.866 857.471,606.866 857.48,606.866 857.49,606.866 857.499,606.866 857.508,606.866 857.517,606.866 857.526,606.866 857.536,606.866 857.545,606.866 857.554,606.866 857.563,606.866 857.572,606.867 857.582,606.867 857.591,606.867 857.6,606.867 857.609,606.867 857.618,606.867 857.628,606.867 857.637,606.867 857.646,606.867 857.655,606.867 857.664,606.867 857.673,606.867 857.683,606.867 857.692,606.867 857.701,606.867 857.71,606.867 857.719,606.867 857.729,606.867 857.738,606.867 857.747,606.867 857.756,606.867 857.765,606.868 857.775,606.868 857.784,606.868 857.793,606.868 857.802,606.868 857.811,606.868 857.82,606.868 857.83,606.868 857.839,606.868 857.848,606.868 857.857,606.868 857.866,606.868 857.876,606.868 857.885,606.868 857.894,606.868 857.903,606.868 857.912,606.868 857.922,606.868 857.931,606.868 857.94,606.868 857.949,606.869 857.958,606.869 857.968,606.869 857.977,606.869 857.986,606.869 857.995,606.869 858.004,606.869 858.013,606.869 858.023,606.869 858.032,606.869 858.041,606.869 858.05,606.869 858.059,606.869 858.069,606.869 858.078,606.869 858.087,606.869 858.096,606.869 858.105,606.869 858.115,606.869 858.124,606.869 858.133,606.869 858.142,606.869 858.151,606.87 858.16,606.87 858.17,606.87 858.179,606.87 858.188,606.87 858.197,606.87 858.206,606.87 858.216,606.87 858.225,606.87 858.234,606.87 858.243,606.87 858.252,606.87 858.262,606.87 858.271,606.87 858.28,606.87 858.289,606.87 858.298,606.87 858.308,606.87 858.317,606.87 858.326,606.87 858.335,606.87 858.344,606.87 858.353,606.87 858.363,606.87 858.372,606.871 858.381,606.871 858.39,606.871 858.399,606.871 858.409,606.871 858.418,606.871 858.427,606.871 858.436,606.871 858.445,606.871 858.455,606.871 858.464,606.871 858.473,606.871 858.482,606.871 858.491,606.871 858.5,606.871 858.51,606.871 858.519,606.871 858.528,606.871 858.537,606.871 858.546,606.871 858.556,606.871 858.565,606.871 858.574,606.871 858.583,606.871 858.592,606.872 858.602,606.872 858.611,606.872 858.62,606.872 858.629,606.872 858.638,606.872 858.648,606.872 858.657,606.872 858.666,606.872 858.675,606.872 858.684,606.872 858.693,606.872 858.703,606.872 858.712,606.872 858.721,606.872 858.73,606.872 858.739,606.872 858.749,606.872 858.758,606.872 858.767,606.872 858.776,606.872 858.785,606.872 858.795,606.872 858.804,606.872 858.813,606.872 858.822,606.872 858.831,606.873 858.84,606.873 858.85,606.873 858.859,606.873 858.868,606.873 858.877,606.873 858.886,606.873 858.896,606.873 858.905,606.873 858.914,606.873 858.923,606.873 858.932,606.873 858.942,606.873 858.951,606.873 858.96,606.873 858.969,606.873 858.978,606.873 858.988,606.873 858.997,606.873 859.006,606.873 859.015,606.873 859.024,606.873 859.033,606.873 859.043,606.873 859.052,606.873 859.061,606.873 859.07,606.873 859.079,606.873 859.089,606.874 859.098,606.874 859.107,606.874 859.116,606.874 859.125,606.874 859.135,606.874 859.144,606.874 859.153,606.874 859.162,606.874 859.171,606.874 859.181,606.874 859.19,606.874 859.199,606.874 859.208,606.874 859.217,606.874 859.226,606.874 859.236,606.874 859.245,606.874 859.254,606.874 859.263,606.874 859.272,606.874 859.282,606.874 859.291,606.874 859.3,606.874 859.309,606.874 859.318,606.874 859.328,606.874 859.337,606.874 859.346,606.874 859.355,606.874 859.364,606.874 859.373,606.875 859.383,606.875 859.392,606.875 859.401,606.875 859.41,606.875 859.419,606.875 859.429,606.875 859.438,606.875 859.447,606.875 859.456,606.875 859.465,606.875 859.475,606.875 859.484,606.875 859.493,606.875 859.502,606.875 859.511,606.875 859.521,606.875 859.53,606.875 859.539,606.875 859.548,606.875 859.557,606.875 859.566,606.875 859.576,606.875 859.585,606.875 859.594,606.875 859.603,606.875 859.612,606.875 859.622,606.875 859.631,606.875 859.64,606.875 859.649,606.875 859.658,606.875 859.668,606.875 859.677,606.875 859.686,606.876 859.695,606.876 859.704,606.876 859.713,606.876 859.723,606.876 859.732,606.876 859.741,606.876 859.75,606.876 859.759,606.876 859.769,606.876 859.778,606.876 859.787,606.876 859.796,606.876 859.805,606.876 859.815,606.876 859.824,606.876 859.833,606.876 859.842,606.876 859.851,606.876 859.861,606.876 859.87,606.876 859.879,606.876 859.888,606.876 859.897,606.876 859.906,606.876 859.916,606.876 859.925,606.876 859.934,606.876 859.943,606.876 859.952,606.876 859.962,606.876 859.971,606.876 859.98,606.876 859.989,606.876 859.998,606.876 860.008,606.876 860.017,606.876 860.026,606.876 860.035,606.877 860.044,606.877 860.053,606.877 860.063,606.877 860.072,606.877 860.081,606.877 860.09,606.877 860.099,606.877 860.109,606.877 860.118,606.877 860.127,606.877 860.136,606.877 860.145,606.877 860.155,606.877 860.164,606.877 860.173,606.877 860.182,606.877 860.191,606.877 860.201,606.877 860.21,606.877 860.219,606.877 860.228,606.877 860.237,606.877 860.246,606.877 860.256,606.877 860.265,606.877 860.274,606.877 860.283,606.877 860.292,606.877 860.302,606.877 860.311,606.877 860.32,606.877 860.329,606.877 860.338,606.877 860.348,606.877 860.357,606.877 860.366,606.877 860.375,606.877 860.384,606.877 860.393,606.877 860.403,606.877 860.412,606.877 860.421,606.877 860.43,606.877 860.439,606.877 860.449,606.878 860.458,606.878 860.467,606.878 860.476,606.878 860.485,606.878 860.495,606.878 860.504,606.878 860.513,606.878 860.522,606.878 860.531,606.878 860.541,606.878 860.55,606.878 860.559,606.878 860.568,606.878 860.577,606.878 860.586,606.878 860.596,606.878 860.605,606.878 860.614,606.878 860.623,606.878 860.632,606.878 860.642,606.878 860.651,606.878 860.66,606.878 860.669,606.878 860.678,606.878 860.688,606.878 860.697,606.878 860.706,606.878 860.715,606.878 860.724,606.878 860.733,606.878 860.743,606.878 860.752,606.878 860.761,606.878 860.77,606.878 860.779,606.878 860.789,606.878 860.798,606.878 860.807,606.878 860.816,606.878 860.825,606.878 860.835,606.878 860.844,606.878 860.853,606.878 860.862,606.878 860.871,606.878 860.881,606.878 860.89,606.878 860.899,606.878 860.908,606.878 860.917,606.878 860.926,606.878 860.936,606.878 860.945,606.878 860.954,606.878 860.963,606.879 860.972,606.879 860.982,606.879 860.991,606.879 861,606.879 861.009,606.879 861.018,606.879 861.028,606.879 861.037,606.879 861.046,606.879 861.055,606.879 861.064,606.879 861.073,606.879 861.083,606.879 861.092,606.879 861.101,606.879 861.11,606.879 861.119,606.879 861.129,606.879 861.138,606.879 861.147,606.879 861.156,606.879 861.165,606.879 861.175,606.879 861.184,606.879 861.193,606.879 861.202,606.879 861.211,606.879 861.221,606.879 861.23,606.879 861.239,606.879 861.248,606.879 861.257,606.879 861.266,606.879 861.276,606.879 861.285,606.879 861.294,606.879 861.303,606.879 861.312,606.879 861.322,606.879 861.331,606.879 861.34,606.879 861.349,606.879 861.358,606.879 861.368,606.879 861.377,606.879 861.386,606.879 861.395,606.879 861.404,606.879 861.414,606.879 861.423,606.879 861.432,606.879 861.441,606.879 861.45,606.879 861.459,606.879 861.469,606.879 861.478,606.879 861.487,606.879 861.496,606.879 861.505,606.879 861.515,606.879 861.524,606.879 861.533,606.879 861.542,606.879 861.551,606.879 861.561,606.879 861.57,606.879 861.579,606.879 861.588,606.879 861.597,606.879 861.606,606.879 861.616,606.879 861.625,606.879 861.634,606.879 861.643,606.879 861.652,606.879 861.662,606.879 861.671,606.879 861.68,606.879 861.689,606.879 861.698,606.879 861.708,606.879 861.717,606.879 861.726,606.879 861.735,606.879 861.744,606.879 861.754,606.879 861.763,606.879 861.772,606.879 861.781,606.879 861.79,606.879 861.799,606.879 861.809,606.88 861.818,606.88 861.827,606.88 861.836,606.88 861.845,606.88 861.855,606.88 861.864,606.88 861.873,606.88 861.882,606.88 861.891,606.88 861.901,606.88 861.91,606.88 861.919,606.88 861.928,606.88 861.937,606.88 861.946,606.88 861.956,606.88 861.965,606.88 861.974,606.88 861.983,606.88 861.992,606.88 862.002,606.88 862.011,606.88 862.02,606.88 862.029,606.88 862.038,606.88 862.048,606.88 862.057,606.88 862.066,606.88 862.075,606.88 862.084,606.88 862.094,606.88 862.103,606.88 862.112,606.88 862.121,606.88 862.13,606.88 862.139,606.88 862.149,606.88 862.158,606.88 862.167,606.88 862.176,606.88 862.185,606.88 862.195,606.88 862.204,606.88 862.213,606.88 862.222,606.88 862.231,606.88 862.241,606.88 862.25,606.88 862.259,606.88 862.268,606.88 862.277,606.88 862.286,606.88 862.296,606.88 862.305,606.88 862.314,606.88 862.323,606.88 862.332,606.88 862.342,606.88 862.351,606.88 862.36,606.88 862.369,606.88 862.378,606.88 862.388,606.88 862.397,606.88 862.406,606.88 862.415,606.88 862.424,606.88 862.434,606.88 862.443,606.88 862.452,606.88 862.461,606.88 862.47,606.88 862.479,606.88 862.489,606.88 862.498,606.88 862.507,606.88 862.516,606.88 862.525,606.88 862.535,606.88 862.544,606.88 862.553,606.88 862.562,606.88 862.571,606.88 862.581,606.88 862.59,606.88 862.599,606.88 862.608,606.88 862.617,606.88 862.626,606.88 862.636,606.88 862.645,606.88 862.654,606.88 862.663,606.88 862.672,606.88 862.682,606.88 862.691,606.88 862.7,606.88 862.709,606.88 862.718,606.88 862.728,606.88 862.737,606.88 862.746,606.88 862.755,606.88 862.764,606.88 862.774,606.88 862.783,606.88 862.792,606.88 862.801,606.88 862.81,606.88 862.819,606.88 862.829,606.88 862.838,606.88 862.847,606.88 862.856,606.88 862.865,606.88 862.875,606.88 862.884,606.88 862.893,606.88 862.902,606.88 862.911,606.88 862.921,606.88 862.93,606.88 862.939,606.88 862.948,606.88 862.957,606.88 862.966,606.88 862.976,606.88 862.985,606.88 862.994,606.88 863.003,606.88 863.012,606.88 863.022,606.88 863.031,606.88 863.04,606.88 863.049,606.88 863.058,606.88 863.068,606.88 863.077,606.88 863.086,606.88 863.095,606.88 863.104,606.88 863.114,606.88 863.123,606.88 863.132,606.88 863.141,606.88 863.15,606.88 863.159,606.88 863.169,606.88 863.178,606.88 863.187,606.88 863.196,606.88 863.205,606.88 863.215,606.88 863.224,606.88 863.233,606.88 863.242,606.88 863.251,606.88 863.261,606.88 863.27,606.88 863.279,606.88 863.288,606.88 863.297,606.879 863.306,606.879 863.316,606.879 863.325,606.879 863.334,606.879 863.343,606.879 863.352,606.879 863.362,606.879 863.371,606.879 863.38,606.879 863.389,606.879 863.398,606.879 863.408,606.879 863.417,606.879 863.426,606.879 863.435,606.879 863.444,606.879 863.454,606.879 863.463,606.879 863.472,606.879 863.481,606.879 863.49,606.879 863.499,606.879 863.509,606.879 863.518,606.879 863.527,606.879 863.536,606.879 863.545,606.879 863.555,606.879 863.564,606.879 863.573,606.879 863.582,606.879 863.591,606.879 863.601,606.879 863.61,606.879 863.619,606.879 863.628,606.879 863.637,606.879 863.646,606.879 863.656,606.879 863.665,606.879 863.674,606.879 863.683,606.879 863.692,606.879 863.702,606.879 863.711,606.879 863.72,606.879 863.729,606.879 863.738,606.879 863.748,606.879 863.757,606.879 863.766,606.879 863.775,606.879 863.784,606.879 863.794,606.879 863.803,606.879 863.812,606.879 863.821,606.879 863.83,606.879 863.839,606.879 863.849,606.879 863.858,606.879 863.867,606.879 863.876,606.879 863.885,606.879 863.895,606.879 863.904,606.879 863.913,606.879 863.922,606.879 863.931,606.879 863.941,606.879 863.95,606.879 863.959,606.879 863.968,606.879 863.977,606.879 863.987,606.879 863.996,606.879 864.005,606.879 864.014,606.879 864.023,606.879 864.032,606.879 864.042,606.879 864.051,606.879 864.06,606.879 864.069,606.879 864.078,606.879 864.088,606.879 864.097,606.879 864.106,606.879 864.115,606.879 864.124,606.879 864.134,606.879 864.143,606.879 864.152,606.879 864.161,606.879 864.17,606.878 864.179,606.878 864.189,606.878 864.198,606.878 864.207,606.878 864.216,606.878 864.225,606.878 864.235,606.878 864.244,606.878 864.253,606.878 864.262,606.878 864.271,606.878 864.281,606.878 864.29,606.878 864.299,606.878 864.308,606.878 864.317,606.878 864.327,606.878 864.336,606.878 864.345,606.878 864.354,606.878 864.363,606.878 864.372,606.878 864.382,606.878 864.391,606.878 864.4,606.878 864.409,606.878 864.418,606.878 864.428,606.878 864.437,606.878 864.446,606.878 864.455,606.878 864.464,606.878 864.474,606.878 864.483,606.878 864.492,606.878 864.501,606.878 864.51,606.878 864.519,606.878 864.529,606.878 864.538,606.878 864.547,606.878 864.556,606.878 864.565,606.878 864.575,606.878 864.584,606.878 864.593,606.878 864.602,606.878 864.611,606.878 864.621,606.878 864.63,606.878 864.639,606.878 864.648,606.878 864.657,606.878 864.667,606.878 864.676,606.878 864.685,606.878 864.694,606.878 864.703,606.878 864.712,606.878 864.722,606.877 864.731,606.877 864.74,606.877 864.749,606.877 864.758,606.877 864.768,606.877 864.777,606.877 864.786,606.877 864.795,606.877 864.804,606.877 864.814,606.877 864.823,606.877 864.832,606.877 864.841,606.877 864.85,606.877 864.859,606.877 864.869,606.877 864.878,606.877 864.887,606.877 864.896,606.877 864.905,606.877 864.915,606.877 864.924,606.877 864.933,606.877 864.942,606.877 864.951,606.877 864.961,606.877 864.97,606.877 864.979,606.877 864.988,606.877 864.997,606.877 865.007,606.877 865.016,606.877 865.025,606.877 865.034,606.877 865.043,606.877 865.052,606.877 865.062,606.877 865.071,606.877 865.08,606.877 865.089,606.877 865.098,606.877 865.108,606.877 865.117,606.877 865.126,606.877 865.135,606.877 865.144,606.877 865.154,606.877 865.163,606.876 865.172,606.876 865.181,606.876 865.19,606.876 865.199,606.876 865.209,606.876 865.218,606.876 865.227,606.876 865.236,606.876 865.245,606.876 865.255,606.876 865.264,606.876 865.273,606.876 865.282,606.876 865.291,606.876 865.301,606.876 865.31,606.876 865.319,606.876 865.328,606.876 865.337,606.876 865.347,606.876 865.356,606.876 865.365,606.876 865.374,606.876 865.383,606.876 865.392,606.876 865.402,606.876 865.411,606.876 865.42,606.876 865.429,606.876 865.438,606.876 865.448,606.876 865.457,606.876 865.466,606.876 865.475,606.876 865.484,606.876 865.494,606.876 865.503,606.876 865.512,606.876 865.521,606.876 865.53,606.876 865.539,606.876 865.549,606.875 865.558,606.875 865.567,606.875 865.576,606.875 865.585,606.875 865.595,606.875 865.604,606.875 865.613,606.875 865.622,606.875 865.631,606.875 865.641,606.875 865.65,606.875 865.659,606.875 865.668,606.875 865.677,606.875 865.687,606.875 865.696,606.875 865.705,606.875 865.714,606.875 865.723,606.875 865.732,606.875 865.742,606.875 865.751,606.875 865.76,606.875 865.769,606.875 865.778,606.875 865.788,606.875 865.797,606.875 865.806,606.875 865.815,606.875 865.824,606.875 865.834,606.875 865.843,606.875 865.852,606.875 865.861,606.875 865.87,606.875 865.879,606.875 865.889,606.874 865.898,606.874 865.907,606.874 865.916,606.874 865.925,606.874 865.935,606.874 865.944,606.874 865.953,606.874 865.962,606.874 865.971,606.874 865.981,606.874 865.99,606.874 865.999,606.874 866.008,606.874 866.017,606.874 866.027,606.874 866.036,606.874 866.045,606.874 866.054,606.874 866.063,606.874 866.072,606.874 866.082,606.874 866.091,606.874 866.1,606.874 866.109,606.874 866.118,606.874 866.128,606.874 866.137,606.874 866.146,606.874 866.155,606.874 866.164,606.874 866.174,606.874 866.183,606.874 866.192,606.874 866.201,606.873 866.21,606.873 866.219,606.873 866.229,606.873 866.238,606.873 866.247,606.873 866.256,606.873 866.265,606.873 866.275,606.873 866.284,606.873 866.293,606.873 866.302,606.873 866.311,606.873 866.321,606.873 866.33,606.873 866.339,606.873 866.348,606.873 866.357,606.873 866.367,606.873 866.376,606.873 866.385,606.873 866.394,606.873 866.403,606.873 866.412,606.873 866.422,606.873 866.431,606.873 866.44,606.873 866.449,606.873 866.458,606.873 866.468,606.873 866.477,606.873 866.486,606.872 866.495,606.872 866.504,606.872 866.514,606.872 866.523,606.872 866.532,606.872 866.541,606.872 866.55,606.872 866.56,606.872 866.569,606.872 866.578,606.872 866.587,606.872 866.596,606.872 866.605,606.872 866.615,606.872 866.624,606.872 866.633,606.872 866.642,606.872 866.651,606.872 866.661,606.872 866.67,606.872 866.679,606.872 866.688,606.872 866.697,606.872 866.707,606.872 866.716,606.872 866.725,606.872 866.734,606.872 866.743,606.872 866.752,606.872 866.762,606.871 866.771,606.871 866.78,606.871 866.789,606.871 866.798,606.871 866.808,606.871 866.817,606.871 866.826,606.871 866.835,606.871 866.844,606.871 866.854,606.871 866.863,606.871 866.872,606.871 866.881,606.871 866.89,606.871 866.9,606.871 866.909,606.871 866.918,606.871 866.927,606.871 866.936,606.871 866.945,606.871 866.955,606.871 866.964,606.871 866.973,606.871 866.982,606.871 866.991,606.871 867.001,606.871 867.01,606.87 867.019,606.87 867.028,606.87 867.037,606.87 867.047,606.87 867.056,606.87 867.065,606.87 867.074,606.87 867.083,606.87 867.092,606.87 867.102,606.87 867.111,606.87 867.12,606.87 867.129,606.87 867.138,606.87 867.148,606.87 867.157,606.87 867.166,606.87 867.175,606.87 867.184,606.87 867.194,606.87 867.203,606.87 867.212,606.87 867.221,606.87 867.23,606.87 867.24,606.87 867.249,606.87 867.258,606.869 867.267,606.869 867.276,606.869 867.285,606.869 867.295,606.869 867.304,606.869 867.313,606.869 867.322,606.869 867.331,606.869 867.341,606.869 867.35,606.869 867.359,606.869 867.368,606.869 867.377,606.869 867.387,606.869 867.396,606.869 867.405,606.869 867.414,606.869 867.423,606.869 867.432,606.869 867.442,606.869 867.451,606.869 867.46,606.869 867.469,606.869 867.478,606.869 867.488,606.868 867.497,606.868 867.506,606.868 867.515,606.868 867.524,606.868 867.534,606.868 867.543,606.868 867.552,606.868 867.561,606.868 867.57,606.868 867.58,606.868 867.589,606.868 867.598,606.868 867.607,606.868 867.616,606.868 867.625,606.868 867.635,606.868 867.644,606.868 867.653,606.868 867.662,606.868 867.671,606.868 867.681,606.868 867.69,606.868 867.699,606.868 867.708,606.867 867.717,606.867 867.727,606.867 867.736,606.867 867.745,606.867 867.754,606.867 867.763,606.867 867.772,606.867 867.782,606.867 867.791,606.867 867.8,606.867 867.809,606.867 867.818,606.867 867.828,606.867 867.837,606.867 867.846,606.867 867.855,606.867 867.864,606.867 867.874,606.867 867.883,606.867 867.892,606.867 867.901,606.867 867.91,606.867 867.92,606.867 867.929,606.866 867.938,606.866 867.947,606.866 867.956,606.866 867.965,606.866 867.975,606.866 867.984,606.866 867.993,606.866 868.002,606.866 868.011,606.866 868.021,606.866 868.03,606.866 868.039,606.866 868.048,606.866 868.057,606.866 868.067,606.866 868.076,606.866 868.085,606.866 868.094,606.866 868.103,606.866 868.112,606.866 868.122,606.866 868.131,606.865 868.14,606.865 868.149,606.865 868.158,606.865 868.168,606.865 868.177,606.865 868.186,606.865 868.195,606.865 868.204,606.865 868.214,606.865 868.223,606.865 868.232,606.865 868.241,606.865 868.25,606.865 868.26,606.865 868.269,606.865 868.278,606.865 868.287,606.865 868.296,606.865 868.305,606.865 868.315,606.865 868.324,606.865 868.333,606.864 868.342,606.864 868.351,606.864 868.361,606.864 868.37,606.864 868.379,606.864 868.388,606.864 868.397,606.864 868.407,606.864 868.416,606.864 868.425,606.864 868.434,606.864 868.443,606.864 868.452,606.864 868.462,606.864 868.471,606.864 868.48,606.864 868.489,606.864 868.498,606.864 868.508,606.864 868.517,606.864 868.526,606.863 868.535,606.863 868.544,606.863 868.554,606.863 868.563,606.863 868.572,606.863 868.581,606.863 868.59,606.863 868.6,606.863 868.609,606.863 868.618,606.863 868.627,606.863 868.636,606.863 868.645,606.863 868.655,606.863 868.664,606.863 868.673,606.863 868.682,606.863 868.691,606.863 868.701,606.863 868.71,606.863 868.719,606.862 868.728,606.862 868.737,606.862 868.747,606.862 868.756,606.862 868.765,606.862 868.774,606.862 868.783,606.862 868.793,606.862 868.802,606.862 868.811,606.862 868.82,606.862 868.829,606.862 868.838,606.862 868.848,606.862 868.857,606.862 868.866,606.862 868.875,606.862 868.884,606.862 868.894,606.862 868.903,606.861 868.912,606.861 868.921,606.861 868.93,606.861 868.94,606.861 868.949,606.861 868.958,606.861 868.967,606.861 868.976,606.861 868.985,606.861 868.995,606.861 869.004,606.861 869.013,606.861 869.022,606.861 869.031,606.861 869.041,606.861 869.05,606.861 869.059,606.861 869.068,606.861 869.077,606.861 869.087,606.86 869.096,606.86 869.105,606.86 869.114,606.86 869.123,606.86 869.133,606.86 869.142,606.86 869.151,606.86 869.16,606.86 869.169,606.86 869.178,606.86 869.188,606.86 869.197,606.86 869.206,606.86 869.215,606.86 869.224,606.86 869.234,606.86 869.243,606.86 869.252,606.86 869.261,606.859 869.27,606.859 869.28,606.859 869.289,606.859 869.298,606.859 869.307,606.859 869.316,606.859 869.325,606.859 869.335,606.859 869.344,606.859 869.353,606.859 869.362,606.859 869.371,606.859 869.381,606.859 869.39,606.859 869.399,606.859 869.408,606.859 869.417,606.859 869.427,606.859 869.436,606.858 869.445,606.858 869.454,606.858 869.463,606.858 869.473,606.858 869.482,606.858 869.491,606.858 869.5,606.858 869.509,606.858 869.518,606.858 869.528,606.858 869.537,606.858 869.546,606.858 869.555,606.858 869.564,606.858 869.574,606.858 869.583,606.858 869.592,606.858 869.601,606.857 869.61,606.857 869.62,606.857 869.629,606.857 869.638,606.857 869.647,606.857 869.656,606.857 869.665,606.857 869.675,606.857 869.684,606.857 869.693,606.857 869.702,606.857 869.711,606.857 869.721,606.857 869.73,606.857 869.739,606.857 869.748,606.857 869.757,606.857 869.767,606.856 869.776,606.856 869.785,606.856 869.794,606.856 869.803,606.856 869.813,606.856 869.822,606.856 869.831,606.856 869.84,606.856 869.849,606.856 869.858,606.856 869.868,606.856 869.877,606.856 869.886,606.856 869.895,606.856 869.904,606.856 869.914,606.856 869.923,606.856 869.932,606.855 869.941,606.855 869.95,606.855 869.96,606.855 869.969,606.855 869.978,606.855 869.987,606.855 869.996,606.855 870.005,606.855 870.015,606.855 870.024,606.855 870.033,606.855 870.042,606.855 870.051,606.855 870.061,606.855 870.07,606.855 870.079,606.855 870.088,606.854 870.097,606.854 870.107,606.854 870.116,606.854 870.125,606.854 870.134,606.854 870.143,606.854 870.153,606.854 870.162,606.854 870.171,606.854 870.18,606.854 870.189,606.854 870.198,606.854 870.208,606.854 870.217,606.854 870.226,606.854 870.235,606.854 870.244,606.853 870.254,606.853 870.263,606.853 870.272,606.853 870.281,606.853 870.29,606.853 870.3,606.853 870.309,606.853 870.318,606.853 870.327,606.853 870.336,606.853 870.345,606.853 870.355,606.853 870.364,606.853 870.373,606.853 870.382,606.853 870.391,606.853 870.401,606.852 870.41,606.852 870.419,606.852 870.428,606.852 870.437,606.852 870.447,606.852 870.456,606.852 870.465,606.852 870.474,606.852 870.483,606.852 870.493,606.852 870.502,606.852 870.511,606.852 870.52,606.852 870.529,606.852 870.538,606.852 870.548,606.851 870.557,606.851 870.566,606.851 870.575,606.851 870.584,606.851 870.594,606.851 870.603,606.851 870.612,606.851 870.621,606.851 870.63,606.851 870.64,606.851 870.649,606.851 870.658,606.851 870.667,606.851 870.676,606.851 870.685,606.851 870.695,606.851 870.704,606.85 870.713,606.85 870.722,606.85 870.731,606.85 870.741,606.85 870.75,606.85 870.759,606.85 870.768,606.85 870.777,606.85 870.787,606.85 870.796,606.85 870.805,606.85 870.814,606.85 870.823,606.85 870.833,606.85 870.842,606.85 870.851,606.849 870.86,606.849 870.869,606.849 870.878,606.849 870.888,606.849 870.897,606.849 870.906,606.849 870.915,606.849 870.924,606.849 870.934,606.849 870.943,606.849 870.952,606.849 870.961,606.849 870.97,606.849 870.98,606.849 870.989,606.848 870.998,606.848 871.007,606.848 871.016,606.848 871.025,606.848 871.035,606.848 871.044,606.848 871.053,606.848 871.062,606.848 871.071,606.848 871.081,606.848 871.09,606.848 871.099,606.848 871.108,606.848 871.117,606.848 871.127,606.848 871.136,606.847 871.145,606.847 871.154,606.847 871.163,606.847 871.173,606.847 871.182,606.847 871.191,606.847 871.2,606.847 871.209,606.847 871.218,606.847 871.228,606.847 871.237,606.847 871.246,606.847 871.255,606.847 871.264,606.847 871.274,606.846 871.283,606.846 871.292,606.846 871.301,606.846 871.31,606.846 871.32,606.846 871.329,606.846 871.338,606.846 871.347,606.846 871.356,606.846 871.366,606.846 871.375,606.846 871.384,606.846 871.393,606.846 871.402,606.846 871.411,606.845 871.421,606.845 871.43,606.845 871.439,606.845 871.448,606.845 871.457,606.845 871.467,606.845 871.476,606.845 871.485,606.845 871.494,606.845 871.503,606.845 871.513,606.845 871.522,606.845 871.531,606.845 871.54,606.845 871.549,606.844 871.558,606.844 871.568,606.844 871.577,606.844 871.586,606.844 871.595,606.844 871.604,606.844 871.614,606.844 871.623,606.844 871.632,606.844 871.641,606.844 871.65,606.844 871.66,606.844 871.669,606.844 871.678,606.844 871.687,606.843 871.696,606.843 871.706,606.843 871.715,606.843 871.724,606.843 871.733,606.843 871.742,606.843 871.751,606.843 871.761,606.843 871.77,606.843 871.779,606.843 871.788,606.843 871.797,606.843 871.807,606.843 871.816,606.843 871.825,606.842 871.834,606.842 871.843,606.842 871.853,606.842 871.862,606.842 871.871,606.842 871.88,606.842 871.889,606.842 871.898,606.842 871.908,606.842 871.917,606.842 871.926,606.842 871.935,606.842 871.944,606.842 871.954,606.841 871.963,606.841 871.972,606.841 871.981,606.841 871.99,606.841 872,606.841 872.009,606.841 872.018,606.841 872.027,606.841 872.036,606.841 872.046,606.841 872.055,606.841 872.064,606.841 872.073,606.841 872.082,606.841 872.091,606.84 872.101,606.84 872.11,606.84 872.119,606.84 872.128,606.84 872.137,606.84 872.147,606.84 872.156,606.84 872.165,606.84 872.174,606.84 872.183,606.84 872.193,606.84 872.202,606.84 872.211,606.84 872.22,606.839 872.229,606.839 872.238,606.839 872.248,606.839 872.257,606.839 872.266,606.839 872.275,606.839 872.284,606.839 872.294,606.839 872.303,606.839 872.312,606.839 872.321,606.839 872.33,606.839 872.34,606.839 872.349,606.838 872.358,606.838 872.367,606.838 872.376,606.838 872.386,606.838 872.395,606.838 872.404,606.838 872.413,606.838 872.422,606.838 872.431,606.838 872.441,606.838 872.45,606.838 872.459,606.838 872.468,606.837 872.477,606.837 872.487,606.837 872.496,606.837 872.505,606.837 872.514,606.837 872.523,606.837 872.533,606.837 872.542,606.837 872.551,606.837 872.56,606.837 872.569,606.837 872.578,606.837 872.588,606.837 872.597,606.836 872.606,606.836 872.615,606.836 872.624,606.836 872.634,606.836 872.643,606.836 872.652,606.836 872.661,606.836 872.67,606.836 872.68,606.836 872.689,606.836 872.698,606.836 872.707,606.836 872.716,606.836 872.726,606.835 872.735,606.835 872.744,606.835 872.753,606.835 872.762,606.835 872.771,606.835 872.781,606.835 872.79,606.835 872.799,606.835 872.808,606.835 872.817,606.835 872.827,606.835 872.836,606.835 872.845,606.834 872.854,606.834 872.863,606.834 872.873,606.834 872.882,606.834 872.891,606.834 872.9,606.834 872.909,606.834 872.918,606.834 872.928,606.834 872.937,606.834 872.946,606.834 872.955,606.834 872.964,606.834 872.974,606.833 872.983,606.833 872.992,606.833 873.001,606.833 873.01,606.833 873.02,606.833 873.029,606.833 873.038,606.833 873.047,606.833 873.056,606.833 873.066,606.833 873.075,606.833 873.084,606.833 873.093,606.832 873.102,606.832 873.111,606.832 873.121,606.832 873.13,606.832 873.139,606.832 873.148,606.832 873.157,606.832 873.167,606.832 873.176,606.832 873.185,606.832 873.194,606.832 873.203,606.832 873.213,606.831 873.222,606.831 873.231,606.831 873.24,606.831 873.249,606.831 873.258,606.831 873.268,606.831 873.277,606.831 873.286,606.831 873.295,606.831 873.304,606.831 873.314,606.831 873.323,606.831 873.332,606.83 873.341,606.83 873.35,606.83 873.36,606.83 873.369,606.83 873.378,606.83 873.387,606.83 873.396,606.83 873.406,606.83 873.415,606.83 873.424,606.83 873.433,606.83 873.442,606.83 873.451,606.829 873.461,606.829 873.47,606.829 873.479,606.829 873.488,606.829 873.497,606.829 873.507,606.829 873.516,606.829 873.525,606.829 873.534,606.829 873.543,606.829 873.553,606.829 873.562,606.828 873.571,606.828 873.58,606.828 873.589,606.828 873.598,606.828 873.608,606.828 873.617,606.828 873.626,606.828 873.635,606.828 873.644,606.828 873.654,606.828 873.663,606.828 873.672,606.828 873.681,606.827 873.69,606.827 873.7,606.827 873.709,606.827 873.718,606.827 873.727,606.827 873.736,606.827 873.746,606.827 873.755,606.827 873.764,606.827 873.773,606.827 873.782,606.827 873.791,606.827 873.801,606.826 873.81,606.826 873.819,606.826 873.828,606.826 873.837,606.826 873.847,606.826 873.856,606.826 873.865,606.826 873.874,606.826 873.883,606.826 873.893,606.826 873.902,606.826 873.911,606.825 873.92,606.825 873.929,606.825 873.939,606.825 873.948,606.825 873.957,606.825 873.966,606.825 873.975,606.825 873.984,606.825 873.994,606.825 874.003,606.825 874.012,606.825 874.021,606.825 874.03,606.824 874.04,606.824 874.049,606.824 874.058,606.824 874.067,606.824 874.076,606.824 874.086,606.824 874.095,606.824 874.104,606.824 874.113,606.824 874.122,606.824 874.131,606.824 874.141,606.823 874.15,606.823 874.159,606.823 874.168,606.823 874.177,606.823 874.187,606.823 874.196,606.823 874.205,606.823 874.214,606.823 874.223,606.823 874.233,606.823 874.242,606.823 874.251,606.822 874.26,606.822 874.269,606.822 874.279,606.822 874.288,606.822 874.297,606.822 874.306,606.822 874.315,606.822 874.324,606.822 874.334,606.822 874.343,606.822 874.352,606.822 874.361,606.821 874.37,606.821 874.38,606.821 874.389,606.821 874.398,606.821 874.407,606.821 874.416,606.821 874.426,606.821 874.435,606.821 874.444,606.821 874.453,606.821 874.462,606.821 874.471,606.82 874.481,606.82 874.49,606.82 874.499,606.82 874.508,606.82 874.517,606.82 874.527,606.82 874.536,606.82 874.545,606.82 874.554,606.82 874.563,606.82 874.573,606.82 874.582,606.819 874.591,606.819 874.6,606.819 874.609,606.819 874.619,606.819 874.628,606.819 874.637,606.819 874.646,606.819 874.655,606.819 874.664,606.819 874.674,606.819 874.683,606.819 874.692,606.818 874.701,606.818 874.71,606.818 874.72,606.818 874.729,606.818 874.738,606.818 874.747,606.818 874.756,606.818 874.766,606.818 874.775,606.818 874.784,606.818 874.793,606.818 874.802,606.817 874.811,606.817 874.821,606.817 874.83,606.817 874.839,606.817 874.848,606.817 874.857,606.817 874.867,606.817 874.876,606.817 874.885,606.817 874.894,606.817 874.903,606.816 874.913,606.816 874.922,606.816 874.931,606.816 874.94,606.816 874.949,606.816 874.959,606.816 874.968,606.816 874.977,606.816 874.986,606.816 874.995,606.816 875.004,606.816 875.014,606.815 875.023,606.815 875.032,606.815 875.041,606.815 875.05,606.815 875.06,606.815 875.069,606.815 875.078,606.815 875.087,606.815 875.096,606.815 875.106,606.815 875.115,606.815 875.124,606.814 875.133,606.814 875.142,606.814 875.151,606.814 875.161,606.814 875.17,606.814 875.179,606.814 875.188,606.814 875.197,606.814 875.207,606.814 875.216,606.814 875.225,606.813 875.234,606.813 875.243,606.813 875.253,606.813 875.262,606.813 875.271,606.813 875.28,606.813 875.289,606.813 875.299,606.813 875.308,606.813 875.317,606.813 875.326,606.813 875.335,606.812 875.344,606.812 875.354,606.812 875.363,606.812 875.372,606.812 875.381,606.812 875.39,606.812 875.4,606.812 875.409,606.812 875.418,606.812 875.427,606.812 875.436,606.811 875.446,606.811 875.455,606.811 875.464,606.811 875.473,606.811 875.482,606.811 875.491,606.811 875.501,606.811 875.51,606.811 875.519,606.811 875.528,606.811 875.537,606.81 875.547,606.81 875.556,606.81 875.565,606.81 875.574,606.81 875.583,606.81 875.593,606.81 875.602,606.81 875.611,606.81 875.62,606.81 875.629,606.81 875.639,606.81 875.648,606.809 875.657,606.809 875.666,606.809 875.675,606.809 875.684,606.809 875.694,606.809 875.703,606.809 875.712,606.809 875.721,606.809 875.73,606.809 875.74,606.809 875.749,606.808 875.758,606.808 875.767,606.808 875.776,606.808 875.786,606.808 875.795,606.808 875.804,606.808 875.813,606.808 875.822,606.808 875.831,606.808 875.841,606.808 875.85,606.807 875.859,606.807 875.868,606.807 875.877,606.807 875.887,606.807 875.896,606.807 875.905,606.807 875.914,606.807 875.923,606.807 875.933,606.807 875.942,606.807 875.951,606.806 875.96,606.806 875.969,606.806 875.979,606.806 875.988,606.806 875.997,606.806 876.006,606.806 876.015,606.806 876.024,606.806 876.034,606.806 876.043,606.806 876.052,606.805 876.061,606.805 876.07,606.805 876.08,606.805 876.089,606.805 876.098,606.805 876.107,606.805 876.116,606.805 876.126,606.805 876.135,606.805 876.144,606.805 876.153,606.804 876.162,606.804 876.171,606.804 876.181,606.804 876.19,606.804 876.199,606.804 876.208,606.804 876.217,606.804 876.227,606.804 876.236,606.804 876.245,606.804 876.254,606.803 876.263,606.803 876.273,606.803 876.282,606.803 876.291,606.803 876.3,606.803 876.309,606.803 876.319,606.803 876.328,606.803 876.337,606.803 876.346,606.802 876.355,606.802 876.364,606.802 876.374,606.802 876.383,606.802 876.392,606.802 876.401,606.802 876.41,606.802 876.42,606.802 876.429,606.802 876.438,606.802 876.447,606.801 876.456,606.801 876.466,606.801 876.475,606.801 876.484,606.801 876.493,606.801 876.502,606.801 876.512,606.801 876.521,606.801 876.53,606.801 876.539,606.801 876.548,606.8 876.557,606.8 876.567,606.8 876.576,606.8 876.585,606.8 876.594,606.8 876.603,606.8 876.613,606.8 876.622,606.8 876.631,606.8 876.64,606.8 876.649,606.799 876.659,606.799 876.668,606.799 876.677,606.799 876.686,606.799 876.695,606.799 876.704,606.799 876.714,606.799 876.723,606.799 876.732,606.799 876.741,606.798 876.75,606.798 876.76,606.798 876.769,606.798 876.778,606.798 876.787,606.798 876.796,606.798 876.806,606.798 876.815,606.798 876.824,606.798 876.833,606.798 876.842,606.797 876.852,606.797 876.861,606.797 876.87,606.797 876.879,606.797 876.888,606.797 876.897,606.797 876.907,606.797 876.916,606.797 876.925,606.797 876.934,606.796 876.943,606.796 876.953,606.796 876.962,606.796 876.971,606.796 876.98,606.796 876.989,606.796 876.999,606.796 877.008,606.796 877.017,606.796 877.026,606.796 877.035,606.795 877.044,606.795 877.054,606.795 877.063,606.795 877.072,606.795 877.081,606.795 877.09,606.795 877.1,606.795 877.109,606.795 877.118,606.795 877.127,606.794 877.136,606.794 877.146,606.794 877.155,606.794 877.164,606.794 877.173,606.794 877.182,606.794 877.192,606.794 877.201,606.794 877.21,606.794 877.219,606.794 877.228,606.793 877.237,606.793 877.247,606.793 877.256,606.793 877.265,606.793 877.274,606.793 877.283,606.793 877.293,606.793 877.302,606.793 877.311,606.793 877.32,606.792 877.329,606.792 877.339,606.792 877.348,606.792 877.357,606.792 877.366,606.792 877.375,606.792 877.384,606.792 877.394,606.792 877.403,606.792 877.412,606.791 877.421,606.791 877.43,606.791 877.44,606.791 877.449,606.791 877.458,606.791 877.467,606.791 877.476,606.791 877.486,606.791 877.495,606.791 877.504,606.79 877.513,606.79 877.522,606.79 877.532,606.79 877.541,606.79 877.55,606.79 877.559,606.79 877.568,606.79 877.577,606.79 877.587,606.79 877.596,606.79 877.605,606.789 877.614,606.789 877.623,606.789 877.633,606.789 877.642,606.789 877.651,606.789 877.66,606.789 877.669,606.789 877.679,606.789 877.688,606.789 877.697,606.788 877.706,606.788 877.715,606.788 877.724,606.788 877.734,606.788 877.743,606.788 877.752,606.788 877.761,606.788 877.77,606.788 877.78,606.788 877.789,606.787 877.798,606.787 877.807,606.787 877.816,606.787 877.826,606.787 877.835,606.787 877.844,606.787 877.853,606.787 877.862,606.787 877.872,606.787 877.881,606.786 877.89,606.786 877.899,606.786 877.908,606.786 877.917,606.786 877.927,606.786 877.936,606.786 877.945,606.786 877.954,606.786 877.963,606.786 877.973,606.785 877.982,606.785 877.991,606.785 878,606.785 878.009,606.785 878.019,606.785 878.028,606.785 878.037,606.785 878.046,606.785 878.055,606.785 878.064,606.784 878.074,606.784 878.083,606.784 878.092,606.784 878.101,606.784 878.11,606.784 878.12,606.784 878.129,606.784 878.138,606.784 878.147,606.784 878.156,606.783 878.166,606.783 878.175,606.783 878.184,606.783 878.193,606.783 878.202,606.783 878.212,606.783 878.221,606.783 878.23,606.783 878.239,606.783 878.248,606.782 878.257,606.782 878.267,606.782 878.276,606.782 878.285,606.782 878.294,606.782 878.303,606.782 878.313,606.782 878.322,606.782 878.331,606.782 878.34,606.781 878.349,606.781 878.359,606.781 878.368,606.781 878.377,606.781 878.386,606.781 878.395,606.781 878.404,606.781 878.414,606.781 878.423,606.781 878.432,606.78 878.441,606.78 878.45,606.78 878.46,606.78 878.469,606.78 878.478,606.78 878.487,606.78 878.496,606.78 878.506,606.78 878.515,606.779 878.524,606.779 878.533,606.779 878.542,606.779 878.552,606.779 878.561,606.779 878.57,606.779 878.579,606.779 878.588,606.779 878.597,606.779 878.607,606.778 878.616,606.778 878.625,606.778 878.634,606.778 878.643,606.778 878.653,606.778 878.662,606.778 878.671,606.778 878.68,606.778 878.689,606.778 878.699,606.777 878.708,606.777 878.717,606.777 878.726,606.777 878.735,606.777 878.745,606.777 878.754,606.777 878.763,606.777 878.772,606.777 878.781,606.777 878.79,606.776 878.8,606.776 878.809,606.776 878.818,606.776 878.827,606.776 878.836,606.776 878.846,606.776 878.855,606.776 878.864,606.776 878.873,606.775 878.882,606.775 878.892,606.775 878.901,606.775 878.91,606.775 878.919,606.775 878.928,606.775 878.937,606.775 878.947,606.775 878.956,606.775 878.965,606.774 878.974,606.774 878.983,606.774 878.993,606.774 879.002,606.774 879.011,606.774 879.02,606.774 879.029,606.774 879.039,606.774 879.048,606.774 879.057,606.773 879.066,606.773 879.075,606.773 879.085,606.773 879.094,606.773 879.103,606.773 879.112,606.773 879.121,606.773 879.13,606.773 879.14,606.772 879.149,606.772 879.158,606.772 879.167,606.772 879.176,606.772 879.186,606.772 879.195,606.772 879.204,606.772 879.213,606.772 879.222,606.772 879.232,606.771 879.241,606.771 879.25,606.771 879.259,606.771 879.268,606.771 879.277,606.771 879.287,606.771 879.296,606.771 879.305,606.771 879.314,606.77 879.323,606.77 879.333,606.77 879.342,606.77 879.351,606.77 879.36,606.77 879.369,606.77 879.379,606.77 879.388,606.77 879.397,606.77 879.406,606.769 879.415,606.769 879.425,606.769 879.434,606.769 879.443,606.769 879.452,606.769 879.461,606.769 879.47,606.769 879.48,606.769 879.489,606.768 879.498,606.768 879.507,606.768 879.516,606.768 879.526,606.768 879.535,606.768 879.544,606.768 879.553,606.768 879.562,606.768 879.572,606.767 879.581,606.767 879.59,606.767 879.599,606.767 879.608,606.767 879.617,606.767 879.627,606.767 879.636,606.767 879.645,606.767 879.654,606.767 879.663,606.766 879.673,606.766 879.682,606.766 879.691,606.766 879.7,606.766 879.709,606.766 879.719,606.766 879.728,606.766 879.737,606.766 879.746,606.765 879.755,606.765 879.765,606.765 879.774,606.765 879.783,606.765 879.792,606.765 879.801,606.765 879.81,606.765 879.82,606.765 879.829,606.765 879.838,606.764 879.847,606.764 879.856,606.764 879.866,606.764 879.875,606.764 879.884,606.764 879.893,606.764 879.902,606.764 879.912,606.764 879.921,606.763 879.93,606.763 879.939,606.763 879.948,606.763 879.957,606.763 879.967,606.763 879.976,606.763 879.985,606.763 879.994,606.763 880.003,606.762 880.013,606.762 880.022,606.762 880.031,606.762 880.04,606.762 880.049,606.762 880.059,606.762 880.068,606.762 880.077,606.762 880.086,606.761 880.095,606.761 880.105,606.761 880.114,606.761 880.123,606.761 880.132,606.761 880.141,606.761 880.15,606.761 880.16,606.761 880.169,606.761 880.178,606.76 880.187,606.76 880.196,606.76 880.206,606.76 880.215,606.76 880.224,606.76 880.233,606.76 880.242,606.76 880.252,606.76 880.261,606.759 880.27,606.759 880.279,606.759 880.288,606.759 880.297,606.759 880.307,606.759 880.316,606.759 880.325,606.759 880.334,606.759 880.343,606.758 880.353,606.758 880.362,606.758 880.371,606.758 880.38,606.758 880.389,606.758 880.399,606.758 880.408,606.758 880.417,606.758 880.426,606.757 880.435,606.757 880.445,606.757 880.454,606.757 880.463,606.757 880.472,606.757 880.481,606.757 880.49,606.757 880.5,606.757 880.509,606.756 880.518,606.756 880.527,606.756 880.536,606.756 880.546,606.756 880.555,606.756 880.564,606.756 880.573,606.756 880.582,606.756 880.592,606.755 880.601,606.755 880.61,606.755 880.619,606.755 880.628,606.755 880.637,606.755 880.647,606.755 880.656,606.755 880.665,606.755 880.674,606.754 880.683,606.754 880.693,606.754 880.702,606.754 880.711,606.754 880.72,606.754 880.729,606.754 880.739,606.754 880.748,606.754 880.757,606.753 880.766,606.753 880.775,606.753 880.785,606.753 880.794,606.753 880.803,606.753 880.812,606.753 880.821,606.753 880.83,606.753 880.84,606.752 880.849,606.752 880.858,606.752 880.867,606.752 880.876,606.752 880.886,606.752 880.895,606.752 880.904,606.752 880.913,606.752 880.922,606.751 880.932,606.751 880.941,606.751 880.95,606.751 880.959,606.751 880.968,606.751 880.977,606.751 880.987,606.751 880.996,606.751 881.005,606.75 881.014,606.75 881.023,606.75 881.033,606.75 881.042,606.75 881.051,606.75 881.06,606.75 881.069,606.75 881.079,606.75 881.088,606.749 881.097,606.749 881.106,606.749 881.115,606.749 881.125,606.749 881.134,606.749 881.143,606.749 881.152,606.749 881.161,606.749 881.17,606.748 881.18,606.748 881.189,606.748 881.198,606.748 881.207,606.748 881.216,606.748 881.226,606.748 881.235,606.748 881.244,606.748 881.253,606.747 881.262,606.747 881.272,606.747 881.281,606.747 881.29,606.747 881.299,606.747 881.308,606.747 881.318,606.747 881.327,606.747 881.336,606.746 881.345,606.746 881.354,606.746 881.363,606.746 881.373,606.746 881.382,606.746 881.391,606.746 881.4,606.746 881.409,606.746 881.419,606.745 881.428,606.745 881.437,606.745 881.446,606.745 881.455,606.745 881.465,606.745 881.474,606.745 881.483,606.745 881.492,606.744 881.501,606.744 881.51,606.744 881.52,606.744 881.529,606.744 881.538,606.744 881.547,606.744 881.556,606.744 881.566,606.744 881.575,606.743 881.584,606.743 881.593,606.743 881.602,606.743 881.612,606.743 881.621,606.743 881.63,606.743 881.639,606.743 881.648,606.743 881.658,606.742 881.667,606.742 881.676,606.742 881.685,606.742 881.694,606.742 881.703,606.742 881.713,606.742 881.722,606.742 881.731,606.742 881.74,606.741 881.749,606.741 881.759,606.741 881.768,606.741 881.777,606.741 881.786,606.741 881.795,606.741 881.805,606.741 881.814,606.741 881.823,606.74 881.832,606.74 881.841,606.74 881.85,606.74 881.86,606.74 881.869,606.74 881.878,606.74 881.887,606.74 881.896,606.739 881.906,606.739 881.915,606.739 881.924,606.739 881.933,606.739 881.942,606.739 881.952,606.739 881.961,606.739 881.97,606.739 881.979,606.738 881.988,606.738 881.998,606.738 882.007,606.738 882.016,606.738 882.025,606.738 882.034,606.738 882.043,606.738 882.053,606.738 882.062,606.737 882.071,606.737 882.08,606.737 882.089,606.737 882.099,606.737 882.108,606.737 882.117,606.737 882.126,606.737 882.135,606.736 882.145,606.736 882.154,606.736 882.163,606.736 882.172,606.736 882.181,606.736 882.19,606.736 882.2,606.736 882.209,606.736 882.218,606.735 882.227,606.735 882.236,606.735 882.246,606.735 882.255,606.735 882.264,606.735 882.273,606.735 882.282,606.735 882.292,606.734 882.301,606.734 882.31,606.734 882.319,606.734 882.328,606.734 882.338,606.734 882.347,606.734 882.356,606.734 882.365,606.734 882.374,606.733 882.383,606.733 882.393,606.733 882.402,606.733 882.411,606.733 882.42,606.733 882.429,606.733 882.439,606.733 882.448,606.733 882.457,606.732 882.466,606.732 882.475,606.732 882.485,606.732 882.494,606.732 882.503,606.732 882.512,606.732 882.521,606.732 882.53,606.731 882.54,606.731 882.549,606.731 882.558,606.731 882.567,606.731 882.576,606.731 882.586,606.731 882.595,606.731 882.604,606.731 882.613,606.73 882.622,606.73 882.632,606.73 882.641,606.73 882.65,606.73 882.659,606.73 882.668,606.73 882.678,606.73 882.687,606.729 882.696,606.729 882.705,606.729 882.714,606.729 882.723,606.729 882.733,606.729 882.742,606.729 882.751,606.729 882.76,606.729 882.769,606.728 882.779,606.728 882.788,606.728 882.797,606.728 882.806,606.728 882.815,606.728 882.825,606.728 882.834,606.728 882.843,606.727 882.852,606.727 882.861,606.727 882.87,606.727 882.88,606.727 882.889,606.727 882.898,606.727 882.907,606.727 882.916,606.727 882.926,606.726 882.935,606.726 882.944,606.726 882.953,606.726 882.962,606.726 882.972,606.726 882.981,606.726 882.99,606.726 882.999,606.725 883.008,606.725 883.018,606.725 883.027,606.725 883.036,606.725 883.045,606.725 883.054,606.725 883.063,606.725 883.073,606.725 883.082,606.724 883.091,606.724 883.1,606.724 883.109,606.724 883.119,606.724 883.128,606.724 883.137,606.724 883.146,606.724 883.155,606.723 883.165,606.723 883.174,606.723 883.183,606.723 883.192,606.723 883.201,606.723 883.21,606.723 883.22,606.723 883.229,606.722 883.238,606.722 883.247,606.722 883.256,606.722 883.266,606.722 883.275,606.722 883.284,606.722 883.293,606.722 883.302,606.722 883.312,606.721 883.321,606.721 883.33,606.721 883.339,606.721 883.348,606.721 883.358,606.721 883.367,606.721 883.376,606.721 883.385,606.72 883.394,606.72 883.403,606.72 883.413,606.72 883.422,606.72 883.431,606.72 883.44,606.72 883.449,606.72 883.459,606.719 883.468,606.719 883.477,606.719 883.486,606.719 883.495,606.719 883.505,606.719 883.514,606.719 883.523,606.719 883.532,606.719 883.541,606.718 883.55,606.718 883.56,606.718 883.569,606.718 883.578,606.718 883.587,606.718 883.596,606.718 883.606,606.718 883.615,606.717 883.624,606.717 883.633,606.717 883.642,606.717 883.652,606.717 883.661,606.717 883.67,606.717 883.679,606.717 883.688,606.716 883.698,606.716 883.707,606.716 883.716,606.716 883.725,606.716 883.734,606.716 883.743,606.716 883.753,606.716 883.762,606.716 883.771,606.715 883.78,606.715 883.789,606.715 883.799,606.715 883.808,606.715 883.817,606.715 883.826,606.715 883.835,606.715 883.845,606.714 883.854,606.714 883.863,606.714 883.872,606.714 883.881,606.714 883.891,606.714 883.9,606.714 883.909,606.714 883.918,606.713 883.927,606.713 883.936,606.713 883.946,606.713 883.955,606.713 883.964,606.713 883.973,606.713 883.982,606.713 883.992,606.712 884.001,606.712 884.01,606.712 884.019,606.712 884.028,606.712 884.038,606.712 884.047,606.712 884.056,606.712 884.065,606.712 884.074,606.711 884.083,606.711 884.093,606.711 884.102,606.711 884.111,606.711 884.12,606.711 884.129,606.711 884.139,606.711 884.148,606.71 884.157,606.71 884.166,606.71 884.175,606.71 884.185,606.71 884.194,606.71 884.203,606.71 884.212,606.71 884.221,606.709 884.231,606.709 884.24,606.709 884.249,606.709 884.258,606.709 884.267,606.709 884.276,606.709 884.286,606.709 884.295,606.708 884.304,606.708 884.313,606.708 884.322,606.708 884.332,606.708 884.341,606.708 884.35,606.708 884.359,606.708 884.368,606.707 884.378,606.707 884.387,606.707 884.396,606.707 884.405,606.707 884.414,606.707 884.423,606.707 884.433,606.707 884.442,606.706 884.451,606.706 884.46,606.706 884.469,606.706 884.479,606.706 884.488,606.706 884.497,606.706 884.506,606.706 884.515,606.705 884.525,606.705 884.534,606.705 884.543,606.705 884.552,606.705 884.561,606.705 884.571,606.705 884.58,606.705 884.589,606.705 884.598,606.704 884.607,606.704 884.616,606.704 884.626,606.704 884.635,606.704 884.644,606.704 884.653,606.704 884.662,606.704 884.672,606.703 884.681,606.703 884.69,606.703 884.699,606.703 884.708,606.703 884.718,606.703 884.727,606.703 884.736,606.703 884.745,606.702 884.754,606.702 884.763,606.702 884.773,606.702 884.782,606.702 884.791,606.702 884.8,606.702 884.809,606.702 884.819,606.701 884.828,606.701 884.837,606.701 884.846,606.701 884.855,606.701 884.865,606.701 884.874,606.701 884.883,606.701 884.892,606.7 884.901,606.7 884.911,606.7 884.92,606.7 884.929,606.7 884.938,606.7 884.947,606.7 884.956,606.7 884.966,606.699 884.975,606.699 884.984,606.699 884.993,606.699 885.002,606.699 885.012,606.699 885.021,606.699 885.03,606.699 885.039,606.698 885.048,606.698 885.058,606.698 885.067,606.698 885.076,606.698 885.085,606.698 885.094,606.698 885.103,606.698 885.113,606.697 885.122,606.697 885.131,606.697 885.14,606.697 885.149,606.697 885.159,606.697 885.168,606.697 885.177,606.697 885.186,606.696 885.195,606.696 885.205,606.696 885.214,606.696 885.223,606.696 885.232,606.696 885.241,606.696 885.251,606.696 885.26,606.695 885.269,606.695 885.278,606.695 885.287,606.695 885.296,606.695 885.306,606.695 885.315,606.695 885.324,606.695 885.333,606.694 885.342,606.694 885.352,606.694 885.361,606.694 885.37,606.694 885.379,606.694 885.388,606.694 885.398,606.694 885.407,606.693 885.416,606.693 885.425,606.693 885.434,606.693 885.443,606.693 885.453,606.693 885.462,606.693 885.471,606.693 885.48,606.692 885.489,606.692 885.499,606.692 885.508,606.692 885.517,606.692 885.526,606.692 885.535,606.692 885.545,606.692 885.554,606.691 885.563,606.691 885.572,606.691 885.581,606.691 885.591,606.691 885.6,606.691 885.609,606.691 885.618,606.691 885.627,606.69 885.636,606.69 885.646,606.69 885.655,606.69 885.664,606.69 885.673,606.69 885.682,606.69 885.692,606.69 885.701,606.689 885.71,606.689 885.719,606.689 885.728,606.689 885.738,606.689 885.747,606.689 885.756,606.689 885.765,606.688 885.774,606.688 885.783,606.688 885.793,606.688 885.802,606.688 885.811,606.688 885.82,606.688 885.829,606.688 885.839,606.687 885.848,606.687 885.857,606.687 885.866,606.687 885.875,606.687 885.885,606.687 885.894,606.687 885.903,606.687 885.912,606.686 885.921,606.686 885.931,606.686 885.94,606.686 885.949,606.686 885.958,606.686 885.967,606.686 885.976,606.686 885.986,606.685 885.995,606.685 886.004,606.685 886.013,606.685 886.022,606.685 886.032,606.685 886.041,606.685 886.05,606.685 886.059,606.684 886.068,606.684 886.078,606.684 886.087,606.684 886.096,606.684 886.105,606.684 886.114,606.684 886.124,606.684 886.133,606.683 886.142,606.683 886.151,606.683 886.16,606.683 886.169,606.683 886.179,606.683 886.188,606.683 886.197,606.683 886.206,606.682 886.215,606.682 886.225,606.682 886.234,606.682 886.243,606.682 886.252,606.682 886.261,606.682 886.271,606.681 886.28,606.681 886.289,606.681 886.298,606.681 886.307,606.681 886.316,606.681 886.326,606.681 886.335,606.681 886.344,606.68 886.353,606.68 886.362,606.68 886.372,606.68 886.381,606.68 886.39,606.68 886.399,606.68 886.408,606.68 886.418,606.679 886.427,606.679 886.436,606.679 886.445,606.679 886.454,606.679 886.464,606.679 886.473,606.679 886.482,606.679 886.491,606.678 886.5,606.678 886.509,606.678 886.519,606.678 886.528,606.678 886.537,606.678 886.546,606.678 886.555,606.677 886.565,606.677 886.574,606.677 886.583,606.677 886.592,606.677 886.601,606.677 886.611,606.677 886.62,606.677 886.629,606.676 886.638,606.676 886.647,606.676 886.656,606.676 886.666,606.676 886.675,606.676 886.684,606.676 886.693,606.676 886.702,606.675 886.712,606.675 886.721,606.675 886.73,606.675 886.739,606.675 886.748,606.675 886.758,606.675 886.767,606.675 886.776,606.674 886.785,606.674 886.794,606.674 886.804,606.674 886.813,606.674 886.822,606.674 886.831,606.674 886.84,606.673 886.849,606.673 886.859,606.673 886.868,606.673 886.877,606.673 886.886,606.673 886.895,606.673 886.905,606.673 886.914,606.672 886.923,606.672 886.932,606.672 886.941,606.672 886.951,606.672 886.96,606.672 886.969,606.672 886.978,606.672 886.987,606.671 886.996,606.671 887.006,606.671 887.015,606.671 887.024,606.671 887.033,606.671 887.042,606.671 887.052,606.67 887.061,606.67 887.07,606.67 887.079,606.67 887.088,606.67 887.098,606.67 887.107,606.67 887.116,606.67 887.125,606.669 887.134,606.669 887.144,606.669 887.153,606.669 887.162,606.669 887.171,606.669 887.18,606.669 887.189,606.669 887.199,606.668 887.208,606.668 887.217,606.668 887.226,606.668 887.235,606.668 887.245,606.668 887.254,606.668 887.263,606.667 887.272,606.667 887.281,606.667 887.291,606.667 887.3,606.667 887.309,606.667 887.318,606.667 887.327,606.667 887.336,606.666 887.346,606.666 887.355,606.666 887.364,606.666 887.373,606.666 887.382,606.666 887.392,606.666 887.401,606.666 887.41,606.665 887.419,606.665 887.428,606.665 887.438,606.665 887.447,606.665 887.456,606.665 887.465,606.665 887.474,606.664 887.484,606.664 887.493,606.664 887.502,606.664 887.511,606.664 887.52,606.664 887.529,606.664 887.539,606.664 887.548,606.663 887.557,606.663 887.566,606.663 887.575,606.663 887.585,606.663 887.594,606.663 887.603,606.663 887.612,606.663 887.621,606.662 887.631,606.662 887.64,606.662 887.649,606.662 887.658,606.662 887.667,606.662 887.676,606.662 887.686,606.661 887.695,606.661 887.704,606.661 887.713,606.661 887.722,606.661 887.732,606.661 887.741,606.661 887.75,606.661 887.759,606.66 887.768,606.66 887.778,606.66 887.787,606.66 887.796,606.66 887.805,606.66 887.814,606.66 887.824,606.659 887.833,606.659 887.842,606.659 887.851,606.659 887.86,606.659 887.869,606.659 887.879,606.659 887.888,606.659 887.897,606.658 887.906,606.658 887.915,606.658 887.925,606.658 887.934,606.658 887.943,606.658 887.952,606.658 887.961,606.658 887.971,606.657 887.98,606.657 887.989,606.657 887.998,606.657 888.007,606.657 888.016,606.657 888.026,606.657 888.035,606.656 888.044,606.656 888.053,606.656 888.062,606.656 888.072,606.656 888.081,606.656 888.09,606.656 888.099,606.656 888.108,606.655 888.118,606.655 888.127,606.655 888.136,606.655 888.145,606.655 888.154,606.655 888.164,606.655 888.173,606.654 888.182,606.654 888.191,606.654 888.2,606.654 888.209,606.654 888.219,606.654 888.228,606.654 888.237,606.654 888.246,606.653 888.255,606.653 888.265,606.653 888.274,606.653 888.283,606.653 888.292,606.653 888.301,606.653 888.311,606.652 888.32,606.652 888.329,606.652 888.338,606.652 888.347,606.652 888.356,606.652 888.366,606.652 888.375,606.652 888.384,606.651 888.393,606.651 888.402,606.651 888.412,606.651 888.421,606.651 888.43,606.651 888.439,606.651 888.448,606.65 888.458,606.65 888.467,606.65 888.476,606.65 888.485,606.65 888.494,606.65 888.504,606.65 888.513,606.65 888.522,606.649 888.531,606.649 888.54,606.649 888.549,606.649 888.559,606.649 888.568,606.649 888.577,606.649 888.586,606.648 888.595,606.648 888.605,606.648 888.614,606.648 888.623,606.648 888.632,606.648 888.641,606.648 888.651,606.648 888.66,606.647 888.669,606.647 888.678,606.647 888.687,606.647 888.697,606.647 888.706,606.647 888.715,606.647 888.724,606.646 888.733,606.646 888.742,606.646 888.752,606.646 888.761,606.646 888.77,606.646 888.779,606.646 888.788,606.646 888.798,606.645 888.807,606.645 888.816,606.645 888.825,606.645 888.834,606.645 888.844,606.645 888.853,606.645 888.862,606.644 888.871,606.644 888.88,606.644 888.889,606.644 888.899,606.644 888.908,606.644 888.917,606.644 888.926,606.643 888.935,606.643 888.945,606.643 888.954,606.643 888.963,606.643 888.972,606.643 888.981,606.643 888.991,606.643 889,606.642 889.009,606.642 889.018,606.642 889.027,606.642 889.037,606.642 889.046,606.642 889.055,606.642 889.064,606.641 889.073,606.641 889.082,606.641 889.092,606.641 889.101,606.641 889.11,606.641 889.119,606.641 889.128,606.641 889.138,606.64 889.147,606.64 889.156,606.64 889.165,606.64 889.174,606.64 889.184,606.64 889.193,606.64 889.202,606.639 889.211,606.639 889.22,606.639 889.229,606.639 889.239,606.639 889.248,606.639 889.257,606.639 889.266,606.638 889.275,606.638 889.285,606.638 889.294,606.638 889.303,606.638 889.312,606.638 889.321,606.638 889.331,606.638 889.34,606.637 889.349,606.637 889.358,606.637 889.367,606.637 889.377,606.637 889.386,606.637 889.395,606.637 889.404,606.636 889.413,606.636 889.422,606.636 889.432,606.636 889.441,606.636 889.45,606.636 889.459,606.636 889.468,606.636 889.478,606.635 889.487,606.635 889.496,606.635 889.505,606.635 889.514,606.635 889.524,606.635 889.533,606.635 889.542,606.634 889.551,606.634 889.56,606.634 889.569,606.634 889.579,606.634 889.588,606.634 889.597,606.634 889.606,606.633 889.615,606.633 889.625,606.633 889.634,606.633 889.643,606.633 889.652,606.633 889.661,606.633 889.671,606.633 889.68,606.632 889.689,606.632 889.698,606.632 889.707,606.632 889.717,606.632 889.726,606.632 889.735,606.632 889.744,606.631 889.753,606.631 889.762,606.631 889.772,606.631 889.781,606.631 889.79,606.631 889.799,606.631 889.808,606.63 889.818,606.63 889.827,606.63 889.836,606.63 889.845,606.63 889.854,606.63 889.864,606.63 889.873,606.63 889.882,606.629 889.891,606.629 889.9,606.629 889.909,606.629 889.919,606.629 889.928,606.629 889.937,606.629 889.946,606.628 889.955,606.628 889.965,606.628 889.974,606.628 889.983,606.628 889.992,606.628 890.001,606.628 890.011,606.627 890.02,606.627 890.029,606.627 890.038,606.627 890.047,606.627 890.057,606.627 890.066,606.627 890.075,606.627 890.084,606.626 890.093,606.626 890.102,606.626 890.112,606.626 890.121,606.626 890.13,606.626 890.139,606.626 890.148,606.625 890.158,606.625 890.167,606.625 890.176,606.625 890.185,606.625 890.194,606.625 890.204,606.625 890.213,606.624 890.222,606.624 890.231,606.624 890.24,606.624 890.249,606.624 890.259,606.624 890.268,606.624 890.277,606.623 890.286,606.623 890.295,606.623 890.305,606.623 890.314,606.623 890.323,606.623 890.332,606.623 890.341,606.623 890.351,606.622 890.36,606.622 890.369,606.622 890.378,606.622 890.387,606.622 890.397,606.622 890.406,606.622 890.415,606.621 890.424,606.621 890.433,606.621 890.442,606.621 890.452,606.621 890.461,606.621 890.47,606.621 890.479,606.62 890.488,606.62 890.498,606.62 890.507,606.62 890.516,606.62 890.525,606.62 890.534,606.62 890.544,606.619 890.553,606.619 890.562,606.619 890.571,606.619 890.58,606.619 890.589,606.619 890.599,606.619 890.608,606.619 890.617,606.618 890.626,606.618 890.635,606.618 890.645,606.618 890.654,606.618 890.663,606.618 890.672,606.618 890.681,606.617 890.691,606.617 890.7,606.617 890.709,606.617 890.718,606.617 890.727,606.617 890.737,606.617 890.746,606.616 890.755,606.616 890.764,606.616 890.773,606.616 890.782,606.616 890.792,606.616 890.801,606.616 890.81,606.615 890.819,606.615 890.828,606.615 890.838,606.615 890.847,606.615 890.856,606.615 890.865,606.615 890.874,606.615 890.884,606.614 890.893,606.614 890.902,606.614 890.911,606.614 890.92,606.614 890.929,606.614 890.939,606.614 890.948,606.613 890.957,606.613 890.966,606.613 890.975,606.613 890.985,606.613 890.994,606.613 891.003,606.613 891.012,606.612 891.021,606.612 891.031,606.612 891.04,606.612 891.049,606.612 891.058,606.612 891.067,606.612 891.077,606.611 891.086,606.611 891.095,606.611 891.104,606.611 891.113,606.611 891.122,606.611 891.132,606.611 891.141,606.61 891.15,606.61 891.159,606.61 891.168,606.61 891.178,606.61 891.187,606.61 891.196,606.61 891.205,606.61 891.214,606.609 891.224,606.609 891.233,606.609 891.242,606.609 891.251,606.609 891.26,606.609 891.27,606.609 891.279,606.608 891.288,606.608 891.297,606.608 891.306,606.608 891.315,606.608 891.325,606.608 891.334,606.608 891.343,606.607 891.352,606.607 891.361,606.607 891.371,606.607 891.38,606.607 891.389,606.607 891.398,606.607 891.407,606.606 891.417,606.606 891.426,606.606 891.435,606.606 891.444,606.606 891.453,606.606 891.462,606.606 891.472,606.605 891.481,606.605 891.49,606.605 891.499,606.605 891.508,606.605 891.518,606.605 891.527,606.605 891.536,606.604 891.545,606.604 891.554,606.604 891.564,606.604 891.573,606.604 891.582,606.604 891.591,606.604 891.6,606.604 891.61,606.603 891.619,606.603 891.628,606.603 891.637,606.603 891.646,606.603 891.655,606.603 891.665,606.603 891.674,606.602 891.683,606.602 891.692,606.602 891.701,606.602 891.711,606.602 891.72,606.602 891.729,606.602 891.738,606.601 891.747,606.601 891.757,606.601 891.766,606.601 891.775,606.601 891.784,606.601 891.793,606.601 891.802,606.6 891.812,606.6 891.821,606.6 891.83,606.6 891.839,606.6 891.848,606.6 891.858,606.6 891.867,606.599 891.876,606.599 891.885,606.599 891.894,606.599 891.904,606.599 891.913,606.599 891.922,606.599 891.931,606.598 891.94,606.598 891.95,606.598 891.959,606.598 891.968,606.598 891.977,606.598 891.986,606.598 891.995,606.597 892.005,606.597 892.014,606.597 892.023,606.597 892.032,606.597 892.041,606.597 892.051,606.597 892.06,606.596 892.069,606.596 892.078,606.596 892.087,606.596 892.097,606.596 892.106,606.596 892.115,606.596 892.124,606.596 892.133,606.595 892.142,606.595 892.152,606.595 892.161,606.595 892.17,606.595 892.179,606.595 892.188,606.595 892.198,606.594 892.207,606.594 892.216,606.594 892.225,606.594 892.234,606.594 892.244,606.594 892.253,606.594 892.262,606.593 892.271,606.593 892.28,606.593 892.29,606.593 892.299,606.593 892.308,606.593 892.317,606.593 892.326,606.592 892.335,606.592 892.345,606.592 892.354,606.592 892.363,606.592 892.372,606.592 892.381,606.592 892.391,606.591 892.4,606.591 892.409,606.591 892.418,606.591 892.427,606.591 892.437,606.591 892.446,606.591 892.455,606.59 892.464,606.59 892.473,606.59 892.482,606.59 892.492,606.59 892.501,606.59 892.51,606.59 892.519,606.589 892.528,606.589 892.538,606.589 892.547,606.589 892.556,606.589 892.565,606.589 892.574,606.589 892.584,606.588 892.593,606.588 892.602,606.588 892.611,606.588 892.62,606.588 892.63,606.588 892.639,606.588 892.648,606.587 892.657,606.587 892.666,606.587 892.675,606.587 892.685,606.587 892.694,606.587 892.703,606.587 892.712,606.586 892.721,606.586 892.731,606.586 892.74,606.586 892.749,606.586 892.758,606.586 892.767,606.586 892.777,606.585 892.786,606.585 892.795,606.585 892.804,606.585 892.813,606.585 892.822,606.585 892.832,606.585 892.841,606.584 892.85,606.584 892.859,606.584 892.868,606.584 892.878,606.584 892.887,606.584 892.896,606.584 892.905,606.583 892.914,606.583 892.924,606.583 892.933,606.583 892.942,606.583 892.951,606.583 892.96,606.583 892.97,606.582 892.979,606.582 892.988,606.582 892.997,606.582 893.006,606.582 893.015,606.582 893.025,606.582 893.034,606.581 893.043,606.581 893.052,606.581 893.061,606.581 893.071,606.581 893.08,606.581 893.089,606.581 893.098,606.58 893.107,606.58 893.117,606.58 893.126,606.58 893.135,606.58 893.144,606.58 893.153,606.58 893.162,606.579 893.172,606.579 893.181,606.579 893.19,606.579 893.199,606.579 893.208,606.579 893.218,606.579 893.227,606.578 893.236,606.578 893.245,606.578 893.254,606.578 893.264,606.578 893.273,606.578 893.282,606.578 893.291,606.577 893.3,606.577 893.31,606.577 893.319,606.577 893.328,606.577 893.337,606.577 893.346,606.577 893.355,606.576 893.365,606.576 893.374,606.576 893.383,606.576 893.392,606.576 893.401,606.576 893.411,606.576 893.42,606.575 893.429,606.575 893.438,606.575 893.447,606.575 893.457,606.575 893.466,606.575 893.475,606.575 893.484,606.574 893.493,606.574 893.503,606.574 893.512,606.574 893.521,606.574 893.53,606.574 893.539,606.574 893.548,606.573 893.558,606.573 893.567,606.573 893.576,606.573 893.585,606.573 893.594,606.573 893.604,606.573 893.613,606.572 893.622,606.572 893.631,606.572 893.64,606.572 893.65,606.572 893.659,606.572 893.668,606.572 893.677,606.571 893.686,606.571 893.695,606.571 893.705,606.571 893.714,606.571 893.723,606.571 893.732,606.571 893.741,606.57 893.751,606.57 893.76,606.57 893.769,606.57 893.778,606.57 893.787,606.57 893.797,606.57 893.806,606.569 893.815,606.569 893.824,606.569 893.833,606.569 893.843,606.569 893.852,606.569 893.861,606.569 893.87,606.568 893.879,606.568 893.888,606.568 893.898,606.568 893.907,606.568 893.916,606.568 893.925,606.568 893.934,606.567 893.944,606.567 893.953,606.567 893.962,606.567 893.971,606.567 893.98,606.567 893.99,606.567 893.999,606.566 894.008,606.566 894.017,606.566 894.026,606.566 894.035,606.566 894.045,606.566 894.054,606.566 894.063,606.565 894.072,606.565 894.081,606.565 894.091,606.565 894.1,606.565 894.109,606.565 894.118,606.565 894.127,606.564 894.137,606.564 894.146,606.564 894.155,606.564 894.164,606.564 894.173,606.564 894.183,606.564 894.192,606.563 894.201,606.563 894.21,606.563 894.219,606.563 894.228,606.563 894.238,606.563 894.247,606.563 894.256,606.562 894.265,606.562 894.274,606.562 894.284,606.562 894.293,606.562 894.302,606.562 894.311,606.562 894.32,606.561 894.33,606.561 894.339,606.561 894.348,606.561 894.357,606.561 894.366,606.561 894.375,606.561 894.385,606.56 894.394,606.56 894.403,606.56 894.412,606.56 894.421,606.56 894.431,606.56 894.44,606.56 894.449,606.559 894.458,606.559 894.467,606.559 894.477,606.559 894.486,606.559 894.495,606.559 894.504,606.559 894.513,606.558 894.523,606.558 894.532,606.558 894.541,606.558 894.55,606.558 894.559,606.558 894.568,606.557 894.578,606.557 894.587,606.557 894.596,606.557 894.605,606.557 894.614,606.557 894.624,606.557 894.633,606.556 894.642,606.556 894.651,606.556 894.66,606.556 894.67,606.556 894.679,606.556 894.688,606.556 894.697,606.555 894.706,606.555 894.715,606.555 894.725,606.555 894.734,606.555 894.743,606.555 894.752,606.555 894.761,606.554 894.771,606.554 894.78,606.554 894.789,606.554 894.798,606.554 894.807,606.554 894.817,606.554 894.826,606.553 894.835,606.553 894.844,606.553 894.853,606.553 894.863,606.553 894.872,606.553 894.881,606.553 894.89,606.552 894.899,606.552 894.908,606.552 894.918,606.552 894.927,606.552 894.936,606.552 894.945,606.552 894.954,606.551 894.964,606.551 894.973,606.551 894.982,606.551 894.991,606.551 895,606.551 895.01,606.551 895.019,606.55 895.028,606.55 895.037,606.55 895.046,606.55 895.055,606.55 895.065,606.55 895.074,606.55 895.083,606.549 895.092,606.549 895.101,606.549 895.111,606.549 895.12,606.549 895.129,606.549 895.138,606.548 895.147,606.548 895.157,606.548 895.166,606.548 895.175,606.548 895.184,606.548 895.193,606.548 895.203,606.547 895.212,606.547 895.221,606.547 895.23,606.547 895.239,606.547 895.248,606.547 895.258,606.547 895.267,606.546 895.276,606.546 895.285,606.546 895.294,606.546 895.304,606.546 895.313,606.546 895.322,606.546 895.331,606.545 895.34,606.545 895.35,606.545 895.359,606.545 895.368,606.545 895.377,606.545 895.386,606.545 895.395,606.544 895.405,606.544 895.414,606.544 895.423,606.544 895.432,606.544 895.441,606.544 895.451,606.544 895.46,606.543 895.469,606.543 895.478,606.543 895.487,606.543 895.497,606.543 895.506,606.543 895.515,606.542 895.524,606.542 895.533,606.542 895.543,606.542 895.552,606.542 895.561,606.542 895.57,606.542 895.579,606.541 895.588,606.541 895.598,606.541 895.607,606.541 895.616,606.541 895.625,606.541 895.634,606.541 895.644,606.54 895.653,606.54 895.662,606.54 895.671,606.54 895.68,606.54 895.69,606.54 895.699,606.54 895.708,606.539 895.717,606.539 895.726,606.539 895.735,606.539 895.745,606.539 895.754,606.539 895.763,606.539 895.772,606.538 895.781,606.538 895.791,606.538 895.8,606.538 895.809,606.538 895.818,606.538 895.827,606.538 895.837,606.537 895.846,606.537 895.855,606.537 895.864,606.537 895.873,606.537 895.883,606.537 895.892,606.536 895.901,606.536 895.91,606.536 895.919,606.536 895.928,606.536 895.938,606.536 895.947,606.536 895.956,606.535 895.965,606.535 895.974,606.535 895.984,606.535 895.993,606.535 896.002,606.535 896.011,606.535 896.02,606.534 896.03,606.534 896.039,606.534 896.048,606.534 896.057,606.534 896.066,606.534 896.076,606.534 896.085,606.533 896.094,606.533 896.103,606.533 896.112,606.533 896.121,606.533 896.131,606.533 896.14,606.533 896.149,606.532 896.158,606.532 896.167,606.532 896.177,606.532 896.186,606.532 896.195,606.532 896.204,606.532 896.213,606.531 896.223,606.531 896.232,606.531 896.241,606.531 896.25,606.531 896.259,606.531 896.268,606.53 896.278,606.53 896.287,606.53 896.296,606.53 896.305,606.53 896.314,606.53 896.324,606.53 896.333,606.529 896.342,606.529 896.351,606.529 896.36,606.529 896.37,606.529 896.379,606.529 896.388,606.529 896.397,606.528 896.406,606.528 896.416,606.528 896.425,606.528 896.434,606.528 896.443,606.528 896.452,606.528 896.461,606.527 896.471,606.527 896.48,606.527 896.489,606.527 896.498,606.527 896.507,606.527 896.517,606.526 896.526,606.526 896.535,606.526 896.544,606.526 896.553,606.526 896.563,606.526 896.572,606.526 896.581,606.525 896.59,606.525 896.599,606.525 896.608,606.525 896.618,606.525 896.627,606.525 896.636,606.525 896.645,606.524 896.654,606.524 896.664,606.524 896.673,606.524 896.682,606.524 896.691,606.524 896.7,606.524 896.71,606.523 896.719,606.523 896.728,606.523 896.737,606.523 896.746,606.523 896.756,606.523 896.765,606.523 896.774,606.522 896.783,606.522 896.792,606.522 896.801,606.522 896.811,606.522 896.82,606.522 896.829,606.521 896.838,606.521 896.847,606.521 896.857,606.521 896.866,606.521 896.875,606.521 896.884,606.521 896.893,606.52 896.903,606.52 896.912,606.52 896.921,606.52 896.93,606.52 896.939,606.52 896.948,606.52 896.958,606.519 896.967,606.519 896.976,606.519 896.985,606.519 896.994,606.519 897.004,606.519 897.013,606.519 897.022,606.518 897.031,606.518 897.04,606.518 897.05,606.518 897.059,606.518 897.068,606.518 897.077,606.517 897.086,606.517 897.096,606.517 897.105,606.517 897.114,606.517 897.123,606.517 897.132,606.517 897.141,606.516 897.151,606.516 897.16,606.516 897.169,606.516 897.178,606.516 897.187,606.516 897.197,606.516 897.206,606.515 897.215,606.515 897.224,606.515 897.233,606.515 897.243,606.515 897.252,606.515 897.261,606.515 897.27,606.514 897.279,606.514 897.288,606.514 897.298,606.514 897.307,606.514 897.316,606.514 897.325,606.513 897.334,606.513 897.344,606.513 897.353,606.513 897.362,606.513 897.371,606.513 897.38,606.513 897.39,606.512 897.399,606.512 897.408,606.512 897.417,606.512 897.426,606.512 897.436,606.512 897.445,606.512 897.454,606.511 897.463,606.511 897.472,606.511 897.481,606.511 897.491,606.511 897.5,606.511 897.509,606.511 897.518,606.51 897.527,606.51 897.537,606.51 897.546,606.51 897.555,606.51 897.564,606.51 897.573,606.509 897.583,606.509 897.592,606.509 897.601,606.509 897.61,606.509 897.619,606.509 897.628,606.509 897.638,606.508 897.647,606.508 897.656,606.508 897.665,606.508 897.674,606.508 897.684,606.508 897.693,606.508 897.702,606.507 897.711,606.507 897.72,606.507 897.73,606.507 897.739,606.507 897.748,606.507 897.757,606.506 897.766,606.506 897.776,606.506 897.785,606.506 897.794,606.506 897.803,606.506 897.812,606.506 897.821,606.505 897.831,606.505 897.84,606.505 897.849,606.505 897.858,606.505 897.867,606.505 897.877,606.505 897.886,606.504 897.895,606.504 897.904,606.504 897.913,606.504 897.923,606.504 897.932,606.504 897.941,606.504 897.95,606.503 897.959,606.503 897.968,606.503 897.978,606.503 897.987,606.503 897.996,606.503 898.005,606.502 898.014,606.502 898.024,606.502 898.033,606.502 898.042,606.502 898.051,606.502 898.06,606.502 898.07,606.501 898.079,606.501 898.088,606.501 898.097,606.501 898.106,606.501 898.116,606.501 898.125,606.501 898.134,606.5 898.143,606.5 898.152,606.5 898.161,606.5 898.171,606.5 898.18,606.5 898.189,606.499 898.198,606.499 898.207,606.499 898.217,606.499 898.226,606.499 898.235,606.499 898.244,606.499 898.253,606.498 898.263,606.498 898.272,606.498 898.281,606.498 898.29,606.498 898.299,606.498 898.308,606.498 898.318,606.497 898.327,606.497 898.336,606.497 898.345,606.497 898.354,606.497 898.364,606.497 898.373,606.496 898.382,606.496 898.391,606.496 898.4,606.496 898.41,606.496 898.419,606.496 898.428,606.496 898.437,606.495 898.446,606.495 898.456,606.495 898.465,606.495 898.474,606.495 898.483,606.495 898.492,606.495 898.501,606.494 898.511,606.494 898.52,606.494 898.529,606.494 898.538,606.494 898.547,606.494 898.557,606.493 898.566,606.493 898.575,606.493 898.584,606.493 898.593,606.493 898.603,606.493 898.612,606.493 898.621,606.492 898.63,606.492 898.639,606.492 898.649,606.492 898.658,606.492 898.667,606.492 898.676,606.492 898.685,606.491 898.694,606.491 898.704,606.491 898.713,606.491 898.722,606.491 898.731,606.491 898.74,606.49 898.75,606.49 898.759,606.49 898.768,606.49 898.777,606.49 898.786,606.49 898.796,606.49 898.805,606.489 898.814,606.489 898.823,606.489 898.832,606.489 898.841,606.489 898.851,606.489 898.86,606.489 898.869,606.488 898.878,606.488 898.887,606.488 898.897,606.488 898.906,606.488 898.915,606.488 898.924,606.487 898.933,606.487 898.943,606.487 898.952,606.487 898.961,606.487 898.97,606.487 898.979,606.487 898.989,606.486 898.998,606.486 899.007,606.486 899.016,606.486 899.025,606.486 899.034,606.486 899.044,606.486 899.053,606.485 899.062,606.485 899.071,606.485 899.08,606.485 899.09,606.485 899.099,606.485 899.108,606.484 899.117,606.484 899.126,606.484 899.136,606.484 899.145,606.484 899.154,606.484 899.163,606.484 899.172,606.483 899.181,606.483 899.191,606.483 899.2,606.483 899.209,606.483 899.218,606.483 899.227,606.483 899.237,606.482 899.246,606.482 899.255,606.482 899.264,606.482 899.273,606.482 899.283,606.482 899.292,606.481 899.301,606.481 899.31,606.481 899.319,606.481 899.329,606.481 899.338,606.481 899.347,606.481 899.356,606.48 899.365,606.48 899.374,606.48 899.384,606.48 899.393,606.48 899.402,606.48 899.411,606.48 899.42,606.479 899.43,606.479 899.439,606.479 899.448,606.479 899.457,606.479 899.466,606.479 899.476,606.478 899.485,606.478 899.494,606.478 899.503,606.478 899.512,606.478 899.521,606.478 899.531,606.478 899.54,606.477 899.549,606.477 899.558,606.477 899.567,606.477 899.577,606.477 899.586,606.477 899.595,606.477 899.604,606.476 899.613,606.476 899.623,606.476 899.632,606.476 899.641,606.476 899.65,606.476 899.659,606.475 899.669,606.475 899.678,606.475 899.687,606.475 899.696,606.475 899.705,606.475 899.714,606.475 899.724,606.474 899.733,606.474 899.742,606.474 899.751,606.474 899.76,606.474 899.77,606.474 899.779,606.473 899.788,606.473 899.797,606.473 899.806,606.473 899.816,606.473 899.825,606.473 899.834,606.473 899.843,606.472 899.852,606.472 899.861,606.472 899.871,606.472 899.88,606.472 899.889,606.472 899.898,606.472 899.907,606.471 899.917,606.471 899.926,606.471 899.935,606.471 899.944,606.471 899.953,606.471 899.963,606.47 899.972,606.47 899.981,606.47 899.99,606.47 899.999,606.47 900.009,606.47 900.018,606.47 900.027,606.469 900.036,606.469 900.045,606.469 900.054,606.469 900.064,606.469 900.073,606.469 900.082,606.468 900.091,606.468 900.1,606.468 900.11,606.468 900.119,606.468 900.128,606.468 900.137,606.468 900.146,606.467 900.156,606.467 900.165,606.467 900.174,606.467 900.183,606.467 900.192,606.467 900.201,606.467 900.211,606.466 900.22,606.466 900.229,606.466 900.238,606.466 900.247,606.466 900.257,606.466 900.266,606.465 900.275,606.465 900.284,606.465 900.293,606.465 900.303,606.465 900.312,606.465 900.321,606.465 900.33,606.464 900.339,606.464 900.349,606.464 900.358,606.464 900.367,606.464 900.376,606.464 900.385,606.464 900.394,606.463 900.404,606.463 900.413,606.463 900.422,606.463 900.431,606.463 900.44,606.463 900.45,606.462 900.459,606.462 900.468,606.462 900.477,606.462 900.486,606.462 900.496,606.462 900.505,606.462 900.514,606.461 900.523,606.461 900.532,606.461 900.541,606.461 900.551,606.461 900.56,606.461 900.569,606.46 900.578,606.46 900.587,606.46 900.597,606.46 900.606,606.46 900.615,606.46 900.624,606.46 900.633,606.459 900.643,606.459 900.652,606.459 900.661,606.459 900.67,606.459 900.679,606.459 900.689,606.458 900.698,606.458 900.707,606.458 900.716,606.458 900.725,606.458 900.734,606.458 900.744,606.458 900.753,606.457 900.762,606.457 900.771,606.457 900.78,606.457 900.79,606.457 900.799,606.457 900.808,606.457 900.817,606.456 900.826,606.456 900.836,606.456 900.845,606.456 900.854,606.456 900.863,606.456 900.872,606.455 900.882,606.455 900.891,606.455 900.9,606.455 900.909,606.455 900.918,606.455 900.927,606.455 900.937,606.454 900.946,606.454 900.955,606.454 900.964,606.454 900.973,606.454 900.983,606.454 900.992,606.453 901.001,606.453 901.01,606.453 901.019,606.453 901.029,606.453 901.038,606.453 901.047,606.453 901.056,606.452 901.065,606.452 901.074,606.452 901.084,606.452 901.093,606.452 901.102,606.452 901.111,606.452 901.12,606.451 901.13,606.451 901.139,606.451 901.148,606.451 901.157,606.451 901.166,606.451 901.176,606.45 901.185,606.45 901.194,606.45 901.203,606.45 901.212,606.45 901.222,606.45 901.231,606.45 901.24,606.449 901.249,606.449 901.258,606.449 901.267,606.449 901.277,606.449 901.286,606.449 901.295,606.448 901.304,606.448 901.313,606.448 901.323,606.448 901.332,606.448 901.341,606.448 901.35,606.448 901.359,606.447 901.369,606.447 901.378,606.447 901.387,606.447 901.396,606.447 901.405,606.447 901.414,606.446 901.424,606.446 901.433,606.446 901.442,606.446 901.451,606.446 901.46,606.446 901.47,606.446 901.479,606.445 901.488,606.445 901.497,606.445 901.506,606.445 901.516,606.445 901.525,606.445 901.534,606.445 901.543,606.444 901.552,606.444 901.562,606.444 901.571,606.444 901.58,606.444 901.589,606.444 901.598,606.443 901.607,606.443 901.617,606.443 901.626,606.443 901.635,606.443 901.644,606.443 901.653,606.443 901.663,606.442 901.672,606.442 901.681,606.442 901.69,606.442 901.699,606.442 901.709,606.442 901.718,606.441 901.727,606.441 901.736,606.441 901.745,606.441 901.754,606.441 901.764,606.441 901.773,606.441 901.782,606.44 901.791,606.44 901.8,606.44 901.81,606.44 901.819,606.44 901.828,606.44 901.837,606.439 901.846,606.439 901.856,606.439 901.865,606.439 901.874,606.439 901.883,606.439 901.892,606.439 901.902,606.438 901.911,606.438 901.92,606.438 901.929,606.438 901.938,606.438 901.947,606.438 901.957,606.437 901.966,606.437 901.975,606.437 901.984,606.437 901.993,606.437 902.003,606.437 902.012,606.437 902.021,606.436 902.03,606.436 902.039,606.436 902.049,606.436 902.058,606.436 902.067,606.436 902.076,606.435 902.085,606.435 902.094,606.435 902.104,606.435 902.113,606.435 902.122,606.435 902.131,606.435 902.14,606.434 902.15,606.434 902.159,606.434 902.168,606.434 902.177,606.434 902.186,606.434 902.196,606.434 902.205,606.433 902.214,606.433 902.223,606.433 902.232,606.433 902.242,606.433 902.251,606.433 902.26,606.432 902.269,606.432 902.278,606.432 902.287,606.432 902.297,606.432 902.306,606.432 902.315,606.432 902.324,606.431 902.333,606.431 902.343,606.431 902.352,606.431 902.361,606.431 902.37,606.431 902.379,606.43 902.389,606.43 902.398,606.43 902.407,606.43 902.416,606.43 902.425,606.43 902.434,606.43 902.444,606.429 902.453,606.429 902.462,606.429 902.471,606.429 902.48,606.429 902.49,606.429 902.499,606.428 902.508,606.428 902.517,606.428 902.526,606.428 902.536,606.428 902.545,606.428 902.554,606.428 902.563,606.427 902.572,606.427 902.582,606.427 902.591,606.427 902.6,606.427 902.609,606.427 902.618,606.426 902.627,606.426 902.637,606.426 902.646,606.426 902.655,606.426 902.664,606.426 902.673,606.426 902.683,606.425 902.692,606.425 902.701,606.425 902.71,606.425 902.719,606.425 902.729,606.425 902.738,606.424 902.747,606.424 902.756,606.424 902.765,606.424 902.774,606.424 902.784,606.424 902.793,606.424 902.802,606.423 902.811,606.423 902.82,606.423 902.83,606.423 902.839,606.423 902.848,606.423 902.857,606.422 902.866,606.422 902.876,606.422 902.885,606.422 902.894,606.422 902.903,606.422 902.912,606.422 902.922,606.421 902.931,606.421 902.94,606.421 902.949,606.421 902.958,606.421 902.967,606.421 902.977,606.42 902.986,606.42 902.995,606.42 903.004,606.42 903.013,606.42 903.023,606.42 903.032,606.42 903.041,606.419 903.05,606.419 903.059,606.419 903.069,606.419 903.078,606.419 903.087,606.419 903.096,606.418 903.105,606.418 903.114,606.418 903.124,606.418 903.133,606.418 903.142,606.418 903.151,606.418 903.16,606.417 903.17,606.417 903.179,606.417 903.188,606.417 903.197,606.417 903.206,606.417 903.216,606.416 903.225,606.416 903.234,606.416 903.243,606.416 903.252,606.416 903.262,606.416 903.271,606.416 903.28,606.415 903.289,606.415 903.298,606.415 903.307,606.415 903.317,606.415 903.326,606.415 903.335,606.415 903.344,606.414 903.353,606.414 903.363,606.414 903.372,606.414 903.381,606.414 903.39,606.414 903.399,606.413 903.409,606.413 903.418,606.413 903.427,606.413 903.436,606.413 903.445,606.413 903.455,606.413 903.464,606.412 903.473,606.412 903.482,606.412 903.491,606.412 903.5,606.412 903.51,606.412 903.519,606.411 903.528,606.411 903.537,606.411 903.546,606.411 903.556,606.411 903.565,606.411 903.574,606.411 903.583,606.41 903.592,606.41 903.602,606.41 903.611,606.41 903.62,606.41 903.629,606.41 903.638,606.409 903.647,606.409 903.657,606.409 903.666,606.409 903.675,606.409 903.684,606.409 903.693,606.409 903.703,606.408 903.712,606.408 903.721,606.408 903.73,606.408 903.739,606.408 903.749,606.408 903.758,606.407 903.767,606.407 903.776,606.407 903.785,606.407 903.795,606.407 903.804,606.407 903.813,606.407 903.822,606.406 903.831,606.406 903.84,606.406 903.85,606.406 903.859,606.406 903.868,606.406 903.877,606.405 903.886,606.405 903.896,606.405 903.905,606.405 903.914,606.405 903.923,606.405 903.932,606.405 903.942,606.404 903.951,606.404 903.96,606.404 903.969,606.404 903.978,606.404 903.987,606.404 903.997,606.403 904.006,606.403 904.015,606.403 904.024,606.403 904.033,606.403 904.043,606.403 904.052,606.402 904.061,606.402 904.07,606.402 904.079,606.402 904.089,606.402 904.098,606.402 904.107,606.402 904.116,606.401 904.125,606.401 904.135,606.401 904.144,606.401 904.153,606.401 904.162,606.401 904.171,606.4 904.18,606.4 904.19,606.4 904.199,606.4 904.208,606.4 904.217,606.4 904.226,606.4 904.236,606.399 904.245,606.399 904.254,606.399 904.263,606.399 904.272,606.399 904.282,606.399 904.291,606.398 904.3,606.398 904.309,606.398 904.318,606.398 904.327,606.398 904.337,606.398 904.346,606.398 904.355,606.397 904.364,606.397 904.373,606.397 904.383,606.397 904.392,606.397 904.401,606.397 904.41,606.396 904.419,606.396 904.429,606.396 904.438,606.396 904.447,606.396 904.456,606.396 904.465,606.396 904.475,606.395 904.484,606.395 904.493,606.395 904.502,606.395 904.511,606.395 904.52,606.395 904.53,606.394 904.539,606.394 904.548,606.394 904.557,606.394 904.566,606.394 904.576,606.394 904.585,606.394 904.594,606.393 904.603,606.393 904.612,606.393 904.622,606.393 904.631,606.393 904.64,606.393 904.649,606.392 904.658,606.392 904.667,606.392 904.677,606.392 904.686,606.392 904.695,606.392 904.704,606.392 904.713,606.391 904.723,606.391 904.732,606.391 904.741,606.391 904.75,606.391 904.759,606.391 904.769,606.39 904.778,606.39 904.787,606.39 904.796,606.39 904.805,606.39 904.815,606.39 904.824,606.39 904.833,606.389 904.842,606.389 904.851,606.389 904.86,606.389 904.87,606.389 904.879,606.389 904.888,606.388 904.897,606.388 904.906,606.388 904.916,606.388 904.925,606.388 904.934,606.388 904.943,606.388 904.952,606.387 904.962,606.387 904.971,606.387 904.98,606.387 904.989,606.387 904.998,606.387 905.007,606.386 905.017,606.386 905.026,606.386 905.035,606.386 905.044,606.386 905.053,606.386 905.063,606.386 905.072,606.385 905.081,606.385 905.09,606.385 905.099,606.385 905.109,606.385 905.118,606.385 905.127,606.384 905.136,606.384 905.145,606.384 905.155,606.384 905.164,606.384 905.173,606.384 905.182,606.384 905.191,606.383 905.2,606.383 905.21,606.383 905.219,606.383 905.228,606.383 905.237,606.383 905.246,606.382 905.256,606.382 905.265,606.382 905.274,606.382 905.283,606.382 905.292,606.382 905.302,606.381 905.311,606.381 905.32,606.381 905.329,606.381 905.338,606.381 905.347,606.381 905.357,606.381 905.366,606.38 905.375,606.38 905.384,606.38 905.393,606.38 905.403,606.38 905.412,606.38 905.421,606.379 905.43,606.379 905.439,606.379 905.449,606.379 905.458,606.379 905.467,606.379 905.476,606.379 905.485,606.378 905.495,606.378 905.504,606.378 905.513,606.378 905.522,606.378 905.531,606.378 905.54,606.377 905.55,606.377 905.559,606.377 905.568,606.377 905.577,606.377 905.586,606.377 905.596,606.377 905.605,606.376 905.614,606.376 905.623,606.376 905.632,606.376 905.642,606.376 905.651,606.376 905.66,606.375 905.669,606.375 905.678,606.375 905.687,606.375 905.697,606.375 905.706,606.375 905.715,606.375 905.724,606.374 905.733,606.374 905.743,606.374 905.752,606.374 905.761,606.374 905.77,606.374 905.779,606.373 905.789,606.373 905.798,606.373 905.807,606.373 905.816,606.373 905.825,606.373 905.835,606.373 905.844,606.372 905.853,606.372 905.862,606.372 905.871,606.372 905.88,606.372 905.89,606.372 905.899,606.371 905.908,606.371 905.917,606.371 905.926,606.371 905.936,606.371 905.945,606.371 905.954,606.371 905.963,606.37 905.972,606.37 905.982,606.37 905.991,606.37 906,606.37 906.009,606.37 906.018,606.369 906.028,606.369 906.037,606.369 906.046,606.369 906.055,606.369 906.064,606.369 906.073,606.368 906.083,606.368 906.092,606.368 906.101,606.368 906.11,606.368 906.119,606.368 906.129,606.368 906.138,606.367 906.147,606.367 906.156,606.367 906.165,606.367 906.175,606.367 906.184,606.367 906.193,606.366 906.202,606.366 906.211,606.366 906.22,606.366 906.23,606.366 906.239,606.366 906.248,606.366 906.257,606.365 906.266,606.365 906.276,606.365 906.285,606.365 906.294,606.365 906.303,606.365 906.312,606.364 906.322,606.364 906.331,606.364 906.34,606.364 906.349,606.364 906.358,606.364 906.368,606.364 906.377,606.363 906.386,606.363 906.395,606.363 906.404,606.363 906.413,606.363 906.423,606.363 906.432,606.362 906.441,606.362 906.45,606.362 906.459,606.362 906.469,606.362 906.478,606.362 906.487,606.362 906.496,606.361 906.505,606.361 906.515,606.361 906.524,606.361 906.533,606.361 906.542,606.361 906.551,606.36 906.56,606.36 906.57,606.36 906.579,606.36 906.588,606.36 906.597,606.36 906.606,606.359 906.616,606.359 906.625,606.359 906.634,606.359 906.643,606.359 906.652,606.359 906.662,606.359 906.671,606.358 906.68,606.358 906.689,606.358 906.698,606.358 906.708,606.358 906.717,606.358 906.726,606.357 906.735,606.357 906.744,606.357 906.753,606.357 906.763,606.357 906.772,606.357 906.781,606.357 906.79,606.356 906.799,606.356 906.809,606.356 906.818,606.356 906.827,606.356 906.836,606.356 906.845,606.355 906.855,606.355 906.864,606.355 906.873,606.355 906.882,606.355 906.891,606.355 906.9,606.355 906.91,606.354 906.919,606.354 906.928,606.354 906.937,606.354 906.946,606.354 906.956,606.354 906.965,606.353 906.974,606.353 906.983,606.353 906.992,606.353 907.002,606.353 907.011,606.353 907.02,606.353 907.029,606.352 907.038,606.352 907.048,606.352 907.057,606.352 907.066,606.352 907.075,606.352 907.084,606.351 907.093,606.351 907.103,606.351 907.112,606.351 907.121,606.351 907.13,606.351 907.139,606.35 907.149,606.35 907.158,606.35 907.167,606.35 907.176,606.35 907.185,606.35 907.195,606.35 907.204,606.349 907.213,606.349 907.222,606.349 907.231,606.349 907.24,606.349 907.25,606.349 907.259,606.348 907.268,606.348 907.277,606.348 907.286,606.348 907.296,606.348 907.305,606.348 907.314,606.348 907.323,606.347 907.332,606.347 907.342,606.347 907.351,606.347 907.36,606.347 907.369,606.347 907.378,606.346 907.388,606.346 907.397,606.346 907.406,606.346 907.415,606.346 907.424,606.346 907.433,606.346 907.443,606.345 907.452,606.345 907.461,606.345 907.47,606.345 907.479,606.345 907.489,606.345 907.498,606.344 907.507,606.344 907.516,606.344 907.525,606.344 907.535,606.344 907.544,606.344 907.553,606.343 907.562,606.343 907.571,606.343 907.58,606.343 907.59,606.343 907.599,606.343 907.608,606.343 907.617,606.342 907.626,606.342 907.636,606.342 907.645,606.342 907.654,606.342 907.663,606.342 907.672,606.341 907.682,606.341 907.691,606.341 907.7,606.341 907.709,606.341 907.718,606.341 907.728,606.341 907.737,606.34 907.746,606.34 907.755,606.34 907.764,606.34 907.773,606.34 907.783,606.34 907.792,606.339 907.801,606.339 907.81,606.339 907.819,606.339 907.829,606.339 907.838,606.339 907.847,606.339 907.856,606.338 907.865,606.338 907.875,606.338 907.884,606.338 907.893,606.338 907.902,606.338 907.911,606.337 907.92,606.337 907.93,606.337 907.939,606.337 907.948,606.337 907.957,606.337 907.966,606.336 907.976,606.336 907.985,606.336 907.994,606.336 908.003,606.336 908.012,606.336 908.022,606.336 908.031,606.335 908.04,606.335 908.049,606.335 908.058,606.335 908.068,606.335 908.077,606.335 908.086,606.334 908.095,606.334 908.104,606.334 908.113,606.334 908.123,606.334 908.132,606.334 908.141,606.334 908.15,606.333 908.159,606.333 908.169,606.333 908.178,606.333 908.187,606.333 908.196,606.333 908.205,606.332 908.215,606.332 908.224,606.332 908.233,606.332 908.242,606.332 908.251,606.332 908.261,606.332 908.27,606.331 908.279,606.331 908.288,606.331 908.297,606.331 908.306,606.331 908.316,606.331 908.325,606.33 908.334,606.33 908.343,606.33 908.352,606.33 908.362,606.33 908.371,606.33 908.38,606.329 908.389,606.329 908.398,606.329 908.408,606.329 908.417,606.329 908.426,606.329 908.435,606.329 908.444,606.328 908.453,606.328 908.463,606.328 908.472,606.328 908.481,606.328 908.49,606.328 908.499,606.327 908.509,606.327 908.518,606.327 908.527,606.327 908.536,606.327 908.545,606.327 908.555,606.327 908.564,606.326 908.573,606.326 908.582,606.326 908.591,606.326 908.601,606.326 908.61,606.326 908.619,606.325 908.628,606.325 908.637,606.325 908.646,606.325 908.656,606.325 908.665,606.325 908.674,606.324 908.683,606.324 908.692,606.324 908.702,606.324 908.711,606.324 908.72,606.324 908.729,606.324 908.738,606.323 908.748,606.323 908.757,606.323 908.766,606.323 908.775,606.323 908.784,606.323 908.793,606.322 908.803,606.322 908.812,606.322 908.821,606.322 908.83,606.322 908.839,606.322 908.849,606.322 908.858,606.321 908.867,606.321 908.876,606.321 908.885,606.321 908.895,606.321 908.904,606.321 908.913,606.32 908.922,606.32 908.931,606.32 908.941,606.32 908.95,606.32 908.959,606.32 908.968,606.32 908.977,606.319 908.986,606.319 908.996,606.319 909.005,606.319 909.014,606.319 909.023,606.319 909.032,606.318 909.042,606.318 909.051,606.318 909.06,606.318 909.069,606.318 909.078,606.318 909.088,606.317 909.097,606.317 909.106,606.317 909.115,606.317 909.124,606.317 909.133,606.317 909.143,606.317 909.152,606.316 909.161,606.316 909.17,606.316 909.179,606.316 909.189,606.316 909.198,606.316 909.207,606.315 909.216,606.315 909.225,606.315 909.235,606.315 909.244,606.315 909.253,606.315 909.262,606.315 909.271,606.314 909.281,606.314 909.29,606.314 909.299,606.314 909.308,606.314 909.317,606.314 909.326,606.313 909.336,606.313 909.345,606.313 909.354,606.313 909.363,606.313 909.372,606.313 909.382,606.312 909.391,606.312 909.4,606.312 909.409,606.312 909.418,606.312 909.428,606.312 909.437,606.312 909.446,606.311 909.455,606.311 909.464,606.311 909.473,606.311 909.483,606.311 909.492,606.311 909.501,606.31 909.51,606.31 909.519,606.31 909.529,606.31 909.538,606.31 909.547,606.31 909.556,606.31 909.565,606.309 909.575,606.309 909.584,606.309 909.593,606.309 909.602,606.309 909.611,606.309 909.621,606.308 909.63,606.308 909.639,606.308 909.648,606.308 909.657,606.308 909.666,606.308 909.676,606.307 909.685,606.307 909.694,606.307 909.703,606.307 909.712,606.307 909.722,606.307 909.731,606.307 909.74,606.306 909.749,606.306 909.758,606.306 909.768,606.306 909.777,606.306 909.786,606.306 909.795,606.305 909.804,606.305 909.813,606.305 909.823,606.305 909.832,606.305 909.841,606.305 909.85,606.305 909.859,606.304 909.869,606.304 909.878,606.304 909.887,606.304 909.896,606.304 909.905,606.304 909.915,606.303 909.924,606.303 909.933,606.303 909.942,606.303 909.951,606.303 909.961,606.303 909.97,606.302 909.979,606.302 909.988,606.302 909.997,606.302 910.006,606.302 910.016,606.302 910.025,606.302 910.034,606.301 910.043,606.301 910.052,606.301 910.062,606.301 910.071,606.301 910.08,606.301 910.089,606.3 910.098,606.3 910.108,606.3 910.117,606.3 910.126,606.3 910.135,606.3 910.144,606.3 910.153,606.299 910.163,606.299 910.172,606.299 910.181,606.299 910.19,606.299 910.199,606.299 910.209,606.298 910.218,606.298 910.227,606.298 910.236,606.298 910.245,606.298 910.255,606.298 910.264,606.298 910.273,606.297 910.282,606.297 910.291,606.297 910.301,606.297 910.31,606.297 910.319,606.297 910.328,606.296 910.337,606.296 910.346,606.296 910.356,606.296 910.365,606.296 910.374,606.296 910.383,606.295 910.392,606.295 910.402,606.295 910.411,606.295 910.42,606.295 910.429,606.295 910.438,606.295 910.448,606.294 910.457,606.294 910.466,606.294 910.475,606.294 910.484,606.294 910.493,606.294 910.503,606.293 910.512,606.293 910.521,606.293 910.53,606.293 910.539,606.293 910.549,606.293 910.558,606.293 910.567,606.292 910.576,606.292 910.585,606.292 910.595,606.292 910.604,606.292 910.613,606.292 910.622,606.291 910.631,606.291 910.641,606.291 910.65,606.291 910.659,606.291 910.668,606.291 910.677,606.29 910.686,606.29 910.696,606.29 910.705,606.29 910.714,606.29 910.723,606.29 910.732,606.29 910.742,606.289 910.751,606.289 910.76,606.289 910.769,606.289 910.778,606.289 910.788,606.289 910.797,606.288 910.806,606.288 910.815,606.288 910.824,606.288 910.834,606.288 910.843,606.288 910.852,606.288 910.861,606.287 910.87,606.287 910.879,606.287 910.889,606.287 910.898,606.287 910.907,606.287 910.916,606.286 910.925,606.286 910.935,606.286 910.944,606.286 910.953,606.286 910.962,606.286 910.971,606.285 910.981,606.285 910.99,606.285 910.999,606.285 911.008,606.285 911.017,606.285 911.026,606.285 911.036,606.284 911.045,606.284 911.054,606.284 911.063,606.284 911.072,606.284 911.082,606.284 911.091,606.283 911.1,606.283 911.109,606.283 911.118,606.283 911.128,606.283 911.137,606.283 911.146,606.283 911.155,606.282 911.164,606.282 911.174,606.282 911.183,606.282 911.192,606.282 911.201,606.282 911.21,606.281 911.219,606.281 911.229,606.281 911.238,606.281 911.247,606.281 911.256,606.281 911.265,606.28 911.275,606.28 911.284,606.28 911.293,606.28 911.302,606.28 911.311,606.28 911.321,606.28 911.33,606.279 911.339,606.279 911.348,606.279 911.357,606.279 911.366,606.279 911.376,606.279 911.385,606.278 911.394,606.278 911.403,606.278 911.412,606.278 911.422,606.278 911.431,606.278 911.44,606.278 911.449,606.277 911.458,606.277 911.468,606.277 911.477,606.277 911.486,606.277 911.495,606.277 911.504,606.276 911.514,606.276 911.523,606.276 911.532,606.276 911.541,606.276 911.55,606.276 911.559,606.275 911.569,606.275 911.578,606.275 911.587,606.275 911.596,606.275 911.605,606.275 911.615,606.275 911.624,606.274 911.633,606.274 911.642,606.274 911.651,606.274 911.661,606.274 911.67,606.274 911.679,606.273 911.688,606.273 911.697,606.273 911.706,606.273 911.716,606.273 911.725,606.273 911.734,606.273 911.743,606.272 911.752,606.272 911.762,606.272 911.771,606.272 911.78,606.272 911.789,606.272 911.798,606.271 911.808,606.271 911.817,606.271 911.826,606.271 911.835,606.271 911.844,606.271 911.854,606.27 911.863,606.27 911.872,606.27 911.881,606.27 911.89,606.27 911.899,606.27 911.909,606.27 911.918,606.269 911.927,606.269 911.936,606.269 911.945,606.269 911.955,606.269 911.964,606.269 911.973,606.268 911.982,606.268 911.991,606.268 912.001,606.268 912.01,606.268 912.019,606.268 912.028,606.268 912.037,606.267 912.046,606.267 912.056,606.267 912.065,606.267 912.074,606.267 912.083,606.267 912.092,606.266 912.102,606.266 912.111,606.266 912.12,606.266 912.129,606.266 912.138,606.266 912.148,606.265 912.157,606.265 912.166,606.265 912.175,606.265 912.184,606.265 912.194,606.265 912.203,606.265 912.212,606.264 912.221,606.264 912.23,606.264 912.239,606.264 912.249,606.264 912.258,606.264 912.267,606.263 912.276,606.263 912.285,606.263 912.295,606.263 912.304,606.263 912.313,606.263 912.322,606.263 912.331,606.262 912.341,606.262 912.35,606.262 912.359,606.262 912.368,606.262 912.377,606.262 912.386,606.261 912.396,606.261 912.405,606.261 912.414,606.261 912.423,606.261 912.432,606.261 912.442,606.26 912.451,606.26 912.46,606.26 912.469,606.26 912.478,606.26 912.488,606.26 912.497,606.26 912.506,606.259 912.515,606.259 912.524,606.259 912.534,606.259 912.543,606.259 912.552,606.259 912.561,606.258 912.57,606.258 912.579,606.258 912.589,606.258 912.598,606.258 912.607,606.258 912.616,606.258 912.625,606.257 912.635,606.257 912.644,606.257 912.653,606.257 912.662,606.257 912.671,606.257 912.681,606.256 912.69,606.256 912.699,606.256 912.708,606.256 912.717,606.256 912.726,606.256 912.736,606.255 912.745,606.255 912.754,606.255 912.763,606.255 912.772,606.255 912.782,606.255 912.791,606.255 912.8,606.254 912.809,606.254 912.818,606.254 912.828,606.254 912.837,606.254 912.846,606.254 912.855,606.253 912.864,606.253 912.874,606.253 912.883,606.253 912.892,606.253 912.901,606.253 912.91,606.253 912.919,606.252 912.929,606.252 912.938,606.252 912.947,606.252 912.956,606.252 912.965,606.252 912.975,606.251 912.984,606.251 912.993,606.251 913.002,606.251 913.011,606.251 913.021,606.251 913.03,606.25 913.039,606.25 913.048,606.25 913.057,606.25 913.066,606.25 913.076,606.25 913.085,606.25 913.094,606.249 913.103,606.249 913.112,606.249 913.122,606.249 913.131,606.249 913.14,606.249 913.149,606.248 913.158,606.248 913.168,606.248 913.177,606.248 913.186,606.248 913.195,606.248 913.204,606.248 913.214,606.247 913.223,606.247 913.232,606.247 913.241,606.247 913.25,606.247 913.259,606.247 913.269,606.246 913.278,606.246 913.287,606.246 913.296,606.246 913.305,606.246 913.315,606.246 913.324,606.245 913.333,606.245 913.342,606.245 913.351,606.245 913.361,606.245 913.37,606.245 913.379,606.245 913.388,606.244 913.397,606.244 913.407,606.244 913.416,606.244 913.425,606.244 913.434,606.244 913.443,606.243 913.452,606.243 913.462,606.243 913.471,606.243 913.48,606.243 913.489,606.243 913.498,606.243 913.508,606.242 913.517,606.242 913.526,606.242 913.535,606.242 913.544,606.242 913.554,606.242 913.563,606.241 913.572,606.241 913.581,606.241 913.59,606.241 913.599,606.241 913.609,606.241 913.618,606.24 913.627,606.24 913.636,606.24 913.645,606.24 913.655,606.24 913.664,606.24 913.673,606.24 913.682,606.239 913.691,606.239 913.701,606.239 913.71,606.239 913.719,606.239 913.728,606.239 913.737,606.238 913.747,606.238 913.756,606.238 913.765,606.238 913.774,606.238 913.783,606.238 913.792,606.238 913.802,606.237 913.811,606.237 913.82,606.237 913.829,606.237 913.838,606.237 913.848,606.237 913.857,606.236 913.866,606.236 913.875,606.236 913.884,606.236 913.894,606.236 913.903,606.236 913.912,606.235 913.921,606.235 913.93,606.235 913.939,606.235 913.949,606.235 913.958,606.235 913.967,606.235 913.976,606.234 913.985,606.234 913.995,606.234 914.004,606.234 914.013,606.234 914.022,606.234 914.031,606.233 914.041,606.233 914.05,606.233 914.059,606.233 914.068,606.233 914.077,606.233 914.087,606.233 914.096,606.232 914.105,606.232 914.114,606.232 914.123,606.232 914.132,606.232 914.142,606.232 914.151,606.231 914.16,606.231 914.169,606.231 914.178,606.231 914.188,606.231 914.197,606.231 914.206,606.23 914.215,606.23 914.224,606.23 914.234,606.23 914.243,606.23 914.252,606.23 914.261,606.23 914.27,606.229 914.279,606.229 914.289,606.229 914.298,606.229 914.307,606.229 914.316,606.229 914.325,606.228 914.335,606.228 914.344,606.228 914.353,606.228 914.362,606.228 914.371,606.228 914.381,606.228 914.39,606.227 914.399,606.227 914.408,606.227 914.417,606.227 914.427,606.227 914.436,606.227 914.445,606.226 914.454,606.226 914.463,606.226 914.472,606.226 914.482,606.226 914.491,606.226 914.5,606.225 914.509,606.225 914.518,606.225 914.528,606.225 914.537,606.225 914.546,606.225 914.555,606.225 914.564,606.224 914.574,606.224 914.583,606.224 914.592,606.224 914.601,606.224 914.61,606.224 914.619,606.223 914.629,606.223 914.638,606.223 914.647,606.223 914.656,606.223 914.665,606.223 914.675,606.223 914.684,606.222 914.693,606.222 914.702,606.222 914.711,606.222 914.721,606.222 914.73,606.222 914.739,606.221 914.748,606.221 914.757,606.221 914.767,606.221 914.776,606.221 914.785,606.221 914.794,606.22 914.803,606.22 914.812,606.22 914.822,606.22 914.831,606.22 914.84,606.22 914.849,606.22 914.858,606.219 914.868,606.219 914.877,606.219 914.886,606.219 914.895,606.219 914.904,606.219 914.914,606.218 914.923,606.218 914.932,606.218 914.941,606.218 914.95,606.218 914.959,606.218 914.969,606.218 914.978,606.217 914.987,606.217 914.996,606.217 915.005,606.217 915.015,606.217 915.024,606.217 915.033,606.216 915.042,606.216 915.051,606.216 915.061,606.216 915.07,606.216 915.079,606.216 915.088,606.215 915.097,606.215 915.107,606.215 915.116,606.215 915.125,606.215 915.134,606.215 915.143,606.215 915.152,606.214 915.162,606.214 915.171,606.214 915.18,606.214 915.189,606.214 915.198,606.214 915.208,606.213 915.217,606.213 915.226,606.213 915.235,606.213 915.244,606.213 915.254,606.213 915.263,606.213 915.272,606.212 915.281,606.212 915.29,606.212 915.299,606.212 915.309,606.212 915.318,606.212 915.327,606.211 915.336,606.211 915.345,606.211 915.355,606.211 915.364,606.211 915.373,606.211 915.382,606.21 915.391,606.21 915.401,606.21 915.41,606.21 915.419,606.21 915.428,606.21 915.437,606.21 915.447,606.209 915.456,606.209 915.465,606.209 915.474,606.209 915.483,606.209 915.492,606.209 915.502,606.208 915.511,606.208 915.52,606.208 915.529,606.208 915.538,606.208 915.548,606.208 915.557,606.208 915.566,606.207 915.575,606.207 915.584,606.207 915.594,606.207 915.603,606.207 915.612,606.207 915.621,606.206 915.63,606.206 915.64,606.206 915.649,606.206 915.658,606.206 915.667,606.206 915.676,606.205 915.685,606.205 915.695,606.205 915.704,606.205 915.713,606.205 915.722,606.205 915.731,606.205 915.741,606.204 915.75,606.204 915.759,606.204 915.768,606.204 915.777,606.204 915.787,606.204 915.796,606.203 915.805,606.203 915.814,606.203 915.823,606.203 915.832,606.203 915.842,606.203 915.851,606.203 915.86,606.202 915.869,606.202 915.878,606.202 915.888,606.202 915.897,606.202 915.906,606.202 915.915,606.201 915.924,606.201 915.934,606.201 915.943,606.201 915.952,606.201 915.961,606.201 915.97,606.2 915.98,606.2 915.989,606.2 915.998,606.2 916.007,606.2 916.016,606.2 916.025,606.2 916.035,606.199 916.044,606.199 916.053,606.199 916.062,606.199 916.071,606.199 916.081,606.199 916.09,606.198 916.099,606.198 916.108,606.198 916.117,606.198 916.127,606.198 916.136,606.198 916.145,606.198 916.154,606.197 916.163,606.197 916.172,606.197 916.182,606.197 916.191,606.197 916.2,606.197 916.209,606.196 916.218,606.196 916.228,606.196 916.237,606.196 916.246,606.196 916.255,606.196 916.264,606.195 916.274,606.195 916.283,606.195 916.292,606.195 916.301,606.195 916.31,606.195 916.32,606.195 916.329,606.194 916.338,606.194 916.347,606.194 916.356,606.194 916.365,606.194 916.375,606.194 916.384,606.193 916.393,606.193 916.402,606.193 916.411,606.193 916.421,606.193 916.43,606.193 916.439,606.193 916.448,606.192 916.457,606.192 916.467,606.192 916.476,606.192 916.485,606.192 916.494,606.192 916.503,606.191 916.512,606.191 916.522,606.191 916.531,606.191 916.54,606.191 916.549,606.191 916.558,606.191 916.568,606.19 916.577,606.19 916.586,606.19 916.595,606.19 916.604,606.19 916.614,606.19 916.623,606.189 916.632,606.189 916.641,606.189 916.65,606.189 916.66,606.189 916.669,606.189 916.678,606.188 916.687,606.188 916.696,606.188 916.705,606.188 916.715,606.188 916.724,606.188 916.733,606.188 916.742,606.187 916.751,606.187 916.761,606.187 916.77,606.187 916.779,606.187 916.788,606.187 916.797,606.186 916.807,606.186 916.816,606.186 916.825,606.186 916.834,606.186 916.843,606.186 916.852,606.186 916.862,606.185 916.871,606.185 916.88,606.185 916.889,606.185 916.898,606.185 916.908,606.185 916.917,606.184 916.926,606.184 916.935,606.184 916.944,606.184 916.954,606.184 916.963,606.184 916.972,606.183 916.981,606.183 916.99,606.183 917,606.183 917.009,606.183 917.018,606.183 917.027,606.183 917.036,606.182 917.045,606.182 917.055,606.182 917.064,606.182 917.073,606.182 917.082,606.182 917.091,606.181 917.101,606.181 917.11,606.181 917.119,606.181 917.128,606.181 917.137,606.181 917.147,606.181 917.156,606.18 917.165,606.18 917.174,606.18 917.183,606.18 917.192,606.18 917.202,606.18 917.211,606.179 917.22,606.179 917.229,606.179 917.238,606.179 917.248,606.179 917.257,606.179 917.266,606.179 917.275,606.178 917.284,606.178 917.294,606.178 917.303,606.178 917.312,606.178 917.321,606.178 917.33,606.177 917.34,606.177 917.349,606.177 917.358,606.177 917.367,606.177 917.376,606.177 917.385,606.176 917.395,606.176 917.404,606.176 917.413,606.176 917.422,606.176 917.431,606.176 917.441,606.176 917.45,606.175 917.459,606.175 917.468,606.175 917.477,606.175 917.487,606.175 917.496,606.175 917.505,606.174 917.514,606.174 917.523,606.174 917.532,606.174 917.542,606.174 917.551,606.174 917.56,606.174 917.569,606.173 917.578,606.173 917.588,606.173 917.597,606.173 917.606,606.173 917.615,606.173 917.624,606.172 917.634,606.172 917.643,606.172 917.652,606.172 917.661,606.172 917.67,606.172 917.68,606.171 917.689,606.171 917.698,606.171 917.707,606.171 917.716,606.171 917.725,606.171 917.735,606.171 917.744,606.17 917.753,606.17 917.762,606.17 917.771,606.17 917.781,606.17 917.79,606.17 917.799,606.169 917.808,606.169 917.817,606.169 917.827,606.169 917.836,606.169 917.845,606.169 917.854,606.169 917.863,606.168 917.872,606.168 917.882,606.168 917.891,606.168 917.9,606.168 917.909,606.168 917.918,606.167 917.928,606.167 917.937,606.167 917.946,606.167 917.955,606.167 917.964,606.167 917.974,606.167 917.983,606.166 917.992,606.166 918.001,606.166 918.01,606.166 918.02,606.166 918.029,606.166 918.038,606.165 918.047,606.165 918.056,606.165 918.065,606.165 918.075,606.165 918.084,606.165 918.093,606.164 918.102,606.164 918.111,606.164 918.121,606.164 918.13,606.164 918.139,606.164 918.148,606.164 918.157,606.163 918.167,606.163 918.176,606.163 918.185,606.163 918.194,606.163 918.203,606.163 918.213,606.162 918.222,606.162 918.231,606.162 918.24,606.162 918.249,606.162 918.258,606.162 918.268,606.162 918.277,606.161 918.286,606.161 918.295,606.161 918.304,606.161 918.314,606.161 918.323,606.161 918.332,606.16 918.341,606.16 918.35,606.16 918.36,606.16 918.369,606.16 918.378,606.16 918.387,606.16 918.396,606.159 918.405,606.159 918.415,606.159 918.424,606.159 918.433,606.159 918.442,606.159 918.451,606.158 918.461,606.158 918.47,606.158 918.479,606.158 918.488,606.158 918.497,606.158 918.507,606.157 918.516,606.157 918.525,606.157 918.534,606.157 918.543,606.157 918.553,606.157 918.562,606.157 918.571,606.156 918.58,606.156 918.589,606.156 918.598,606.156 918.608,606.156 918.617,606.156 918.626,606.155 918.635,606.155 918.644,606.155 918.654,606.155 918.663,606.155 918.672,606.155 918.681,606.155 918.69,606.154 918.7,606.154 918.709,606.154 918.718,606.154 918.727,606.154 918.736,606.154 918.745,606.153 918.755,606.153 918.764,606.153 918.773,606.153 918.782,606.153 918.791,606.153 918.801,606.153 918.81,606.152 918.819,606.152 918.828,606.152 918.837,606.152 918.847,606.152 918.856,606.152 918.865,606.151 918.874,606.151 918.883,606.151 918.893,606.151 918.902,606.151 918.911,606.151 918.92,606.15 918.929,606.15 918.938,606.15 918.948,606.15 918.957,606.15 918.966,606.15 918.975,606.15 918.984,606.149 918.994,606.149 919.003,606.149 919.012,606.149 919.021,606.149 919.03,606.149 919.04,606.148 919.049,606.148 919.058,606.148 919.067,606.148 919.076,606.148 919.085,606.148 919.095,606.148 919.104,606.147 919.113,606.147 919.122,606.147 919.131,606.147 919.141,606.147 919.15,606.147 919.159,606.146 919.168,606.146 919.177,606.146 919.187,606.146 919.196,606.146 919.205,606.146 919.214,606.146 919.223,606.145 919.233,606.145 919.242,606.145 919.251,606.145 919.26,606.145 919.269,606.145 919.278,606.144 919.288,606.144 919.297,606.144 919.306,606.144 919.315,606.144 919.324,606.144 919.334,606.144 919.343,606.143 919.352,606.143 919.361,606.143 919.37,606.143 919.38,606.143 919.389,606.143 919.398,606.142 919.407,606.142 919.416,606.142 919.425,606.142 919.435,606.142 919.444,606.142 919.453,606.141 919.462,606.141 919.471,606.141 919.481,606.141 919.49,606.141 919.499,606.141 919.508,606.141 919.517,606.14 919.527,606.14 919.536,606.14 919.545,606.14 919.554,606.14 919.563,606.14 919.573,606.139 919.582,606.139 919.591,606.139 919.6,606.139 919.609,606.139 919.618,606.139 919.628,606.139 919.637,606.138 919.646,606.138 919.655,606.138 919.664,606.138 919.674,606.138 919.683,606.138 919.692,606.137 919.701,606.137 919.71,606.137 919.72,606.137 919.729,606.137 919.738,606.137 919.747,606.137 919.756,606.136 919.765,606.136 919.775,606.136 919.784,606.136 919.793,606.136 919.802,606.136 919.811,606.135 919.821,606.135 919.83,606.135 919.839,606.135 919.848,606.135 919.857,606.135 919.867,606.135 919.876,606.134 919.885,606.134 919.894,606.134 919.903,606.134 919.913,606.134 919.922,606.134 919.931,606.133 919.94,606.133 919.949,606.133 919.958,606.133 919.968,606.133 919.977,606.133 919.986,606.132 919.995,606.132 920.004,606.132 920.014,606.132 920.023,606.132 920.032,606.132 920.041,606.132 920.05,606.131 920.06,606.131 920.069,606.131 920.078,606.131 920.087,606.131 920.096,606.131 920.105,606.13 920.115,606.13 920.124,606.13 920.133,606.13 920.142,606.13 920.151,606.13 920.161,606.13 920.17,606.129 920.179,606.129 920.188,606.129 920.197,606.129 920.207,606.129 920.216,606.129 920.225,606.128 920.234,606.128 920.243,606.128 920.253,606.128 920.262,606.128 920.271,606.128 920.28,606.128 920.289,606.127 920.298,606.127 920.308,606.127 920.317,606.127 920.326,606.127 920.335,606.127 920.344,606.126 920.354,606.126 920.363,606.126 920.372,606.126 920.381,606.126 920.39,606.126 920.4,606.126 920.409,606.125 920.418,606.125 920.427,606.125 920.436,606.125 920.445,606.125 920.455,606.125 920.464,606.124 920.473,606.124 920.482,606.124 920.491,606.124 920.501,606.124 920.51,606.124 920.519,606.123 920.528,606.123 920.537,606.123 920.547,606.123 920.556,606.123 920.565,606.123 920.574,606.123 920.583,606.122 920.593,606.122 920.602,606.122 920.611,606.122 920.62,606.122 920.629,606.122 920.638,606.121 920.648,606.121 920.657,606.121 920.666,606.121 920.675,606.121 920.684,606.121 920.694,606.121 920.703,606.12 920.712,606.12 920.721,606.12 920.73,606.12 920.74,606.12 920.749,606.12 920.758,606.119 920.767,606.119 920.776,606.119 920.786,606.119 920.795,606.119 920.804,606.119 920.813,606.119 920.822,606.118 920.831,606.118 920.841,606.118 920.85,606.118 920.859,606.118 920.868,606.118 920.877,606.117 920.887,606.117 920.896,606.117 920.905,606.117 920.914,606.117 920.923,606.117 920.933,606.117 920.942,606.116 920.951,606.116 920.96,606.116 920.969,606.116 920.978,606.116 920.988,606.116 920.997,606.115 921.006,606.115 921.015,606.115 921.024,606.115 921.034,606.115 921.043,606.115 921.052,606.115 921.061,606.114 921.07,606.114 921.08,606.114 921.089,606.114 921.098,606.114 921.107,606.114 921.116,606.113 921.126,606.113 921.135,606.113 921.144,606.113 921.153,606.113 921.162,606.113 921.171,606.113 921.181,606.112 921.19,606.112 921.199,606.112 921.208,606.112 921.217,606.112 921.227,606.112 921.236,606.111 921.245,606.111 921.254,606.111 921.263,606.111 921.273,606.111 921.282,606.111 921.291,606.11 921.3,606.11 921.309,606.11 921.318,606.11 921.328,606.11 921.337,606.11 921.346,606.11 921.355,606.109 921.364,606.109 921.374,606.109 921.383,606.109 921.392,606.109 921.401,606.109 921.41,606.108 921.42,606.108 921.429,606.108 921.438,606.108 921.447,606.108 921.456,606.108 921.466,606.108 921.475,606.107 921.484,606.107 921.493,606.107 921.502,606.107 921.511,606.107 921.521,606.107 921.53,606.106 921.539,606.106 921.548,606.106 921.557,606.106 921.567,606.106 921.576,606.106 921.585,606.106 921.594,606.105 921.603,606.105 921.613,606.105 921.622,606.105 921.631,606.105 921.64,606.105 921.649,606.104 921.658,606.104 921.668,606.104 921.677,606.104 921.686,606.104 921.695,606.104 921.704,606.104 921.714,606.103 921.723,606.103 921.732,606.103 921.741,606.103 921.75,606.103 921.76,606.103 921.769,606.102 921.778,606.102 921.787,606.102 921.796,606.102 921.806,606.102 921.815,606.102 921.824,606.102 921.833,606.101 921.842,606.101 921.851,606.101 921.861,606.101 921.87,606.101 921.879,606.101 921.888,606.1 921.897,606.1 921.907,606.1 921.916,606.1 921.925,606.1 921.934,606.1 921.943,606.1 921.953,606.099 921.962,606.099 921.971,606.099 921.98,606.099 921.989,606.099 921.998,606.099 922.008,606.098 922.017,606.098 922.026,606.098 922.035,606.098 922.044,606.098 922.054,606.098 922.063,606.098 922.072,606.097 922.081,606.097 922.09,606.097 922.1,606.097 922.109,606.097 922.118,606.097 922.127,606.096 922.136,606.096 922.146,606.096 922.155,606.096 922.164,606.096 922.173,606.096 922.182,606.096 922.191,606.095 922.201,606.095 922.21,606.095 922.219,606.095 922.228,606.095 922.237,606.095 922.247,606.094 922.256,606.094 922.265,606.094 922.274,606.094 922.283,606.094 922.293,606.094 922.302,606.093 922.311,606.093 922.32,606.093 922.329,606.093 922.338,606.093 922.348,606.093 922.357,606.093 922.366,606.092 922.375,606.092 922.384,606.092 922.394,606.092 922.403,606.092 922.412,606.092 922.421,606.091 922.43,606.091 922.44,606.091 922.449,606.091 922.458,606.091 922.467,606.091 922.476,606.091 922.486,606.09 922.495,606.09 922.504,606.09 922.513,606.09 922.522,606.09 922.531,606.09 922.541,606.089 922.55,606.089 922.559,606.089 922.568,606.089 922.577,606.089 922.587,606.089 922.596,606.089 922.605,606.088 922.614,606.088 922.623,606.088 922.633,606.088 922.642,606.088 922.651,606.088 922.66,606.087 922.669,606.087 922.678,606.087 922.688,606.087 922.697,606.087 922.706,606.087 922.715,606.087 922.724,606.086 922.734,606.086 922.743,606.086 922.752,606.086 922.761,606.086 922.77,606.086 922.78,606.085 922.789,606.085 922.798,606.085 922.807,606.085 922.816,606.085 922.826,606.085 922.835,606.085 922.844,606.084 922.853,606.084 922.862,606.084 922.871,606.084 922.881,606.084 922.89,606.084 922.899,606.083 922.908,606.083 922.917,606.083 922.927,606.083 922.936,606.083 922.945,606.083 922.954,606.083 922.963,606.082 922.973,606.082 922.982,606.082 922.991,606.082 923,606.082 923.009,606.082 923.019,606.081 923.028,606.081 923.037,606.081 923.046,606.081 923.055,606.081 923.064,606.081 923.074,606.081 923.083,606.08 923.092,606.08 923.101,606.08 923.11,606.08 923.12,606.08 923.129,606.08 923.138,606.079 923.147,606.079 923.156,606.079 923.166,606.079 923.175,606.079 923.184,606.079 923.193,606.079 923.202,606.078 923.211,606.078 923.221,606.078 923.23,606.078 923.239,606.078 923.248,606.078 923.257,606.077 923.267,606.077 923.276,606.077 923.285,606.077 923.294,606.077 923.303,606.077 923.313,606.077 923.322,606.076 923.331,606.076 923.34,606.076 923.349,606.076 923.359,606.076 923.368,606.076 923.377,606.075 923.386,606.075 923.395,606.075 923.404,606.075 923.414,606.075 923.423,606.075 923.432,606.075 923.441,606.074 923.45,606.074 923.46,606.074 923.469,606.074 923.478,606.074 923.487,606.074 923.496,606.073 923.506,606.073 923.515,606.073 923.524,606.073 923.533,606.073 923.542,606.073 923.551,606.073 923.561,606.072 923.57,606.072 923.579,606.072 923.588,606.072 923.597,606.072 923.607,606.072 923.616,606.071 923.625,606.071 923.634,606.071 923.643,606.071 923.653,606.071 923.662,606.071 923.671,606.071 923.68,606.07 923.689,606.07 923.699,606.07 923.708,606.07 923.717,606.07 923.726,606.07 923.735,606.069 923.744,606.069 923.754,606.069 923.763,606.069 923.772,606.069 923.781,606.069 923.79,606.069 923.8,606.068 923.809,606.068 923.818,606.068 923.827,606.068 923.836,606.068 923.846,606.068 923.855,606.067 923.864,606.067 923.873,606.067 923.882,606.067 923.891,606.067 923.901,606.067 923.91,606.067 923.919,606.066 923.928,606.066 923.937,606.066 923.947,606.066 923.956,606.066 923.965,606.066 923.974,606.065 923.983,606.065 923.993,606.065 924.002,606.065 924.011,606.065 924.02,606.065 924.029,606.065 924.039,606.064 924.048,606.064 924.057,606.064 924.066,606.064 924.075,606.064 924.084,606.064 924.094,606.063 924.103,606.063 924.112,606.063 924.121,606.063 924.13,606.063 924.14,606.063 924.149,606.063 924.158,606.062 924.167,606.062 924.176,606.062 924.186,606.062 924.195,606.062 924.204,606.062 924.213,606.061 924.222,606.061 924.231,606.061 924.241,606.061 924.25,606.061 924.259,606.061 924.268,606.061 924.277,606.06 924.287,606.06 924.296,606.06 924.305,606.06 924.314,606.06 924.323,606.06 924.333,606.059 924.342,606.059 924.351,606.059 924.36,606.059 924.369,606.059 924.379,606.059 924.388,606.059 924.397,606.058 924.406,606.058 924.415,606.058 924.424,606.058 924.434,606.058 924.443,606.058 924.452,606.057 924.461,606.057 924.47,606.057 924.48,606.057 924.489,606.057 924.498,606.057 924.507,606.057 924.516,606.056 924.526,606.056 924.535,606.056 924.544,606.056 924.553,606.056 924.562,606.056 924.571,606.056 924.581,606.055 924.59,606.055 924.599,606.055 924.608,606.055 924.617,606.055 924.627,606.055 924.636,606.054 924.645,606.054 924.654,606.054 924.663,606.054 924.673,606.054 924.682,606.054 924.691,606.054 924.7,606.053 924.709,606.053 924.719,606.053 924.728,606.053 924.737,606.053 924.746,606.053 924.755,606.052 924.764,606.052 924.774,606.052 924.783,606.052 924.792,606.052 924.801,606.052 924.81,606.052 924.82,606.051 924.829,606.051 924.838,606.051 924.847,606.051 924.856,606.051 924.866,606.051 924.875,606.05 924.884,606.05 924.893,606.05 924.902,606.05 924.911,606.05 924.921,606.05 924.93,606.05 924.939,606.049 924.948,606.049 924.957,606.049 924.967,606.049 924.976,606.049 924.985,606.049 924.994,606.048 925.003,606.048 925.013,606.048 925.022,606.048 925.031,606.048 925.04,606.048 925.049,606.048 925.059,606.047 925.068,606.047 925.077,606.047 925.086,606.047 925.095,606.047 925.104,606.047 925.114,606.046 925.123,606.046 925.132,606.046 925.141,606.046 925.15,606.046 925.16,606.046 925.169,606.046 925.178,606.045 925.187,606.045 925.196,606.045 925.206,606.045 925.215,606.045 925.224,606.045 925.233,606.044 925.242,606.044 925.251,606.044 925.261,606.044 925.27,606.044 925.279,606.044 925.288,606.044 925.297,606.043 925.307,606.043 925.316,606.043 925.325,606.043 925.334,606.043 925.343,606.043 925.353,606.042 925.362,606.042 925.371,606.042 925.38,606.042 925.389,606.042 925.399,606.042 925.408,606.042 925.417,606.041 925.426,606.041 925.435,606.041 925.444,606.041 925.454,606.041 925.463,606.041 925.472,606.04 925.481,606.04 925.49,606.04 925.5,606.04 925.509,606.04 925.518,606.04 925.527,606.04 925.536,606.039 925.546,606.039 925.555,606.039 925.564,606.039 925.573,606.039 925.582,606.039 925.592,606.039 925.601,606.038 925.61,606.038 925.619,606.038 925.628,606.038 925.637,606.038 925.647,606.038 925.656,606.037 925.665,606.037 925.674,606.037 925.683,606.037 925.693,606.037 925.702,606.037 925.711,606.037 925.72,606.036 925.729,606.036 925.739,606.036 925.748,606.036 925.757,606.036 925.766,606.036 925.775,606.035 925.784,606.035 925.794,606.035 925.803,606.035 925.812,606.035 925.821,606.035 925.83,606.035 925.84,606.034 925.849,606.034 925.858,606.034 925.867,606.034 925.876,606.034 925.886,606.034 925.895,606.033 925.904,606.033 925.913,606.033 925.922,606.033 925.932,606.033 925.941,606.033 925.95,606.033 925.959,606.032 925.968,606.032 925.977,606.032 925.987,606.032 925.996,606.032 926.005,606.032 926.014,606.031 926.023,606.031 926.033,606.031 926.042,606.031 926.051,606.031 926.06,606.031 926.069,606.031 926.079,606.03 926.088,606.03 926.097,606.03 926.106,606.03 926.115,606.03 926.124,606.03 926.134,606.029 926.143,606.029 926.152,606.029 926.161,606.029 926.17,606.029 926.18,606.029 926.189,606.029 926.198,606.028 926.207,606.028 926.216,606.028 926.226,606.028 926.235,606.028 926.244,606.028 926.253,606.028 926.262,606.027 926.272,606.027 926.281,606.027 926.29,606.027 926.299,606.027 926.308,606.027 926.317,606.026 926.327,606.026 926.336,606.026 926.345,606.026 926.354,606.026 926.363,606.026 926.373,606.026 926.382,606.025 926.391,606.025 926.4,606.025 926.409,606.025 926.419,606.025 926.428,606.025 926.437,606.024 926.446,606.024 926.455,606.024 926.464,606.024 926.474,606.024 926.483,606.024 926.492,606.024 926.501,606.023 926.51,606.023 926.52,606.023 926.529,606.023 926.538,606.023 926.547,606.023 926.556,606.022 926.566,606.022 926.575,606.022 926.584,606.022 926.593,606.022 926.602,606.022 926.612,606.022 926.621,606.021 926.63,606.021 926.639,606.021 926.648,606.021 926.657,606.021 926.667,606.021 926.676,606.02 926.685,606.02 926.694,606.02 926.703,606.02 926.713,606.02 926.722,606.02 926.731,606.02 926.74,606.019 926.749,606.019 926.759,606.019 926.768,606.019 926.777,606.019 926.786,606.019 926.795,606.019 926.804,606.018 926.814,606.018 926.823,606.018 926.832,606.018 926.841,606.018 926.85,606.018 926.86,606.017 926.869,606.017 926.878,606.017 926.887,606.017 926.896,606.017 926.906,606.017 926.915,606.017 926.924,606.016 926.933,606.016 926.942,606.016 926.952,606.016 926.961,606.016 926.97,606.016 926.979,606.015 926.988,606.015 926.997,606.015 927.007,606.015 927.016,606.015 927.025,606.015 927.034,606.015 927.043,606.014 927.053,606.014 927.062,606.014 927.071,606.014 927.08,606.014 927.089,606.014 927.099,606.013 927.108,606.013 927.117,606.013 927.126,606.013 927.135,606.013 927.144,606.013 927.154,606.013 927.163,606.012 927.172,606.012 927.181,606.012 927.19,606.012 927.2,606.012 927.209,606.012 927.218,606.012 927.227,606.011 927.236,606.011 927.246,606.011 927.255,606.011 927.264,606.011 927.273,606.011 927.282,606.01 927.292,606.01 927.301,606.01 927.31,606.01 927.319,606.01 927.328,606.01 927.337,606.01 927.347,606.009 927.356,606.009 927.365,606.009 927.374,606.009 927.383,606.009 927.393,606.009 927.402,606.008 927.411,606.008 927.42,606.008 927.429,606.008 927.439,606.008 927.448,606.008 927.457,606.008 927.466,606.007 927.475,606.007 927.484,606.007 927.494,606.007 927.503,606.007 927.512,606.007 927.521,606.007 927.53,606.006 927.54,606.006 927.549,606.006 927.558,606.006 927.567,606.006 927.576,606.006 927.586,606.005 927.595,606.005 927.604,606.005 927.613,606.005 927.622,606.005 927.632,606.005 927.641,606.005 927.65,606.004 927.659,606.004 927.668,606.004 927.677,606.004 927.687,606.004 927.696,606.004 927.705,606.003 927.714,606.003 927.723,606.003 927.733,606.003 927.742,606.003 927.751,606.003 927.76,606.003 927.769,606.002 927.779,606.002 927.788,606.002 927.797,606.002 927.806,606.002 927.815,606.002 927.824,606.001 927.834,606.001 927.843,606.001 927.852,606.001 927.861,606.001 927.87,606.001 927.88,606.001 927.889,606 927.898,606 927.907,606 927.916,606 927.926,606 927.935,606 927.944,606 927.953,605.999 927.962,605.999 927.972,605.999 927.981,605.999 927.99,605.999 927.999,605.999 928.008,605.998 928.017,605.998 928.027,605.998 928.036,605.998 928.045,605.998 928.054,605.998 928.063,605.998 928.073,605.997 928.082,605.997 928.091,605.997 928.1,605.997 928.109,605.997 928.119,605.997 928.128,605.996 928.137,605.996 928.146,605.996 928.155,605.996 928.165,605.996 928.174,605.996 928.183,605.996 928.192,605.995 928.201,605.995 928.21,605.995 928.22,605.995 928.229,605.995 928.238,605.995 928.247,605.995 928.256,605.994 928.266,605.994 928.275,605.994 928.284,605.994 928.293,605.994 928.302,605.994 928.312,605.993 928.321,605.993 928.33,605.993 928.339,605.993 928.348,605.993 928.357,605.993 928.367,605.993 928.376,605.992 928.385,605.992 928.394,605.992 928.403,605.992 928.413,605.992 928.422,605.992 928.431,605.991 928.44,605.991 928.449,605.991 928.459,605.991 928.468,605.991 928.477,605.991 928.486,605.991 928.495,605.99 928.505,605.99 928.514,605.99 928.523,605.99 928.532,605.99 928.541,605.99 928.55,605.99 928.56,605.989 928.569,605.989 928.578,605.989 928.587,605.989 928.596,605.989 928.606,605.989 928.615,605.988 928.624,605.988 928.633,605.988 928.642,605.988 928.652,605.988 928.661,605.988 928.67,605.988 928.679,605.987 928.688,605.987 928.697,605.987 928.707,605.987 928.716,605.987 928.725,605.987 928.734,605.986 928.743,605.986 928.753,605.986 928.762,605.986 928.771,605.986 928.78,605.986 928.789,605.986 928.799,605.985 928.808,605.985 928.817,605.985 928.826,605.985 928.835,605.985 928.845,605.985 928.854,605.985 928.863,605.984 928.872,605.984 928.881,605.984 928.89,605.984 928.9,605.984 928.909,605.984 928.918,605.983 928.927,605.983 928.936,605.983 928.946,605.983 928.955,605.983 928.964,605.983 928.973,605.983 928.982,605.982 928.992,605.982 929.001,605.982 929.01,605.982 929.019,605.982 929.028,605.982 929.037,605.982 929.047,605.981 929.056,605.981 929.065,605.981 929.074,605.981 929.083,605.981 929.093,605.981 929.102,605.98 929.111,605.98 929.12,605.98 929.129,605.98 929.139,605.98 929.148,605.98 929.157,605.98 929.166,605.979 929.175,605.979 929.185,605.979 929.194,605.979 929.203,605.979 929.212,605.979 929.221,605.978 929.23,605.978 929.24,605.978 929.249,605.978 929.258,605.978 929.267,605.978 929.276,605.978 929.286,605.977 929.295,605.977 929.304,605.977 929.313,605.977 929.322,605.977 929.332,605.977 929.341,605.977 929.35,605.976 929.359,605.976 929.368,605.976 929.377,605.976 929.387,605.976 929.396,605.976 929.405,605.975 929.414,605.975 929.423,605.975 929.433,605.975 929.442,605.975 929.451,605.975 929.46,605.975 929.469,605.974 929.479,605.974 929.488,605.974 929.497,605.974 929.506,605.974 929.515,605.974 929.525,605.974 929.534,605.973 929.543,605.973 929.552,605.973 929.561,605.973 929.57,605.973 929.58,605.973 929.589,605.972 929.598,605.972 929.607,605.972 929.616,605.972 929.626,605.972 929.635,605.972 929.644,605.972 929.653,605.971 929.662,605.971 929.672,605.971 929.681,605.971 929.69,605.971 929.699,605.971 929.708,605.97 929.717,605.97 929.727,605.97 929.736,605.97 929.745,605.97 929.754,605.97 929.763,605.97 929.773,605.969 929.782,605.969 929.791,605.969 929.8,605.969 929.809,605.969 929.819,605.969 929.828,605.969 929.837,605.968 929.846,605.968 929.855,605.968 929.865,605.968 929.874,605.968 929.883,605.968 929.892,605.967 929.901,605.967 929.91,605.967 929.92,605.967 929.929,605.967 929.938,605.967 929.947,605.967 929.956,605.966 929.966,605.966 929.975,605.966 929.984,605.966 929.993,605.966 930.002,605.966 930.012,605.966 930.021,605.965 930.03,605.965 930.039,605.965 930.048,605.965 930.057,605.965 930.067,605.965 930.076,605.964 930.085,605.964 930.094,605.964 930.103,605.964 930.113,605.964 930.122,605.964 930.131,605.964 930.14,605.963 930.149,605.963 930.159,605.963 930.168,605.963 930.177,605.963 930.186,605.963 930.195,605.963 930.205,605.962 930.214,605.962 930.223,605.962 930.232,605.962 930.241,605.962 930.25,605.962 930.26,605.961 930.269,605.961 930.278,605.961 930.287,605.961 930.296,605.961 930.306,605.961 930.315,605.961 930.324,605.96 930.333,605.96 930.342,605.96 930.352,605.96 930.361,605.96 930.37,605.96 930.379,605.959 930.388,605.959 930.397,605.959 930.407,605.959 930.416,605.959 930.425,605.959 930.434,605.959 930.443,605.958 930.453,605.958 930.462,605.958 930.471,605.958 930.48,605.958 930.489,605.958 930.499,605.958 930.508,605.957 930.517,605.957 930.526,605.957 930.535,605.957 930.545,605.957 930.554,605.957 930.563,605.956 930.572,605.956 930.581,605.956 930.59,605.956 930.6,605.956 930.609,605.956 930.618,605.956 930.627,605.955 930.636,605.955 930.646,605.955 930.655,605.955 930.664,605.955 930.673,605.955 930.682,605.955 930.692,605.954 930.701,605.954 930.71,605.954 930.719,605.954 930.728,605.954 930.738,605.954 930.747,605.953 930.756,605.953 930.765,605.953 930.774,605.953 930.783,605.953 930.793,605.953 930.802,605.953 930.811,605.952 930.82,605.952 930.829,605.952 930.839,605.952 930.848,605.952 930.857,605.952 930.866,605.952 930.875,605.951 930.885,605.951 930.894,605.951 930.903,605.951 930.912,605.951 930.921,605.951 930.93,605.95 930.94,605.95 930.949,605.95 930.958,605.95 930.967,605.95 930.976,605.95 930.986,605.95 930.995,605.949 931.004,605.949 931.013,605.949 931.022,605.949 931.032,605.949 931.041,605.949 931.05,605.949 931.059,605.948 931.068,605.948 931.078,605.948 931.087,605.948 931.096,605.948 931.105,605.948 931.114,605.947 931.123,605.947 931.133,605.947 931.142,605.947 931.151,605.947 931.16,605.947 931.169,605.947 931.179,605.946 931.188,605.946 931.197,605.946 931.206,605.946 931.215,605.946 931.225,605.946 931.234,605.946 931.243,605.945 931.252,605.945 931.261,605.945 931.27,605.945 931.28,605.945 931.289,605.945 931.298,605.944 931.307,605.944 931.316,605.944 931.326,605.944 931.335,605.944 931.344,605.944 931.353,605.944 931.362,605.943 931.372,605.943 931.381,605.943 931.39,605.943 931.399,605.943 931.408,605.943 931.418,605.943 931.427,605.942 931.436,605.942 931.445,605.942 931.454,605.942 931.463,605.942 931.473,605.942 931.482,605.941 931.491,605.941 931.5,605.941 931.509,605.941 931.519,605.941 931.528,605.941 931.537,605.941 931.546,605.94 931.555,605.94 931.565,605.94 931.574,605.94 931.583,605.94 931.592,605.94 931.601,605.94 931.61,605.939 931.62,605.939 931.629,605.939 931.638,605.939 931.647,605.939 931.656,605.939 931.666,605.939 931.675,605.938 931.684,605.938 931.693,605.938 931.702,605.938 931.712,605.938 931.721,605.938 931.73,605.937 931.739,605.937 931.748,605.937 931.758,605.937 931.767,605.937 931.776,605.937 931.785,605.937 931.794,605.936 931.803,605.936 931.813,605.936 931.822,605.936 931.831,605.936 931.84,605.936 931.849,605.936 931.859,605.935 931.868,605.935 931.877,605.935 931.886,605.935 931.895,605.935 931.905,605.935 931.914,605.934 931.923,605.934 931.932,605.934 931.941,605.934 931.95,605.934 931.96,605.934 931.969,605.934 931.978,605.933 931.987,605.933 931.996,605.933 932.006,605.933 932.015,605.933 932.024,605.933 932.033,605.933 932.042,605.932 932.052,605.932 932.061,605.932 932.07,605.932 932.079,605.932 932.088,605.932 932.098,605.931 932.107,605.931 932.116,605.931 932.125,605.931 932.134,605.931 932.143,605.931 932.153,605.931 932.162,605.93 932.171,605.93 932.18,605.93 932.189,605.93 932.199,605.93 932.208,605.93 932.217,605.93 932.226,605.929 932.235,605.929 932.245,605.929 932.254,605.929 932.263,605.929 932.272,605.929 932.281,605.928 932.29,605.928 932.3,605.928 932.309,605.928 932.318,605.928 932.327,605.928 932.336,605.928 932.346,605.927 932.355,605.927 932.364,605.927 932.373,605.927 932.382,605.927 932.392,605.927 932.401,605.927 932.41,605.926 932.419,605.926 932.428,605.926 932.438,605.926 932.447,605.926 932.456,605.926 932.465,605.926 932.474,605.925 932.483,605.925 932.493,605.925 932.502,605.925 932.511,605.925 932.52,605.925 932.529,605.924 932.539,605.924 932.548,605.924 932.557,605.924 932.566,605.924 932.575,605.924 932.585,605.924 932.594,605.923 932.603,605.923 932.612,605.923 932.621,605.923 932.63,605.923 932.64,605.923 932.649,605.923 932.658,605.922 932.667,605.922 932.676,605.922 932.686,605.922 932.695,605.922 932.704,605.922 932.713,605.921 932.722,605.921 932.732,605.921 932.741,605.921 932.75,605.921 932.759,605.921 932.768,605.921 932.778,605.92 932.787,605.92 932.796,605.92 932.805,605.92 932.814,605.92 932.823,605.92 932.833,605.92 932.842,605.919 932.851,605.919 932.86,605.919 932.869,605.919 932.879,605.919 932.888,605.919 932.897,605.919 932.906,605.918 932.915,605.918 932.925,605.918 932.934,605.918 932.943,605.918 932.952,605.918 932.961,605.917 932.971,605.917 932.98,605.917 932.989,605.917 932.998,605.917 933.007,605.917 933.016,605.917 933.026,605.916 933.035,605.916 933.044,605.916 933.053,605.916 933.062,605.916 933.072,605.916 933.081,605.916 933.09,605.915 933.099,605.915 933.108,605.915 933.118,605.915 933.127,605.915 933.136,605.915 933.145,605.914 933.154,605.914 933.163,605.914 933.173,605.914 933.182,605.914 933.191,605.914 933.2,605.914 933.209,605.913 933.219,605.913 933.228,605.913 933.237,605.913 933.246,605.913 933.255,605.913 933.265,605.913 933.274,605.912 933.283,605.912 933.292,605.912 933.301,605.912 933.311,605.912 933.32,605.912 933.329,605.912 933.338,605.911 933.347,605.911 933.356,605.911 933.366,605.911 933.375,605.911 933.384,605.911 933.393,605.91 933.402,605.91 933.412,605.91 933.421,605.91 933.43,605.91 933.439,605.91 933.448,605.91 933.458,605.909 933.467,605.909 933.476,605.909 933.485,605.909 933.494,605.909 933.503,605.909 933.513,605.909 933.522,605.908 933.531,605.908 933.54,605.908 933.549,605.908 933.559,605.908 933.568,605.908 933.577,605.908 933.586,605.907 933.595,605.907 933.605,605.907 933.614,605.907 933.623,605.907 933.632,605.907 933.641,605.906 933.651,605.906 933.66,605.906 933.669,605.906 933.678,605.906 933.687,605.906 933.696,605.906 933.706,605.905 933.715,605.905 933.724,605.905 933.733,605.905 933.742,605.905 933.752,605.905 933.761,605.905 933.77,605.904 933.779,605.904 933.788,605.904 933.798,605.904 933.807,605.904 933.816,605.904 933.825,605.904 933.834,605.903 933.843,605.903 933.853,605.903 933.862,605.903 933.871,605.903 933.88,605.903 933.889,605.902 933.899,605.902 933.908,605.902 933.917,605.902 933.926,605.902 933.935,605.902 933.945,605.902 933.954,605.901 933.963,605.901 933.972,605.901 933.981,605.901 933.991,605.901 934,605.901 934.009,605.901 934.018,605.9 934.027,605.9 934.036,605.9 934.046,605.9 934.055,605.9 934.064,605.9 934.073,605.9 934.082,605.899 934.092,605.899 934.101,605.899 934.11,605.899 934.119,605.899 934.128,605.899 934.138,605.898 934.147,605.898 934.156,605.898 934.165,605.898 934.174,605.898 934.183,605.898 934.193,605.898 934.202,605.897 934.211,605.897 934.22,605.897 934.229,605.897 934.239,605.897 934.248,605.897 934.257,605.897 934.266,605.896 934.275,605.896 934.285,605.896 934.294,605.896 934.303,605.896 934.312,605.896 934.321,605.896 934.331,605.895 934.34,605.895 934.349,605.895 934.358,605.895 934.367,605.895 934.376,605.895 934.386,605.894 934.395,605.894 934.404,605.894 934.413,605.894 934.422,605.894 934.432,605.894 934.441,605.894 934.45,605.893 934.459,605.893 934.468,605.893 934.478,605.893 934.487,605.893 934.496,605.893 934.505,605.893 934.514,605.892 934.523,605.892 934.533,605.892 934.542,605.892 934.551,605.892 934.56,605.892 934.569,605.892 934.579,605.891 934.588,605.891 934.597,605.891 934.606,605.891 934.615,605.891 934.625,605.891 934.634,605.89 934.643,605.89 934.652,605.89 934.661,605.89 934.671,605.89 934.68,605.89 934.689,605.89 934.698,605.889 934.707,605.889 934.716,605.889 934.726,605.889 934.735,605.889 934.744,605.889 934.753,605.889 934.762,605.888 934.772,605.888 934.781,605.888 934.79,605.888 934.799,605.888 934.808,605.888 934.818,605.888 934.827,605.887 934.836,605.887 934.845,605.887 934.854,605.887 934.863,605.887 934.873,605.887 934.882,605.886 934.891,605.886 934.9,605.886 934.909,605.886 934.919,605.886 934.928,605.886 934.937,605.886 934.946,605.885 934.955,605.885 934.965,605.885 934.974,605.885 934.983,605.885 934.992,605.885 935.001,605.885 935.011,605.884 935.02,605.884 935.029,605.884 935.038,605.884 935.047,605.884 935.056,605.884 935.066,605.884 935.075,605.883 935.084,605.883 935.093,605.883 935.102,605.883 935.112,605.883 935.121,605.883 935.13,605.883 935.139,605.882 935.148,605.882 935.158,605.882 935.167,605.882 935.176,605.882 935.185,605.882 935.194,605.881 935.203,605.881 935.213,605.881 935.222,605.881 935.231,605.881 935.24,605.881 935.249,605.881 935.259,605.88 935.268,605.88 935.277,605.88 935.286,605.88 935.295,605.88 935.305,605.88 935.314,605.88 935.323,605.879 935.332,605.879 935.341,605.879 935.351,605.879 935.36,605.879 935.369,605.879 935.378,605.879 935.387,605.878 935.396,605.878 935.406,605.878 935.415,605.878 935.424,605.878 935.433,605.878 935.442,605.877 935.452,605.877 935.461,605.877 935.47,605.877 935.479,605.877 935.488,605.877 935.498,605.877 935.507,605.876 935.516,605.876 935.525,605.876 935.534,605.876 935.544,605.876 935.553,605.876 935.562,605.876 935.571,605.875 935.58,605.875 935.589,605.875 935.599,605.875 935.608,605.875 935.617,605.875 935.626,605.875 935.635,605.874 935.645,605.874 935.654,605.874 935.663,605.874 935.672,605.874 935.681,605.874 935.691,605.874 935.7,605.873 935.709,605.873 935.718,605.873 935.727,605.873 935.736,605.873 935.746,605.873 935.755,605.872 935.764,605.872 935.773,605.872 935.782,605.872 935.792,605.872 935.801,605.872 935.81,605.872 935.819,605.871 935.828,605.871 935.838,605.871 935.847,605.871 935.856,605.871 935.865,605.871 935.874,605.871 935.884,605.87 935.893,605.87 935.902,605.87 935.911,605.87 935.92,605.87 935.929,605.87 935.939,605.87 935.948,605.869 935.957,605.869 935.966,605.869 935.975,605.869 935.985,605.869 935.994,605.869 936.003,605.869 936.012,605.868 936.021,605.868 936.031,605.868 936.04,605.868 936.049,605.868 936.058,605.868 936.067,605.868 936.076,605.867 936.086,605.867 936.095,605.867 936.104,605.867 936.113,605.867 936.122,605.867 936.132,605.866 936.141,605.866 936.15,605.866 936.159,605.866 936.168,605.866 936.178,605.866 936.187,605.866 936.196,605.865 936.205,605.865 936.214,605.865 936.224,605.865 936.233,605.865 936.242,605.865 936.251,605.865 936.26,605.864 936.269,605.864 936.279,605.864 936.288,605.864 936.297,605.864 936.306,605.864 936.315,605.864 936.325,605.863 936.334,605.863 936.343,605.863 936.352,605.863 936.361,605.863 936.371,605.863 936.38,605.863 936.389,605.862 936.398,605.862 936.407,605.862 936.416,605.862 936.426,605.862 936.435,605.862 936.444,605.861 936.453,605.861 936.462,605.861 936.472,605.861 936.481,605.861 936.49,605.861 936.499,605.861 936.508,605.86 936.518,605.86 936.527,605.86 936.536,605.86 936.545,605.86 936.554,605.86 936.564,605.86 936.573,605.859 936.582,605.859 936.591,605.859 936.6,605.859 936.609,605.859 936.619,605.859 936.628,605.859 936.637,605.858 936.646,605.858 936.655,605.858 936.665,605.858 936.674,605.858 936.683,605.858 936.692,605.858 936.701,605.857 936.711,605.857 936.72,605.857 936.729,605.857 936.738,605.857 936.747,605.857 936.756,605.857 936.766,605.856 936.775,605.856 936.784,605.856 936.793,605.856 936.802,605.856 936.812,605.856 936.821,605.855 936.83,605.855 936.839,605.855 936.848,605.855 936.858,605.855 936.867,605.855 936.876,605.855 936.885,605.854 936.894,605.854 936.904,605.854 936.913,605.854 936.922,605.854 936.931,605.854 936.94,605.854 936.949,605.853 936.959,605.853 936.968,605.853 936.977,605.853 936.986,605.853 936.995,605.853 937.005,605.853 937.014,605.852 937.023,605.852 937.032,605.852 937.041,605.852 937.051,605.852 937.06,605.852 937.069,605.852 937.078,605.851 937.087,605.851 937.096,605.851 937.106,605.851 937.115,605.851 937.124,605.851 937.133,605.851 937.142,605.85 937.152,605.85 937.161,605.85 937.17,605.85 937.179,605.85 937.188,605.85 937.198,605.849 937.207,605.849 937.216,605.849 937.225,605.849 937.234,605.849 937.244,605.849 937.253,605.849 937.262,605.848 937.271,605.848 937.28,605.848 937.289,605.848 937.299,605.848 937.308,605.848 937.317,605.848 937.326,605.847 937.335,605.847 937.345,605.847 937.354,605.847 937.363,605.847 937.372,605.847 937.381,605.847 937.391,605.846 937.4,605.846 937.409,605.846 937.418,605.846 937.427,605.846 937.436,605.846 937.446,605.846 937.455,605.845 937.464,605.845 937.473,605.845 937.482,605.845 937.492,605.845 937.501,605.845 937.51,605.845 937.519,605.844 937.528,605.844 937.538,605.844 937.547,605.844 937.556,605.844 937.565,605.844 937.574,605.844 937.584,605.843 937.593,605.843 937.602,605.843 937.611,605.843 937.62,605.843 937.629,605.843 937.639,605.842 937.648,605.842 937.657,605.842 937.666,605.842 937.675,605.842 937.685,605.842 937.694,605.842 937.703,605.841 937.712,605.841 937.721,605.841 937.731,605.841 937.74,605.841 937.749,605.841 937.758,605.841 937.767,605.84 937.776,605.84 937.786,605.84 937.795,605.84 937.804,605.84 937.813,605.84 937.822,605.84 937.832,605.839 937.841,605.839 937.85,605.839 937.859,605.839 937.868,605.839 937.878,605.839 937.887,605.839 937.896,605.838 937.905,605.838 937.914,605.838 937.924,605.838 937.933,605.838 937.942,605.838 937.951,605.838 937.96,605.837 937.969,605.837 937.979,605.837 937.988,605.837 937.997,605.837 938.006,605.837 938.015,605.837 938.025,605.836 938.034,605.836 938.043,605.836 938.052,605.836 938.061,605.836 938.071,605.836 938.08,605.836 938.089,605.835 938.098,605.835 938.107,605.835 938.117,605.835 938.126,605.835 938.135,605.835 938.144,605.834 938.153,605.834 938.162,605.834 938.172,605.834 938.181,605.834 938.19,605.834 938.199,605.834 938.208,605.833 938.218,605.833 938.227,605.833 938.236,605.833 938.245,605.833 938.254,605.833 938.264,605.833 938.273,605.832 938.282,605.832 938.291,605.832 938.3,605.832 938.309,605.832 938.319,605.832 938.328,605.832 938.337,605.831 938.346,605.831 938.355,605.831 938.365,605.831 938.374,605.831 938.383,605.831 938.392,605.831 938.401,605.83 938.411,605.83 938.42,605.83 938.429,605.83 938.438,605.83 938.447,605.83 938.457,605.83 938.466,605.829 938.475,605.829 938.484,605.829 938.493,605.829 938.502,605.829 938.512,605.829 938.521,605.829 938.53,605.828 938.539,605.828 938.548,605.828 938.558,605.828 938.567,605.828 938.576,605.828 938.585,605.828 938.594,605.827 938.604,605.827 938.613,605.827 938.622,605.827 938.631,605.827 938.64,605.827 938.649,605.826 938.659,605.826 938.668,605.826 938.677,605.826 938.686,605.826 938.695,605.826 938.705,605.826 938.714,605.825 938.723,605.825 938.732,605.825 938.741,605.825 938.751,605.825 938.76,605.825 938.769,605.825 938.778,605.824 938.787,605.824 938.797,605.824 938.806,605.824 938.815,605.824 938.824,605.824 938.833,605.824 938.842,605.823 938.852,605.823 938.861,605.823 938.87,605.823 938.879,605.823 938.888,605.823 938.898,605.823 938.907,605.822 938.916,605.822 938.925,605.822 938.934,605.822 938.944,605.822 938.953,605.822 938.962,605.822 938.971,605.821 938.98,605.821 938.989,605.821 938.999,605.821 939.008,605.821 939.017,605.821 939.026,605.821 939.035,605.82 939.045,605.82 939.054,605.82 939.063,605.82 939.072,605.82 939.081,605.82 939.091,605.82 939.1,605.819 939.109,605.819 939.118,605.819 939.127,605.819 939.137,605.819 939.146,605.819 939.155,605.819 939.164,605.818 939.173,605.818 939.182,605.818 939.192,605.818 939.201,605.818 939.21,605.818 939.219,605.818 939.228,605.817 939.238,605.817 939.247,605.817 939.256,605.817 939.265,605.817 939.274,605.817 939.284,605.817 939.293,605.816 939.302,605.816 939.311,605.816 939.32,605.816 939.329,605.816 939.339,605.816 939.348,605.815 939.357,605.815 939.366,605.815 939.375,605.815 939.385,605.815 939.394,605.815 939.403,605.815 939.412,605.814 939.421,605.814 939.431,605.814 939.44,605.814 939.449,605.814 939.458,605.814 939.467,605.814 939.477,605.813 939.486,605.813 939.495,605.813 939.504,605.813 939.513,605.813 939.522,605.813 939.532,605.813 939.541,605.812 939.55,605.812 939.559,605.812 939.568,605.812 939.578,605.812 939.587,605.812 939.596,605.812 939.605,605.811 939.614,605.811 939.624,605.811 939.633,605.811 939.642,605.811 939.651,605.811 939.66,605.811 939.669,605.81 939.679,605.81 939.688,605.81 939.697,605.81 939.706,605.81 939.715,605.81 939.725,605.81 939.734,605.809 939.743,605.809 939.752,605.809 939.761,605.809 939.771,605.809 939.78,605.809 939.789,605.809 939.798,605.808 939.807,605.808 939.817,605.808 939.826,605.808 939.835,605.808 939.844,605.808 939.853,605.808 939.862,605.807 939.872,605.807 939.881,605.807 939.89,605.807 939.899,605.807 939.908,605.807 939.918,605.807 939.927,605.806 939.936,605.806 939.945,605.806 939.954,605.806 939.964,605.806 939.973,605.806 939.982,605.806 939.991,605.805 940,605.805 940.009,605.805 940.019,605.805 940.028,605.805 940.037,605.805 940.046,605.805 940.055,605.804 940.065,605.804 940.074,605.804 940.083,605.804 940.092,605.804 940.101,605.804 940.111,605.804 940.12,605.803 940.129,605.803 940.138,605.803 940.147,605.803 940.157,605.803 940.166,605.803 940.175,605.803 940.184,605.802 940.193,605.802 940.202,605.802 940.212,605.802 940.221,605.802 940.23,605.802 940.239,605.801 940.248,605.801 940.258,605.801 940.267,605.801 940.276,605.801 940.285,605.801 940.294,605.801 940.304,605.8 940.313,605.8 940.322,605.8 940.331,605.8 940.34,605.8 940.35,605.8 940.359,605.8 940.368,605.799 940.377,605.799 940.386,605.799 940.395,605.799 940.405,605.799 940.414,605.799 940.423,605.799 940.432,605.798 940.441,605.798 940.451,605.798 940.46,605.798 940.469,605.798 940.478,605.798 940.487,605.798 940.497,605.797 940.506,605.797 940.515,605.797 940.524,605.797 940.533,605.797 940.542,605.797 940.552,605.797 940.561,605.796 940.57,605.796 940.579,605.796 940.588,605.796 940.598,605.796 940.607,605.796 940.616,605.796 940.625,605.795 940.634,605.795 940.644,605.795 940.653,605.795 940.662,605.795 940.671,605.795 940.68,605.795 940.69,605.794 940.699,605.794 940.708,605.794 940.717,605.794 940.726,605.794 940.735,605.794 940.745,605.794 940.754,605.793 940.763,605.793 940.772,605.793 940.781,605.793 940.791,605.793 940.8,605.793 940.809,605.793 940.818,605.792 940.827,605.792 940.837,605.792 940.846,605.792 940.855,605.792 940.864,605.792 940.873,605.792 940.882,605.791 940.892,605.791 940.901,605.791 940.91,605.791 940.919,605.791 940.928,605.791 940.938,605.791 940.947,605.79 940.956,605.79 940.965,605.79 940.974,605.79 940.984,605.79 940.993,605.79 941.002,605.79 941.011,605.789 941.02,605.789 941.03,605.789 941.039,605.789 941.048,605.789 941.057,605.789 941.066,605.789 941.075,605.788 941.085,605.788 941.094,605.788 941.103,605.788 941.112,605.788 941.121,605.788 941.131,605.788 941.14,605.787 941.149,605.787 941.158,605.787 941.167,605.787 941.177,605.787 941.186,605.787 941.195,605.787 941.204,605.786 941.213,605.786 941.222,605.786 941.232,605.786 941.241,605.786 941.25,605.786 941.259,605.786 941.268,605.785 941.278,605.785 941.287,605.785 941.296,605.785 941.305,605.785 941.314,605.785 941.324,605.785 941.333,605.784 941.342,605.784 941.351,605.784 941.36,605.784 941.37,605.784 941.379,605.784 941.388,605.784 941.397,605.783 941.406,605.783 941.415,605.783 941.425,605.783 941.434,605.783 941.443,605.783 941.452,605.783 941.461,605.782 941.471,605.782 941.48,605.782 941.489,605.782 941.498,605.782 941.507,605.782 941.517,605.782 941.526,605.781 941.535,605.781 941.544,605.781 941.553,605.781 941.562,605.781 941.572,605.781 941.581,605.781 941.59,605.78 941.599,605.78 941.608,605.78 941.618,605.78 941.627,605.78 941.636,605.78 941.645,605.78 941.654,605.779 941.664,605.779 941.673,605.779 941.682,605.779 941.691,605.779 941.7,605.779 941.71,605.779 941.719,605.778 941.728,605.778 941.737,605.778 941.746,605.778 941.755,605.778 941.765,605.778 941.774,605.778 941.783,605.777 941.792,605.777 941.801,605.777 941.811,605.777 941.82,605.777 941.829,605.777 941.838,605.777 941.847,605.776 941.857,605.776 941.866,605.776 941.875,605.776 941.884,605.776 941.893,605.776 941.902,605.776 941.912,605.775 941.921,605.775 941.93,605.775 941.939,605.775 941.948,605.775 941.958,605.775 941.967,605.775 941.976,605.774 941.985,605.774 941.994,605.774 942.004,605.774 942.013,605.774 942.022,605.774 942.031,605.774 942.04,605.773 942.05,605.773 942.059,605.773 942.068,605.773 942.077,605.773 942.086,605.773 942.095,605.773 942.105,605.772 942.114,605.772 942.123,605.772 942.132,605.772 942.141,605.772 942.151,605.772 942.16,605.772 942.169,605.771 942.178,605.771 942.187,605.771 942.197,605.771 942.206,605.771 942.215,605.771 942.224,605.771 942.233,605.77 942.242,605.77 942.252,605.77 942.261,605.77 942.27,605.77 942.279,605.77 942.288,605.77 942.298,605.769 942.307,605.769 942.316,605.769 942.325,605.769 942.334,605.769 942.344,605.769 942.353,605.769 942.362,605.768 942.371,605.768 942.38,605.768 942.39,605.768 942.399,605.768 942.408,605.768 942.417,605.768 942.426,605.767 942.435,605.767 942.445,605.767 942.454,605.767 942.463,605.767 942.472,605.767 942.481,605.767 942.491,605.766 942.5,605.766 942.509,605.766 942.518,605.766 942.527,605.766 942.537,605.766 942.546,605.766 942.555,605.765 942.564,605.765 942.573,605.765 942.582,605.765 942.592,605.765 942.601,605.765 942.61,605.765 942.619,605.764 942.628,605.764 942.638,605.764 942.647,605.764 942.656,605.764 942.665,605.764 942.674,605.764 942.684,605.763 942.693,605.763 942.702,605.763 942.711,605.763 942.72,605.763 942.73,605.763 942.739,605.763 942.748,605.762 942.757,605.762 942.766,605.762 942.775,605.762 942.785,605.762 942.794,605.762 942.803,605.762 942.812,605.761 942.821,605.761 942.831,605.761 942.84,605.761 942.849,605.761 942.858,605.761 942.867,605.761 942.877,605.76 942.886,605.76 942.895,605.76 942.904,605.76 942.913,605.76 942.923,605.76 942.932,605.76 942.941,605.759 942.95,605.759 942.959,605.759 942.968,605.759 942.978,605.759 942.987,605.759 942.996,605.759 943.005,605.758 943.014,605.758 943.024,605.758 943.033,605.758 943.042,605.758 943.051,605.758 943.06,605.758 943.07,605.757 943.079,605.757 943.088,605.757 943.097,605.757 943.106,605.757 943.115,605.757 943.125,605.757 943.134,605.756 943.143,605.756 943.152,605.756 943.161,605.756 943.171,605.756 943.18,605.756 943.189,605.756 943.198,605.755 943.207,605.755 943.217,605.755 943.226,605.755 943.235,605.755 943.244,605.755 943.253,605.755 943.263,605.754 943.272,605.754 943.281,605.754 943.29,605.754 943.299,605.754 943.308,605.754 943.318,605.754 943.327,605.753 943.336,605.753 943.345,605.753 943.354,605.753 943.364,605.753 943.373,605.753 943.382,605.753 943.391,605.753 943.4,605.752 943.41,605.752 943.419,605.752 943.428,605.752 943.437,605.752 943.446,605.752 943.455,605.752 943.465,605.751 943.474,605.751 943.483,605.751 943.492,605.751 943.501,605.751 943.511,605.751 943.52,605.751 943.529,605.75 943.538,605.75 943.547,605.75 943.557,605.75 943.566,605.75 943.575,605.75 943.584,605.75 943.593,605.749 943.603,605.749 943.612,605.749 943.621,605.749 943.63,605.749 943.639,605.749 943.648,605.749 943.658,605.748 943.667,605.748 943.676,605.748 943.685,605.748 943.694,605.748 943.704,605.748 943.713,605.748 943.722,605.747 943.731,605.747 943.74,605.747 943.75,605.747 943.759,605.747 943.768,605.747 943.777,605.747 943.786,605.746 943.795,605.746 943.805,605.746 943.814,605.746 943.823,605.746 943.832,605.746 943.841,605.746 943.851,605.745 943.86,605.745 943.869,605.745 943.878,605.745 943.887,605.745 943.897,605.745 943.906,605.745 943.915,605.744 943.924,605.744 943.933,605.744 943.943,605.744 943.952,605.744 943.961,605.744 943.97,605.744 943.979,605.743 943.988,605.743 943.998,605.743 944.007,605.743 944.016,605.743 944.025,605.743 944.034,605.743 944.044,605.742 944.053,605.742 944.062,605.742 944.071,605.742 944.08,605.742 944.09,605.742 944.099,605.742 944.108,605.741 944.117,605.741 944.126,605.741 944.135,605.741 944.145,605.741 944.154,605.741 944.163,605.741 944.172,605.74 944.181,605.74 944.191,605.74 944.2,605.74 944.209,605.74 944.218,605.74 944.227,605.74 944.237,605.74 944.246,605.739 944.255,605.739 944.264,605.739 944.273,605.739 944.283,605.739 944.292,605.739 944.301,605.739 944.31,605.738 944.319,605.738 944.328,605.738 944.338,605.738 944.347,605.738 944.356,605.738 944.365,605.738 944.374,605.737 944.384,605.737 944.393,605.737 944.402,605.737 944.411,605.737 944.42,605.737 944.43,605.737 944.439,605.736 944.448,605.736 944.457,605.736 944.466,605.736 944.475,605.736 944.485,605.736 944.494,605.736 944.503,605.735 944.512,605.735 944.521,605.735 944.531,605.735 944.54,605.735 944.549,605.735 944.558,605.735 944.567,605.734 944.577,605.734 944.586,605.734 944.595,605.734 944.604,605.734 944.613,605.734 944.623,605.734 944.632,605.733 944.641,605.733 944.65,605.733 944.659,605.733 944.668,605.733 944.678,605.733 944.687,605.733 944.696,605.732 944.705,605.732 944.714,605.732 944.724,605.732 944.733,605.732 944.742,605.732 944.751,605.732 944.76,605.731 944.77,605.731 944.779,605.731 944.788,605.731 944.797,605.731 944.806,605.731 944.815,605.731 944.825,605.73 944.834,605.73 944.843,605.73 944.852,605.73 944.861,605.73 944.871,605.73 944.88,605.73 944.889,605.73 944.898,605.729 944.907,605.729 944.917,605.729 944.926,605.729 944.935,605.729 944.944,605.729 944.953,605.729 944.963,605.728 944.972,605.728 944.981,605.728 944.99,605.728 944.999,605.728 945.008,605.728 945.018,605.728 945.027,605.727 945.036,605.727 945.045,605.727 945.054,605.727 945.064,605.727 945.073,605.727 945.082,605.727 945.091,605.726 945.1,605.726 945.11,605.726 945.119,605.726 945.128,605.726 945.137,605.726 945.146,605.726 945.155,605.725 945.165,605.725 945.174,605.725 945.183,605.725 945.192,605.725 945.201,605.725 945.211,605.725 945.22,605.724 945.229,605.724 945.238,605.724 945.247,605.724 945.257,605.724 945.266,605.724 945.275,605.724 945.284,605.723 945.293,605.723 945.303,605.723 945.312,605.723 945.321,605.723 945.33,605.723 945.339,605.723 945.348,605.722 945.358,605.722 945.367,605.722 945.376,605.722 945.385,605.722 945.394,605.722 945.404,605.722 945.413,605.721 945.422,605.721 945.431,605.721 945.44,605.721 945.45,605.721 945.459,605.721 945.468,605.721 945.477,605.721 945.486,605.72 945.496,605.72 945.505,605.72 945.514,605.72 945.523,605.72 945.532,605.72 945.541,605.72 945.551,605.719 945.56,605.719 945.569,605.719 945.578,605.719 945.587,605.719 945.597,605.719 945.606,605.719 945.615,605.718 945.624,605.718 945.633,605.718 945.643,605.718 945.652,605.718 945.661,605.718 945.67,605.718 945.679,605.717 945.688,605.717 945.698,605.717 945.707,605.717 945.716,605.717 945.725,605.717 945.734,605.717 945.744,605.716 945.753,605.716 945.762,605.716 945.771,605.716 945.78,605.716 945.79,605.716 945.799,605.716 945.808,605.715 945.817,605.715 945.826,605.715 945.836,605.715 945.845,605.715 945.854,605.715 945.863,605.715 945.872,605.714 945.881,605.714 945.891,605.714 945.9,605.714 945.909,605.714 945.918,605.714 945.927,605.714 945.937,605.714 945.946,605.713 945.955,605.713 945.964,605.713 945.973,605.713 945.983,605.713 945.992,605.713 946.001,605.713 946.01,605.712 946.019,605.712 946.028,605.712 946.038,605.712 946.047,605.712 946.056,605.712 946.065,605.712 946.074,605.711 946.084,605.711 946.093,605.711 946.102,605.711 946.111,605.711 946.12,605.711 946.13,605.711 946.139,605.71 946.148,605.71 946.157,605.71 946.166,605.71 946.176,605.71 946.185,605.71 946.194,605.71 946.203,605.709 946.212,605.709 946.221,605.709 946.231,605.709 946.24,605.709 946.249,605.709 946.258,605.709 946.267,605.708 946.277,605.708 946.286,605.708 946.295,605.708 946.304,605.708 946.313,605.708 946.323,605.708 946.332,605.708 946.341,605.707 946.35,605.707 946.359,605.707 946.368,605.707 946.378,605.707 946.387,605.707 946.396,605.707 946.405,605.706 946.414,605.706 946.424,605.706 946.433,605.706 946.442,605.706 946.451,605.706 946.46,605.706 946.47,605.705 946.479,605.705 946.488,605.705 946.497,605.705 946.506,605.705 946.516,605.705 946.525,605.705 946.534,605.704 946.543,605.704 946.552,605.704 946.561,605.704 946.571,605.704 946.58,605.704 946.589,605.704 946.598,605.703 946.607,605.703 946.617,605.703 946.626,605.703 946.635,605.703 946.644,605.703 946.653,605.703 946.663,605.702 946.672,605.702 946.681,605.702 946.69,605.702 946.699,605.702 946.708,605.702 946.718,605.702 946.727,605.702 946.736,605.701 946.745,605.701 946.754,605.701 946.764,605.701 946.773,605.701 946.782,605.701 946.791,605.701 946.8,605.7 946.81,605.7 946.819,605.7 946.828,605.7 946.837,605.7 946.846,605.7 946.856,605.7 946.865,605.699 946.874,605.699 946.883,605.699 946.892,605.699 946.901,605.699 946.911,605.699 946.92,605.699 946.929,605.698 946.938,605.698 946.947,605.698 946.957,605.698 946.966,605.698 946.975,605.698 946.984,605.698 946.993,605.697 947.003,605.697 947.012,605.697 947.021,605.697 947.03,605.697 947.039,605.697 947.048,605.697 947.058,605.697 947.067,605.696 947.076,605.696 947.085,605.696 947.094,605.696 947.104,605.696 947.113,605.696 947.122,605.696 947.131,605.695 947.14,605.695 947.15,605.695 947.159,605.695 947.168,605.695 947.177,605.695 947.186,605.695 947.196,605.694 947.205,605.694 947.214,605.694 947.223,605.694 947.232,605.694 947.241,605.694 947.251,605.694 947.26,605.693 947.269,605.693 947.278,605.693 947.287,605.693 947.297,605.693 947.306,605.693 947.315,605.693 947.324,605.692 947.333,605.692 947.343,605.692 947.352,605.692 947.361,605.692 947.37,605.692 947.379,605.692 947.388,605.692 947.398,605.691 947.407,605.691 947.416,605.691 947.425,605.691 947.434,605.691 947.444,605.691 947.453,605.691 947.462,605.69 947.471,605.69 947.48,605.69 947.49,605.69 947.499,605.69 947.508,605.69 947.517,605.69 947.526,605.689 947.536,605.689 947.545,605.689 947.554,605.689 947.563,605.689 947.572,605.689 947.581,605.689 947.591,605.688 947.6,605.688 947.609,605.688 947.618,605.688 947.627,605.688 947.637,605.688 947.646,605.688 947.655,605.687 947.664,605.687 947.673,605.687 947.683,605.687 947.692,605.687 947.701,605.687 947.71,605.687 947.719,605.687 947.729,605.686 947.738,605.686 947.747,605.686 947.756,605.686 947.765,605.686 947.774,605.686 947.784,605.686 947.793,605.685 947.802,605.685 947.811,605.685 947.82,605.685 947.83,605.685 947.839,605.685 947.848,605.685 947.857,605.684 947.866,605.684 947.876,605.684 947.885,605.684 947.894,605.684 947.903,605.684 947.912,605.684 947.921,605.683 947.931,605.683 947.94,605.683 947.949,605.683 947.958,605.683 947.967,605.683 947.977,605.683 947.986,605.683 947.995,605.682 948.004,605.682 948.013,605.682 948.023,605.682 948.032,605.682 948.041,605.682 948.05,605.682 948.059,605.681 948.069,605.681 948.078,605.681 948.087,605.681 948.096,605.681 948.105,605.681 948.114,605.681 948.124,605.68 948.133,605.68 948.142,605.68 948.151,605.68 948.16,605.68 948.17,605.68 948.179,605.68 948.188,605.679 948.197,605.679 948.206,605.679 948.216,605.679 948.225,605.679 948.234,605.679 948.243,605.679 948.252,605.678 948.261,605.678 948.271,605.678 948.28,605.678 948.289,605.678 948.298,605.678 948.307,605.678 948.317,605.678 948.326,605.677 948.335,605.677 948.344,605.677 948.353,605.677 948.363,605.677 948.372,605.677 948.381,605.677 948.39,605.676 948.399,605.676 948.409,605.676 948.418,605.676 948.427,605.676 948.436,605.676 948.445,605.676 948.454,605.675 948.464,605.675 948.473,605.675 948.482,605.675 948.491,605.675 948.5,605.675 948.51,605.675 948.519,605.674 948.528,605.674 948.537,605.674 948.546,605.674 948.556,605.674 948.565,605.674 948.574,605.674 948.583,605.674 948.592,605.673 948.601,605.673 948.611,605.673 948.62,605.673 948.629,605.673 948.638,605.673 948.647,605.673 948.657,605.672 948.666,605.672 948.675,605.672 948.684,605.672 948.693,605.672 948.703,605.672 948.712,605.672 948.721,605.671 948.73,605.671 948.739,605.671 948.749,605.671 948.758,605.671 948.767,605.671 948.776,605.671 948.785,605.671 948.794,605.67 948.804,605.67 948.813,605.67 948.822,605.67 948.831,605.67 948.84,605.67 948.85,605.67 948.859,605.669 948.868,605.669 948.877,605.669 948.886,605.669 948.896,605.669 948.905,605.669 948.914,605.669 948.923,605.668 948.932,605.668 948.941,605.668 948.951,605.668 948.96,605.668 948.969,605.668 948.978,605.668 948.987,605.667 948.997,605.667 949.006,605.667 949.015,605.667 949.024,605.667 949.033,605.667 949.043,605.667 949.052,605.667 949.061,605.666 949.07,605.666 949.079,605.666 949.089,605.666 949.098,605.666 949.107,605.666 949.116,605.666 949.125,605.665 949.134,605.665 949.144,605.665 949.153,605.665 949.162,605.665 949.171,605.665 949.18,605.665 949.19,605.664 949.199,605.664 949.208,605.664 949.217,605.664 949.226,605.664 949.236,605.664 949.245,605.664 949.254,605.663 949.263,605.663 949.272,605.663 949.281,605.663 949.291,605.663 949.3,605.663 949.309,605.663 949.318,605.663 949.327,605.662 949.337,605.662 949.346,605.662 949.355,605.662 949.364,605.662 949.373,605.662 949.383,605.662 949.392,605.661 949.401,605.661 949.41,605.661 949.419,605.661 949.429,605.661 949.438,605.661 949.447,605.661 949.456,605.66 949.465,605.66 949.474,605.66 949.484,605.66 949.493,605.66 949.502,605.66 949.511,605.66 949.52,605.66 949.53,605.659 949.539,605.659 949.548,605.659 949.557,605.659 949.566,605.659 949.576,605.659 949.585,605.659 949.594,605.658 949.603,605.658 949.612,605.658 949.621,605.658 949.631,605.658 949.64,605.658 949.649,605.658 949.658,605.657 949.667,605.657 949.677,605.657 949.686,605.657 949.695,605.657 949.704,605.657 949.713,605.657 949.723,605.656 949.732,605.656 949.741,605.656 949.75,605.656 949.759,605.656 949.769,605.656 949.778,605.656 949.787,605.656 949.796,605.655 949.805,605.655 949.814,605.655 949.824,605.655 949.833,605.655 949.842,605.655 949.851,605.655 949.86,605.654 949.87,605.654 949.879,605.654 949.888,605.654 949.897,605.654 949.906,605.654 949.916,605.654 949.925,605.653 949.934,605.653 949.943,605.653 949.952,605.653 949.961,605.653 949.971,605.653 949.98,605.653 949.989,605.653 949.998,605.652 950.007,605.652 950.017,605.652 950.026,605.652 950.035,605.652 950.044,605.652 950.053,605.652 950.063,605.651 950.072,605.651 950.081,605.651 950.09,605.651 950.099,605.651 950.109,605.651 950.118,605.651 950.127,605.65 950.136,605.65 950.145,605.65 950.154,605.65 950.164,605.65 950.173,605.65 950.182,605.65 950.191,605.65 950.2,605.649 950.21,605.649 950.219,605.649 950.228,605.649 950.237,605.649 950.246,605.649 950.256,605.649 950.265,605.648 950.274,605.648 950.283,605.648 950.292,605.648 950.302,605.648 950.311,605.648 950.32,605.648 950.329,605.647 950.338,605.647 950.347,605.647 950.357,605.647 950.366,605.647 950.375,605.647 950.384,605.647 950.393,605.647 950.403,605.646 950.412,605.646 950.421,605.646 950.43,605.646 950.439,605.646 950.449,605.646 950.458,605.646 950.467,605.645 950.476,605.645 950.485,605.645 950.494,605.645 950.504,605.645 950.513,605.645 950.522,605.645 950.531,605.644 950.54,605.644 950.55,605.644 950.559,605.644 950.568,605.644 950.577,605.644 950.586,605.644 950.596,605.644 950.605,605.643 950.614,605.643 950.623,605.643 950.632,605.643 950.642,605.643 950.651,605.643 950.66,605.643 950.669,605.642 950.678,605.642 950.687,605.642 950.697,605.642 950.706,605.642 950.715,605.642 950.724,605.642 950.733,605.641 950.743,605.641 950.752,605.641 950.761,605.641 950.77,605.641 950.779,605.641 950.789,605.641 950.798,605.641 950.807,605.64 950.816,605.64 950.825,605.64 950.834,605.64 950.844,605.64 950.853,605.64 950.862,605.64 950.871,605.639 950.88,605.639 950.89,605.639 950.899,605.639 950.908,605.639 950.917,605.639 950.926,605.639 950.936,605.638 950.945,605.638 950.954,605.638 950.963,605.638 950.972,605.638 950.982,605.638 950.991,605.638 951,605.638 951.009,605.637 951.018,605.637 951.027,605.637 951.037,605.637 951.046,605.637 951.055,605.637 951.064,605.637 951.073,605.636 951.083,605.636 951.092,605.636 951.101,605.636 951.11,605.636 951.119,605.636 951.129,605.636 951.138,605.635 951.147,605.635 951.156,605.635 951.165,605.635 951.174,605.635 951.184,605.635 951.193,605.635 951.202,605.635 951.211,605.634 951.22,605.634 951.23,605.634 951.239,605.634 951.248,605.634 951.257,605.634 951.266,605.634 951.276,605.633 951.285,605.633 951.294,605.633 951.303,605.633 951.312,605.633 951.322,605.633 951.331,605.633 951.34,605.632 951.349,605.632 951.358,605.632 951.367,605.632 951.377,605.632 951.386,605.632 951.395,605.632 951.404,605.632 951.413,605.631 951.423,605.631 951.432,605.631 951.441,605.631 951.45,605.631 951.459,605.631 951.469,605.631 951.478,605.63 951.487,605.63 951.496,605.63 951.505,605.63 951.514,605.63 951.524,605.63 951.533,605.63 951.542,605.63 951.551,605.629 951.56,605.629 951.57,605.629 951.579,605.629 951.588,605.629 951.597,605.629 951.606,605.629 951.616,605.628 951.625,605.628 951.634,605.628 951.643,605.628 951.652,605.628 951.662,605.628 951.671,605.628 951.68,605.627 951.689,605.627 951.698,605.627 951.707,605.627 951.717,605.627 951.726,605.627 951.735,605.627 951.744,605.627 951.753,605.626 951.763,605.626 951.772,605.626 951.781,605.626 951.79,605.626 951.799,605.626 951.809,605.626 951.818,605.625 951.827,605.625 951.836,605.625 951.845,605.625 951.854,605.625 951.864,605.625 951.873,605.625 951.882,605.624 951.891,605.624 951.9,605.624 951.91,605.624 951.919,605.624 951.928,605.624 951.937,605.624 951.946,605.624 951.956,605.623 951.965,605.623 951.974,605.623 951.983,605.623 951.992,605.623 952.002,605.623 952.011,605.623 952.02,605.622 952.029,605.622 952.038,605.622 952.047,605.622 952.057,605.622 952.066,605.622 952.075,605.622 952.084,605.622 952.093,605.621 952.103,605.621 952.112,605.621 952.121,605.621 952.13,605.621 952.139,605.621 952.149,605.621 952.158,605.62 952.167,605.62 952.176,605.62 952.185,605.62 952.194,605.62 952.204,605.62 952.213,605.62 952.222,605.619 952.231,605.619 952.24,605.619 952.25,605.619 952.259,605.619 952.268,605.619 952.277,605.619 952.286,605.619 952.296,605.618 952.305,605.618 952.314,605.618 952.323,605.618 952.332,605.618 952.342,605.618 952.351,605.618 952.36,605.617 952.369,605.617 952.378,605.617 952.387,605.617 952.397,605.617 952.406,605.617 952.415,605.617 952.424,605.617 952.433,605.616 952.443,605.616 952.452,605.616 952.461,605.616 952.47,605.616 952.479,605.616 952.489,605.616 952.498,605.615 952.507,605.615 952.516,605.615 952.525,605.615 952.534,605.615 952.544,605.615 952.553,605.615 952.562,605.614 952.571,605.614 952.58,605.614 952.59,605.614 952.599,605.614 952.608,605.614 952.617,605.614 952.626,605.614 952.636,605.613 952.645,605.613 952.654,605.613 952.663,605.613 952.672,605.613 952.682,605.613 952.691,605.613 952.7,605.612 952.709,605.612 952.718,605.612 952.727,605.612 952.737,605.612 952.746,605.612 952.755,605.612 952.764,605.612 952.773,605.611 952.783,605.611 952.792,605.611 952.801,605.611 952.81,605.611 952.819,605.611 952.829,605.611 952.838,605.61 952.847,605.61 952.856,605.61 952.865,605.61 952.875,605.61 952.884,605.61 952.893,605.61 952.902,605.61 952.911,605.609 952.92,605.609 952.93,605.609 952.939,605.609 952.948,605.609 952.957,605.609 952.966,605.609 952.976,605.608 952.985,605.608 952.994,605.608 953.003,605.608 953.012,605.608 953.022,605.608 953.031,605.608 953.04,605.607 953.049,605.607 953.058,605.607 953.067,605.607 953.077,605.607 953.086,605.607 953.095,605.607 953.104,605.607 953.113,605.606 953.123,605.606 953.132,605.606 953.141,605.606 953.15,605.606 953.159,605.606 953.169,605.606 953.178,605.605 953.187,605.605 953.196,605.605 953.205,605.605 953.215,605.605 953.224,605.605 953.233,605.605 953.242,605.605 953.251,605.604 953.26,605.604 953.27,605.604 953.279,605.604 953.288,605.604 953.297,605.604 953.306,605.604 953.316,605.603 953.325,605.603 953.334,605.603 953.343,605.603 953.352,605.603 953.362,605.603 953.371,605.603 953.38,605.603 953.389,605.602 953.398,605.602 953.407,605.602 953.417,605.602 953.426,605.602 953.435,605.602 953.444,605.602 953.453,605.601 953.463,605.601 953.472,605.601 953.481,605.601 953.49,605.601 953.499,605.601 953.509,605.601 953.518,605.6 953.527,605.6 953.536,605.6 953.545,605.6 953.555,605.6 953.564,605.6 953.573,605.6 953.582,605.6 953.591,605.599 953.6,605.599 953.61,605.599 953.619,605.599 953.628,605.599 953.637,605.599 953.646,605.599 953.656,605.598 953.665,605.598 953.674,605.598 953.683,605.598 953.692,605.598 953.702,605.598 953.711,605.598 953.72,605.598 953.729,605.597 953.738,605.597 953.747,605.597 953.757,605.597 953.766,605.597 953.775,605.597 953.784,605.597 953.793,605.596 953.803,605.596 953.812,605.596 953.821,605.596 953.83,605.596 953.839,605.596 953.849,605.596 953.858,605.596 953.867,605.595 953.876,605.595 953.885,605.595 953.895,605.595 953.904,605.595 953.913,605.595 953.922,605.595 953.931,605.594 953.94,605.594 953.95,605.594 953.959,605.594 953.968,605.594 953.977,605.594 953.986,605.594 953.996,605.594 954.005,605.593 954.014,605.593 954.023,605.593 954.032,605.593 954.042,605.593 954.051,605.593 954.06,605.593 954.069,605.592 954.078,605.592 954.087,605.592 954.097,605.592 954.106,605.592 954.115,605.592 954.124,605.592 954.133,605.592 954.143,605.591 954.152,605.591 954.161,605.591 954.17,605.591 954.179,605.591 954.189,605.591 954.198,605.591 954.207,605.59 954.216,605.59 954.225,605.59 954.235,605.59 954.244,605.59 954.253,605.59 954.262,605.59 954.271,605.59 954.28,605.589 954.29,605.589 954.299,605.589 954.308,605.589 954.317,605.589 954.326,605.589 954.336,605.589 954.345,605.588 954.354,605.588 954.363,605.588 954.372,605.588 954.382,605.588 954.391,605.588 954.4,605.588 954.409,605.588 954.418,605.587 954.427,605.587 954.437,605.587 954.446,605.587 954.455,605.587 954.464,605.587 954.473,605.587 954.483,605.586 954.492,605.586 954.501,605.586 954.51,605.586 954.519,605.586 954.529,605.586 954.538,605.586 954.547,605.586 954.556,605.585 954.565,605.585 954.575,605.585 954.584,605.585 954.593,605.585 954.602,605.585 954.611,605.585 954.62,605.584 954.63,605.584 954.639,605.584 954.648,605.584 954.657,605.584 954.666,605.584 954.676,605.584 954.685,605.584 954.694,605.583 954.703,605.583 954.712,605.583 954.722,605.583 954.731,605.583 954.74,605.583 954.749,605.583 954.758,605.582 954.767,605.582 954.777,605.582 954.786,605.582 954.795,605.582 954.804,605.582 954.813,605.582 954.823,605.582 954.832,605.581 954.841,605.581 954.85,605.581 954.859,605.581 954.869,605.581 954.878,605.581 954.887,605.581 954.896,605.58 954.905,605.58 954.915,605.58 954.924,605.58 954.933,605.58 954.942,605.58 954.951,605.58 954.96,605.58 954.97,605.579 954.979,605.579 954.988,605.579 954.997,605.579 955.006,605.579 955.016,605.579 955.025,605.579 955.034,605.578 955.043,605.578 955.052,605.578 955.062,605.578 955.071,605.578 955.08,605.578 955.089,605.578 955.098,605.578 955.108,605.577 955.117,605.577 955.126,605.577 955.135,605.577 955.144,605.577 955.153,605.577 955.163,605.577 955.172,605.576 955.181,605.576 955.19,605.576 955.199,605.576 955.209,605.576 955.218,605.576 955.227,605.576 955.236,605.576 955.245,605.575 955.255,605.575 955.264,605.575 955.273,605.575 955.282,605.575 955.291,605.575 955.3,605.575 955.31,605.574 955.319,605.574 955.328,605.574 955.337,605.574 955.346,605.574 955.356,605.574 955.365,605.574 955.374,605.574 955.383,605.573 955.392,605.573 955.402,605.573 955.411,605.573 955.42,605.573 955.429,605.573 955.438,605.573 955.448,605.572 955.457,605.572 955.466,605.572 955.475,605.572 955.484,605.572 955.493,605.572 955.503,605.572 955.512,605.572 955.521,605.571 955.53,605.571 955.539,605.571 955.549,605.571 955.558,605.571 955.567,605.571 955.576,605.571 955.585,605.57 955.595,605.57 955.604,605.57 955.613,605.57 955.622,605.57 955.631,605.57 955.64,605.57 955.65,605.57 955.659,605.569 955.668,605.569 955.677,605.569 955.686,605.569 955.696,605.569 955.705,605.569 955.714,605.569 955.723,605.569 955.732,605.568 955.742,605.568 955.751,605.568 955.76,605.568 955.769,605.568 955.778,605.568 955.788,605.568 955.797,605.567 955.806,605.567 955.815,605.567 955.824,605.567 955.833,605.567 955.843,605.567 955.852,605.567 955.861,605.567 955.87,605.566 955.879,605.566 955.889,605.566 955.898,605.566 955.907,605.566 955.916,605.566 955.925,605.566 955.935,605.565 955.944,605.565 955.953,605.565 955.962,605.565 955.971,605.565 955.98,605.565 955.99,605.565 955.999,605.565 956.008,605.564 956.017,605.564 956.026,605.564 956.036,605.564 956.045,605.564 956.054,605.564 956.063,605.564 956.072,605.563 956.082,605.563 956.091,605.563 956.1,605.563 956.109,605.563 956.118,605.563 956.128,605.563 956.137,605.563 956.146,605.562 956.155,605.562 956.164,605.562 956.173,605.562 956.183,605.562 956.192,605.562 956.201,605.562 956.21,605.561 956.219,605.561 956.229,605.561 956.238,605.561 956.247,605.561 956.256,605.561 956.265,605.561 956.275,605.561 956.284,605.56 956.293,605.56 956.302,605.56 956.311,605.56 956.32,605.56 956.33,605.56 956.339,605.56 956.348,605.56 956.357,605.559 956.366,605.559 956.376,605.559 956.385,605.559 956.394,605.559 956.403,605.559 956.412,605.559 956.422,605.558 956.431,605.558 956.44,605.558 956.449,605.558 956.458,605.558 956.468,605.558 956.477,605.558 956.486,605.558 956.495,605.557 956.504,605.557 956.513,605.557 956.523,605.557 956.532,605.557 956.541,605.557 956.55,605.557 956.559,605.556 956.569,605.556 956.578,605.556 956.587,605.556 956.596,605.556 956.605,605.556 956.615,605.556 956.624,605.556 956.633,605.555 956.642,605.555 956.651,605.555 956.66,605.555 956.67,605.555 956.679,605.555 956.688,605.555 956.697,605.555 956.706,605.554 956.716,605.554 956.725,605.554 956.734,605.554 956.743,605.554 956.752,605.554 956.762,605.554 956.771,605.553 956.78,605.553 956.789,605.553 956.798,605.553 956.808,605.553 956.817,605.553 956.826,605.553 956.835,605.553 956.844,605.552 956.853,605.552 956.863,605.552 956.872,605.552 956.881,605.552 956.89,605.552 956.899,605.552 956.909,605.551 956.918,605.551 956.927,605.551 956.936,605.551 956.945,605.551 956.955,605.551 956.964,605.551 956.973,605.551 956.982,605.55 956.991,605.55 957,605.55 957.01,605.55 957.019,605.55 957.028,605.55 957.037,605.55 957.046,605.549 957.056,605.549 957.065,605.549 957.074,605.549 957.083,605.549 957.092,605.549 957.102,605.549 957.111,605.549 957.12,605.548 957.129,605.548 957.138,605.548 957.148,605.548 957.157,605.548 957.166,605.548 957.175,605.548 957.184,605.548 957.193,605.547 957.203,605.547 957.212,605.547 957.221,605.547 957.23,605.547 957.239,605.547 957.249,605.547 957.258,605.546 957.267,605.546 957.276,605.546 957.285,605.546 957.295,605.546 957.304,605.546 957.313,605.546 957.322,605.546 957.331,605.545 957.34,605.545 957.35,605.545 957.359,605.545 957.368,605.545 957.377,605.545 957.386,605.545 957.396,605.545 957.405,605.544 957.414,605.544 957.423,605.544 957.432,605.544 957.442,605.544 957.451,605.544 957.46,605.544 957.469,605.543 957.478,605.543 957.488,605.543 957.497,605.543 957.506,605.543 957.515,605.543 957.524,605.543 957.533,605.543 957.543,605.542 957.552,605.542 957.561,605.542 957.57,605.542 957.579,605.542 957.589,605.542 957.598,605.542 957.607,605.541 957.616,605.541 957.625,605.541 957.635,605.541 957.644,605.541 957.653,605.541 957.662,605.541 957.671,605.541 957.681,605.54 957.69,605.54 957.699,605.54 957.708,605.54 957.717,605.54 957.726,605.54 957.736,605.54 957.745,605.54 957.754,605.539 957.763,605.539 957.772,605.539 957.782,605.539 957.791,605.539 957.8,605.539 957.809,605.539 957.818,605.538 957.828,605.538 957.837,605.538 957.846,605.538 957.855,605.538 957.864,605.538 957.873,605.538 957.883,605.538 957.892,605.537 957.901,605.537 957.91,605.537 957.919,605.537 957.929,605.537 957.938,605.537 957.947,605.537 957.956,605.537 957.965,605.536 957.975,605.536 957.984,605.536 957.993,605.536 958.002,605.536 958.011,605.536 958.021,605.536 958.03,605.535 958.039,605.535 958.048,605.535 958.057,605.535 958.066,605.535 958.076,605.535 958.085,605.535 958.094,605.535 958.103,605.534 958.112,605.534 958.122,605.534 958.131,605.534 958.14,605.534 958.149,605.534 958.158,605.534 958.168,605.534 958.177,605.533 958.186,605.533 958.195,605.533 958.204,605.533 958.213,605.533 958.223,605.533 958.232,605.533 958.241,605.532 958.25,605.532 958.259,605.532 958.269,605.532 958.278,605.532 958.287,605.532 958.296,605.532 958.305,605.532 958.315,605.531 958.324,605.531 958.333,605.531 958.342,605.531 958.351,605.531 958.361,605.531 958.37,605.531 958.379,605.531 958.388,605.53 958.397,605.53 958.406,605.53 958.416,605.53 958.425,605.53 958.434,605.53 958.443,605.53 958.452,605.529 958.462,605.529 958.471,605.529 958.48,605.529 958.489,605.529 958.498,605.529 958.508,605.529 958.517,605.529 958.526,605.528 958.535,605.528 958.544,605.528 958.553,605.528 958.563,605.528 958.572,605.528 958.581,605.528 958.59,605.528 958.599,605.527 958.609,605.527 958.618,605.527 958.627,605.527 958.636,605.527 958.645,605.527 958.655,605.527 958.664,605.526 958.673,605.526 958.682,605.526 958.691,605.526 958.701,605.526 958.71,605.526 958.719,605.526 958.728,605.526 958.737,605.525 958.746,605.525 958.756,605.525 958.765,605.525 958.774,605.525 958.783,605.525 958.792,605.525 958.802,605.525 958.811,605.524 958.82,605.524 958.829,605.524 958.838,605.524 958.848,605.524 958.857,605.524 958.866,605.524 958.875,605.523 958.884,605.523 958.893,605.523 958.903,605.523 958.912,605.523 958.921,605.523 958.93,605.523 958.939,605.523 958.949,605.522 958.958,605.522 958.967,605.522 958.976,605.522 958.985,605.522 958.995,605.522 959.004,605.522 959.013,605.522 959.022,605.521 959.031,605.521 959.041,605.521 959.05,605.521 959.059,605.521 959.068,605.521 959.077,605.521 959.086,605.52 959.096,605.52 959.105,605.52 959.114,605.52 959.123,605.52 959.132,605.52 959.142,605.52 959.151,605.52 959.16,605.519 959.169,605.519 959.178,605.519 959.188,605.519 959.197,605.519 959.206,605.519 959.215,605.519 959.224,605.519 959.233,605.518 959.243,605.518 959.252,605.518 959.261,605.518 959.27,605.518 959.279,605.518 959.289,605.518 959.298,605.517 959.307,605.517 959.316,605.517 959.325,605.517 959.335,605.517 959.344,605.517 959.353,605.517 959.362,605.517 959.371,605.516 959.381,605.516 959.39,605.516 959.399,605.516 959.408,605.516 959.417,605.516 959.426,605.516 959.436,605.516 959.445,605.515 959.454,605.515 959.463,605.515 959.472,605.515 959.482,605.515 959.491,605.515 959.5,605.515 959.509,605.515 959.518,605.514 959.528,605.514 959.537,605.514 959.546,605.514 959.555,605.514 959.564,605.514 959.573,605.514 959.583,605.513 959.592,605.513 959.601,605.513 959.61,605.513 959.619,605.513 959.629,605.513 959.638,605.513 959.647,605.513 959.656,605.512 959.665,605.512 959.675,605.512 959.684,605.512 959.693,605.512 959.702,605.512 959.711,605.512 959.721,605.512 959.73,605.511 959.739,605.511 959.748,605.511 959.757,605.511 959.766,605.511 959.776,605.511 959.785,605.511 959.794,605.51 959.803,605.51 959.812,605.51 959.822,605.51 959.831,605.51 959.84,605.51 959.849,605.51 959.858,605.51 959.868,605.509 959.877,605.509 959.886,605.509 959.895,605.509 959.904,605.509 959.913,605.509 959.923,605.509 959.932,605.509 959.941,605.508 959.95,605.508 959.959,605.508 959.969,605.508 959.978,605.508 959.987,605.508 959.996,605.508 960.005,605.508 960.015,605.507 960.024,605.507 960.033,605.507 960.042,605.507 960.051,605.507 960.061,605.507 960.07,605.507 960.079,605.506 960.088,605.506 960.097,605.506 960.106,605.506 960.116,605.506 960.125,605.506 960.134,605.506 960.143,605.506 960.152,605.505 960.162,605.505 960.171,605.505 960.18,605.505 960.189,605.505 960.198,605.505 960.208,605.505 960.217,605.505 960.226,605.504 960.235,605.504 960.244,605.504 960.254,605.504 960.263,605.504 960.272,605.504 960.281,605.504 960.29,605.504 960.299,605.503 960.309,605.503 960.318,605.503 960.327,605.503 960.336,605.503 960.345,605.503 960.355,605.503 960.364,605.502 960.373,605.502 960.382,605.502 960.391,605.502 960.401,605.502 960.41,605.502 960.419,605.502 960.428,605.502 960.437,605.501 960.446,605.501 960.456,605.501 960.465,605.501 960.474,605.501 960.483,605.501 960.492,605.501 960.502,605.501 960.511,605.5 960.52,605.5 960.529,605.5 960.538,605.5 960.548,605.5 960.557,605.5 960.566,605.5 960.575,605.5 960.584,605.499 960.594,605.499 960.603,605.499 960.612,605.499 960.621,605.499 960.63,605.499 960.639,605.499 960.649,605.498 960.658,605.498 960.667,605.498 960.676,605.498 960.685,605.498 960.695,605.498 960.704,605.498 960.713,605.498 960.722,605.497 960.731,605.497 960.741,605.497 960.75,605.497 960.759,605.497 960.768,605.497 960.777,605.497 960.786,605.497 960.796,605.496 960.805,605.496 960.814,605.496 960.823,605.496 960.832,605.496 960.842,605.496 960.851,605.496 960.86,605.496 960.869,605.495 960.878,605.495 960.888,605.495 960.897,605.495 960.906,605.495 960.915,605.495 960.924,605.495 960.934,605.494 960.943,605.494 960.952,605.494 960.961,605.494 960.97,605.494 960.979,605.494 960.989,605.494 960.998,605.494 961.007,605.493 961.016,605.493 961.025,605.493 961.035,605.493 961.044,605.493 961.053,605.493 961.062,605.493 961.071,605.493 961.081,605.492 961.09,605.492 961.099,605.492 961.108,605.492 961.117,605.492 961.126,605.492 961.136,605.492 961.145,605.492 961.154,605.491 961.163,605.491 961.172,605.491 961.182,605.491 961.191,605.491 961.2,605.491 961.209,605.491 961.218,605.491 961.228,605.49 961.237,605.49 961.246,605.49 961.255,605.49 961.264,605.49 961.274,605.49 961.283,605.49 961.292,605.489 961.301,605.489 961.31,605.489 961.319,605.489 961.329,605.489 961.338,605.489 961.347,605.489 961.356,605.489 961.365,605.488 961.375,605.488 961.384,605.488 961.393,605.488 961.402,605.488 961.411,605.488 961.421,605.488 961.43,605.488 961.439,605.487 961.448,605.487 961.457,605.487 961.466,605.487 961.476,605.487 961.485,605.487 961.494,605.487 961.503,605.487 961.512,605.486 961.522,605.486 961.531,605.486 961.54,605.486 961.549,605.486 961.558,605.486 961.568,605.486 961.577,605.486 961.586,605.485 961.595,605.485 961.604,605.485 961.614,605.485 961.623,605.485 961.632,605.485 961.641,605.485 961.65,605.484 961.659,605.484 961.669,605.484 961.678,605.484 961.687,605.484 961.696,605.484 961.705,605.484 961.715,605.484 961.724,605.483 961.733,605.483 961.742,605.483 961.751,605.483 961.761,605.483 961.77,605.483 961.779,605.483 961.788,605.483 961.797,605.482 961.806,605.482 961.816,605.482 961.825,605.482 961.834,605.482 961.843,605.482 961.852,605.482 961.862,605.482 961.871,605.481 961.88,605.481 961.889,605.481 961.898,605.481 961.908,605.481 961.917,605.481 961.926,605.481 961.935,605.481 961.944,605.48 961.954,605.48 961.963,605.48 961.972,605.48 961.981,605.48 961.99,605.48 961.999,605.48 962.009,605.48 962.018,605.479 962.027,605.479 962.036,605.479 962.045,605.479 962.055,605.479 962.064,605.479 962.073,605.479 962.082,605.478 962.091,605.478 962.101,605.478 962.11,605.478 962.119,605.478 962.128,605.478 962.137,605.478 962.146,605.478 962.156,605.477 962.165,605.477 962.174,605.477 962.183,605.477 962.192,605.477 962.202,605.477 962.211,605.477 962.22,605.477 962.229,605.476 962.238,605.476 962.248,605.476 962.257,605.476 962.266,605.476 962.275,605.476 962.284,605.476 962.294,605.476 962.303,605.475 962.312,605.475 962.321,605.475 962.33,605.475 962.339,605.475 962.349,605.475 962.358,605.475 962.367,605.475 962.376,605.474 962.385,605.474 962.395,605.474 962.404,605.474 962.413,605.474 962.422,605.474 962.431,605.474 962.441,605.474 962.45,605.473 962.459,605.473 962.468,605.473 962.477,605.473 962.487,605.473 962.496,605.473 962.505,605.473 962.514,605.472 962.523,605.472 962.532,605.472 962.542,605.472 962.551,605.472 962.56,605.472 962.569,605.472 962.578,605.472 962.588,605.471 962.597,605.471 962.606,605.471 962.615,605.471 962.624,605.471 962.634,605.471 962.643,605.471 962.652,605.471 962.661,605.47 962.67,605.47 962.679,605.47 962.689,605.47 962.698,605.47 962.707,605.47 962.716,605.47 962.725,605.47 962.735,605.469 962.744,605.469 962.753,605.469 962.762,605.469 962.771,605.469 962.781,605.469 962.79,605.469 962.799,605.469 962.808,605.468 962.817,605.468 962.827,605.468 962.836,605.468 962.845,605.468 962.854,605.468 962.863,605.468 962.872,605.468 962.882,605.467 962.891,605.467 962.9,605.467 962.909,605.467 962.918,605.467 962.928,605.467 962.937,605.467 962.946,605.467 962.955,605.466 962.964,605.466 962.974,605.466 962.983,605.466 962.992,605.466 963.001,605.466 963.01,605.466 963.019,605.465 963.029,605.465 963.038,605.465 963.047,605.465 963.056,605.465 963.065,605.465 963.075,605.465 963.084,605.465 963.093,605.464 963.102,605.464 963.111,605.464 963.121,605.464 963.13,605.464 963.139,605.464 963.148,605.464 963.157,605.464 963.167,605.463 963.176,605.463 963.185,605.463 963.194,605.463 963.203,605.463 963.212,605.463 963.222,605.463 963.231,605.463 963.24,605.462 963.249,605.462 963.258,605.462 963.268,605.462 963.277,605.462 963.286,605.462 963.295,605.462 963.304,605.462 963.314,605.461 963.323,605.461 963.332,605.461 963.341,605.461 963.35,605.461 963.359,605.461 963.369,605.461 963.378,605.461 963.387,605.46 963.396,605.46 963.405,605.46 963.415,605.46 963.424,605.46 963.433,605.46 963.442,605.46 963.451,605.46 963.461,605.459 963.47,605.459 963.479,605.459 963.488,605.459 963.497,605.459 963.507,605.459 963.516,605.459 963.525,605.459 963.534,605.458 963.543,605.458 963.552,605.458 963.562,605.458 963.571,605.458 963.58,605.458 963.589,605.458 963.598,605.457 963.608,605.457 963.617,605.457 963.626,605.457 963.635,605.457 963.644,605.457 963.654,605.457 963.663,605.457 963.672,605.456 963.681,605.456 963.69,605.456 963.699,605.456 963.709,605.456 963.718,605.456 963.727,605.456 963.736,605.456 963.745,605.455 963.755,605.455 963.764,605.455 963.773,605.455 963.782,605.455 963.791,605.455 963.801,605.455 963.81,605.455 963.819,605.454 963.828,605.454 963.837,605.454 963.847,605.454 963.856,605.454 963.865,605.454 963.874,605.454 963.883,605.454 963.892,605.453 963.902,605.453 963.911,605.453 963.92,605.453 963.929,605.453 963.938,605.453 963.948,605.453 963.957,605.453 963.966,605.452 963.975,605.452 963.984,605.452 963.994,605.452 964.003,605.452 964.012,605.452 964.021,605.452 964.03,605.452 964.039,605.451 964.049,605.451 964.058,605.451 964.067,605.451 964.076,605.451 964.085,605.451 964.095,605.451 964.104,605.451 964.113,605.45 964.122,605.45 964.131,605.45 964.141,605.45 964.15,605.45 964.159,605.45 964.168,605.45 964.177,605.45 964.187,605.449 964.196,605.449 964.205,605.449 964.214,605.449 964.223,605.449 964.232,605.449 964.242,605.449 964.251,605.449 964.26,605.448 964.269,605.448 964.278,605.448 964.288,605.448 964.297,605.448 964.306,605.448 964.315,605.448 964.324,605.448 964.334,605.447 964.343,605.447 964.352,605.447 964.361,605.447 964.37,605.447 964.379,605.447 964.389,605.447 964.398,605.447 964.407,605.446 964.416,605.446 964.425,605.446 964.435,605.446 964.444,605.446 964.453,605.446 964.462,605.446 964.471,605.446 964.481,605.445 964.49,605.445 964.499,605.445 964.508,605.445 964.517,605.445 964.527,605.445 964.536,605.445 964.545,605.444 964.554,605.444 964.563,605.444 964.572,605.444 964.582,605.444 964.591,605.444 964.6,605.444 964.609,605.444 964.618,605.443 964.628,605.443 964.637,605.443 964.646,605.443 964.655,605.443 964.664,605.443 964.674,605.443 964.683,605.443 964.692,605.442 964.701,605.442 964.71,605.442 964.719,605.442 964.729,605.442 964.738,605.442 964.747,605.442 964.756,605.442 964.765,605.441 964.775,605.441 964.784,605.441 964.793,605.441 964.802,605.441 964.811,605.441 964.821,605.441 964.83,605.441 964.839,605.44 964.848,605.44 964.857,605.44 964.867,605.44 964.876,605.44 964.885,605.44 964.894,605.44 964.903,605.44 964.912,605.439 964.922,605.439 964.931,605.439 964.94,605.439 964.949,605.439 964.958,605.439 964.968,605.439 964.977,605.439 964.986,605.438 964.995,605.438 965.004,605.438 965.014,605.438 965.023,605.438 965.032,605.438 965.041,605.438 965.05,605.438 965.06,605.437 965.069,605.437 965.078,605.437 965.087,605.437 965.096,605.437 965.105,605.437 965.115,605.437 965.124,605.437 965.133,605.436 965.142,605.436 965.151,605.436 965.161,605.436 965.17,605.436 965.179,605.436 965.188,605.436 965.197,605.436 965.207,605.435 965.216,605.435 965.225,605.435 965.234,605.435 965.243,605.435 965.252,605.435 965.262,605.435 965.271,605.435 965.28,605.434 965.289,605.434 965.298,605.434 965.308,605.434 965.317,605.434 965.326,605.434 965.335,605.434 965.344,605.434 965.354,605.433 965.363,605.433 965.372,605.433 965.381,605.433 965.39,605.433 965.4,605.433 965.409,605.433 965.418,605.433 965.427,605.432 965.436,605.432 965.445,605.432 965.455,605.432 965.464,605.432 965.473,605.432 965.482,605.432 965.491,605.432 965.501,605.431 965.51,605.431 965.519,605.431 965.528,605.431 965.537,605.431 965.547,605.431 965.556,605.431 965.565,605.431 965.574,605.43 965.583,605.43 965.592,605.43 965.602,605.43 965.611,605.43 965.62,605.43 965.629,605.43 965.638,605.43 965.648,605.429 965.657,605.429 965.666,605.429 965.675,605.429 965.684,605.429 965.694,605.429 965.703,605.429 965.712,605.429 965.721,605.428 965.73,605.428 965.74,605.428 965.749,605.428 965.758,605.428 965.767,605.428 965.776,605.428 965.785,605.428 965.795,605.427 965.804,605.427 965.813,605.427 965.822,605.427 965.831,605.427 965.841,605.427 965.85,605.427 965.859,605.427 965.868,605.426 965.877,605.426 965.887,605.426 965.896,605.426 965.905,605.426 965.914,605.426 965.923,605.426 965.932,605.426 965.942,605.425 965.951,605.425 965.96,605.425 965.969,605.425 965.978,605.425 965.988,605.425 965.997,605.425 966.006,605.425 966.015,605.424 966.024,605.424 966.034,605.424 966.043,605.424 966.052,605.424 966.061,605.424 966.07,605.424 966.08,605.424 966.089,605.423 966.098,605.423 966.107,605.423 966.116,605.423 966.125,605.423 966.135,605.423 966.144,605.423 966.153,605.423 966.162,605.422 966.171,605.422 966.181,605.422 966.19,605.422 966.199,605.422 966.208,605.422 966.217,605.422 966.227,605.422 966.236,605.421 966.245,605.421 966.254,605.421 966.263,605.421 966.272,605.421 966.282,605.421 966.291,605.421 966.3,605.421 966.309,605.42 966.318,605.42 966.328,605.42 966.337,605.42 966.346,605.42 966.355,605.42 966.364,605.42 966.374,605.42 966.383,605.419 966.392,605.419 966.401,605.419 966.41,605.419 966.42,605.419 966.429,605.419 966.438,605.419 966.447,605.419 966.456,605.418 966.465,605.418 966.475,605.418 966.484,605.418 966.493,605.418 966.502,605.418 966.511,605.418 966.521,605.418 966.53,605.417 966.539,605.417 966.548,605.417 966.557,605.417 966.567,605.417 966.576,605.417 966.585,605.417 966.594,605.417 966.603,605.416 966.612,605.416 966.622,605.416 966.631,605.416 966.64,605.416 966.649,605.416 966.658,605.416 966.668,605.416 966.677,605.415 966.686,605.415 966.695,605.415 966.704,605.415 966.714,605.415 966.723,605.415 966.732,605.415 966.741,605.415 966.75,605.414 966.76,605.414 966.769,605.414 966.778,605.414 966.787,605.414 966.796,605.414 966.805,605.414 966.815,605.414 966.824,605.413 966.833,605.413 966.842,605.413 966.851,605.413 966.861,605.413 966.87,605.413 966.879,605.413 966.888,605.413 966.897,605.412 966.907,605.412 966.916,605.412 966.925,605.412 966.934,605.412 966.943,605.412 966.952,605.412 966.962,605.412 966.971,605.411 966.98,605.411 966.989,605.411 966.998,605.411 967.008,605.411 967.017,605.411 967.026,605.411 967.035,605.411 967.044,605.41 967.054,605.41 967.063,605.41 967.072,605.41 967.081,605.41 967.09,605.41 967.1,605.41 967.109,605.41 967.118,605.41 967.127,605.409 967.136,605.409 967.145,605.409 967.155,605.409 967.164,605.409 967.173,605.409 967.182,605.409 967.191,605.409 967.201,605.408 967.21,605.408 967.219,605.408 967.228,605.408 967.237,605.408 967.247,605.408 967.256,605.408 967.265,605.408 967.274,605.407 967.283,605.407 967.292,605.407 967.302,605.407 967.311,605.407 967.32,605.407 967.329,605.407 967.338,605.407 967.348,605.406 967.357,605.406 967.366,605.406 967.375,605.406 967.384,605.406 967.394,605.406 967.403,605.406 967.412,605.406 967.421,605.405 967.43,605.405 967.44,605.405 967.449,605.405 967.458,605.405 967.467,605.405 967.476,605.405 967.485,605.405 967.495,605.404 967.504,605.404 967.513,605.404 967.522,605.404 967.531,605.404 967.541,605.404 967.55,605.404 967.559,605.404 967.568,605.403 967.577,605.403 967.587,605.403 967.596,605.403 967.605,605.403 967.614,605.403 967.623,605.403 967.633,605.403 967.642,605.402 967.651,605.402 967.66,605.402 967.669,605.402 967.678,605.402 967.688,605.402 967.697,605.402 967.706,605.402 967.715,605.401 967.724,605.401 967.734,605.401 967.743,605.401 967.752,605.401 967.761,605.401 967.77,605.401 967.78,605.401 967.789,605.4 967.798,605.4 967.807,605.4 967.816,605.4 967.825,605.4 967.835,605.4 967.844,605.4 967.853,605.4 967.862,605.399 967.871,605.399 967.881,605.399 967.89,605.399 967.899,605.399 967.908,605.399 967.917,605.399 967.927,605.399 967.936,605.398 967.945,605.398 967.954,605.398 967.963,605.398 967.973,605.398 967.982,605.398 967.991,605.398 968,605.398 968.009,605.398 968.018,605.397 968.028,605.397 968.037,605.397 968.046,605.397 968.055,605.397 968.064,605.397 968.074,605.397 968.083,605.397 968.092,605.396 968.101,605.396 968.11,605.396 968.12,605.396 968.129,605.396 968.138,605.396 968.147,605.396 968.156,605.396 968.165,605.395 968.175,605.395 968.184,605.395 968.193,605.395 968.202,605.395 968.211,605.395 968.221,605.395 968.23,605.395 968.239,605.394 968.248,605.394 968.257,605.394 968.267,605.394 968.276,605.394 968.285,605.394 968.294,605.394 968.303,605.394 968.313,605.393 968.322,605.393 968.331,605.393 968.34,605.393 968.349,605.393 968.358,605.393 968.368,605.393 968.377,605.393 968.386,605.392 968.395,605.392 968.404,605.392 968.414,605.392 968.423,605.392 968.432,605.392 968.441,605.392 968.45,605.392 968.46,605.391 968.469,605.391 968.478,605.391 968.487,605.391 968.496,605.391 968.505,605.391 968.515,605.391 968.524,605.391 968.533,605.39 968.542,605.39 968.551,605.39 968.561,605.39 968.57,605.39 968.579,605.39 968.588,605.39 968.597,605.39 968.607,605.389 968.616,605.389 968.625,605.389 968.634,605.389 968.643,605.389 968.653,605.389 968.662,605.389 968.671,605.389 968.68,605.389 968.689,605.388 968.698,605.388 968.708,605.388 968.717,605.388 968.726,605.388 968.735,605.388 968.744,605.388 968.754,605.388 968.763,605.387 968.772,605.387 968.781,605.387 968.79,605.387 968.8,605.387 968.809,605.387 968.818,605.387 968.827,605.387 968.836,605.386 968.845,605.386 968.855,605.386 968.864,605.386 968.873,605.386 968.882,605.386 968.891,605.386 968.901,605.386 968.91,605.385 968.919,605.385 968.928,605.385 968.937,605.385 968.947,605.385 968.956,605.385 968.965,605.385 968.974,605.385 968.983,605.384 968.993,605.384 969.002,605.384 969.011,605.384 969.02,605.384 969.029,605.384 969.038,605.384 969.048,605.384 969.057,605.383 969.066,605.383 969.075,605.383 969.084,605.383 969.094,605.383 969.103,605.383 969.112,605.383 969.121,605.383 969.13,605.382 969.14,605.382 969.149,605.382 969.158,605.382 969.167,605.382 969.176,605.382 969.185,605.382 969.195,605.382 969.204,605.382 969.213,605.381 969.222,605.381 969.231,605.381 969.241,605.381 969.25,605.381 969.259,605.381 969.268,605.381 969.277,605.381 969.287,605.38 969.296,605.38 969.305,605.38 969.314,605.38 969.323,605.38 969.333,605.38 969.342,605.38 969.351,605.38 969.36,605.379 969.369,605.379 969.378,605.379 969.388,605.379 969.397,605.379 969.406,605.379 969.415,605.379 969.424,605.379 969.434,605.378 969.443,605.378 969.452,605.378 969.461,605.378 969.47,605.378 969.48,605.378 969.489,605.378 969.498,605.378 969.507,605.377 969.516,605.377 969.525,605.377 969.535,605.377 969.544,605.377 969.553,605.377 969.562,605.377 969.571,605.377 969.581,605.377 969.59,605.376 969.599,605.376 969.608,605.376 969.617,605.376 969.627,605.376 969.636,605.376 969.645,605.376 969.654,605.376 969.663,605.375 969.673,605.375 969.682,605.375 969.691,605.375 969.7,605.375 969.709,605.375 969.718,605.375 969.728,605.375 969.737,605.374 969.746,605.374 969.755,605.374 969.764,605.374 969.774,605.374 969.783,605.374 969.792,605.374 969.801,605.374 969.81,605.373 969.82,605.373 969.829,605.373 969.838,605.373 969.847,605.373 969.856,605.373 969.866,605.373 969.875,605.373 969.884,605.372 969.893,605.372 969.902,605.372 969.911,605.372 969.921,605.372 969.93,605.372 969.939,605.372 969.948,605.372 969.957,605.371 969.967,605.371 969.976,605.371 969.985,605.371 969.994,605.371 970.003,605.371 970.013,605.371 970.022,605.371 970.031,605.371 970.04,605.37 970.049,605.37 970.058,605.37 970.068,605.37 970.077,605.37 970.086,605.37 970.095,605.37 970.104,605.37 970.114,605.369 970.123,605.369 970.132,605.369 970.141,605.369 970.15,605.369 970.16,605.369 970.169,605.369 970.178,605.369 970.187,605.368 970.196,605.368 970.206,605.368 970.215,605.368 970.224,605.368 970.233,605.368 970.242,605.368 970.251,605.368 970.261,605.367 970.27,605.367 970.279,605.367 970.288,605.367 970.297,605.367 970.307,605.367 970.316,605.367 970.325,605.367 970.334,605.366 970.343,605.366 970.353,605.366 970.362,605.366 970.371,605.366 970.38,605.366 970.389,605.366 970.398,605.366 970.408,605.366 970.417,605.365 970.426,605.365 970.435,605.365 970.444,605.365 970.454,605.365 970.463,605.365 970.472,605.365 970.481,605.365 970.49,605.364 970.5,605.364 970.509,605.364 970.518,605.364 970.527,605.364 970.536,605.364 970.546,605.364 970.555,605.364 970.564,605.363 970.573,605.363 970.582,605.363 970.591,605.363 970.601,605.363 970.61,605.363 970.619,605.363 970.628,605.363 970.637,605.362 970.647,605.362 970.656,605.362 970.665,605.362 970.674,605.362 970.683,605.362 970.693,605.362 970.702,605.362 970.711,605.362 970.72,605.361 970.729,605.361 970.738,605.361 970.748,605.361 970.757,605.361 970.766,605.361 970.775,605.361 970.784,605.361 970.794,605.36 970.803,605.36 970.812,605.36 970.821,605.36 970.83,605.36 970.84,605.36 970.849,605.36 970.858,605.36 970.867,605.359 970.876,605.359 970.886,605.359 970.895,605.359 970.904,605.359 970.913,605.359 970.922,605.359 970.931,605.359 970.941,605.358 970.95,605.358 970.959,605.358 970.968,605.358 970.977,605.358 970.987,605.358 970.996,605.358 971.005,605.358 971.014,605.358 971.023,605.357 971.033,605.357 971.042,605.357 971.051,605.357 971.06,605.357 971.069,605.357 971.078,605.357 971.088,605.357 971.097,605.356 971.106,605.356 971.115,605.356 971.124,605.356 971.134,605.356 971.143,605.356 971.152,605.356 971.161,605.356 971.17,605.355 971.18,605.355 971.189,605.355 971.198,605.355 971.207,605.355 971.216,605.355 971.226,605.355 971.235,605.355 971.244,605.354 971.253,605.354 971.262,605.354 971.271,605.354 971.281,605.354 971.29,605.354 971.299,605.354 971.308,605.354 971.317,605.354 971.327,605.353 971.336,605.353 971.345,605.353 971.354,605.353 971.363,605.353 971.373,605.353 971.382,605.353 971.391,605.353 971.4,605.352 971.409,605.352 971.418,605.352 971.428,605.352 971.437,605.352 971.446,605.352 971.455,605.352 971.464,605.352 971.474,605.351 971.483,605.351 971.492,605.351 971.501,605.351 971.51,605.351 971.52,605.351 971.529,605.351 971.538,605.351 971.547,605.35 971.556,605.35 971.566,605.35 971.575,605.35 971.584,605.35 971.593,605.35 971.602,605.35 971.611,605.35 971.621,605.35 971.63,605.349 971.639,605.349 971.648,605.349 971.657,605.349 971.667,605.349 971.676,605.349 971.685,605.349 971.694,605.349 971.703,605.348 971.713,605.348 971.722,605.348 971.731,605.348 971.74,605.348 971.749,605.348 971.758,605.348 971.768,605.348 971.777,605.347 971.786,605.347 971.795,605.347 971.804,605.347 971.814,605.347 971.823,605.347 971.832,605.347 971.841,605.347 971.85,605.347 971.86,605.346 971.869,605.346 971.878,605.346 971.887,605.346 971.896,605.346 971.906,605.346 971.915,605.346 971.924,605.346 971.933,605.345 971.942,605.345 971.951,605.345 971.961,605.345 971.97,605.345 971.979,605.345 971.988,605.345 971.997,605.345 972.007,605.344 972.016,605.344 972.025,605.344 972.034,605.344 972.043,605.344 972.053,605.344 972.062,605.344 972.071,605.344 972.08,605.343 972.089,605.343 972.098,605.343 972.108,605.343 972.117,605.343 972.126,605.343 972.135,605.343 972.144,605.343 972.154,605.343 972.163,605.342 972.172,605.342 972.181,605.342 972.19,605.342 972.2,605.342 972.209,605.342 972.218,605.342 972.227,605.342 972.236,605.341 972.246,605.341 972.255,605.341 972.264,605.341 972.273,605.341 972.282,605.341 972.291,605.341 972.301,605.341 972.31,605.34 972.319,605.34 972.328,605.34 972.337,605.34 972.347,605.34 972.356,605.34 972.365,605.34 972.374,605.34 972.383,605.34 972.393,605.339 972.402,605.339 972.411,605.339 972.42,605.339 972.429,605.339 972.439,605.339 972.448,605.339 972.457,605.339 972.466,605.338 972.475,605.338 972.484,605.338 972.494,605.338 972.503,605.338 972.512,605.338 972.521,605.338 972.53,605.338 972.54,605.337 972.549,605.337 972.558,605.337 972.567,605.337 972.576,605.337 972.586,605.337 972.595,605.337 972.604,605.337 972.613,605.337 972.622,605.336 972.631,605.336 972.641,605.336 972.65,605.336 972.659,605.336 972.668,605.336 972.677,605.336 972.687,605.336 972.696,605.335 972.705,605.335 972.714,605.335 972.723,605.335 972.733,605.335 972.742,605.335 972.751,605.335 972.76,605.335 972.769,605.334 972.779,605.334 972.788,605.334 972.797,605.334 972.806,605.334 972.815,605.334 972.824,605.334 972.834,605.334 972.843,605.334 972.852,605.333 972.861,605.333 972.87,605.333 972.88,605.333 972.889,605.333 972.898,605.333 972.907,605.333 972.916,605.333 972.926,605.332 972.935,605.332 972.944,605.332 972.953,605.332 972.962,605.332 972.971,605.332 972.981,605.332 972.99,605.332 972.999,605.331 973.008,605.331 973.017,605.331 973.027,605.331 973.036,605.331 973.045,605.331 973.054,605.331 973.063,605.331 973.073,605.331 973.082,605.33 973.091,605.33 973.1,605.33 973.109,605.33 973.119,605.33 973.128,605.33 973.137,605.33 973.146,605.33 973.155,605.329 973.164,605.329 973.174,605.329 973.183,605.329 973.192,605.329 973.201,605.329 973.21,605.329 973.22,605.329 973.229,605.328 973.238,605.328 973.247,605.328 973.256,605.328 973.266,605.328 973.275,605.328 973.284,605.328 973.293,605.328 973.302,605.328 973.311,605.327 973.321,605.327 973.33,605.327 973.339,605.327 973.348,605.327 973.357,605.327 973.367,605.327 973.376,605.327 973.385,605.326 973.394,605.326 973.403,605.326 973.413,605.326 973.422,605.326 973.431,605.326 973.44,605.326 973.449,605.326 973.459,605.325 973.468,605.325 973.477,605.325 973.486,605.325 973.495,605.325 973.504,605.325 973.514,605.325 973.523,605.325 973.532,605.325 973.541,605.324 973.55,605.324 973.56,605.324 973.569,605.324 973.578,605.324 973.587,605.324 973.596,605.324 973.606,605.324 973.615,605.323 973.624,605.323 973.633,605.323 973.642,605.323 973.651,605.323 973.661,605.323 973.67,605.323 973.679,605.323 973.688,605.322 973.697,605.322 973.707,605.322 973.716,605.322 973.725,605.322 973.734,605.322 973.743,605.322 973.753,605.322 973.762,605.322 973.771,605.321 973.78,605.321 973.789,605.321 973.799,605.321 973.808,605.321 973.817,605.321 973.826,605.321 973.835,605.321 973.844,605.32 973.854,605.32 973.863,605.32 973.872,605.32 973.881,605.32 973.89,605.32 973.9,605.32 973.909,605.32 973.918,605.32 973.927,605.319 973.936,605.319 973.946,605.319 973.955,605.319 973.964,605.319 973.973,605.319 973.982,605.319 973.991,605.319 974.001,605.318 974.01,605.318 974.019,605.318 974.028,605.318 974.037,605.318 974.047,605.318 974.056,605.318 974.065,605.318 974.074,605.317 974.083,605.317 974.093,605.317 974.102,605.317 974.111,605.317 974.12,605.317 974.129,605.317 974.139,605.317 974.148,605.317 974.157,605.316 974.166,605.316 974.175,605.316 974.184,605.316 974.194,605.316 974.203,605.316 974.212,605.316 974.221,605.316 974.23,605.315 974.24,605.315 974.249,605.315 974.258,605.315 974.267,605.315 974.276,605.315 974.286,605.315 974.295,605.315 974.304,605.315 974.313,605.314 974.322,605.314 974.331,605.314 974.341,605.314 974.35,605.314 974.359,605.314 974.368,605.314 974.377,605.314 974.387,605.313 974.396,605.313 974.405,605.313 974.414,605.313 974.423,605.313 974.433,605.313 974.442,605.313 974.451,605.313 974.46,605.312 974.469,605.312 974.479,605.312 974.488,605.312 974.497,605.312 974.506,605.312 974.515,605.312 974.524,605.312 974.534,605.312 974.543,605.311 974.552,605.311 974.561,605.311 974.57,605.311 974.58,605.311 974.589,605.311 974.598,605.311 974.607,605.311 974.616,605.31 974.626,605.31 974.635,605.31 974.644,605.31 974.653,605.31 974.662,605.31 974.671,605.31 974.681,605.31 974.69,605.31 974.699,605.309 974.708,605.309 974.717,605.309 974.727,605.309 974.736,605.309 974.745,605.309 974.754,605.309 974.763,605.309 974.773,605.308 974.782,605.308 974.791,605.308 974.8,605.308 974.809,605.308 974.819,605.308 974.828,605.308 974.837,605.308 974.846,605.308 974.855,605.307 974.864,605.307 974.874,605.307 974.883,605.307 974.892,605.307 974.901,605.307 974.91,605.307 974.92,605.307 974.929,605.306 974.938,605.306 974.947,605.306 974.956,605.306 974.966,605.306 974.975,605.306 974.984,605.306 974.993,605.306 975.002,605.305 975.012,605.305 975.021,605.305 975.03,605.305 975.039,605.305 975.048,605.305 975.057,605.305 975.067,605.305 975.076,605.305 975.085,605.304 975.094,605.304 975.103,605.304 975.113,605.304 975.122,605.304 975.131,605.304 975.14,605.304 975.149,605.304 975.159,605.303 975.168,605.303 975.177,605.303 975.186,605.303 975.195,605.303 975.204,605.303 975.214,605.303 975.223,605.303 975.232,605.303 975.241,605.302 975.25,605.302 975.26,605.302 975.269,605.302 975.278,605.302 975.287,605.302 975.296,605.302 975.306,605.302 975.315,605.301 975.324,605.301 975.333,605.301 975.342,605.301 975.352,605.301 975.361,605.301 975.37,605.301 975.379,605.301 975.388,605.301 975.397,605.3 975.407,605.3 975.416,605.3 975.425,605.3 975.434,605.3 975.443,605.3 975.453,605.3 975.462,605.3 975.471,605.299 975.48,605.299 975.489,605.299 975.499,605.299 975.508,605.299 975.517,605.299 975.526,605.299 975.535,605.299 975.544,605.299 975.554,605.298 975.563,605.298 975.572,605.298 975.581,605.298 975.59,605.298 975.6,605.298 975.609,605.298 975.618,605.298 975.627,605.297 975.636,605.297 975.646,605.297 975.655,605.297 975.664,605.297 975.673,605.297 975.682,605.297 975.692,605.297 975.701,605.297 975.71,605.296 975.719,605.296 975.728,605.296 975.737,605.296 975.747,605.296 975.756,605.296 975.765,605.296 975.774,605.296 975.783,605.295 975.793,605.295 975.802,605.295 975.811,605.295 975.82,605.295 975.829,605.295 975.839,605.295 975.848,605.295 975.857,605.295 975.866,605.294 975.875,605.294 975.884,605.294 975.894,605.294 975.903,605.294 975.912,605.294 975.921,605.294 975.93,605.294 975.94,605.293 975.949,605.293 975.958,605.293 975.967,605.293 975.976,605.293 975.986,605.293 975.995,605.293 976.004,605.293 976.013,605.293 976.022,605.292 976.032,605.292 976.041,605.292 976.05,605.292 976.059,605.292 976.068,605.292 976.077,605.292 976.087,605.292 976.096,605.291 976.105,605.291 976.114,605.291 976.123,605.291 976.133,605.291 976.142,605.291 976.151,605.291 976.16,605.291 976.169,605.29 976.179,605.29 976.188,605.29 976.197,605.29 976.206,605.29 976.215,605.29 976.224,605.29 976.234,605.29 976.243,605.29 976.252,605.289 976.261,605.289 976.27,605.289 976.28,605.289 976.289,605.289 976.298,605.289 976.307,605.289 976.316,605.289 976.326,605.289 976.335,605.288 976.344,605.288 976.353,605.288 976.362,605.288 976.372,605.288 976.381,605.288 976.39,605.288 976.399,605.288 976.408,605.287 976.417,605.287 976.427,605.287 976.436,605.287 976.445,605.287 976.454,605.287 976.463,605.287 976.473,605.287 976.482,605.287 976.491,605.286 976.5,605.286 976.509,605.286 976.519,605.286 976.528,605.286 976.537,605.286 976.546,605.286 976.555,605.286 976.564,605.285 976.574,605.285 976.583,605.285 976.592,605.285 976.601,605.285 976.61,605.285 976.62,605.285 976.629,605.285 976.638,605.285 976.647,605.284 976.656,605.284 976.666,605.284 976.675,605.284 976.684,605.284 976.693,605.284 976.702,605.284 976.712,605.284 976.721,605.283 976.73,605.283 976.739,605.283 976.748,605.283 976.757,605.283 976.767,605.283 976.776,605.283 976.785,605.283 976.794,605.283 976.803,605.282 976.813,605.282 976.822,605.282 976.831,605.282 976.84,605.282 976.849,605.282 976.859,605.282 976.868,605.282 976.877,605.281 976.886,605.281 976.895,605.281 976.904,605.281 976.914,605.281 976.923,605.281 976.932,605.281 976.941,605.281 976.95,605.281 976.96,605.28 976.969,605.28 976.978,605.28 976.987,605.28 976.996,605.28 977.006,605.28 977.015,605.28 977.024,605.28 977.033,605.279 977.042,605.279 977.052,605.279 977.061,605.279 977.07,605.279 977.079,605.279 977.088,605.279 977.097,605.279 977.107,605.279 977.116,605.278 977.125,605.278 977.134,605.278 977.143,605.278 977.153,605.278 977.162,605.278 977.171,605.278 977.18,605.278 977.189,605.277 977.199,605.277 977.208,605.277 977.217,605.277 977.226,605.277 977.235,605.277 977.245,605.277 977.254,605.277 977.263,605.277 977.272,605.276 977.281,605.276 977.29,605.276 977.3,605.276 977.309,605.276 977.318,605.276 977.327,605.276 977.336,605.276 977.346,605.275 977.355,605.275 977.364,605.275 977.373,605.275 977.382,605.275 977.392,605.275 977.401,605.275 977.41,605.275 977.419,605.275 977.428,605.274 977.437,605.274 977.447,605.274 977.456,605.274 977.465,605.274 977.474,605.274 977.483,605.274 977.493,605.274 977.502,605.274 977.511,605.273 977.52,605.273 977.529,605.273 977.539,605.273 977.548,605.273 977.557,605.273 977.566,605.273 977.575,605.273 977.585,605.272 977.594,605.272 977.603,605.272 977.612,605.272 977.621,605.272 977.63,605.272 977.64,605.272 977.649,605.272 977.658,605.272 977.667,605.271 977.676,605.271 977.686,605.271 977.695,605.271 977.704,605.271 977.713,605.271 977.722,605.271 977.732,605.271 977.741,605.27 977.75,605.27 977.759,605.27 977.768,605.27 977.777,605.27 977.787,605.27 977.796,605.27 977.805,605.27 977.814,605.27 977.823,605.269 977.833,605.269 977.842,605.269 977.851,605.269 977.86,605.269 977.869,605.269 977.879,605.269 977.888,605.269 977.897,605.268 977.906,605.268 977.915,605.268 977.925,605.268 977.934,605.268 977.943,605.268 977.952,605.268 977.961,605.268 977.97,605.268 977.98,605.267 977.989,605.267 977.998,605.267 978.007,605.267 978.016,605.267 978.026,605.267 978.035,605.267 978.044,605.267 978.053,605.267 978.062,605.266 978.072,605.266 978.081,605.266 978.09,605.266 978.099,605.266 978.108,605.266 978.117,605.266 978.127,605.266 978.136,605.265 978.145,605.265 978.154,605.265 978.163,605.265 978.173,605.265 978.182,605.265 978.191,605.265 978.2,605.265 978.209,605.265 978.219,605.264 978.228,605.264 978.237,605.264 978.246,605.264 978.255,605.264 978.265,605.264 978.274,605.264 978.283,605.264 978.292,605.263 978.301,605.263 978.31,605.263 978.32,605.263 978.329,605.263 978.338,605.263 978.347,605.263 978.356,605.263 978.366,605.263 978.375,605.262 978.384,605.262 978.393,605.262 978.402,605.262 978.412,605.262 978.421,605.262 978.43,605.262 978.439,605.262 978.448,605.262 978.457,605.261 978.467,605.261 978.476,605.261 978.485,605.261 978.494,605.261 978.503,605.261 978.513,605.261 978.522,605.261 978.531,605.26 978.54,605.26 978.549,605.26 978.559,605.26 978.568,605.26 978.577,605.26 978.586,605.26 978.595,605.26 978.605,605.26 978.614,605.259 978.623,605.259 978.632,605.259 978.641,605.259 978.65,605.259 978.66,605.259 978.669,605.259 978.678,605.259 978.687,605.258 978.696,605.258 978.706,605.258 978.715,605.258 978.724,605.258 978.733,605.258 978.742,605.258 978.752,605.258 978.761,605.258 978.77,605.257 978.779,605.257 978.788,605.257 978.797,605.257 978.807,605.257 978.816,605.257 978.825,605.257 978.834,605.257 978.843,605.257 978.853,605.256 978.862,605.256 978.871,605.256 978.88,605.256 978.889,605.256 978.899,605.256 978.908,605.256 978.917,605.256 978.926,605.255 978.935,605.255 978.945,605.255 978.954,605.255 978.963,605.255 978.972,605.255 978.981,605.255 978.99,605.255 979,605.255 979.009,605.254 979.018,605.254 979.027,605.254 979.036,605.254 979.046,605.254 979.055,605.254 979.064,605.254 979.073,605.254 979.082,605.254 979.092,605.253 979.101,605.253 979.11,605.253 979.119,605.253 979.128,605.253 979.137,605.253 979.147,605.253 979.156,605.253 979.165,605.252 979.174,605.252 979.183,605.252 979.193,605.252 979.202,605.252 979.211,605.252 979.22,605.252 979.229,605.252 979.239,605.252 979.248,605.251 979.257,605.251 979.266,605.251 979.275,605.251 979.285,605.251 979.294,605.251 979.303,605.251 979.312,605.251 979.321,605.251 979.33,605.25 979.34,605.25 979.349,605.25 979.358,605.25 979.367,605.25 979.376,605.25 979.386,605.25 979.395,605.25 979.404,605.249 979.413,605.249 979.422,605.249 979.432,605.249 979.441,605.249 979.45,605.249 979.459,605.249 979.468,605.249 979.477,605.249 979.487,605.248 979.496,605.248 979.505,605.248 979.514,605.248 979.523,605.248 979.533,605.248 979.542,605.248 979.551,605.248 979.56,605.248 979.569,605.247 979.579,605.247 979.588,605.247 979.597,605.247 979.606,605.247 979.615,605.247 979.625,605.247 979.634,605.247 979.643,605.246 979.652,605.246 979.661,605.246 979.67,605.246 979.68,605.246 979.689,605.246 979.698,605.246 979.707,605.246 979.716,605.246 979.726,605.245 979.735,605.245 979.744,605.245 979.753,605.245 979.762,605.245 979.772,605.245 979.781,605.245 979.79,605.245 979.799,605.245 979.808,605.244 979.818,605.244 979.827,605.244 979.836,605.244 979.845,605.244 979.854,605.244 979.863,605.244 979.873,605.244 979.882,605.243 979.891,605.243 979.9,605.243 979.909,605.243 979.919,605.243 979.928,605.243 979.937,605.243 979.946,605.243 979.955,605.243 979.965,605.242 979.974,605.242 979.983,605.242 979.992,605.242 980.001,605.242 980.01,605.242 980.02,605.242 980.029,605.242 980.038,605.242 980.047,605.241 980.056,605.241 980.066,605.241 980.075,605.241 980.084,605.241 980.093,605.241 980.102,605.241 980.112,605.241 980.121,605.24 980.13,605.24 980.139,605.24 980.148,605.24 980.158,605.24 980.167,605.24 980.176,605.24 980.185,605.24 980.194,605.24 980.203,605.239 980.213,605.239 980.222,605.239 980.231,605.239 980.24,605.239 980.249,605.239 980.259,605.239 980.268,605.239 980.277,605.239 980.286,605.238 980.295,605.238 980.305,605.238 980.314,605.238 980.323,605.238 980.332,605.238 980.341,605.238 980.35,605.238 980.36,605.237 980.369,605.237 980.378,605.237 980.387,605.237 980.396,605.237 980.406,605.237 980.415,605.237 980.424,605.237 980.433,605.237 980.442,605.236 980.452,605.236 980.461,605.236 980.47,605.236 980.479,605.236 980.488,605.236 980.498,605.236 980.507,605.236 980.516,605.236 980.525,605.235 980.534,605.235 980.543,605.235 980.553,605.235 980.562,605.235 980.571,605.235 980.58,605.235 980.589,605.235 980.599,605.235 980.608,605.234 980.617,605.234 980.626,605.234 980.635,605.234 980.645,605.234 980.654,605.234 980.663,605.234 980.672,605.234 980.681,605.233 980.69,605.233 980.7,605.233 980.709,605.233 980.718,605.233 980.727,605.233 980.736,605.233 980.746,605.233 980.755,605.233 980.764,605.232 980.773,605.232 980.782,605.232 980.792,605.232 980.801,605.232 980.81,605.232 980.819,605.232 980.828,605.232 980.838,605.232 980.847,605.231 980.856,605.231 980.865,605.231 980.874,605.231 980.883,605.231 980.893,605.231 980.902,605.231 980.911,605.231 980.92,605.23 980.929,605.23 980.939,605.23 980.948,605.23 980.957,605.23 980.966,605.23 980.975,605.23 980.985,605.23 980.994,605.23 981.003,605.229 981.012,605.229 981.021,605.229 981.03,605.229 981.04,605.229 981.049,605.229 981.058,605.229 981.067,605.229 981.076,605.229 981.086,605.228 981.095,605.228 981.104,605.228 981.113,605.228 981.122,605.228 981.132,605.228 981.141,605.228 981.15,605.228 981.159,605.228 981.168,605.227 981.178,605.227 981.187,605.227 981.196,605.227 981.205,605.227 981.214,605.227 981.223,605.227 981.233,605.227 981.242,605.226 981.251,605.226 981.26,605.226 981.269,605.226 981.279,605.226 981.288,605.226 981.297,605.226 981.306,605.226 981.315,605.226 981.325,605.225 981.334,605.225 981.343,605.225 981.352,605.225 981.361,605.225 981.37,605.225 981.38,605.225 981.389,605.225 981.398,605.225 981.407,605.224 981.416,605.224 981.426,605.224 981.435,605.224 981.444,605.224 981.453,605.224 981.462,605.224 981.472,605.224 981.481,605.224 981.49,605.223 981.499,605.223 981.508,605.223 981.518,605.223 981.527,605.223 981.536,605.223 981.545,605.223 981.554,605.223 981.563,605.222 981.573,605.222 981.582,605.222 981.591,605.222 981.6,605.222 981.609,605.222 981.619,605.222 981.628,605.222 981.637,605.222 981.646,605.221 981.655,605.221 981.665,605.221 981.674,605.221 981.683,605.221 981.692,605.221 981.701,605.221 981.71,605.221 981.72,605.221 981.729,605.22 981.738,605.22 981.747,605.22 981.756,605.22 981.766,605.22 981.775,605.22 981.784,605.22 981.793,605.22 981.802,605.22 981.812,605.219 981.821,605.219 981.83,605.219 981.839,605.219 981.848,605.219 981.858,605.219 981.867,605.219 981.876,605.219 981.885,605.219 981.894,605.218 981.903,605.218 981.913,605.218 981.922,605.218 981.931,605.218 981.94,605.218 981.949,605.218 981.959,605.218 981.968,605.217 981.977,605.217 981.986,605.217 981.995,605.217 982.005,605.217 982.014,605.217 982.023,605.217 982.032,605.217 982.041,605.217 982.05,605.216 982.06,605.216 982.069,605.216 982.078,605.216 982.087,605.216 982.096,605.216 982.106,605.216 982.115,605.216 982.124,605.216 982.133,605.215 982.142,605.215 982.152,605.215 982.161,605.215 982.17,605.215 982.179,605.215 982.188,605.215 982.198,605.215 982.207,605.215 982.216,605.214 982.225,605.214 982.234,605.214 982.243,605.214 982.253,605.214 982.262,605.214 982.271,605.214 982.28,605.214 982.289,605.213 982.299,605.213 982.308,605.213 982.317,605.213 982.326,605.213 982.335,605.213 982.345,605.213 982.354,605.213 982.363,605.213 982.372,605.212 982.381,605.212 982.391,605.212 982.4,605.212 982.409,605.212 982.418,605.212 982.427,605.212 982.436,605.212 982.446,605.212 982.455,605.211 982.464,605.211 982.473,605.211 982.482,605.211 982.492,605.211 982.501,605.211 982.51,605.211 982.519,605.211 982.528,605.211 982.538,605.21 982.547,605.21 982.556,605.21 982.565,605.21 982.574,605.21 982.583,605.21 982.593,605.21 982.602,605.21 982.611,605.21 982.62,605.209 982.629,605.209 982.639,605.209 982.648,605.209 982.657,605.209 982.666,605.209 982.675,605.209 982.685,605.209 982.694,605.209 982.703,605.208 982.712,605.208 982.721,605.208 982.731,605.208 982.74,605.208 982.749,605.208 982.758,605.208 982.767,605.208 982.776,605.207 982.786,605.207 982.795,605.207 982.804,605.207 982.813,605.207 982.822,605.207 982.832,605.207 982.841,605.207 982.85,605.207 982.859,605.206 982.868,605.206 982.878,605.206 982.887,605.206 982.896,605.206 982.905,605.206 982.914,605.206 982.923,605.206 982.933,605.206 982.942,605.205 982.951,605.205 982.96,605.205 982.969,605.205 982.979,605.205 982.988,605.205 982.997,605.205 983.006,605.205 983.015,605.205 983.025,605.204 983.034,605.204 983.043,605.204 983.052,605.204 983.061,605.204 983.071,605.204 983.08,605.204 983.089,605.204 983.098,605.204 983.107,605.203 983.116,605.203 983.126,605.203 983.135,605.203 983.144,605.203 983.153,605.203 983.162,605.203 983.172,605.203 983.181,605.203 983.19,605.202 983.199,605.202 983.208,605.202 983.218,605.202 983.227,605.202 983.236,605.202 983.245,605.202 983.254,605.202 983.263,605.201 983.273,605.201 983.282,605.201 983.291,605.201 983.3,605.201 983.309,605.201 983.319,605.201 983.328,605.201 983.337,605.201 983.346,605.2 983.355,605.2 983.365,605.2 983.374,605.2 983.383,605.2 983.392,605.2 983.401,605.2 983.411,605.2 983.42,605.2 983.429,605.199 983.438,605.199 983.447,605.199 983.456,605.199 983.466,605.199 983.475,605.199 983.484,605.199 983.493,605.199 983.502,605.199 983.512,605.198 983.521,605.198 983.53,605.198 983.539,605.198 983.548,605.198 983.558,605.198 983.567,605.198 983.576,605.198 983.585,605.198 983.594,605.197 983.603,605.197 983.613,605.197 983.622,605.197 983.631,605.197 983.64,605.197 983.649,605.197 983.659,605.197 983.668,605.197 983.677,605.196 983.686,605.196 983.695,605.196 983.705,605.196 983.714,605.196 983.723,605.196 983.732,605.196 983.741,605.196 983.751,605.196 983.76,605.195 983.769,605.195 983.778,605.195 983.787,605.195 983.796,605.195 983.806,605.195 983.815,605.195 983.824,605.195 983.833,605.194 983.842,605.194 983.852,605.194 983.861,605.194 983.87,605.194 983.879,605.194 983.888,605.194 983.898,605.194 983.907,605.194 983.916,605.193 983.925,605.193 983.934,605.193 983.943,605.193 983.953,605.193 983.962,605.193 983.971,605.193 983.98,605.193 983.989,605.193 983.999,605.192 984.008,605.192 984.017,605.192 984.026,605.192 984.035,605.192 984.045,605.192 984.054,605.192 984.063,605.192 984.072,605.192 984.081,605.191 984.091,605.191 984.1,605.191 984.109,605.191 984.118,605.191 984.127,605.191 984.136,605.191 984.146,605.191 984.155,605.191 984.164,605.19 984.173,605.19 984.182,605.19 984.192,605.19 984.201,605.19 984.21,605.19 984.219,605.19 984.228,605.19 984.238,605.19 984.247,605.189 984.256,605.189 984.265,605.189 984.274,605.189 984.283,605.189 984.293,605.189 984.302,605.189 984.311,605.189 984.32,605.189 984.329,605.188 984.339,605.188 984.348,605.188 984.357,605.188 984.366,605.188 984.375,605.188 984.385,605.188 984.394,605.188 984.403,605.188 984.412,605.187 984.421,605.187 984.431,605.187 984.44,605.187 984.449,605.187 984.458,605.187 984.467,605.187 984.476,605.187 984.486,605.187 984.495,605.186 984.504,605.186 984.513,605.186 984.522,605.186 984.532,605.186 984.541,605.186 984.55,605.186 984.559,605.186 984.568,605.186 984.578,605.185 984.587,605.185 984.596,605.185 984.605,605.185 984.614,605.185 984.624,605.185 984.633,605.185 984.642,605.185 984.651,605.184 984.66,605.184 984.669,605.184 984.679,605.184 984.688,605.184 984.697,605.184 984.706,605.184 984.715,605.184 984.725,605.184 984.734,605.183 984.743,605.183 984.752,605.183 984.761,605.183 984.771,605.183 984.78,605.183 984.789,605.183 984.798,605.183 984.807,605.183 984.816,605.182 984.826,605.182 984.835,605.182 984.844,605.182 984.853,605.182 984.862,605.182 984.872,605.182 984.881,605.182 984.89,605.182 984.899,605.181 984.908,605.181 984.918,605.181 984.927,605.181 984.936,605.181 984.945,605.181 984.954,605.181 984.964,605.181 984.973,605.181 984.982,605.18 984.991,605.18 985,605.18 985.009,605.18 985.019,605.18 985.028,605.18 985.037,605.18 985.046,605.18 985.055,605.18 985.065,605.179 985.074,605.179 985.083,605.179 985.092,605.179 985.101,605.179 985.111,605.179 985.12,605.179 985.129,605.179 985.138,605.179 985.147,605.178 985.156,605.178 985.166,605.178 985.175,605.178 985.184,605.178 985.193,605.178 985.202,605.178 985.212,605.178 985.221,605.178 985.23,605.177 985.239,605.177 985.248,605.177 985.258,605.177 985.267,605.177 985.276,605.177 985.285,605.177 985.294,605.177 985.304,605.177 985.313,605.176 985.322,605.176 985.331,605.176 985.34,605.176 985.349,605.176 985.359,605.176 985.368,605.176 985.377,605.176 985.386,605.176 985.395,605.175 985.405,605.175 985.414,605.175 985.423,605.175 985.432,605.175 985.441,605.175 985.451,605.175 985.46,605.175 985.469,605.175 985.478,605.174 985.487,605.174 985.496,605.174 985.506,605.174 985.515,605.174 985.524,605.174 985.533,605.174 985.542,605.174 985.552,605.174 985.561,605.173 985.57,605.173 985.579,605.173 985.588,605.173 985.598,605.173 985.607,605.173 985.616,605.173 985.625,605.173 985.634,605.173 985.644,605.172 985.653,605.172 985.662,605.172 985.671,605.172 985.68,605.172 985.689,605.172 985.699,605.172 985.708,605.172 985.717,605.172 985.726,605.171 985.735,605.171 985.745,605.171 985.754,605.171 985.763,605.171 985.772,605.171 985.781,605.171 985.791,605.171 985.8,605.171 985.809,605.17 985.818,605.17 985.827,605.17 985.836,605.17 985.846,605.17 985.855,605.17 985.864,605.17 985.873,605.17 985.882,605.17 985.892,605.169 985.901,605.169 985.91,605.169 985.919,605.169 985.928,605.169 985.938,605.169 985.947,605.169 985.956,605.169 985.965,605.169 985.974,605.168 985.984,605.168 985.993,605.168 986.002,605.168 986.011,605.168 986.02,605.168 986.029,605.168 986.039,605.168 986.048,605.168 986.057,605.167 986.066,605.167 986.075,605.167 986.085,605.167 986.094,605.167 986.103,605.167 986.112,605.167 986.121,605.167 986.131,605.167 986.14,605.166 986.149,605.166 986.158,605.166 986.167,605.166 986.176,605.166 986.186,605.166 986.195,605.166 986.204,605.166 986.213,605.166 986.222,605.165 986.232,605.165 986.241,605.165 986.25,605.165 986.259,605.165 986.268,605.165 986.278,605.165 986.287,605.165 986.296,605.165 986.305,605.164 986.314,605.164 986.324,605.164 986.333,605.164 986.342,605.164 986.351,605.164 986.36,605.164 986.369,605.164 986.379,605.164 986.388,605.163 986.397,605.163 986.406,605.163 986.415,605.163 986.425,605.163 986.434,605.163 986.443,605.163 986.452,605.163 986.461,605.163 986.471,605.162 986.48,605.162 986.489,605.162 986.498,605.162 986.507,605.162 986.516,605.162 986.526,605.162 986.535,605.162 986.544,605.162 986.553,605.161 986.562,605.161 986.572,605.161 986.581,605.161 986.59,605.161 986.599,605.161 986.608,605.161 986.618,605.161 986.627,605.161 986.636,605.16 986.645,605.16 986.654,605.16 986.664,605.16 986.673,605.16 986.682,605.16 986.691,605.16 986.7,605.16 986.709,605.16 986.719,605.159 986.728,605.159 986.737,605.159 986.746,605.159 986.755,605.159 986.765,605.159 986.774,605.159 986.783,605.159 986.792,605.159 986.801,605.158 986.811,605.158 986.82,605.158 986.829,605.158 986.838,605.158 986.847,605.158 986.856,605.158 986.866,605.158 986.875,605.158 986.884,605.157 986.893,605.157 986.902,605.157 986.912,605.157 986.921,605.157 986.93,605.157 986.939,605.157 986.948,605.157 986.958,605.157 986.967,605.156 986.976,605.156 986.985,605.156 986.994,605.156 987.004,605.156 987.013,605.156 987.022,605.156 987.031,605.156 987.04,605.156 987.049,605.155 987.059,605.155 987.068,605.155 987.077,605.155 987.086,605.155 987.095,605.155 987.105,605.155 987.114,605.155 987.123,605.155 987.132,605.154 987.141,605.154 987.151,605.154 987.16,605.154 987.169,605.154 987.178,605.154 987.187,605.154 987.197,605.154 987.206,605.154 987.215,605.153 987.224,605.153 987.233,605.153 987.242,605.153 987.252,605.153 987.261,605.153 987.27,605.153 987.279,605.153 987.288,605.153 987.298,605.152 987.307,605.152 987.316,605.152 987.325,605.152 987.334,605.152 987.344,605.152 987.353,605.152 987.362,605.152 987.371,605.152 987.38,605.151 987.389,605.151 987.399,605.151 987.408,605.151 987.417,605.151 987.426,605.151 987.435,605.151 987.445,605.151 987.454,605.151 987.463,605.15 987.472,605.15 987.481,605.15 987.491,605.15 987.5,605.15 987.509,605.15 987.518,605.15 987.527,605.15 987.537,605.15 987.546,605.149 987.555,605.149 987.564,605.149 987.573,605.149 987.582,605.149 987.592,605.149 987.601,605.149 987.61,605.149 987.619,605.149 987.628,605.148 987.638,605.148 987.647,605.148 987.656,605.148 987.665,605.148 987.674,605.148 987.684,605.148 987.693,605.148 987.702,605.148 987.711,605.147 987.72,605.147 987.729,605.147 987.739,605.147 987.748,605.147 987.757,605.147 987.766,605.147 987.775,605.147 987.785,605.147 987.794,605.146 987.803,605.146 987.812,605.146 987.821,605.146 987.831,605.146 987.84,605.146 987.849,605.146 987.858,605.146 987.867,605.146 987.877,605.146 987.886,605.145 987.895,605.145 987.904,605.145 987.913,605.145 987.922,605.145 987.932,605.145 987.941,605.145 987.95,605.145 987.959,605.145 987.968,605.144 987.978,605.144 987.987,605.144 987.996,605.144 988.005,605.144 988.014,605.144 988.024,605.144 988.033,605.144 988.042,605.144 988.051,605.143 988.06,605.143 988.069,605.143 988.079,605.143 988.088,605.143 988.097,605.143 988.106,605.143 988.115,605.143 988.125,605.143 988.134,605.142 988.143,605.142 988.152,605.142 988.161,605.142 988.171,605.142 988.18,605.142 988.189,605.142 988.198,605.142 988.207,605.142 988.217,605.141 988.226,605.141 988.235,605.141 988.244,605.141 988.253,605.141 988.262,605.141 988.272,605.141 988.281,605.141 988.29,605.141 988.299,605.14 988.308,605.14 988.318,605.14 988.327,605.14 988.336,605.14 988.345,605.14 988.354,605.14 988.364,605.14 988.373,605.14 988.382,605.139 988.391,605.139 988.4,605.139 988.409,605.139 988.419,605.139 988.428,605.139 988.437,605.139 988.446,605.139 988.455,605.139 988.465,605.138 988.474,605.138 988.483,605.138 988.492,605.138 988.501,605.138 988.511,605.138 988.52,605.138 988.529,605.138 988.538,605.138 988.547,605.137 988.557,605.137 988.566,605.137 988.575,605.137 988.584,605.137 988.593,605.137 988.602,605.137 988.612,605.137 988.621,605.137 988.63,605.136 988.639,605.136 988.648,605.136 988.658,605.136 988.667,605.136 988.676,605.136 988.685,605.136 988.694,605.136 988.704,605.136 988.713,605.136 988.722,605.135 988.731,605.135 988.74,605.135 988.749,605.135 988.759,605.135 988.768,605.135 988.777,605.135 988.786,605.135 988.795,605.135 988.805,605.134 988.814,605.134 988.823,605.134 988.832,605.134 988.841,605.134 988.851,605.134 988.86,605.134 988.869,605.134 988.878,605.134 988.887,605.133 988.897,605.133 988.906,605.133 988.915,605.133 988.924,605.133 988.933,605.133 988.942,605.133 988.952,605.133 988.961,605.133 988.97,605.132 988.979,605.132 988.988,605.132 988.998,605.132 989.007,605.132 989.016,605.132 989.025,605.132 989.034,605.132 989.044,605.132 989.053,605.131 989.062,605.131 989.071,605.131 989.08,605.131 989.089,605.131 989.099,605.131 989.108,605.131 989.117,605.131 989.126,605.131 989.135,605.13 989.145,605.13 989.154,605.13 989.163,605.13 989.172,605.13 989.181,605.13 989.191,605.13 989.2,605.13 989.209,605.13 989.218,605.129 989.227,605.129 989.237,605.129 989.246,605.129 989.255,605.129 989.264,605.129 989.273,605.129 989.282,605.129 989.292,605.129 989.301,605.129 989.31,605.128 989.319,605.128 989.328,605.128 989.338,605.128 989.347,605.128 989.356,605.128 989.365,605.128 989.374,605.128 989.384,605.128 989.393,605.127 989.402,605.127 989.411,605.127 989.42,605.127 989.429,605.127 989.439,605.127 989.448,605.127 989.457,605.127 989.466,605.127 989.475,605.126 989.485,605.126 989.494,605.126 989.503,605.126 989.512,605.126 989.521,605.126 989.531,605.126 989.54,605.126 989.549,605.126 989.558,605.125 989.567,605.125 989.577,605.125 989.586,605.125 989.595,605.125 989.604,605.125 989.613,605.125 989.622,605.125 989.632,605.125 989.641,605.124 989.65,605.124 989.659,605.124 989.668,605.124 989.678,605.124 989.687,605.124 989.696,605.124 989.705,605.124 989.714,605.124 989.724,605.123 989.733,605.123 989.742,605.123 989.751,605.123 989.76,605.123 989.77,605.123 989.779,605.123 989.788,605.123 989.797,605.123 989.806,605.123 989.815,605.122 989.825,605.122 989.834,605.122 989.843,605.122 989.852,605.122 989.861,605.122 989.871,605.122 989.88,605.122 989.889,605.122 989.898,605.121 989.907,605.121 989.917,605.121 989.926,605.121 989.935,605.121 989.944,605.121 989.953,605.121 989.962,605.121 989.972,605.121 989.981,605.12 989.99,605.12 989.999,605.12 990.008,605.12 990.018,605.12 990.027,605.12 990.036,605.12 990.045,605.12 990.054,605.12 990.064,605.119 990.073,605.119 990.082,605.119 990.091,605.119 990.1,605.119 990.11,605.119 990.119,605.119 990.128,605.119 990.137,605.119 990.146,605.118 990.155,605.118 990.165,605.118 990.174,605.118 990.183,605.118 990.192,605.118 990.201,605.118 990.211,605.118 990.22,605.118 990.229,605.118 990.238,605.117 990.247,605.117 990.257,605.117 990.266,605.117 990.275,605.117 990.284,605.117 990.293,605.117 990.302,605.117 990.312,605.117 990.321,605.116 990.33,605.116 990.339,605.116 990.348,605.116 990.358,605.116 990.367,605.116 990.376,605.116 990.385,605.116 990.394,605.116 990.404,605.115 990.413,605.115 990.422,605.115 990.431,605.115 990.44,605.115 990.45,605.115 990.459,605.115 990.468,605.115 990.477,605.115 990.486,605.114 990.495,605.114 990.505,605.114 990.514,605.114 990.523,605.114 990.532,605.114 990.541,605.114 990.551,605.114 990.56,605.114 990.569,605.113 990.578,605.113 990.587,605.113 990.597,605.113 990.606,605.113 990.615,605.113 990.624,605.113 990.633,605.113 990.642,605.113 990.652,605.113 990.661,605.112 990.67,605.112 990.679,605.112 990.688,605.112 990.698,605.112 990.707,605.112 990.716,605.112 990.725,605.112 990.734,605.112 990.744,605.111 990.753,605.111 990.762,605.111 990.771,605.111 990.78,605.111 990.79,605.111 990.799,605.111 990.808,605.111 990.817,605.111 990.826,605.11 990.835,605.11 990.845,605.11 990.854,605.11 990.863,605.11 990.872,605.11 990.881,605.11 990.891,605.11 990.9,605.11 990.909,605.109 990.918,605.109 990.927,605.109 990.937,605.109 990.946,605.109 990.955,605.109 990.964,605.109 990.973,605.109 990.982,605.109 990.992,605.109 991.001,605.108 991.01,605.108 991.019,605.108 991.028,605.108 991.038,605.108 991.047,605.108 991.056,605.108 991.065,605.108 991.074,605.108 991.084,605.107 991.093,605.107 991.102,605.107 991.111,605.107 991.12,605.107 991.13,605.107 991.139,605.107 991.148,605.107 991.157,605.107 991.166,605.106 991.175,605.106 991.185,605.106 991.194,605.106 991.203,605.106 991.212,605.106 991.221,605.106 991.231,605.106 991.24,605.106 991.249,605.105 991.258,605.105 991.267,605.105 991.277,605.105 991.286,605.105 991.295,605.105 991.304,605.105 991.313,605.105 991.322,605.105 991.332,605.105 991.341,605.104 991.35,605.104 991.359,605.104 991.368,605.104 991.378,605.104 991.387,605.104 991.396,605.104 991.405,605.104 991.414,605.104 991.424,605.103 991.433,605.103 991.442,605.103 991.451,605.103 991.46,605.103 991.47,605.103 991.479,605.103 991.488,605.103 991.497,605.103 991.506,605.102 991.515,605.102 991.525,605.102 991.534,605.102 991.543,605.102 991.552,605.102 991.561,605.102 991.571,605.102 991.58,605.102 991.589,605.101 991.598,605.101 991.607,605.101 991.617,605.101 991.626,605.101 991.635,605.101 991.644,605.101 991.653,605.101 991.662,605.101 991.672,605.101 991.681,605.1 991.69,605.1 991.699,605.1 991.708,605.1 991.718,605.1 991.727,605.1 991.736,605.1 991.745,605.1 991.754,605.1 991.764,605.099 991.773,605.099 991.782,605.099 991.791,605.099 991.8,605.099 991.81,605.099 991.819,605.099 991.828,605.099 991.837,605.099 991.846,605.098 991.855,605.098 991.865,605.098 991.874,605.098 991.883,605.098 991.892,605.098 991.901,605.098 991.911,605.098 991.92,605.098 991.929,605.097 991.938,605.097 991.947,605.097 991.957,605.097 991.966,605.097 991.975,605.097 991.984,605.097 991.993,605.097 992.002,605.097 992.012,605.097 992.021,605.096 992.03,605.096 992.039,605.096 992.048,605.096 992.058,605.096 992.067,605.096 992.076,605.096 992.085,605.096 992.094,605.096 992.104,605.095 992.113,605.095 992.122,605.095 992.131,605.095 992.14,605.095 992.15,605.095 992.159,605.095 992.168,605.095 992.177,605.095 992.186,605.094 992.195,605.094 992.205,605.094 992.214,605.094 992.223,605.094 992.232,605.094 992.241,605.094 992.251,605.094 992.26,605.094 992.269,605.094 992.278,605.093 992.287,605.093 992.297,605.093 992.306,605.093 992.315,605.093 992.324,605.093 992.333,605.093 992.343,605.093 992.352,605.093 992.361,605.092 992.37,605.092 992.379,605.092 992.388,605.092 992.398,605.092 992.407,605.092 992.416,605.092 992.425,605.092 992.434,605.092 992.444,605.091 992.453,605.091 992.462,605.091 992.471,605.091 992.48,605.091 992.49,605.091 992.499,605.091 992.508,605.091 992.517,605.091 992.526,605.091 992.535,605.09 992.545,605.09 992.554,605.09 992.563,605.09 992.572,605.09 992.581,605.09 992.591,605.09 992.6,605.09 992.609,605.09 992.618,605.089 992.627,605.089 992.637,605.089 992.646,605.089 992.655,605.089 992.664,605.089 992.673,605.089 992.683,605.089 992.692,605.089 992.701,605.088 992.71,605.088 992.719,605.088 992.728,605.088 992.738,605.088 992.747,605.088 992.756,605.088 992.765,605.088 992.774,605.088 992.784,605.088 992.793,605.087 992.802,605.087 992.811,605.087 992.82,605.087 992.83,605.087 992.839,605.087 992.848,605.087 992.857,605.087 992.866,605.087 992.875,605.086 992.885,605.086 992.894,605.086 992.903,605.086 992.912,605.086 992.921,605.086 992.931,605.086 992.94,605.086 992.949,605.086 992.958,605.085 992.967,605.085 992.977,605.085 992.986,605.085 992.995,605.085 993.004,605.085 993.013,605.085 993.023,605.085 993.032,605.085 993.041,605.085 993.05,605.084 993.059,605.084 993.068,605.084 993.078,605.084 993.087,605.084 993.096,605.084 993.105,605.084 993.114,605.084 993.124,605.084 993.133,605.083 993.142,605.083 993.151,605.083 993.16,605.083 993.17,605.083 993.179,605.083 993.188,605.083 993.197,605.083 993.206,605.083 993.215,605.082 993.225,605.082 993.234,605.082 993.243,605.082 993.252,605.082 993.261,605.082 993.271,605.082 993.28,605.082 993.289,605.082 993.298,605.082 993.307,605.081 993.317,605.081 993.326,605.081 993.335,605.081 993.344,605.081 993.353,605.081 993.363,605.081 993.372,605.081 993.381,605.081 993.39,605.08 993.399,605.08 993.408,605.08 993.418,605.08 993.427,605.08 993.436,605.08 993.445,605.08 993.454,605.08 993.464,605.08 993.473,605.079 993.482,605.079 993.491,605.079 993.5,605.079 993.51,605.079 993.519,605.079 993.528,605.079 993.537,605.079 993.546,605.079 993.555,605.079 993.565,605.078 993.574,605.078 993.583,605.078 993.592,605.078 993.601,605.078 993.611,605.078 993.62,605.078 993.629,605.078 993.638,605.078 993.647,605.077 993.657,605.077 993.666,605.077 993.675,605.077 993.684,605.077 993.693,605.077 993.703,605.077 993.712,605.077 993.721,605.077 993.73,605.076 993.739,605.076 993.748,605.076 993.758,605.076 993.767,605.076 993.776,605.076 993.785,605.076 993.794,605.076 993.804,605.076 993.813,605.076 993.822,605.075 993.831,605.075 993.84,605.075 993.85,605.075 993.859,605.075 993.868,605.075 993.877,605.075 993.886,605.075 993.895,605.075 993.905,605.074 993.914,605.074 993.923,605.074 993.932,605.074 993.941,605.074 993.951,605.074 993.96,605.074 993.969,605.074 993.978,605.074 993.987,605.074 993.997,605.073 994.006,605.073 994.015,605.073 994.024,605.073 994.033,605.073 994.043,605.073 994.052,605.073 994.061,605.073 994.07,605.073 994.079,605.072 994.088,605.072 994.098,605.072 994.107,605.072 994.116,605.072 994.125,605.072 994.134,605.072 994.144,605.072 994.153,605.072 994.162,605.071 994.171,605.071 994.18,605.071 994.19,605.071 994.199,605.071 994.208,605.071 994.217,605.071 994.226,605.071 994.235,605.071 994.245,605.071 994.254,605.07 994.263,605.07 994.272,605.07 994.281,605.07 994.291,605.07 994.3,605.07 994.309,605.07 994.318,605.07 994.327,605.07 994.337,605.069 994.346,605.069 994.355,605.069 994.364,605.069 994.373,605.069 994.383,605.069 994.392,605.069 994.401,605.069 994.41,605.069 994.419,605.069 994.428,605.068 994.438,605.068 994.447,605.068 994.456,605.068 994.465,605.068 994.474,605.068 994.484,605.068 994.493,605.068 994.502,605.068 994.511,605.067 994.52,605.067 994.53,605.067 994.539,605.067 994.548,605.067 994.557,605.067 994.566,605.067 994.576,605.067 994.585,605.067 994.594,605.066 994.603,605.066 994.612,605.066 994.621,605.066 994.631,605.066 994.64,605.066 994.649,605.066 994.658,605.066 994.667,605.066 994.677,605.066 994.686,605.065 994.695,605.065 994.704,605.065 994.713,605.065 994.723,605.065 994.732,605.065 994.741,605.065 994.75,605.065 994.759,605.065 994.768,605.064 994.778,605.064 994.787,605.064 994.796,605.064 994.805,605.064 994.814,605.064 994.824,605.064 994.833,605.064 994.842,605.064 994.851,605.064 994.86,605.063 994.87,605.063 994.879,605.063 994.888,605.063 994.897,605.063 994.906,605.063 994.916,605.063 994.925,605.063 994.934,605.063 994.943,605.062 994.952,605.062 994.961,605.062 994.971,605.062 994.98,605.062 994.989,605.062 994.998,605.062 995.007,605.062 995.017,605.062 995.026,605.062 995.035,605.061 995.044,605.061 995.053,605.061 995.063,605.061 995.072,605.061 995.081,605.061 995.09,605.061 995.099,605.061 995.108,605.061 995.118,605.06 995.127,605.06 995.136,605.06 995.145,605.06 995.154,605.06 995.164,605.06 995.173,605.06 995.182,605.06 995.191,605.06 995.2,605.06 995.21,605.059 995.219,605.059 995.228,605.059 995.237,605.059 995.246,605.059 995.256,605.059 995.265,605.059 995.274,605.059 995.283,605.059 995.292,605.058 995.301,605.058 995.311,605.058 995.32,605.058 995.329,605.058 995.338,605.058 995.347,605.058 995.357,605.058 995.366,605.058 995.375,605.057 995.384,605.057 995.393,605.057 995.403,605.057 995.412,605.057 995.421,605.057 995.43,605.057 995.439,605.057 995.448,605.057 995.458,605.057 995.467,605.056 995.476,605.056 995.485,605.056 995.494,605.056 995.504,605.056 995.513,605.056 995.522,605.056 995.531,605.056 995.54,605.056 995.55,605.055 995.559,605.055 995.568,605.055 995.577,605.055 995.586,605.055 995.596,605.055 995.605,605.055 995.614,605.055 995.623,605.055 995.632,605.055 995.641,605.054 995.651,605.054 995.66,605.054 995.669,605.054 995.678,605.054 995.687,605.054 995.697,605.054 995.706,605.054 995.715,605.054 995.724,605.053 995.733,605.053 995.743,605.053 995.752,605.053 995.761,605.053 995.77,605.053 995.779,605.053 995.788,605.053 995.798,605.053 995.807,605.053 995.816,605.052 995.825,605.052 995.834,605.052 995.844,605.052 995.853,605.052 995.862,605.052 995.871,605.052 995.88,605.052 995.89,605.052 995.899,605.051 995.908,605.051 995.917,605.051 995.926,605.051 995.936,605.051 995.945,605.051 995.954,605.051 995.963,605.051 995.972,605.051 995.981,605.051 995.991,605.05 996,605.05 996.009,605.05 996.018,605.05 996.027,605.05 996.037,605.05 996.046,605.05 996.055,605.05 996.064,605.05 996.073,605.049 996.083,605.049 996.092,605.049 996.101,605.049 996.11,605.049 996.119,605.049 996.128,605.049 996.138,605.049 996.147,605.049 996.156,605.049 996.165,605.048 996.174,605.048 996.184,605.048 996.193,605.048 996.202,605.048 996.211,605.048 996.22,605.048 996.23,605.048 996.239,605.048 996.248,605.047 996.257,605.047 996.266,605.047 996.276,605.047 996.285,605.047 996.294,605.047 996.303,605.047 996.312,605.047 996.321,605.047 996.331,605.047 996.34,605.046 996.349,605.046 996.358,605.046 996.367,605.046 996.377,605.046 996.386,605.046 996.395,605.046 996.404,605.046 996.413,605.046 996.423,605.045 996.432,605.045 996.441,605.045 996.45,605.045 996.459,605.045 996.468,605.045 996.478,605.045 996.487,605.045 996.496,605.045 996.505,605.045 996.514,605.044 996.524,605.044 996.533,605.044 996.542,605.044 996.551,605.044 996.56,605.044 996.57,605.044 996.579,605.044 996.588,605.044 996.597,605.043 996.606,605.043 996.616,605.043 996.625,605.043 996.634,605.043 996.643,605.043 996.652,605.043 996.661,605.043 996.671,605.043 996.68,605.043 996.689,605.042 996.698,605.042 996.707,605.042 996.717,605.042 996.726,605.042 996.735,605.042 996.744,605.042 996.753,605.042 996.763,605.042 996.772,605.041 996.781,605.041 996.79,605.041 996.799,605.041 996.808,605.041 996.818,605.041 996.827,605.041 996.836,605.041 996.845,605.041 996.854,605.041 996.864,605.04 996.873,605.04 996.882,605.04 996.891,605.04 996.9,605.04 996.91,605.04 996.919,605.04 996.928,605.04 996.937,605.04 996.946,605.04 996.956,605.039 996.965,605.039 996.974,605.039 996.983,605.039 996.992,605.039 997.001,605.039 997.011,605.039 997.02,605.039 997.029,605.039 997.038,605.038 997.047,605.038 997.057,605.038 997.066,605.038 997.075,605.038 997.084,605.038 997.093,605.038 997.103,605.038 997.112,605.038 997.121,605.038 997.13,605.037 997.139,605.037 997.149,605.037 997.158,605.037 997.167,605.037 997.176,605.037 997.185,605.037 997.194,605.037 997.204,605.037 997.213,605.036 997.222,605.036 997.231,605.036 997.24,605.036 997.25,605.036 997.259,605.036 997.268,605.036 997.277,605.036 997.286,605.036 997.296,605.036 997.305,605.035 997.314,605.035 997.323,605.035 997.332,605.035 997.341,605.035 997.351,605.035 997.36,605.035 997.369,605.035 997.378,605.035 997.387,605.034 997.397,605.034 997.406,605.034 997.415,605.034 997.424,605.034 997.433,605.034 997.443,605.034 997.452,605.034 997.461,605.034 997.47,605.034 997.479,605.033 997.489,605.033 997.498,605.033 997.507,605.033 997.516,605.033 997.525,605.033 997.534,605.033 997.544,605.033 997.553,605.033 997.562,605.032 997.571,605.032 997.58,605.032 997.59,605.032 997.599,605.032 997.608,605.032 997.617,605.032 997.626,605.032 997.636,605.032 997.645,605.032 997.654,605.031 997.663,605.031 997.672,605.031 997.681,605.031 997.691,605.031 997.7,605.031 997.709,605.031 997.718,605.031 997.727,605.031 997.737,605.031 997.746,605.03 997.755,605.03 997.764,605.03 997.773,605.03 997.783,605.03 997.792,605.03 997.801,605.03 997.81,605.03 997.819,605.03 997.829,605.029 997.838,605.029 997.847,605.029 997.856,605.029 997.865,605.029 997.874,605.029 997.884,605.029 997.893,605.029 997.902,605.029 997.911,605.029 997.92,605.028 997.93,605.028 997.939,605.028 997.948,605.028 997.957,605.028 997.966,605.028 997.976,605.028 997.985,605.028 997.994,605.028 998.003,605.027 998.012,605.027 998.021,605.027 998.031,605.027 998.04,605.027 998.049,605.027 998.058,605.027 998.067,605.027 998.077,605.027 998.086,605.027 998.095,605.026 998.104,605.026 998.113,605.026 998.123,605.026 998.132,605.026 998.141,605.026 998.15,605.026 998.159,605.026 998.169,605.026 998.178,605.026 998.187,605.025 998.196,605.025 998.205,605.025 998.214,605.025 998.224,605.025 998.233,605.025 998.242,605.025 998.251,605.025 998.26,605.025 998.27,605.024 998.279,605.024 998.288,605.024 998.297,605.024 998.306,605.024 998.316,605.024 998.325,605.024 998.334,605.024 998.343,605.024 998.352,605.024 998.361,605.023 998.371,605.023 998.38,605.023 998.389,605.023 998.398,605.023 998.407,605.023 998.417,605.023 998.426,605.023 998.435,605.023 998.444,605.022 998.453,605.022 998.463,605.022 998.472,605.022 998.481,605.022 998.49,605.022 998.499,605.022 998.509,605.022 998.518,605.022 998.527,605.022 998.536,605.021 998.545,605.021 998.554,605.021 998.564,605.021 998.573,605.021 998.582,605.021 998.591,605.021 998.6,605.021 998.61,605.021 998.619,605.021 998.628,605.02 998.637,605.02 998.646,605.02 998.656,605.02 998.665,605.02 998.674,605.02 998.683,605.02 998.692,605.02 998.701,605.02 998.711,605.019 998.72,605.019 998.729,605.019 998.738,605.019 998.747,605.019 998.757,605.019 998.766,605.019 998.775,605.019 998.784,605.019 998.793,605.019 998.803,605.018 998.812,605.018 998.821,605.018 998.83,605.018 998.839,605.018 998.849,605.018 998.858,605.018 998.867,605.018 998.876,605.018 998.885,605.018 998.894,605.017 998.904,605.017 998.913,605.017 998.922,605.017 998.931,605.017 998.94,605.017 998.95,605.017 998.959,605.017 998.968,605.017 998.977,605.016 998.986,605.016 998.996,605.016 999.005,605.016 999.014,605.016 999.023,605.016 999.032,605.016 999.041,605.016 999.051,605.016 999.06,605.016 999.069,605.015 999.078,605.015 999.087,605.015 999.097,605.015 999.106,605.015 999.115,605.015 999.124,605.015 999.133,605.015 999.143,605.015 999.152,605.014 999.161,605.014 999.17,605.014 999.179,605.014 999.189,605.014 999.198,605.014 999.207,605.014 999.216,605.014 999.225,605.014 999.234,605.014 999.244,605.013 999.253,605.013 999.262,605.013 999.271,605.013 999.28,605.013 999.29,605.013 999.299,605.013 999.308,605.013 999.317,605.013 999.326,605.013 999.336,605.012 999.345,605.012 999.354,605.012 999.363,605.012 999.372,605.012 999.381,605.012 999.391,605.012 999.4,605.012 999.409,605.012 999.418,605.011 999.427,605.011 999.437,605.011 999.446,605.011 999.455,605.011 999.464,605.011 999.473,605.011 999.483,605.011 999.492,605.011 999.501,605.011 999.51,605.01 999.519,605.01 999.529,605.01 999.538,605.01 999.547,605.01 999.556,605.01 999.565,605.01 999.574,605.01 999.584,605.01 999.593,605.01 999.602,605.009 999.611,605.009 999.62,605.009 999.63,605.009 999.639,605.009 999.648,605.009 999.657,605.009 999.666,605.009 999.676,605.009 999.685,605.008 999.694,605.008 999.703,605.008 999.712,605.008 999.722,605.008 999.731,605.008 999.74,605.008 999.749,605.008 999.758,605.008 999.767,605.008 999.777,605.007 999.786,605.007 999.795,605.007 999.804,605.007 999.813,605.007 999.823,605.007 999.832,605.007 999.841,605.007 999.85,605.007 999.859,605.007 999.869,605.006 999.878,605.006 999.887,605.006 999.896,605.006 999.905,605.006 999.914,605.006 999.924,605.006 999.933,605.006 999.942,605.006 999.951,605.006 999.96,605.005 999.97,605.005 999.979,605.005 999.988,605.005 999.997,605.005 1000.01,605.005 1000.02,605.005 1000.02,605.005 1000.03,605.005 1000.04,605.004 1000.05,605.004 1000.06,605.004 1000.07,605.004 1000.08,605.004 1000.09,605.004 1000.1,605.004 1000.11,605.004 1000.12,605.004 1000.13,605.004 1000.14,605.003 1000.14,605.003 1000.15,605.003 1000.16,605.003 1000.17,605.003 1000.18,605.003 1000.19,605.003 1000.2,605.003 1000.21,605.003 1000.22,605.003 1000.23,605.002 1000.24,605.002 1000.25,605.002 1000.25,605.002 1000.26,605.002 1000.27,605.002 1000.28,605.002 1000.29,605.002 1000.3,605.002 1000.31,605.001 1000.32,605.001 1000.33,605.001 1000.34,605.001 1000.35,605.001 1000.36,605.001 1000.36,605.001 1000.37,605.001 1000.38,605.001 1000.39,605.001 1000.4,605 1000.41,605 1000.42,605 1000.43,605 1000.44,605 1000.45,605 1000.46,605 1000.47,605 1000.48,605 1000.48,605 1000.49,604.999 1000.5,604.999 1000.51,604.999 1000.52,604.999 1000.53,604.999 1000.54,604.999 1000.55,604.999 1000.56,604.999 1000.57,604.999 1000.58,604.999 1000.59,604.998 1000.59,604.998 1000.6,604.998 1000.61,604.998 1000.62,604.998 1000.63,604.998 1000.64,604.998 1000.65,604.998 1000.66,604.998 1000.67,604.997 1000.68,604.997 1000.69,604.997 1000.7,604.997 1000.7,604.997 1000.71,604.997 1000.72,604.997 1000.73,604.997 1000.74,604.997 1000.75,604.997 1000.76,604.996 1000.77,604.996 1000.78,604.996 1000.79,604.996 1000.8,604.996 1000.81,604.996 1000.82,604.996 1000.82,604.996 1000.83,604.996 1000.84,604.996 1000.85,604.995 1000.86,604.995 1000.87,604.995 1000.88,604.995 1000.89,604.995 1000.9,604.995 1000.91,604.995 1000.92,604.995 1000.93,604.995 1000.93,604.994 1000.94,604.994 1000.95,604.994 1000.96,604.994 1000.97,604.994 1000.98,604.994 1000.99,604.994 1001,604.994 1001.01,604.994 1001.02,604.994 1001.03,604.993 1001.04,604.993 1001.04,604.993 1001.05,604.993 1001.06,604.993 1001.07,604.993 1001.08,604.993 1001.09,604.993 1001.1,604.993 1001.11,604.993 1001.12,604.992 1001.13,604.992 1001.14,604.992 1001.15,604.992 1001.16,604.992 1001.16,604.992 1001.17,604.992 1001.18,604.992 1001.19,604.992 1001.2,604.992 1001.21,604.991 1001.22,604.991 1001.23,604.991 1001.24,604.991 1001.25,604.991 1001.26,604.991 1001.27,604.991 1001.27,604.991 1001.28,604.991 1001.29,604.99 1001.3,604.99 1001.31,604.99 1001.32,604.99 1001.33,604.99 1001.34,604.99 1001.35,604.99 1001.36,604.99 1001.37,604.99 1001.38,604.99 1001.38,604.989 1001.39,604.989 1001.4,604.989 1001.41,604.989 1001.42,604.989 1001.43,604.989 1001.44,604.989 1001.45,604.989 1001.46,604.989 1001.47,604.989 1001.48,604.988 1001.49,604.988 1001.5,604.988 1001.5,604.988 1001.51,604.988 1001.52,604.988 1001.53,604.988 1001.54,604.988 1001.55,604.988 1001.56,604.988 1001.57,604.987 1001.58,604.987 1001.59,604.987 1001.6,604.987 1001.61,604.987 1001.61,604.987 1001.62,604.987 1001.63,604.987 1001.64,604.987 1001.65,604.987 1001.66,604.986 1001.67,604.986 1001.68,604.986 1001.69,604.986 1001.7,604.986 1001.71,604.986 1001.72,604.986 1001.72,604.986 1001.73,604.986 1001.74,604.985 1001.75,604.985 1001.76,604.985 1001.77,604.985 1001.78,604.985 1001.79,604.985 1001.8,604.985 1001.81,604.985 1001.82,604.985 1001.83,604.985 1001.84,604.984 1001.84,604.984 1001.85,604.984 1001.86,604.984 1001.87,604.984 1001.88,604.984 1001.89,604.984 1001.9,604.984 1001.91,604.984 1001.92,604.984 1001.93,604.983 1001.94,604.983 1001.95,604.983 1001.95,604.983 1001.96,604.983 1001.97,604.983 1001.98,604.983 1001.99,604.983 1002,604.983 1002.01,604.983 1002.02,604.982 1002.03,604.982 1002.04,604.982 1002.05,604.982 1002.06,604.982 1002.06,604.982 1002.07,604.982 1002.08,604.982 1002.09,604.982 1002.1,604.982 1002.11,604.981 1002.12,604.981 1002.13,604.981 1002.14,604.981 1002.15,604.981 1002.16,604.981 1002.17,604.981 1002.18,604.981 1002.18,604.981 1002.19,604.98 1002.2,604.98 1002.21,604.98 1002.22,604.98 1002.23,604.98 1002.24,604.98 1002.25,604.98 1002.26,604.98 1002.27,604.98 1002.28,604.98 1002.29,604.979 1002.29,604.979 1002.3,604.979 1002.31,604.979 1002.32,604.979 1002.33,604.979 1002.34,604.979 1002.35,604.979 1002.36,604.979 1002.37,604.979 1002.38,604.978 1002.39,604.978 1002.4,604.978 1002.4,604.978 1002.41,604.978 1002.42,604.978 1002.43,604.978 1002.44,604.978 1002.45,604.978 1002.46,604.978 1002.47,604.977 1002.48,604.977 1002.49,604.977 1002.5,604.977 1002.51,604.977 1002.52,604.977 1002.52,604.977 1002.53,604.977 1002.54,604.977 1002.55,604.977 1002.56,604.976 1002.57,604.976 1002.58,604.976 1002.59,604.976 1002.6,604.976 1002.61,604.976 1002.62,604.976 1002.63,604.976 1002.63,604.976 1002.64,604.975 1002.65,604.975 1002.66,604.975 1002.67,604.975 1002.68,604.975 1002.69,604.975 1002.7,604.975 1002.71,604.975 1002.72,604.975 1002.73,604.975 1002.74,604.974 1002.74,604.974 1002.75,604.974 1002.76,604.974 1002.77,604.974 1002.78,604.974 1002.79,604.974 1002.8,604.974 1002.81,604.974 1002.82,604.974 1002.83,604.973 1002.84,604.973 1002.85,604.973 1002.86,604.973 1002.86,604.973 1002.87,604.973 1002.88,604.973 1002.89,604.973 1002.9,604.973 1002.91,604.973 1002.92,604.972 1002.93,604.972 1002.94,604.972 1002.95,604.972 1002.96,604.972 1002.97,604.972 1002.97,604.972 1002.98,604.972 1002.99,604.972 1003,604.972 1003.01,604.971 1003.02,604.971 1003.03,604.971 1003.04,604.971 1003.05,604.971 1003.06,604.971 1003.07,604.971 1003.08,604.971 1003.08,604.971 1003.09,604.971 1003.1,604.97 1003.11,604.97 1003.12,604.97 1003.13,604.97 1003.14,604.97 1003.15,604.97 1003.16,604.97 1003.17,604.97 1003.18,604.97 1003.19,604.969 1003.2,604.969 1003.2,604.969 1003.21,604.969 1003.22,604.969 1003.23,604.969 1003.24,604.969 1003.25,604.969 1003.26,604.969 1003.27,604.969 1003.28,604.968 1003.29,604.968 1003.3,604.968 1003.31,604.968 1003.31,604.968 1003.32,604.968 1003.33,604.968 1003.34,604.968 1003.35,604.968 1003.36,604.968 1003.37,604.967 1003.38,604.967 1003.39,604.967 1003.4,604.967 1003.41,604.967 1003.42,604.967 1003.42,604.967 1003.43,604.967 1003.44,604.967 1003.45,604.967 1003.46,604.966 1003.47,604.966 1003.48,604.966 1003.49,604.966 1003.5,604.966 1003.51,604.966 1003.52,604.966 1003.53,604.966 1003.54,604.966 1003.54,604.966 1003.55,604.965 1003.56,604.965 1003.57,604.965 1003.58,604.965 1003.59,604.965 1003.6,604.965 1003.61,604.965 1003.62,604.965 1003.63,604.965 1003.64,604.965 1003.65,604.964 1003.65,604.964 1003.66,604.964 1003.67,604.964 1003.68,604.964 1003.69,604.964 1003.7,604.964 1003.71,604.964 1003.72,604.964 1003.73,604.964 1003.74,604.963 1003.75,604.963 1003.76,604.963 1003.76,604.963 1003.77,604.963 1003.78,604.963 1003.79,604.963 1003.8,604.963 1003.81,604.963 1003.82,604.963 1003.83,604.962 1003.84,604.962 1003.85,604.962 1003.86,604.962 1003.87,604.962 1003.88,604.962 1003.88,604.962 1003.89,604.962 1003.9,604.962 1003.91,604.962 1003.92,604.961 1003.93,604.961 1003.94,604.961 1003.95,604.961 1003.96,604.961 1003.97,604.961 1003.98,604.961 1003.99,604.961 1003.99,604.961 1004,604.96 1004.01,604.96 1004.02,604.96 1004.03,604.96 1004.04,604.96 1004.05,604.96 1004.06,604.96 1004.07,604.96 1004.08,604.96 1004.09,604.96 1004.1,604.959 1004.1,604.959 1004.11,604.959 1004.12,604.959 1004.13,604.959 1004.14,604.959 1004.15,604.959 1004.16,604.959 1004.17,604.959 1004.18,604.959 1004.19,604.958 1004.2,604.958 1004.21,604.958 1004.22,604.958 1004.22,604.958 1004.23,604.958 1004.24,604.958 1004.25,604.958 1004.26,604.958 1004.27,604.958 1004.28,604.957 1004.29,604.957 1004.3,604.957 1004.31,604.957 1004.32,604.957 1004.33,604.957 1004.33,604.957 1004.34,604.957 1004.35,604.957 1004.36,604.957 1004.37,604.956 1004.38,604.956 1004.39,604.956 1004.4,604.956 1004.41,604.956 1004.42,604.956 1004.43,604.956 1004.44,604.956 1004.44,604.956 1004.45,604.956 1004.46,604.955 1004.47,604.955 1004.48,604.955 1004.49,604.955 1004.5,604.955 1004.51,604.955 1004.52,604.955 1004.53,604.955 1004.54,604.955 1004.55,604.955 1004.56,604.954 1004.56,604.954 1004.57,604.954 1004.58,604.954 1004.59,604.954 1004.6,604.954 1004.61,604.954 1004.62,604.954 1004.63,604.954 1004.64,604.954 1004.65,604.953 1004.66,604.953 1004.67,604.953 1004.67,604.953 1004.68,604.953 1004.69,604.953 1004.7,604.953 1004.71,604.953 1004.72,604.953 1004.73,604.953 1004.74,604.952 1004.75,604.952 1004.76,604.952 1004.77,604.952 1004.78,604.952 1004.78,604.952 1004.79,604.952 1004.8,604.952 1004.81,604.952 1004.82,604.952 1004.83,604.951 1004.84,604.951 1004.85,604.951 1004.86,604.951 1004.87,604.951 1004.88,604.951 1004.89,604.951 1004.9,604.951 1004.9,604.951 1004.91,604.951 1004.92,604.95 1004.93,604.95 1004.94,604.95 1004.95,604.95 1004.96,604.95 1004.97,604.95 1004.98,604.95 1004.99,604.95 1005,604.95 1005.01,604.95 1005.01,604.949 1005.02,604.949 1005.03,604.949 1005.04,604.949 1005.05,604.949 1005.06,604.949 1005.07,604.949 1005.08,604.949 1005.09,604.949 1005.1,604.949 1005.11,604.948 1005.12,604.948 1005.12,604.948 1005.13,604.948 1005.14,604.948 1005.15,604.948 1005.16,604.948 1005.17,604.948 1005.18,604.948 1005.19,604.947 1005.2,604.947 1005.21,604.947 1005.22,604.947 1005.23,604.947 1005.24,604.947 1005.24,604.947 1005.25,604.947 1005.26,604.947 1005.27,604.947 1005.28,604.946 1005.29,604.946 1005.3,604.946 1005.31,604.946 1005.32,604.946 1005.33,604.946 1005.34,604.946 1005.35,604.946 1005.35,604.946 1005.36,604.946 1005.37,604.945 1005.38,604.945 1005.39,604.945 1005.4,604.945 1005.41,604.945 1005.42,604.945 1005.43,604.945 1005.44,604.945 1005.45,604.945 1005.46,604.945 1005.46,604.944 1005.47,604.944 1005.48,604.944 1005.49,604.944 1005.5,604.944 1005.51,604.944 1005.52,604.944 1005.53,604.944 1005.54,604.944 1005.55,604.944 1005.56,604.943 1005.57,604.943 1005.58,604.943 1005.58,604.943 1005.59,604.943 1005.6,604.943 1005.61,604.943 1005.62,604.943 1005.63,604.943 1005.64,604.943 1005.65,604.942 1005.66,604.942 1005.67,604.942 1005.68,604.942 1005.69,604.942 1005.69,604.942 1005.7,604.942 1005.71,604.942 1005.72,604.942 1005.73,604.942 1005.74,604.941 1005.75,604.941 1005.76,604.941 1005.77,604.941 1005.78,604.941 1005.79,604.941 1005.8,604.941 1005.8,604.941 1005.81,604.941 1005.82,604.941 1005.83,604.94 1005.84,604.94 1005.85,604.94 1005.86,604.94 1005.87,604.94 1005.88,604.94 1005.89,604.94 1005.9,604.94 1005.91,604.94 1005.92,604.94 1005.92,604.939 1005.93,604.939 1005.94,604.939 1005.95,604.939 1005.96,604.939 1005.97,604.939 1005.98,604.939 1005.99,604.939 1006,604.939 1006.01,604.939 1006.02,604.938 1006.03,604.938 1006.03,604.938 1006.04,604.938 1006.05,604.938 1006.06,604.938 1006.07,604.938 1006.08,604.938 1006.09,604.938 1006.1,604.938 1006.11,604.937 1006.12,604.937 1006.13,604.937 1006.14,604.937 1006.14,604.937 1006.15,604.937 1006.16,604.937 1006.17,604.937 1006.18,604.937 1006.19,604.937 1006.2,604.936 1006.21,604.936 1006.22,604.936 1006.23,604.936 1006.24,604.936 1006.25,604.936 1006.26,604.936 1006.26,604.936 1006.27,604.936 1006.28,604.936 1006.29,604.935 1006.3,604.935 1006.31,604.935 1006.32,604.935 1006.33,604.935 1006.34,604.935 1006.35,604.935 1006.36,604.935 1006.37,604.935 1006.37,604.935 1006.38,604.934 1006.39,604.934 1006.4,604.934 1006.41,604.934 1006.42,604.934 1006.43,604.934 1006.44,604.934 1006.45,604.934 1006.46,604.934 1006.47,604.934 1006.48,604.933 1006.48,604.933 1006.49,604.933 1006.5,604.933 1006.51,604.933 1006.52,604.933 1006.53,604.933 1006.54,604.933 1006.55,604.933 1006.56,604.933 1006.57,604.932 1006.58,604.932 1006.59,604.932 1006.6,604.932 1006.6,604.932 1006.61,604.932 1006.62,604.932 1006.63,604.932 1006.64,604.932 1006.65,604.932 1006.66,604.931 1006.67,604.931 1006.68,604.931 1006.69,604.931 1006.7,604.931 1006.71,604.931 1006.71,604.931 1006.72,604.931 1006.73,604.931 1006.74,604.931 1006.75,604.93 1006.76,604.93 1006.77,604.93 1006.78,604.93 1006.79,604.93 1006.8,604.93 1006.81,604.93 1006.82,604.93 1006.82,604.93 1006.83,604.93 1006.84,604.929 1006.85,604.929 1006.86,604.929 1006.87,604.929 1006.88,604.929 1006.89,604.929 1006.9,604.929 1006.91,604.929 1006.92,604.929 1006.93,604.929 1006.94,604.929 1006.94,604.928 1006.95,604.928 1006.96,604.928 1006.97,604.928 1006.98,604.928 1006.99,604.928 1007,604.928 1007.01,604.928 1007.02,604.928 1007.03,604.928 1007.04,604.927 1007.05,604.927 1007.05,604.927 1007.06,604.927 1007.07,604.927 1007.08,604.927 1007.09,604.927 1007.1,604.927 1007.11,604.927 1007.12,604.927 1007.13,604.926 1007.14,604.926 1007.15,604.926 1007.16,604.926 1007.16,604.926 1007.17,604.926 1007.18,604.926 1007.19,604.926 1007.2,604.926 1007.21,604.926 1007.22,604.925 1007.23,604.925 1007.24,604.925 1007.25,604.925 1007.26,604.925 1007.27,604.925 1007.28,604.925 1007.28,604.925 1007.29,604.925 1007.3,604.925 1007.31,604.924 1007.32,604.924 1007.33,604.924 1007.34,604.924 1007.35,604.924 1007.36,604.924 1007.37,604.924 1007.38,604.924 1007.39,604.924 1007.39,604.924 1007.4,604.923 1007.41,604.923 1007.42,604.923 1007.43,604.923 1007.44,604.923 1007.45,604.923 1007.46,604.923 1007.47,604.923 1007.48,604.923 1007.49,604.923 1007.5,604.922 1007.5,604.922 1007.51,604.922 1007.52,604.922 1007.53,604.922 1007.54,604.922 1007.55,604.922 1007.56,604.922 1007.57,604.922 1007.58,604.922 1007.59,604.921 1007.6,604.921 1007.61,604.921 1007.62,604.921 1007.62,604.921 1007.63,604.921 1007.64,604.921 1007.65,604.921 1007.66,604.921 1007.67,604.921 1007.68,604.92 1007.69,604.92 1007.7,604.92 1007.71,604.92 1007.72,604.92 1007.73,604.92 1007.73,604.92 1007.74,604.92 1007.75,604.92 1007.76,604.92 1007.77,604.919 1007.78,604.919 1007.79,604.919 1007.8,604.919 1007.81,604.919 1007.82,604.919 1007.83,604.919 1007.84,604.919 1007.84,604.919 1007.85,604.919 1007.86,604.918 1007.87,604.918 1007.88,604.918 1007.89,604.918 1007.9,604.918 1007.91,604.918 1007.92,604.918 1007.93,604.918 1007.94,604.918 1007.95,604.918 1007.96,604.917 1007.96,604.917 1007.97,604.917 1007.98,604.917 1007.99,604.917 1008,604.917 1008.01,604.917 1008.02,604.917 1008.03,604.917 1008.04,604.917 1008.05,604.916 1008.06,604.916 1008.07,604.916 1008.07,604.916 1008.08,604.916 1008.09,604.916 1008.1,604.916 1008.11,604.916 1008.12,604.916 1008.13,604.916 1008.14,604.916 1008.15,604.915 1008.16,604.915 1008.17,604.915 1008.18,604.915 1008.18,604.915 1008.19,604.915 1008.2,604.915 1008.21,604.915 1008.22,604.915 1008.23,604.915 1008.24,604.914 1008.25,604.914 1008.26,604.914 1008.27,604.914 1008.28,604.914 1008.29,604.914 1008.3,604.914 1008.3,604.914 1008.31,604.914 1008.32,604.914 1008.33,604.913 1008.34,604.913 1008.35,604.913 1008.36,604.913 1008.37,604.913 1008.38,604.913 1008.39,604.913 1008.4,604.913 1008.41,604.913 1008.41,604.913 1008.42,604.912 1008.43,604.912 1008.44,604.912 1008.45,604.912 1008.46,604.912 1008.47,604.912 1008.48,604.912 1008.49,604.912 1008.5,604.912 1008.51,604.912 1008.52,604.911 1008.52,604.911 1008.53,604.911 1008.54,604.911 1008.55,604.911 1008.56,604.911 1008.57,604.911 1008.58,604.911 1008.59,604.911 1008.6,604.911 1008.61,604.91 1008.62,604.91 1008.63,604.91 1008.64,604.91 1008.64,604.91 1008.65,604.91 1008.66,604.91 1008.67,604.91 1008.68,604.91 1008.69,604.91 1008.7,604.909 1008.71,604.909 1008.72,604.909 1008.73,604.909 1008.74,604.909 1008.75,604.909 1008.75,604.909 1008.76,604.909 1008.77,604.909 1008.78,604.909 1008.79,604.908 1008.8,604.908 1008.81,604.908 1008.82,604.908 1008.83,604.908 1008.84,604.908 1008.85,604.908 1008.86,604.908 1008.86,604.908 1008.87,604.908 1008.88,604.908 1008.89,604.907 1008.9,604.907 1008.91,604.907 1008.92,604.907 1008.93,604.907 1008.94,604.907 1008.95,604.907 1008.96,604.907 1008.97,604.907 1008.98,604.907 1008.98,604.906 1008.99,604.906 1009,604.906 1009.01,604.906 1009.02,604.906 1009.03,604.906 1009.04,604.906 1009.05,604.906 1009.06,604.906 1009.07,604.906 1009.08,604.905 1009.09,604.905 1009.09,604.905 1009.1,604.905 1009.11,604.905 1009.12,604.905 1009.13,604.905 1009.14,604.905 1009.15,604.905 1009.16,604.905 1009.17,604.904 1009.18,604.904 1009.19,604.904 1009.2,604.904 1009.2,604.904 1009.21,604.904 1009.22,604.904 1009.23,604.904 1009.24,604.904 1009.25,604.904 1009.26,604.903 1009.27,604.903 1009.28,604.903 1009.29,604.903 1009.3,604.903 1009.31,604.903 1009.32,604.903 1009.32,604.903 1009.33,604.903 1009.34,604.903 1009.35,604.902 1009.36,604.902 1009.37,604.902 1009.38,604.902 1009.39,604.902 1009.4,604.902 1009.41,604.902 1009.42,604.902 1009.43,604.902 1009.43,604.902 1009.44,604.901 1009.45,604.901 1009.46,604.901 1009.47,604.901 1009.48,604.901 1009.49,604.901 1009.5,604.901 1009.51,604.901 1009.52,604.901 1009.53,604.901 1009.54,604.901 1009.54,604.9 1009.55,604.9 1009.56,604.9 1009.57,604.9 1009.58,604.9 1009.59,604.9 1009.6,604.9 1009.61,604.9 1009.62,604.9 1009.63,604.9 1009.64,604.899 1009.65,604.899 1009.66,604.899 1009.66,604.899 1009.67,604.899 1009.68,604.899 1009.69,604.899 1009.7,604.899 1009.71,604.899 1009.72,604.899 1009.73,604.898 1009.74,604.898 1009.75,604.898 1009.76,604.898 1009.77,604.898 1009.77,604.898 1009.78,604.898 1009.79,604.898 1009.8,604.898 1009.81,604.898 1009.82,604.897 1009.83,604.897 1009.84,604.897 1009.85,604.897 1009.86,604.897 1009.87,604.897 1009.88,604.897 1009.88,604.897 1009.89,604.897 1009.9,604.897 1009.91,604.896 1009.92,604.896 1009.93,604.896 1009.94,604.896 1009.95,604.896 1009.96,604.896 1009.97,604.896 1009.98,604.896 1009.99,604.896 1010,604.896 1010,604.896 1010.01,604.895 1010.02,604.895 1010.03,604.895 1010.04,604.895 1010.05,604.895 1010.06,604.895 1010.07,604.895 1010.08,604.895 1010.09,604.895 1010.1,604.895 1010.11,604.894 1010.11,604.894 1010.12,604.894 1010.13,604.894 1010.14,604.894 1010.15,604.894 1010.16,604.894 1010.17,604.894 1010.18,604.894 1010.19,604.894 1010.2,604.893 1010.21,604.893 1010.22,604.893 1010.22,604.893 1010.23,604.893 1010.24,604.893 1010.25,604.893 1010.26,604.893 1010.27,604.893 1010.28,604.893 1010.29,604.892 1010.3,604.892 1010.31,604.892 1010.32,604.892 1010.33,604.892 1010.34,604.892 1010.34,604.892 1010.35,604.892 1010.36,604.892 1010.37,604.892 1010.38,604.891 1010.39,604.891 1010.4,604.891 1010.41,604.891 1010.42,604.891 1010.43,604.891 1010.44,604.891 1010.45,604.891 1010.45,604.891 1010.46,604.891 1010.47,604.891 1010.48,604.89 1010.49,604.89 1010.5,604.89 1010.51,604.89 1010.52,604.89 1010.53,604.89 1010.54,604.89 1010.55,604.89 1010.56,604.89 1010.56,604.89 1010.57,604.889 1010.58,604.889 1010.59,604.889 1010.6,604.889 1010.61,604.889 1010.62,604.889 1010.63,604.889 1010.64,604.889 1010.65,604.889 1010.66,604.889 1010.67,604.888 1010.68,604.888 1010.68,604.888 1010.69,604.888 1010.7,604.888 1010.71,604.888 1010.72,604.888 1010.73,604.888 1010.74,604.888 1010.75,604.888 1010.76,604.887 1010.77,604.887 1010.78,604.887 1010.79,604.887 1010.79,604.887 1010.8,604.887 1010.81,604.887 1010.82,604.887 1010.83,604.887 1010.84,604.887 1010.85,604.887 1010.86,604.886 1010.87,604.886 1010.88,604.886 1010.89,604.886 1010.9,604.886 1010.9,604.886 1010.91,604.886 1010.92,604.886 1010.93,604.886 1010.94,604.886 1010.95,604.885 1010.96,604.885 1010.97,604.885 1010.98,604.885 1010.99,604.885 1011,604.885 1011.01,604.885 1011.02,604.885 1011.02,604.885 1011.03,604.885 1011.04,604.884 1011.05,604.884 1011.06,604.884 1011.07,604.884 1011.08,604.884 1011.09,604.884 1011.1,604.884 1011.11,604.884 1011.12,604.884 1011.13,604.884 1011.13,604.883 1011.14,604.883 1011.15,604.883 1011.16,604.883 1011.17,604.883 1011.18,604.883 1011.19,604.883 1011.2,604.883 1011.21,604.883 1011.22,604.883 1011.23,604.883 1011.24,604.882 1011.24,604.882 1011.25,604.882 1011.26,604.882 1011.27,604.882 1011.28,604.882 1011.29,604.882 1011.3,604.882 1011.31,604.882 1011.32,604.882 1011.33,604.881 1011.34,604.881 1011.35,604.881 1011.36,604.881 1011.36,604.881 1011.37,604.881 1011.38,604.881 1011.39,604.881 1011.4,604.881 1011.41,604.881 1011.42,604.88 1011.43,604.88 1011.44,604.88 1011.45,604.88 1011.46,604.88 1011.47,604.88 1011.47,604.88 1011.48,604.88 1011.49,604.88 1011.5,604.88 1011.51,604.879 1011.52,604.879 1011.53,604.879 1011.54,604.879 1011.55,604.879 1011.56,604.879 1011.57,604.879 1011.58,604.879 1011.58,604.879 1011.59,604.879 1011.6,604.879 1011.61,604.878 1011.62,604.878 1011.63,604.878 1011.64,604.878 1011.65,604.878 1011.66,604.878 1011.67,604.878 1011.68,604.878 1011.69,604.878 1011.7,604.878 1011.7,604.877 1011.71,604.877 1011.72,604.877 1011.73,604.877 1011.74,604.877 1011.75,604.877 1011.76,604.877 1011.77,604.877 1011.78,604.877 1011.79,604.877 1011.8,604.876 1011.81,604.876 1011.81,604.876 1011.82,604.876 1011.83,604.876 1011.84,604.876 1011.85,604.876 1011.86,604.876 1011.87,604.876 1011.88,604.876 1011.89,604.875 1011.9,604.875 1011.91,604.875 1011.92,604.875 1011.92,604.875 1011.93,604.875 1011.94,604.875 1011.95,604.875 1011.96,604.875 1011.97,604.875 1011.98,604.875 1011.99,604.874 1012,604.874 1012.01,604.874 1012.02,604.874 1012.03,604.874 1012.04,604.874 1012.04,604.874 1012.05,604.874 1012.06,604.874 1012.07,604.874 1012.08,604.873 1012.09,604.873 1012.1,604.873 1012.11,604.873 1012.12,604.873 1012.13,604.873 1012.14,604.873 1012.15,604.873 1012.15,604.873 1012.16,604.873 1012.17,604.872 1012.18,604.872 1012.19,604.872 1012.2,604.872 1012.21,604.872 1012.22,604.872 1012.23,604.872 1012.24,604.872 1012.25,604.872 1012.26,604.872 1012.26,604.872 1012.27,604.871 1012.28,604.871 1012.29,604.871 1012.3,604.871 1012.31,604.871 1012.32,604.871 1012.33,604.871 1012.34,604.871 1012.35,604.871 1012.36,604.871 1012.37,604.87 1012.38,604.87 1012.38,604.87 1012.39,604.87 1012.4,604.87 1012.41,604.87 1012.42,604.87 1012.43,604.87 1012.44,604.87 1012.45,604.87 1012.46,604.869 1012.47,604.869 1012.48,604.869 1012.49,604.869 1012.49,604.869 1012.5,604.869 1012.51,604.869 1012.52,604.869 1012.53,604.869 1012.54,604.869 1012.55,604.869 1012.56,604.868 1012.57,604.868 1012.58,604.868 1012.59,604.868 1012.6,604.868 1012.6,604.868 1012.61,604.868 1012.62,604.868 1012.63,604.868 1012.64,604.868 1012.65,604.867 1012.66,604.867 1012.67,604.867 1012.68,604.867 1012.69,604.867 1012.7,604.867 1012.71,604.867 1012.72,604.867 1012.72,604.867 1012.73,604.867 1012.74,604.866 1012.75,604.866 1012.76,604.866 1012.77,604.866 1012.78,604.866 1012.79,604.866 1012.8,604.866 1012.81,604.866 1012.82,604.866 1012.83,604.866 1012.83,604.866 1012.84,604.865 1012.85,604.865 1012.86,604.865 1012.87,604.865 1012.88,604.865 1012.89,604.865 1012.9,604.865 1012.91,604.865 1012.92,604.865 1012.93,604.865 1012.94,604.864 1012.94,604.864 1012.95,604.864 1012.96,604.864 1012.97,604.864 1012.98,604.864 1012.99,604.864 1013,604.864 1013.01,604.864 1013.02,604.864 1013.03,604.863 1013.04,604.863 1013.05,604.863 1013.06,604.863 1013.06,604.863 1013.07,604.863 1013.08,604.863 1013.09,604.863 1013.1,604.863 1013.11,604.863 1013.12,604.863 1013.13,604.862 1013.14,604.862 1013.15,604.862 1013.16,604.862 1013.17,604.862 1013.17,604.862 1013.18,604.862 1013.19,604.862 1013.2,604.862 1013.21,604.862 1013.22,604.861 1013.23,604.861 1013.24,604.861 1013.25,604.861 1013.26,604.861 1013.27,604.861 1013.28,604.861 1013.28,604.861 1013.29,604.861 1013.3,604.861 1013.31,604.86 1013.32,604.86 1013.33,604.86 1013.34,604.86 1013.35,604.86 1013.36,604.86 1013.37,604.86 1013.38,604.86 1013.39,604.86 1013.4,604.86 1013.4,604.86 1013.41,604.859 1013.42,604.859 1013.43,604.859 1013.44,604.859 1013.45,604.859 1013.46,604.859 1013.47,604.859 1013.48,604.859 1013.49,604.859 1013.5,604.859 1013.51,604.858 1013.51,604.858 1013.52,604.858 1013.53,604.858 1013.54,604.858 1013.55,604.858 1013.56,604.858 1013.57,604.858 1013.58,604.858 1013.59,604.858 1013.6,604.858 1013.61,604.857 1013.62,604.857 1013.62,604.857 1013.63,604.857 1013.64,604.857 1013.65,604.857 1013.66,604.857 1013.67,604.857 1013.68,604.857 1013.69,604.857 1013.7,604.856 1013.71,604.856 1013.72,604.856 1013.73,604.856 1013.74,604.856 1013.74,604.856 1013.75,604.856 1013.76,604.856 1013.77,604.856 1013.78,604.856 1013.79,604.855 1013.8,604.855 1013.81,604.855 1013.82,604.855 1013.83,604.855 1013.84,604.855 1013.85,604.855 1013.85,604.855 1013.86,604.855 1013.87,604.855 1013.88,604.855 1013.89,604.854 1013.9,604.854 1013.91,604.854 1013.92,604.854 1013.93,604.854 1013.94,604.854 1013.95,604.854 1013.96,604.854 1013.96,604.854 1013.97,604.854 1013.98,604.853 1013.99,604.853 1014,604.853 1014.01,604.853 1014.02,604.853 1014.03,604.853 1014.04,604.853 1014.05,604.853 1014.06,604.853 1014.07,604.853 1014.08,604.852 1014.08,604.852 1014.09,604.852 1014.1,604.852 1014.11,604.852 1014.12,604.852 1014.13,604.852 1014.14,604.852 1014.15,604.852 1014.16,604.852 1014.17,604.852 1014.18,604.851 1014.19,604.851 1014.19,604.851 1014.2,604.851 1014.21,604.851 1014.22,604.851 1014.23,604.851 1014.24,604.851 1014.25,604.851 1014.26,604.851 1014.27,604.85 1014.28,604.85 1014.29,604.85 1014.3,604.85 1014.3,604.85 1014.31,604.85 1014.32,604.85 1014.33,604.85 1014.34,604.85 1014.35,604.85 1014.36,604.85 1014.37,604.849 1014.38,604.849 1014.39,604.849 1014.4,604.849 1014.41,604.849 1014.42,604.849 1014.42,604.849 1014.43,604.849 1014.44,604.849 1014.45,604.849 1014.46,604.848 1014.47,604.848 1014.48,604.848 1014.49,604.848 1014.5,604.848 1014.51,604.848 1014.52,604.848 1014.53,604.848 1014.53,604.848 1014.54,604.848 1014.55,604.848 1014.56,604.847 1014.57,604.847 1014.58,604.847 1014.59,604.847 1014.6,604.847 1014.61,604.847 1014.62,604.847 1014.63,604.847 1014.64,604.847 1014.64,604.847 1014.65,604.846 1014.66,604.846 1014.67,604.846 1014.68,604.846 1014.69,604.846 1014.7,604.846 1014.71,604.846 1014.72,604.846 1014.73,604.846 1014.74,604.846 1014.75,604.845 1014.76,604.845 1014.76,604.845 1014.77,604.845 1014.78,604.845 1014.79,604.845 1014.8,604.845 1014.81,604.845 1014.82,604.845 1014.83,604.845 1014.84,604.845 1014.85,604.844 1014.86,604.844 1014.87,604.844 1014.87,604.844 1014.88,604.844 1014.89,604.844 1014.9,604.844 1014.91,604.844 1014.92,604.844 1014.93,604.844 1014.94,604.843 1014.95,604.843 1014.96,604.843 1014.97,604.843 1014.98,604.843 1014.98,604.843 1014.99,604.843 1015,604.843 1015.01,604.843 1015.02,604.843 1015.03,604.843 1015.04,604.842 1015.05,604.842 1015.06,604.842 1015.07,604.842 1015.08,604.842 1015.09,604.842 1015.1,604.842 1015.1,604.842 1015.11,604.842 1015.12,604.842 1015.13,604.841 1015.14,604.841 1015.15,604.841 1015.16,604.841 1015.17,604.841 1015.18,604.841 1015.19,604.841 1015.2,604.841 1015.21,604.841 1015.21,604.841 1015.22,604.841 1015.23,604.84 1015.24,604.84 1015.25,604.84 1015.26,604.84 1015.27,604.84 1015.28,604.84 1015.29,604.84 1015.3,604.84 1015.31,604.84 1015.32,604.84 1015.32,604.839 1015.33,604.839 1015.34,604.839 1015.35,604.839 1015.36,604.839 1015.37,604.839 1015.38,604.839 1015.39,604.839 1015.4,604.839 1015.41,604.839 1015.42,604.839 1015.43,604.838 1015.44,604.838 1015.44,604.838 1015.45,604.838 1015.46,604.838 1015.47,604.838 1015.48,604.838 1015.49,604.838 1015.5,604.838 1015.51,604.838 1015.52,604.837 1015.53,604.837 1015.54,604.837 1015.55,604.837 1015.55,604.837 1015.56,604.837 1015.57,604.837 1015.58,604.837 1015.59,604.837 1015.6,604.837 1015.61,604.836 1015.62,604.836 1015.63,604.836 1015.64,604.836 1015.65,604.836 1015.66,604.836 1015.66,604.836 1015.67,604.836 1015.68,604.836 1015.69,604.836 1015.7,604.836 1015.71,604.835 1015.72,604.835 1015.73,604.835 1015.74,604.835 1015.75,604.835 1015.76,604.835 1015.77,604.835 1015.78,604.835 1015.78,604.835 1015.79,604.835 1015.8,604.834 1015.81,604.834 1015.82,604.834 1015.83,604.834 1015.84,604.834 1015.85,604.834 1015.86,604.834 1015.87,604.834 1015.88,604.834 1015.89,604.834 1015.89,604.834 1015.9,604.833 1015.91,604.833 1015.92,604.833 1015.93,604.833 1015.94,604.833 1015.95,604.833 1015.96,604.833 1015.97,604.833 1015.98,604.833 1015.99,604.833 1016,604.832 1016,604.832 1016.01,604.832 1016.02,604.832 1016.03,604.832 1016.04,604.832 1016.05,604.832 1016.06,604.832 1016.07,604.832 1016.08,604.832 1016.09,604.832 1016.1,604.831 1016.11,604.831 1016.12,604.831 1016.12,604.831 1016.13,604.831 1016.14,604.831 1016.15,604.831 1016.16,604.831 1016.17,604.831 1016.18,604.831 1016.19,604.83 1016.2,604.83 1016.21,604.83 1016.22,604.83 1016.23,604.83 1016.23,604.83 1016.24,604.83 1016.25,604.83 1016.26,604.83 1016.27,604.83 1016.28,604.83 1016.29,604.829 1016.3,604.829 1016.31,604.829 1016.32,604.829 1016.33,604.829 1016.34,604.829 1016.34,604.829 1016.35,604.829 1016.36,604.829 1016.37,604.829 1016.38,604.828 1016.39,604.828 1016.4,604.828 1016.41,604.828 1016.42,604.828 1016.43,604.828 1016.44,604.828 1016.45,604.828 1016.46,604.828 1016.46,604.828 1016.47,604.828 1016.48,604.827 1016.49,604.827 1016.5,604.827 1016.51,604.827 1016.52,604.827 1016.53,604.827 1016.54,604.827 1016.55,604.827 1016.56,604.827 1016.57,604.827 1016.57,604.826 1016.58,604.826 1016.59,604.826 1016.6,604.826 1016.61,604.826 1016.62,604.826 1016.63,604.826 1016.64,604.826 1016.65,604.826 1016.66,604.826 1016.67,604.826 1016.68,604.825 1016.68,604.825 1016.69,604.825 1016.7,604.825 1016.71,604.825 1016.72,604.825 1016.73,604.825 1016.74,604.825 1016.75,604.825 1016.76,604.825 1016.77,604.825 1016.78,604.824 1016.79,604.824 1016.8,604.824 1016.8,604.824 1016.81,604.824 1016.82,604.824 1016.83,604.824 1016.84,604.824 1016.85,604.824 1016.86,604.824 1016.87,604.823 1016.88,604.823 1016.89,604.823 1016.9,604.823 1016.91,604.823 1016.91,604.823 1016.92,604.823 1016.93,604.823 1016.94,604.823 1016.95,604.823 1016.96,604.823 1016.97,604.822 1016.98,604.822 1016.99,604.822 1017,604.822 1017.01,604.822 1017.02,604.822 1017.02,604.822 1017.03,604.822 1017.04,604.822 1017.05,604.822 1017.06,604.821 1017.07,604.821 1017.08,604.821 1017.09,604.821 1017.1,604.821 1017.11,604.821 1017.12,604.821 1017.13,604.821 1017.14,604.821 1017.14,604.821 1017.15,604.821 1017.16,604.82 1017.17,604.82 1017.18,604.82 1017.19,604.82 1017.2,604.82 1017.21,604.82 1017.22,604.82 1017.23,604.82 1017.24,604.82 1017.25,604.82 1017.25,604.819 1017.26,604.819 1017.27,604.819 1017.28,604.819 1017.29,604.819 1017.3,604.819 1017.31,604.819 1017.32,604.819 1017.33,604.819 1017.34,604.819 1017.35,604.819 1017.36,604.818 1017.36,604.818 1017.37,604.818 1017.38,604.818 1017.39,604.818 1017.4,604.818 1017.41,604.818 1017.42,604.818 1017.43,604.818 1017.44,604.818 1017.45,604.817 1017.46,604.817 1017.47,604.817 1017.48,604.817 1017.48,604.817 1017.49,604.817 1017.5,604.817 1017.51,604.817 1017.52,604.817 1017.53,604.817 1017.54,604.817 1017.55,604.816 1017.56,604.816 1017.57,604.816 1017.58,604.816 1017.59,604.816 1017.59,604.816 1017.6,604.816 1017.61,604.816 1017.62,604.816 1017.63,604.816 1017.64,604.816 1017.65,604.815 1017.66,604.815 1017.67,604.815 1017.68,604.815 1017.69,604.815 1017.7,604.815 1017.7,604.815 1017.71,604.815 1017.72,604.815 1017.73,604.815 1017.74,604.814 1017.75,604.814 1017.76,604.814 1017.77,604.814 1017.78,604.814 1017.79,604.814 1017.8,604.814 1017.81,604.814 1017.82,604.814 1017.82,604.814 1017.83,604.814 1017.84,604.813 1017.85,604.813 1017.86,604.813 1017.87,604.813 1017.88,604.813 1017.89,604.813 1017.9,604.813 1017.91,604.813 1017.92,604.813 1017.93,604.813 1017.93,604.812 1017.94,604.812 1017.95,604.812 1017.96,604.812 1017.97,604.812 1017.98,604.812 1017.99,604.812 1018,604.812 1018.01,604.812 1018.02,604.812 1018.03,604.812 1018.04,604.811 1018.04,604.811 1018.05,604.811 1018.06,604.811 1018.07,604.811 1018.08,604.811 1018.09,604.811 1018.1,604.811 1018.11,604.811 1018.12,604.811 1018.13,604.81 1018.14,604.81 1018.15,604.81 1018.16,604.81 1018.16,604.81 1018.17,604.81 1018.18,604.81 1018.19,604.81 1018.2,604.81 1018.21,604.81 1018.22,604.81 1018.23,604.809 1018.24,604.809 1018.25,604.809 1018.26,604.809 1018.27,604.809 1018.27,604.809 1018.28,604.809 1018.29,604.809 1018.3,604.809 1018.31,604.809 1018.32,604.809 1018.33,604.808 1018.34,604.808 1018.35,604.808 1018.36,604.808 1018.37,604.808 1018.38,604.808 1018.38,604.808 1018.39,604.808 1018.4,604.808 1018.41,604.808 1018.42,604.807 1018.43,604.807 1018.44,604.807 1018.45,604.807 1018.46,604.807 1018.47,604.807 1018.48,604.807 1018.49,604.807 1018.5,604.807 1018.5,604.807 1018.51,604.807 1018.52,604.806 1018.53,604.806 1018.54,604.806 1018.55,604.806 1018.56,604.806 1018.57,604.806 1018.58,604.806 1018.59,604.806 1018.6,604.806 1018.61,604.806 1018.61,604.805 1018.62,604.805 1018.63,604.805 1018.64,604.805 1018.65,604.805 1018.66,604.805 1018.67,604.805 1018.68,604.805 1018.69,604.805 1018.7,604.805 1018.71,604.805 1018.72,604.804 1018.72,604.804 1018.73,604.804 1018.74,604.804 1018.75,604.804 1018.76,604.804 1018.77,604.804 1018.78,604.804 1018.79,604.804 1018.8,604.804 1018.81,604.804 1018.82,604.803 1018.83,604.803 1018.84,604.803 1018.84,604.803 1018.85,604.803 1018.86,604.803 1018.87,604.803 1018.88,604.803 1018.89,604.803 1018.9,604.803 1018.91,604.802 1018.92,604.802 1018.93,604.802 1018.94,604.802 1018.95,604.802 1018.95,604.802 1018.96,604.802 1018.97,604.802 1018.98,604.802 1018.99,604.802 1019,604.802 1019.01,604.801 1019.02,604.801 1019.03,604.801 1019.04,604.801 1019.05,604.801 1019.06,604.801 1019.06,604.801 1019.07,604.801 1019.08,604.801 1019.09,604.801 1019.1,604.801 1019.11,604.8 1019.12,604.8 1019.13,604.8 1019.14,604.8 1019.15,604.8 1019.16,604.8 1019.17,604.8 1019.18,604.8 1019.18,604.8 1019.19,604.8 1019.2,604.799 1019.21,604.799 1019.22,604.799 1019.23,604.799 1019.24,604.799 1019.25,604.799 1019.26,604.799 1019.27,604.799 1019.28,604.799 1019.29,604.799 1019.29,604.799 1019.3,604.798 1019.31,604.798 1019.32,604.798 1019.33,604.798 1019.34,604.798 1019.35,604.798 1019.36,604.798 1019.37,604.798 1019.38,604.798 1019.39,604.798 1019.4,604.798 1019.4,604.797 1019.41,604.797 1019.42,604.797 1019.43,604.797 1019.44,604.797 1019.45,604.797 1019.46,604.797 1019.47,604.797 1019.48,604.797 1019.49,604.797 1019.5,604.796 1019.51,604.796 1019.52,604.796 1019.52,604.796 1019.53,604.796 1019.54,604.796 1019.55,604.796 1019.56,604.796 1019.57,604.796 1019.58,604.796 1019.59,604.796 1019.6,604.795 1019.61,604.795 1019.62,604.795 1019.63,604.795 1019.63,604.795 1019.64,604.795 1019.65,604.795 1019.66,604.795 1019.67,604.795 1019.68,604.795 1019.69,604.795 1019.7,604.794 1019.71,604.794 1019.72,604.794 1019.73,604.794 1019.74,604.794 1019.74,604.794 1019.75,604.794 1019.76,604.794 1019.77,604.794 1019.78,604.794 1019.79,604.793 1019.8,604.793 1019.81,604.793 1019.82,604.793 1019.83,604.793 1019.84,604.793 1019.85,604.793 1019.86,604.793 1019.86,604.793 1019.87,604.793 1019.88,604.793 1019.89,604.792 1019.9,604.792 1019.91,604.792 1019.92,604.792 1019.93,604.792 1019.94,604.792 1019.95,604.792 1019.96,604.792 1019.97,604.792 1019.97,604.792 1019.98,604.792 1019.99,604.791 1020,604.791 1020.01,604.791 1020.02,604.791 1020.03,604.791 1020.04,604.791 1020.05,604.791 1020.06,604.791 1020.07,604.791 1020.08,604.791 1020.08,604.79 1020.09,604.79 1020.1,604.79 1020.11,604.79 1020.12,604.79 1020.13,604.79 1020.14,604.79 1020.15,604.79 1020.16,604.79 1020.17,604.79 1020.18,604.79 1020.19,604.789 1020.2,604.789 1020.2,604.789 1020.21,604.789 1020.22,604.789 1020.23,604.789 1020.24,604.789 1020.25,604.789 1020.26,604.789 1020.27,604.789 1020.28,604.789 1020.29,604.788 1020.3,604.788 1020.31,604.788 1020.31,604.788 1020.32,604.788 1020.33,604.788 1020.34,604.788 1020.35,604.788 1020.36,604.788 1020.37,604.788 1020.38,604.787 1020.39,604.787 1020.4,604.787 1020.41,604.787 1020.42,604.787 1020.42,604.787 1020.43,604.787 1020.44,604.787 1020.45,604.787 1020.46,604.787 1020.47,604.787 1020.48,604.786 1020.49,604.786 1020.5,604.786 1020.51,604.786 1020.52,604.786 1020.53,604.786 1020.54,604.786 1020.54,604.786 1020.55,604.786 1020.56,604.786 1020.57,604.786 1020.58,604.785 1020.59,604.785 1020.6,604.785 1020.61,604.785 1020.62,604.785 1020.63,604.785 1020.64,604.785 1020.65,604.785 1020.65,604.785 1020.66,604.785 1020.67,604.785 1020.68,604.784 1020.69,604.784 1020.7,604.784 1020.71,604.784 1020.72,604.784 1020.73,604.784 1020.74,604.784 1020.75,604.784 1020.76,604.784 1020.76,604.784 1020.77,604.783 1020.78,604.783 1020.79,604.783 1020.8,604.783 1020.81,604.783 1020.82,604.783 1020.83,604.783 1020.84,604.783 1020.85,604.783 1020.86,604.783 1020.87,604.783 1020.88,604.782 1020.88,604.782 1020.89,604.782 1020.9,604.782 1020.91,604.782 1020.92,604.782 1020.93,604.782 1020.94,604.782 1020.95,604.782 1020.96,604.782 1020.97,604.782 1020.98,604.781 1020.99,604.781 1020.99,604.781 1021,604.781 1021.01,604.781 1021.02,604.781 1021.03,604.781 1021.04,604.781 1021.05,604.781 1021.06,604.781 1021.07,604.781 1021.08,604.78 1021.09,604.78 1021.1,604.78 1021.1,604.78 1021.11,604.78 1021.12,604.78 1021.13,604.78 1021.14,604.78 1021.15,604.78 1021.16,604.78 1021.17,604.779 1021.18,604.779 1021.19,604.779 1021.2,604.779 1021.21,604.779 1021.22,604.779 1021.22,604.779 1021.23,604.779 1021.24,604.779 1021.25,604.779 1021.26,604.779 1021.27,604.778 1021.28,604.778 1021.29,604.778 1021.3,604.778 1021.31,604.778 1021.32,604.778 1021.33,604.778 1021.33,604.778 1021.34,604.778 1021.35,604.778 1021.36,604.778 1021.37,604.777 1021.38,604.777 1021.39,604.777 1021.4,604.777 1021.41,604.777 1021.42,604.777 1021.43,604.777 1021.44,604.777 1021.44,604.777 1021.45,604.777 1021.46,604.777 1021.47,604.776 1021.48,604.776 1021.49,604.776 1021.5,604.776 1021.51,604.776 1021.52,604.776 1021.53,604.776 1021.54,604.776 1021.55,604.776 1021.56,604.776 1021.56,604.775 1021.57,604.775 1021.58,604.775 1021.59,604.775 1021.6,604.775 1021.61,604.775 1021.62,604.775 1021.63,604.775 1021.64,604.775 1021.65,604.775 1021.66,604.775 1021.67,604.774 1021.67,604.774 1021.68,604.774 1021.69,604.774 1021.7,604.774 1021.71,604.774 1021.72,604.774 1021.73,604.774 1021.74,604.774 1021.75,604.774 1021.76,604.774 1021.77,604.773 1021.78,604.773 1021.78,604.773 1021.79,604.773 1021.8,604.773 1021.81,604.773 1021.82,604.773 1021.83,604.773 1021.84,604.773 1021.85,604.773 1021.86,604.773 1021.87,604.772 1021.88,604.772 1021.89,604.772 1021.9,604.772 1021.9,604.772 1021.91,604.772 1021.92,604.772 1021.93,604.772 1021.94,604.772 1021.95,604.772 1021.96,604.771 1021.97,604.771 1021.98,604.771 1021.99,604.771 1022,604.771 1022.01,604.771 1022.01,604.771 1022.02,604.771 1022.03,604.771 1022.04,604.771 1022.05,604.771 1022.06,604.77 1022.07,604.77 1022.08,604.77 1022.09,604.77 1022.1,604.77 1022.11,604.77 1022.12,604.77 1022.12,604.77 1022.13,604.77 1022.14,604.77 1022.15,604.77 1022.16,604.769 1022.17,604.769 1022.18,604.769 1022.19,604.769 1022.2,604.769 1022.21,604.769 1022.22,604.769 1022.23,604.769 1022.24,604.769 1022.24,604.769 1022.25,604.769 1022.26,604.768 1022.27,604.768 1022.28,604.768 1022.29,604.768 1022.3,604.768 1022.31,604.768 1022.32,604.768 1022.33,604.768 1022.34,604.768 1022.35,604.768 1022.35,604.768 1022.36,604.767 1022.37,604.767 1022.38,604.767 1022.39,604.767 1022.4,604.767 1022.41,604.767 1022.42,604.767 1022.43,604.767 1022.44,604.767 1022.45,604.767 1022.46,604.766 1022.46,604.766 1022.47,604.766 1022.48,604.766 1022.49,604.766 1022.5,604.766 1022.51,604.766 1022.52,604.766 1022.53,604.766 1022.54,604.766 1022.55,604.766 1022.56,604.765 1022.57,604.765 1022.58,604.765 1022.58,604.765 1022.59,604.765 1022.6,604.765 1022.61,604.765 1022.62,604.765 1022.63,604.765 1022.64,604.765 1022.65,604.765 1022.66,604.764 1022.67,604.764 1022.68,604.764 1022.69,604.764 1022.69,604.764 1022.7,604.764 1022.71,604.764 1022.72,604.764 1022.73,604.764 1022.74,604.764 1022.75,604.764 1022.76,604.763 1022.77,604.763 1022.78,604.763 1022.79,604.763 1022.8,604.763 1022.8,604.763 1022.81,604.763 1022.82,604.763 1022.83,604.763 1022.84,604.763 1022.85,604.763 1022.86,604.762 1022.87,604.762 1022.88,604.762 1022.89,604.762 1022.9,604.762 1022.91,604.762 1022.92,604.762 1022.92,604.762 1022.93,604.762 1022.94,604.762 1022.95,604.761 1022.96,604.761 1022.97,604.761 1022.98,604.761 1022.99,604.761 1023,604.761 1023.01,604.761 1023.02,604.761 1023.03,604.761 1023.03,604.761 1023.04,604.761 1023.05,604.76 1023.06,604.76 1023.07,604.76 1023.08,604.76 1023.09,604.76 1023.1,604.76 1023.11,604.76 1023.12,604.76 1023.13,604.76 1023.14,604.76 1023.15,604.76 1023.15,604.759 1023.16,604.759 1023.17,604.759 1023.18,604.759 1023.19,604.759 1023.2,604.759 1023.21,604.759 1023.22,604.759 1023.23,604.759 1023.24,604.759 1023.25,604.759 1023.26,604.758 1023.26,604.758 1023.27,604.758 1023.28,604.758 1023.29,604.758 1023.3,604.758 1023.31,604.758 1023.32,604.758 1023.33,604.758 1023.34,604.758 1023.35,604.758 1023.36,604.757 1023.37,604.757 1023.37,604.757 1023.38,604.757 1023.39,604.757 1023.4,604.757 1023.41,604.757 1023.42,604.757 1023.43,604.757 1023.44,604.757 1023.45,604.757 1023.46,604.756 1023.47,604.756 1023.48,604.756 1023.49,604.756 1023.49,604.756 1023.5,604.756 1023.51,604.756 1023.52,604.756 1023.53,604.756 1023.54,604.756 1023.55,604.756 1023.56,604.755 1023.57,604.755 1023.58,604.755 1023.59,604.755 1023.6,604.755 1023.6,604.755 1023.61,604.755 1023.62,604.755 1023.63,604.755 1023.64,604.755 1023.65,604.754 1023.66,604.754 1023.67,604.754 1023.68,604.754 1023.69,604.754 1023.7,604.754 1023.71,604.754 1023.71,604.754 1023.72,604.754 1023.73,604.754 1023.74,604.754 1023.75,604.753 1023.76,604.753 1023.77,604.753 1023.78,604.753 1023.79,604.753 1023.8,604.753 1023.81,604.753 1023.82,604.753 1023.83,604.753 1023.83,604.753 1023.84,604.753 1023.85,604.752 1023.86,604.752 1023.87,604.752 1023.88,604.752 1023.89,604.752 1023.9,604.752 1023.91,604.752 1023.92,604.752 1023.93,604.752 1023.94,604.752 1023.94,604.752 1023.95,604.751 1023.96,604.751 1023.97,604.751 1023.98,604.751 1023.99,604.751 1024,604.751 1024.01,604.751 1024.02,604.751 1024.03,604.751 1024.04,604.751 1024.05,604.751 1024.05,604.75 1024.06,604.75 1024.07,604.75 1024.08,604.75 1024.09,604.75 1024.1,604.75 1024.11,604.75 1024.12,604.75 1024.13,604.75 1024.14,604.75 1024.15,604.75 1024.16,604.749 1024.17,604.749 1024.17,604.749 1024.18,604.749 1024.19,604.749 1024.2,604.749 1024.21,604.749 1024.22,604.749 1024.23,604.749 1024.24,604.749 1024.25,604.749 1024.26,604.748 1024.27,604.748 1024.28,604.748 1024.28,604.748 1024.29,604.748 1024.3,604.748 1024.31,604.748 1024.32,604.748 1024.33,604.748 1024.34,604.748 1024.35,604.748 1024.36,604.747 1024.37,604.747 1024.38,604.747 1024.39,604.747 1024.39,604.747 1024.4,604.747 1024.41,604.747 1024.42,604.747 1024.43,604.747 1024.44,604.747 1024.45,604.746 1024.46,604.746 1024.47,604.746 1024.48,604.746 1024.49,604.746 1024.5,604.746 1024.51,604.746 1024.51,604.746 1024.52,604.746 1024.53,604.746 1024.54,604.746 1024.55,604.745 1024.56,604.745 1024.57,604.745 1024.58,604.745 1024.59,604.745 1024.6,604.745 1024.61,604.745 1024.62,604.745 1024.62,604.745 1024.63,604.745 1024.64,604.745 1024.65,604.744 1024.66,604.744 1024.67,604.744 1024.68,604.744 1024.69,604.744 1024.7,604.744 1024.71,604.744 1024.72,604.744 1024.73,604.744 1024.73,604.744 1024.74,604.744 1024.75,604.743 1024.76,604.743 1024.77,604.743 1024.78,604.743 1024.79,604.743 1024.8,604.743 1024.81,604.743 1024.82,604.743 1024.83,604.743 1024.84,604.743 1024.85,604.743 1024.85,604.742 1024.86,604.742 1024.87,604.742 1024.88,604.742 1024.89,604.742 1024.9,604.742 1024.91,604.742 1024.92,604.742 1024.93,604.742 1024.94,604.742 1024.95,604.742 1024.96,604.741 1024.96,604.741 1024.97,604.741 1024.98,604.741 1024.99,604.741 1025,604.741 1025.01,604.741 1025.02,604.741 1025.03,604.741 1025.04,604.741 1025.05,604.741 1025.06,604.74 1025.07,604.74 1025.07,604.74 1025.08,604.74 1025.09,604.74 1025.1,604.74 1025.11,604.74 1025.12,604.74 1025.13,604.74 1025.14,604.74 1025.15,604.74 1025.16,604.739 1025.17,604.739 1025.18,604.739 1025.19,604.739 1025.19,604.739 1025.2,604.739 1025.21,604.739 1025.22,604.739 1025.23,604.739 1025.24,604.739 1025.25,604.739 1025.26,604.738 1025.27,604.738 1025.28,604.738 1025.29,604.738 1025.3,604.738 1025.3,604.738 1025.31,604.738 1025.32,604.738 1025.33,604.738 1025.34,604.738 1025.35,604.738 1025.36,604.737 1025.37,604.737 1025.38,604.737 1025.39,604.737 1025.4,604.737 1025.41,604.737 1025.41,604.737 1025.42,604.737 1025.43,604.737 1025.44,604.737 1025.45,604.737 1025.46,604.736 1025.47,604.736 1025.48,604.736 1025.49,604.736 1025.5,604.736 1025.51,604.736 1025.52,604.736 1025.53,604.736 1025.53,604.736 1025.54,604.736 1025.55,604.736 1025.56,604.735 1025.57,604.735 1025.58,604.735 1025.59,604.735 1025.6,604.735 1025.61,604.735 1025.62,604.735 1025.63,604.735 1025.64,604.735 1025.64,604.735 1025.65,604.735 1025.66,604.734 1025.67,604.734 1025.68,604.734 1025.69,604.734 1025.7,604.734 1025.71,604.734 1025.72,604.734 1025.73,604.734 1025.74,604.734 1025.75,604.734 1025.75,604.734 1025.76,604.733 1025.77,604.733 1025.78,604.733 1025.79,604.733 1025.8,604.733 1025.81,604.733 1025.82,604.733 1025.83,604.733 1025.84,604.733 1025.85,604.733 1025.86,604.733 1025.87,604.732 1025.87,604.732 1025.88,604.732 1025.89,604.732 1025.9,604.732 1025.91,604.732 1025.92,604.732 1025.93,604.732 1025.94,604.732 1025.95,604.732 1025.96,604.731 1025.97,604.731 1025.98,604.731 1025.98,604.731 1025.99,604.731 1026,604.731 1026.01,604.731 1026.02,604.731 1026.03,604.731 1026.04,604.731 1026.05,604.731 1026.06,604.73 1026.07,604.73 1026.08,604.73 1026.09,604.73 1026.09,604.73 1026.1,604.73 1026.11,604.73 1026.12,604.73 1026.13,604.73 1026.14,604.73 1026.15,604.73 1026.16,604.729 1026.17,604.729 1026.18,604.729 1026.19,604.729 1026.2,604.729 1026.21,604.729 1026.21,604.729 1026.22,604.729 1026.23,604.729 1026.24,604.729 1026.25,604.729 1026.26,604.728 1026.27,604.728 1026.28,604.728 1026.29,604.728 1026.3,604.728 1026.31,604.728 1026.32,604.728 1026.32,604.728 1026.33,604.728 1026.34,604.728 1026.35,604.728 1026.36,604.727 1026.37,604.727 1026.38,604.727 1026.39,604.727 1026.4,604.727 1026.41,604.727 1026.42,604.727 1026.43,604.727 1026.43,604.727 1026.44,604.727 1026.45,604.727 1026.46,604.726 1026.47,604.726 1026.48,604.726 1026.49,604.726 1026.5,604.726 1026.51,604.726 1026.52,604.726 1026.53,604.726 1026.54,604.726 1026.55,604.726 1026.55,604.726 1026.56,604.725 1026.57,604.725 1026.58,604.725 1026.59,604.725 1026.6,604.725 1026.61,604.725 1026.62,604.725 1026.63,604.725 1026.64,604.725 1026.65,604.725 1026.66,604.725 1026.66,604.724 1026.67,604.724 1026.68,604.724 1026.69,604.724 1026.7,604.724 1026.71,604.724 1026.72,604.724 1026.73,604.724 1026.74,604.724 1026.75,604.724 1026.76,604.724 1026.77,604.723 1026.77,604.723 1026.78,604.723 1026.79,604.723 1026.8,604.723 1026.81,604.723 1026.82,604.723 1026.83,604.723 1026.84,604.723 1026.85,604.723 1026.86,604.723 1026.87,604.722 1026.88,604.722 1026.89,604.722 1026.89,604.722 1026.9,604.722 1026.91,604.722 1026.92,604.722 1026.93,604.722 1026.94,604.722 1026.95,604.722 1026.96,604.722 1026.97,604.721 1026.98,604.721 1026.99,604.721 1027,604.721 1027,604.721 1027.01,604.721 1027.02,604.721 1027.03,604.721 1027.04,604.721 1027.05,604.721 1027.06,604.721 1027.07,604.72 1027.08,604.72 1027.09,604.72 1027.1,604.72 1027.11,604.72 1027.11,604.72 1027.12,604.72 1027.13,604.72 1027.14,604.72 1027.15,604.72 1027.16,604.72 1027.17,604.719 1027.18,604.719 1027.19,604.719 1027.2,604.719 1027.21,604.719 1027.22,604.719 1027.23,604.719 1027.23,604.719 1027.24,604.719 1027.25,604.719 1027.26,604.719 1027.27,604.719 1027.28,604.718 1027.29,604.718 1027.3,604.718 1027.31,604.718 1027.32,604.718 1027.33,604.718 1027.34,604.718 1027.34,604.718 1027.35,604.718 1027.36,604.718 1027.37,604.718 1027.38,604.717 1027.39,604.717 1027.4,604.717 1027.41,604.717 1027.42,604.717 1027.43,604.717 1027.44,604.717 1027.45,604.717 1027.45,604.717 1027.46,604.717 1027.47,604.717 1027.48,604.716 1027.49,604.716 1027.5,604.716 1027.51,604.716 1027.52,604.716 1027.53,604.716 1027.54,604.716 1027.55,604.716 1027.56,604.716 1027.57,604.716 1027.57,604.716 1027.58,604.715 1027.59,604.715 1027.6,604.715 1027.61,604.715 1027.62,604.715 1027.63,604.715 1027.64,604.715 1027.65,604.715 1027.66,604.715 1027.67,604.715 1027.68,604.715 1027.68,604.714 1027.69,604.714 1027.7,604.714 1027.71,604.714 1027.72,604.714 1027.73,604.714 1027.74,604.714 1027.75,604.714 1027.76,604.714 1027.77,604.714 1027.78,604.714 1027.79,604.713 1027.79,604.713 1027.8,604.713 1027.81,604.713 1027.82,604.713 1027.83,604.713 1027.84,604.713 1027.85,604.713 1027.86,604.713 1027.87,604.713 1027.88,604.713 1027.89,604.712 1027.9,604.712 1027.91,604.712 1027.91,604.712 1027.92,604.712 1027.93,604.712 1027.94,604.712 1027.95,604.712 1027.96,604.712 1027.97,604.712 1027.98,604.712 1027.99,604.711 1028,604.711 1028.01,604.711 1028.02,604.711 1028.02,604.711 1028.03,604.711 1028.04,604.711 1028.05,604.711 1028.06,604.711 1028.07,604.711 1028.08,604.711 1028.09,604.71 1028.1,604.71 1028.11,604.71 1028.12,604.71 1028.13,604.71 1028.13,604.71 1028.14,604.71 1028.15,604.71 1028.16,604.71 1028.17,604.71 1028.18,604.71 1028.19,604.709 1028.2,604.709 1028.21,604.709 1028.22,604.709 1028.23,604.709 1028.24,604.709 1028.25,604.709 1028.25,604.709 1028.26,604.709 1028.27,604.709 1028.28,604.709 1028.29,604.708 1028.3,604.708 1028.31,604.708 1028.32,604.708 1028.33,604.708 1028.34,604.708 1028.35,604.708 1028.36,604.708 1028.36,604.708 1028.37,604.708 1028.38,604.708 1028.39,604.707 1028.4,604.707 1028.41,604.707 1028.42,604.707 1028.43,604.707 1028.44,604.707 1028.45,604.707 1028.46,604.707 1028.47,604.707 1028.47,604.707 1028.48,604.707 1028.49,604.706 1028.5,604.706 1028.51,604.706 1028.52,604.706 1028.53,604.706 1028.54,604.706 1028.55,604.706 1028.56,604.706 1028.57,604.706 1028.58,604.706 1028.59,604.706 1028.59,604.705 1028.6,604.705 1028.61,604.705 1028.62,604.705 1028.63,604.705 1028.64,604.705 1028.65,604.705 1028.66,604.705 1028.67,604.705 1028.68,604.705 1028.69,604.705 1028.7,604.704 1028.7,604.704 1028.71,604.704 1028.72,604.704 1028.73,604.704 1028.74,604.704 1028.75,604.704 1028.76,604.704 1028.77,604.704 1028.78,604.704 1028.79,604.704 1028.8,604.704 1028.81,604.703 1028.81,604.703 1028.82,604.703 1028.83,604.703 1028.84,604.703 1028.85,604.703 1028.86,604.703 1028.87,604.703 1028.88,604.703 1028.89,604.703 1028.9,604.703 1028.91,604.702 1028.92,604.702 1028.93,604.702 1028.93,604.702 1028.94,604.702 1028.95,604.702 1028.96,604.702 1028.97,604.702 1028.98,604.702 1028.99,604.702 1029,604.702 1029.01,604.701 1029.02,604.701 1029.03,604.701 1029.04,604.701 1029.04,604.701 1029.05,604.701 1029.06,604.701 1029.07,604.701 1029.08,604.701 1029.09,604.701 1029.1,604.701 1029.11,604.7 1029.12,604.7 1029.13,604.7 1029.14,604.7 1029.15,604.7 1029.15,604.7 1029.16,604.7 1029.17,604.7 1029.18,604.7 1029.19,604.7 1029.2,604.7 1029.21,604.699 1029.22,604.699 1029.23,604.699 1029.24,604.699 1029.25,604.699 1029.26,604.699 1029.27,604.699 1029.27,604.699 1029.28,604.699 1029.29,604.699 1029.3,604.699 1029.31,604.698 1029.32,604.698 1029.33,604.698 1029.34,604.698 1029.35,604.698 1029.36,604.698 1029.37,604.698 1029.38,604.698 1029.38,604.698 1029.39,604.698 1029.4,604.698 1029.41,604.697 1029.42,604.697 1029.43,604.697 1029.44,604.697 1029.45,604.697 1029.46,604.697 1029.47,604.697 1029.48,604.697 1029.49,604.697 1029.49,604.697 1029.5,604.697 1029.51,604.696 1029.52,604.696 1029.53,604.696 1029.54,604.696 1029.55,604.696 1029.56,604.696 1029.57,604.696 1029.58,604.696 1029.59,604.696 1029.6,604.696 1029.61,604.696 1029.61,604.696 1029.62,604.695 1029.63,604.695 1029.64,604.695 1029.65,604.695 1029.66,604.695 1029.67,604.695 1029.68,604.695 1029.69,604.695 1029.7,604.695 1029.71,604.695 1029.72,604.695 1029.72,604.694 1029.73,604.694 1029.74,604.694 1029.75,604.694 1029.76,604.694 1029.77,604.694 1029.78,604.694 1029.79,604.694 1029.8,604.694 1029.81,604.694 1029.82,604.694 1029.83,604.693 1029.83,604.693 1029.84,604.693 1029.85,604.693 1029.86,604.693 1029.87,604.693 1029.88,604.693 1029.89,604.693 1029.9,604.693 1029.91,604.693 1029.92,604.693 1029.93,604.692 1029.94,604.692 1029.95,604.692 1029.95,604.692 1029.96,604.692 1029.97,604.692 1029.98,604.692 1029.99,604.692 1030,604.692 1030.01,604.692 1030.02,604.692 1030.03,604.691 1030.04,604.691 1030.05,604.691 1030.06,604.691 1030.06,604.691 1030.07,604.691 1030.08,604.691 1030.09,604.691 1030.1,604.691 1030.11,604.691 1030.12,604.691 1030.13,604.69 1030.14,604.69 1030.15,604.69 1030.16,604.69 1030.17,604.69 1030.17,604.69 1030.18,604.69 1030.19,604.69 1030.2,604.69 1030.21,604.69 1030.22,604.69 1030.23,604.69 1030.24,604.689 1030.25,604.689 1030.26,604.689 1030.27,604.689 1030.28,604.689 1030.29,604.689 1030.29,604.689 1030.3,604.689 1030.31,604.689 1030.32,604.689 1030.33,604.689 1030.34,604.688 1030.35,604.688 1030.36,604.688 1030.37,604.688 1030.38,604.688 1030.39,604.688 1030.4,604.688 1030.4,604.688 1030.41,604.688 1030.42,604.688 1030.43,604.688 1030.44,604.687 1030.45,604.687 1030.46,604.687 1030.47,604.687 1030.48,604.687 1030.49,604.687 1030.5,604.687 1030.51,604.687 1030.51,604.687 1030.52,604.687 1030.53,604.687 1030.54,604.686 1030.55,604.686 1030.56,604.686 1030.57,604.686 1030.58,604.686 1030.59,604.686 1030.6,604.686 1030.61,604.686 1030.62,604.686 1030.63,604.686 1030.63,604.686 1030.64,604.685 1030.65,604.685 1030.66,604.685 1030.67,604.685 1030.68,604.685 1030.69,604.685 1030.7,604.685 1030.71,604.685 1030.72,604.685 1030.73,604.685 1030.74,604.685 1030.74,604.684 1030.75,604.684 1030.76,604.684 1030.77,604.684 1030.78,604.684 1030.79,604.684 1030.8,604.684 1030.81,604.684 1030.82,604.684 1030.83,604.684 1030.84,604.684 1030.85,604.684 1030.85,604.683 1030.86,604.683 1030.87,604.683 1030.88,604.683 1030.89,604.683 1030.9,604.683 1030.91,604.683 1030.92,604.683 1030.93,604.683 1030.94,604.683 1030.95,604.683 1030.96,604.682 1030.97,604.682 1030.97,604.682 1030.98,604.682 1030.99,604.682 1031,604.682 1031.01,604.682 1031.02,604.682 1031.03,604.682 1031.04,604.682 1031.05,604.682 1031.06,604.681 1031.07,604.681 1031.08,604.681 1031.08,604.681 1031.09,604.681 1031.1,604.681 1031.11,604.681 1031.12,604.681 1031.13,604.681 1031.14,604.681 1031.15,604.681 1031.16,604.68 1031.17,604.68 1031.18,604.68 1031.19,604.68 1031.19,604.68 1031.2,604.68 1031.21,604.68 1031.22,604.68 1031.23,604.68 1031.24,604.68 1031.25,604.68 1031.26,604.679 1031.27,604.679 1031.28,604.679 1031.29,604.679 1031.3,604.679 1031.31,604.679 1031.31,604.679 1031.32,604.679 1031.33,604.679 1031.34,604.679 1031.35,604.679 1031.36,604.679 1031.37,604.678 1031.38,604.678 1031.39,604.678 1031.4,604.678 1031.41,604.678 1031.42,604.678 1031.42,604.678 1031.43,604.678 1031.44,604.678 1031.45,604.678 1031.46,604.678 1031.47,604.677 1031.48,604.677 1031.49,604.677 1031.5,604.677 1031.51,604.677 1031.52,604.677 1031.53,604.677 1031.53,604.677 1031.54,604.677 1031.55,604.677 1031.56,604.677 1031.57,604.676 1031.58,604.676 1031.59,604.676 1031.6,604.676 1031.61,604.676 1031.62,604.676 1031.63,604.676 1031.64,604.676 1031.65,604.676 1031.65,604.676 1031.66,604.676 1031.67,604.675 1031.68,604.675 1031.69,604.675 1031.7,604.675 1031.71,604.675 1031.72,604.675 1031.73,604.675 1031.74,604.675 1031.75,604.675 1031.76,604.675 1031.76,604.675 1031.77,604.675 1031.78,604.674 1031.79,604.674 1031.8,604.674 1031.81,604.674 1031.82,604.674 1031.83,604.674 1031.84,604.674 1031.85,604.674 1031.86,604.674 1031.87,604.674 1031.87,604.674 1031.88,604.673 1031.89,604.673 1031.9,604.673 1031.91,604.673 1031.92,604.673 1031.93,604.673 1031.94,604.673 1031.95,604.673 1031.96,604.673 1031.97,604.673 1031.98,604.673 1031.99,604.672 1031.99,604.672 1032,604.672 1032.01,604.672 1032.02,604.672 1032.03,604.672 1032.04,604.672 1032.05,604.672 1032.06,604.672 1032.07,604.672 1032.08,604.672 1032.09,604.671 1032.1,604.671 1032.1,604.671 1032.11,604.671 1032.12,604.671 1032.13,604.671 1032.14,604.671 1032.15,604.671 1032.16,604.671 1032.17,604.671 1032.18,604.671 1032.19,604.671 1032.2,604.67 1032.21,604.67 1032.21,604.67 1032.22,604.67 1032.23,604.67 1032.24,604.67 1032.25,604.67 1032.26,604.67 1032.27,604.67 1032.28,604.67 1032.29,604.67 1032.3,604.669 1032.31,604.669 1032.32,604.669 1032.33,604.669 1032.33,604.669 1032.34,604.669 1032.35,604.669 1032.36,604.669 1032.37,604.669 1032.38,604.669 1032.39,604.669 1032.4,604.668 1032.41,604.668 1032.42,604.668 1032.43,604.668 1032.44,604.668 1032.44,604.668 1032.45,604.668 1032.46,604.668 1032.47,604.668 1032.48,604.668 1032.49,604.668 1032.5,604.667 1032.51,604.667 1032.52,604.667 1032.53,604.667 1032.54,604.667 1032.55,604.667 1032.55,604.667 1032.56,604.667 1032.57,604.667 1032.58,604.667 1032.59,604.667 1032.6,604.667 1032.61,604.666 1032.62,604.666 1032.63,604.666 1032.64,604.666 1032.65,604.666 1032.66,604.666 1032.67,604.666 1032.67,604.666 1032.68,604.666 1032.69,604.666 1032.7,604.666 1032.71,604.665 1032.72,604.665 1032.73,604.665 1032.74,604.665 1032.75,604.665 1032.76,604.665 1032.77,604.665 1032.78,604.665 1032.78,604.665 1032.79,604.665 1032.8,604.665 1032.81,604.664 1032.82,604.664 1032.83,604.664 1032.84,604.664 1032.85,604.664 1032.86,604.664 1032.87,604.664 1032.88,604.664 1032.89,604.664 1032.89,604.664 1032.9,604.664 1032.91,604.664 1032.92,604.663 1032.93,604.663 1032.94,604.663 1032.95,604.663 1032.96,604.663 1032.97,604.663 1032.98,604.663 1032.99,604.663 1033,604.663 1033.01,604.663 1033.01,604.663 1033.02,604.662 1033.03,604.662 1033.04,604.662 1033.05,604.662 1033.06,604.662 1033.07,604.662 1033.08,604.662 1033.09,604.662 1033.1,604.662 1033.11,604.662 1033.12,604.662 1033.12,604.661 1033.13,604.661 1033.14,604.661 1033.15,604.661 1033.16,604.661 1033.17,604.661 1033.18,604.661 1033.19,604.661 1033.2,604.661 1033.21,604.661 1033.22,604.661 1033.23,604.66 1033.23,604.66 1033.24,604.66 1033.25,604.66 1033.26,604.66 1033.27,604.66 1033.28,604.66 1033.29,604.66 1033.3,604.66 1033.31,604.66 1033.32,604.66 1033.33,604.66 1033.34,604.659 1033.35,604.659 1033.35,604.659 1033.36,604.659 1033.37,604.659 1033.38,604.659 1033.39,604.659 1033.4,604.659 1033.41,604.659 1033.42,604.659 1033.43,604.659 1033.44,604.658 1033.45,604.658 1033.46,604.658 1033.46,604.658 1033.47,604.658 1033.48,604.658 1033.49,604.658 1033.5,604.658 1033.51,604.658 1033.52,604.658 1033.53,604.658 1033.54,604.657 1033.55,604.657 1033.56,604.657 1033.57,604.657 1033.57,604.657 1033.58,604.657 1033.59,604.657 1033.6,604.657 1033.61,604.657 1033.62,604.657 1033.63,604.657 1033.64,604.657 1033.65,604.656 1033.66,604.656 1033.67,604.656 1033.68,604.656 1033.69,604.656 1033.69,604.656 1033.7,604.656 1033.71,604.656 1033.72,604.656 1033.73,604.656 1033.74,604.656 1033.75,604.655 1033.76,604.655 1033.77,604.655 1033.78,604.655 1033.79,604.655 1033.8,604.655 1033.8,604.655 1033.81,604.655 1033.82,604.655 1033.83,604.655 1033.84,604.655 1033.85,604.654 1033.86,604.654 1033.87,604.654 1033.88,604.654 1033.89,604.654 1033.9,604.654 1033.91,604.654 1033.91,604.654 1033.92,604.654 1033.93,604.654 1033.94,604.654 1033.95,604.654 1033.96,604.653 1033.97,604.653 1033.98,604.653 1033.99,604.653 1034,604.653 1034.01,604.653 1034.02,604.653 1034.03,604.653 1034.03,604.653 1034.04,604.653 1034.05,604.653 1034.06,604.652 1034.07,604.652 1034.08,604.652 1034.09,604.652 1034.1,604.652 1034.11,604.652 1034.12,604.652 1034.13,604.652 1034.14,604.652 1034.14,604.652 1034.15,604.652 1034.16,604.651 1034.17,604.651 1034.18,604.651 1034.19,604.651 1034.2,604.651 1034.21,604.651 1034.22,604.651 1034.23,604.651 1034.24,604.651 1034.25,604.651 1034.25,604.651 1034.26,604.651 1034.27,604.65 1034.28,604.65 1034.29,604.65 1034.3,604.65 1034.31,604.65 1034.32,604.65 1034.33,604.65 1034.34,604.65 1034.35,604.65 1034.36,604.65 1034.37,604.65 1034.37,604.649 1034.38,604.649 1034.39,604.649 1034.4,604.649 1034.41,604.649 1034.42,604.649 1034.43,604.649 1034.44,604.649 1034.45,604.649 1034.46,604.649 1034.47,604.649 1034.48,604.649 1034.48,604.648 1034.49,604.648 1034.5,604.648 1034.51,604.648 1034.52,604.648 1034.53,604.648 1034.54,604.648 1034.55,604.648 1034.56,604.648 1034.57,604.648 1034.58,604.648 1034.59,604.647 1034.59,604.647 1034.6,604.647 1034.61,604.647 1034.62,604.647 1034.63,604.647 1034.64,604.647 1034.65,604.647 1034.66,604.647 1034.67,604.647 1034.68,604.647 1034.69,604.646 1034.7,604.646 1034.71,604.646 1034.71,604.646 1034.72,604.646 1034.73,604.646 1034.74,604.646 1034.75,604.646 1034.76,604.646 1034.77,604.646 1034.78,604.646 1034.79,604.646 1034.8,604.645 1034.81,604.645 1034.82,604.645 1034.82,604.645 1034.83,604.645 1034.84,604.645 1034.85,604.645 1034.86,604.645 1034.87,604.645 1034.88,604.645 1034.89,604.645 1034.9,604.644 1034.91,604.644 1034.92,604.644 1034.93,604.644 1034.93,604.644 1034.94,604.644 1034.95,604.644 1034.96,604.644 1034.97,604.644 1034.98,604.644 1034.99,604.644 1035,604.643 1035.01,604.643 1035.02,604.643 1035.03,604.643 1035.04,604.643 1035.05,604.643 1035.05,604.643 1035.06,604.643 1035.07,604.643 1035.08,604.643 1035.09,604.643 1035.1,604.643 1035.11,604.642 1035.12,604.642 1035.13,604.642 1035.14,604.642 1035.15,604.642 1035.16,604.642 1035.16,604.642 1035.17,604.642 1035.18,604.642 1035.19,604.642 1035.2,604.642 1035.21,604.641 1035.22,604.641 1035.23,604.641 1035.24,604.641 1035.25,604.641 1035.26,604.641 1035.27,604.641 1035.27,604.641 1035.28,604.641 1035.29,604.641 1035.3,604.641 1035.31,604.641 1035.32,604.64 1035.33,604.64 1035.34,604.64 1035.35,604.64 1035.36,604.64 1035.37,604.64 1035.38,604.64 1035.39,604.64 1035.39,604.64 1035.4,604.64 1035.41,604.64 1035.42,604.639 1035.43,604.639 1035.44,604.639 1035.45,604.639 1035.46,604.639 1035.47,604.639 1035.48,604.639 1035.49,604.639 1035.5,604.639 1035.5,604.639 1035.51,604.639 1035.52,604.638 1035.53,604.638 1035.54,604.638 1035.55,604.638 1035.56,604.638 1035.57,604.638 1035.58,604.638 1035.59,604.638 1035.6,604.638 1035.61,604.638 1035.61,604.638 1035.62,604.638 1035.63,604.637 1035.64,604.637 1035.65,604.637 1035.66,604.637 1035.67,604.637 1035.68,604.637 1035.69,604.637 1035.7,604.637 1035.71,604.637 1035.72,604.637 1035.73,604.637 1035.73,604.636 1035.74,604.636 1035.75,604.636 1035.76,604.636 1035.77,604.636 1035.78,604.636 1035.79,604.636 1035.8,604.636 1035.81,604.636 1035.82,604.636 1035.83,604.636 1035.84,604.636 1035.84,604.635 1035.85,604.635 1035.86,604.635 1035.87,604.635 1035.88,604.635 1035.89,604.635 1035.9,604.635 1035.91,604.635 1035.92,604.635 1035.93,604.635 1035.94,604.635 1035.95,604.634 1035.95,604.634 1035.96,604.634 1035.97,604.634 1035.98,604.634 1035.99,604.634 1036,604.634 1036.01,604.634 1036.02,604.634 1036.03,604.634 1036.04,604.634 1036.05,604.634 1036.06,604.633 1036.07,604.633 1036.07,604.633 1036.08,604.633 1036.09,604.633 1036.1,604.633 1036.11,604.633 1036.12,604.633 1036.13,604.633 1036.14,604.633 1036.15,604.633 1036.16,604.632 1036.17,604.632 1036.18,604.632 1036.18,604.632 1036.19,604.632 1036.2,604.632 1036.21,604.632 1036.22,604.632 1036.23,604.632 1036.24,604.632 1036.25,604.632 1036.26,604.631 1036.27,604.631 1036.28,604.631 1036.29,604.631 1036.29,604.631 1036.3,604.631 1036.31,604.631 1036.32,604.631 1036.33,604.631 1036.34,604.631 1036.35,604.631 1036.36,604.631 1036.37,604.63 1036.38,604.63 1036.39,604.63 1036.4,604.63 1036.41,604.63 1036.41,604.63 1036.42,604.63 1036.43,604.63 1036.44,604.63 1036.45,604.63 1036.46,604.63 1036.47,604.629 1036.48,604.629 1036.49,604.629 1036.5,604.629 1036.51,604.629 1036.52,604.629 1036.52,604.629 1036.53,604.629 1036.54,604.629 1036.55,604.629 1036.56,604.629 1036.57,604.629 1036.58,604.628 1036.59,604.628 1036.6,604.628 1036.61,604.628 1036.62,604.628 1036.63,604.628 1036.63,604.628 1036.64,604.628 1036.65,604.628 1036.66,604.628 1036.67,604.628 1036.68,604.627 1036.69,604.627 1036.7,604.627 1036.71,604.627 1036.72,604.627 1036.73,604.627 1036.74,604.627 1036.75,604.627 1036.75,604.627 1036.76,604.627 1036.77,604.627 1036.78,604.627 1036.79,604.626 1036.8,604.626 1036.81,604.626 1036.82,604.626 1036.83,604.626 1036.84,604.626 1036.85,604.626 1036.86,604.626 1036.86,604.626 1036.87,604.626 1036.88,604.626 1036.89,604.625 1036.9,604.625 1036.91,604.625 1036.92,604.625 1036.93,604.625 1036.94,604.625 1036.95,604.625 1036.96,604.625 1036.97,604.625 1036.97,604.625 1036.98,604.625 1036.99,604.625 1037,604.624 1037.01,604.624 1037.02,604.624 1037.03,604.624 1037.04,604.624 1037.05,604.624 1037.06,604.624 1037.07,604.624 1037.08,604.624 1037.09,604.624 1037.09,604.624 1037.1,604.623 1037.11,604.623 1037.12,604.623 1037.13,604.623 1037.14,604.623 1037.15,604.623 1037.16,604.623 1037.17,604.623 1037.18,604.623 1037.19,604.623 1037.2,604.623 1037.2,604.623 1037.21,604.622 1037.22,604.622 1037.23,604.622 1037.24,604.622 1037.25,604.622 1037.26,604.622 1037.27,604.622 1037.28,604.622 1037.29,604.622 1037.3,604.622 1037.31,604.622 1037.31,604.621 1037.32,604.621 1037.33,604.621 1037.34,604.621 1037.35,604.621 1037.36,604.621 1037.37,604.621 1037.38,604.621 1037.39,604.621 1037.4,604.621 1037.41,604.621 1037.42,604.621 1037.43,604.62 1037.43,604.62 1037.44,604.62 1037.45,604.62 1037.46,604.62 1037.47,604.62 1037.48,604.62 1037.49,604.62 1037.5,604.62 1037.51,604.62 1037.52,604.62 1037.53,604.619 1037.54,604.619 1037.54,604.619 1037.55,604.619 1037.56,604.619 1037.57,604.619 1037.58,604.619 1037.59,604.619 1037.6,604.619 1037.61,604.619 1037.62,604.619 1037.63,604.619 1037.64,604.618 1037.65,604.618 1037.65,604.618 1037.66,604.618 1037.67,604.618 1037.68,604.618 1037.69,604.618 1037.7,604.618 1037.71,604.618 1037.72,604.618 1037.73,604.618 1037.74,604.617 1037.75,604.617 1037.76,604.617 1037.77,604.617 1037.77,604.617 1037.78,604.617 1037.79,604.617 1037.8,604.617 1037.81,604.617 1037.82,604.617 1037.83,604.617 1037.84,604.617 1037.85,604.616 1037.86,604.616 1037.87,604.616 1037.88,604.616 1037.88,604.616 1037.89,604.616 1037.9,604.616 1037.91,604.616 1037.92,604.616 1037.93,604.616 1037.94,604.616 1037.95,604.615 1037.96,604.615 1037.97,604.615 1037.98,604.615 1037.99,604.615 1037.99,604.615 1038,604.615 1038.01,604.615 1038.02,604.615 1038.03,604.615 1038.04,604.615 1038.05,604.615 1038.06,604.614 1038.07,604.614 1038.08,604.614 1038.09,604.614 1038.1,604.614 1038.11,604.614 1038.11,604.614 1038.12,604.614 1038.13,604.614 1038.14,604.614 1038.15,604.614 1038.16,604.613 1038.17,604.613 1038.18,604.613 1038.19,604.613 1038.2,604.613 1038.21,604.613 1038.22,604.613 1038.22,604.613 1038.23,604.613 1038.24,604.613 1038.25,604.613 1038.26,604.613 1038.27,604.612 1038.28,604.612 1038.29,604.612 1038.3,604.612 1038.31,604.612 1038.32,604.612 1038.33,604.612 1038.33,604.612 1038.34,604.612 1038.35,604.612 1038.36,604.612 1038.37,604.611 1038.38,604.611 1038.39,604.611 1038.4,604.611 1038.41,604.611 1038.42,604.611 1038.43,604.611 1038.44,604.611 1038.45,604.611 1038.45,604.611 1038.46,604.611 1038.47,604.611 1038.48,604.61 1038.49,604.61 1038.5,604.61 1038.51,604.61 1038.52,604.61 1038.53,604.61 1038.54,604.61 1038.55,604.61 1038.56,604.61 1038.56,604.61 1038.57,604.61 1038.58,604.609 1038.59,604.609 1038.6,604.609 1038.61,604.609 1038.62,604.609 1038.63,604.609 1038.64,604.609 1038.65,604.609 1038.66,604.609 1038.67,604.609 1038.67,604.609 1038.68,604.609 1038.69,604.608 1038.7,604.608 1038.71,604.608 1038.72,604.608 1038.73,604.608 1038.74,604.608 1038.75,604.608 1038.76,604.608 1038.77,604.608 1038.78,604.608 1038.79,604.608 1038.79,604.607 1038.8,604.607 1038.81,604.607 1038.82,604.607 1038.83,604.607 1038.84,604.607 1038.85,604.607 1038.86,604.607 1038.87,604.607 1038.88,604.607 1038.89,604.607 1038.9,604.607 1038.9,604.606 1038.91,604.606 1038.92,604.606 1038.93,604.606 1038.94,604.606 1038.95,604.606 1038.96,604.606 1038.97,604.606 1038.98,604.606 1038.99,604.606 1039,604.606 1039.01,604.606 1039.01,604.605 1039.02,604.605 1039.03,604.605 1039.04,604.605 1039.05,604.605 1039.06,604.605 1039.07,604.605 1039.08,604.605 1039.09,604.605 1039.1,604.605 1039.11,604.605 1039.12,604.604 1039.13,604.604 1039.13,604.604 1039.14,604.604 1039.15,604.604 1039.16,604.604 1039.17,604.604 1039.18,604.604 1039.19,604.604 1039.2,604.604 1039.21,604.604 1039.22,604.604 1039.23,604.603 1039.24,604.603 1039.24,604.603 1039.25,604.603 1039.26,604.603 1039.27,604.603 1039.28,604.603 1039.29,604.603 1039.3,604.603 1039.31,604.603 1039.32,604.603 1039.33,604.602 1039.34,604.602 1039.35,604.602 1039.35,604.602 1039.36,604.602 1039.37,604.602 1039.38,604.602 1039.39,604.602 1039.4,604.602 1039.41,604.602 1039.42,604.602 1039.43,604.602 1039.44,604.601 1039.45,604.601 1039.46,604.601 1039.47,604.601 1039.47,604.601 1039.48,604.601 1039.49,604.601 1039.5,604.601 1039.51,604.601 1039.52,604.601 1039.53,604.601 1039.54,604.601 1039.55,604.6 1039.56,604.6 1039.57,604.6 1039.58,604.6 1039.58,604.6 1039.59,604.6 1039.6,604.6 1039.61,604.6 1039.62,604.6 1039.63,604.6 1039.64,604.6 1039.65,604.599 1039.66,604.599 1039.67,604.599 1039.68,604.599 1039.69,604.599 1039.69,604.599 1039.7,604.599 1039.71,604.599 1039.72,604.599 1039.73,604.599 1039.74,604.599 1039.75,604.599 1039.76,604.598 1039.77,604.598 1039.78,604.598 1039.79,604.598 1039.8,604.598 1039.81,604.598 1039.81,604.598 1039.82,604.598 1039.83,604.598 1039.84,604.598 1039.85,604.598 1039.86,604.597 1039.87,604.597 1039.88,604.597 1039.89,604.597 1039.9,604.597 1039.91,604.597 1039.92,604.597 1039.92,604.597 1039.93,604.597 1039.94,604.597 1039.95,604.597 1039.96,604.597 1039.97,604.596 1039.98,604.596 1039.99,604.596 1040,604.596 1040.01,604.596 1040.02,604.596 1040.03,604.596 1040.03,604.596 1040.04,604.596 1040.05,604.596 1040.06,604.596 1040.07,604.596 1040.08,604.595 1040.09,604.595 1040.1,604.595 1040.11,604.595 1040.12,604.595 1040.13,604.595 1040.14,604.595 1040.15,604.595 1040.15,604.595 1040.16,604.595 1040.17,604.595 1040.18,604.594 1040.19,604.594 1040.2,604.594 1040.21,604.594 1040.22,604.594 1040.23,604.594 1040.24,604.594 1040.25,604.594 1040.26,604.594 1040.26,604.594 1040.27,604.594 1040.28,604.594 1040.29,604.593 1040.3,604.593 1040.31,604.593 1040.32,604.593 1040.33,604.593 1040.34,604.593 1040.35,604.593 1040.36,604.593 1040.37,604.593 1040.37,604.593 1040.38,604.593 1040.39,604.592 1040.4,604.592 1040.41,604.592 1040.42,604.592 1040.43,604.592 1040.44,604.592 1040.45,604.592 1040.46,604.592 1040.47,604.592 1040.48,604.592 1040.49,604.592 1040.49,604.592 1040.5,604.591 1040.51,604.591 1040.52,604.591 1040.53,604.591 1040.54,604.591 1040.55,604.591 1040.56,604.591 1040.57,604.591 1040.58,604.591 1040.59,604.591 1040.6,604.591 1040.6,604.591 1040.61,604.59 1040.62,604.59 1040.63,604.59 1040.64,604.59 1040.65,604.59 1040.66,604.59 1040.67,604.59 1040.68,604.59 1040.69,604.59 1040.7,604.59 1040.71,604.59 1040.71,604.589 1040.72,604.589 1040.73,604.589 1040.74,604.589 1040.75,604.589 1040.76,604.589 1040.77,604.589 1040.78,604.589 1040.79,604.589 1040.8,604.589 1040.81,604.589 1040.82,604.589 1040.83,604.588 1040.83,604.588 1040.84,604.588 1040.85,604.588 1040.86,604.588 1040.87,604.588 1040.88,604.588 1040.89,604.588 1040.9,604.588 1040.91,604.588 1040.92,604.588 1040.93,604.588 1040.94,604.587 1040.94,604.587 1040.95,604.587 1040.96,604.587 1040.97,604.587 1040.98,604.587 1040.99,604.587 1041,604.587 1041.01,604.587 1041.02,604.587 1041.03,604.587 1041.04,604.586 1041.05,604.586 1041.05,604.586 1041.06,604.586 1041.07,604.586 1041.08,604.586 1041.09,604.586 1041.1,604.586 1041.11,604.586 1041.12,604.586 1041.13,604.586 1041.14,604.586 1041.15,604.585 1041.16,604.585 1041.17,604.585 1041.17,604.585 1041.18,604.585 1041.19,604.585 1041.2,604.585 1041.21,604.585 1041.22,604.585 1041.23,604.585 1041.24,604.585 1041.25,604.585 1041.26,604.584 1041.27,604.584 1041.28,604.584 1041.28,604.584 1041.29,604.584 1041.3,604.584 1041.31,604.584 1041.32,604.584 1041.33,604.584 1041.34,604.584 1041.35,604.584 1041.36,604.583 1041.37,604.583 1041.38,604.583 1041.39,604.583 1041.39,604.583 1041.4,604.583 1041.41,604.583 1041.42,604.583 1041.43,604.583 1041.44,604.583 1041.45,604.583 1041.46,604.583 1041.47,604.582 1041.48,604.582 1041.49,604.582 1041.5,604.582 1041.51,604.582 1041.51,604.582 1041.52,604.582 1041.53,604.582 1041.54,604.582 1041.55,604.582 1041.56,604.582 1041.57,604.582 1041.58,604.581 1041.59,604.581 1041.6,604.581 1041.61,604.581 1041.62,604.581 1041.62,604.581 1041.63,604.581 1041.64,604.581 1041.65,604.581 1041.66,604.581 1041.67,604.581 1041.68,604.58 1041.69,604.58 1041.7,604.58 1041.71,604.58 1041.72,604.58 1041.73,604.58 1041.73,604.58 1041.74,604.58 1041.75,604.58 1041.76,604.58 1041.77,604.58 1041.78,604.58 1041.79,604.579 1041.8,604.579 1041.81,604.579 1041.82,604.579 1041.83,604.579 1041.84,604.579 1041.85,604.579 1041.85,604.579 1041.86,604.579 1041.87,604.579 1041.88,604.579 1041.89,604.579 1041.9,604.578 1041.91,604.578 1041.92,604.578 1041.93,604.578 1041.94,604.578 1041.95,604.578 1041.96,604.578 1041.96,604.578 1041.97,604.578 1041.98,604.578 1041.99,604.578 1042,604.577 1042.01,604.577 1042.02,604.577 1042.03,604.577 1042.04,604.577 1042.05,604.577 1042.06,604.577 1042.07,604.577 1042.07,604.577 1042.08,604.577 1042.09,604.577 1042.1,604.577 1042.11,604.576 1042.12,604.576 1042.13,604.576 1042.14,604.576 1042.15,604.576 1042.16,604.576 1042.17,604.576 1042.18,604.576 1042.19,604.576 1042.19,604.576 1042.2,604.576 1042.21,604.576 1042.22,604.575 1042.23,604.575 1042.24,604.575 1042.25,604.575 1042.26,604.575 1042.27,604.575 1042.28,604.575 1042.29,604.575 1042.3,604.575 1042.3,604.575 1042.31,604.575 1042.32,604.574 1042.33,604.574 1042.34,604.574 1042.35,604.574 1042.36,604.574 1042.37,604.574 1042.38,604.574 1042.39,604.574 1042.4,604.574 1042.41,604.574 1042.41,604.574 1042.42,604.574 1042.43,604.573 1042.44,604.573 1042.45,604.573 1042.46,604.573 1042.47,604.573 1042.48,604.573 1042.49,604.573 1042.5,604.573 1042.51,604.573 1042.52,604.573 1042.53,604.573 1042.53,604.573 1042.54,604.572 1042.55,604.572 1042.56,604.572 1042.57,604.572 1042.58,604.572 1042.59,604.572 1042.6,604.572 1042.61,604.572 1042.62,604.572 1042.63,604.572 1042.64,604.572 1042.64,604.572 1042.65,604.571 1042.66,604.571 1042.67,604.571 1042.68,604.571 1042.69,604.571 1042.7,604.571 1042.71,604.571 1042.72,604.571 1042.73,604.571 1042.74,604.571 1042.75,604.571 1042.75,604.57 1042.76,604.57 1042.77,604.57 1042.78,604.57 1042.79,604.57 1042.8,604.57 1042.81,604.57 1042.82,604.57 1042.83,604.57 1042.84,604.57 1042.85,604.57 1042.86,604.57 1042.87,604.569 1042.87,604.569 1042.88,604.569 1042.89,604.569 1042.9,604.569 1042.91,604.569 1042.92,604.569 1042.93,604.569 1042.94,604.569 1042.95,604.569 1042.96,604.569 1042.97,604.569 1042.98,604.568 1042.98,604.568 1042.99,604.568 1043,604.568 1043.01,604.568 1043.02,604.568 1043.03,604.568 1043.04,604.568 1043.05,604.568 1043.06,604.568 1043.07,604.568 1043.08,604.568 1043.09,604.567 1043.09,604.567 1043.1,604.567 1043.11,604.567 1043.12,604.567 1043.13,604.567 1043.14,604.567 1043.15,604.567 1043.16,604.567 1043.17,604.567 1043.18,604.567 1043.19,604.566 1043.2,604.566 1043.21,604.566 1043.21,604.566 1043.22,604.566 1043.23,604.566 1043.24,604.566 1043.25,604.566 1043.26,604.566 1043.27,604.566 1043.28,604.566 1043.29,604.566 1043.3,604.565 1043.31,604.565 1043.32,604.565 1043.32,604.565 1043.33,604.565 1043.34,604.565 1043.35,604.565 1043.36,604.565 1043.37,604.565 1043.38,604.565 1043.39,604.565 1043.4,604.565 1043.41,604.564 1043.42,604.564 1043.43,604.564 1043.43,604.564 1043.44,604.564 1043.45,604.564 1043.46,604.564 1043.47,604.564 1043.48,604.564 1043.49,604.564 1043.5,604.564 1043.51,604.564 1043.52,604.563 1043.53,604.563 1043.54,604.563 1043.55,604.563 1043.55,604.563 1043.56,604.563 1043.57,604.563 1043.58,604.563 1043.59,604.563 1043.6,604.563 1043.61,604.563 1043.62,604.562 1043.63,604.562 1043.64,604.562 1043.65,604.562 1043.66,604.562 1043.66,604.562 1043.67,604.562 1043.68,604.562 1043.69,604.562 1043.7,604.562 1043.71,604.562 1043.72,604.562 1043.73,604.561 1043.74,604.561 1043.75,604.561 1043.76,604.561 1043.77,604.561 1043.77,604.561 1043.78,604.561 1043.79,604.561 1043.8,604.561 1043.81,604.561 1043.82,604.561 1043.83,604.561 1043.84,604.56 1043.85,604.56 1043.86,604.56 1043.87,604.56 1043.88,604.56 1043.89,604.56 1043.89,604.56 1043.9,604.56 1043.91,604.56 1043.92,604.56 1043.93,604.56 1043.94,604.56 1043.95,604.559 1043.96,604.559 1043.97,604.559 1043.98,604.559 1043.99,604.559 1044,604.559 1044,604.559 1044.01,604.559 1044.02,604.559 1044.03,604.559 1044.04,604.559 1044.05,604.558 1044.06,604.558 1044.07,604.558 1044.08,604.558 1044.09,604.558 1044.1,604.558 1044.11,604.558 1044.11,604.558 1044.12,604.558 1044.13,604.558 1044.14,604.558 1044.15,604.558 1044.16,604.557 1044.17,604.557 1044.18,604.557 1044.19,604.557 1044.2,604.557 1044.21,604.557 1044.22,604.557 1044.23,604.557 1044.23,604.557 1044.24,604.557 1044.25,604.557 1044.26,604.557 1044.27,604.556 1044.28,604.556 1044.29,604.556 1044.3,604.556 1044.31,604.556 1044.32,604.556 1044.33,604.556 1044.34,604.556 1044.34,604.556 1044.35,604.556 1044.36,604.556 1044.37,604.556 1044.38,604.555 1044.39,604.555 1044.4,604.555 1044.41,604.555 1044.42,604.555 1044.43,604.555 1044.44,604.555 1044.45,604.555 1044.45,604.555 1044.46,604.555 1044.47,604.555 1044.48,604.555 1044.49,604.554 1044.5,604.554 1044.51,604.554 1044.52,604.554 1044.53,604.554 1044.54,604.554 1044.55,604.554 1044.56,604.554 1044.57,604.554 1044.57,604.554 1044.58,604.554 1044.59,604.553 1044.6,604.553 1044.61,604.553 1044.62,604.553 1044.63,604.553 1044.64,604.553 1044.65,604.553 1044.66,604.553 1044.67,604.553 1044.68,604.553 1044.68,604.553 1044.69,604.553 1044.7,604.552 1044.71,604.552 1044.72,604.552 1044.73,604.552 1044.74,604.552 1044.75,604.552 1044.76,604.552 1044.77,604.552 1044.78,604.552 1044.79,604.552 1044.79,604.552 1044.8,604.552 1044.81,604.551 1044.82,604.551 1044.83,604.551 1044.84,604.551 1044.85,604.551 1044.86,604.551 1044.87,604.551 1044.88,604.551 1044.89,604.551 1044.9,604.551 1044.91,604.551 1044.91,604.551 1044.92,604.55 1044.93,604.55 1044.94,604.55 1044.95,604.55 1044.96,604.55 1044.97,604.55 1044.98,604.55 1044.99,604.55 1045,604.55 1045.01,604.55 1045.02,604.55 1045.02,604.55 1045.03,604.549 1045.04,604.549 1045.05,604.549 1045.06,604.549 1045.07,604.549 1045.08,604.549 1045.09,604.549 1045.1,604.549 1045.11,604.549 1045.12,604.549 1045.13,604.549 1045.13,604.549 1045.14,604.548 1045.15,604.548 1045.16,604.548 1045.17,604.548 1045.18,604.548 1045.19,604.548 1045.2,604.548 1045.21,604.548 1045.22,604.548 1045.23,604.548 1045.24,604.548 1045.25,604.547 1045.25,604.547 1045.26,604.547 1045.27,604.547 1045.28,604.547 1045.29,604.547 1045.3,604.547 1045.31,604.547 1045.32,604.547 1045.33,604.547 1045.34,604.547 1045.35,604.547 1045.36,604.546 1045.36,604.546 1045.37,604.546 1045.38,604.546 1045.39,604.546 1045.4,604.546 1045.41,604.546 1045.42,604.546 1045.43,604.546 1045.44,604.546 1045.45,604.546 1045.46,604.546 1045.47,604.545 1045.47,604.545 1045.48,604.545 1045.49,604.545 1045.5,604.545 1045.51,604.545 1045.52,604.545 1045.53,604.545 1045.54,604.545 1045.55,604.545 1045.56,604.545 1045.57,604.545 1045.58,604.544 1045.59,604.544 1045.59,604.544 1045.6,604.544 1045.61,604.544 1045.62,604.544 1045.63,604.544 1045.64,604.544 1045.65,604.544 1045.66,604.544 1045.67,604.544 1045.68,604.544 1045.69,604.543 1045.7,604.543 1045.7,604.543 1045.71,604.543 1045.72,604.543 1045.73,604.543 1045.74,604.543 1045.75,604.543 1045.76,604.543 1045.77,604.543 1045.78,604.543 1045.79,604.543 1045.8,604.542 1045.81,604.542 1045.81,604.542 1045.82,604.542 1045.83,604.542 1045.84,604.542 1045.85,604.542 1045.86,604.542 1045.87,604.542 1045.88,604.542 1045.89,604.542 1045.9,604.542 1045.91,604.541 1045.92,604.541 1045.93,604.541 1045.93,604.541 1045.94,604.541 1045.95,604.541 1045.96,604.541 1045.97,604.541 1045.98,604.541 1045.99,604.541 1046,604.541 1046.01,604.54 1046.02,604.54 1046.03,604.54 1046.04,604.54 1046.04,604.54 1046.05,604.54 1046.06,604.54 1046.07,604.54 1046.08,604.54 1046.09,604.54 1046.1,604.54 1046.11,604.54 1046.12,604.539 1046.13,604.539 1046.14,604.539 1046.15,604.539 1046.15,604.539 1046.16,604.539 1046.17,604.539 1046.18,604.539 1046.19,604.539 1046.2,604.539 1046.21,604.539 1046.22,604.539 1046.23,604.538 1046.24,604.538 1046.25,604.538 1046.26,604.538 1046.27,604.538 1046.27,604.538 1046.28,604.538 1046.29,604.538 1046.3,604.538 1046.31,604.538 1046.32,604.538 1046.33,604.538 1046.34,604.537 1046.35,604.537 1046.36,604.537 1046.37,604.537 1046.38,604.537 1046.38,604.537 1046.39,604.537 1046.4,604.537 1046.41,604.537 1046.42,604.537 1046.43,604.537 1046.44,604.537 1046.45,604.536 1046.46,604.536 1046.47,604.536 1046.48,604.536 1046.49,604.536 1046.49,604.536 1046.5,604.536 1046.51,604.536 1046.52,604.536 1046.53,604.536 1046.54,604.536 1046.55,604.536 1046.56,604.535 1046.57,604.535 1046.58,604.535 1046.59,604.535 1046.6,604.535 1046.61,604.535 1046.61,604.535 1046.62,604.535 1046.63,604.535 1046.64,604.535 1046.65,604.535 1046.66,604.535 1046.67,604.534 1046.68,604.534 1046.69,604.534 1046.7,604.534 1046.71,604.534 1046.72,604.534 1046.72,604.534 1046.73,604.534 1046.74,604.534 1046.75,604.534 1046.76,604.534 1046.77,604.534 1046.78,604.533 1046.79,604.533 1046.8,604.533 1046.81,604.533 1046.82,604.533 1046.83,604.533 1046.83,604.533 1046.84,604.533 1046.85,604.533 1046.86,604.533 1046.87,604.533 1046.88,604.532 1046.89,604.532 1046.9,604.532 1046.91,604.532 1046.92,604.532 1046.93,604.532 1046.94,604.532 1046.95,604.532 1046.95,604.532 1046.96,604.532 1046.97,604.532 1046.98,604.532 1046.99,604.531 1047,604.531 1047.01,604.531 1047.02,604.531 1047.03,604.531 1047.04,604.531 1047.05,604.531 1047.06,604.531 1047.06,604.531 1047.07,604.531 1047.08,604.531 1047.09,604.531 1047.1,604.53 1047.11,604.53 1047.12,604.53 1047.13,604.53 1047.14,604.53 1047.15,604.53 1047.16,604.53 1047.17,604.53 1047.17,604.53 1047.18,604.53 1047.19,604.53 1047.2,604.53 1047.21,604.529 1047.22,604.529 1047.23,604.529 1047.24,604.529 1047.25,604.529 1047.26,604.529 1047.27,604.529 1047.28,604.529 1047.29,604.529 1047.29,604.529 1047.3,604.529 1047.31,604.529 1047.32,604.528 1047.33,604.528 1047.34,604.528 1047.35,604.528 1047.36,604.528 1047.37,604.528 1047.38,604.528 1047.39,604.528 1047.4,604.528 1047.4,604.528 1047.41,604.528 1047.42,604.528 1047.43,604.527 1047.44,604.527 1047.45,604.527 1047.46,604.527 1047.47,604.527 1047.48,604.527 1047.49,604.527 1047.5,604.527 1047.51,604.527 1047.52,604.527 1047.52,604.527 1047.53,604.527 1047.54,604.526 1047.55,604.526 1047.56,604.526 1047.57,604.526 1047.58,604.526 1047.59,604.526 1047.6,604.526 1047.61,604.526 1047.62,604.526 1047.63,604.526 1047.63,604.526 1047.64,604.526 1047.65,604.525 1047.66,604.525 1047.67,604.525 1047.68,604.525 1047.69,604.525 1047.7,604.525 1047.71,604.525 1047.72,604.525 1047.73,604.525 1047.74,604.525 1047.74,604.525 1047.75,604.525 1047.76,604.524 1047.77,604.524 1047.78,604.524 1047.79,604.524 1047.8,604.524 1047.81,604.524 1047.82,604.524 1047.83,604.524 1047.84,604.524 1047.85,604.524 1047.86,604.524 1047.86,604.524 1047.87,604.523 1047.88,604.523 1047.89,604.523 1047.9,604.523 1047.91,604.523 1047.92,604.523 1047.93,604.523 1047.94,604.523 1047.95,604.523 1047.96,604.523 1047.97,604.523 1047.97,604.523 1047.98,604.522 1047.99,604.522 1048,604.522 1048.01,604.522 1048.02,604.522 1048.03,604.522 1048.04,604.522 1048.05,604.522 1048.06,604.522 1048.07,604.522 1048.08,604.522 1048.08,604.522 1048.09,604.521 1048.1,604.521 1048.11,604.521 1048.12,604.521 1048.13,604.521 1048.14,604.521 1048.15,604.521 1048.16,604.521 1048.17,604.521 1048.18,604.521 1048.19,604.521 1048.2,604.521 1048.2,604.52 1048.21,604.52 1048.22,604.52 1048.23,604.52 1048.24,604.52 1048.25,604.52 1048.26,604.52 1048.27,604.52 1048.28,604.52 1048.29,604.52 1048.3,604.52 1048.31,604.52 1048.31,604.519 1048.32,604.519 1048.33,604.519 1048.34,604.519 1048.35,604.519 1048.36,604.519 1048.37,604.519 1048.38,604.519 1048.39,604.519 1048.4,604.519 1048.41,604.519 1048.42,604.519 1048.42,604.518 1048.43,604.518 1048.44,604.518 1048.45,604.518 1048.46,604.518 1048.47,604.518 1048.48,604.518 1048.49,604.518 1048.5,604.518 1048.51,604.518 1048.52,604.518 1048.53,604.518 1048.54,604.517 1048.54,604.517 1048.55,604.517 1048.56,604.517 1048.57,604.517 1048.58,604.517 1048.59,604.517 1048.6,604.517 1048.61,604.517 1048.62,604.517 1048.63,604.517 1048.64,604.517 1048.65,604.516 1048.65,604.516 1048.66,604.516 1048.67,604.516 1048.68,604.516 1048.69,604.516 1048.7,604.516 1048.71,604.516 1048.72,604.516 1048.73,604.516 1048.74,604.516 1048.75,604.516 1048.76,604.515 1048.76,604.515 1048.77,604.515 1048.78,604.515 1048.79,604.515 1048.8,604.515 1048.81,604.515 1048.82,604.515 1048.83,604.515 1048.84,604.515 1048.85,604.515 1048.86,604.515 1048.87,604.514 1048.88,604.514 1048.88,604.514 1048.89,604.514 1048.9,604.514 1048.91,604.514 1048.92,604.514 1048.93,604.514 1048.94,604.514 1048.95,604.514 1048.96,604.514 1048.97,604.514 1048.98,604.513 1048.99,604.513 1048.99,604.513 1049,604.513 1049.01,604.513 1049.02,604.513 1049.03,604.513 1049.04,604.513 1049.05,604.513 1049.06,604.513 1049.07,604.513 1049.08,604.513 1049.09,604.512 1049.1,604.512 1049.1,604.512 1049.11,604.512 1049.12,604.512 1049.13,604.512 1049.14,604.512 1049.15,604.512 1049.16,604.512 1049.17,604.512 1049.18,604.512 1049.19,604.512 1049.2,604.511 1049.21,604.511 1049.22,604.511 1049.22,604.511 1049.23,604.511 1049.24,604.511 1049.25,604.511 1049.26,604.511 1049.27,604.511 1049.28,604.511 1049.29,604.511 1049.3,604.511 1049.31,604.51 1049.32,604.51 1049.33,604.51 1049.33,604.51 1049.34,604.51 1049.35,604.51 1049.36,604.51 1049.37,604.51 1049.38,604.51 1049.39,604.51 1049.4,604.51 1049.41,604.51 1049.42,604.509 1049.43,604.509 1049.44,604.509 1049.44,604.509 1049.45,604.509 1049.46,604.509 1049.47,604.509 1049.48,604.509 1049.49,604.509 1049.5,604.509 1049.51,604.509 1049.52,604.509 1049.53,604.508 1049.54,604.508 1049.55,604.508 1049.56,604.508 1049.56,604.508 1049.57,604.508 1049.58,604.508 1049.59,604.508 1049.6,604.508 1049.61,604.508 1049.62,604.508 1049.63,604.508 1049.64,604.507 1049.65,604.507 1049.66,604.507 1049.67,604.507 1049.67,604.507 1049.68,604.507 1049.69,604.507 1049.7,604.507 1049.71,604.507 1049.72,604.507 1049.73,604.507 1049.74,604.507 1049.75,604.506 1049.76,604.506 1049.77,604.506 1049.78,604.506 1049.78,604.506 1049.79,604.506 1049.8,604.506 1049.81,604.506 1049.82,604.506 1049.83,604.506 1049.84,604.506 1049.85,604.506 1049.86,604.505 1049.87,604.505 1049.88,604.505 1049.89,604.505 1049.9,604.505 1049.9,604.505 1049.91,604.505 1049.92,604.505 1049.93,604.505 1049.94,604.505 1049.95,604.505 1049.96,604.505 1049.97,604.504 1049.98,604.504 1049.99,604.504 1050,604.504 1050.01,604.504 1050.01,604.504 1050.02,604.504 1050.03,604.504 1050.04,604.504 1050.05,604.504 1050.06,604.504 1050.07,604.504 1050.08,604.503 1050.09,604.503 1050.1,604.503 1050.11,604.503 1050.12,604.503 1050.12,604.503 1050.13,604.503 1050.14,604.503 1050.15,604.503 1050.16,604.503 1050.17,604.503 1050.18,604.503 1050.19,604.502 1050.2,604.502 1050.21,604.502 1050.22,604.502 1050.23,604.502 1050.24,604.502 1050.24,604.502 1050.25,604.502 1050.26,604.502 1050.27,604.502 1050.28,604.502 1050.29,604.502 1050.3,604.501 1050.31,604.501 1050.32,604.501 1050.33,604.501 1050.34,604.501 1050.35,604.501 1050.35,604.501 1050.36,604.501 1050.37,604.501 1050.38,604.501 1050.39,604.501 1050.4,604.501 1050.41,604.5 1050.42,604.5 1050.43,604.5 1050.44,604.5 1050.45,604.5 1050.46,604.5 1050.46,604.5 1050.47,604.5 1050.48,604.5 1050.49,604.5 1050.5,604.5 1050.51,604.5 1050.52,604.499 1050.53,604.499 1050.54,604.499 1050.55,604.499 1050.56,604.499 1050.57,604.499 1050.58,604.499 1050.58,604.499 1050.59,604.499 1050.6,604.499 1050.61,604.499 1050.62,604.499 1050.63,604.498 1050.64,604.498 1050.65,604.498 1050.66,604.498 1050.67,604.498 1050.68,604.498 1050.69,604.498 1050.69,604.498 1050.7,604.498 1050.71,604.498 1050.72,604.498 1050.73,604.498 1050.74,604.497 1050.75,604.497 1050.76,604.497 1050.77,604.497 1050.78,604.497 1050.79,604.497 1050.8,604.497 1050.8,604.497 1050.81,604.497 1050.82,604.497 1050.83,604.497 1050.84,604.497 1050.85,604.496 1050.86,604.496 1050.87,604.496 1050.88,604.496 1050.89,604.496 1050.9,604.496 1050.91,604.496 1050.92,604.496 1050.92,604.496 1050.93,604.496 1050.94,604.496 1050.95,604.496 1050.96,604.495 1050.97,604.495 1050.98,604.495 1050.99,604.495 1051,604.495 1051.01,604.495 1051.02,604.495 1051.03,604.495 1051.03,604.495 1051.04,604.495 1051.05,604.495 1051.06,604.495 1051.07,604.494 1051.08,604.494 1051.09,604.494 1051.1,604.494 1051.11,604.494 1051.12,604.494 1051.13,604.494 1051.14,604.494 1051.14,604.494 1051.15,604.494 1051.16,604.494 1051.17,604.494 1051.18,604.493 1051.19,604.493 1051.2,604.493 1051.21,604.493 1051.22,604.493 1051.23,604.493 1051.24,604.493 1051.25,604.493 1051.26,604.493 1051.26,604.493 1051.27,604.493 1051.28,604.493 1051.29,604.492 1051.3,604.492 1051.31,604.492 1051.32,604.492 1051.33,604.492 1051.34,604.492 1051.35,604.492 1051.36,604.492 1051.37,604.492 1051.37,604.492 1051.38,604.492 1051.39,604.492 1051.4,604.492 1051.41,604.491 1051.42,604.491 1051.43,604.491 1051.44,604.491 1051.45,604.491 1051.46,604.491 1051.47,604.491 1051.48,604.491 1051.48,604.491 1051.49,604.491 1051.5,604.491 1051.51,604.491 1051.52,604.49 1051.53,604.49 1051.54,604.49 1051.55,604.49 1051.56,604.49 1051.57,604.49 1051.58,604.49 1051.59,604.49 1051.6,604.49 1051.6,604.49 1051.61,604.49 1051.62,604.49 1051.63,604.489 1051.64,604.489 1051.65,604.489 1051.66,604.489 1051.67,604.489 1051.68,604.489 1051.69,604.489 1051.7,604.489 1051.71,604.489 1051.71,604.489 1051.72,604.489 1051.73,604.489 1051.74,604.488 1051.75,604.488 1051.76,604.488 1051.77,604.488 1051.78,604.488 1051.79,604.488 1051.8,604.488 1051.81,604.488 1051.82,604.488 1051.82,604.488 1051.83,604.488 1051.84,604.488 1051.85,604.487 1051.86,604.487 1051.87,604.487 1051.88,604.487 1051.89,604.487 1051.9,604.487 1051.91,604.487 1051.92,604.487 1051.93,604.487 1051.94,604.487 1051.94,604.487 1051.95,604.487 1051.96,604.486 1051.97,604.486 1051.98,604.486 1051.99,604.486 1052,604.486 1052.01,604.486 1052.02,604.486 1052.03,604.486 1052.04,604.486 1052.05,604.486 1052.05,604.486 1052.06,604.486 1052.07,604.485 1052.08,604.485 1052.09,604.485 1052.1,604.485 1052.11,604.485 1052.12,604.485 1052.13,604.485 1052.14,604.485 1052.15,604.485 1052.16,604.485 1052.16,604.485 1052.17,604.485 1052.18,604.484 1052.19,604.484 1052.2,604.484 1052.21,604.484 1052.22,604.484 1052.23,604.484 1052.24,604.484 1052.25,604.484 1052.26,604.484 1052.27,604.484 1052.28,604.484 1052.28,604.484 1052.29,604.483 1052.3,604.483 1052.31,604.483 1052.32,604.483 1052.33,604.483 1052.34,604.483 1052.35,604.483 1052.36,604.483 1052.37,604.483 1052.38,604.483 1052.39,604.483 1052.39,604.483 1052.4,604.483 1052.41,604.482 1052.42,604.482 1052.43,604.482 1052.44,604.482 1052.45,604.482 1052.46,604.482 1052.47,604.482 1052.48,604.482 1052.49,604.482 1052.5,604.482 1052.5,604.482 1052.51,604.482 1052.52,604.481 1052.53,604.481 1052.54,604.481 1052.55,604.481 1052.56,604.481 1052.57,604.481 1052.58,604.481 1052.59,604.481 1052.6,604.481 1052.61,604.481 1052.62,604.481 1052.62,604.481 1052.63,604.48 1052.64,604.48 1052.65,604.48 1052.66,604.48 1052.67,604.48 1052.68,604.48 1052.69,604.48 1052.7,604.48 1052.71,604.48 1052.72,604.48 1052.73,604.48 1052.73,604.48 1052.74,604.479 1052.75,604.479 1052.76,604.479 1052.77,604.479 1052.78,604.479 1052.79,604.479 1052.8,604.479 1052.81,604.479 1052.82,604.479 1052.83,604.479 1052.84,604.479 1052.84,604.479 1052.85,604.478 1052.86,604.478 1052.87,604.478 1052.88,604.478 1052.89,604.478 1052.9,604.478 1052.91,604.478 1052.92,604.478 1052.93,604.478 1052.94,604.478 1052.95,604.478 1052.96,604.478 1052.96,604.477 1052.97,604.477 1052.98,604.477 1052.99,604.477 1053,604.477 1053.01,604.477 1053.02,604.477 1053.03,604.477 1053.04,604.477 1053.05,604.477 1053.06,604.477 1053.07,604.477 1053.07,604.476 1053.08,604.476 1053.09,604.476 1053.1,604.476 1053.11,604.476 1053.12,604.476 1053.13,604.476 1053.14,604.476 1053.15,604.476 1053.16,604.476 1053.17,604.476 1053.18,604.476 1053.18,604.476 1053.19,604.475 1053.2,604.475 1053.21,604.475 1053.22,604.475 1053.23,604.475 1053.24,604.475 1053.25,604.475 1053.26,604.475 1053.27,604.475 1053.28,604.475 1053.29,604.475 1053.3,604.475 1053.3,604.474 1053.31,604.474 1053.32,604.474 1053.33,604.474 1053.34,604.474 1053.35,604.474 1053.36,604.474 1053.37,604.474 1053.38,604.474 1053.39,604.474 1053.4,604.474 1053.41,604.474 1053.41,604.473 1053.42,604.473 1053.43,604.473 1053.44,604.473 1053.45,604.473 1053.46,604.473 1053.47,604.473 1053.48,604.473 1053.49,604.473 1053.5,604.473 1053.51,604.473 1053.52,604.473 1053.52,604.472 1053.53,604.472 1053.54,604.472 1053.55,604.472 1053.56,604.472 1053.57,604.472 1053.58,604.472 1053.59,604.472 1053.6,604.472 1053.61,604.472 1053.62,604.472 1053.63,604.472 1053.64,604.471 1053.64,604.471 1053.65,604.471 1053.66,604.471 1053.67,604.471 1053.68,604.471 1053.69,604.471 1053.7,604.471 1053.71,604.471 1053.72,604.471 1053.73,604.471 1053.74,604.471 1053.75,604.471 1053.75,604.47 1053.76,604.47 1053.77,604.47 1053.78,604.47 1053.79,604.47 1053.8,604.47 1053.81,604.47 1053.82,604.47 1053.83,604.47 1053.84,604.47 1053.85,604.47 1053.86,604.47 1053.86,604.469 1053.87,604.469 1053.88,604.469 1053.89,604.469 1053.9,604.469 1053.91,604.469 1053.92,604.469 1053.93,604.469 1053.94,604.469 1053.95,604.469 1053.96,604.469 1053.97,604.469 1053.98,604.468 1053.98,604.468 1053.99,604.468 1054,604.468 1054.01,604.468 1054.02,604.468 1054.03,604.468 1054.04,604.468 1054.05,604.468 1054.06,604.468 1054.07,604.468 1054.08,604.468 1054.09,604.467 1054.09,604.467 1054.1,604.467 1054.11,604.467 1054.12,604.467 1054.13,604.467 1054.14,604.467 1054.15,604.467 1054.16,604.467 1054.17,604.467 1054.18,604.467 1054.19,604.467 1054.2,604.466 1054.2,604.466 1054.21,604.466 1054.22,604.466 1054.23,604.466 1054.24,604.466 1054.25,604.466 1054.26,604.466 1054.27,604.466 1054.28,604.466 1054.29,604.466 1054.3,604.466 1054.31,604.466 1054.32,604.465 1054.32,604.465 1054.33,604.465 1054.34,604.465 1054.35,604.465 1054.36,604.465 1054.37,604.465 1054.38,604.465 1054.39,604.465 1054.4,604.465 1054.41,604.465 1054.42,604.465 1054.43,604.464 1054.43,604.464 1054.44,604.464 1054.45,604.464 1054.46,604.464 1054.47,604.464 1054.48,604.464 1054.49,604.464 1054.5,604.464 1054.51,604.464 1054.52,604.464 1054.53,604.464 1054.54,604.463 1054.54,604.463 1054.55,604.463 1054.56,604.463 1054.57,604.463 1054.58,604.463 1054.59,604.463 1054.6,604.463 1054.61,604.463 1054.62,604.463 1054.63,604.463 1054.64,604.463 1054.65,604.462 1054.66,604.462 1054.66,604.462 1054.67,604.462 1054.68,604.462 1054.69,604.462 1054.7,604.462 1054.71,604.462 1054.72,604.462 1054.73,604.462 1054.74,604.462 1054.75,604.462 1054.76,604.461 1054.77,604.461 1054.77,604.461 1054.78,604.461 1054.79,604.461 1054.8,604.461 1054.81,604.461 1054.82,604.461 1054.83,604.461 1054.84,604.461 1054.85,604.461 1054.86,604.461 1054.87,604.461 1054.88,604.46 1054.88,604.46 1054.89,604.46 1054.9,604.46 1054.91,604.46 1054.92,604.46 1054.93,604.46 1054.94,604.46 1054.95,604.46 1054.96,604.46 1054.97,604.46 1054.98,604.46 1054.99,604.459 1055,604.459 1055,604.459 1055.01,604.459 1055.02,604.459 1055.03,604.459 1055.04,604.459 1055.05,604.459 1055.06,604.459 1055.07,604.459 1055.08,604.459 1055.09,604.459 1055.1,604.458 1055.11,604.458 1055.11,604.458 1055.12,604.458 1055.13,604.458 1055.14,604.458 1055.15,604.458 1055.16,604.458 1055.17,604.458 1055.18,604.458 1055.19,604.458 1055.2,604.458 1055.21,604.457 1055.22,604.457 1055.22,604.457 1055.23,604.457 1055.24,604.457 1055.25,604.457 1055.26,604.457 1055.27,604.457 1055.28,604.457 1055.29,604.457 1055.3,604.457 1055.31,604.457 1055.32,604.457 1055.33,604.456 1055.34,604.456 1055.34,604.456 1055.35,604.456 1055.36,604.456 1055.37,604.456 1055.38,604.456 1055.39,604.456 1055.4,604.456 1055.41,604.456 1055.42,604.456 1055.43,604.456 1055.44,604.455 1055.45,604.455 1055.45,604.455 1055.46,604.455 1055.47,604.455 1055.48,604.455 1055.49,604.455 1055.5,604.455 1055.51,604.455 1055.52,604.455 1055.53,604.455 1055.54,604.455 1055.55,604.454 1055.56,604.454 1055.56,604.454 1055.57,604.454 1055.58,604.454 1055.59,604.454 1055.6,604.454 1055.61,604.454 1055.62,604.454 1055.63,604.454 1055.64,604.454 1055.65,604.454 1055.66,604.453 1055.67,604.453 1055.68,604.453 1055.68,604.453 1055.69,604.453 1055.7,604.453 1055.71,604.453 1055.72,604.453 1055.73,604.453 1055.74,604.453 1055.75,604.453 1055.76,604.453 1055.77,604.453 1055.78,604.452 1055.79,604.452 1055.79,604.452 1055.8,604.452 1055.81,604.452 1055.82,604.452 1055.83,604.452 1055.84,604.452 1055.85,604.452 1055.86,604.452 1055.87,604.452 1055.88,604.452 1055.89,604.451 1055.9,604.451 1055.9,604.451 1055.91,604.451 1055.92,604.451 1055.93,604.451 1055.94,604.451 1055.95,604.451 1055.96,604.451 1055.97,604.451 1055.98,604.451 1055.99,604.451 1056,604.45 1056.01,604.45 1056.02,604.45 1056.02,604.45 1056.03,604.45 1056.04,604.45 1056.05,604.45 1056.06,604.45 1056.07,604.45 1056.08,604.45 1056.09,604.45 1056.1,604.45 1056.11,604.45 1056.12,604.449 1056.13,604.449 1056.13,604.449 1056.14,604.449 1056.15,604.449 1056.16,604.449 1056.17,604.449 1056.18,604.449 1056.19,604.449 1056.2,604.449 1056.21,604.449 1056.22,604.449 1056.23,604.448 1056.24,604.448 1056.24,604.448 1056.25,604.448 1056.26,604.448 1056.27,604.448 1056.28,604.448 1056.29,604.448 1056.3,604.448 1056.31,604.448 1056.32,604.448 1056.33,604.448 1056.34,604.447 1056.35,604.447 1056.36,604.447 1056.36,604.447 1056.37,604.447 1056.38,604.447 1056.39,604.447 1056.4,604.447 1056.41,604.447 1056.42,604.447 1056.43,604.447 1056.44,604.447 1056.45,604.446 1056.46,604.446 1056.47,604.446 1056.47,604.446 1056.48,604.446 1056.49,604.446 1056.5,604.446 1056.51,604.446 1056.52,604.446 1056.53,604.446 1056.54,604.446 1056.55,604.446 1056.56,604.446 1056.57,604.445 1056.58,604.445 1056.58,604.445 1056.59,604.445 1056.6,604.445 1056.61,604.445 1056.62,604.445 1056.63,604.445 1056.64,604.445 1056.65,604.445 1056.66,604.445 1056.67,604.445 1056.68,604.444 1056.69,604.444 1056.7,604.444 1056.7,604.444 1056.71,604.444 1056.72,604.444 1056.73,604.444 1056.74,604.444 1056.75,604.444 1056.76,604.444 1056.77,604.444 1056.78,604.444 1056.79,604.443 1056.8,604.443 1056.81,604.443 1056.81,604.443 1056.82,604.443 1056.83,604.443 1056.84,604.443 1056.85,604.443 1056.86,604.443 1056.87,604.443 1056.88,604.443 1056.89,604.443 1056.9,604.443 1056.91,604.442 1056.92,604.442 1056.92,604.442 1056.93,604.442 1056.94,604.442 1056.95,604.442 1056.96,604.442 1056.97,604.442 1056.98,604.442 1056.99,604.442 1057,604.442 1057.01,604.442 1057.02,604.441 1057.03,604.441 1057.04,604.441 1057.04,604.441 1057.05,604.441 1057.06,604.441 1057.07,604.441 1057.08,604.441 1057.09,604.441 1057.1,604.441 1057.11,604.441 1057.12,604.441 1057.13,604.44 1057.14,604.44 1057.15,604.44 1057.15,604.44 1057.16,604.44 1057.17,604.44 1057.18,604.44 1057.19,604.44 1057.2,604.44 1057.21,604.44 1057.22,604.44 1057.23,604.44 1057.24,604.44 1057.25,604.439 1057.26,604.439 1057.26,604.439 1057.27,604.439 1057.28,604.439 1057.29,604.439 1057.3,604.439 1057.31,604.439 1057.32,604.439 1057.33,604.439 1057.34,604.439 1057.35,604.439 1057.36,604.438 1057.37,604.438 1057.38,604.438 1057.38,604.438 1057.39,604.438 1057.4,604.438 1057.41,604.438 1057.42,604.438 1057.43,604.438 1057.44,604.438 1057.45,604.438 1057.46,604.438 1057.47,604.437 1057.48,604.437 1057.49,604.437 1057.49,604.437 1057.5,604.437 1057.51,604.437 1057.52,604.437 1057.53,604.437 1057.54,604.437 1057.55,604.437 1057.56,604.437 1057.57,604.437 1057.58,604.437 1057.59,604.436 1057.6,604.436 1057.6,604.436 1057.61,604.436 1057.62,604.436 1057.63,604.436 1057.64,604.436 1057.65,604.436 1057.66,604.436 1057.67,604.436 1057.68,604.436 1057.69,604.436 1057.7,604.435 1057.71,604.435 1057.72,604.435 1057.72,604.435 1057.73,604.435 1057.74,604.435 1057.75,604.435 1057.76,604.435 1057.77,604.435 1057.78,604.435 1057.79,604.435 1057.8,604.435 1057.81,604.434 1057.82,604.434 1057.83,604.434 1057.83,604.434 1057.84,604.434 1057.85,604.434 1057.86,604.434 1057.87,604.434 1057.88,604.434 1057.89,604.434 1057.9,604.434 1057.91,604.434 1057.92,604.434 1057.93,604.433 1057.94,604.433 1057.94,604.433 1057.95,604.433 1057.96,604.433 1057.97,604.433 1057.98,604.433 1057.99,604.433 1058,604.433 1058.01,604.433 1058.02,604.433 1058.03,604.433 1058.04,604.432 1058.05,604.432 1058.06,604.432 1058.06,604.432 1058.07,604.432 1058.08,604.432 1058.09,604.432 1058.1,604.432 1058.11,604.432 1058.12,604.432 1058.13,604.432 1058.14,604.432 1058.15,604.431 1058.16,604.431 1058.17,604.431 1058.17,604.431 1058.18,604.431 1058.19,604.431 1058.2,604.431 1058.21,604.431 1058.22,604.431 1058.23,604.431 1058.24,604.431 1058.25,604.431 1058.26,604.431 1058.27,604.43 1058.28,604.43 1058.28,604.43 1058.29,604.43 1058.3,604.43 1058.31,604.43 1058.32,604.43 1058.33,604.43 1058.34,604.43 1058.35,604.43 1058.36,604.43 1058.37,604.43 1058.38,604.429 1058.39,604.429 1058.4,604.429 1058.4,604.429 1058.41,604.429 1058.42,604.429 1058.43,604.429 1058.44,604.429 1058.45,604.429 1058.46,604.429 1058.47,604.429 1058.48,604.429 1058.49,604.429 1058.5,604.428 1058.51,604.428 1058.51,604.428 1058.52,604.428 1058.53,604.428 1058.54,604.428 1058.55,604.428 1058.56,604.428 1058.57,604.428 1058.58,604.428 1058.59,604.428 1058.6,604.428 1058.61,604.427 1058.62,604.427 1058.62,604.427 1058.63,604.427 1058.64,604.427 1058.65,604.427 1058.66,604.427 1058.67,604.427 1058.68,604.427 1058.69,604.427 1058.7,604.427 1058.71,604.427 1058.72,604.426 1058.73,604.426 1058.74,604.426 1058.74,604.426 1058.75,604.426 1058.76,604.426 1058.77,604.426 1058.78,604.426 1058.79,604.426 1058.8,604.426 1058.81,604.426 1058.82,604.426 1058.83,604.426 1058.84,604.425 1058.85,604.425 1058.85,604.425 1058.86,604.425 1058.87,604.425 1058.88,604.425 1058.89,604.425 1058.9,604.425 1058.91,604.425 1058.92,604.425 1058.93,604.425 1058.94,604.425 1058.95,604.424 1058.96,604.424 1058.96,604.424 1058.97,604.424 1058.98,604.424 1058.99,604.424 1059,604.424 1059.01,604.424 1059.02,604.424 1059.03,604.424 1059.04,604.424 1059.05,604.424 1059.06,604.423 1059.07,604.423 1059.08,604.423 1059.08,604.423 1059.09,604.423 1059.1,604.423 1059.11,604.423 1059.12,604.423 1059.13,604.423 1059.14,604.423 1059.15,604.423 1059.16,604.423 1059.17,604.423 1059.18,604.422 1059.19,604.422 1059.19,604.422 1059.2,604.422 1059.21,604.422 1059.22,604.422 1059.23,604.422 1059.24,604.422 1059.25,604.422 1059.26,604.422 1059.27,604.422 1059.28,604.422 1059.29,604.421 1059.3,604.421 1059.3,604.421 1059.31,604.421 1059.32,604.421 1059.33,604.421 1059.34,604.421 1059.35,604.421 1059.36,604.421 1059.37,604.421 1059.38,604.421 1059.39,604.421 1059.4,604.421 1059.41,604.42 1059.42,604.42 1059.42,604.42 1059.43,604.42 1059.44,604.42 1059.45,604.42 1059.46,604.42 1059.47,604.42 1059.48,604.42 1059.49,604.42 1059.5,604.42 1059.51,604.42 1059.52,604.419 1059.53,604.419 1059.53,604.419 1059.54,604.419 1059.55,604.419 1059.56,604.419 1059.57,604.419 1059.58,604.419 1059.59,604.419 1059.6,604.419 1059.61,604.419 1059.62,604.419 1059.63,604.419 1059.64,604.418 1059.64,604.418 1059.65,604.418 1059.66,604.418 1059.67,604.418 1059.68,604.418 1059.69,604.418 1059.7,604.418 1059.71,604.418 1059.72,604.418 1059.73,604.418 1059.74,604.418 1059.75,604.417 1059.76,604.417 1059.76,604.417 1059.77,604.417 1059.78,604.417 1059.79,604.417 1059.8,604.417 1059.81,604.417 1059.82,604.417 1059.83,604.417 1059.84,604.417 1059.85,604.417 1059.86,604.416 1059.87,604.416 1059.87,604.416 1059.88,604.416 1059.89,604.416 1059.9,604.416 1059.91,604.416 1059.92,604.416 1059.93,604.416 1059.94,604.416 1059.95,604.416 1059.96,604.416 1059.97,604.416 1059.98,604.415 1059.98,604.415 1059.99,604.415 1060,604.415 1060.01,604.415 1060.02,604.415 1060.03,604.415 1060.04,604.415 1060.05,604.415 1060.06,604.415 1060.07,604.415 1060.08,604.415 1060.09,604.414 1060.1,604.414 1060.1,604.414 1060.11,604.414 1060.12,604.414 1060.13,604.414 1060.14,604.414 1060.15,604.414 1060.16,604.414 1060.17,604.414 1060.18,604.414 1060.19,604.414 1060.2,604.414 1060.21,604.413 1060.21,604.413 1060.22,604.413 1060.23,604.413 1060.24,604.413 1060.25,604.413 1060.26,604.413 1060.27,604.413 1060.28,604.413 1060.29,604.413 1060.3,604.413 1060.31,604.413 1060.32,604.412 1060.32,604.412 1060.33,604.412 1060.34,604.412 1060.35,604.412 1060.36,604.412 1060.37,604.412 1060.38,604.412 1060.39,604.412 1060.4,604.412 1060.41,604.412 1060.42,604.412 1060.43,604.412 1060.44,604.411 1060.44,604.411 1060.45,604.411 1060.46,604.411 1060.47,604.411 1060.48,604.411 1060.49,604.411 1060.5,604.411 1060.51,604.411 1060.52,604.411 1060.53,604.411 1060.54,604.411 1060.55,604.41 1060.55,604.41 1060.56,604.41 1060.57,604.41 1060.58,604.41 1060.59,604.41 1060.6,604.41 1060.61,604.41 1060.62,604.41 1060.63,604.41 1060.64,604.41 1060.65,604.41 1060.66,604.409 1060.66,604.409 1060.67,604.409 1060.68,604.409 1060.69,604.409 1060.7,604.409 1060.71,604.409 1060.72,604.409 1060.73,604.409 1060.74,604.409 1060.75,604.409 1060.76,604.409 1060.77,604.409 1060.78,604.408 1060.78,604.408 1060.79,604.408 1060.8,604.408 1060.81,604.408 1060.82,604.408 1060.83,604.408 1060.84,604.408 1060.85,604.408 1060.86,604.408 1060.87,604.408 1060.88,604.408 1060.89,604.407 1060.89,604.407 1060.9,604.407 1060.91,604.407 1060.92,604.407 1060.93,604.407 1060.94,604.407 1060.95,604.407 1060.96,604.407 1060.97,604.407 1060.98,604.407 1060.99,604.407 1061,604.407 1061,604.406 1061.01,604.406 1061.02,604.406 1061.03,604.406 1061.04,604.406 1061.05,604.406 1061.06,604.406 1061.07,604.406 1061.08,604.406 1061.09,604.406 1061.1,604.406 1061.11,604.406 1061.12,604.405 1061.12,604.405 1061.13,604.405 1061.14,604.405 1061.15,604.405 1061.16,604.405 1061.17,604.405 1061.18,604.405 1061.19,604.405 1061.2,604.405 1061.21,604.405 1061.22,604.405 1061.23,604.405 1061.23,604.404 1061.24,604.404 1061.25,604.404 1061.26,604.404 1061.27,604.404 1061.28,604.404 1061.29,604.404 1061.3,604.404 1061.31,604.404 1061.32,604.404 1061.33,604.404 1061.34,604.404 1061.34,604.403 1061.35,604.403 1061.36,604.403 1061.37,604.403 1061.38,604.403 1061.39,604.403 1061.4,604.403 1061.41,604.403 1061.42,604.403 1061.43,604.403 1061.44,604.403 1061.45,604.403 1061.46,604.403 1061.46,604.402 1061.47,604.402 1061.48,604.402 1061.49,604.402 1061.5,604.402 1061.51,604.402 1061.52,604.402 1061.53,604.402 1061.54,604.402 1061.55,604.402 1061.56,604.402 1061.57,604.402 1061.57,604.401 1061.58,604.401 1061.59,604.401 1061.6,604.401 1061.61,604.401 1061.62,604.401 1061.63,604.401 1061.64,604.401 1061.65,604.401 1061.66,604.401 1061.67,604.401 1061.68,604.401 1061.68,604.401 1061.69,604.4 1061.7,604.4 1061.71,604.4 1061.72,604.4 1061.73,604.4 1061.74,604.4 1061.75,604.4 1061.76,604.4 1061.77,604.4 1061.78,604.4 1061.79,604.4 1061.8,604.4 1061.8,604.399 1061.81,604.399 1061.82,604.399 1061.83,604.399 1061.84,604.399 1061.85,604.399 1061.86,604.399 1061.87,604.399 1061.88,604.399 1061.89,604.399 1061.9,604.399 1061.91,604.399 1061.91,604.399 1061.92,604.398 1061.93,604.398 1061.94,604.398 1061.95,604.398 1061.96,604.398 1061.97,604.398 1061.98,604.398 1061.99,604.398 1062,604.398 1062.01,604.398 1062.02,604.398 1062.02,604.398 1062.03,604.397 1062.04,604.397 1062.05,604.397 1062.06,604.397 1062.07,604.397 1062.08,604.397 1062.09,604.397 1062.1,604.397 1062.11,604.397 1062.12,604.397 1062.13,604.397 1062.14,604.397 1062.14,604.397 1062.15,604.396 1062.16,604.396 1062.17,604.396 1062.18,604.396 1062.19,604.396 1062.2,604.396 1062.21,604.396 1062.22,604.396 1062.23,604.396 1062.24,604.396 1062.25,604.396 1062.25,604.396 1062.26,604.395 1062.27,604.395 1062.28,604.395 1062.29,604.395 1062.3,604.395 1062.31,604.395 1062.32,604.395 1062.33,604.395 1062.34,604.395 1062.35,604.395 1062.36,604.395 1062.36,604.395 1062.37,604.395 1062.38,604.394 1062.39,604.394 1062.4,604.394 1062.41,604.394 1062.42,604.394 1062.43,604.394 1062.44,604.394 1062.45,604.394 1062.46,604.394 1062.47,604.394 1062.48,604.394 1062.48,604.394 1062.49,604.393 1062.5,604.393 1062.51,604.393 1062.52,604.393 1062.53,604.393 1062.54,604.393 1062.55,604.393 1062.56,604.393 1062.57,604.393 1062.58,604.393 1062.59,604.393 1062.59,604.393 1062.6,604.393 1062.61,604.392 1062.62,604.392 1062.63,604.392 1062.64,604.392 1062.65,604.392 1062.66,604.392 1062.67,604.392 1062.68,604.392 1062.69,604.392 1062.7,604.392 1062.7,604.392 1062.71,604.392 1062.72,604.392 1062.73,604.391 1062.74,604.391 1062.75,604.391 1062.76,604.391 1062.77,604.391 1062.78,604.391 1062.79,604.391 1062.8,604.391 1062.81,604.391 1062.82,604.391 1062.82,604.391 1062.83,604.391 1062.84,604.39 1062.85,604.39 1062.86,604.39 1062.87,604.39 1062.88,604.39 1062.89,604.39 1062.9,604.39 1062.91,604.39 1062.92,604.39 1062.93,604.39 1062.93,604.39 1062.94,604.39 1062.95,604.39 1062.96,604.389 1062.97,604.389 1062.98,604.389 1062.99,604.389 1063,604.389 1063.01,604.389 1063.02,604.389 1063.03,604.389 1063.04,604.389 1063.04,604.389 1063.05,604.389 1063.06,604.389 1063.07,604.388 1063.08,604.388 1063.09,604.388 1063.1,604.388 1063.11,604.388 1063.12,604.388 1063.13,604.388 1063.14,604.388 1063.15,604.388 1063.16,604.388 1063.16,604.388 1063.17,604.388 1063.18,604.388 1063.19,604.387 1063.2,604.387 1063.21,604.387 1063.22,604.387 1063.23,604.387 1063.24,604.387 1063.25,604.387 1063.26,604.387 1063.27,604.387 1063.27,604.387 1063.28,604.387 1063.29,604.387 1063.3,604.386 1063.31,604.386 1063.32,604.386 1063.33,604.386 1063.34,604.386 1063.35,604.386 1063.36,604.386 1063.37,604.386 1063.38,604.386 1063.38,604.386 1063.39,604.386 1063.4,604.386 1063.41,604.386 1063.42,604.385 1063.43,604.385 1063.44,604.385 1063.45,604.385 1063.46,604.385 1063.47,604.385 1063.48,604.385 1063.49,604.385 1063.5,604.385 1063.5,604.385 1063.51,604.385 1063.52,604.385 1063.53,604.384 1063.54,604.384 1063.55,604.384 1063.56,604.384 1063.57,604.384 1063.58,604.384 1063.59,604.384 1063.6,604.384 1063.61,604.384 1063.61,604.384 1063.62,604.384 1063.63,604.384 1063.64,604.384 1063.65,604.383 1063.66,604.383 1063.67,604.383 1063.68,604.383 1063.69,604.383 1063.7,604.383 1063.71,604.383 1063.72,604.383 1063.72,604.383 1063.73,604.383 1063.74,604.383 1063.75,604.383 1063.76,604.383 1063.77,604.382 1063.78,604.382 1063.79,604.382 1063.8,604.382 1063.81,604.382 1063.82,604.382 1063.83,604.382 1063.84,604.382 1063.84,604.382 1063.85,604.382 1063.86,604.382 1063.87,604.382 1063.88,604.381 1063.89,604.381 1063.9,604.381 1063.91,604.381 1063.92,604.381 1063.93,604.381 1063.94,604.381 1063.95,604.381 1063.95,604.381 1063.96,604.381 1063.97,604.381 1063.98,604.381 1063.99,604.381 1064,604.38 1064.01,604.38 1064.02,604.38 1064.03,604.38 1064.04,604.38 1064.05,604.38 1064.06,604.38 1064.06,604.38 1064.07,604.38 1064.08,604.38 1064.09,604.38 1064.1,604.38 1064.11,604.379 1064.12,604.379 1064.13,604.379 1064.14,604.379 1064.15,604.379 1064.16,604.379 1064.17,604.379 1064.18,604.379 1064.18,604.379 1064.19,604.379 1064.2,604.379 1064.21,604.379 1064.22,604.379 1064.23,604.378 1064.24,604.378 1064.25,604.378 1064.26,604.378 1064.27,604.378 1064.28,604.378 1064.29,604.378 1064.29,604.378 1064.3,604.378 1064.31,604.378 1064.32,604.378 1064.33,604.378 1064.34,604.378 1064.35,604.377 1064.36,604.377 1064.37,604.377 1064.38,604.377 1064.39,604.377 1064.4,604.377 1064.4,604.377 1064.41,604.377 1064.42,604.377 1064.43,604.377 1064.44,604.377 1064.45,604.377 1064.46,604.376 1064.47,604.376 1064.48,604.376 1064.49,604.376 1064.5,604.376 1064.51,604.376 1064.52,604.376 1064.52,604.376 1064.53,604.376 1064.54,604.376 1064.55,604.376 1064.56,604.376 1064.57,604.376 1064.58,604.375 1064.59,604.375 1064.6,604.375 1064.61,604.375 1064.62,604.375 1064.63,604.375 1064.63,604.375 1064.64,604.375 1064.65,604.375 1064.66,604.375 1064.67,604.375 1064.68,604.375 1064.69,604.374 1064.7,604.374 1064.71,604.374 1064.72,604.374 1064.73,604.374 1064.74,604.374 1064.74,604.374 1064.75,604.374 1064.76,604.374 1064.77,604.374 1064.78,604.374 1064.79,604.374 1064.8,604.374 1064.81,604.373 1064.82,604.373 1064.83,604.373 1064.84,604.373 1064.85,604.373 1064.86,604.373 1064.86,604.373 1064.87,604.373 1064.88,604.373 1064.89,604.373 1064.9,604.373 1064.91,604.373 1064.92,604.373 1064.93,604.372 1064.94,604.372 1064.95,604.372 1064.96,604.372 1064.97,604.372 1064.97,604.372 1064.98,604.372 1064.99,604.372 1065,604.372 1065.01,604.372 1065.02,604.372 1065.03,604.372 1065.04,604.371 1065.05,604.371 1065.06,604.371 1065.07,604.371 1065.08,604.371 1065.08,604.371 1065.09,604.371 1065.1,604.371 1065.11,604.371 1065.12,604.371 1065.13,604.371 1065.14,604.371 1065.15,604.371 1065.16,604.37 1065.17,604.37 1065.18,604.37 1065.19,604.37 1065.2,604.37 1065.2,604.37 1065.21,604.37 1065.22,604.37 1065.23,604.37 1065.24,604.37 1065.25,604.37 1065.26,604.37 1065.27,604.369 1065.28,604.369 1065.29,604.369 1065.3,604.369 1065.31,604.369 1065.31,604.369 1065.32,604.369 1065.33,604.369 1065.34,604.369 1065.35,604.369 1065.36,604.369 1065.37,604.369 1065.38,604.369 1065.39,604.368 1065.4,604.368 1065.41,604.368 1065.42,604.368 1065.42,604.368 1065.43,604.368 1065.44,604.368 1065.45,604.368 1065.46,604.368 1065.47,604.368 1065.48,604.368 1065.49,604.368 1065.5,604.368 1065.51,604.367 1065.52,604.367 1065.53,604.367 1065.54,604.367 1065.54,604.367 1065.55,604.367 1065.56,604.367 1065.57,604.367 1065.58,604.367 1065.59,604.367 1065.6,604.367 1065.61,604.367 1065.62,604.366 1065.63,604.366 1065.64,604.366 1065.65,604.366 1065.65,604.366 1065.66,604.366 1065.67,604.366 1065.68,604.366 1065.69,604.366 1065.7,604.366 1065.71,604.366 1065.72,604.366 1065.73,604.366 1065.74,604.365 1065.75,604.365 1065.76,604.365 1065.76,604.365 1065.77,604.365 1065.78,604.365 1065.79,604.365 1065.8,604.365 1065.81,604.365 1065.82,604.365 1065.83,604.365 1065.84,604.365 1065.85,604.365 1065.86,604.364 1065.87,604.364 1065.88,604.364 1065.88,604.364 1065.89,604.364 1065.9,604.364 1065.91,604.364 1065.92,604.364 1065.93,604.364 1065.94,604.364 1065.95,604.364 1065.96,604.364 1065.97,604.363 1065.98,604.363 1065.99,604.363 1065.99,604.363 1066,604.363 1066.01,604.363 1066.02,604.363 1066.03,604.363 1066.04,604.363 1066.05,604.363 1066.06,604.363 1066.07,604.363 1066.08,604.363 1066.09,604.362 1066.1,604.362 1066.1,604.362 1066.11,604.362 1066.12,604.362 1066.13,604.362 1066.14,604.362 1066.15,604.362 1066.16,604.362 1066.17,604.362 1066.18,604.362 1066.19,604.362 1066.2,604.362 1066.21,604.361 1066.22,604.361 1066.22,604.361 1066.23,604.361 1066.24,604.361 1066.25,604.361 1066.26,604.361 1066.27,604.361 1066.28,604.361 1066.29,604.361 1066.3,604.361 1066.31,604.361 1066.32,604.36 1066.33,604.36 1066.33,604.36 1066.34,604.36 1066.35,604.36 1066.36,604.36 1066.37,604.36 1066.38,604.36 1066.39,604.36 1066.4,604.36 1066.41,604.36 1066.42,604.36 1066.43,604.36 1066.44,604.359 1066.44,604.359 1066.45,604.359 1066.46,604.359 1066.47,604.359 1066.48,604.359 1066.49,604.359 1066.5,604.359 1066.51,604.359 1066.52,604.359 1066.53,604.359 1066.54,604.359 1066.55,604.359 1066.56,604.358 1066.56,604.358 1066.57,604.358 1066.58,604.358 1066.59,604.358 1066.6,604.358 1066.61,604.358 1066.62,604.358 1066.63,604.358 1066.64,604.358 1066.65,604.358 1066.66,604.358 1066.67,604.357 1066.67,604.357 1066.68,604.357 1066.69,604.357 1066.7,604.357 1066.71,604.357 1066.72,604.357 1066.73,604.357 1066.74,604.357 1066.75,604.357 1066.76,604.357 1066.77,604.357 1066.78,604.357 1066.78,604.356 1066.79,604.356 1066.8,604.356 1066.81,604.356 1066.82,604.356 1066.83,604.356 1066.84,604.356 1066.85,604.356 1066.86,604.356 1066.87,604.356 1066.88,604.356 1066.89,604.356 1066.9,604.356 1066.9,604.355 1066.91,604.355 1066.92,604.355 1066.93,604.355 1066.94,604.355 1066.95,604.355 1066.96,604.355 1066.97,604.355 1066.98,604.355 1066.99,604.355 1067,604.355 1067.01,604.355 1067.01,604.355 1067.02,604.354 1067.03,604.354 1067.04,604.354 1067.05,604.354 1067.06,604.354 1067.07,604.354 1067.08,604.354 1067.09,604.354 1067.1,604.354 1067.11,604.354 1067.12,604.354 1067.12,604.354 1067.13,604.353 1067.14,604.353 1067.15,604.353 1067.16,604.353 1067.17,604.353 1067.18,604.353 1067.19,604.353 1067.2,604.353 1067.21,604.353 1067.22,604.353 1067.23,604.353 1067.24,604.353 1067.24,604.353 1067.25,604.352 1067.26,604.352 1067.27,604.352 1067.28,604.352 1067.29,604.352 1067.3,604.352 1067.31,604.352 1067.32,604.352 1067.33,604.352 1067.34,604.352 1067.35,604.352 1067.35,604.352 1067.36,604.352 1067.37,604.351 1067.38,604.351 1067.39,604.351 1067.4,604.351 1067.41,604.351 1067.42,604.351 1067.43,604.351 1067.44,604.351 1067.45,604.351 1067.46,604.351 1067.46,604.351 1067.47,604.351 1067.48,604.35 1067.49,604.35 1067.5,604.35 1067.51,604.35 1067.52,604.35 1067.53,604.35 1067.54,604.35 1067.55,604.35 1067.56,604.35 1067.57,604.35 1067.58,604.35 1067.58,604.35 1067.59,604.35 1067.6,604.349 1067.61,604.349 1067.62,604.349 1067.63,604.349 1067.64,604.349 1067.65,604.349 1067.66,604.349 1067.67,604.349 1067.68,604.349 1067.69,604.349 1067.69,604.349 1067.7,604.349 1067.71,604.349 1067.72,604.348 1067.73,604.348 1067.74,604.348 1067.75,604.348 1067.76,604.348 1067.77,604.348 1067.78,604.348 1067.79,604.348 1067.8,604.348 1067.8,604.348 1067.81,604.348 1067.82,604.348 1067.83,604.348 1067.84,604.347 1067.85,604.347 1067.86,604.347 1067.87,604.347 1067.88,604.347 1067.89,604.347 1067.9,604.347 1067.91,604.347 1067.92,604.347 1067.92,604.347 1067.93,604.347 1067.94,604.347 1067.95,604.346 1067.96,604.346 1067.97,604.346 1067.98,604.346 1067.99,604.346 1068,604.346 1068.01,604.346 1068.02,604.346 1068.03,604.346 1068.03,604.346 1068.04,604.346 1068.05,604.346 1068.06,604.346 1068.07,604.345 1068.08,604.345 1068.09,604.345 1068.1,604.345 1068.11,604.345 1068.12,604.345 1068.13,604.345 1068.14,604.345 1068.14,604.345 1068.15,604.345 1068.16,604.345 1068.17,604.345 1068.18,604.345 1068.19,604.344 1068.2,604.344 1068.21,604.344 1068.22,604.344 1068.23,604.344 1068.24,604.344 1068.25,604.344 1068.26,604.344 1068.26,604.344 1068.27,604.344 1068.28,604.344 1068.29,604.344 1068.3,604.343 1068.31,604.343 1068.32,604.343 1068.33,604.343 1068.34,604.343 1068.35,604.343 1068.36,604.343 1068.37,604.343 1068.37,604.343 1068.38,604.343 1068.39,604.343 1068.4,604.343 1068.41,604.343 1068.42,604.342 1068.43,604.342 1068.44,604.342 1068.45,604.342 1068.46,604.342 1068.47,604.342 1068.48,604.342 1068.48,604.342 1068.49,604.342 1068.5,604.342 1068.51,604.342 1068.52,604.342 1068.53,604.342 1068.54,604.341 1068.55,604.341 1068.56,604.341 1068.57,604.341 1068.58,604.341 1068.59,604.341 1068.6,604.341 1068.6,604.341 1068.61,604.341 1068.62,604.341 1068.63,604.341 1068.64,604.341 1068.65,604.341 1068.66,604.34 1068.67,604.34 1068.68,604.34 1068.69,604.34 1068.7,604.34 1068.71,604.34 1068.71,604.34 1068.72,604.34 1068.73,604.34 1068.74,604.34 1068.75,604.34 1068.76,604.34 1068.77,604.34 1068.78,604.339 1068.79,604.339 1068.8,604.339 1068.81,604.339 1068.82,604.339 1068.82,604.339 1068.83,604.339 1068.84,604.339 1068.85,604.339 1068.86,604.339 1068.87,604.339 1068.88,604.339 1068.89,604.338 1068.9,604.338 1068.91,604.338 1068.92,604.338 1068.93,604.338 1068.94,604.338 1068.94,604.338 1068.95,604.338 1068.96,604.338 1068.97,604.338 1068.98,604.338 1068.99,604.338 1069,604.338 1069.01,604.337 1069.02,604.337 1069.03,604.337 1069.04,604.337 1069.05,604.337 1069.05,604.337 1069.06,604.337 1069.07,604.337 1069.08,604.337 1069.09,604.337 1069.1,604.337 1069.11,604.337 1069.12,604.337 1069.13,604.336 1069.14,604.336 1069.15,604.336 1069.16,604.336 1069.16,604.336 1069.17,604.336 1069.18,604.336 1069.19,604.336 1069.2,604.336 1069.21,604.336 1069.22,604.336 1069.23,604.336 1069.24,604.336 1069.25,604.335 1069.26,604.335 1069.27,604.335 1069.28,604.335 1069.28,604.335 1069.29,604.335 1069.3,604.335 1069.31,604.335 1069.32,604.335 1069.33,604.335 1069.34,604.335 1069.35,604.335 1069.36,604.334 1069.37,604.334 1069.38,604.334 1069.39,604.334 1069.39,604.334 1069.4,604.334 1069.41,604.334 1069.42,604.334 1069.43,604.334 1069.44,604.334 1069.45,604.334 1069.46,604.334 1069.47,604.334 1069.48,604.333 1069.49,604.333 1069.5,604.333 1069.5,604.333 1069.51,604.333 1069.52,604.333 1069.53,604.333 1069.54,604.333 1069.55,604.333 1069.56,604.333 1069.57,604.333 1069.58,604.333 1069.59,604.333 1069.6,604.332 1069.61,604.332 1069.62,604.332 1069.62,604.332 1069.63,604.332 1069.64,604.332 1069.65,604.332 1069.66,604.332 1069.67,604.332 1069.68,604.332 1069.69,604.332 1069.7,604.332 1069.71,604.332 1069.72,604.331 1069.73,604.331 1069.73,604.331 1069.74,604.331 1069.75,604.331 1069.76,604.331 1069.77,604.331 1069.78,604.331 1069.79,604.331 1069.8,604.331 1069.81,604.331 1069.82,604.331 1069.83,604.331 1069.84,604.33 1069.84,604.33 1069.85,604.33 1069.86,604.33 1069.87,604.33 1069.88,604.33 1069.89,604.33 1069.9,604.33 1069.91,604.33 1069.92,604.33 1069.93,604.33 1069.94,604.33 1069.95,604.329 1069.96,604.329 1069.96,604.329 1069.97,604.329 1069.98,604.329 1069.99,604.329 1070,604.329 1070.01,604.329 1070.02,604.329 1070.03,604.329 1070.04,604.329 1070.05,604.329 1070.06,604.329 1070.07,604.328 1070.07,604.328 1070.08,604.328 1070.09,604.328 1070.1,604.328 1070.11,604.328 1070.12,604.328 1070.13,604.328 1070.14,604.328 1070.15,604.328 1070.16,604.328 1070.17,604.328 1070.18,604.328 1070.18,604.327 1070.19,604.327 1070.2,604.327 1070.21,604.327 1070.22,604.327 1070.23,604.327 1070.24,604.327 1070.25,604.327 1070.26,604.327 1070.27,604.327 1070.28,604.327 1070.29,604.327 1070.3,604.327 1070.3,604.326 1070.31,604.326 1070.32,604.326 1070.33,604.326 1070.34,604.326 1070.35,604.326 1070.36,604.326 1070.37,604.326 1070.38,604.326 1070.39,604.326 1070.4,604.326 1070.41,604.326 1070.41,604.326 1070.42,604.325 1070.43,604.325 1070.44,604.325 1070.45,604.325 1070.46,604.325 1070.47,604.325 1070.48,604.325 1070.49,604.325 1070.5,604.325 1070.51,604.325 1070.52,604.325 1070.52,604.325 1070.53,604.324 1070.54,604.324 1070.55,604.324 1070.56,604.324 1070.57,604.324 1070.58,604.324 1070.59,604.324 1070.6,604.324 1070.61,604.324 1070.62,604.324 1070.63,604.324 1070.64,604.324 1070.64,604.324 1070.65,604.323 1070.66,604.323 1070.67,604.323 1070.68,604.323 1070.69,604.323 1070.7,604.323 1070.71,604.323 1070.72,604.323 1070.73,604.323 1070.74,604.323 1070.75,604.323 1070.75,604.323 1070.76,604.323 1070.77,604.322 1070.78,604.322 1070.79,604.322 1070.8,604.322 1070.81,604.322 1070.82,604.322 1070.83,604.322 1070.84,604.322 1070.85,604.322 1070.86,604.322 1070.86,604.322 1070.87,604.322 1070.88,604.322 1070.89,604.321 1070.9,604.321 1070.91,604.321 1070.92,604.321 1070.93,604.321 1070.94,604.321 1070.95,604.321 1070.96,604.321 1070.97,604.321 1070.98,604.321 1070.98,604.321 1070.99,604.321 1071,604.321 1071.01,604.32 1071.02,604.32 1071.03,604.32 1071.04,604.32 1071.05,604.32 1071.06,604.32 1071.07,604.32 1071.08,604.32 1071.09,604.32 1071.09,604.32 1071.1,604.32 1071.11,604.32 1071.12,604.32 1071.13,604.319 1071.14,604.319 1071.15,604.319 1071.16,604.319 1071.17,604.319 1071.18,604.319 1071.19,604.319 1071.2,604.319 1071.2,604.319 1071.21,604.319 1071.22,604.319 1071.23,604.319 1071.24,604.319 1071.25,604.318 1071.26,604.318 1071.27,604.318 1071.28,604.318 1071.29,604.318 1071.3,604.318 1071.31,604.318 1071.32,604.318 1071.32,604.318 1071.33,604.318 1071.34,604.318 1071.35,604.318 1071.36,604.317 1071.37,604.317 1071.38,604.317 1071.39,604.317 1071.4,604.317 1071.41,604.317 1071.42,604.317 1071.43,604.317 1071.43,604.317 1071.44,604.317 1071.45,604.317 1071.46,604.317 1071.47,604.317 1071.48,604.316 1071.49,604.316 1071.5,604.316 1071.51,604.316 1071.52,604.316 1071.53,604.316 1071.54,604.316 1071.54,604.316 1071.55,604.316 1071.56,604.316 1071.57,604.316 1071.58,604.316 1071.59,604.316 1071.6,604.315 1071.61,604.315 1071.62,604.315 1071.63,604.315 1071.64,604.315 1071.65,604.315 1071.66,604.315 1071.66,604.315 1071.67,604.315 1071.68,604.315 1071.69,604.315 1071.7,604.315 1071.71,604.315 1071.72,604.314 1071.73,604.314 1071.74,604.314 1071.75,604.314 1071.76,604.314 1071.77,604.314 1071.77,604.314 1071.78,604.314 1071.79,604.314 1071.8,604.314 1071.81,604.314 1071.82,604.314 1071.83,604.314 1071.84,604.313 1071.85,604.313 1071.86,604.313 1071.87,604.313 1071.88,604.313 1071.88,604.313 1071.89,604.313 1071.9,604.313 1071.91,604.313 1071.92,604.313 1071.93,604.313 1071.94,604.313 1071.95,604.313 1071.96,604.312 1071.97,604.312 1071.98,604.312 1071.99,604.312 1072,604.312 1072,604.312 1072.01,604.312 1072.02,604.312 1072.03,604.312 1072.04,604.312 1072.05,604.312 1072.06,604.312 1072.07,604.312 1072.08,604.311 1072.09,604.311 1072.1,604.311 1072.11,604.311 1072.11,604.311 1072.12,604.311 1072.13,604.311 1072.14,604.311 1072.15,604.311 1072.16,604.311 1072.17,604.311 1072.18,604.311 1072.19,604.311 1072.2,604.31 1072.21,604.31 1072.22,604.31 1072.23,604.31 1072.23,604.31 1072.24,604.31 1072.25,604.31 1072.26,604.31 1072.27,604.31 1072.28,604.31 1072.29,604.31 1072.3,604.31 1072.31,604.309 1072.32,604.309 1072.33,604.309 1072.34,604.309 1072.34,604.309 1072.35,604.309 1072.36,604.309 1072.37,604.309 1072.38,604.309 1072.39,604.309 1072.4,604.309 1072.41,604.309 1072.42,604.309 1072.43,604.308 1072.44,604.308 1072.45,604.308 1072.45,604.308 1072.46,604.308 1072.47,604.308 1072.48,604.308 1072.49,604.308 1072.5,604.308 1072.51,604.308 1072.52,604.308 1072.53,604.308 1072.54,604.308 1072.55,604.307 1072.56,604.307 1072.57,604.307 1072.57,604.307 1072.58,604.307 1072.59,604.307 1072.6,604.307 1072.61,604.307 1072.62,604.307 1072.63,604.307 1072.64,604.307 1072.65,604.307 1072.66,604.307 1072.67,604.306 1072.68,604.306 1072.68,604.306 1072.69,604.306 1072.7,604.306 1072.71,604.306 1072.72,604.306 1072.73,604.306 1072.74,604.306 1072.75,604.306 1072.76,604.306 1072.77,604.306 1072.78,604.306 1072.79,604.305 1072.79,604.305 1072.8,604.305 1072.81,604.305 1072.82,604.305 1072.83,604.305 1072.84,604.305 1072.85,604.305 1072.86,604.305 1072.87,604.305 1072.88,604.305 1072.89,604.305 1072.9,604.305 1072.91,604.304 1072.91,604.304 1072.92,604.304 1072.93,604.304 1072.94,604.304 1072.95,604.304 1072.96,604.304 1072.97,604.304 1072.98,604.304 1072.99,604.304 1073,604.304 1073.01,604.304 1073.02,604.304 1073.02,604.303 1073.03,604.303 1073.04,604.303 1073.05,604.303 1073.06,604.303 1073.07,604.303 1073.08,604.303 1073.09,604.303 1073.1,604.303 1073.11,604.303 1073.12,604.303 1073.13,604.303 1073.13,604.303 1073.14,604.302 1073.15,604.302 1073.16,604.302 1073.17,604.302 1073.18,604.302 1073.19,604.302 1073.2,604.302 1073.21,604.302 1073.22,604.302 1073.23,604.302 1073.24,604.302 1073.25,604.302 1073.25,604.302 1073.26,604.301 1073.27,604.301 1073.28,604.301 1073.29,604.301 1073.3,604.301 1073.31,604.301 1073.32,604.301 1073.33,604.301 1073.34,604.301 1073.35,604.301 1073.36,604.301 1073.36,604.301 1073.37,604.301 1073.38,604.3 1073.39,604.3 1073.4,604.3 1073.41,604.3 1073.42,604.3 1073.43,604.3 1073.44,604.3 1073.45,604.3 1073.46,604.3 1073.47,604.3 1073.47,604.3 1073.48,604.3 1073.49,604.3 1073.5,604.299 1073.51,604.299 1073.52,604.299 1073.53,604.299 1073.54,604.299 1073.55,604.299 1073.56,604.299 1073.57,604.299 1073.58,604.299 1073.59,604.299 1073.59,604.299 1073.6,604.299 1073.61,604.298 1073.62,604.298 1073.63,604.298 1073.64,604.298 1073.65,604.298 1073.66,604.298 1073.67,604.298 1073.68,604.298 1073.69,604.298 1073.7,604.298 1073.7,604.298 1073.71,604.298 1073.72,604.298 1073.73,604.297 1073.74,604.297 1073.75,604.297 1073.76,604.297 1073.77,604.297 1073.78,604.297 1073.79,604.297 1073.8,604.297 1073.81,604.297 1073.81,604.297 1073.82,604.297 1073.83,604.297 1073.84,604.297 1073.85,604.296 1073.86,604.296 1073.87,604.296 1073.88,604.296 1073.89,604.296 1073.9,604.296 1073.91,604.296 1073.92,604.296 1073.93,604.296 1073.93,604.296 1073.94,604.296 1073.95,604.296 1073.96,604.296 1073.97,604.295 1073.98,604.295 1073.99,604.295 1074,604.295 1074.01,604.295 1074.02,604.295 1074.03,604.295 1074.04,604.295 1074.04,604.295 1074.05,604.295 1074.06,604.295 1074.07,604.295 1074.08,604.295 1074.09,604.294 1074.1,604.294 1074.11,604.294 1074.12,604.294 1074.13,604.294 1074.14,604.294 1074.15,604.294 1074.15,604.294 1074.16,604.294 1074.17,604.294 1074.18,604.294 1074.19,604.294 1074.2,604.294 1074.21,604.293 1074.22,604.293 1074.23,604.293 1074.24,604.293 1074.25,604.293 1074.26,604.293 1074.27,604.293 1074.27,604.293 1074.28,604.293 1074.29,604.293 1074.3,604.293 1074.31,604.293 1074.32,604.293 1074.33,604.292 1074.34,604.292 1074.35,604.292 1074.36,604.292 1074.37,604.292 1074.38,604.292 1074.38,604.292 1074.39,604.292 1074.4,604.292 1074.41,604.292 1074.42,604.292 1074.43,604.292 1074.44,604.292 1074.45,604.291 1074.46,604.291 1074.47,604.291 1074.48,604.291 1074.49,604.291 1074.49,604.291 1074.5,604.291 1074.51,604.291 1074.52,604.291 1074.53,604.291 1074.54,604.291 1074.55,604.291 1074.56,604.291 1074.57,604.29 1074.58,604.29 1074.59,604.29 1074.6,604.29 1074.61,604.29 1074.61,604.29 1074.62,604.29 1074.63,604.29 1074.64,604.29 1074.65,604.29 1074.66,604.29 1074.67,604.29 1074.68,604.29 1074.69,604.289 1074.7,604.289 1074.71,604.289 1074.72,604.289 1074.72,604.289 1074.73,604.289 1074.74,604.289 1074.75,604.289 1074.76,604.289 1074.77,604.289 1074.78,604.289 1074.79,604.289 1074.8,604.289 1074.81,604.288 1074.82,604.288 1074.83,604.288 1074.83,604.288 1074.84,604.288 1074.85,604.288 1074.86,604.288 1074.87,604.288 1074.88,604.288 1074.89,604.288 1074.9,604.288 1074.91,604.288 1074.92,604.288 1074.93,604.287 1074.94,604.287 1074.95,604.287 1074.95,604.287 1074.96,604.287 1074.97,604.287 1074.98,604.287 1074.99,604.287 1075,604.287 1075.01,604.287 1075.02,604.287 1075.03,604.287 1075.04,604.287 1075.05,604.286 1075.06,604.286 1075.06,604.286 1075.07,604.286 1075.08,604.286 1075.09,604.286 1075.1,604.286 1075.11,604.286 1075.12,604.286 1075.13,604.286 1075.14,604.286 1075.15,604.286 1075.16,604.286 1075.17,604.285 1075.17,604.285 1075.18,604.285 1075.19,604.285 1075.2,604.285 1075.21,604.285 1075.22,604.285 1075.23,604.285 1075.24,604.285 1075.25,604.285 1075.26,604.285 1075.27,604.285 1075.28,604.285 1075.29,604.284 1075.29,604.284 1075.3,604.284 1075.31,604.284 1075.32,604.284 1075.33,604.284 1075.34,604.284 1075.35,604.284 1075.36,604.284 1075.37,604.284 1075.38,604.284 1075.39,604.284 1075.4,604.284 1075.4,604.283 1075.41,604.283 1075.42,604.283 1075.43,604.283 1075.44,604.283 1075.45,604.283 1075.46,604.283 1075.47,604.283 1075.48,604.283 1075.49,604.283 1075.5,604.283 1075.51,604.283 1075.51,604.283 1075.52,604.282 1075.53,604.282 1075.54,604.282 1075.55,604.282 1075.56,604.282 1075.57,604.282 1075.58,604.282 1075.59,604.282 1075.6,604.282 1075.61,604.282 1075.62,604.282 1075.63,604.282 1075.63,604.282 1075.64,604.281 1075.65,604.281 1075.66,604.281 1075.67,604.281 1075.68,604.281 1075.69,604.281 1075.7,604.281 1075.71,604.281 1075.72,604.281 1075.73,604.281 1075.74,604.281 1075.74,604.281 1075.75,604.281 1075.76,604.28 1075.77,604.28 1075.78,604.28 1075.79,604.28 1075.8,604.28 1075.81,604.28 1075.82,604.28 1075.83,604.28 1075.84,604.28 1075.85,604.28 1075.85,604.28 1075.86,604.28 1075.87,604.28 1075.88,604.279 1075.89,604.279 1075.9,604.279 1075.91,604.279 1075.92,604.279 1075.93,604.279 1075.94,604.279 1075.95,604.279 1075.96,604.279 1075.97,604.279 1075.97,604.279 1075.98,604.279 1075.99,604.279 1076,604.278 1076.01,604.278 1076.02,604.278 1076.03,604.278 1076.04,604.278 1076.05,604.278 1076.06,604.278 1076.07,604.278 1076.08,604.278 1076.08,604.278 1076.09,604.278 1076.1,604.278 1076.11,604.278 1076.12,604.277 1076.13,604.277 1076.14,604.277 1076.15,604.277 1076.16,604.277 1076.17,604.277 1076.18,604.277 1076.19,604.277 1076.19,604.277 1076.2,604.277 1076.21,604.277 1076.22,604.277 1076.23,604.277 1076.24,604.276 1076.25,604.276 1076.26,604.276 1076.27,604.276 1076.28,604.276 1076.29,604.276 1076.3,604.276 1076.31,604.276 1076.31,604.276 1076.32,604.276 1076.33,604.276 1076.34,604.276 1076.35,604.276 1076.36,604.275 1076.37,604.275 1076.38,604.275 1076.39,604.275 1076.4,604.275 1076.41,604.275 1076.42,604.275 1076.42,604.275 1076.43,604.275 1076.44,604.275 1076.45,604.275 1076.46,604.275 1076.47,604.275 1076.48,604.274 1076.49,604.274 1076.5,604.274 1076.51,604.274 1076.52,604.274 1076.53,604.274 1076.53,604.274 1076.54,604.274 1076.55,604.274 1076.56,604.274 1076.57,604.274 1076.58,604.274 1076.59,604.274 1076.6,604.273 1076.61,604.273 1076.62,604.273 1076.63,604.273 1076.64,604.273 1076.65,604.273 1076.65,604.273 1076.66,604.273 1076.67,604.273 1076.68,604.273 1076.69,604.273 1076.7,604.273 1076.71,604.273 1076.72,604.272 1076.73,604.272 1076.74,604.272 1076.75,604.272 1076.76,604.272 1076.76,604.272 1076.77,604.272 1076.78,604.272 1076.79,604.272 1076.8,604.272 1076.81,604.272 1076.82,604.272 1076.83,604.272 1076.84,604.271 1076.85,604.271 1076.86,604.271 1076.87,604.271 1076.87,604.271 1076.88,604.271 1076.89,604.271 1076.9,604.271 1076.91,604.271 1076.92,604.271 1076.93,604.271 1076.94,604.271 1076.95,604.271 1076.96,604.27 1076.97,604.27 1076.98,604.27 1076.99,604.27 1076.99,604.27 1077,604.27 1077.01,604.27 1077.02,604.27 1077.03,604.27 1077.04,604.27 1077.05,604.27 1077.06,604.27 1077.07,604.27 1077.08,604.269 1077.09,604.269 1077.1,604.269 1077.1,604.269 1077.11,604.269 1077.12,604.269 1077.13,604.269 1077.14,604.269 1077.15,604.269 1077.16,604.269 1077.17,604.269 1077.18,604.269 1077.19,604.269 1077.2,604.268 1077.21,604.268 1077.21,604.268 1077.22,604.268 1077.23,604.268 1077.24,604.268 1077.25,604.268 1077.26,604.268 1077.27,604.268 1077.28,604.268 1077.29,604.268 1077.3,604.268 1077.31,604.268 1077.32,604.268 1077.33,604.267 1077.33,604.267 1077.34,604.267 1077.35,604.267 1077.36,604.267 1077.37,604.267 1077.38,604.267 1077.39,604.267 1077.4,604.267 1077.41,604.267 1077.42,604.267 1077.43,604.267 1077.44,604.267 1077.44,604.266 1077.45,604.266 1077.46,604.266 1077.47,604.266 1077.48,604.266 1077.49,604.266 1077.5,604.266 1077.51,604.266 1077.52,604.266 1077.53,604.266 1077.54,604.266 1077.55,604.266 1077.55,604.266 1077.56,604.265 1077.57,604.265 1077.58,604.265 1077.59,604.265 1077.6,604.265 1077.61,604.265 1077.62,604.265 1077.63,604.265 1077.64,604.265 1077.65,604.265 1077.66,604.265 1077.67,604.265 1077.67,604.265 1077.68,604.264 1077.69,604.264 1077.7,604.264 1077.71,604.264 1077.72,604.264 1077.73,604.264 1077.74,604.264 1077.75,604.264 1077.76,604.264 1077.77,604.264 1077.78,604.264 1077.78,604.264 1077.79,604.264 1077.8,604.263 1077.81,604.263 1077.82,604.263 1077.83,604.263 1077.84,604.263 1077.85,604.263 1077.86,604.263 1077.87,604.263 1077.88,604.263 1077.89,604.263 1077.89,604.263 1077.9,604.263 1077.91,604.263 1077.92,604.262 1077.93,604.262 1077.94,604.262 1077.95,604.262 1077.96,604.262 1077.97,604.262 1077.98,604.262 1077.99,604.262 1078,604.262 1078.01,604.262 1078.01,604.262 1078.02,604.262 1078.03,604.262 1078.04,604.261 1078.05,604.261 1078.06,604.261 1078.07,604.261 1078.08,604.261 1078.09,604.261 1078.1,604.261 1078.11,604.261 1078.12,604.261 1078.12,604.261 1078.13,604.261 1078.14,604.261 1078.15,604.261 1078.16,604.26 1078.17,604.26 1078.18,604.26 1078.19,604.26 1078.2,604.26 1078.21,604.26 1078.22,604.26 1078.23,604.26 1078.23,604.26 1078.24,604.26 1078.25,604.26 1078.26,604.26 1078.27,604.26 1078.28,604.259 1078.29,604.259 1078.3,604.259 1078.31,604.259 1078.32,604.259 1078.33,604.259 1078.34,604.259 1078.35,604.259 1078.35,604.259 1078.36,604.259 1078.37,604.259 1078.38,604.259 1078.39,604.259 1078.4,604.258 1078.41,604.258 1078.42,604.258 1078.43,604.258 1078.44,604.258 1078.45,604.258 1078.46,604.258 1078.46,604.258 1078.47,604.258 1078.48,604.258 1078.49,604.258 1078.5,604.258 1078.51,604.258 1078.52,604.257 1078.53,604.257 1078.54,604.257 1078.55,604.257 1078.56,604.257 1078.57,604.257 1078.57,604.257 1078.58,604.257 1078.59,604.257 1078.6,604.257 1078.61,604.257 1078.62,604.257 1078.63,604.257 1078.64,604.257 1078.65,604.256 1078.66,604.256 1078.67,604.256 1078.68,604.256 1078.69,604.256 1078.69,604.256 1078.7,604.256 1078.71,604.256 1078.72,604.256 1078.73,604.256 1078.74,604.256 1078.75,604.256 1078.76,604.256 1078.77,604.255 1078.78,604.255 1078.79,604.255 1078.8,604.255 1078.8,604.255 1078.81,604.255 1078.82,604.255 1078.83,604.255 1078.84,604.255 1078.85,604.255 1078.86,604.255 1078.87,604.255 1078.88,604.255 1078.89,604.254 1078.9,604.254 1078.91,604.254 1078.91,604.254 1078.92,604.254 1078.93,604.254 1078.94,604.254 1078.95,604.254 1078.96,604.254 1078.97,604.254 1078.98,604.254 1078.99,604.254 1079,604.254 1079.01,604.253 1079.02,604.253 1079.03,604.253 1079.03,604.253 1079.04,604.253 1079.05,604.253 1079.06,604.253 1079.07,604.253 1079.08,604.253 1079.09,604.253 1079.1,604.253 1079.11,604.253 1079.12,604.253 1079.13,604.252 1079.14,604.252 1079.14,604.252 1079.15,604.252 1079.16,604.252 1079.17,604.252 1079.18,604.252 1079.19,604.252 1079.2,604.252 1079.21,604.252 1079.22,604.252 1079.23,604.252 1079.24,604.252 1079.25,604.251 1079.25,604.251 1079.26,604.251 1079.27,604.251 1079.28,604.251 1079.29,604.251 1079.3,604.251 1079.31,604.251 1079.32,604.251 1079.33,604.251 1079.34,604.251 1079.35,604.251 1079.36,604.251 1079.37,604.25 1079.37,604.25 1079.38,604.25 1079.39,604.25 1079.4,604.25 1079.41,604.25 1079.42,604.25 1079.43,604.25 1079.44,604.25 1079.45,604.25 1079.46,604.25 1079.47,604.25 1079.48,604.25 1079.48,604.249 1079.49,604.249 1079.5,604.249 1079.51,604.249 1079.52,604.249 1079.53,604.249 1079.54,604.249 1079.55,604.249 1079.56,604.249 1079.57,604.249 1079.58,604.249 1079.59,604.249 1079.59,604.249 1079.6,604.249 1079.61,604.248 1079.62,604.248 1079.63,604.248 1079.64,604.248 1079.65,604.248 1079.66,604.248 1079.67,604.248 1079.68,604.248 1079.69,604.248 1079.7,604.248 1079.71,604.248 1079.71,604.248 1079.72,604.248 1079.73,604.247 1079.74,604.247 1079.75,604.247 1079.76,604.247 1079.77,604.247 1079.78,604.247 1079.79,604.247 1079.8,604.247 1079.81,604.247 1079.82,604.247 1079.82,604.247 1079.83,604.247 1079.84,604.247 1079.85,604.246 1079.86,604.246 1079.87,604.246 1079.88,604.246 1079.89,604.246 1079.9,604.246 1079.91,604.246 1079.92,604.246 1079.93,604.246 1079.93,604.246 1079.94,604.246 1079.95,604.246 1079.96,604.246 1079.97,604.245 1079.98,604.245 1079.99,604.245 1080,604.245 1080.01,604.245 1080.02,604.245 1080.03,604.245 1080.04,604.245 1080.05,604.245 1080.05,604.245 1080.06,604.245 1080.07,604.245 1080.08,604.245 1080.09,604.244 1080.1,604.244 1080.11,604.244 1080.12,604.244 1080.13,604.244 1080.14,604.244 1080.15,604.244 1080.16,604.244 1080.16,604.244 1080.17,604.244 1080.18,604.244 1080.19,604.244 1080.2,604.244 1080.21,604.243 1080.22,604.243 1080.23,604.243 1080.24,604.243 1080.25,604.243 1080.26,604.243 1080.27,604.243 1080.27,604.243 1080.28,604.243 1080.29,604.243 1080.3,604.243 1080.31,604.243 1080.32,604.243 1080.33,604.242 1080.34,604.242 1080.35,604.242 1080.36,604.242 1080.37,604.242 1080.38,604.242 1080.39,604.242 1080.39,604.242 1080.4,604.242 1080.41,604.242 1080.42,604.242 1080.43,604.242 1080.44,604.242 1080.45,604.242 1080.46,604.241 1080.47,604.241 1080.48,604.241 1080.49,604.241 1080.5,604.241 1080.5,604.241 1080.51,604.241 1080.52,604.241 1080.53,604.241 1080.54,604.241 1080.55,604.241 1080.56,604.241 1080.57,604.241 1080.58,604.24 1080.59,604.24 1080.6,604.24 1080.61,604.24 1080.61,604.24 1080.62,604.24 1080.63,604.24 1080.64,604.24 1080.65,604.24 1080.66,604.24 1080.67,604.24 1080.68,604.24 1080.69,604.24 1080.7,604.239 1080.71,604.239 1080.72,604.239 1080.73,604.239 1080.73,604.239 1080.74,604.239 1080.75,604.239 1080.76,604.239 1080.77,604.239 1080.78,604.239 1080.79,604.239 1080.8,604.239 1080.81,604.239 1080.82,604.238 1080.83,604.238 1080.84,604.238 1080.84,604.238 1080.85,604.238 1080.86,604.238 1080.87,604.238 1080.88,604.238 1080.89,604.238 1080.9,604.238 1080.91,604.238 1080.92,604.238 1080.93,604.238 1080.94,604.237 1080.95,604.237 1080.95,604.237 1080.96,604.237 1080.97,604.237 1080.98,604.237 1080.99,604.237 1081,604.237 1081.01,604.237 1081.02,604.237 1081.03,604.237 1081.04,604.237 1081.05,604.237 1081.06,604.237 1081.07,604.236 1081.07,604.236 1081.08,604.236 1081.09,604.236 1081.1,604.236 1081.11,604.236 1081.12,604.236 1081.13,604.236 1081.14,604.236 1081.15,604.236 1081.16,604.236 1081.17,604.236 1081.18,604.236 1081.18,604.235 1081.19,604.235 1081.2,604.235 1081.21,604.235 1081.22,604.235 1081.23,604.235 1081.24,604.235 1081.25,604.235 1081.26,604.235 1081.27,604.235 1081.28,604.235 1081.29,604.235 1081.29,604.235 1081.3,604.234 1081.31,604.234 1081.32,604.234 1081.33,604.234 1081.34,604.234 1081.35,604.234 1081.36,604.234 1081.37,604.234 1081.38,604.234 1081.39,604.234 1081.4,604.234 1081.41,604.234 1081.41,604.234 1081.42,604.233 1081.43,604.233 1081.44,604.233 1081.45,604.233 1081.46,604.233 1081.47,604.233 1081.48,604.233 1081.49,604.233 1081.5,604.233 1081.51,604.233 1081.52,604.233 1081.52,604.233 1081.53,604.233 1081.54,604.232 1081.55,604.232 1081.56,604.232 1081.57,604.232 1081.58,604.232 1081.59,604.232 1081.6,604.232 1081.61,604.232 1081.62,604.232 1081.63,604.232 1081.63,604.232 1081.64,604.232 1081.65,604.232 1081.66,604.232 1081.67,604.231 1081.68,604.231 1081.69,604.231 1081.7,604.231 1081.71,604.231 1081.72,604.231 1081.73,604.231 1081.74,604.231 1081.75,604.231 1081.75,604.231 1081.76,604.231 1081.77,604.231 1081.78,604.231 1081.79,604.23 1081.8,604.23 1081.81,604.23 1081.82,604.23 1081.83,604.23 1081.84,604.23 1081.85,604.23 1081.86,604.23 1081.86,604.23 1081.87,604.23 1081.88,604.23 1081.89,604.23 1081.9,604.23 1081.91,604.229 1081.92,604.229 1081.93,604.229 1081.94,604.229 1081.95,604.229 1081.96,604.229 1081.97,604.229 1081.97,604.229 1081.98,604.229 1081.99,604.229 1082,604.229 1082.01,604.229 1082.02,604.229 1082.03,604.228 1082.04,604.228 1082.05,604.228 1082.06,604.228 1082.07,604.228 1082.08,604.228 1082.09,604.228 1082.09,604.228 1082.1,604.228 1082.11,604.228 1082.12,604.228 1082.13,604.228 1082.14,604.228 1082.15,604.227 1082.16,604.227 1082.17,604.227 1082.18,604.227 1082.19,604.227 1082.2,604.227 1082.2,604.227 1082.21,604.227 1082.22,604.227 1082.23,604.227 1082.24,604.227 1082.25,604.227 1082.26,604.227 1082.27,604.227 1082.28,604.226 1082.29,604.226 1082.3,604.226 1082.31,604.226 1082.31,604.226 1082.32,604.226 1082.33,604.226 1082.34,604.226 1082.35,604.226 1082.36,604.226 1082.37,604.226 1082.38,604.226 1082.39,604.226 1082.4,604.225 1082.41,604.225 1082.42,604.225 1082.43,604.225 1082.43,604.225 1082.44,604.225 1082.45,604.225 1082.46,604.225 1082.47,604.225 1082.48,604.225 1082.49,604.225 1082.5,604.225 1082.51,604.225 1082.52,604.224 1082.53,604.224 1082.54,604.224 1082.54,604.224 1082.55,604.224 1082.56,604.224 1082.57,604.224 1082.58,604.224 1082.59,604.224 1082.6,604.224 1082.61,604.224 1082.62,604.224 1082.63,604.224 1082.64,604.223 1082.65,604.223 1082.65,604.223 1082.66,604.223 1082.67,604.223 1082.68,604.223 1082.69,604.223 1082.7,604.223 1082.71,604.223 1082.72,604.223 1082.73,604.223 1082.74,604.223 1082.75,604.223 1082.76,604.223 1082.77,604.222 1082.77,604.222 1082.78,604.222 1082.79,604.222 1082.8,604.222 1082.81,604.222 1082.82,604.222 1082.83,604.222 1082.84,604.222 1082.85,604.222 1082.86,604.222 1082.87,604.222 1082.88,604.222 1082.88,604.221 1082.89,604.221 1082.9,604.221 1082.91,604.221 1082.92,604.221 1082.93,604.221 1082.94,604.221 1082.95,604.221 1082.96,604.221 1082.97,604.221 1082.98,604.221 1082.99,604.221 1082.99,604.221 1083,604.22 1083.01,604.22 1083.02,604.22 1083.03,604.22 1083.04,604.22 1083.05,604.22 1083.06,604.22 1083.07,604.22 1083.08,604.22 1083.09,604.22 1083.1,604.22 1083.11,604.22 1083.11,604.22 1083.12,604.219 1083.13,604.219 1083.14,604.219 1083.15,604.219 1083.16,604.219 1083.17,604.219 1083.18,604.219 1083.19,604.219 1083.2,604.219 1083.21,604.219 1083.22,604.219 1083.22,604.219 1083.23,604.219 1083.24,604.219 1083.25,604.218 1083.26,604.218 1083.27,604.218 1083.28,604.218 1083.29,604.218 1083.3,604.218 1083.31,604.218 1083.32,604.218 1083.33,604.218 1083.33,604.218 1083.34,604.218 1083.35,604.218 1083.36,604.218 1083.37,604.217 1083.38,604.217 1083.39,604.217 1083.4,604.217 1083.41,604.217 1083.42,604.217 1083.43,604.217 1083.44,604.217 1083.45,604.217 1083.45,604.217 1083.46,604.217 1083.47,604.217 1083.48,604.217 1083.49,604.216 1083.5,604.216 1083.51,604.216 1083.52,604.216 1083.53,604.216 1083.54,604.216 1083.55,604.216 1083.56,604.216 1083.56,604.216 1083.57,604.216 1083.58,604.216 1083.59,604.216 1083.6,604.216 1083.61,604.215 1083.62,604.215 1083.63,604.215 1083.64,604.215 1083.65,604.215 1083.66,604.215 1083.67,604.215 1083.67,604.215 1083.68,604.215 1083.69,604.215 1083.7,604.215 1083.71,604.215 1083.72,604.215 1083.73,604.215 1083.74,604.214 1083.75,604.214 1083.76,604.214 1083.77,604.214 1083.78,604.214 1083.79,604.214 1083.79,604.214 1083.8,604.214 1083.81,604.214 1083.82,604.214 1083.83,604.214 1083.84,604.214 1083.85,604.214 1083.86,604.213 1083.87,604.213 1083.88,604.213 1083.89,604.213 1083.9,604.213 1083.9,604.213 1083.91,604.213 1083.92,604.213 1083.93,604.213 1083.94,604.213 1083.95,604.213 1083.96,604.213 1083.97,604.213 1083.98,604.212 1083.99,604.212 1084,604.212 1084.01,604.212 1084.01,604.212 1084.02,604.212 1084.03,604.212 1084.04,604.212 1084.05,604.212 1084.06,604.212 1084.07,604.212 1084.08,604.212 1084.09,604.212 1084.1,604.212 1084.11,604.211 1084.12,604.211 1084.13,604.211 1084.13,604.211 1084.14,604.211 1084.15,604.211 1084.16,604.211 1084.17,604.211 1084.18,604.211 1084.19,604.211 1084.2,604.211 1084.21,604.211 1084.22,604.211 1084.23,604.21 1084.24,604.21 1084.24,604.21 1084.25,604.21 1084.26,604.21 1084.27,604.21 1084.28,604.21 1084.29,604.21 1084.3,604.21 1084.31,604.21 1084.32,604.21 1084.33,604.21 1084.34,604.21 1084.35,604.209 1084.35,604.209 1084.36,604.209 1084.37,604.209 1084.38,604.209 1084.39,604.209 1084.4,604.209 1084.41,604.209 1084.42,604.209 1084.43,604.209 1084.44,604.209 1084.45,604.209 1084.46,604.209 1084.47,604.208 1084.47,604.208 1084.48,604.208 1084.49,604.208 1084.5,604.208 1084.51,604.208 1084.52,604.208 1084.53,604.208 1084.54,604.208 1084.55,604.208 1084.56,604.208 1084.57,604.208 1084.58,604.208 1084.58,604.208 1084.59,604.207 1084.6,604.207 1084.61,604.207 1084.62,604.207 1084.63,604.207 1084.64,604.207 1084.65,604.207 1084.66,604.207 1084.67,604.207 1084.68,604.207 1084.69,604.207 1084.69,604.207 1084.7,604.207 1084.71,604.206 1084.72,604.206 1084.73,604.206 1084.74,604.206 1084.75,604.206 1084.76,604.206 1084.77,604.206 1084.78,604.206 1084.79,604.206 1084.8,604.206 1084.81,604.206 1084.81,604.206 1084.82,604.206 1084.83,604.205 1084.84,604.205 1084.85,604.205 1084.86,604.205 1084.87,604.205 1084.88,604.205 1084.89,604.205 1084.9,604.205 1084.91,604.205 1084.92,604.205 1084.92,604.205 1084.93,604.205 1084.94,604.205 1084.95,604.205 1084.96,604.204 1084.97,604.204 1084.98,604.204 1084.99,604.204 1085,604.204 1085.01,604.204 1085.02,604.204 1085.03,604.204 1085.03,604.204 1085.04,604.204 1085.05,604.204 1085.06,604.204 1085.07,604.204 1085.08,604.203 1085.09,604.203 1085.1,604.203 1085.11,604.203 1085.12,604.203 1085.13,604.203 1085.14,604.203 1085.15,604.203 1085.15,604.203 1085.16,604.203 1085.17,604.203 1085.18,604.203 1085.19,604.203 1085.2,604.202 1085.21,604.202 1085.22,604.202 1085.23,604.202 1085.24,604.202 1085.25,604.202 1085.26,604.202 1085.26,604.202 1085.27,604.202 1085.28,604.202 1085.29,604.202 1085.3,604.202 1085.31,604.202 1085.32,604.202 1085.33,604.201 1085.34,604.201 1085.35,604.201 1085.36,604.201 1085.37,604.201 1085.37,604.201 1085.38,604.201 1085.39,604.201 1085.4,604.201 1085.41,604.201 1085.42,604.201 1085.43,604.201 1085.44,604.201 1085.45,604.2 1085.46,604.2 1085.47,604.2 1085.48,604.2 1085.49,604.2 1085.49,604.2 1085.5,604.2 1085.51,604.2 1085.52,604.2 1085.53,604.2 1085.54,604.2 1085.55,604.2 1085.56,604.2 1085.57,604.199 1085.58,604.199 1085.59,604.199 1085.6,604.199 1085.6,604.199 1085.61,604.199 1085.62,604.199 1085.63,604.199 1085.64,604.199 1085.65,604.199 1085.66,604.199 1085.67,604.199 1085.68,604.199 1085.69,604.199 1085.7,604.198 1085.71,604.198 1085.71,604.198 1085.72,604.198 1085.73,604.198 1085.74,604.198 1085.75,604.198 1085.76,604.198 1085.77,604.198 1085.78,604.198 1085.79,604.198 1085.8,604.198 1085.81,604.198 1085.82,604.197 1085.83,604.197 1085.83,604.197 1085.84,604.197 1085.85,604.197 1085.86,604.197 1085.87,604.197 1085.88,604.197 1085.89,604.197 1085.9,604.197 1085.91,604.197 1085.92,604.197 1085.93,604.197 1085.94,604.196 1085.94,604.196 1085.95,604.196 1085.96,604.196 1085.97,604.196 1085.98,604.196 1085.99,604.196 1086,604.196 1086.01,604.196 1086.02,604.196 1086.03,604.196 1086.04,604.196 1086.05,604.196 1086.05,604.196 1086.06,604.195 1086.07,604.195 1086.08,604.195 1086.09,604.195 1086.1,604.195 1086.11,604.195 1086.12,604.195 1086.13,604.195 1086.14,604.195 1086.15,604.195 1086.16,604.195 1086.17,604.195 1086.17,604.195 1086.18,604.194 1086.19,604.194 1086.2,604.194 1086.21,604.194 1086.22,604.194 1086.23,604.194 1086.24,604.194 1086.25,604.194 1086.26,604.194 1086.27,604.194 1086.28,604.194 1086.28,604.194 1086.29,604.194 1086.3,604.193 1086.31,604.193 1086.32,604.193 1086.33,604.193 1086.34,604.193 1086.35,604.193 1086.36,604.193 1086.37,604.193 1086.38,604.193 1086.39,604.193 1086.39,604.193 1086.4,604.193 1086.41,604.193 1086.42,604.193 1086.43,604.192 1086.44,604.192 1086.45,604.192 1086.46,604.192 1086.47,604.192 1086.48,604.192 1086.49,604.192 1086.5,604.192 1086.51,604.192 1086.51,604.192 1086.52,604.192 1086.53,604.192 1086.54,604.192 1086.55,604.191 1086.56,604.191 1086.57,604.191 1086.58,604.191 1086.59,604.191 1086.6,604.191 1086.61,604.191 1086.62,604.191 1086.62,604.191 1086.63,604.191 1086.64,604.191 1086.65,604.191 1086.66,604.191 1086.67,604.191 1086.68,604.19 1086.69,604.19 1086.7,604.19 1086.71,604.19 1086.72,604.19 1086.73,604.19 1086.73,604.19 1086.74,604.19 1086.75,604.19 1086.76,604.19 1086.77,604.19 1086.78,604.19 1086.79,604.19 1086.8,604.189 1086.81,604.189 1086.82,604.189 1086.83,604.189 1086.84,604.189 1086.85,604.189 1086.85,604.189 1086.86,604.189 1086.87,604.189 1086.88,604.189 1086.89,604.189 1086.9,604.189 1086.91,604.189 1086.92,604.188 1086.93,604.188 1086.94,604.188 1086.95,604.188 1086.96,604.188 1086.96,604.188 1086.97,604.188 1086.98,604.188 1086.99,604.188 1087,604.188 1087.01,604.188 1087.02,604.188 1087.03,604.188 1087.04,604.188 1087.05,604.187 1087.06,604.187 1087.07,604.187 1087.07,604.187 1087.08,604.187 1087.09,604.187 1087.1,604.187 1087.11,604.187 1087.12,604.187 1087.13,604.187 1087.14,604.187 1087.15,604.187 1087.16,604.187 1087.17,604.186 1087.18,604.186 1087.19,604.186 1087.19,604.186 1087.2,604.186 1087.21,604.186 1087.22,604.186 1087.23,604.186 1087.24,604.186 1087.25,604.186 1087.26,604.186 1087.27,604.186 1087.28,604.186 1087.29,604.186 1087.3,604.185 1087.3,604.185 1087.31,604.185 1087.32,604.185 1087.33,604.185 1087.34,604.185 1087.35,604.185 1087.36,604.185 1087.37,604.185 1087.38,604.185 1087.39,604.185 1087.4,604.185 1087.41,604.185 1087.41,604.184 1087.42,604.184 1087.43,604.184 1087.44,604.184 1087.45,604.184 1087.46,604.184 1087.47,604.184 1087.48,604.184 1087.49,604.184 1087.5,604.184 1087.51,604.184 1087.52,604.184 1087.53,604.184 1087.53,604.183 1087.54,604.183 1087.55,604.183 1087.56,604.183 1087.57,604.183 1087.58,604.183 1087.59,604.183 1087.6,604.183 1087.61,604.183 1087.62,604.183 1087.63,604.183 1087.64,604.183 1087.64,604.183 1087.65,604.183 1087.66,604.182 1087.67,604.182 1087.68,604.182 1087.69,604.182 1087.7,604.182 1087.71,604.182 1087.72,604.182 1087.73,604.182 1087.74,604.182 1087.75,604.182 1087.75,604.182 1087.76,604.182 1087.77,604.182 1087.78,604.181 1087.79,604.181 1087.8,604.181 1087.81,604.181 1087.82,604.181 1087.83,604.181 1087.84,604.181 1087.85,604.181 1087.86,604.181 1087.87,604.181 1087.87,604.181 1087.88,604.181 1087.89,604.181 1087.9,604.181 1087.91,604.18 1087.92,604.18 1087.93,604.18 1087.94,604.18 1087.95,604.18 1087.96,604.18 1087.97,604.18 1087.98,604.18 1087.98,604.18 1087.99,604.18 1088,604.18 1088.01,604.18 1088.02,604.18 1088.03,604.179 1088.04,604.179 1088.05,604.179 1088.06,604.179 1088.07,604.179 1088.08,604.179 1088.09,604.179 1088.09,604.179 1088.1,604.179 1088.11,604.179 1088.12,604.179 1088.13,604.179 1088.14,604.179 1088.15,604.178 1088.16,604.178 1088.17,604.178 1088.18,604.178 1088.19,604.178 1088.2,604.178 1088.21,604.178 1088.21,604.178 1088.22,604.178 1088.23,604.178 1088.24,604.178 1088.25,604.178 1088.26,604.178 1088.27,604.178 1088.28,604.177 1088.29,604.177 1088.3,604.177 1088.31,604.177 1088.32,604.177 1088.32,604.177 1088.33,604.177 1088.34,604.177 1088.35,604.177 1088.36,604.177 1088.37,604.177 1088.38,604.177 1088.39,604.177 1088.4,604.176 1088.41,604.176 1088.42,604.176 1088.43,604.176 1088.43,604.176 1088.44,604.176 1088.45,604.176 1088.46,604.176 1088.47,604.176 1088.48,604.176 1088.49,604.176 1088.5,604.176 1088.51,604.176 1088.52,604.176 1088.53,604.175 1088.54,604.175 1088.55,604.175 1088.55,604.175 1088.56,604.175 1088.57,604.175 1088.58,604.175 1088.59,604.175 1088.6,604.175 1088.61,604.175 1088.62,604.175 1088.63,604.175 1088.64,604.175 1088.65,604.174 1088.66,604.174 1088.66,604.174 1088.67,604.174 1088.68,604.174 1088.69,604.174 1088.7,604.174 1088.71,604.174 1088.72,604.174 1088.73,604.174 1088.74,604.174 1088.75,604.174 1088.76,604.174 1088.77,604.174 1088.77,604.173 1088.78,604.173 1088.79,604.173 1088.8,604.173 1088.81,604.173 1088.82,604.173 1088.83,604.173 1088.84,604.173 1088.85,604.173 1088.86,604.173 1088.87,604.173 1088.88,604.173 1088.89,604.173 1088.89,604.172 1088.9,604.172 1088.91,604.172 1088.92,604.172 1088.93,604.172 1088.94,604.172 1088.95,604.172 1088.96,604.172 1088.97,604.172 1088.98,604.172 1088.99,604.172 1089,604.172 1089,604.172 1089.01,604.171 1089.02,604.171 1089.03,604.171 1089.04,604.171 1089.05,604.171 1089.06,604.171 1089.07,604.171 1089.08,604.171 1089.09,604.171 1089.1,604.171 1089.11,604.171 1089.11,604.171 1089.12,604.171 1089.13,604.171 1089.14,604.17 1089.15,604.17 1089.16,604.17 1089.17,604.17 1089.18,604.17 1089.19,604.17 1089.2,604.17 1089.21,604.17 1089.22,604.17 1089.23,604.17 1089.23,604.17 1089.24,604.17 1089.25,604.17 1089.26,604.169 1089.27,604.169 1089.28,604.169 1089.29,604.169 1089.3,604.169 1089.31,604.169 1089.32,604.169 1089.33,604.169 1089.34,604.169 1089.34,604.169 1089.35,604.169 1089.36,604.169 1089.37,604.169 1089.38,604.169 1089.39,604.168 1089.4,604.168 1089.41,604.168 1089.42,604.168 1089.43,604.168 1089.44,604.168 1089.45,604.168 1089.45,604.168 1089.46,604.168 1089.47,604.168 1089.48,604.168 1089.49,604.168 1089.5,604.168 1089.51,604.167 1089.52,604.167 1089.53,604.167 1089.54,604.167 1089.55,604.167 1089.56,604.167 1089.57,604.167 1089.57,604.167 1089.58,604.167 1089.59,604.167 1089.6,604.167 1089.61,604.167 1089.62,604.167 1089.63,604.167 1089.64,604.166 1089.65,604.166 1089.66,604.166 1089.67,604.166 1089.68,604.166 1089.68,604.166 1089.69,604.166 1089.7,604.166 1089.71,604.166 1089.72,604.166 1089.73,604.166 1089.74,604.166 1089.75,604.166 1089.76,604.165 1089.77,604.165 1089.78,604.165 1089.79,604.165 1089.79,604.165 1089.8,604.165 1089.81,604.165 1089.82,604.165 1089.83,604.165 1089.84,604.165 1089.85,604.165 1089.86,604.165 1089.87,604.165 1089.88,604.165 1089.89,604.164 1089.9,604.164 1089.91,604.164 1089.91,604.164 1089.92,604.164 1089.93,604.164 1089.94,604.164 1089.95,604.164 1089.96,604.164 1089.97,604.164 1089.98,604.164 1089.99,604.164 1090,604.164 1090.01,604.163 1090.02,604.163 1090.02,604.163 1090.03,604.163 1090.04,604.163 1090.05,604.163 1090.06,604.163 1090.07,604.163 1090.08,604.163 1090.09,604.163 1090.1,604.163 1090.11,604.163 1090.12,604.163 1090.13,604.163 1090.13,604.162 1090.14,604.162 1090.15,604.162 1090.16,604.162 1090.17,604.162 1090.18,604.162 1090.19,604.162 1090.2,604.162 1090.21,604.162 1090.22,604.162 1090.23,604.162 1090.24,604.162 1090.25,604.162 1090.25,604.161 1090.26,604.161 1090.27,604.161 1090.28,604.161 1090.29,604.161 1090.3,604.161 1090.31,604.161 1090.32,604.161 1090.33,604.161 1090.34,604.161 1090.35,604.161 1090.36,604.161 1090.36,604.161 1090.37,604.161 1090.38,604.16 1090.39,604.16 1090.4,604.16 1090.41,604.16 1090.42,604.16 1090.43,604.16 1090.44,604.16 1090.45,604.16 1090.46,604.16 1090.47,604.16 1090.47,604.16 1090.48,604.16 1090.49,604.16 1090.5,604.159 1090.51,604.159 1090.52,604.159 1090.53,604.159 1090.54,604.159 1090.55,604.159 1090.56,604.159 1090.57,604.159 1090.58,604.159 1090.59,604.159 1090.59,604.159 1090.6,604.159 1090.61,604.159 1090.62,604.159 1090.63,604.158 1090.64,604.158 1090.65,604.158 1090.66,604.158 1090.67,604.158 1090.68,604.158 1090.69,604.158 1090.7,604.158 1090.7,604.158 1090.71,604.158 1090.72,604.158 1090.73,604.158 1090.74,604.158 1090.75,604.157 1090.76,604.157 1090.77,604.157 1090.78,604.157 1090.79,604.157 1090.8,604.157 1090.81,604.157 1090.81,604.157 1090.82,604.157 1090.83,604.157 1090.84,604.157 1090.85,604.157 1090.86,604.157 1090.87,604.157 1090.88,604.156 1090.89,604.156 1090.9,604.156 1090.91,604.156 1090.92,604.156 1090.93,604.156 1090.93,604.156 1090.94,604.156 1090.95,604.156 1090.96,604.156 1090.97,604.156 1090.98,604.156 1090.99,604.156 1091,604.155 1091.01,604.155 1091.02,604.155 1091.03,604.155 1091.04,604.155 1091.04,604.155 1091.05,604.155 1091.06,604.155 1091.07,604.155 1091.08,604.155 1091.09,604.155 1091.1,604.155 1091.11,604.155 1091.12,604.155 1091.13,604.154 1091.14,604.154 1091.15,604.154 1091.15,604.154 1091.16,604.154 1091.17,604.154 1091.18,604.154 1091.19,604.154 1091.2,604.154 1091.21,604.154 1091.22,604.154 1091.23,604.154 1091.24,604.154 1091.25,604.153 1091.26,604.153 1091.27,604.153 1091.27,604.153 1091.28,604.153 1091.29,604.153 1091.3,604.153 1091.31,604.153 1091.32,604.153 1091.33,604.153 1091.34,604.153 1091.35,604.153 1091.36,604.153 1091.37,604.153 1091.38,604.152 1091.38,604.152 1091.39,604.152 1091.4,604.152 1091.41,604.152 1091.42,604.152 1091.43,604.152 1091.44,604.152 1091.45,604.152 1091.46,604.152 1091.47,604.152 1091.48,604.152 1091.49,604.152 1091.49,604.151 1091.5,604.151 1091.51,604.151 1091.52,604.151 1091.53,604.151 1091.54,604.151 1091.55,604.151 1091.56,604.151 1091.57,604.151 1091.58,604.151 1091.59,604.151 1091.6,604.151 1091.61,604.151 1091.61,604.151 1091.62,604.15 1091.63,604.15 1091.64,604.15 1091.65,604.15 1091.66,604.15 1091.67,604.15 1091.68,604.15 1091.69,604.15 1091.7,604.15 1091.71,604.15 1091.72,604.15 1091.72,604.15 1091.73,604.15 1091.74,604.149 1091.75,604.149 1091.76,604.149 1091.77,604.149 1091.78,604.149 1091.79,604.149 1091.8,604.149 1091.81,604.149 1091.82,604.149 1091.83,604.149 1091.83,604.149 1091.84,604.149 1091.85,604.149 1091.86,604.149 1091.87,604.148 1091.88,604.148 1091.89,604.148 1091.9,604.148 1091.91,604.148 1091.92,604.148 1091.93,604.148 1091.94,604.148 1091.95,604.148 1091.95,604.148 1091.96,604.148 1091.97,604.148 1091.98,604.148 1091.99,604.147 1092,604.147 1092.01,604.147 1092.02,604.147 1092.03,604.147 1092.04,604.147 1092.05,604.147 1092.06,604.147 1092.06,604.147 1092.07,604.147 1092.08,604.147 1092.09,604.147 1092.1,604.147 1092.11,604.147 1092.12,604.146 1092.13,604.146 1092.14,604.146 1092.15,604.146 1092.16,604.146 1092.17,604.146 1092.17,604.146 1092.18,604.146 1092.19,604.146 1092.2,604.146 1092.21,604.146 1092.22,604.146 1092.23,604.146 1092.24,604.145 1092.25,604.145 1092.26,604.145 1092.27,604.145 1092.28,604.145 1092.29,604.145 1092.29,604.145 1092.3,604.145 1092.31,604.145 1092.32,604.145 1092.33,604.145 1092.34,604.145 1092.35,604.145 1092.36,604.145 1092.37,604.144 1092.38,604.144 1092.39,604.144 1092.4,604.144 1092.4,604.144 1092.41,604.144 1092.42,604.144 1092.43,604.144 1092.44,604.144 1092.45,604.144 1092.46,604.144 1092.47,604.144 1092.48,604.144 1092.49,604.143 1092.5,604.143 1092.51,604.143 1092.51,604.143 1092.52,604.143 1092.53,604.143 1092.54,604.143 1092.55,604.143 1092.56,604.143 1092.57,604.143 1092.58,604.143 1092.59,604.143 1092.6,604.143 1092.61,604.143 1092.62,604.142 1092.63,604.142 1092.63,604.142 1092.64,604.142 1092.65,604.142 1092.66,604.142 1092.67,604.142 1092.68,604.142 1092.69,604.142 1092.7,604.142 1092.71,604.142 1092.72,604.142 1092.73,604.142 1092.74,604.142 1092.74,604.141 1092.75,604.141 1092.76,604.141 1092.77,604.141 1092.78,604.141 1092.79,604.141 1092.8,604.141 1092.81,604.141 1092.82,604.141 1092.83,604.141 1092.84,604.141 1092.85,604.141 1092.85,604.141 1092.86,604.14 1092.87,604.14 1092.88,604.14 1092.89,604.14 1092.9,604.14 1092.91,604.14 1092.92,604.14 1092.93,604.14 1092.94,604.14 1092.95,604.14 1092.96,604.14 1092.97,604.14 1092.97,604.14 1092.98,604.14 1092.99,604.139 1093,604.139 1093.01,604.139 1093.02,604.139 1093.03,604.139 1093.04,604.139 1093.05,604.139 1093.06,604.139 1093.07,604.139 1093.08,604.139 1093.08,604.139 1093.09,604.139 1093.1,604.139 1093.11,604.138 1093.12,604.138 1093.13,604.138 1093.14,604.138 1093.15,604.138 1093.16,604.138 1093.17,604.138 1093.18,604.138 1093.19,604.138 1093.19,604.138 1093.2,604.138 1093.21,604.138 1093.22,604.138 1093.23,604.138 1093.24,604.137 1093.25,604.137 1093.26,604.137 1093.27,604.137 1093.28,604.137 1093.29,604.137 1093.3,604.137 1093.31,604.137 1093.31,604.137 1093.32,604.137 1093.33,604.137 1093.34,604.137 1093.35,604.137 1093.36,604.136 1093.37,604.136 1093.38,604.136 1093.39,604.136 1093.4,604.136 1093.41,604.136 1093.42,604.136 1093.42,604.136 1093.43,604.136 1093.44,604.136 1093.45,604.136 1093.46,604.136 1093.47,604.136 1093.48,604.136 1093.49,604.135 1093.5,604.135 1093.51,604.135 1093.52,604.135 1093.53,604.135 1093.53,604.135 1093.54,604.135 1093.55,604.135 1093.56,604.135 1093.57,604.135 1093.58,604.135 1093.59,604.135 1093.6,604.135 1093.61,604.135 1093.62,604.134 1093.63,604.134 1093.64,604.134 1093.65,604.134 1093.65,604.134 1093.66,604.134 1093.67,604.134 1093.68,604.134 1093.69,604.134 1093.7,604.134 1093.71,604.134 1093.72,604.134 1093.73,604.134 1093.74,604.133 1093.75,604.133 1093.76,604.133 1093.76,604.133 1093.77,604.133 1093.78,604.133 1093.79,604.133 1093.8,604.133 1093.81,604.133 1093.82,604.133 1093.83,604.133 1093.84,604.133 1093.85,604.133 1093.86,604.133 1093.87,604.132 1093.87,604.132 1093.88,604.132 1093.89,604.132 1093.9,604.132 1093.91,604.132 1093.92,604.132 1093.93,604.132 1093.94,604.132 1093.95,604.132 1093.96,604.132 1093.97,604.132 1093.98,604.132 1093.99,604.131 1093.99,604.131 1094,604.131 1094.01,604.131 1094.02,604.131 1094.03,604.131 1094.04,604.131 1094.05,604.131 1094.06,604.131 1094.07,604.131 1094.08,604.131 1094.09,604.131 1094.1,604.131 1094.1,604.131 1094.11,604.13 1094.12,604.13 1094.13,604.13 1094.14,604.13 1094.15,604.13 1094.16,604.13 1094.17,604.13 1094.18,604.13 1094.19,604.13 1094.2,604.13 1094.21,604.13 1094.21,604.13 1094.22,604.13 1094.23,604.13 1094.24,604.129 1094.25,604.129 1094.26,604.129 1094.27,604.129 1094.28,604.129 1094.29,604.129 1094.3,604.129 1094.31,604.129 1094.32,604.129 1094.33,604.129 1094.33,604.129 1094.34,604.129 1094.35,604.129 1094.36,604.128 1094.37,604.128 1094.38,604.128 1094.39,604.128 1094.4,604.128 1094.41,604.128 1094.42,604.128 1094.43,604.128 1094.44,604.128 1094.44,604.128 1094.45,604.128 1094.46,604.128 1094.47,604.128 1094.48,604.128 1094.49,604.127 1094.5,604.127 1094.51,604.127 1094.52,604.127 1094.53,604.127 1094.54,604.127 1094.55,604.127 1094.55,604.127 1094.56,604.127 1094.57,604.127 1094.58,604.127 1094.59,604.127 1094.6,604.127 1094.61,604.126 1094.62,604.126 1094.63,604.126 1094.64,604.126 1094.65,604.126 1094.66,604.126 1094.67,604.126 1094.67,604.126 1094.68,604.126 1094.69,604.126 1094.7,604.126 1094.71,604.126 1094.72,604.126 1094.73,604.126 1094.74,604.125 1094.75,604.125 1094.76,604.125 1094.77,604.125 1094.78,604.125 1094.78,604.125 1094.79,604.125 1094.8,604.125 1094.81,604.125 1094.82,604.125 1094.83,604.125 1094.84,604.125 1094.85,604.125 1094.86,604.125 1094.87,604.124 1094.88,604.124 1094.89,604.124 1094.89,604.124 1094.9,604.124 1094.91,604.124 1094.92,604.124 1094.93,604.124 1094.94,604.124 1094.95,604.124 1094.96,604.124 1094.97,604.124 1094.98,604.124 1094.99,604.123 1095,604.123 1095.01,604.123 1095.01,604.123 1095.02,604.123 1095.03,604.123 1095.04,604.123 1095.05,604.123 1095.06,604.123 1095.07,604.123 1095.08,604.123 1095.09,604.123 1095.1,604.123 1095.11,604.123 1095.12,604.122 1095.12,604.122 1095.13,604.122 1095.14,604.122 1095.15,604.122 1095.16,604.122 1095.17,604.122 1095.18,604.122 1095.19,604.122 1095.2,604.122 1095.21,604.122 1095.22,604.122 1095.23,604.122 1095.23,604.122 1095.24,604.121 1095.25,604.121 1095.26,604.121 1095.27,604.121 1095.28,604.121 1095.29,604.121 1095.3,604.121 1095.31,604.121 1095.32,604.121 1095.33,604.121 1095.34,604.121 1095.35,604.121 1095.35,604.121 1095.36,604.12 1095.37,604.12 1095.38,604.12 1095.39,604.12 1095.4,604.12 1095.41,604.12 1095.42,604.12 1095.43,604.12 1095.44,604.12 1095.45,604.12 1095.46,604.12 1095.46,604.12 1095.47,604.12 1095.48,604.12 1095.49,604.119 1095.5,604.119 1095.51,604.119 1095.52,604.119 1095.53,604.119 1095.54,604.119 1095.55,604.119 1095.56,604.119 1095.57,604.119 1095.57,604.119 1095.58,604.119 1095.59,604.119 1095.6,604.119 1095.61,604.118 1095.62,604.118 1095.63,604.118 1095.64,604.118 1095.65,604.118 1095.66,604.118 1095.67,604.118 1095.68,604.118 1095.69,604.118 1095.69,604.118 1095.7,604.118 1095.71,604.118 1095.72,604.118 1095.73,604.118 1095.74,604.117 1095.75,604.117 1095.76,604.117 1095.77,604.117 1095.78,604.117 1095.79,604.117 1095.8,604.117 1095.8,604.117 1095.81,604.117 1095.82,604.117 1095.83,604.117 1095.84,604.117 1095.85,604.117 1095.86,604.117 1095.87,604.116 1095.88,604.116 1095.89,604.116 1095.9,604.116 1095.91,604.116 1095.91,604.116 1095.92,604.116 1095.93,604.116 1095.94,604.116 1095.95,604.116 1095.96,604.116 1095.97,604.116 1095.98,604.116 1095.99,604.115 1096,604.115 1096.01,604.115 1096.02,604.115 1096.03,604.115 1096.03,604.115 1096.04,604.115 1096.05,604.115 1096.06,604.115 1096.07,604.115 1096.08,604.115 1096.09,604.115 1096.1,604.115 1096.11,604.115 1096.12,604.114 1096.13,604.114 1096.14,604.114 1096.14,604.114 1096.15,604.114 1096.16,604.114 1096.17,604.114 1096.18,604.114 1096.19,604.114 1096.2,604.114 1096.21,604.114 1096.22,604.114 1096.23,604.114 1096.24,604.114 1096.25,604.113 1096.25,604.113 1096.26,604.113 1096.27,604.113 1096.28,604.113 1096.29,604.113 1096.3,604.113 1096.31,604.113 1096.32,604.113 1096.33,604.113 1096.34,604.113 1096.35,604.113 1096.36,604.113 1096.37,604.112 1096.37,604.112 1096.38,604.112 1096.39,604.112 1096.4,604.112 1096.41,604.112 1096.42,604.112 1096.43,604.112 1096.44,604.112 1096.45,604.112 1096.46,604.112 1096.47,604.112 1096.48,604.112 1096.48,604.112 1096.49,604.111 1096.5,604.111 1096.51,604.111 1096.52,604.111 1096.53,604.111 1096.54,604.111 1096.55,604.111 1096.56,604.111 1096.57,604.111 1096.58,604.111 1096.59,604.111 1096.59,604.111 1096.6,604.111 1096.61,604.111 1096.62,604.11 1096.63,604.11 1096.64,604.11 1096.65,604.11 1096.66,604.11 1096.67,604.11 1096.68,604.11 1096.69,604.11 1096.7,604.11 1096.71,604.11 1096.71,604.11 1096.72,604.11 1096.73,604.11 1096.74,604.109 1096.75,604.109 1096.76,604.109 1096.77,604.109 1096.78,604.109 1096.79,604.109 1096.8,604.109 1096.81,604.109 1096.82,604.109 1096.82,604.109 1096.83,604.109 1096.84,604.109 1096.85,604.109 1096.86,604.109 1096.87,604.108 1096.88,604.108 1096.89,604.108 1096.9,604.108 1096.91,604.108 1096.92,604.108 1096.93,604.108 1096.94,604.108 1096.94,604.108 1096.95,604.108 1096.96,604.108 1096.97,604.108 1096.98,604.108 1096.99,604.108 1097,604.107 1097.01,604.107 1097.02,604.107 1097.03,604.107 1097.04,604.107 1097.05,604.107 1097.05,604.107 1097.06,604.107 1097.07,604.107 1097.08,604.107 1097.09,604.107 1097.1,604.107 1097.11,604.107 1097.12,604.107 1097.13,604.106 1097.14,604.106 1097.15,604.106 1097.16,604.106 1097.16,604.106 1097.17,604.106 1097.18,604.106 1097.19,604.106 1097.2,604.106 1097.21,604.106 1097.22,604.106 1097.23,604.106 1097.24,604.106 1097.25,604.105 1097.26,604.105 1097.27,604.105 1097.28,604.105 1097.28,604.105 1097.29,604.105 1097.3,604.105 1097.31,604.105 1097.32,604.105 1097.33,604.105 1097.34,604.105 1097.35,604.105 1097.36,604.105 1097.37,604.105 1097.38,604.104 1097.39,604.104 1097.39,604.104 1097.4,604.104 1097.41,604.104 1097.42,604.104 1097.43,604.104 1097.44,604.104 1097.45,604.104 1097.46,604.104 1097.47,604.104 1097.48,604.104 1097.49,604.104 1097.5,604.104 1097.5,604.103 1097.51,604.103 1097.52,604.103 1097.53,604.103 1097.54,604.103 1097.55,604.103 1097.56,604.103 1097.57,604.103 1097.58,604.103 1097.59,604.103 1097.6,604.103 1097.61,604.103 1097.62,604.103 1097.62,604.102 1097.63,604.102 1097.64,604.102 1097.65,604.102 1097.66,604.102 1097.67,604.102 1097.68,604.102 1097.69,604.102 1097.7,604.102 1097.71,604.102 1097.72,604.102 1097.73,604.102 1097.73,604.102 1097.74,604.102 1097.75,604.101 1097.76,604.101 1097.77,604.101 1097.78,604.101 1097.79,604.101 1097.8,604.101 1097.81,604.101 1097.82,604.101 1097.83,604.101 1097.84,604.101 1097.84,604.101 1097.85,604.101 1097.86,604.101 1097.87,604.101 1097.88,604.1 1097.89,604.1 1097.9,604.1 1097.91,604.1 1097.92,604.1 1097.93,604.1 1097.94,604.1 1097.95,604.1 1097.96,604.1 1097.96,604.1 1097.97,604.1 1097.98,604.1 1097.99,604.1 1098,604.099 1098.01,604.099 1098.02,604.099 1098.03,604.099 1098.04,604.099 1098.05,604.099 1098.06,604.099 1098.07,604.099 1098.07,604.099 1098.08,604.099 1098.09,604.099 1098.1,604.099 1098.11,604.099 1098.12,604.099 1098.13,604.098 1098.14,604.098 1098.15,604.098 1098.16,604.098 1098.17,604.098 1098.18,604.098 1098.18,604.098 1098.19,604.098 1098.2,604.098 1098.21,604.098 1098.22,604.098 1098.23,604.098 1098.24,604.098 1098.25,604.098 1098.26,604.097 1098.27,604.097 1098.28,604.097 1098.29,604.097 1098.3,604.097 1098.3,604.097 1098.31,604.097 1098.32,604.097 1098.33,604.097 1098.34,604.097 1098.35,604.097 1098.36,604.097 1098.37,604.097 1098.38,604.097 1098.39,604.096 1098.4,604.096 1098.41,604.096 1098.41,604.096 1098.42,604.096 1098.43,604.096 1098.44,604.096 1098.45,604.096 1098.46,604.096 1098.47,604.096 1098.48,604.096 1098.49,604.096 1098.5,604.096 1098.51,604.095 1098.52,604.095 1098.52,604.095 1098.53,604.095 1098.54,604.095 1098.55,604.095 1098.56,604.095 1098.57,604.095 1098.58,604.095 1098.59,604.095 1098.6,604.095 1098.61,604.095 1098.62,604.095 1098.63,604.095 1098.64,604.094 1098.64,604.094 1098.65,604.094 1098.66,604.094 1098.67,604.094 1098.68,604.094 1098.69,604.094 1098.7,604.094 1098.71,604.094 1098.72,604.094 1098.73,604.094 1098.74,604.094 1098.75,604.094 1098.75,604.094 1098.76,604.093 1098.77,604.093 1098.78,604.093 1098.79,604.093 1098.8,604.093 1098.81,604.093 1098.82,604.093 1098.83,604.093 1098.84,604.093 1098.85,604.093 1098.86,604.093 1098.86,604.093 1098.87,604.093 1098.88,604.093 1098.89,604.092 1098.9,604.092 1098.91,604.092 1098.92,604.092 1098.93,604.092 1098.94,604.092 1098.95,604.092 1098.96,604.092 1098.97,604.092 1098.98,604.092 1098.98,604.092 1098.99,604.092 1099,604.092 1099.01,604.091 1099.02,604.091 1099.03,604.091 1099.04,604.091 1099.05,604.091 1099.06,604.091 1099.07,604.091 1099.08,604.091 1099.09,604.091 1099.09,604.091 1099.1,604.091 1099.11,604.091 1099.12,604.091 1099.13,604.091 1099.14,604.09 1099.15,604.09 1099.16,604.09 1099.17,604.09 1099.18,604.09 1099.19,604.09 1099.2,604.09 1099.2,604.09 1099.21,604.09 1099.22,604.09 1099.23,604.09 1099.24,604.09 1099.25,604.09 1099.26,604.09 1099.27,604.089 1099.28,604.089 1099.29,604.089 1099.3,604.089 1099.31,604.089 1099.32,604.089 1099.32,604.089 1099.33,604.089 1099.34,604.089 1099.35,604.089 1099.36,604.089 1099.37,604.089 1099.38,604.089 1099.39,604.089 1099.4,604.088 1099.41,604.088 1099.42,604.088 1099.43,604.088 1099.43,604.088 1099.44,604.088 1099.45,604.088 1099.46,604.088 1099.47,604.088 1099.48,604.088 1099.49,604.088 1099.5,604.088 1099.51,604.088 1099.52,604.087 1099.53,604.087 1099.54,604.087 1099.54,604.087 1099.55,604.087 1099.56,604.087 1099.57,604.087 1099.58,604.087 1099.59,604.087 1099.6,604.087 1099.61,604.087 1099.62,604.087 1099.63,604.087 1099.64,604.087 1099.65,604.086 1099.66,604.086 1099.66,604.086 1099.67,604.086 1099.68,604.086 1099.69,604.086 1099.7,604.086 1099.71,604.086 1099.72,604.086 1099.73,604.086 1099.74,604.086 1099.75,604.086 1099.76,604.086 1099.77,604.086 1099.77,604.085 1099.78,604.085 1099.79,604.085 1099.8,604.085 1099.81,604.085 1099.82,604.085 1099.83,604.085 1099.84,604.085 1099.85,604.085 1099.86,604.085 1099.87,604.085 1099.88,604.085 1099.88,604.085 1099.89,604.085 1099.9,604.084 1099.91,604.084 1099.92,604.084 1099.93,604.084 1099.94,604.084 1099.95,604.084 1099.96,604.084 1099.97,604.084 1099.98,604.084 1099.99,604.084 1100,604.084 1100,604.084 1100.01,604.084 1100.02,604.083 1100.03,604.083 1100.04,604.083 1100.05,604.083 1100.06,604.083 1100.07,604.083 1100.08,604.083 1100.09,604.083 1100.1,604.083 1100.11,604.083 1100.11,604.083 1100.12,604.083 1100.13,604.083 1100.14,604.083 1100.15,604.082 1100.16,604.082 1100.17,604.082 1100.18,604.082 1100.19,604.082 1100.2,604.082 1100.21,604.082 1100.22,604.082 1100.22,604.082 1100.23,604.082 1100.24,604.082 1100.25,604.082 1100.26,604.082 1100.27,604.082 1100.28,604.081 1100.29,604.081 1100.3,604.081 1100.31,604.081 1100.32,604.081 1100.33,604.081 1100.34,604.081 1100.34,604.081 1100.35,604.081 1100.36,604.081 1100.37,604.081 1100.38,604.081 1100.39,604.081 1100.4,604.081 1100.41,604.08 1100.42,604.08 1100.43,604.08 1100.44,604.08 1100.45,604.08 1100.45,604.08 1100.46,604.08 1100.47,604.08 1100.48,604.08 1100.49,604.08 1100.5,604.08 1100.51,604.08 1100.52,604.08 1100.53,604.08 1100.54,604.079 1100.55,604.079 1100.56,604.079 1100.56,604.079 1100.57,604.079 1100.58,604.079 1100.59,604.079 1100.6,604.079 1100.61,604.079 1100.62,604.079 1100.63,604.079 1100.64,604.079 1100.65,604.079 1100.66,604.078 1100.67,604.078 1100.68,604.078 1100.68,604.078 1100.69,604.078 1100.7,604.078 1100.71,604.078 1100.72,604.078 1100.73,604.078 1100.74,604.078 1100.75,604.078 1100.76,604.078 1100.77,604.078 1100.78,604.078 1100.79,604.077 1100.79,604.077 1100.8,604.077 1100.81,604.077 1100.82,604.077 1100.83,604.077 1100.84,604.077 1100.85,604.077 1100.86,604.077 1100.87,604.077 1100.88,604.077 1100.89,604.077 1100.9,604.077 1100.9,604.077 1100.91,604.076 1100.92,604.076 1100.93,604.076 1100.94,604.076 1100.95,604.076 1100.96,604.076 1100.97,604.076 1100.98,604.076 1100.99,604.076 1101,604.076 1101.01,604.076 1101.02,604.076 1101.02,604.076 1101.03,604.076 1101.04,604.075 1101.05,604.075 1101.06,604.075 1101.07,604.075 1101.08,604.075 1101.09,604.075 1101.1,604.075 1101.11,604.075 1101.12,604.075 1101.13,604.075 1101.13,604.075 1101.14,604.075 1101.15,604.075 1101.16,604.075 1101.17,604.074 1101.18,604.074 1101.19,604.074 1101.2,604.074 1101.21,604.074 1101.22,604.074 1101.23,604.074 1101.24,604.074 1101.24,604.074 1101.25,604.074 1101.26,604.074 1101.27,604.074 1101.28,604.074 1101.29,604.073 1101.3,604.073 1101.31,604.073 1101.32,604.073 1101.33,604.073 1101.34,604.073 1101.35,604.073 1101.36,604.073 1101.36,604.073 1101.37,604.073 1101.38,604.073 1101.39,604.073 1101.4,604.073 1101.41,604.073 1101.42,604.072 1101.43,604.072 1101.44,604.072 1101.45,604.072 1101.46,604.072 1101.47,604.072 1101.47,604.072 1101.48,604.072 1101.49,604.072 1101.5,604.072 1101.51,604.072 1101.52,604.072 1101.53,604.072 1101.54,604.072 1101.55,604.071 1101.56,604.071 1101.57,604.071 1101.58,604.071 1101.58,604.071 1101.59,604.071 1101.6,604.071 1101.61,604.071 1101.62,604.071 1101.63,604.071 1101.64,604.071 1101.65,604.071 1101.66,604.071 1101.67,604.071 1101.68,604.07 1101.69,604.07 1101.7,604.07 1101.7,604.07 1101.71,604.07 1101.72,604.07 1101.73,604.07 1101.74,604.07 1101.75,604.07 1101.76,604.07 1101.77,604.07 1101.78,604.07 1101.79,604.07 1101.8,604.07 1101.81,604.069 1101.81,604.069 1101.82,604.069 1101.83,604.069 1101.84,604.069 1101.85,604.069 1101.86,604.069 1101.87,604.069 1101.88,604.069 1101.89,604.069 1101.9,604.069 1101.91,604.069 1101.92,604.069 1101.92,604.068 1101.93,604.068 1101.94,604.068 1101.95,604.068 1101.96,604.068 1101.97,604.068 1101.98,604.068 1101.99,604.068 1102,604.068 1102.01,604.068 1102.02,604.068 1102.03,604.068 1102.04,604.068 1102.04,604.068 1102.05,604.067 1102.06,604.067 1102.07,604.067 1102.08,604.067 1102.09,604.067 1102.1,604.067 1102.11,604.067 1102.12,604.067 1102.13,604.067 1102.14,604.067 1102.15,604.067 1102.15,604.067 1102.16,604.067 1102.17,604.067 1102.18,604.066 1102.19,604.066 1102.2,604.066 1102.21,604.066 1102.22,604.066 1102.23,604.066 1102.24,604.066 1102.25,604.066 1102.26,604.066 1102.26,604.066 1102.27,604.066 1102.28,604.066 1102.29,604.066 1102.3,604.066 1102.31,604.065 1102.32,604.065 1102.33,604.065 1102.34,604.065 1102.35,604.065 1102.36,604.065 1102.37,604.065 1102.38,604.065 1102.38,604.065 1102.39,604.065 1102.4,604.065 1102.41,604.065 1102.42,604.065 1102.43,604.065 1102.44,604.064 1102.45,604.064 1102.46,604.064 1102.47,604.064 1102.48,604.064 1102.49,604.064 1102.49,604.064 1102.5,604.064 1102.51,604.064 1102.52,604.064 1102.53,604.064 1102.54,604.064 1102.55,604.064 1102.56,604.064 1102.57,604.063 1102.58,604.063 1102.59,604.063 1102.6,604.063 1102.6,604.063 1102.61,604.063 1102.62,604.063 1102.63,604.063 1102.64,604.063 1102.65,604.063 1102.66,604.063 1102.67,604.063 1102.68,604.063 1102.69,604.063 1102.7,604.062 1102.71,604.062 1102.72,604.062 1102.72,604.062 1102.73,604.062 1102.74,604.062 1102.75,604.062 1102.76,604.062 1102.77,604.062 1102.78,604.062 1102.79,604.062 1102.8,604.062 1102.81,604.062 1102.82,604.061 1102.83,604.061 1102.83,604.061 1102.84,604.061 1102.85,604.061 1102.86,604.061 1102.87,604.061 1102.88,604.061 1102.89,604.061 1102.9,604.061 1102.91,604.061 1102.92,604.061 1102.93,604.061 1102.94,604.061 1102.94,604.06 1102.95,604.06 1102.96,604.06 1102.97,604.06 1102.98,604.06 1102.99,604.06 1103,604.06 1103.01,604.06 1103.02,604.06 1103.03,604.06 1103.04,604.06 1103.05,604.06 1103.06,604.06 1103.06,604.06 1103.07,604.059 1103.08,604.059 1103.09,604.059 1103.1,604.059 1103.11,604.059 1103.12,604.059 1103.13,604.059 1103.14,604.059 1103.15,604.059 1103.16,604.059 1103.17,604.059 1103.17,604.059 1103.18,604.059 1103.19,604.059 1103.2,604.058 1103.21,604.058 1103.22,604.058 1103.23,604.058 1103.24,604.058 1103.25,604.058 1103.26,604.058 1103.27,604.058 1103.28,604.058 1103.28,604.058 1103.29,604.058 1103.3,604.058 1103.31,604.058 1103.32,604.058 1103.33,604.057 1103.34,604.057 1103.35,604.057 1103.36,604.057 1103.37,604.057 1103.38,604.057 1103.39,604.057 1103.4,604.057 1103.4,604.057 1103.41,604.057 1103.42,604.057 1103.43,604.057 1103.44,604.057 1103.45,604.057 1103.46,604.056 1103.47,604.056 1103.48,604.056 1103.49,604.056 1103.5,604.056 1103.51,604.056 1103.51,604.056 1103.52,604.056 1103.53,604.056 1103.54,604.056 1103.55,604.056 1103.56,604.056 1103.57,604.056 1103.58,604.056 1103.59,604.055 1103.6,604.055 1103.61,604.055 1103.62,604.055 1103.62,604.055 1103.63,604.055 1103.64,604.055 1103.65,604.055 1103.66,604.055 1103.67,604.055 1103.68,604.055 1103.69,604.055 1103.7,604.055 1103.71,604.054 1103.72,604.054 1103.73,604.054 1103.74,604.054 1103.74,604.054 1103.75,604.054 1103.76,604.054 1103.77,604.054 1103.78,604.054 1103.79,604.054 1103.8,604.054 1103.81,604.054 1103.82,604.054 1103.83,604.054 1103.84,604.053 1103.85,604.053 1103.85,604.053 1103.86,604.053 1103.87,604.053 1103.88,604.053 1103.89,604.053 1103.9,604.053 1103.91,604.053 1103.92,604.053 1103.93,604.053 1103.94,604.053 1103.95,604.053 1103.96,604.053 1103.96,604.052 1103.97,604.052 1103.98,604.052 1103.99,604.052 1104,604.052 1104.01,604.052 1104.02,604.052 1104.03,604.052 1104.04,604.052 1104.05,604.052 1104.06,604.052 1104.07,604.052 1104.08,604.052 1104.08,604.052 1104.09,604.051 1104.1,604.051 1104.11,604.051 1104.12,604.051 1104.13,604.051 1104.14,604.051 1104.15,604.051 1104.16,604.051 1104.17,604.051 1104.18,604.051 1104.19,604.051 1104.19,604.051 1104.2,604.051 1104.21,604.051 1104.22,604.05 1104.23,604.05 1104.24,604.05 1104.25,604.05 1104.26,604.05 1104.27,604.05 1104.28,604.05 1104.29,604.05 1104.3,604.05 1104.3,604.05 1104.31,604.05 1104.32,604.05 1104.33,604.05 1104.34,604.05 1104.35,604.049 1104.36,604.049 1104.37,604.049 1104.38,604.049 1104.39,604.049 1104.4,604.049 1104.41,604.049 1104.42,604.049 1104.42,604.049 1104.43,604.049 1104.44,604.049 1104.45,604.049 1104.46,604.049 1104.47,604.049 1104.48,604.048 1104.49,604.048 1104.5,604.048 1104.51,604.048 1104.52,604.048 1104.53,604.048 1104.53,604.048 1104.54,604.048 1104.55,604.048 1104.56,604.048 1104.57,604.048 1104.58,604.048 1104.59,604.048 1104.6,604.048 1104.61,604.047 1104.62,604.047 1104.63,604.047 1104.64,604.047 1104.64,604.047 1104.65,604.047 1104.66,604.047 1104.67,604.047 1104.68,604.047 1104.69,604.047 1104.7,604.047 1104.71,604.047 1104.72,604.047 1104.73,604.047 1104.74,604.046 1104.75,604.046 1104.76,604.046 1104.76,604.046 1104.77,604.046 1104.78,604.046 1104.79,604.046 1104.8,604.046 1104.81,604.046 1104.82,604.046 1104.83,604.046 1104.84,604.046 1104.85,604.046 1104.86,604.046 1104.87,604.045 1104.87,604.045 1104.88,604.045 1104.89,604.045 1104.9,604.045 1104.91,604.045 1104.92,604.045 1104.93,604.045 1104.94,604.045 1104.95,604.045 1104.96,604.045 1104.97,604.045 1104.98,604.045 1104.98,604.044 1104.99,604.044 1105,604.044 1105.01,604.044 1105.02,604.044 1105.03,604.044 1105.04,604.044 1105.05,604.044 1105.06,604.044 1105.07,604.044 1105.08,604.044 1105.09,604.044 1105.1,604.044 1105.1,604.044 1105.11,604.043 1105.12,604.043 1105.13,604.043 1105.14,604.043 1105.15,604.043 1105.16,604.043 1105.17,604.043 1105.18,604.043 1105.19,604.043 1105.2,604.043 1105.21,604.043 1105.21,604.043 1105.22,604.043 1105.23,604.043 1105.24,604.042 1105.25,604.042 1105.26,604.042 1105.27,604.042 1105.28,604.042 1105.29,604.042 1105.3,604.042 1105.31,604.042 1105.32,604.042 1105.32,604.042 1105.33,604.042 1105.34,604.042 1105.35,604.042 1105.36,604.042 1105.37,604.041 1105.38,604.041 1105.39,604.041 1105.4,604.041 1105.41,604.041 1105.42,604.041 1105.43,604.041 1105.44,604.041 1105.44,604.041 1105.45,604.041 1105.46,604.041 1105.47,604.041 1105.48,604.041 1105.49,604.041 1105.5,604.04 1105.51,604.04 1105.52,604.04 1105.53,604.04 1105.54,604.04 1105.55,604.04 1105.55,604.04 1105.56,604.04 1105.57,604.04 1105.58,604.04 1105.59,604.04 1105.6,604.04 1105.61,604.04 1105.62,604.04 1105.63,604.039 1105.64,604.039 1105.65,604.039 1105.66,604.039 1105.66,604.039 1105.67,604.039 1105.68,604.039 1105.69,604.039 1105.7,604.039 1105.71,604.039 1105.72,604.039 1105.73,604.039 1105.74,604.039 1105.75,604.039 1105.76,604.038 1105.77,604.038 1105.78,604.038 1105.78,604.038 1105.79,604.038 1105.8,604.038 1105.81,604.038 1105.82,604.038 1105.83,604.038 1105.84,604.038 1105.85,604.038 1105.86,604.038 1105.87,604.038 1105.88,604.038 1105.89,604.037 1105.89,604.037 1105.9,604.037 1105.91,604.037 1105.92,604.037 1105.93,604.037 1105.94,604.037 1105.95,604.037 1105.96,604.037 1105.97,604.037 1105.98,604.037 1105.99,604.037 1106,604.037 1106,604.037 1106.01,604.036 1106.02,604.036 1106.03,604.036 1106.04,604.036 1106.05,604.036 1106.06,604.036 1106.07,604.036 1106.08,604.036 1106.09,604.036 1106.1,604.036 1106.11,604.036 1106.12,604.036 1106.12,604.036 1106.13,604.036 1106.14,604.035 1106.15,604.035 1106.16,604.035 1106.17,604.035 1106.18,604.035 1106.19,604.035 1106.2,604.035 1106.21,604.035 1106.22,604.035 1106.23,604.035 1106.23,604.035 1106.24,604.035 1106.25,604.035 1106.26,604.035 1106.27,604.034 1106.28,604.034 1106.29,604.034 1106.3,604.034 1106.31,604.034 1106.32,604.034 1106.33,604.034 1106.34,604.034 1106.34,604.034 1106.35,604.034 1106.36,604.034 1106.37,604.034 1106.38,604.034 1106.39,604.034 1106.4,604.033 1106.41,604.033 1106.42,604.033 1106.43,604.033 1106.44,604.033 1106.45,604.033 1106.46,604.033 1106.46,604.033 1106.47,604.033 1106.48,604.033 1106.49,604.033 1106.5,604.033 1106.51,604.033 1106.52,604.033 1106.53,604.032 1106.54,604.032 1106.55,604.032 1106.56,604.032 1106.57,604.032 1106.57,604.032 1106.58,604.032 1106.59,604.032 1106.6,604.032 1106.61,604.032 1106.62,604.032 1106.63,604.032 1106.64,604.032 1106.65,604.032 1106.66,604.031 1106.67,604.031 1106.68,604.031 1106.68,604.031 1106.69,604.031 1106.7,604.031 1106.71,604.031 1106.72,604.031 1106.73,604.031 1106.74,604.031 1106.75,604.031 1106.76,604.031 1106.77,604.031 1106.78,604.031 1106.79,604.03 1106.8,604.03 1106.8,604.03 1106.81,604.03 1106.82,604.03 1106.83,604.03 1106.84,604.03 1106.85,604.03 1106.86,604.03 1106.87,604.03 1106.88,604.03 1106.89,604.03 1106.9,604.03 1106.91,604.03 1106.91,604.029 1106.92,604.029 1106.93,604.029 1106.94,604.029 1106.95,604.029 1106.96,604.029 1106.97,604.029 1106.98,604.029 1106.99,604.029 1107,604.029 1107.01,604.029 1107.02,604.029 1107.02,604.029 1107.03,604.029 1107.04,604.028 1107.05,604.028 1107.06,604.028 1107.07,604.028 1107.08,604.028 1107.09,604.028 1107.1,604.028 1107.11,604.028 1107.12,604.028 1107.13,604.028 1107.14,604.028 1107.14,604.028 1107.15,604.028 1107.16,604.028 1107.17,604.027 1107.18,604.027 1107.19,604.027 1107.2,604.027 1107.21,604.027 1107.22,604.027 1107.23,604.027 1107.24,604.027 1107.25,604.027 1107.25,604.027 1107.26,604.027 1107.27,604.027 1107.28,604.027 1107.29,604.027 1107.3,604.026 1107.31,604.026 1107.32,604.026 1107.33,604.026 1107.34,604.026 1107.35,604.026 1107.36,604.026 1107.36,604.026 1107.37,604.026 1107.38,604.026 1107.39,604.026 1107.4,604.026 1107.41,604.026 1107.42,604.026 1107.43,604.025 1107.44,604.025 1107.45,604.025 1107.46,604.025 1107.47,604.025 1107.48,604.025 1107.48,604.025 1107.49,604.025 1107.5,604.025 1107.51,604.025 1107.52,604.025 1107.53,604.025 1107.54,604.025 1107.55,604.025 1107.56,604.024 1107.57,604.024 1107.58,604.024 1107.59,604.024 1107.59,604.024 1107.6,604.024 1107.61,604.024 1107.62,604.024 1107.63,604.024 1107.64,604.024 1107.65,604.024 1107.66,604.024 1107.67,604.024 1107.68,604.023 1107.69,604.023 1107.7,604.023 1107.7,604.023 1107.71,604.023 1107.72,604.023 1107.73,604.023 1107.74,604.023 1107.75,604.023 1107.76,604.023 1107.77,604.023 1107.78,604.023 1107.79,604.023 1107.8,604.023 1107.81,604.022 1107.82,604.022 1107.82,604.022 1107.83,604.022 1107.84,604.022 1107.85,604.022 1107.86,604.022 1107.87,604.022 1107.88,604.022 1107.89,604.022 1107.9,604.022 1107.91,604.022 1107.92,604.022 1107.93,604.022 1107.93,604.021 1107.94,604.021 1107.95,604.021 1107.96,604.021 1107.97,604.021 1107.98,604.021 1107.99,604.021 1108,604.021 1108.01,604.021 1108.02,604.021 1108.03,604.021 1108.04,604.021 1108.04,604.021 1108.05,604.021 1108.06,604.02 1108.07,604.02 1108.08,604.02 1108.09,604.02 1108.1,604.02 1108.11,604.02 1108.12,604.02 1108.13,604.02 1108.14,604.02 1108.15,604.02 1108.16,604.02 1108.16,604.02 1108.17,604.02 1108.18,604.02 1108.19,604.019 1108.2,604.019 1108.21,604.019 1108.22,604.019 1108.23,604.019 1108.24,604.019 1108.25,604.019 1108.26,604.019 1108.27,604.019 1108.27,604.019 1108.28,604.019 1108.29,604.019 1108.3,604.019 1108.31,604.019 1108.32,604.018 1108.33,604.018 1108.34,604.018 1108.35,604.018 1108.36,604.018 1108.37,604.018 1108.38,604.018 1108.38,604.018 1108.39,604.018 1108.4,604.018 1108.41,604.018 1108.42,604.018 1108.43,604.018 1108.44,604.018 1108.45,604.017 1108.46,604.017 1108.47,604.017 1108.48,604.017 1108.49,604.017 1108.5,604.017 1108.5,604.017 1108.51,604.017 1108.52,604.017 1108.53,604.017 1108.54,604.017 1108.55,604.017 1108.56,604.017 1108.57,604.017 1108.58,604.017 1108.59,604.016 1108.6,604.016 1108.61,604.016 1108.61,604.016 1108.62,604.016 1108.63,604.016 1108.64,604.016 1108.65,604.016 1108.66,604.016 1108.67,604.016 1108.68,604.016 1108.69,604.016 1108.7,604.016 1108.71,604.016 1108.72,604.015 1108.72,604.015 1108.73,604.015 1108.74,604.015 1108.75,604.015 1108.76,604.015 1108.77,604.015 1108.78,604.015 1108.79,604.015 1108.8,604.015 1108.81,604.015 1108.82,604.015 1108.83,604.015 1108.84,604.015 1108.84,604.014 1108.85,604.014 1108.86,604.014 1108.87,604.014 1108.88,604.014 1108.89,604.014 1108.9,604.014 1108.91,604.014 1108.92,604.014 1108.93,604.014 1108.94,604.014 1108.95,604.014 1108.95,604.014 1108.96,604.014 1108.97,604.013 1108.98,604.013 1108.99,604.013 1109,604.013 1109.01,604.013 1109.02,604.013 1109.03,604.013 1109.04,604.013 1109.05,604.013 1109.06,604.013 1109.06,604.013 1109.07,604.013 1109.08,604.013 1109.09,604.013 1109.1,604.012 1109.11,604.012 1109.12,604.012 1109.13,604.012 1109.14,604.012 1109.15,604.012 1109.16,604.012 1109.17,604.012 1109.18,604.012 1109.18,604.012 1109.19,604.012 1109.2,604.012 1109.21,604.012 1109.22,604.012 1109.23,604.011 1109.24,604.011 1109.25,604.011 1109.26,604.011 1109.27,604.011 1109.28,604.011 1109.29,604.011 1109.29,604.011 1109.3,604.011 1109.31,604.011 1109.32,604.011 1109.33,604.011 1109.34,604.011 1109.35,604.011 1109.36,604.01 1109.37,604.01 1109.38,604.01 1109.39,604.01 1109.4,604.01 1109.4,604.01 1109.41,604.01 1109.42,604.01 1109.43,604.01 1109.44,604.01 1109.45,604.01 1109.46,604.01 1109.47,604.01 1109.48,604.01 1109.49,604.009 1109.5,604.009 1109.51,604.009 1109.52,604.009 1109.52,604.009 1109.53,604.009 1109.54,604.009 1109.55,604.009 1109.56,604.009 1109.57,604.009 1109.58,604.009 1109.59,604.009 1109.6,604.009 1109.61,604.009 1109.62,604.008 1109.63,604.008 1109.63,604.008 1109.64,604.008 1109.65,604.008 1109.66,604.008 1109.67,604.008 1109.68,604.008 1109.69,604.008 1109.7,604.008 1109.71,604.008 1109.72,604.008 1109.73,604.008 1109.74,604.008 1109.74,604.007 1109.75,604.007 1109.76,604.007 1109.77,604.007 1109.78,604.007 1109.79,604.007 1109.8,604.007 1109.81,604.007 1109.82,604.007 1109.83,604.007 1109.84,604.007 1109.85,604.007 1109.86,604.007 1109.86,604.007 1109.87,604.006 1109.88,604.006 1109.89,604.006 1109.9,604.006 1109.91,604.006 1109.92,604.006 1109.93,604.006 1109.94,604.006 1109.95,604.006 1109.96,604.006 1109.97,604.006 1109.97,604.006 1109.98,604.006 1109.99,604.006 1110,604.005 1110.01,604.005 1110.02,604.005 1110.03,604.005 1110.04,604.005 1110.05,604.005 1110.06,604.005 1110.07,604.005 1110.08,604.005 1110.08,604.005 1110.09,604.005 1110.1,604.005 1110.11,604.005 1110.12,604.005 1110.13,604.004 1110.14,604.004 1110.15,604.004 1110.16,604.004 1110.17,604.004 1110.18,604.004 1110.19,604.004 1110.2,604.004 1110.2,604.004 1110.21,604.004 1110.22,604.004 1110.23,604.004 1110.24,604.004 1110.25,604.004 1110.26,604.003 1110.27,604.003 1110.28,604.003 1110.29,604.003 1110.3,604.003 1110.31,604.003 1110.31,604.003 1110.32,604.003 1110.33,604.003 1110.34,604.003 1110.35,604.003 1110.36,604.003 1110.37,604.003 1110.38,604.003 1110.39,604.002 1110.4,604.002 1110.41,604.002 1110.42,604.002 1110.42,604.002 1110.43,604.002 1110.44,604.002 1110.45,604.002 1110.46,604.002 1110.47,604.002 1110.48,604.002 1110.49,604.002 1110.5,604.002 1110.51,604.002 1110.52,604.001 1110.53,604.001 1110.54,604.001 1110.54,604.001 1110.55,604.001 1110.56,604.001 1110.57,604.001 1110.58,604.001 1110.59,604.001 1110.6,604.001 1110.61,604.001 1110.62,604.001 1110.63,604.001 1110.64,604.001 1110.65,604 1110.65,604 1110.66,604 1110.67,604 1110.68,604 1110.69,604 1110.7,604 1110.71,604 1110.72,604 1110.73,604 1110.74,604 1110.75,604 1110.76,604 1110.76,604 1110.77,603.999 1110.78,603.999 1110.79,603.999 1110.8,603.999 1110.81,603.999 1110.82,603.999 1110.83,603.999 1110.84,603.999 1110.85,603.999 1110.86,603.999 1110.87,603.999 1110.88,603.999 1110.88,603.999 1110.89,603.999 1110.9,603.998 1110.91,603.998 1110.92,603.998 1110.93,603.998 1110.94,603.998 1110.95,603.998 1110.96,603.998 1110.97,603.998 1110.98,603.998 1110.99,603.998 1110.99,603.998 1111,603.998 1111.01,603.998 1111.02,603.998 1111.03,603.997 1111.04,603.997 1111.05,603.997 1111.06,603.997 1111.07,603.997 1111.08,603.997 1111.09,603.997 1111.1,603.997 1111.1,603.997 1111.11,603.997 1111.12,603.997 1111.13,603.997 1111.14,603.997 1111.15,603.997 1111.16,603.996 1111.17,603.996 1111.18,603.996 1111.19,603.996 1111.2,603.996 1111.21,603.996 1111.22,603.996 1111.22,603.996 1111.23,603.996 1111.24,603.996 1111.25,603.996 1111.26,603.996 1111.27,603.996 1111.28,603.996 1111.29,603.996 1111.3,603.995 1111.31,603.995 1111.32,603.995 1111.33,603.995 1111.33,603.995 1111.34,603.995 1111.35,603.995 1111.36,603.995 1111.37,603.995 1111.38,603.995 1111.39,603.995 1111.4,603.995 1111.41,603.995 1111.42,603.995 1111.43,603.994 1111.44,603.994 1111.44,603.994 1111.45,603.994 1111.46,603.994 1111.47,603.994 1111.48,603.994 1111.49,603.994 1111.5,603.994 1111.51,603.994 1111.52,603.994 1111.53,603.994 1111.54,603.994 1111.55,603.994 1111.56,603.993 1111.56,603.993 1111.57,603.993 1111.58,603.993 1111.59,603.993 1111.6,603.993 1111.61,603.993 1111.62,603.993 1111.63,603.993 1111.64,603.993 1111.65,603.993 1111.66,603.993 1111.67,603.993 1111.67,603.993 1111.68,603.992 1111.69,603.992 1111.7,603.992 1111.71,603.992 1111.72,603.992 1111.73,603.992 1111.74,603.992 1111.75,603.992 1111.76,603.992 1111.77,603.992 1111.78,603.992 1111.78,603.992 1111.79,603.992 1111.8,603.992 1111.81,603.991 1111.82,603.991 1111.83,603.991 1111.84,603.991 1111.85,603.991 1111.86,603.991 1111.87,603.991 1111.88,603.991 1111.89,603.991 1111.9,603.991 1111.9,603.991 1111.91,603.991 1111.92,603.991 1111.93,603.991 1111.94,603.99 1111.95,603.99 1111.96,603.99 1111.97,603.99 1111.98,603.99 1111.99,603.99 1112,603.99 1112.01,603.99 1112.01,603.99 1112.02,603.99 1112.03,603.99 1112.04,603.99 1112.05,603.99 1112.06,603.99 1112.07,603.989 1112.08,603.989 1112.09,603.989 1112.1,603.989 1112.11,603.989 1112.12,603.989 1112.12,603.989 1112.13,603.989 1112.14,603.989 1112.15,603.989 1112.16,603.989 1112.17,603.989 1112.18,603.989 1112.19,603.989 1112.2,603.988 1112.21,603.988 1112.22,603.988 1112.23,603.988 1112.24,603.988 1112.24,603.988 1112.25,603.988 1112.26,603.988 1112.27,603.988 1112.28,603.988 1112.29,603.988 1112.3,603.988 1112.31,603.988 1112.32,603.988 1112.33,603.987 1112.34,603.987 1112.35,603.987 1112.35,603.987 1112.36,603.987 1112.37,603.987 1112.38,603.987 1112.39,603.987 1112.4,603.987 1112.41,603.987 1112.42,603.987 1112.43,603.987 1112.44,603.987 1112.45,603.987 1112.46,603.986 1112.46,603.986 1112.47,603.986 1112.48,603.986 1112.49,603.986 1112.5,603.986 1112.51,603.986 1112.52,603.986 1112.53,603.986 1112.54,603.986 1112.55,603.986 1112.56,603.986 1112.57,603.986 1112.58,603.986 1112.58,603.986 1112.59,603.985 1112.6,603.985 1112.61,603.985 1112.62,603.985 1112.63,603.985 1112.64,603.985 1112.65,603.985 1112.66,603.985 1112.67,603.985 1112.68,603.985 1112.69,603.985 1112.69,603.985 1112.7,603.985 1112.71,603.985 1112.72,603.984 1112.73,603.984 1112.74,603.984 1112.75,603.984 1112.76,603.984 1112.77,603.984 1112.78,603.984 1112.79,603.984 1112.8,603.984 1112.8,603.984 1112.81,603.984 1112.82,603.984 1112.83,603.984 1112.84,603.984 1112.85,603.983 1112.86,603.983 1112.87,603.983 1112.88,603.983 1112.89,603.983 1112.9,603.983 1112.91,603.983 1112.92,603.983 1112.92,603.983 1112.93,603.983 1112.94,603.983 1112.95,603.983 1112.96,603.983 1112.97,603.983 1112.98,603.982 1112.99,603.982 1113,603.982 1113.01,603.982 1113.02,603.982 1113.03,603.982 1113.03,603.982 1113.04,603.982 1113.05,603.982 1113.06,603.982 1113.07,603.982 1113.08,603.982 1113.09,603.982 1113.1,603.982 1113.11,603.981 1113.12,603.981 1113.13,603.981 1113.14,603.981 1113.14,603.981 1113.15,603.981 1113.16,603.981 1113.17,603.981 1113.18,603.981 1113.19,603.981 1113.2,603.981 1113.21,603.981 1113.22,603.981 1113.23,603.981 1113.24,603.98 1113.25,603.98 1113.26,603.98 1113.26,603.98 1113.27,603.98 1113.28,603.98 1113.29,603.98 1113.3,603.98 1113.31,603.98 1113.32,603.98 1113.33,603.98 1113.34,603.98 1113.35,603.98 1113.36,603.98 1113.37,603.979 1113.37,603.979 1113.38,603.979 1113.39,603.979 1113.4,603.979 1113.41,603.979 1113.42,603.979 1113.43,603.979 1113.44,603.979 1113.45,603.979 1113.46,603.979 1113.47,603.979 1113.48,603.979 1113.48,603.979 1113.49,603.979 1113.5,603.978 1113.51,603.978 1113.52,603.978 1113.53,603.978 1113.54,603.978 1113.55,603.978 1113.56,603.978 1113.57,603.978 1113.58,603.978 1113.59,603.978 1113.6,603.978 1113.6,603.978 1113.61,603.978 1113.62,603.978 1113.63,603.977 1113.64,603.977 1113.65,603.977 1113.66,603.977 1113.67,603.977 1113.68,603.977 1113.69,603.977 1113.7,603.977 1113.71,603.977 1113.71,603.977 1113.72,603.977 1113.73,603.977 1113.74,603.977 1113.75,603.977 1113.76,603.976 1113.77,603.976 1113.78,603.976 1113.79,603.976 1113.8,603.976 1113.81,603.976 1113.82,603.976 1113.82,603.976 1113.83,603.976 1113.84,603.976 1113.85,603.976 1113.86,603.976 1113.87,603.976 1113.88,603.976 1113.89,603.975 1113.9,603.975 1113.91,603.975 1113.92,603.975 1113.93,603.975 1113.94,603.975 1113.94,603.975 1113.95,603.975 1113.96,603.975 1113.97,603.975 1113.98,603.975 1113.99,603.975 1114,603.975 1114.01,603.975 1114.02,603.974 1114.03,603.974 1114.04,603.974 1114.05,603.974 1114.05,603.974 1114.06,603.974 1114.07,603.974 1114.08,603.974 1114.09,603.974 1114.1,603.974 1114.11,603.974 1114.12,603.974 1114.13,603.974 1114.14,603.974 1114.15,603.973 1114.16,603.973 1114.16,603.973 1114.17,603.973 1114.18,603.973 1114.19,603.973 1114.2,603.973 1114.21,603.973 1114.22,603.973 1114.23,603.973 1114.24,603.973 1114.25,603.973 1114.26,603.973 1114.27,603.973 1114.28,603.972 1114.28,603.972 1114.29,603.972 1114.3,603.972 1114.31,603.972 1114.32,603.972 1114.33,603.972 1114.34,603.972 1114.35,603.972 1114.36,603.972 1114.37,603.972 1114.38,603.972 1114.39,603.972 1114.39,603.972 1114.4,603.972 1114.41,603.971 1114.42,603.971 1114.43,603.971 1114.44,603.971 1114.45,603.971 1114.46,603.971 1114.47,603.971 1114.48,603.971 1114.49,603.971 1114.5,603.971 1114.5,603.971 1114.51,603.971 1114.52,603.971 1114.53,603.971 1114.54,603.97 1114.55,603.97 1114.56,603.97 1114.57,603.97 1114.58,603.97 1114.59,603.97 1114.6,603.97 1114.61,603.97 1114.62,603.97 1114.62,603.97 1114.63,603.97 1114.64,603.97 1114.65,603.97 1114.66,603.97 1114.67,603.969 1114.68,603.969 1114.69,603.969 1114.7,603.969 1114.71,603.969 1114.72,603.969 1114.73,603.969 1114.73,603.969 1114.74,603.969 1114.75,603.969 1114.76,603.969 1114.77,603.969 1114.78,603.969 1114.79,603.969 1114.8,603.968 1114.81,603.968 1114.82,603.968 1114.83,603.968 1114.84,603.968 1114.84,603.968 1114.85,603.968 1114.86,603.968 1114.87,603.968 1114.88,603.968 1114.89,603.968 1114.9,603.968 1114.91,603.968 1114.92,603.968 1114.93,603.967 1114.94,603.967 1114.95,603.967 1114.96,603.967 1114.96,603.967 1114.97,603.967 1114.98,603.967 1114.99,603.967 1115,603.967 1115.01,603.967 1115.02,603.967 1115.03,603.967 1115.04,603.967 1115.05,603.967 1115.06,603.967 1115.07,603.966 1115.07,603.966 1115.08,603.966 1115.09,603.966 1115.1,603.966 1115.11,603.966 1115.12,603.966 1115.13,603.966 1115.14,603.966 1115.15,603.966 1115.16,603.966 1115.17,603.966 1115.18,603.966 1115.18,603.966 1115.19,603.965 1115.2,603.965 1115.21,603.965 1115.22,603.965 1115.23,603.965 1115.24,603.965 1115.25,603.965 1115.26,603.965 1115.27,603.965 1115.28,603.965 1115.29,603.965 1115.3,603.965 1115.3,603.965 1115.31,603.965 1115.32,603.964 1115.33,603.964 1115.34,603.964 1115.35,603.964 1115.36,603.964 1115.37,603.964 1115.38,603.964 1115.39,603.964 1115.4,603.964 1115.41,603.964 1115.41,603.964 1115.42,603.964 1115.43,603.964 1115.44,603.964 1115.45,603.963 1115.46,603.963 1115.47,603.963 1115.48,603.963 1115.49,603.963 1115.5,603.963 1115.51,603.963 1115.52,603.963 1115.52,603.963 1115.53,603.963 1115.54,603.963 1115.55,603.963 1115.56,603.963 1115.57,603.963 1115.58,603.962 1115.59,603.962 1115.6,603.962 1115.61,603.962 1115.62,603.962 1115.63,603.962 1115.64,603.962 1115.64,603.962 1115.65,603.962 1115.66,603.962 1115.67,603.962 1115.68,603.962 1115.69,603.962 1115.7,603.962 1115.71,603.961 1115.72,603.961 1115.73,603.961 1115.74,603.961 1115.75,603.961 1115.75,603.961 1115.76,603.961 1115.77,603.961 1115.78,603.961 1115.79,603.961 1115.8,603.961 1115.81,603.961 1115.82,603.961 1115.83,603.961 1115.84,603.961 1115.85,603.96 1115.86,603.96 1115.86,603.96 1115.87,603.96 1115.88,603.96 1115.89,603.96 1115.9,603.96 1115.91,603.96 1115.92,603.96 1115.93,603.96 1115.94,603.96 1115.95,603.96 1115.96,603.96 1115.97,603.96 1115.98,603.959 1115.98,603.959 1115.99,603.959 1116,603.959 1116.01,603.959 1116.02,603.959 1116.03,603.959 1116.04,603.959 1116.05,603.959 1116.06,603.959 1116.07,603.959 1116.08,603.959 1116.09,603.959 1116.09,603.959 1116.1,603.958 1116.11,603.958 1116.12,603.958 1116.13,603.958 1116.14,603.958 1116.15,603.958 1116.16,603.958 1116.17,603.958 1116.18,603.958 1116.19,603.958 1116.2,603.958 1116.2,603.958 1116.21,603.958 1116.22,603.958 1116.23,603.957 1116.24,603.957 1116.25,603.957 1116.26,603.957 1116.27,603.957 1116.28,603.957 1116.29,603.957 1116.3,603.957 1116.31,603.957 1116.32,603.957 1116.32,603.957 1116.33,603.957 1116.34,603.957 1116.35,603.957 1116.36,603.957 1116.37,603.956 1116.38,603.956 1116.39,603.956 1116.4,603.956 1116.41,603.956 1116.42,603.956 1116.43,603.956 1116.43,603.956 1116.44,603.956 1116.45,603.956 1116.46,603.956 1116.47,603.956 1116.48,603.956 1116.49,603.956 1116.5,603.955 1116.51,603.955 1116.52,603.955 1116.53,603.955 1116.54,603.955 1116.54,603.955 1116.55,603.955 1116.56,603.955 1116.57,603.955 1116.58,603.955 1116.59,603.955 1116.6,603.955 1116.61,603.955 1116.62,603.955 1116.63,603.954 1116.64,603.954 1116.65,603.954 1116.66,603.954 1116.66,603.954 1116.67,603.954 1116.68,603.954 1116.69,603.954 1116.7,603.954 1116.71,603.954 1116.72,603.954 1116.73,603.954 1116.74,603.954 1116.75,603.954 1116.76,603.953 1116.77,603.953 1116.77,603.953 1116.78,603.953 1116.79,603.953 1116.8,603.953 1116.81,603.953 1116.82,603.953 1116.83,603.953 1116.84,603.953 1116.85,603.953 1116.86,603.953 1116.87,603.953 1116.88,603.953 1116.88,603.952 1116.89,603.952 1116.9,603.952 1116.91,603.952 1116.92,603.952 1116.93,603.952 1116.94,603.952 1116.95,603.952 1116.96,603.952 1116.97,603.952 1116.98,603.952 1116.99,603.952 1117,603.952 1117,603.952 1117.01,603.952 1117.02,603.951 1117.03,603.951 1117.04,603.951 1117.05,603.951 1117.06,603.951 1117.07,603.951 1117.08,603.951 1117.09,603.951 1117.1,603.951 1117.11,603.951 1117.11,603.951 1117.12,603.951 1117.13,603.951 1117.14,603.951 1117.15,603.95 1117.16,603.95 1117.17,603.95 1117.18,603.95 1117.19,603.95 1117.2,603.95 1117.21,603.95 1117.22,603.95 1117.22,603.95 1117.23,603.95 1117.24,603.95 1117.25,603.95 1117.26,603.95 1117.27,603.95 1117.28,603.949 1117.29,603.949 1117.3,603.949 1117.31,603.949 1117.32,603.949 1117.33,603.949 1117.34,603.949 1117.34,603.949 1117.35,603.949 1117.36,603.949 1117.37,603.949 1117.38,603.949 1117.39,603.949 1117.4,603.949 1117.41,603.948 1117.42,603.948 1117.43,603.948 1117.44,603.948 1117.45,603.948 1117.45,603.948 1117.46,603.948 1117.47,603.948 1117.48,603.948 1117.49,603.948 1117.5,603.948 1117.51,603.948 1117.52,603.948 1117.53,603.948 1117.54,603.948 1117.55,603.947 1117.56,603.947 1117.56,603.947 1117.57,603.947 1117.58,603.947 1117.59,603.947 1117.6,603.947 1117.61,603.947 1117.62,603.947 1117.63,603.947 1117.64,603.947 1117.65,603.947 1117.66,603.947 1117.67,603.947 1117.68,603.946 1117.68,603.946 1117.69,603.946 1117.7,603.946 1117.71,603.946 1117.72,603.946 1117.73,603.946 1117.74,603.946 1117.75,603.946 1117.76,603.946 1117.77,603.946 1117.78,603.946 1117.79,603.946 1117.79,603.946 1117.8,603.945 1117.81,603.945 1117.82,603.945 1117.83,603.945 1117.84,603.945 1117.85,603.945 1117.86,603.945 1117.87,603.945 1117.88,603.945 1117.89,603.945 1117.9,603.945 1117.9,603.945 1117.91,603.945 1117.92,603.945 1117.93,603.944 1117.94,603.944 1117.95,603.944 1117.96,603.944 1117.97,603.944 1117.98,603.944 1117.99,603.944 1118,603.944 1118.01,603.944 1118.02,603.944 1118.02,603.944 1118.03,603.944 1118.04,603.944 1118.05,603.944 1118.06,603.944 1118.07,603.943 1118.08,603.943 1118.09,603.943 1118.1,603.943 1118.11,603.943 1118.12,603.943 1118.13,603.943 1118.13,603.943 1118.14,603.943 1118.15,603.943 1118.16,603.943 1118.17,603.943 1118.18,603.943 1118.19,603.943 1118.2,603.942 1118.21,603.942 1118.22,603.942 1118.23,603.942 1118.24,603.942 1118.24,603.942 1118.25,603.942 1118.26,603.942 1118.27,603.942 1118.28,603.942 1118.29,603.942 1118.3,603.942 1118.31,603.942 1118.32,603.942 1118.33,603.941 1118.34,603.941 1118.35,603.941 1118.36,603.941 1118.36,603.941 1118.37,603.941 1118.38,603.941 1118.39,603.941 1118.4,603.941 1118.41,603.941 1118.42,603.941 1118.43,603.941 1118.44,603.941 1118.45,603.941 1118.46,603.94 1118.47,603.94 1118.47,603.94 1118.48,603.94 1118.49,603.94 1118.5,603.94 1118.51,603.94 1118.52,603.94 1118.53,603.94 1118.54,603.94 1118.55,603.94 1118.56,603.94 1118.57,603.94 1118.58,603.94 1118.58,603.94 1118.59,603.939 1118.6,603.939 1118.61,603.939 1118.62,603.939 1118.63,603.939 1118.64,603.939 1118.65,603.939 1118.66,603.939 1118.67,603.939 1118.68,603.939 1118.69,603.939 1118.7,603.939 1118.7,603.939 1118.71,603.939 1118.72,603.938 1118.73,603.938 1118.74,603.938 1118.75,603.938 1118.76,603.938 1118.77,603.938 1118.78,603.938 1118.79,603.938 1118.8,603.938 1118.81,603.938 1118.81,603.938 1118.82,603.938 1118.83,603.938 1118.84,603.938 1118.85,603.937 1118.86,603.937 1118.87,603.937 1118.88,603.937 1118.89,603.937 1118.9,603.937 1118.91,603.937 1118.92,603.937 1118.92,603.937 1118.93,603.937 1118.94,603.937 1118.95,603.937 1118.96,603.937 1118.97,603.937 1118.98,603.937 1118.99,603.936 1119,603.936 1119.01,603.936 1119.02,603.936 1119.03,603.936 1119.04,603.936 1119.04,603.936 1119.05,603.936 1119.06,603.936 1119.07,603.936 1119.08,603.936 1119.09,603.936 1119.1,603.936 1119.11,603.936 1119.12,603.935 1119.13,603.935 1119.14,603.935 1119.15,603.935 1119.15,603.935 1119.16,603.935 1119.17,603.935 1119.18,603.935 1119.19,603.935 1119.2,603.935 1119.21,603.935 1119.22,603.935 1119.23,603.935 1119.24,603.935 1119.25,603.934 1119.26,603.934 1119.26,603.934 1119.27,603.934 1119.28,603.934 1119.29,603.934 1119.3,603.934 1119.31,603.934 1119.32,603.934 1119.33,603.934 1119.34,603.934 1119.35,603.934 1119.36,603.934 1119.37,603.934 1119.38,603.933 1119.38,603.933 1119.39,603.933 1119.4,603.933 1119.41,603.933 1119.42,603.933 1119.43,603.933 1119.44,603.933 1119.45,603.933 1119.46,603.933 1119.47,603.933 1119.48,603.933 1119.49,603.933 1119.49,603.933 1119.5,603.933 1119.51,603.932 1119.52,603.932 1119.53,603.932 1119.54,603.932 1119.55,603.932 1119.56,603.932 1119.57,603.932 1119.58,603.932 1119.59,603.932 1119.6,603.932 1119.6,603.932 1119.61,603.932 1119.62,603.932 1119.63,603.932 1119.64,603.931 1119.65,603.931 1119.66,603.931 1119.67,603.931 1119.68,603.931 1119.69,603.931 1119.7,603.931 1119.71,603.931 1119.72,603.931 1119.72,603.931 1119.73,603.931 1119.74,603.931 1119.75,603.931 1119.76,603.931 1119.77,603.93 1119.78,603.93 1119.79,603.93 1119.8,603.93 1119.81,603.93 1119.82,603.93 1119.83,603.93 1119.83,603.93 1119.84,603.93 1119.85,603.93 1119.86,603.93 1119.87,603.93 1119.88,603.93 1119.89,603.93 1119.9,603.93 1119.91,603.929 1119.92,603.929 1119.93,603.929 1119.94,603.929 1119.94,603.929 1119.95,603.929 1119.96,603.929 1119.97,603.929 1119.98,603.929 1119.99,603.929 1120,603.929 1120.01,603.929 1120.02,603.929 1120.03,603.929 1120.04,603.928 1120.05,603.928 1120.06,603.928 1120.06,603.928 1120.07,603.928 1120.08,603.928 1120.09,603.928 1120.1,603.928 1120.11,603.928 1120.12,603.928 1120.13,603.928 1120.14,603.928 1120.15,603.928 1120.16,603.928 1120.17,603.927 1120.17,603.927 1120.18,603.927 1120.19,603.927 1120.2,603.927 1120.21,603.927 1120.22,603.927 1120.23,603.927 1120.24,603.927 1120.25,603.927 1120.26,603.927 1120.27,603.927 1120.28,603.927 1120.28,603.927 1120.29,603.927 1120.3,603.926 1120.31,603.926 1120.32,603.926 1120.33,603.926 1120.34,603.926 1120.35,603.926 1120.36,603.926 1120.37,603.926 1120.38,603.926 1120.39,603.926 1120.4,603.926 1120.4,603.926 1120.41,603.926 1120.42,603.926 1120.43,603.925 1120.44,603.925 1120.45,603.925 1120.46,603.925 1120.47,603.925 1120.48,603.925 1120.49,603.925 1120.5,603.925 1120.51,603.925 1120.51,603.925 1120.52,603.925 1120.53,603.925 1120.54,603.925 1120.55,603.925 1120.56,603.924 1120.57,603.924 1120.58,603.924 1120.59,603.924 1120.6,603.924 1120.61,603.924 1120.62,603.924 1120.62,603.924 1120.63,603.924 1120.64,603.924 1120.65,603.924 1120.66,603.924 1120.67,603.924 1120.68,603.924 1120.69,603.923 1120.7,603.923 1120.71,603.923 1120.72,603.923 1120.73,603.923 1120.74,603.923 1120.74,603.923 1120.75,603.923 1120.76,603.923 1120.77,603.923 1120.78,603.923 1120.79,603.923 1120.8,603.923 1120.81,603.923 1120.82,603.923 1120.83,603.922 1120.84,603.922 1120.85,603.922 1120.85,603.922 1120.86,603.922 1120.87,603.922 1120.88,603.922 1120.89,603.922 1120.9,603.922 1120.91,603.922 1120.92,603.922 1120.93,603.922 1120.94,603.922 1120.95,603.922 1120.96,603.921 1120.96,603.921 1120.97,603.921 1120.98,603.921 1120.99,603.921 1121,603.921 1121.01,603.921 1121.02,603.921 1121.03,603.921 1121.04,603.921 1121.05,603.921 1121.06,603.921 1121.07,603.921 1121.08,603.921 1121.08,603.92 1121.09,603.92 1121.1,603.92 1121.11,603.92 1121.12,603.92 1121.13,603.92 1121.14,603.92 1121.15,603.92 1121.16,603.92 1121.17,603.92 1121.18,603.92 1121.19,603.92 1121.19,603.92 1121.2,603.92 1121.21,603.92 1121.22,603.919 1121.23,603.919 1121.24,603.919 1121.25,603.919 1121.26,603.919 1121.27,603.919 1121.28,603.919 1121.29,603.919 1121.3,603.919 1121.3,603.919 1121.31,603.919 1121.32,603.919 1121.33,603.919 1121.34,603.919 1121.35,603.918 1121.36,603.918 1121.37,603.918 1121.38,603.918 1121.39,603.918 1121.4,603.918 1121.41,603.918 1121.42,603.918 1121.42,603.918 1121.43,603.918 1121.44,603.918 1121.45,603.918 1121.46,603.918 1121.47,603.918 1121.48,603.918 1121.49,603.917 1121.5,603.917 1121.51,603.917 1121.52,603.917 1121.53,603.917 1121.53,603.917 1121.54,603.917 1121.55,603.917 1121.56,603.917 1121.57,603.917 1121.58,603.917 1121.59,603.917 1121.6,603.917 1121.61,603.917 1121.62,603.916 1121.63,603.916 1121.64,603.916 1121.65,603.916 1121.65,603.916 1121.66,603.916 1121.67,603.916 1121.68,603.916 1121.69,603.916 1121.7,603.916 1121.71,603.916 1121.72,603.916 1121.73,603.916 1121.74,603.916 1121.75,603.915 1121.76,603.915 1121.76,603.915 1121.77,603.915 1121.78,603.915 1121.79,603.915 1121.8,603.915 1121.81,603.915 1121.82,603.915 1121.83,603.915 1121.84,603.915 1121.85,603.915 1121.86,603.915 1121.87,603.915 1121.87,603.915 1121.88,603.914 1121.89,603.914 1121.9,603.914 1121.91,603.914 1121.92,603.914 1121.93,603.914 1121.94,603.914 1121.95,603.914 1121.96,603.914 1121.97,603.914 1121.98,603.914 1121.99,603.914 1121.99,603.914 1122,603.914 1122.01,603.913 1122.02,603.913 1122.03,603.913 1122.04,603.913 1122.05,603.913 1122.06,603.913 1122.07,603.913 1122.08,603.913 1122.09,603.913 1122.1,603.913 1122.1,603.913 1122.11,603.913 1122.12,603.913 1122.13,603.913 1122.14,603.912 1122.15,603.912 1122.16,603.912 1122.17,603.912 1122.18,603.912 1122.19,603.912 1122.2,603.912 1122.21,603.912 1122.21,603.912 1122.22,603.912 1122.23,603.912 1122.24,603.912 1122.25,603.912 1122.26,603.912 1122.27,603.912 1122.28,603.911 1122.29,603.911 1122.3,603.911 1122.31,603.911 1122.32,603.911 1122.33,603.911 1122.33,603.911 1122.34,603.911 1122.35,603.911 1122.36,603.911 1122.37,603.911 1122.38,603.911 1122.39,603.911 1122.4,603.911 1122.41,603.91 1122.42,603.91 1122.43,603.91 1122.44,603.91 1122.44,603.91 1122.45,603.91 1122.46,603.91 1122.47,603.91 1122.48,603.91 1122.49,603.91 1122.5,603.91 1122.51,603.91 1122.52,603.91 1122.53,603.91 1122.54,603.909 1122.55,603.909 1122.55,603.909 1122.56,603.909 1122.57,603.909 1122.58,603.909 1122.59,603.909 1122.6,603.909 1122.61,603.909 1122.62,603.909 1122.63,603.909 1122.64,603.909 1122.65,603.909 1122.66,603.909 1122.67,603.909 1122.67,603.908 1122.68,603.908 1122.69,603.908 1122.7,603.908 1122.71,603.908 1122.72,603.908 1122.73,603.908 1122.74,603.908 1122.75,603.908 1122.76,603.908 1122.77,603.908 1122.78,603.908 1122.78,603.908 1122.79,603.908 1122.8,603.907 1122.81,603.907 1122.82,603.907 1122.83,603.907 1122.84,603.907 1122.85,603.907 1122.86,603.907 1122.87,603.907 1122.88,603.907 1122.89,603.907 1122.89,603.907 1122.9,603.907 1122.91,603.907 1122.92,603.907 1122.93,603.906 1122.94,603.906 1122.95,603.906 1122.96,603.906 1122.97,603.906 1122.98,603.906 1122.99,603.906 1123,603.906 1123.01,603.906 1123.01,603.906 1123.02,603.906 1123.03,603.906 1123.04,603.906 1123.05,603.906 1123.06,603.906 1123.07,603.905 1123.08,603.905 1123.09,603.905 1123.1,603.905 1123.11,603.905 1123.12,603.905 1123.12,603.905 1123.13,603.905 1123.14,603.905 1123.15,603.905 1123.16,603.905 1123.17,603.905 1123.18,603.905 1123.19,603.905 1123.2,603.904 1123.21,603.904 1123.22,603.904 1123.23,603.904 1123.23,603.904 1123.24,603.904 1123.25,603.904 1123.26,603.904 1123.27,603.904 1123.28,603.904 1123.29,603.904 1123.3,603.904 1123.31,603.904 1123.32,603.904 1123.33,603.904 1123.34,603.903 1123.35,603.903 1123.35,603.903 1123.36,603.903 1123.37,603.903 1123.38,603.903 1123.39,603.903 1123.4,603.903 1123.41,603.903 1123.42,603.903 1123.43,603.903 1123.44,603.903 1123.45,603.903 1123.46,603.903 1123.46,603.902 1123.47,603.902 1123.48,603.902 1123.49,603.902 1123.5,603.902 1123.51,603.902 1123.52,603.902 1123.53,603.902 1123.54,603.902 1123.55,603.902 1123.56,603.902 1123.57,603.902 1123.57,603.902 1123.58,603.902 1123.59,603.901 1123.6,603.901 1123.61,603.901 1123.62,603.901 1123.63,603.901 1123.64,603.901 1123.65,603.901 1123.66,603.901 1123.67,603.901 1123.68,603.901 1123.69,603.901 1123.69,603.901 1123.7,603.901 1123.71,603.901 1123.72,603.901 1123.73,603.9 1123.74,603.9 1123.75,603.9 1123.76,603.9 1123.77,603.9 1123.78,603.9 1123.79,603.9 1123.8,603.9 1123.8,603.9 1123.81,603.9 1123.82,603.9 1123.83,603.9 1123.84,603.9 1123.85,603.9 1123.86,603.899 1123.87,603.899 1123.88,603.899 1123.89,603.899 1123.9,603.899 1123.91,603.899 1123.91,603.899 1123.92,603.899 1123.93,603.899 1123.94,603.899 1123.95,603.899 1123.96,603.899 1123.97,603.899 1123.98,603.899 1123.99,603.899 1124,603.898 1124.01,603.898 1124.02,603.898 1124.03,603.898 1124.03,603.898 1124.04,603.898 1124.05,603.898 1124.06,603.898 1124.07,603.898 1124.08,603.898 1124.09,603.898 1124.1,603.898 1124.11,603.898 1124.12,603.898 1124.13,603.897 1124.14,603.897 1124.14,603.897 1124.15,603.897 1124.16,603.897 1124.17,603.897 1124.18,603.897 1124.19,603.897 1124.2,603.897 1124.21,603.897 1124.22,603.897 1124.23,603.897 1124.24,603.897 1124.25,603.897 1124.25,603.896 1124.26,603.896 1124.27,603.896 1124.28,603.896 1124.29,603.896 1124.3,603.896 1124.31,603.896 1124.32,603.896 1124.33,603.896 1124.34,603.896 1124.35,603.896 1124.36,603.896 1124.37,603.896 1124.37,603.896 1124.38,603.896 1124.39,603.895 1124.4,603.895 1124.41,603.895 1124.42,603.895 1124.43,603.895 1124.44,603.895 1124.45,603.895 1124.46,603.895 1124.47,603.895 1124.48,603.895 1124.48,603.895 1124.49,603.895 1124.5,603.895 1124.51,603.895 1124.52,603.894 1124.53,603.894 1124.54,603.894 1124.55,603.894 1124.56,603.894 1124.57,603.894 1124.58,603.894 1124.59,603.894 1124.59,603.894 1124.6,603.894 1124.61,603.894 1124.62,603.894 1124.63,603.894 1124.64,603.894 1124.65,603.894 1124.66,603.893 1124.67,603.893 1124.68,603.893 1124.69,603.893 1124.7,603.893 1124.71,603.893 1124.71,603.893 1124.72,603.893 1124.73,603.893 1124.74,603.893 1124.75,603.893 1124.76,603.893 1124.77,603.893 1124.78,603.893 1124.79,603.892 1124.8,603.892 1124.81,603.892 1124.82,603.892 1124.82,603.892 1124.83,603.892 1124.84,603.892 1124.85,603.892 1124.86,603.892 1124.87,603.892 1124.88,603.892 1124.89,603.892 1124.9,603.892 1124.91,603.892 1124.92,603.892 1124.93,603.891 1124.93,603.891 1124.94,603.891 1124.95,603.891 1124.96,603.891 1124.97,603.891 1124.98,603.891 1124.99,603.891 1125,603.891 1125.01,603.891 1125.02,603.891 1125.03,603.891 1125.04,603.891 1125.05,603.891 1125.05,603.89 1125.06,603.89 1125.07,603.89 1125.08,603.89 1125.09,603.89 1125.1,603.89 1125.11,603.89 1125.12,603.89 1125.13,603.89 1125.14,603.89 1125.15,603.89 1125.16,603.89 1125.16,603.89 1125.17,603.89 1125.18,603.889 1125.19,603.889 1125.2,603.889 1125.21,603.889 1125.22,603.889 1125.23,603.889 1125.24,603.889 1125.25,603.889 1125.26,603.889 1125.27,603.889 1125.27,603.889 1125.28,603.889 1125.29,603.889 1125.3,603.889 1125.31,603.889 1125.32,603.888 1125.33,603.888 1125.34,603.888 1125.35,603.888 1125.36,603.888 1125.37,603.888 1125.38,603.888 1125.39,603.888 1125.39,603.888 1125.4,603.888 1125.41,603.888 1125.42,603.888 1125.43,603.888 1125.44,603.888 1125.45,603.887 1125.46,603.887 1125.47,603.887 1125.48,603.887 1125.49,603.887 1125.5,603.887 1125.5,603.887 1125.51,603.887 1125.52,603.887 1125.53,603.887 1125.54,603.887 1125.55,603.887 1125.56,603.887 1125.57,603.887 1125.58,603.887 1125.59,603.886 1125.6,603.886 1125.61,603.886 1125.61,603.886 1125.62,603.886 1125.63,603.886 1125.64,603.886 1125.65,603.886 1125.66,603.886 1125.67,603.886 1125.68,603.886 1125.69,603.886 1125.7,603.886 1125.71,603.886 1125.72,603.885 1125.73,603.885 1125.73,603.885 1125.74,603.885 1125.75,603.885 1125.76,603.885 1125.77,603.885 1125.78,603.885 1125.79,603.885 1125.8,603.885 1125.81,603.885 1125.82,603.885 1125.83,603.885 1125.84,603.885 1125.84,603.885 1125.85,603.884 1125.86,603.884 1125.87,603.884 1125.88,603.884 1125.89,603.884 1125.9,603.884 1125.91,603.884 1125.92,603.884 1125.93,603.884 1125.94,603.884 1125.95,603.884 1125.95,603.884 1125.96,603.884 1125.97,603.884 1125.98,603.883 1125.99,603.883 1126,603.883 1126.01,603.883 1126.02,603.883 1126.03,603.883 1126.04,603.883 1126.05,603.883 1126.06,603.883 1126.07,603.883 1126.07,603.883 1126.08,603.883 1126.09,603.883 1126.1,603.883 1126.11,603.883 1126.12,603.882 1126.13,603.882 1126.14,603.882 1126.15,603.882 1126.16,603.882 1126.17,603.882 1126.18,603.882 1126.18,603.882 1126.19,603.882 1126.2,603.882 1126.21,603.882 1126.22,603.882 1126.23,603.882 1126.24,603.882 1126.25,603.881 1126.26,603.881 1126.27,603.881 1126.28,603.881 1126.29,603.881 1126.29,603.881 1126.3,603.881 1126.31,603.881 1126.32,603.881 1126.33,603.881 1126.34,603.881 1126.35,603.881 1126.36,603.881 1126.37,603.881 1126.38,603.88 1126.39,603.88 1126.4,603.88 1126.41,603.88 1126.41,603.88 1126.42,603.88 1126.43,603.88 1126.44,603.88 1126.45,603.88 1126.46,603.88 1126.47,603.88 1126.48,603.88 1126.49,603.88 1126.5,603.88 1126.51,603.88 1126.52,603.879 1126.52,603.879 1126.53,603.879 1126.54,603.879 1126.55,603.879 1126.56,603.879 1126.57,603.879 1126.58,603.879 1126.59,603.879 1126.6,603.879 1126.61,603.879 1126.62,603.879 1126.63,603.879 1126.63,603.879 1126.64,603.878 1126.65,603.878 1126.66,603.878 1126.67,603.878 1126.68,603.878 1126.69,603.878 1126.7,603.878 1126.71,603.878 1126.72,603.878 1126.73,603.878 1126.74,603.878 1126.75,603.878 1126.75,603.878 1126.76,603.878 1126.77,603.878 1126.78,603.877 1126.79,603.877 1126.8,603.877 1126.81,603.877 1126.82,603.877 1126.83,603.877 1126.84,603.877 1126.85,603.877 1126.86,603.877 1126.86,603.877 1126.87,603.877 1126.88,603.877 1126.89,603.877 1126.9,603.877 1126.91,603.876 1126.92,603.876 1126.93,603.876 1126.94,603.876 1126.95,603.876 1126.96,603.876 1126.97,603.876 1126.97,603.876 1126.98,603.876 1126.99,603.876 1127,603.876 1127.01,603.876 1127.02,603.876 1127.03,603.876 1127.04,603.876 1127.05,603.875 1127.06,603.875 1127.07,603.875 1127.08,603.875 1127.09,603.875 1127.09,603.875 1127.1,603.875 1127.11,603.875 1127.12,603.875 1127.13,603.875 1127.14,603.875 1127.15,603.875 1127.16,603.875 1127.17,603.875 1127.18,603.874 1127.19,603.874 1127.2,603.874 1127.2,603.874 1127.21,603.874 1127.22,603.874 1127.23,603.874 1127.24,603.874 1127.25,603.874 1127.26,603.874 1127.27,603.874 1127.28,603.874 1127.29,603.874 1127.3,603.874 1127.31,603.874 1127.31,603.873 1127.32,603.873 1127.33,603.873 1127.34,603.873 1127.35,603.873 1127.36,603.873 1127.37,603.873 1127.38,603.873 1127.39,603.873 1127.4,603.873 1127.41,603.873 1127.42,603.873 1127.43,603.873 1127.43,603.873 1127.44,603.872 1127.45,603.872 1127.46,603.872 1127.47,603.872 1127.48,603.872 1127.49,603.872 1127.5,603.872 1127.51,603.872 1127.52,603.872 1127.53,603.872 1127.54,603.872 1127.54,603.872 1127.55,603.872 1127.56,603.872 1127.57,603.872 1127.58,603.871 1127.59,603.871 1127.6,603.871 1127.61,603.871 1127.62,603.871 1127.63,603.871 1127.64,603.871 1127.65,603.871 1127.65,603.871 1127.66,603.871 1127.67,603.871 1127.68,603.871 1127.69,603.871 1127.7,603.871 1127.71,603.87 1127.72,603.87 1127.73,603.87 1127.74,603.87 1127.75,603.87 1127.76,603.87 1127.77,603.87 1127.77,603.87 1127.78,603.87 1127.79,603.87 1127.8,603.87 1127.81,603.87 1127.82,603.87 1127.83,603.87 1127.84,603.87 1127.85,603.869 1127.86,603.869 1127.87,603.869 1127.88,603.869 1127.88,603.869 1127.89,603.869 1127.9,603.869 1127.91,603.869 1127.92,603.869 1127.93,603.869 1127.94,603.869 1127.95,603.869 1127.96,603.869 1127.97,603.869 1127.98,603.868 1127.99,603.868 1127.99,603.868 1128,603.868 1128.01,603.868 1128.02,603.868 1128.03,603.868 1128.04,603.868 1128.05,603.868 1128.06,603.868 1128.07,603.868 1128.08,603.868 1128.09,603.868 1128.1,603.868 1128.11,603.868 1128.11,603.867 1128.12,603.867 1128.13,603.867 1128.14,603.867 1128.15,603.867 1128.16,603.867 1128.17,603.867 1128.18,603.867 1128.19,603.867 1128.2,603.867 1128.21,603.867 1128.22,603.867 1128.22,603.867 1128.23,603.867 1128.24,603.866 1128.25,603.866 1128.26,603.866 1128.27,603.866 1128.28,603.866 1128.29,603.866 1128.3,603.866 1128.31,603.866 1128.32,603.866 1128.33,603.866 1128.33,603.866 1128.34,603.866 1128.35,603.866 1128.36,603.866 1128.37,603.866 1128.38,603.865 1128.39,603.865 1128.4,603.865 1128.41,603.865 1128.42,603.865 1128.43,603.865 1128.44,603.865 1128.45,603.865 1128.45,603.865 1128.46,603.865 1128.47,603.865 1128.48,603.865 1128.49,603.865 1128.5,603.865 1128.51,603.864 1128.52,603.864 1128.53,603.864 1128.54,603.864 1128.55,603.864 1128.56,603.864 1128.56,603.864 1128.57,603.864 1128.58,603.864 1128.59,603.864 1128.6,603.864 1128.61,603.864 1128.62,603.864 1128.63,603.864 1128.64,603.864 1128.65,603.863 1128.66,603.863 1128.67,603.863 1128.67,603.863 1128.68,603.863 1128.69,603.863 1128.7,603.863 1128.71,603.863 1128.72,603.863 1128.73,603.863 1128.74,603.863 1128.75,603.863 1128.76,603.863 1128.77,603.863 1128.78,603.862 1128.79,603.862 1128.79,603.862 1128.8,603.862 1128.81,603.862 1128.82,603.862 1128.83,603.862 1128.84,603.862 1128.85,603.862 1128.86,603.862 1128.87,603.862 1128.88,603.862 1128.89,603.862 1128.9,603.862 1128.9,603.862 1128.91,603.861 1128.92,603.861 1128.93,603.861 1128.94,603.861 1128.95,603.861 1128.96,603.861 1128.97,603.861 1128.98,603.861 1128.99,603.861 1129,603.861 1129.01,603.861 1129.01,603.861 1129.02,603.861 1129.03,603.861 1129.04,603.86 1129.05,603.86 1129.06,603.86 1129.07,603.86 1129.08,603.86 1129.09,603.86 1129.1,603.86 1129.11,603.86 1129.12,603.86 1129.13,603.86 1129.13,603.86 1129.14,603.86 1129.15,603.86 1129.16,603.86 1129.17,603.86 1129.18,603.859 1129.19,603.859 1129.2,603.859 1129.21,603.859 1129.22,603.859 1129.23,603.859 1129.24,603.859 1129.24,603.859 1129.25,603.859 1129.26,603.859 1129.27,603.859 1129.28,603.859 1129.29,603.859 1129.3,603.859 1129.31,603.858 1129.32,603.858 1129.33,603.858 1129.34,603.858 1129.35,603.858 1129.35,603.858 1129.36,603.858 1129.37,603.858 1129.38,603.858 1129.39,603.858 1129.4,603.858 1129.41,603.858 1129.42,603.858 1129.43,603.858 1129.44,603.858 1129.45,603.857 1129.46,603.857 1129.47,603.857 1129.47,603.857 1129.48,603.857 1129.49,603.857 1129.5,603.857 1129.51,603.857 1129.52,603.857 1129.53,603.857 1129.54,603.857 1129.55,603.857 1129.56,603.857 1129.57,603.857 1129.58,603.856 1129.58,603.856 1129.59,603.856 1129.6,603.856 1129.61,603.856 1129.62,603.856 1129.63,603.856 1129.64,603.856 1129.65,603.856 1129.66,603.856 1129.67,603.856 1129.68,603.856 1129.69,603.856 1129.69,603.856 1129.7,603.856 1129.71,603.855 1129.72,603.855 1129.73,603.855 1129.74,603.855 1129.75,603.855 1129.76,603.855 1129.77,603.855 1129.78,603.855 1129.79,603.855 1129.8,603.855 1129.81,603.855 1129.81,603.855 1129.82,603.855 1129.83,603.855 1129.84,603.855 1129.85,603.854 1129.86,603.854 1129.87,603.854 1129.88,603.854 1129.89,603.854 1129.9,603.854 1129.91,603.854 1129.92,603.854 1129.92,603.854 1129.93,603.854 1129.94,603.854 1129.95,603.854 1129.96,603.854 1129.97,603.854 1129.98,603.853 1129.99,603.853 1130,603.853 1130.01,603.853 1130.02,603.853 1130.03,603.853 1130.03,603.853 1130.04,603.853 1130.05,603.853 1130.06,603.853 1130.07,603.853 1130.08,603.853 1130.09,603.853 1130.1,603.853 1130.11,603.853 1130.12,603.852 1130.13,603.852 1130.14,603.852 1130.15,603.852 1130.15,603.852 1130.16,603.852 1130.17,603.852 1130.18,603.852 1130.19,603.852 1130.2,603.852 1130.21,603.852 1130.22,603.852 1130.23,603.852 1130.24,603.852 1130.25,603.851 1130.26,603.851 1130.26,603.851 1130.27,603.851 1130.28,603.851 1130.29,603.851 1130.3,603.851 1130.31,603.851 1130.32,603.851 1130.33,603.851 1130.34,603.851 1130.35,603.851 1130.36,603.851 1130.37,603.851 1130.37,603.851 1130.38,603.85 1130.39,603.85 1130.4,603.85 1130.41,603.85 1130.42,603.85 1130.43,603.85 1130.44,603.85 1130.45,603.85 1130.46,603.85 1130.47,603.85 1130.48,603.85 1130.49,603.85 1130.49,603.85 1130.5,603.85 1130.51,603.849 1130.52,603.849 1130.53,603.849 1130.54,603.849 1130.55,603.849 1130.56,603.849 1130.57,603.849 1130.58,603.849 1130.59,603.849 1130.6,603.849 1130.6,603.849 1130.61,603.849 1130.62,603.849 1130.63,603.849 1130.64,603.849 1130.65,603.848 1130.66,603.848 1130.67,603.848 1130.68,603.848 1130.69,603.848 1130.7,603.848 1130.71,603.848 1130.71,603.848 1130.72,603.848 1130.73,603.848 1130.74,603.848 1130.75,603.848 1130.76,603.848 1130.77,603.848 1130.78,603.847 1130.79,603.847 1130.8,603.847 1130.81,603.847 1130.82,603.847 1130.83,603.847 1130.83,603.847 1130.84,603.847 1130.85,603.847 1130.86,603.847 1130.87,603.847 1130.88,603.847 1130.89,603.847 1130.9,603.847 1130.91,603.847 1130.92,603.846 1130.93,603.846 1130.94,603.846 1130.94,603.846 1130.95,603.846 1130.96,603.846 1130.97,603.846 1130.98,603.846 1130.99,603.846 1131,603.846 1131.01,603.846 1131.02,603.846 1131.03,603.846 1131.04,603.846 1131.05,603.846 1131.05,603.845 1131.06,603.845 1131.07,603.845 1131.08,603.845 1131.09,603.845 1131.1,603.845 1131.11,603.845 1131.12,603.845 1131.13,603.845 1131.14,603.845 1131.15,603.845 1131.16,603.845 1131.17,603.845 1131.17,603.845 1131.18,603.844 1131.19,603.844 1131.2,603.844 1131.21,603.844 1131.22,603.844 1131.23,603.844 1131.24,603.844 1131.25,603.844 1131.26,603.844 1131.27,603.844 1131.28,603.844 1131.28,603.844 1131.29,603.844 1131.3,603.844 1131.31,603.844 1131.32,603.843 1131.33,603.843 1131.34,603.843 1131.35,603.843 1131.36,603.843 1131.37,603.843 1131.38,603.843 1131.39,603.843 1131.39,603.843 1131.4,603.843 1131.41,603.843 1131.42,603.843 1131.43,603.843 1131.44,603.843 1131.45,603.842 1131.46,603.842 1131.47,603.842 1131.48,603.842 1131.49,603.842 1131.5,603.842 1131.51,603.842 1131.51,603.842 1131.52,603.842 1131.53,603.842 1131.54,603.842 1131.55,603.842 1131.56,603.842 1131.57,603.842 1131.58,603.842 1131.59,603.841 1131.6,603.841 1131.61,603.841 1131.62,603.841 1131.62,603.841 1131.63,603.841 1131.64,603.841 1131.65,603.841 1131.66,603.841 1131.67,603.841 1131.68,603.841 1131.69,603.841 1131.7,603.841 1131.71,603.841 1131.72,603.84 1131.73,603.84 1131.73,603.84 1131.74,603.84 1131.75,603.84 1131.76,603.84 1131.77,603.84 1131.78,603.84 1131.79,603.84 1131.8,603.84 1131.81,603.84 1131.82,603.84 1131.83,603.84 1131.84,603.84 1131.85,603.84 1131.85,603.839 1131.86,603.839 1131.87,603.839 1131.88,603.839 1131.89,603.839 1131.9,603.839 1131.91,603.839 1131.92,603.839 1131.93,603.839 1131.94,603.839 1131.95,603.839 1131.96,603.839 1131.96,603.839 1131.97,603.839 1131.98,603.839 1131.99,603.838 1132,603.838 1132.01,603.838 1132.02,603.838 1132.03,603.838 1132.04,603.838 1132.05,603.838 1132.06,603.838 1132.07,603.838 1132.07,603.838 1132.08,603.838 1132.09,603.838 1132.1,603.838 1132.11,603.838 1132.12,603.837 1132.13,603.837 1132.14,603.837 1132.15,603.837 1132.16,603.837 1132.17,603.837 1132.18,603.837 1132.19,603.837 1132.19,603.837 1132.2,603.837 1132.21,603.837 1132.22,603.837 1132.23,603.837 1132.24,603.837 1132.25,603.837 1132.26,603.836 1132.27,603.836 1132.28,603.836 1132.29,603.836 1132.3,603.836 1132.3,603.836 1132.31,603.836 1132.32,603.836 1132.33,603.836 1132.34,603.836 1132.35,603.836 1132.36,603.836 1132.37,603.836 1132.38,603.836 1132.39,603.835 1132.4,603.835 1132.41,603.835 1132.41,603.835 1132.42,603.835 1132.43,603.835 1132.44,603.835 1132.45,603.835 1132.46,603.835 1132.47,603.835 1132.48,603.835 1132.49,603.835 1132.5,603.835 1132.51,603.835 1132.52,603.835 1132.53,603.834 1132.53,603.834 1132.54,603.834 1132.55,603.834 1132.56,603.834 1132.57,603.834 1132.58,603.834 1132.59,603.834 1132.6,603.834 1132.61,603.834 1132.62,603.834 1132.63,603.834 1132.64,603.834 1132.64,603.834 1132.65,603.834 1132.66,603.833 1132.67,603.833 1132.68,603.833 1132.69,603.833 1132.7,603.833 1132.71,603.833 1132.72,603.833 1132.73,603.833 1132.74,603.833 1132.75,603.833 1132.75,603.833 1132.76,603.833 1132.77,603.833 1132.78,603.833 1132.79,603.832 1132.8,603.832 1132.81,603.832 1132.82,603.832 1132.83,603.832 1132.84,603.832 1132.85,603.832 1132.86,603.832 1132.87,603.832 1132.87,603.832 1132.88,603.832 1132.89,603.832 1132.9,603.832 1132.91,603.832 1132.92,603.832 1132.93,603.831 1132.94,603.831 1132.95,603.831 1132.96,603.831 1132.97,603.831 1132.98,603.831 1132.98,603.831 1132.99,603.831 1133,603.831 1133.01,603.831 1133.02,603.831 1133.03,603.831 1133.04,603.831 1133.05,603.831 1133.06,603.83 1133.07,603.83 1133.08,603.83 1133.09,603.83 1133.09,603.83 1133.1,603.83 1133.11,603.83 1133.12,603.83 1133.13,603.83 1133.14,603.83 1133.15,603.83 1133.16,603.83 1133.17,603.83 1133.18,603.83 1133.19,603.83 1133.2,603.829 1133.21,603.829 1133.21,603.829 1133.22,603.829 1133.23,603.829 1133.24,603.829 1133.25,603.829 1133.26,603.829 1133.27,603.829 1133.28,603.829 1133.29,603.829 1133.3,603.829 1133.31,603.829 1133.32,603.829 1133.32,603.829 1133.33,603.828 1133.34,603.828 1133.35,603.828 1133.36,603.828 1133.37,603.828 1133.38,603.828 1133.39,603.828 1133.4,603.828 1133.41,603.828 1133.42,603.828 1133.43,603.828 1133.43,603.828 1133.44,603.828 1133.45,603.828 1133.46,603.827 1133.47,603.827 1133.48,603.827 1133.49,603.827 1133.5,603.827 1133.51,603.827 1133.52,603.827 1133.53,603.827 1133.54,603.827 1133.55,603.827 1133.55,603.827 1133.56,603.827 1133.57,603.827 1133.58,603.827 1133.59,603.827 1133.6,603.826 1133.61,603.826 1133.62,603.826 1133.63,603.826 1133.64,603.826 1133.65,603.826 1133.66,603.826 1133.66,603.826 1133.67,603.826 1133.68,603.826 1133.69,603.826 1133.7,603.826 1133.71,603.826 1133.72,603.826 1133.73,603.826 1133.74,603.825 1133.75,603.825 1133.76,603.825 1133.77,603.825 1133.77,603.825 1133.78,603.825 1133.79,603.825 1133.8,603.825 1133.81,603.825 1133.82,603.825 1133.83,603.825 1133.84,603.825 1133.85,603.825 1133.86,603.825 1133.87,603.824 1133.88,603.824 1133.89,603.824 1133.89,603.824 1133.9,603.824 1133.91,603.824 1133.92,603.824 1133.93,603.824 1133.94,603.824 1133.95,603.824 1133.96,603.824 1133.97,603.824 1133.98,603.824 1133.99,603.824 1134,603.824 1134,603.823 1134.01,603.823 1134.02,603.823 1134.03,603.823 1134.04,603.823 1134.05,603.823 1134.06,603.823 1134.07,603.823 1134.08,603.823 1134.09,603.823 1134.1,603.823 1134.11,603.823 1134.11,603.823 1134.12,603.823 1134.13,603.822 1134.14,603.822 1134.15,603.822 1134.16,603.822 1134.17,603.822 1134.18,603.822 1134.19,603.822 1134.2,603.822 1134.21,603.822 1134.22,603.822 1134.23,603.822 1134.23,603.822 1134.24,603.822 1134.25,603.822 1134.26,603.822 1134.27,603.821 1134.28,603.821 1134.29,603.821 1134.3,603.821 1134.31,603.821 1134.32,603.821 1134.33,603.821 1134.34,603.821 1134.34,603.821 1134.35,603.821 1134.36,603.821 1134.37,603.821 1134.38,603.821 1134.39,603.821 1134.4,603.821 1134.41,603.82 1134.42,603.82 1134.43,603.82 1134.44,603.82 1134.45,603.82 1134.45,603.82 1134.46,603.82 1134.47,603.82 1134.48,603.82 1134.49,603.82 1134.5,603.82 1134.51,603.82 1134.52,603.82 1134.53,603.82 1134.54,603.819 1134.55,603.819 1134.56,603.819 1134.57,603.819 1134.57,603.819 1134.58,603.819 1134.59,603.819 1134.6,603.819 1134.61,603.819 1134.62,603.819 1134.63,603.819 1134.64,603.819 1134.65,603.819 1134.66,603.819 1134.67,603.819 1134.68,603.818 1134.68,603.818 1134.69,603.818 1134.7,603.818 1134.71,603.818 1134.72,603.818 1134.73,603.818 1134.74,603.818 1134.75,603.818 1134.76,603.818 1134.77,603.818 1134.78,603.818 1134.79,603.818 1134.79,603.818 1134.8,603.818 1134.81,603.817 1134.82,603.817 1134.83,603.817 1134.84,603.817 1134.85,603.817 1134.86,603.817 1134.87,603.817 1134.88,603.817 1134.89,603.817 1134.9,603.817 1134.91,603.817 1134.91,603.817 1134.92,603.817 1134.93,603.817 1134.94,603.816 1134.95,603.816 1134.96,603.816 1134.97,603.816 1134.98,603.816 1134.99,603.816 1135,603.816 1135.01,603.816 1135.02,603.816 1135.02,603.816 1135.03,603.816 1135.04,603.816 1135.05,603.816 1135.06,603.816 1135.07,603.816 1135.08,603.815 1135.09,603.815 1135.1,603.815 1135.11,603.815 1135.12,603.815 1135.13,603.815 1135.13,603.815 1135.14,603.815 1135.15,603.815 1135.16,603.815 1135.17,603.815 1135.18,603.815 1135.19,603.815 1135.2,603.815 1135.21,603.815 1135.22,603.814 1135.23,603.814 1135.24,603.814 1135.25,603.814 1135.25,603.814 1135.26,603.814 1135.27,603.814 1135.28,603.814 1135.29,603.814 1135.3,603.814 1135.31,603.814 1135.32,603.814 1135.33,603.814 1135.34,603.814 1135.35,603.813 1135.36,603.813 1135.36,603.813 1135.37,603.813 1135.38,603.813 1135.39,603.813 1135.4,603.813 1135.41,603.813 1135.42,603.813 1135.43,603.813 1135.44,603.813 1135.45,603.813 1135.46,603.813 1135.47,603.813 1135.47,603.813 1135.48,603.812 1135.49,603.812 1135.5,603.812 1135.51,603.812 1135.52,603.812 1135.53,603.812 1135.54,603.812 1135.55,603.812 1135.56,603.812 1135.57,603.812 1135.58,603.812 1135.59,603.812 1135.59,603.812 1135.6,603.812 1135.61,603.812 1135.62,603.811 1135.63,603.811 1135.64,603.811 1135.65,603.811 1135.66,603.811 1135.67,603.811 1135.68,603.811 1135.69,603.811 1135.7,603.811 1135.7,603.811 1135.71,603.811 1135.72,603.811 1135.73,603.811 1135.74,603.811 1135.75,603.81 1135.76,603.81 1135.77,603.81 1135.78,603.81 1135.79,603.81 1135.8,603.81 1135.81,603.81 1135.81,603.81 1135.82,603.81 1135.83,603.81 1135.84,603.81 1135.85,603.81 1135.86,603.81 1135.87,603.81 1135.88,603.81 1135.89,603.809 1135.9,603.809 1135.91,603.809 1135.92,603.809 1135.93,603.809 1135.93,603.809 1135.94,603.809 1135.95,603.809 1135.96,603.809 1135.97,603.809 1135.98,603.809 1135.99,603.809 1136,603.809 1136.01,603.809 1136.02,603.809 1136.03,603.808 1136.04,603.808 1136.04,603.808 1136.05,603.808 1136.06,603.808 1136.07,603.808 1136.08,603.808 1136.09,603.808 1136.1,603.808 1136.11,603.808 1136.12,603.808 1136.13,603.808 1136.14,603.808 1136.15,603.808 1136.15,603.807 1136.16,603.807 1136.17,603.807 1136.18,603.807 1136.19,603.807 1136.2,603.807 1136.21,603.807 1136.22,603.807 1136.23,603.807 1136.24,603.807 1136.25,603.807 1136.26,603.807 1136.27,603.807 1136.27,603.807 1136.28,603.807 1136.29,603.806 1136.3,603.806 1136.31,603.806 1136.32,603.806 1136.33,603.806 1136.34,603.806 1136.35,603.806 1136.36,603.806 1136.37,603.806 1136.38,603.806 1136.38,603.806 1136.39,603.806 1136.4,603.806 1136.41,603.806 1136.42,603.806 1136.43,603.805 1136.44,603.805 1136.45,603.805 1136.46,603.805 1136.47,603.805 1136.48,603.805 1136.49,603.805 1136.49,603.805 1136.5,603.805 1136.51,603.805 1136.52,603.805 1136.53,603.805 1136.54,603.805 1136.55,603.805 1136.56,603.805 1136.57,603.804 1136.58,603.804 1136.59,603.804 1136.6,603.804 1136.61,603.804 1136.61,603.804 1136.62,603.804 1136.63,603.804 1136.64,603.804 1136.65,603.804 1136.66,603.804 1136.67,603.804 1136.68,603.804 1136.69,603.804 1136.7,603.803 1136.71,603.803 1136.72,603.803 1136.72,603.803 1136.73,603.803 1136.74,603.803 1136.75,603.803 1136.76,603.803 1136.77,603.803 1136.78,603.803 1136.79,603.803 1136.8,603.803 1136.81,603.803 1136.82,603.803 1136.83,603.803 1136.83,603.802 1136.84,603.802 1136.85,603.802 1136.86,603.802 1136.87,603.802 1136.88,603.802 1136.89,603.802 1136.9,603.802 1136.91,603.802 1136.92,603.802 1136.93,603.802 1136.94,603.802 1136.95,603.802 1136.95,603.802 1136.96,603.802 1136.97,603.801 1136.98,603.801 1136.99,603.801 1137,603.801 1137.01,603.801 1137.02,603.801 1137.03,603.801 1137.04,603.801 1137.05,603.801 1137.06,603.801 1137.06,603.801 1137.07,603.801 1137.08,603.801 1137.09,603.801 1137.1,603.8 1137.11,603.8 1137.12,603.8 1137.13,603.8 1137.14,603.8 1137.15,603.8 1137.16,603.8 1137.17,603.8 1137.17,603.8 1137.18,603.8 1137.19,603.8 1137.2,603.8 1137.21,603.8 1137.22,603.8 1137.23,603.8 1137.24,603.799 1137.25,603.799 1137.26,603.799 1137.27,603.799 1137.28,603.799 1137.29,603.799 1137.29,603.799 1137.3,603.799 1137.31,603.799 1137.32,603.799 1137.33,603.799 1137.34,603.799 1137.35,603.799 1137.36,603.799 1137.37,603.799 1137.38,603.798 1137.39,603.798 1137.4,603.798 1137.4,603.798 1137.41,603.798 1137.42,603.798 1137.43,603.798 1137.44,603.798 1137.45,603.798 1137.46,603.798 1137.47,603.798 1137.48,603.798 1137.49,603.798 1137.5,603.798 1137.51,603.797 1137.51,603.797 1137.52,603.797 1137.53,603.797 1137.54,603.797 1137.55,603.797 1137.56,603.797 1137.57,603.797 1137.58,603.797 1137.59,603.797 1137.6,603.797 1137.61,603.797 1137.62,603.797 1137.63,603.797 1137.63,603.797 1137.64,603.796 1137.65,603.796 1137.66,603.796 1137.67,603.796 1137.68,603.796 1137.69,603.796 1137.7,603.796 1137.71,603.796 1137.72,603.796 1137.73,603.796 1137.74,603.796 1137.74,603.796 1137.75,603.796 1137.76,603.796 1137.77,603.796 1137.78,603.795 1137.79,603.795 1137.8,603.795 1137.81,603.795 1137.82,603.795 1137.83,603.795 1137.84,603.795 1137.85,603.795 1137.85,603.795 1137.86,603.795 1137.87,603.795 1137.88,603.795 1137.89,603.795 1137.9,603.795 1137.91,603.795 1137.92,603.794 1137.93,603.794 1137.94,603.794 1137.95,603.794 1137.96,603.794 1137.97,603.794 1137.97,603.794 1137.98,603.794 1137.99,603.794 1138,603.794 1138.01,603.794 1138.02,603.794 1138.03,603.794 1138.04,603.794 1138.05,603.793 1138.06,603.793 1138.07,603.793 1138.08,603.793 1138.08,603.793 1138.09,603.793 1138.1,603.793 1138.11,603.793 1138.12,603.793 1138.13,603.793 1138.14,603.793 1138.15,603.793 1138.16,603.793 1138.17,603.793 1138.18,603.793 1138.19,603.792 1138.19,603.792 1138.2,603.792 1138.21,603.792 1138.22,603.792 1138.23,603.792 1138.24,603.792 1138.25,603.792 1138.26,603.792 1138.27,603.792 1138.28,603.792 1138.29,603.792 1138.3,603.792 1138.31,603.792 1138.31,603.792 1138.32,603.791 1138.33,603.791 1138.34,603.791 1138.35,603.791 1138.36,603.791 1138.37,603.791 1138.38,603.791 1138.39,603.791 1138.4,603.791 1138.41,603.791 1138.42,603.791 1138.42,603.791 1138.43,603.791 1138.44,603.791 1138.45,603.791 1138.46,603.79 1138.47,603.79 1138.48,603.79 1138.49,603.79 1138.5,603.79 1138.51,603.79 1138.52,603.79 1138.53,603.79 1138.53,603.79 1138.54,603.79 1138.55,603.79 1138.56,603.79 1138.57,603.79 1138.58,603.79 1138.59,603.789 1138.6,603.789 1138.61,603.789 1138.62,603.789 1138.63,603.789 1138.64,603.789 1138.65,603.789 1138.65,603.789 1138.66,603.789 1138.67,603.789 1138.68,603.789 1138.69,603.789 1138.7,603.789 1138.71,603.789 1138.72,603.789 1138.73,603.788 1138.74,603.788 1138.75,603.788 1138.76,603.788 1138.76,603.788 1138.77,603.788 1138.78,603.788 1138.79,603.788 1138.8,603.788 1138.81,603.788 1138.82,603.788 1138.83,603.788 1138.84,603.788 1138.85,603.788 1138.86,603.788 1138.87,603.787 1138.87,603.787 1138.88,603.787 1138.89,603.787 1138.9,603.787 1138.91,603.787 1138.92,603.787 1138.93,603.787 1138.94,603.787 1138.95,603.787 1138.96,603.787 1138.97,603.787 1138.98,603.787 1138.99,603.787 1138.99,603.787 1139,603.786 1139.01,603.786 1139.02,603.786 1139.03,603.786 1139.04,603.786 1139.05,603.786 1139.06,603.786 1139.07,603.786 1139.08,603.786 1139.09,603.786 1139.1,603.786 1139.1,603.786 1139.11,603.786 1139.12,603.786 1139.13,603.785 1139.14,603.785 1139.15,603.785 1139.16,603.785 1139.17,603.785 1139.18,603.785 1139.19,603.785 1139.2,603.785 1139.21,603.785 1139.21,603.785 1139.22,603.785 1139.23,603.785 1139.24,603.785 1139.25,603.785 1139.26,603.785 1139.27,603.784 1139.28,603.784 1139.29,603.784 1139.3,603.784 1139.31,603.784 1139.32,603.784 1139.33,603.784 1139.33,603.784 1139.34,603.784 1139.35,603.784 1139.36,603.784 1139.37,603.784 1139.38,603.784 1139.39,603.784 1139.4,603.784 1139.41,603.783 1139.42,603.783 1139.43,603.783 1139.44,603.783 1139.44,603.783 1139.45,603.783 1139.46,603.783 1139.47,603.783 1139.48,603.783 1139.49,603.783 1139.5,603.783 1139.51,603.783 1139.52,603.783 1139.53,603.783 1139.54,603.783 1139.55,603.782 1139.55,603.782 1139.56,603.782 1139.57,603.782 1139.58,603.782 1139.59,603.782 1139.6,603.782 1139.61,603.782 1139.62,603.782 1139.63,603.782 1139.64,603.782 1139.65,603.782 1139.66,603.782 1139.67,603.782 1139.67,603.781 1139.68,603.781 1139.69,603.781 1139.7,603.781 1139.71,603.781 1139.72,603.781 1139.73,603.781 1139.74,603.781 1139.75,603.781 1139.76,603.781 1139.77,603.781 1139.78,603.781 1139.78,603.781 1139.79,603.781 1139.8,603.781 1139.81,603.78 1139.82,603.78 1139.83,603.78 1139.84,603.78 1139.85,603.78 1139.86,603.78 1139.87,603.78 1139.88,603.78 1139.89,603.78 1139.89,603.78 1139.9,603.78 1139.91,603.78 1139.92,603.78 1139.93,603.78 1139.94,603.78 1139.95,603.779 1139.96,603.779 1139.97,603.779 1139.98,603.779 1139.99,603.779 1140,603.779 1140.01,603.779 1140.01,603.779 1140.02,603.779 1140.03,603.779 1140.04,603.779 1140.05,603.779 1140.06,603.779 1140.07,603.779 1140.08,603.779 1140.09,603.778 1140.1,603.778 1140.11,603.778 1140.12,603.778 1140.12,603.778 1140.13,603.778 1140.14,603.778 1140.15,603.778 1140.16,603.778 1140.17,603.778 1140.18,603.778 1140.19,603.778 1140.2,603.778 1140.21,603.778 1140.22,603.777 1140.23,603.777 1140.23,603.777 1140.24,603.777 1140.25,603.777 1140.26,603.777 1140.27,603.777 1140.28,603.777 1140.29,603.777 1140.3,603.777 1140.31,603.777 1140.32,603.777 1140.33,603.777 1140.34,603.777 1140.35,603.777 1140.35,603.776 1140.36,603.776 1140.37,603.776 1140.38,603.776 1140.39,603.776 1140.4,603.776 1140.41,603.776 1140.42,603.776 1140.43,603.776 1140.44,603.776 1140.45,603.776 1140.46,603.776 1140.46,603.776 1140.47,603.776 1140.48,603.776 1140.49,603.775 1140.5,603.775 1140.51,603.775 1140.52,603.775 1140.53,603.775 1140.54,603.775 1140.55,603.775 1140.56,603.775 1140.57,603.775 1140.57,603.775 1140.58,603.775 1140.59,603.775 1140.6,603.775 1140.61,603.775 1140.62,603.775 1140.63,603.774 1140.64,603.774 1140.65,603.774 1140.66,603.774 1140.67,603.774 1140.68,603.774 1140.69,603.774 1140.69,603.774 1140.7,603.774 1140.71,603.774 1140.72,603.774 1140.73,603.774 1140.74,603.774 1140.75,603.774 1140.76,603.773 1140.77,603.773 1140.78,603.773 1140.79,603.773 1140.8,603.773 1140.8,603.773 1140.81,603.773 1140.82,603.773 1140.83,603.773 1140.84,603.773 1140.85,603.773 1140.86,603.773 1140.87,603.773 1140.88,603.773 1140.89,603.773 1140.9,603.772 1140.91,603.772 1140.91,603.772 1140.92,603.772 1140.93,603.772 1140.94,603.772 1140.95,603.772 1140.96,603.772 1140.97,603.772 1140.98,603.772 1140.99,603.772 1141,603.772 1141.01,603.772 1141.02,603.772 1141.03,603.772 1141.03,603.771 1141.04,603.771 1141.05,603.771 1141.06,603.771 1141.07,603.771 1141.08,603.771 1141.09,603.771 1141.1,603.771 1141.11,603.771 1141.12,603.771 1141.13,603.771 1141.14,603.771 1141.14,603.771 1141.15,603.771 1141.16,603.771 1141.17,603.77 1141.18,603.77 1141.19,603.77 1141.2,603.77 1141.21,603.77 1141.22,603.77 1141.23,603.77 1141.24,603.77 1141.25,603.77 1141.25,603.77 1141.26,603.77 1141.27,603.77 1141.28,603.77 1141.29,603.77 1141.3,603.77 1141.31,603.769 1141.32,603.769 1141.33,603.769 1141.34,603.769 1141.35,603.769 1141.36,603.769 1141.37,603.769 1141.37,603.769 1141.38,603.769 1141.39,603.769 1141.4,603.769 1141.41,603.769 1141.42,603.769 1141.43,603.769 1141.44,603.768 1141.45,603.768 1141.46,603.768 1141.47,603.768 1141.48,603.768 1141.48,603.768 1141.49,603.768 1141.5,603.768 1141.51,603.768 1141.52,603.768 1141.53,603.768 1141.54,603.768 1141.55,603.768 1141.56,603.768 1141.57,603.768 1141.58,603.767 1141.59,603.767 1141.59,603.767 1141.6,603.767 1141.61,603.767 1141.62,603.767 1141.63,603.767 1141.64,603.767 1141.65,603.767 1141.66,603.767 1141.67,603.767 1141.68,603.767 1141.69,603.767 1141.7,603.767 1141.71,603.767 1141.71,603.766 1141.72,603.766 1141.73,603.766 1141.74,603.766 1141.75,603.766 1141.76,603.766 1141.77,603.766 1141.78,603.766 1141.79,603.766 1141.8,603.766 1141.81,603.766 1141.82,603.766 1141.82,603.766 1141.83,603.766 1141.84,603.766 1141.85,603.765 1141.86,603.765 1141.87,603.765 1141.88,603.765 1141.89,603.765 1141.9,603.765 1141.91,603.765 1141.92,603.765 1141.93,603.765 1141.93,603.765 1141.94,603.765 1141.95,603.765 1141.96,603.765 1141.97,603.765 1141.98,603.765 1141.99,603.764 1142,603.764 1142.01,603.764 1142.02,603.764 1142.03,603.764 1142.04,603.764 1142.05,603.764 1142.05,603.764 1142.06,603.764 1142.07,603.764 1142.08,603.764 1142.09,603.764 1142.1,603.764 1142.11,603.764 1142.12,603.763 1142.13,603.763 1142.14,603.763 1142.15,603.763 1142.16,603.763 1142.16,603.763 1142.17,603.763 1142.18,603.763 1142.19,603.763 1142.2,603.763 1142.21,603.763 1142.22,603.763 1142.23,603.763 1142.24,603.763 1142.25,603.763 1142.26,603.762 1142.27,603.762 1142.27,603.762 1142.28,603.762 1142.29,603.762 1142.3,603.762 1142.31,603.762 1142.32,603.762 1142.33,603.762 1142.34,603.762 1142.35,603.762 1142.36,603.762 1142.37,603.762 1142.38,603.762 1142.39,603.762 1142.39,603.761 1142.4,603.761 1142.41,603.761 1142.42,603.761 1142.43,603.761 1142.44,603.761 1142.45,603.761 1142.46,603.761 1142.47,603.761 1142.48,603.761 1142.49,603.761 1142.5,603.761 1142.5,603.761 1142.51,603.761 1142.52,603.761 1142.53,603.76 1142.54,603.76 1142.55,603.76 1142.56,603.76 1142.57,603.76 1142.58,603.76 1142.59,603.76 1142.6,603.76 1142.61,603.76 1142.61,603.76 1142.62,603.76 1142.63,603.76 1142.64,603.76 1142.65,603.76 1142.66,603.76 1142.67,603.759 1142.68,603.759 1142.69,603.759 1142.7,603.759 1142.71,603.759 1142.72,603.759 1142.73,603.759 1142.73,603.759 1142.74,603.759 1142.75,603.759 1142.76,603.759 1142.77,603.759 1142.78,603.759 1142.79,603.759 1142.8,603.759 1142.81,603.758 1142.82,603.758 1142.83,603.758 1142.84,603.758 1142.84,603.758 1142.85,603.758 1142.86,603.758 1142.87,603.758 1142.88,603.758 1142.89,603.758 1142.9,603.758 1142.91,603.758 1142.92,603.758 1142.93,603.758 1142.94,603.757 1142.95,603.757 1142.95,603.757 1142.96,603.757 1142.97,603.757 1142.98,603.757 1142.99,603.757 1143,603.757 1143.01,603.757 1143.02,603.757 1143.03,603.757 1143.04,603.757 1143.05,603.757 1143.06,603.757 1143.07,603.757 1143.07,603.756 1143.08,603.756 1143.09,603.756 1143.1,603.756 1143.11,603.756 1143.12,603.756 1143.13,603.756 1143.14,603.756 1143.15,603.756 1143.16,603.756 1143.17,603.756 1143.18,603.756 1143.18,603.756 1143.19,603.756 1143.2,603.756 1143.21,603.755 1143.22,603.755 1143.23,603.755 1143.24,603.755 1143.25,603.755 1143.26,603.755 1143.27,603.755 1143.28,603.755 1143.29,603.755 1143.29,603.755 1143.3,603.755 1143.31,603.755 1143.32,603.755 1143.33,603.755 1143.34,603.755 1143.35,603.754 1143.36,603.754 1143.37,603.754 1143.38,603.754 1143.39,603.754 1143.4,603.754 1143.41,603.754 1143.41,603.754 1143.42,603.754 1143.43,603.754 1143.44,603.754 1143.45,603.754 1143.46,603.754 1143.47,603.754 1143.48,603.754 1143.49,603.753 1143.5,603.753 1143.51,603.753 1143.52,603.753 1143.52,603.753 1143.53,603.753 1143.54,603.753 1143.55,603.753 1143.56,603.753 1143.57,603.753 1143.58,603.753 1143.59,603.753 1143.6,603.753 1143.61,603.753 1143.62,603.753 1143.63,603.752 1143.63,603.752 1143.64,603.752 1143.65,603.752 1143.66,603.752 1143.67,603.752 1143.68,603.752 1143.69,603.752 1143.7,603.752 1143.71,603.752 1143.72,603.752 1143.73,603.752 1143.74,603.752 1143.75,603.752 1143.75,603.751 1143.76,603.751 1143.77,603.751 1143.78,603.751 1143.79,603.751 1143.8,603.751 1143.81,603.751 1143.82,603.751 1143.83,603.751 1143.84,603.751 1143.85,603.751 1143.86,603.751 1143.86,603.751 1143.87,603.751 1143.88,603.751 1143.89,603.75 1143.9,603.75 1143.91,603.75 1143.92,603.75 1143.93,603.75 1143.94,603.75 1143.95,603.75 1143.96,603.75 1143.97,603.75 1143.97,603.75 1143.98,603.75 1143.99,603.75 1144,603.75 1144.01,603.75 1144.02,603.75 1144.03,603.749 1144.04,603.749 1144.05,603.749 1144.06,603.749 1144.07,603.749 1144.08,603.749 1144.09,603.749 1144.09,603.749 1144.1,603.749 1144.11,603.749 1144.12,603.749 1144.13,603.749 1144.14,603.749 1144.15,603.749 1144.16,603.749 1144.17,603.748 1144.18,603.748 1144.19,603.748 1144.2,603.748 1144.2,603.748 1144.21,603.748 1144.22,603.748 1144.23,603.748 1144.24,603.748 1144.25,603.748 1144.26,603.748 1144.27,603.748 1144.28,603.748 1144.29,603.748 1144.3,603.748 1144.31,603.747 1144.31,603.747 1144.32,603.747 1144.33,603.747 1144.34,603.747 1144.35,603.747 1144.36,603.747 1144.37,603.747 1144.38,603.747 1144.39,603.747 1144.4,603.747 1144.41,603.747 1144.42,603.747 1144.43,603.747 1144.43,603.747 1144.44,603.746 1144.45,603.746 1144.46,603.746 1144.47,603.746 1144.48,603.746 1144.49,603.746 1144.5,603.746 1144.51,603.746 1144.52,603.746 1144.53,603.746 1144.54,603.746 1144.54,603.746 1144.55,603.746 1144.56,603.746 1144.57,603.746 1144.58,603.745 1144.59,603.745 1144.6,603.745 1144.61,603.745 1144.62,603.745 1144.63,603.745 1144.64,603.745 1144.65,603.745 1144.65,603.745 1144.66,603.745 1144.67,603.745 1144.68,603.745 1144.69,603.745 1144.7,603.745 1144.71,603.744 1144.72,603.744 1144.73,603.744 1144.74,603.744 1144.75,603.744 1144.76,603.744 1144.77,603.744 1144.77,603.744 1144.78,603.744 1144.79,603.744 1144.8,603.744 1144.81,603.744 1144.82,603.744 1144.83,603.744 1144.84,603.744 1144.85,603.743 1144.86,603.743 1144.87,603.743 1144.88,603.743 1144.88,603.743 1144.89,603.743 1144.9,603.743 1144.91,603.743 1144.92,603.743 1144.93,603.743 1144.94,603.743 1144.95,603.743 1144.96,603.743 1144.97,603.743 1144.98,603.743 1144.99,603.742 1144.99,603.742 1145,603.742 1145.01,603.742 1145.02,603.742 1145.03,603.742 1145.04,603.742 1145.05,603.742 1145.06,603.742 1145.07,603.742 1145.08,603.742 1145.09,603.742 1145.1,603.742 1145.11,603.742 1145.11,603.742 1145.12,603.741 1145.13,603.741 1145.14,603.741 1145.15,603.741 1145.16,603.741 1145.17,603.741 1145.18,603.741 1145.19,603.741 1145.2,603.741 1145.21,603.741 1145.22,603.741 1145.22,603.741 1145.23,603.741 1145.24,603.741 1145.25,603.741 1145.26,603.74 1145.27,603.74 1145.28,603.74 1145.29,603.74 1145.3,603.74 1145.31,603.74 1145.32,603.74 1145.33,603.74 1145.33,603.74 1145.34,603.74 1145.35,603.74 1145.36,603.74 1145.37,603.74 1145.38,603.74 1145.39,603.74 1145.4,603.739 1145.41,603.739 1145.42,603.739 1145.43,603.739 1145.44,603.739 1145.45,603.739 1145.45,603.739 1145.46,603.739 1145.47,603.739 1145.48,603.739 1145.49,603.739 1145.5,603.739 1145.51,603.739 1145.52,603.739 1145.53,603.739 1145.54,603.738 1145.55,603.738 1145.56,603.738 1145.56,603.738 1145.57,603.738 1145.58,603.738 1145.59,603.738 1145.6,603.738 1145.61,603.738 1145.62,603.738 1145.63,603.738 1145.64,603.738 1145.65,603.738 1145.66,603.738 1145.67,603.738 1145.67,603.737 1145.68,603.737 1145.69,603.737 1145.7,603.737 1145.71,603.737 1145.72,603.737 1145.73,603.737 1145.74,603.737 1145.75,603.737 1145.76,603.737 1145.77,603.737 1145.78,603.737 1145.79,603.737 1145.79,603.737 1145.8,603.737 1145.81,603.736 1145.82,603.736 1145.83,603.736 1145.84,603.736 1145.85,603.736 1145.86,603.736 1145.87,603.736 1145.88,603.736 1145.89,603.736 1145.9,603.736 1145.9,603.736 1145.91,603.736 1145.92,603.736 1145.93,603.736 1145.94,603.735 1145.95,603.735 1145.96,603.735 1145.97,603.735 1145.98,603.735 1145.99,603.735 1146,603.735 1146.01,603.735 1146.01,603.735 1146.02,603.735 1146.03,603.735 1146.04,603.735 1146.05,603.735 1146.06,603.735 1146.07,603.735 1146.08,603.734 1146.09,603.734 1146.1,603.734 1146.11,603.734 1146.12,603.734 1146.13,603.734 1146.13,603.734 1146.14,603.734 1146.15,603.734 1146.16,603.734 1146.17,603.734 1146.18,603.734 1146.19,603.734 1146.2,603.734 1146.21,603.734 1146.22,603.733 1146.23,603.733 1146.24,603.733 1146.24,603.733 1146.25,603.733 1146.26,603.733 1146.27,603.733 1146.28,603.733 1146.29,603.733 1146.3,603.733 1146.31,603.733 1146.32,603.733 1146.33,603.733 1146.34,603.733 1146.35,603.733 1146.36,603.732 1146.36,603.732 1146.37,603.732 1146.38,603.732 1146.39,603.732 1146.4,603.732 1146.41,603.732 1146.42,603.732 1146.43,603.732 1146.44,603.732 1146.45,603.732 1146.46,603.732 1146.47,603.732 1146.47,603.732 1146.48,603.732 1146.49,603.731 1146.5,603.731 1146.51,603.731 1146.52,603.731 1146.53,603.731 1146.54,603.731 1146.55,603.731 1146.56,603.731 1146.57,603.731 1146.58,603.731 1146.58,603.731 1146.59,603.731 1146.6,603.731 1146.61,603.731 1146.62,603.731 1146.63,603.73 1146.64,603.73 1146.65,603.73 1146.66,603.73 1146.67,603.73 1146.68,603.73 1146.69,603.73 1146.7,603.73 1146.7,603.73 1146.71,603.73 1146.72,603.73 1146.73,603.73 1146.74,603.73 1146.75,603.73 1146.76,603.73 1146.77,603.729 1146.78,603.729 1146.79,603.729 1146.8,603.729 1146.81,603.729 1146.81,603.729 1146.82,603.729 1146.83,603.729 1146.84,603.729 1146.85,603.729 1146.86,603.729 1146.87,603.729 1146.88,603.729 1146.89,603.729 1146.9,603.729 1146.91,603.728 1146.92,603.728 1146.92,603.728 1146.93,603.728 1146.94,603.728 1146.95,603.728 1146.96,603.728 1146.97,603.728 1146.98,603.728 1146.99,603.728 1147,603.728 1147.01,603.728 1147.02,603.728 1147.03,603.728 1147.04,603.728 1147.04,603.727 1147.05,603.727 1147.06,603.727 1147.07,603.727 1147.08,603.727 1147.09,603.727 1147.1,603.727 1147.11,603.727 1147.12,603.727 1147.13,603.727 1147.14,603.727 1147.15,603.727 1147.15,603.727 1147.16,603.727 1147.17,603.727 1147.18,603.726 1147.19,603.726 1147.2,603.726 1147.21,603.726 1147.22,603.726 1147.23,603.726 1147.24,603.726 1147.25,603.726 1147.26,603.726 1147.26,603.726 1147.27,603.726 1147.28,603.726 1147.29,603.726 1147.3,603.726 1147.31,603.726 1147.32,603.725 1147.33,603.725 1147.34,603.725 1147.35,603.725 1147.36,603.725 1147.37,603.725 1147.38,603.725 1147.38,603.725 1147.39,603.725 1147.4,603.725 1147.41,603.725 1147.42,603.725 1147.43,603.725 1147.44,603.725 1147.45,603.724 1147.46,603.724 1147.47,603.724 1147.48,603.724 1147.49,603.724 1147.49,603.724 1147.5,603.724 1147.51,603.724 1147.52,603.724 1147.53,603.724 1147.54,603.724 1147.55,603.724 1147.56,603.724 1147.57,603.724 1147.58,603.724 1147.59,603.723 1147.6,603.723 1147.6,603.723 1147.61,603.723 1147.62,603.723 1147.63,603.723 1147.64,603.723 1147.65,603.723 1147.66,603.723 1147.67,603.723 1147.68,603.723 1147.69,603.723 1147.7,603.723 1147.71,603.723 1147.72,603.723 1147.72,603.722 1147.73,603.722 1147.74,603.722 1147.75,603.722 1147.76,603.722 1147.77,603.722 1147.78,603.722 1147.79,603.722 1147.8,603.722 1147.81,603.722 1147.82,603.722 1147.83,603.722 1147.83,603.722 1147.84,603.722 1147.85,603.722 1147.86,603.721 1147.87,603.721 1147.88,603.721 1147.89,603.721 1147.9,603.721 1147.91,603.721 1147.92,603.721 1147.93,603.721 1147.94,603.721 1147.94,603.721 1147.95,603.721 1147.96,603.721 1147.97,603.721 1147.98,603.721 1147.99,603.721 1148,603.72 1148.01,603.72 1148.02,603.72 1148.03,603.72 1148.04,603.72 1148.05,603.72 1148.06,603.72 1148.06,603.72 1148.07,603.72 1148.08,603.72 1148.09,603.72 1148.1,603.72 1148.11,603.72 1148.12,603.72 1148.13,603.72 1148.14,603.719 1148.15,603.719 1148.16,603.719 1148.17,603.719 1148.17,603.719 1148.18,603.719 1148.19,603.719 1148.2,603.719 1148.21,603.719 1148.22,603.719 1148.23,603.719 1148.24,603.719 1148.25,603.719 1148.26,603.719 1148.27,603.719 1148.28,603.718 1148.28,603.718 1148.29,603.718 1148.3,603.718 1148.31,603.718 1148.32,603.718 1148.33,603.718 1148.34,603.718 1148.35,603.718 1148.36,603.718 1148.37,603.718 1148.38,603.718 1148.39,603.718 1148.4,603.718 1148.4,603.718 1148.41,603.717 1148.42,603.717 1148.43,603.717 1148.44,603.717 1148.45,603.717 1148.46,603.717 1148.47,603.717 1148.48,603.717 1148.49,603.717 1148.5,603.717 1148.51,603.717 1148.51,603.717 1148.52,603.717 1148.53,603.717 1148.54,603.717 1148.55,603.716 1148.56,603.716 1148.57,603.716 1148.58,603.716 1148.59,603.716 1148.6,603.716 1148.61,603.716 1148.62,603.716 1148.62,603.716 1148.63,603.716 1148.64,603.716 1148.65,603.716 1148.66,603.716 1148.67,603.716 1148.68,603.716 1148.69,603.715 1148.7,603.715 1148.71,603.715 1148.72,603.715 1148.73,603.715 1148.74,603.715 1148.74,603.715 1148.75,603.715 1148.76,603.715 1148.77,603.715 1148.78,603.715 1148.79,603.715 1148.8,603.715 1148.81,603.715 1148.82,603.715 1148.83,603.714 1148.84,603.714 1148.85,603.714 1148.85,603.714 1148.86,603.714 1148.87,603.714 1148.88,603.714 1148.89,603.714 1148.9,603.714 1148.91,603.714 1148.92,603.714 1148.93,603.714 1148.94,603.714 1148.95,603.714 1148.96,603.714 1148.96,603.713 1148.97,603.713 1148.98,603.713 1148.99,603.713 1149,603.713 1149.01,603.713 1149.02,603.713 1149.03,603.713 1149.04,603.713 1149.05,603.713 1149.06,603.713 1149.07,603.713 1149.08,603.713 1149.08,603.713 1149.09,603.713 1149.1,603.712 1149.11,603.712 1149.12,603.712 1149.13,603.712 1149.14,603.712 1149.15,603.712 1149.16,603.712 1149.17,603.712 1149.18,603.712 1149.19,603.712 1149.19,603.712 1149.2,603.712 1149.21,603.712 1149.22,603.712 1149.23,603.712 1149.24,603.711 1149.25,603.711 1149.26,603.711 1149.27,603.711 1149.28,603.711 1149.29,603.711 1149.3,603.711 1149.3,603.711 1149.31,603.711 1149.32,603.711 1149.33,603.711 1149.34,603.711 1149.35,603.711 1149.36,603.711 1149.37,603.711 1149.38,603.71 1149.39,603.71 1149.4,603.71 1149.41,603.71 1149.42,603.71 1149.42,603.71 1149.43,603.71 1149.44,603.71 1149.45,603.71 1149.46,603.71 1149.47,603.71 1149.48,603.71 1149.49,603.71 1149.5,603.71 1149.51,603.71 1149.52,603.709 1149.53,603.709 1149.53,603.709 1149.54,603.709 1149.55,603.709 1149.56,603.709 1149.57,603.709 1149.58,603.709 1149.59,603.709 1149.6,603.709 1149.61,603.709 1149.62,603.709 1149.63,603.709 1149.64,603.709 1149.64,603.709 1149.65,603.708 1149.66,603.708 1149.67,603.708 1149.68,603.708 1149.69,603.708 1149.7,603.708 1149.71,603.708 1149.72,603.708 1149.73,603.708 1149.74,603.708 1149.75,603.708 1149.76,603.708 1149.76,603.708 1149.77,603.708 1149.78,603.708 1149.79,603.707 1149.8,603.707 1149.81,603.707 1149.82,603.707 1149.83,603.707 1149.84,603.707 1149.85,603.707 1149.86,603.707 1149.87,603.707 1149.87,603.707 1149.88,603.707 1149.89,603.707 1149.9,603.707 1149.91,603.707 1149.92,603.707 1149.93,603.706 1149.94,603.706 1149.95,603.706 1149.96,603.706 1149.97,603.706 1149.98,603.706 1149.98,603.706 1149.99,603.706 1150,603.706 1150.01,603.706 1150.02,603.706 1150.03,603.706 1150.04,603.706 1150.05,603.706 1150.06,603.706 1150.07,603.705 1150.08,603.705 1150.09,603.705 1150.1,603.705 1150.1,603.705 1150.11,603.705 1150.12,603.705 1150.13,603.705 1150.14,603.705 1150.15,603.705 1150.16,603.705 1150.17,603.705 1150.18,603.705 1150.19,603.705 1150.2,603.705 1150.21,603.704 1150.21,603.704 1150.22,603.704 1150.23,603.704 1150.24,603.704 1150.25,603.704 1150.26,603.704 1150.27,603.704 1150.28,603.704 1150.29,603.704 1150.3,603.704 1150.31,603.704 1150.32,603.704 1150.32,603.704 1150.33,603.704 1150.34,603.703 1150.35,603.703 1150.36,603.703 1150.37,603.703 1150.38,603.703 1150.39,603.703 1150.4,603.703 1150.41,603.703 1150.42,603.703 1150.43,603.703 1150.44,603.703 1150.44,603.703 1150.45,603.703 1150.46,603.703 1150.47,603.703 1150.48,603.702 1150.49,603.702 1150.5,603.702 1150.51,603.702 1150.52,603.702 1150.53,603.702 1150.54,603.702 1150.55,603.702 1150.55,603.702 1150.56,603.702 1150.57,603.702 1150.58,603.702 1150.59,603.702 1150.6,603.702 1150.61,603.702 1150.62,603.701 1150.63,603.701 1150.64,603.701 1150.65,603.701 1150.66,603.701 1150.66,603.701 1150.67,603.701 1150.68,603.701 1150.69,603.701 1150.7,603.701 1150.71,603.701 1150.72,603.701 1150.73,603.701 1150.74,603.701 1150.75,603.701 1150.76,603.7 1150.77,603.7 1150.78,603.7 1150.78,603.7 1150.79,603.7 1150.8,603.7 1150.81,603.7 1150.82,603.7 1150.83,603.7 1150.84,603.7 1150.85,603.7 1150.86,603.7 1150.87,603.7 1150.88,603.7 1150.89,603.7 1150.89,603.699 1150.9,603.699 1150.91,603.699 1150.92,603.699 1150.93,603.699 1150.94,603.699 1150.95,603.699 1150.96,603.699 1150.97,603.699 1150.98,603.699 1150.99,603.699 1151,603.699 1151,603.699 1151.01,603.699 1151.02,603.698 1151.03,603.698 1151.04,603.698 1151.05,603.698 1151.06,603.698 1151.07,603.698 1151.08,603.698 1151.09,603.698 1151.1,603.698 1151.11,603.698 1151.12,603.698 1151.12,603.698 1151.13,603.698 1151.14,603.698 1151.15,603.698 1151.16,603.697 1151.17,603.697 1151.18,603.697 1151.19,603.697 1151.2,603.697 1151.21,603.697 1151.22,603.697 1151.23,603.697 1151.23,603.697 1151.24,603.697 1151.25,603.697 1151.26,603.697 1151.27,603.697 1151.28,603.697 1151.29,603.697 1151.3,603.697 1151.31,603.696 1151.32,603.696 1151.33,603.696 1151.34,603.696 1151.34,603.696 1151.35,603.696 1151.36,603.696 1151.37,603.696 1151.38,603.696 1151.39,603.696 1151.4,603.696 1151.41,603.696 1151.42,603.696 1151.43,603.696 1151.44,603.696 1151.45,603.695 1151.46,603.695 1151.46,603.695 1151.47,603.695 1151.48,603.695 1151.49,603.695 1151.5,603.695 1151.51,603.695 1151.52,603.695 1151.53,603.695 1151.54,603.695 1151.55,603.695 1151.56,603.695 1151.57,603.695 1151.57,603.695 1151.58,603.694 1151.59,603.694 1151.6,603.694 1151.61,603.694 1151.62,603.694 1151.63,603.694 1151.64,603.694 1151.65,603.694 1151.66,603.694 1151.67,603.694 1151.68,603.694 1151.68,603.694 1151.69,603.694 1151.7,603.694 1151.71,603.694 1151.72,603.693 1151.73,603.693 1151.74,603.693 1151.75,603.693 1151.76,603.693 1151.77,603.693 1151.78,603.693 1151.79,603.693 1151.8,603.693 1151.8,603.693 1151.81,603.693 1151.82,603.693 1151.83,603.693 1151.84,603.693 1151.85,603.693 1151.86,603.692 1151.87,603.692 1151.88,603.692 1151.89,603.692 1151.9,603.692 1151.91,603.692 1151.91,603.692 1151.92,603.692 1151.93,603.692 1151.94,603.692 1151.95,603.692 1151.96,603.692 1151.97,603.692 1151.98,603.692 1151.99,603.692 1152,603.691 1152.01,603.691 1152.02,603.691 1152.02,603.691 1152.03,603.691 1152.04,603.691 1152.05,603.691 1152.06,603.691 1152.07,603.691 1152.08,603.691 1152.09,603.691 1152.1,603.691 1152.11,603.691 1152.12,603.691 1152.13,603.691 1152.14,603.69 1152.14,603.69 1152.15,603.69 1152.16,603.69 1152.17,603.69 1152.18,603.69 1152.19,603.69 1152.2,603.69 1152.21,603.69 1152.22,603.69 1152.23,603.69 1152.24,603.69 1152.25,603.69 1152.25,603.69 1152.26,603.69 1152.27,603.689 1152.28,603.689 1152.29,603.689 1152.3,603.689 1152.31,603.689 1152.32,603.689 1152.33,603.689 1152.34,603.689 1152.35,603.689 1152.36,603.689 1152.36,603.689 1152.37,603.689 1152.38,603.689 1152.39,603.689 1152.4,603.689 1152.41,603.688 1152.42,603.688 1152.43,603.688 1152.44,603.688 1152.45,603.688 1152.46,603.688 1152.47,603.688 1152.48,603.688 1152.48,603.688 1152.49,603.688 1152.5,603.688 1152.51,603.688 1152.52,603.688 1152.53,603.688 1152.54,603.688 1152.55,603.687 1152.56,603.687 1152.57,603.687 1152.58,603.687 1152.59,603.687 1152.59,603.687 1152.6,603.687 1152.61,603.687 1152.62,603.687 1152.63,603.687 1152.64,603.687 1152.65,603.687 1152.66,603.687 1152.67,603.687 1152.68,603.687 1152.69,603.686 1152.7,603.686 1152.7,603.686 1152.71,603.686 1152.72,603.686 1152.73,603.686 1152.74,603.686 1152.75,603.686 1152.76,603.686 1152.77,603.686 1152.78,603.686 1152.79,603.686 1152.8,603.686 1152.81,603.686 1152.82,603.686 1152.82,603.685 1152.83,603.685 1152.84,603.685 1152.85,603.685 1152.86,603.685 1152.87,603.685 1152.88,603.685 1152.89,603.685 1152.9,603.685 1152.91,603.685 1152.92,603.685 1152.93,603.685 1152.93,603.685 1152.94,603.685 1152.95,603.685 1152.96,603.684 1152.97,603.684 1152.98,603.684 1152.99,603.684 1153,603.684 1153.01,603.684 1153.02,603.684 1153.03,603.684 1153.04,603.684 1153.04,603.684 1153.05,603.684 1153.06,603.684 1153.07,603.684 1153.08,603.684 1153.09,603.684 1153.1,603.683 1153.11,603.683 1153.12,603.683 1153.13,603.683 1153.14,603.683 1153.15,603.683 1153.16,603.683 1153.16,603.683 1153.17,603.683 1153.18,603.683 1153.19,603.683 1153.2,603.683 1153.21,603.683 1153.22,603.683 1153.23,603.683 1153.24,603.682 1153.25,603.682 1153.26,603.682 1153.27,603.682 1153.27,603.682 1153.28,603.682 1153.29,603.682 1153.3,603.682 1153.31,603.682 1153.32,603.682 1153.33,603.682 1153.34,603.682 1153.35,603.682 1153.36,603.682 1153.37,603.682 1153.38,603.681 1153.38,603.681 1153.39,603.681 1153.4,603.681 1153.41,603.681 1153.42,603.681 1153.43,603.681 1153.44,603.681 1153.45,603.681 1153.46,603.681 1153.47,603.681 1153.48,603.681 1153.49,603.681 1153.5,603.681 1153.5,603.681 1153.51,603.68 1153.52,603.68 1153.53,603.68 1153.54,603.68 1153.55,603.68 1153.56,603.68 1153.57,603.68 1153.58,603.68 1153.59,603.68 1153.6,603.68 1153.61,603.68 1153.61,603.68 1153.62,603.68 1153.63,603.68 1153.64,603.68 1153.65,603.679 1153.66,603.679 1153.67,603.679 1153.68,603.679 1153.69,603.679 1153.7,603.679 1153.71,603.679 1153.72,603.679 1153.72,603.679 1153.73,603.679 1153.74,603.679 1153.75,603.679 1153.76,603.679 1153.77,603.679 1153.78,603.679 1153.79,603.678 1153.8,603.678 1153.81,603.678 1153.82,603.678 1153.83,603.678 1153.84,603.678 1153.84,603.678 1153.85,603.678 1153.86,603.678 1153.87,603.678 1153.88,603.678 1153.89,603.678 1153.9,603.678 1153.91,603.678 1153.92,603.678 1153.93,603.677 1153.94,603.677 1153.95,603.677 1153.95,603.677 1153.96,603.677 1153.97,603.677 1153.98,603.677 1153.99,603.677 1154,603.677 1154.01,603.677 1154.02,603.677 1154.03,603.677 1154.04,603.677 1154.05,603.677 1154.06,603.677 1154.06,603.676 1154.07,603.676 1154.08,603.676 1154.09,603.676 1154.1,603.676 1154.11,603.676 1154.12,603.676 1154.13,603.676 1154.14,603.676 1154.15,603.676 1154.16,603.676 1154.17,603.676 1154.18,603.676 1154.18,603.676 1154.19,603.676 1154.2,603.675 "/>
<polyline clip-path="url(#clip402)" style="stroke:#e26f46; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,245.157 235.292,245.159 235.301,245.162 235.31,245.164 235.32,245.167 235.329,245.169 235.338,245.171 235.347,245.174 235.356,245.176 235.366,245.179 235.375,245.181 235.384,245.183 235.393,245.186 235.402,245.188 235.412,245.191 235.421,245.193 235.43,245.196 235.439,245.198 235.448,245.2 235.457,245.203 235.467,245.205 235.476,245.208 235.485,245.21 235.494,245.212 235.503,245.215 235.513,245.217 235.522,245.22 235.531,245.222 235.54,245.225 235.549,245.227 235.559,245.229 235.568,245.232 235.577,245.234 235.586,245.237 235.595,245.239 235.604,245.242 235.614,245.244 235.623,245.246 235.632,245.249 235.641,245.251 235.65,245.254 235.66,245.256 235.669,245.258 235.678,245.261 235.687,245.263 235.696,245.266 235.706,245.268 235.715,245.271 235.724,245.273 235.733,245.275 235.742,245.278 235.752,245.28 235.761,245.283 235.77,245.285 235.779,245.287 235.788,245.29 235.797,245.292 235.807,245.295 235.816,245.297 235.825,245.3 235.834,245.302 235.843,245.304 235.853,245.307 235.862,245.309 235.871,245.312 235.88,245.314 235.889,245.316 235.899,245.319 235.908,245.321 235.917,245.324 235.926,245.326 235.935,245.329 235.944,245.331 235.954,245.333 235.963,245.336 235.972,245.338 235.981,245.341 235.99,245.343 236,245.345 236.009,245.348 236.018,245.35 236.027,245.353 236.036,245.355 236.046,245.358 236.055,245.36 236.064,245.362 236.073,245.365 236.082,245.367 236.092,245.37 236.101,245.372 236.11,245.375 236.119,245.377 236.128,245.379 236.137,245.382 236.147,245.384 236.156,245.387 236.165,245.389 236.174,245.391 236.183,245.394 236.193,245.396 236.202,245.399 236.211,245.401 236.22,245.404 236.229,245.406 236.239,245.408 236.248,245.411 236.257,245.413 236.266,245.416 236.275,245.418 236.284,245.42 236.294,245.423 236.303,245.425 236.312,245.428 236.321,245.43 236.33,245.433 236.34,245.435 236.349,245.437 236.358,245.44 236.367,245.442 236.376,245.445 236.386,245.447 236.395,245.449 236.404,245.452 236.413,245.454 236.422,245.457 236.432,245.459 236.441,245.462 236.45,245.464 236.459,245.466 236.468,245.469 236.477,245.471 236.487,245.474 236.496,245.476 236.505,245.478 236.514,245.481 236.523,245.483 236.533,245.486 236.542,245.488 236.551,245.491 236.56,245.493 236.569,245.495 236.579,245.498 236.588,245.5 236.597,245.503 236.606,245.505 236.615,245.507 236.624,245.51 236.634,245.512 236.643,245.515 236.652,245.517 236.661,245.52 236.67,245.522 236.68,245.524 236.689,245.527 236.698,245.529 236.707,245.532 236.716,245.534 236.726,245.536 236.735,245.539 236.744,245.541 236.753,245.544 236.762,245.546 236.772,245.549 236.781,245.551 236.79,245.553 236.799,245.556 236.808,245.558 236.817,245.561 236.827,245.563 236.836,245.565 236.845,245.568 236.854,245.57 236.863,245.573 236.873,245.575 236.882,245.578 236.891,245.58 236.9,245.582 236.909,245.585 236.919,245.587 236.928,245.59 236.937,245.592 236.946,245.594 236.955,245.597 236.964,245.599 236.974,245.602 236.983,245.604 236.992,245.606 237.001,245.609 237.01,245.611 237.02,245.614 237.029,245.616 237.038,245.619 237.047,245.621 237.056,245.623 237.066,245.626 237.075,245.628 237.084,245.631 237.093,245.633 237.102,245.635 237.112,245.638 237.121,245.64 237.13,245.643 237.139,245.645 237.148,245.648 237.157,245.65 237.167,245.652 237.176,245.655 237.185,245.657 237.194,245.66 237.203,245.662 237.213,245.664 237.222,245.667 237.231,245.669 237.24,245.672 237.249,245.674 237.259,245.677 237.268,245.679 237.277,245.681 237.286,245.684 237.295,245.686 237.304,245.689 237.314,245.691 237.323,245.693 237.332,245.696 237.341,245.698 237.35,245.701 237.36,245.703 237.369,245.706 237.378,245.708 237.387,245.71 237.396,245.713 237.406,245.715 237.415,245.718 237.424,245.72 237.433,245.722 237.442,245.725 237.452,245.727 237.461,245.73 237.47,245.732 237.479,245.735 237.488,245.737 237.497,245.739 237.507,245.742 237.516,245.744 237.525,245.747 237.534,245.749 237.543,245.751 237.553,245.754 237.562,245.756 237.571,245.759 237.58,245.761 237.589,245.763 237.599,245.766 237.608,245.768 237.617,245.771 237.626,245.773 237.635,245.776 237.644,245.778 237.654,245.78 237.663,245.783 237.672,245.785 237.681,245.788 237.69,245.79 237.7,245.792 237.709,245.795 237.718,245.797 237.727,245.8 237.736,245.802 237.746,245.805 237.755,245.807 237.764,245.809 237.773,245.812 237.782,245.814 237.792,245.817 237.801,245.819 237.81,245.821 237.819,245.824 237.828,245.826 237.837,245.829 237.847,245.831 237.856,245.833 237.865,245.836 237.874,245.838 237.883,245.841 237.893,245.843 237.902,245.846 237.911,245.848 237.92,245.85 237.929,245.853 237.939,245.855 237.948,245.858 237.957,245.86 237.966,245.862 237.975,245.865 237.985,245.867 237.994,245.87 238.003,245.872 238.012,245.875 238.021,245.877 238.03,245.879 238.04,245.882 238.049,245.884 238.058,245.887 238.067,245.889 238.076,245.891 238.086,245.894 238.095,245.896 238.104,245.899 238.113,245.901 238.122,245.903 238.132,245.906 238.141,245.908 238.15,245.911 238.159,245.913 238.168,245.916 238.177,245.918 238.187,245.92 238.196,245.923 238.205,245.925 238.214,245.928 238.223,245.93 238.233,245.932 238.242,245.935 238.251,245.937 238.26,245.94 238.269,245.942 238.279,245.945 238.288,245.947 238.297,245.949 238.306,245.952 238.315,245.954 238.325,245.957 238.334,245.959 238.343,245.961 238.352,245.964 238.361,245.966 238.37,245.969 238.38,245.971 238.389,245.973 238.398,245.976 238.407,245.978 238.416,245.981 238.426,245.983 238.435,245.986 238.444,245.988 238.453,245.99 238.462,245.993 238.472,245.995 238.481,245.998 238.49,246 238.499,246.002 238.508,246.005 238.517,246.007 238.527,246.01 238.536,246.012 238.545,246.015 238.554,246.017 238.563,246.019 238.573,246.022 238.582,246.024 238.591,246.027 238.6,246.029 238.609,246.031 238.619,246.034 238.628,246.036 238.637,246.039 238.646,246.041 238.655,246.043 238.665,246.046 238.674,246.048 238.683,246.051 238.692,246.053 238.701,246.056 238.71,246.058 238.72,246.06 238.729,246.063 238.738,246.065 238.747,246.068 238.756,246.07 238.766,246.072 238.775,246.075 238.784,246.077 238.793,246.08 238.802,246.082 238.812,246.084 238.821,246.087 238.83,246.089 238.839,246.092 238.848,246.094 238.857,246.097 238.867,246.099 238.876,246.101 238.885,246.104 238.894,246.106 238.903,246.109 238.913,246.111 238.922,246.113 238.931,246.116 238.94,246.118 238.949,246.121 238.959,246.123 238.968,246.125 238.977,246.128 238.986,246.13 238.995,246.133 239.005,246.135 239.014,246.138 239.023,246.14 239.032,246.142 239.041,246.145 239.05,246.147 239.06,246.15 239.069,246.152 239.078,246.154 239.087,246.157 239.096,246.159 239.106,246.162 239.115,246.164 239.124,246.166 239.133,246.169 239.142,246.171 239.152,246.174 239.161,246.176 239.17,246.179 239.179,246.181 239.188,246.183 239.197,246.186 239.207,246.188 239.216,246.191 239.225,246.193 239.234,246.195 239.243,246.198 239.253,246.2 239.262,246.203 239.271,246.205 239.28,246.207 239.289,246.21 239.299,246.212 239.308,246.215 239.317,246.217 239.326,246.22 239.335,246.222 239.345,246.224 239.354,246.227 239.363,246.229 239.372,246.232 239.381,246.234 239.39,246.236 239.4,246.239 239.409,246.241 239.418,246.244 239.427,246.246 239.436,246.248 239.446,246.251 239.455,246.253 239.464,246.256 239.473,246.258 239.482,246.261 239.492,246.263 239.501,246.265 239.51,246.268 239.519,246.27 239.528,246.273 239.537,246.275 239.547,246.277 239.556,246.28 239.565,246.282 239.574,246.285 239.583,246.287 239.593,246.289 239.602,246.292 239.611,246.294 239.62,246.297 239.629,246.299 239.639,246.301 239.648,246.304 239.657,246.306 239.666,246.309 239.675,246.311 239.685,246.314 239.694,246.316 239.703,246.318 239.712,246.321 239.721,246.323 239.73,246.326 239.74,246.328 239.749,246.33 239.758,246.333 239.767,246.335 239.776,246.338 239.786,246.34 239.795,246.342 239.804,246.345 239.813,246.347 239.822,246.35 239.832,246.352 239.841,246.355 239.85,246.357 239.859,246.359 239.868,246.362 239.877,246.364 239.887,246.367 239.896,246.369 239.905,246.371 239.914,246.374 239.923,246.376 239.933,246.379 239.942,246.381 239.951,246.383 239.96,246.386 239.969,246.388 239.979,246.391 239.988,246.393 239.997,246.395 240.006,246.398 240.015,246.4 240.025,246.403 240.034,246.405 240.043,246.408 240.052,246.41 240.061,246.412 240.07,246.415 240.08,246.417 240.089,246.42 240.098,246.422 240.107,246.424 240.116,246.427 240.126,246.429 240.135,246.432 240.144,246.434 240.153,246.436 240.162,246.439 240.172,246.441 240.181,246.444 240.19,246.446 240.199,246.448 240.208,246.451 240.217,246.453 240.227,246.456 240.236,246.458 240.245,246.461 240.254,246.463 240.263,246.465 240.273,246.468 240.282,246.47 240.291,246.473 240.3,246.475 240.309,246.477 240.319,246.48 240.328,246.482 240.337,246.485 240.346,246.487 240.355,246.489 240.365,246.492 240.374,246.494 240.383,246.497 240.392,246.499 240.401,246.502 240.41,246.504 240.42,246.506 240.429,246.509 240.438,246.511 240.447,246.514 240.456,246.516 240.466,246.518 240.475,246.521 240.484,246.523 240.493,246.526 240.502,246.528 240.512,246.53 240.521,246.533 240.53,246.535 240.539,246.538 240.548,246.54 240.558,246.542 240.567,246.545 240.576,246.547 240.585,246.55 240.594,246.552 240.603,246.554 240.613,246.557 240.622,246.559 240.631,246.562 240.64,246.564 240.649,246.567 240.659,246.569 240.668,246.571 240.677,246.574 240.686,246.576 240.695,246.579 240.705,246.581 240.714,246.583 240.723,246.586 240.732,246.588 240.741,246.591 240.75,246.593 240.76,246.595 240.769,246.598 240.778,246.6 240.787,246.603 240.796,246.605 240.806,246.607 240.815,246.61 240.824,246.612 240.833,246.615 240.842,246.617 240.852,246.62 240.861,246.622 240.87,246.624 240.879,246.627 240.888,246.629 240.898,246.632 240.907,246.634 240.916,246.636 240.925,246.639 240.934,246.641 240.943,246.644 240.953,246.646 240.962,246.648 240.971,246.651 240.98,246.653 240.989,246.656 240.999,246.658 241.008,246.66 241.017,246.663 241.026,246.665 241.035,246.668 241.045,246.67 241.054,246.672 241.063,246.675 241.072,246.677 241.081,246.68 241.09,246.682 241.1,246.685 241.109,246.687 241.118,246.689 241.127,246.692 241.136,246.694 241.146,246.697 241.155,246.699 241.164,246.701 241.173,246.704 241.182,246.706 241.192,246.709 241.201,246.711 241.21,246.713 241.219,246.716 241.228,246.718 241.238,246.721 241.247,246.723 241.256,246.725 241.265,246.728 241.274,246.73 241.283,246.733 241.293,246.735 241.302,246.738 241.311,246.74 241.32,246.742 241.329,246.745 241.339,246.747 241.348,246.75 241.357,246.752 241.366,246.754 241.375,246.757 241.385,246.759 241.394,246.762 241.403,246.764 241.412,246.766 241.421,246.769 241.43,246.771 241.44,246.774 241.449,246.776 241.458,246.778 241.467,246.781 241.476,246.783 241.486,246.786 241.495,246.788 241.504,246.79 241.513,246.793 241.522,246.795 241.532,246.798 241.541,246.8 241.55,246.802 241.559,246.805 241.568,246.807 241.578,246.81 241.587,246.812 241.596,246.815 241.605,246.817 241.614,246.819 241.623,246.822 241.633,246.824 241.642,246.827 241.651,246.829 241.66,246.831 241.669,246.834 241.679,246.836 241.688,246.839 241.697,246.841 241.706,246.843 241.715,246.846 241.725,246.848 241.734,246.851 241.743,246.853 241.752,246.855 241.761,246.858 241.77,246.86 241.78,246.863 241.789,246.865 241.798,246.867 241.807,246.87 241.816,246.872 241.826,246.875 241.835,246.877 241.844,246.88 241.853,246.882 241.862,246.884 241.872,246.887 241.881,246.889 241.89,246.892 241.899,246.894 241.908,246.896 241.918,246.899 241.927,246.901 241.936,246.904 241.945,246.906 241.954,246.908 241.963,246.911 241.973,246.913 241.982,246.916 241.991,246.918 242,246.92 242.009,246.923 242.019,246.925 242.028,246.928 242.037,246.93 242.046,246.932 242.055,246.935 242.065,246.937 242.074,246.94 242.083,246.942 242.092,246.944 242.101,246.947 242.11,246.949 242.12,246.952 242.129,246.954 242.138,246.956 242.147,246.959 242.156,246.961 242.166,246.964 242.175,246.966 242.184,246.969 242.193,246.971 242.202,246.973 242.212,246.976 242.221,246.978 242.23,246.981 242.239,246.983 242.248,246.985 242.258,246.988 242.267,246.99 242.276,246.993 242.285,246.995 242.294,246.997 242.303,247 242.313,247.002 242.322,247.005 242.331,247.007 242.34,247.009 242.349,247.012 242.359,247.014 242.368,247.017 242.377,247.019 242.386,247.021 242.395,247.024 242.405,247.026 242.414,247.029 242.423,247.031 242.432,247.033 242.441,247.036 242.45,247.038 242.46,247.041 242.469,247.043 242.478,247.045 242.487,247.048 242.496,247.05 242.506,247.053 242.515,247.055 242.524,247.058 242.533,247.06 242.542,247.062 242.552,247.065 242.561,247.067 242.57,247.07 242.579,247.072 242.588,247.074 242.598,247.077 242.607,247.079 242.616,247.082 242.625,247.084 242.634,247.086 242.643,247.089 242.653,247.091 242.662,247.094 242.671,247.096 242.68,247.098 242.689,247.101 242.699,247.103 242.708,247.106 242.717,247.108 242.726,247.11 242.735,247.113 242.745,247.115 242.754,247.118 242.763,247.12 242.772,247.122 242.781,247.125 242.79,247.127 242.8,247.13 242.809,247.132 242.818,247.134 242.827,247.137 242.836,247.139 242.846,247.142 242.855,247.144 242.864,247.146 242.873,247.149 242.882,247.151 242.892,247.154 242.901,247.156 242.91,247.159 242.919,247.161 242.928,247.163 242.938,247.166 242.947,247.168 242.956,247.171 242.965,247.173 242.974,247.175 242.983,247.178 242.993,247.18 243.002,247.183 243.011,247.185 243.02,247.187 243.029,247.19 243.039,247.192 243.048,247.195 243.057,247.197 243.066,247.199 243.075,247.202 243.085,247.204 243.094,247.207 243.103,247.209 243.112,247.211 243.121,247.214 243.131,247.216 243.14,247.219 243.149,247.221 243.158,247.223 243.167,247.226 243.176,247.228 243.186,247.231 243.195,247.233 243.204,247.235 243.213,247.238 243.222,247.24 243.232,247.243 243.241,247.245 243.25,247.247 243.259,247.25 243.268,247.252 243.278,247.255 243.287,247.257 243.296,247.259 243.305,247.262 243.314,247.264 243.323,247.267 243.333,247.269 243.342,247.271 243.351,247.274 243.36,247.276 243.369,247.279 243.379,247.281 243.388,247.283 243.397,247.286 243.406,247.288 243.415,247.291 243.425,247.293 243.434,247.296 243.443,247.298 243.452,247.3 243.461,247.303 243.471,247.305 243.48,247.308 243.489,247.31 243.498,247.312 243.507,247.315 243.516,247.317 243.526,247.32 243.535,247.322 243.544,247.324 243.553,247.327 243.562,247.329 243.572,247.332 243.581,247.334 243.59,247.336 243.599,247.339 243.608,247.341 243.618,247.344 243.627,247.346 243.636,247.348 243.645,247.351 243.654,247.353 243.663,247.356 243.673,247.358 243.682,247.36 243.691,247.363 243.7,247.365 243.709,247.368 243.719,247.37 243.728,247.372 243.737,247.375 243.746,247.377 243.755,247.38 243.765,247.382 243.774,247.384 243.783,247.387 243.792,247.389 243.801,247.392 243.811,247.394 243.82,247.396 243.829,247.399 243.838,247.401 243.847,247.404 243.856,247.406 243.866,247.408 243.875,247.411 243.884,247.413 243.893,247.416 243.902,247.418 243.912,247.42 243.921,247.423 243.93,247.425 243.939,247.428 243.948,247.43 243.958,247.432 243.967,247.435 243.976,247.437 243.985,247.44 243.994,247.442 244.003,247.444 244.013,247.447 244.022,247.449 244.031,247.452 244.04,247.454 244.049,247.456 244.059,247.459 244.068,247.461 244.077,247.464 244.086,247.466 244.095,247.468 244.105,247.471 244.114,247.473 244.123,247.476 244.132,247.478 244.141,247.48 244.151,247.483 244.16,247.485 244.169,247.488 244.178,247.49 244.187,247.493 244.196,247.495 244.206,247.497 244.215,247.5 244.224,247.502 244.233,247.505 244.242,247.507 244.252,247.509 244.261,247.512 244.27,247.514 244.279,247.517 244.288,247.519 244.298,247.521 244.307,247.524 244.316,247.526 244.325,247.529 244.334,247.531 244.343,247.533 244.353,247.536 244.362,247.538 244.371,247.541 244.38,247.543 244.389,247.545 244.399,247.548 244.408,247.55 244.417,247.553 244.426,247.555 244.435,247.557 244.445,247.56 244.454,247.562 244.463,247.565 244.472,247.567 244.481,247.569 244.491,247.572 244.5,247.574 244.509,247.577 244.518,247.579 244.527,247.581 244.536,247.584 244.546,247.586 244.555,247.589 244.564,247.591 244.573,247.593 244.582,247.596 244.592,247.598 244.601,247.601 244.61,247.603 244.619,247.605 244.628,247.608 244.638,247.61 244.647,247.613 244.656,247.615 244.665,247.617 244.674,247.62 244.683,247.622 244.693,247.625 244.702,247.627 244.711,247.629 244.72,247.632 244.729,247.634 244.739,247.637 244.748,247.639 244.757,247.641 244.766,247.644 244.775,247.646 244.785,247.649 244.794,247.651 244.803,247.653 244.812,247.656 244.821,247.658 244.831,247.661 244.84,247.663 244.849,247.665 244.858,247.668 244.867,247.67 244.876,247.673 244.886,247.675 244.895,247.677 244.904,247.68 244.913,247.682 244.922,247.685 244.932,247.687 244.941,247.689 244.95,247.692 244.959,247.694 244.968,247.697 244.978,247.699 244.987,247.701 244.996,247.704 245.005,247.706 245.014,247.709 245.023,247.711 245.033,247.713 245.042,247.716 245.051,247.718 245.06,247.721 245.069,247.723 245.079,247.725 245.088,247.728 245.097,247.73 245.106,247.733 245.115,247.735 245.125,247.737 245.134,247.74 245.143,247.742 245.152,247.745 245.161,247.747 245.171,247.749 245.18,247.752 245.189,247.754 245.198,247.757 245.207,247.759 245.216,247.761 245.226,247.764 245.235,247.766 245.244,247.769 245.253,247.771 245.262,247.773 245.272,247.776 245.281,247.778 245.29,247.781 245.299,247.783 245.308,247.785 245.318,247.788 245.327,247.79 245.336,247.793 245.345,247.795 245.354,247.797 245.364,247.8 245.373,247.802 245.382,247.805 245.391,247.807 245.4,247.809 245.409,247.812 245.419,247.814 245.428,247.817 245.437,247.819 245.446,247.821 245.455,247.824 245.465,247.826 245.474,247.829 245.483,247.831 245.492,247.833 245.501,247.836 245.511,247.838 245.52,247.841 245.529,247.843 245.538,247.845 245.547,247.848 245.556,247.85 245.566,247.853 245.575,247.855 245.584,247.857 245.593,247.86 245.602,247.862 245.612,247.865 245.621,247.867 245.63,247.869 245.639,247.872 245.648,247.874 245.658,247.877 245.667,247.879 245.676,247.881 245.685,247.884 245.694,247.886 245.704,247.889 245.713,247.891 245.722,247.893 245.731,247.896 245.74,247.898 245.749,247.901 245.759,247.903 245.768,247.905 245.777,247.908 245.786,247.91 245.795,247.913 245.805,247.915 245.814,247.917 245.823,247.92 245.832,247.922 245.841,247.925 245.851,247.927 245.86,247.929 245.869,247.932 245.878,247.934 245.887,247.937 245.896,247.939 245.906,247.941 245.915,247.944 245.924,247.946 245.933,247.948 245.942,247.951 245.952,247.953 245.961,247.956 245.97,247.958 245.979,247.96 245.988,247.963 245.998,247.965 246.007,247.968 246.016,247.97 246.025,247.972 246.034,247.975 246.044,247.977 246.053,247.98 246.062,247.982 246.071,247.984 246.08,247.987 246.089,247.989 246.099,247.992 246.108,247.994 246.117,247.996 246.126,247.999 246.135,248.001 246.145,248.004 246.154,248.006 246.163,248.008 246.172,248.011 246.181,248.013 246.191,248.016 246.2,248.018 246.209,248.02 246.218,248.023 246.227,248.025 246.236,248.028 246.246,248.03 246.255,248.032 246.264,248.035 246.273,248.037 246.282,248.04 246.292,248.042 246.301,248.044 246.31,248.047 246.319,248.049 246.328,248.052 246.338,248.054 246.347,248.056 246.356,248.059 246.365,248.061 246.374,248.064 246.384,248.066 246.393,248.068 246.402,248.071 246.411,248.073 246.42,248.076 246.429,248.078 246.439,248.08 246.448,248.083 246.457,248.085 246.466,248.088 246.475,248.09 246.485,248.092 246.494,248.095 246.503,248.097 246.512,248.1 246.521,248.102 246.531,248.104 246.54,248.107 246.549,248.109 246.558,248.112 246.567,248.114 246.576,248.116 246.586,248.119 246.595,248.121 246.604,248.124 246.613,248.126 246.622,248.128 246.632,248.131 246.641,248.133 246.65,248.136 246.659,248.138 246.668,248.14 246.678,248.143 246.687,248.145 246.696,248.147 246.705,248.15 246.714,248.152 246.724,248.155 246.733,248.157 246.742,248.159 246.751,248.162 246.76,248.164 246.769,248.167 246.779,248.169 246.788,248.171 246.797,248.174 246.806,248.176 246.815,248.179 246.825,248.181 246.834,248.183 246.843,248.186 246.852,248.188 246.861,248.191 246.871,248.193 246.88,248.195 246.889,248.198 246.898,248.2 246.907,248.203 246.916,248.205 246.926,248.207 246.935,248.21 246.944,248.212 246.953,248.215 246.962,248.217 246.972,248.219 246.981,248.222 246.99,248.224 246.999,248.227 247.008,248.229 247.018,248.231 247.027,248.234 247.036,248.236 247.045,248.239 247.054,248.241 247.064,248.243 247.073,248.246 247.082,248.248 247.091,248.251 247.1,248.253 247.109,248.255 247.119,248.258 247.128,248.26 247.137,248.263 247.146,248.265 247.155,248.267 247.165,248.27 247.174,248.272 247.183,248.274 247.192,248.277 247.201,248.279 247.211,248.282 247.22,248.284 247.229,248.286 247.238,248.289 247.247,248.291 247.256,248.294 247.266,248.296 247.275,248.298 247.284,248.301 247.293,248.303 247.302,248.306 247.312,248.308 247.321,248.31 247.33,248.313 247.339,248.315 247.348,248.318 247.358,248.32 247.367,248.322 247.376,248.325 247.385,248.327 247.394,248.33 247.404,248.332 247.413,248.334 247.422,248.337 247.431,248.339 247.44,248.342 247.449,248.344 247.459,248.346 247.468,248.349 247.477,248.351 247.486,248.354 247.495,248.356 247.505,248.358 247.514,248.361 247.523,248.363 247.532,248.366 247.541,248.368 247.551,248.37 247.56,248.373 247.569,248.375 247.578,248.377 247.587,248.38 247.596,248.382 247.606,248.385 247.615,248.387 247.624,248.389 247.633,248.392 247.642,248.394 247.652,248.397 247.661,248.399 247.67,248.401 247.679,248.404 247.688,248.406 247.698,248.409 247.707,248.411 247.716,248.413 247.725,248.416 247.734,248.418 247.744,248.421 247.753,248.423 247.762,248.425 247.771,248.428 247.78,248.43 247.789,248.433 247.799,248.435 247.808,248.437 247.817,248.44 247.826,248.442 247.835,248.445 247.845,248.447 247.854,248.449 247.863,248.452 247.872,248.454 247.881,248.457 247.891,248.459 247.9,248.461 247.909,248.464 247.918,248.466 247.927,248.468 247.937,248.471 247.946,248.473 247.955,248.476 247.964,248.478 247.973,248.48 247.982,248.483 247.992,248.485 248.001,248.488 248.01,248.49 248.019,248.492 248.028,248.495 248.038,248.497 248.047,248.5 248.056,248.502 248.065,248.504 248.074,248.507 248.084,248.509 248.093,248.512 248.102,248.514 248.111,248.516 248.12,248.519 248.129,248.521 248.139,248.524 248.148,248.526 248.157,248.528 248.166,248.531 248.175,248.533 248.185,248.536 248.194,248.538 248.203,248.54 248.212,248.543 248.221,248.545 248.231,248.548 248.24,248.55 248.249,248.552 248.258,248.555 248.267,248.557 248.277,248.559 248.286,248.562 248.295,248.564 248.304,248.567 248.313,248.569 248.322,248.571 248.332,248.574 248.341,248.576 248.35,248.579 248.359,248.581 248.368,248.583 248.378,248.586 248.387,248.588 248.396,248.591 248.405,248.593 248.414,248.595 248.424,248.598 248.433,248.6 248.442,248.603 248.451,248.605 248.46,248.607 248.469,248.61 248.479,248.612 248.488,248.615 248.497,248.617 248.506,248.619 248.515,248.622 248.525,248.624 248.534,248.626 248.543,248.629 248.552,248.631 248.561,248.634 248.571,248.636 248.58,248.638 248.589,248.641 248.598,248.643 248.607,248.646 248.617,248.648 248.626,248.65 248.635,248.653 248.644,248.655 248.653,248.658 248.662,248.66 248.672,248.662 248.681,248.665 248.69,248.667 248.699,248.67 248.708,248.672 248.718,248.674 248.727,248.677 248.736,248.679 248.745,248.682 248.754,248.684 248.764,248.686 248.773,248.689 248.782,248.691 248.791,248.693 248.8,248.696 248.809,248.698 248.819,248.701 248.828,248.703 248.837,248.705 248.846,248.708 248.855,248.71 248.865,248.713 248.874,248.715 248.883,248.717 248.892,248.72 248.901,248.722 248.911,248.725 248.92,248.727 248.929,248.729 248.938,248.732 248.947,248.734 248.957,248.737 248.966,248.739 248.975,248.741 248.984,248.744 248.993,248.746 249.002,248.749 249.012,248.751 249.021,248.753 249.03,248.756 249.039,248.758 249.048,248.76 249.058,248.763 249.067,248.765 249.076,248.768 249.085,248.77 249.094,248.772 249.104,248.775 249.113,248.777 249.122,248.78 249.131,248.782 249.14,248.784 249.149,248.787 249.159,248.789 249.168,248.792 249.177,248.794 249.186,248.796 249.195,248.799 249.205,248.801 249.214,248.804 249.223,248.806 249.232,248.808 249.241,248.811 249.251,248.813 249.26,248.815 249.269,248.818 249.278,248.82 249.287,248.823 249.297,248.825 249.306,248.827 249.315,248.83 249.324,248.832 249.333,248.835 249.342,248.837 249.352,248.839 249.361,248.842 249.37,248.844 249.379,248.847 249.388,248.849 249.398,248.851 249.407,248.854 249.416,248.856 249.425,248.859 249.434,248.861 249.444,248.863 249.453,248.866 249.462,248.868 249.471,248.87 249.48,248.873 249.489,248.875 249.499,248.878 249.508,248.88 249.517,248.882 249.526,248.885 249.535,248.887 249.545,248.89 249.554,248.892 249.563,248.894 249.572,248.897 249.581,248.899 249.591,248.902 249.6,248.904 249.609,248.906 249.618,248.909 249.627,248.911 249.637,248.914 249.646,248.916 249.655,248.918 249.664,248.921 249.673,248.923 249.682,248.925 249.692,248.928 249.701,248.93 249.71,248.933 249.719,248.935 249.728,248.937 249.738,248.94 249.747,248.942 249.756,248.945 249.765,248.947 249.774,248.949 249.784,248.952 249.793,248.954 249.802,248.957 249.811,248.959 249.82,248.961 249.829,248.964 249.839,248.966 249.848,248.969 249.857,248.971 249.866,248.973 249.875,248.976 249.885,248.978 249.894,248.98 249.903,248.983 249.912,248.985 249.921,248.988 249.931,248.99 249.94,248.992 249.949,248.995 249.958,248.997 249.967,249 249.977,249.002 249.986,249.004 249.995,249.007 250.004,249.009 250.013,249.012 250.022,249.014 250.032,249.016 250.041,249.019 250.05,249.021 250.059,249.024 250.068,249.026 250.078,249.028 250.087,249.031 250.096,249.033 250.105,249.035 250.114,249.038 250.124,249.04 250.133,249.043 250.142,249.045 250.151,249.047 250.16,249.05 250.169,249.052 250.179,249.055 250.188,249.057 250.197,249.059 250.206,249.062 250.215,249.064 250.225,249.067 250.234,249.069 250.243,249.071 250.252,249.074 250.261,249.076 250.271,249.078 250.28,249.081 250.289,249.083 250.298,249.086 250.307,249.088 250.317,249.09 250.326,249.093 250.335,249.095 250.344,249.098 250.353,249.1 250.362,249.102 250.372,249.105 250.381,249.107 250.39,249.11 250.399,249.112 250.408,249.114 250.418,249.117 250.427,249.119 250.436,249.121 250.445,249.124 250.454,249.126 250.464,249.129 250.473,249.131 250.482,249.133 250.491,249.136 250.5,249.138 250.51,249.141 250.519,249.143 250.528,249.145 250.537,249.148 250.546,249.15 250.555,249.153 250.565,249.155 250.574,249.157 250.583,249.16 250.592,249.162 250.601,249.164 250.611,249.167 250.62,249.169 250.629,249.172 250.638,249.174 250.647,249.176 250.657,249.179 250.666,249.181 250.675,249.184 250.684,249.186 250.693,249.188 250.702,249.191 250.712,249.193 250.721,249.196 250.73,249.198 250.739,249.2 250.748,249.203 250.758,249.205 250.767,249.208 250.776,249.21 250.785,249.212 250.794,249.215 250.804,249.217 250.813,249.219 250.822,249.222 250.831,249.224 250.84,249.227 250.85,249.229 250.859,249.231 250.868,249.234 250.877,249.236 250.886,249.239 250.895,249.241 250.905,249.243 250.914,249.246 250.923,249.248 250.932,249.25 250.941,249.253 250.951,249.255 250.96,249.258 250.969,249.26 250.978,249.262 250.987,249.265 250.997,249.267 251.006,249.27 251.015,249.272 251.024,249.274 251.033,249.277 251.042,249.279 251.052,249.282 251.061,249.284 251.07,249.286 251.079,249.289 251.088,249.291 251.098,249.293 251.107,249.296 251.116,249.298 251.125,249.301 251.134,249.303 251.144,249.305 251.153,249.308 251.162,249.31 251.171,249.313 251.18,249.315 251.19,249.317 251.199,249.32 251.208,249.322 251.217,249.325 251.226,249.327 251.235,249.329 251.245,249.332 251.254,249.334 251.263,249.336 251.272,249.339 251.281,249.341 251.291,249.344 251.3,249.346 251.309,249.348 251.318,249.351 251.327,249.353 251.337,249.356 251.346,249.358 251.355,249.36 251.364,249.363 251.373,249.365 251.382,249.368 251.392,249.37 251.401,249.372 251.41,249.375 251.419,249.377 251.428,249.379 251.438,249.382 251.447,249.384 251.456,249.387 251.465,249.389 251.474,249.391 251.484,249.394 251.493,249.396 251.502,249.399 251.511,249.401 251.52,249.403 251.53,249.406 251.539,249.408 251.548,249.41 251.557,249.413 251.566,249.415 251.575,249.418 251.585,249.42 251.594,249.422 251.603,249.425 251.612,249.427 251.621,249.43 251.631,249.432 251.64,249.434 251.649,249.437 251.658,249.439 251.667,249.442 251.677,249.444 251.686,249.446 251.695,249.449 251.704,249.451 251.713,249.453 251.722,249.456 251.732,249.458 251.741,249.461 251.75,249.463 251.759,249.465 251.768,249.468 251.778,249.47 251.787,249.473 251.796,249.475 251.805,249.477 251.814,249.48 251.824,249.482 251.833,249.484 251.842,249.487 251.851,249.489 251.86,249.492 251.87,249.494 251.879,249.496 251.888,249.499 251.897,249.501 251.906,249.504 251.915,249.506 251.925,249.508 251.934,249.511 251.943,249.513 251.952,249.516 251.961,249.518 251.971,249.52 251.98,249.523 251.989,249.525 251.998,249.527 252.007,249.53 252.017,249.532 252.026,249.535 252.035,249.537 252.044,249.539 252.053,249.542 252.062,249.544 252.072,249.547 252.081,249.549 252.09,249.551 252.099,249.554 252.108,249.556 252.118,249.558 252.127,249.561 252.136,249.563 252.145,249.566 252.154,249.568 252.164,249.57 252.173,249.573 252.182,249.575 252.191,249.578 252.2,249.58 252.21,249.582 252.219,249.585 252.228,249.587 252.237,249.589 252.246,249.592 252.255,249.594 252.265,249.597 252.274,249.599 252.283,249.601 252.292,249.604 252.301,249.606 252.311,249.609 252.32,249.611 252.329,249.613 252.338,249.616 252.347,249.618 252.357,249.621 252.366,249.623 252.375,249.625 252.384,249.628 252.393,249.63 252.402,249.632 252.412,249.635 252.421,249.637 252.43,249.64 252.439,249.642 252.448,249.644 252.458,249.647 252.467,249.649 252.476,249.652 252.485,249.654 252.494,249.656 252.504,249.659 252.513,249.661 252.522,249.663 252.531,249.666 252.54,249.668 252.55,249.671 252.559,249.673 252.568,249.675 252.577,249.678 252.586,249.68 252.595,249.683 252.605,249.685 252.614,249.687 252.623,249.69 252.632,249.692 252.641,249.694 252.651,249.697 252.66,249.699 252.669,249.702 252.678,249.704 252.687,249.706 252.697,249.709 252.706,249.711 252.715,249.714 252.724,249.716 252.733,249.718 252.743,249.721 252.752,249.723 252.761,249.725 252.77,249.728 252.779,249.73 252.788,249.733 252.798,249.735 252.807,249.737 252.816,249.74 252.825,249.742 252.834,249.745 252.844,249.747 252.853,249.749 252.862,249.752 252.871,249.754 252.88,249.756 252.89,249.759 252.899,249.761 252.908,249.764 252.917,249.766 252.926,249.768 252.935,249.771 252.945,249.773 252.954,249.776 252.963,249.778 252.972,249.78 252.981,249.783 252.991,249.785 253,249.787 253.009,249.79 253.018,249.792 253.027,249.795 253.037,249.797 253.046,249.799 253.055,249.802 253.064,249.804 253.073,249.807 253.083,249.809 253.092,249.811 253.101,249.814 253.11,249.816 253.119,249.818 253.128,249.821 253.138,249.823 253.147,249.826 253.156,249.828 253.165,249.83 253.174,249.833 253.184,249.835 253.193,249.838 253.202,249.84 253.211,249.842 253.22,249.845 253.23,249.847 253.239,249.849 253.248,249.852 253.257,249.854 253.266,249.857 253.275,249.859 253.285,249.861 253.294,249.864 253.303,249.866 253.312,249.869 253.321,249.871 253.331,249.873 253.34,249.876 253.349,249.878 253.358,249.88 253.367,249.883 253.377,249.885 253.386,249.888 253.395,249.89 253.404,249.892 253.413,249.895 253.423,249.897 253.432,249.9 253.441,249.902 253.45,249.904 253.459,249.907 253.468,249.909 253.478,249.911 253.487,249.914 253.496,249.916 253.505,249.919 253.514,249.921 253.524,249.923 253.533,249.926 253.542,249.928 253.551,249.931 253.56,249.933 253.57,249.935 253.579,249.938 253.588,249.94 253.597,249.942 253.606,249.945 253.615,249.947 253.625,249.95 253.634,249.952 253.643,249.954 253.652,249.957 253.661,249.959 253.671,249.961 253.68,249.964 253.689,249.966 253.698,249.969 253.707,249.971 253.717,249.973 253.726,249.976 253.735,249.978 253.744,249.981 253.753,249.983 253.763,249.985 253.772,249.988 253.781,249.99 253.79,249.992 253.799,249.995 253.808,249.997 253.818,250 253.827,250.002 253.836,250.004 253.845,250.007 253.854,250.009 253.864,250.012 253.873,250.014 253.882,250.016 253.891,250.019 253.9,250.021 253.91,250.023 253.919,250.026 253.928,250.028 253.937,250.031 253.946,250.033 253.955,250.035 253.965,250.038 253.974,250.04 253.983,250.043 253.992,250.045 254.001,250.047 254.011,250.05 254.02,250.052 254.029,250.054 254.038,250.057 254.047,250.059 254.057,250.062 254.066,250.064 254.075,250.066 254.084,250.069 254.093,250.071 254.103,250.073 254.112,250.076 254.121,250.078 254.13,250.081 254.139,250.083 254.148,250.085 254.158,250.088 254.167,250.09 254.176,250.093 254.185,250.095 254.194,250.097 254.204,250.1 254.213,250.102 254.222,250.104 254.231,250.107 254.24,250.109 254.25,250.112 254.259,250.114 254.268,250.116 254.277,250.119 254.286,250.121 254.295,250.124 254.305,250.126 254.314,250.128 254.323,250.131 254.332,250.133 254.341,250.135 254.351,250.138 254.36,250.14 254.369,250.143 254.378,250.145 254.387,250.147 254.397,250.15 254.406,250.152 254.415,250.154 254.424,250.157 254.433,250.159 254.443,250.162 254.452,250.164 254.461,250.166 254.47,250.169 254.479,250.171 254.488,250.174 254.498,250.176 254.507,250.178 254.516,250.181 254.525,250.183 254.534,250.185 254.544,250.188 254.553,250.19 254.562,250.193 254.571,250.195 254.58,250.197 254.59,250.2 254.599,250.202 254.608,250.204 254.617,250.207 254.626,250.209 254.635,250.212 254.645,250.214 254.654,250.216 254.663,250.219 254.672,250.221 254.681,250.224 254.691,250.226 254.7,250.228 254.709,250.231 254.718,250.233 254.727,250.235 254.737,250.238 254.746,250.24 254.755,250.243 254.764,250.245 254.773,250.247 254.783,250.25 254.792,250.252 254.801,250.254 254.81,250.257 254.819,250.259 254.828,250.262 254.838,250.264 254.847,250.266 254.856,250.269 254.865,250.271 254.874,250.274 254.884,250.276 254.893,250.278 254.902,250.281 254.911,250.283 254.92,250.285 254.93,250.288 254.939,250.29 254.948,250.293 254.957,250.295 254.966,250.297 254.975,250.3 254.985,250.302 254.994,250.304 255.003,250.307 255.012,250.309 255.021,250.312 255.031,250.314 255.04,250.316 255.049,250.319 255.058,250.321 255.067,250.324 255.077,250.326 255.086,250.328 255.095,250.331 255.104,250.333 255.113,250.335 255.123,250.338 255.132,250.34 255.141,250.343 255.15,250.345 255.159,250.347 255.168,250.35 255.178,250.352 255.187,250.354 255.196,250.357 255.205,250.359 255.214,250.362 255.224,250.364 255.233,250.366 255.242,250.369 255.251,250.371 255.26,250.374 255.27,250.376 255.279,250.378 255.288,250.381 255.297,250.383 255.306,250.385 255.316,250.388 255.325,250.39 255.334,250.393 255.343,250.395 255.352,250.397 255.361,250.4 255.371,250.402 255.38,250.404 255.389,250.407 255.398,250.409 255.407,250.412 255.417,250.414 255.426,250.416 255.435,250.419 255.444,250.421 255.453,250.423 255.463,250.426 255.472,250.428 255.481,250.431 255.49,250.433 255.499,250.435 255.508,250.438 255.518,250.44 255.527,250.443 255.536,250.445 255.545,250.447 255.554,250.45 255.564,250.452 255.573,250.454 255.582,250.457 255.591,250.459 255.6,250.462 255.61,250.464 255.619,250.466 255.628,250.469 255.637,250.471 255.646,250.473 255.656,250.476 255.665,250.478 255.674,250.481 255.683,250.483 255.692,250.485 255.701,250.488 255.711,250.49 255.72,250.492 255.729,250.495 255.738,250.497 255.747,250.5 255.757,250.502 255.766,250.504 255.775,250.507 255.784,250.509 255.793,250.512 255.803,250.514 255.812,250.516 255.821,250.519 255.83,250.521 255.839,250.523 255.848,250.526 255.858,250.528 255.867,250.531 255.876,250.533 255.885,250.535 255.894,250.538 255.904,250.54 255.913,250.542 255.922,250.545 255.931,250.547 255.94,250.55 255.95,250.552 255.959,250.554 255.968,250.557 255.977,250.559 255.986,250.561 255.996,250.564 256.005,250.566 256.014,250.569 256.023,250.571 256.032,250.573 256.041,250.576 256.051,250.578 256.06,250.581 256.069,250.583 256.078,250.585 256.087,250.588 256.097,250.59 256.106,250.592 256.115,250.595 256.124,250.597 256.133,250.6 256.143,250.602 256.152,250.604 256.161,250.607 256.17,250.609 256.179,250.611 256.188,250.614 256.198,250.616 256.207,250.619 256.216,250.621 256.225,250.623 256.234,250.626 256.244,250.628 256.253,250.63 256.262,250.633 256.271,250.635 256.28,250.638 256.29,250.64 256.299,250.642 256.308,250.645 256.317,250.647 256.326,250.649 256.336,250.652 256.345,250.654 256.354,250.657 256.363,250.659 256.372,250.661 256.381,250.664 256.391,250.666 256.4,250.669 256.409,250.671 256.418,250.673 256.427,250.676 256.437,250.678 256.446,250.68 256.455,250.683 256.464,250.685 256.473,250.688 256.483,250.69 256.492,250.692 256.501,250.695 256.51,250.697 256.519,250.699 256.528,250.702 256.538,250.704 256.547,250.707 256.556,250.709 256.565,250.711 256.574,250.714 256.584,250.716 256.593,250.718 256.602,250.721 256.611,250.723 256.62,250.726 256.63,250.728 256.639,250.73 256.648,250.733 256.657,250.735 256.666,250.737 256.676,250.74 256.685,250.742 256.694,250.745 256.703,250.747 256.712,250.749 256.721,250.752 256.731,250.754 256.74,250.756 256.749,250.759 256.758,250.761 256.767,250.764 256.777,250.766 256.786,250.768 256.795,250.771 256.804,250.773 256.813,250.775 256.823,250.778 256.832,250.78 256.841,250.783 256.85,250.785 256.859,250.787 256.868,250.79 256.878,250.792 256.887,250.795 256.896,250.797 256.905,250.799 256.914,250.802 256.924,250.804 256.933,250.806 256.942,250.809 256.951,250.811 256.96,250.814 256.97,250.816 256.979,250.818 256.988,250.821 256.997,250.823 257.006,250.825 257.016,250.828 257.025,250.83 257.034,250.833 257.043,250.835 257.052,250.837 257.061,250.84 257.071,250.842 257.08,250.844 257.089,250.847 257.098,250.849 257.107,250.852 257.117,250.854 257.126,250.856 257.135,250.859 257.144,250.861 257.153,250.863 257.163,250.866 257.172,250.868 257.181,250.871 257.19,250.873 257.199,250.875 257.208,250.878 257.218,250.88 257.227,250.882 257.236,250.885 257.245,250.887 257.254,250.89 257.264,250.892 257.273,250.894 257.282,250.897 257.291,250.899 257.3,250.901 257.31,250.904 257.319,250.906 257.328,250.909 257.337,250.911 257.346,250.913 257.356,250.916 257.365,250.918 257.374,250.92 257.383,250.923 257.392,250.925 257.401,250.928 257.411,250.93 257.42,250.932 257.429,250.935 257.438,250.937 257.447,250.939 257.457,250.942 257.466,250.944 257.475,250.947 257.484,250.949 257.493,250.951 257.503,250.954 257.512,250.956 257.521,250.958 257.53,250.961 257.539,250.963 257.548,250.966 257.558,250.968 257.567,250.97 257.576,250.973 257.585,250.975 257.594,250.977 257.604,250.98 257.613,250.982 257.622,250.985 257.631,250.987 257.64,250.989 257.65,250.992 257.659,250.994 257.668,250.996 257.677,250.999 257.686,251.001 257.696,251.004 257.705,251.006 257.714,251.008 257.723,251.011 257.732,251.013 257.741,251.015 257.751,251.018 257.76,251.02 257.769,251.023 257.778,251.025 257.787,251.027 257.797,251.03 257.806,251.032 257.815,251.035 257.824,251.037 257.833,251.039 257.843,251.042 257.852,251.044 257.861,251.046 257.87,251.049 257.879,251.051 257.889,251.054 257.898,251.056 257.907,251.058 257.916,251.061 257.925,251.063 257.934,251.065 257.944,251.068 257.953,251.07 257.962,251.073 257.971,251.075 257.98,251.077 257.99,251.08 257.999,251.082 258.008,251.084 258.017,251.087 258.026,251.089 258.036,251.092 258.045,251.094 258.054,251.096 258.063,251.099 258.072,251.101 258.081,251.103 258.091,251.106 258.1,251.108 258.109,251.11 258.118,251.113 258.127,251.115 258.137,251.118 258.146,251.12 258.155,251.122 258.164,251.125 258.173,251.127 258.183,251.129 258.192,251.132 258.201,251.134 258.21,251.137 258.219,251.139 258.229,251.141 258.238,251.144 258.247,251.146 258.256,251.148 258.265,251.151 258.274,251.153 258.284,251.156 258.293,251.158 258.302,251.16 258.311,251.163 258.32,251.165 258.33,251.167 258.339,251.17 258.348,251.172 258.357,251.175 258.366,251.177 258.376,251.179 258.385,251.182 258.394,251.184 258.403,251.186 258.412,251.189 258.421,251.191 258.431,251.194 258.44,251.196 258.449,251.198 258.458,251.201 258.467,251.203 258.477,251.205 258.486,251.208 258.495,251.21 258.504,251.213 258.513,251.215 258.523,251.217 258.532,251.22 258.541,251.222 258.55,251.224 258.559,251.227 258.569,251.229 258.578,251.232 258.587,251.234 258.596,251.236 258.605,251.239 258.614,251.241 258.624,251.243 258.633,251.246 258.642,251.248 258.651,251.251 258.66,251.253 258.67,251.255 258.679,251.258 258.688,251.26 258.697,251.262 258.706,251.265 258.716,251.267 258.725,251.27 258.734,251.272 258.743,251.274 258.752,251.277 258.761,251.279 258.771,251.281 258.78,251.284 258.789,251.286 258.798,251.289 258.807,251.291 258.817,251.293 258.826,251.296 258.835,251.298 258.844,251.3 258.853,251.303 258.863,251.305 258.872,251.308 258.881,251.31 258.89,251.312 258.899,251.315 258.909,251.317 258.918,251.319 258.927,251.322 258.936,251.324 258.945,251.327 258.954,251.329 258.964,251.331 258.973,251.334 258.982,251.336 258.991,251.338 259,251.341 259.01,251.343 259.019,251.345 259.028,251.348 259.037,251.35 259.046,251.353 259.056,251.355 259.065,251.357 259.074,251.36 259.083,251.362 259.092,251.364 259.101,251.367 259.111,251.369 259.12,251.372 259.129,251.374 259.138,251.376 259.147,251.379 259.157,251.381 259.166,251.383 259.175,251.386 259.184,251.388 259.193,251.391 259.203,251.393 259.212,251.395 259.221,251.398 259.23,251.4 259.239,251.402 259.249,251.405 259.258,251.407 259.267,251.41 259.276,251.412 259.285,251.414 259.294,251.417 259.304,251.419 259.313,251.421 259.322,251.424 259.331,251.426 259.34,251.429 259.35,251.431 259.359,251.433 259.368,251.436 259.377,251.438 259.386,251.44 259.396,251.443 259.405,251.445 259.414,251.448 259.423,251.45 259.432,251.452 259.441,251.455 259.451,251.457 259.46,251.459 259.469,251.462 259.478,251.464 259.487,251.466 259.497,251.469 259.506,251.471 259.515,251.474 259.524,251.476 259.533,251.478 259.543,251.481 259.552,251.483 259.561,251.485 259.57,251.488 259.579,251.49 259.589,251.493 259.598,251.495 259.607,251.497 259.616,251.5 259.625,251.502 259.634,251.504 259.644,251.507 259.653,251.509 259.662,251.512 259.671,251.514 259.68,251.516 259.69,251.519 259.699,251.521 259.708,251.523 259.717,251.526 259.726,251.528 259.736,251.531 259.745,251.533 259.754,251.535 259.763,251.538 259.772,251.54 259.781,251.542 259.791,251.545 259.8,251.547 259.809,251.549 259.818,251.552 259.827,251.554 259.837,251.557 259.846,251.559 259.855,251.561 259.864,251.564 259.873,251.566 259.883,251.568 259.892,251.571 259.901,251.573 259.91,251.576 259.919,251.578 259.929,251.58 259.938,251.583 259.947,251.585 259.956,251.587 259.965,251.59 259.974,251.592 259.984,251.595 259.993,251.597 260.002,251.599 260.011,251.602 260.02,251.604 260.03,251.606 260.039,251.609 260.048,251.611 260.057,251.614 260.066,251.616 260.076,251.618 260.085,251.621 260.094,251.623 260.103,251.625 260.112,251.628 260.122,251.63 260.131,251.632 260.14,251.635 260.149,251.637 260.158,251.64 260.167,251.642 260.177,251.644 260.186,251.647 260.195,251.649 260.204,251.651 260.213,251.654 260.223,251.656 260.232,251.659 260.241,251.661 260.25,251.663 260.259,251.666 260.269,251.668 260.278,251.67 260.287,251.673 260.296,251.675 260.305,251.678 260.314,251.68 260.324,251.682 260.333,251.685 260.342,251.687 260.351,251.689 260.36,251.692 260.37,251.694 260.379,251.696 260.388,251.699 260.397,251.701 260.406,251.704 260.416,251.706 260.425,251.708 260.434,251.711 260.443,251.713 260.452,251.715 260.462,251.718 260.471,251.72 260.48,251.723 260.489,251.725 260.498,251.727 260.507,251.73 260.517,251.732 260.526,251.734 260.535,251.737 260.544,251.739 260.553,251.742 260.563,251.744 260.572,251.746 260.581,251.749 260.59,251.751 260.599,251.753 260.609,251.756 260.618,251.758 260.627,251.76 260.636,251.763 260.645,251.765 260.654,251.768 260.664,251.77 260.673,251.772 260.682,251.775 260.691,251.777 260.7,251.779 260.71,251.782 260.719,251.784 260.728,251.787 260.737,251.789 260.746,251.791 260.756,251.794 260.765,251.796 260.774,251.798 260.783,251.801 260.792,251.803 260.802,251.805 260.811,251.808 260.82,251.81 260.829,251.813 260.838,251.815 260.847,251.817 260.857,251.82 260.866,251.822 260.875,251.824 260.884,251.827 260.893,251.829 260.903,251.832 260.912,251.834 260.921,251.836 260.93,251.839 260.939,251.841 260.949,251.843 260.958,251.846 260.967,251.848 260.976,251.851 260.985,251.853 260.994,251.855 261.004,251.858 261.013,251.86 261.022,251.862 261.031,251.865 261.04,251.867 261.05,251.869 261.059,251.872 261.068,251.874 261.077,251.877 261.086,251.879 261.096,251.881 261.105,251.884 261.114,251.886 261.123,251.888 261.132,251.891 261.142,251.893 261.151,251.896 261.16,251.898 261.169,251.9 261.178,251.903 261.187,251.905 261.197,251.907 261.206,251.91 261.215,251.912 261.224,251.914 261.233,251.917 261.243,251.919 261.252,251.922 261.261,251.924 261.27,251.926 261.279,251.929 261.289,251.931 261.298,251.933 261.307,251.936 261.316,251.938 261.325,251.941 261.334,251.943 261.344,251.945 261.353,251.948 261.362,251.95 261.371,251.952 261.38,251.955 261.39,251.957 261.399,251.959 261.408,251.962 261.417,251.964 261.426,251.967 261.436,251.969 261.445,251.971 261.454,251.974 261.463,251.976 261.472,251.978 261.482,251.981 261.491,251.983 261.5,251.986 261.509,251.988 261.518,251.99 261.527,251.993 261.537,251.995 261.546,251.997 261.555,252 261.564,252.002 261.573,252.004 261.583,252.007 261.592,252.009 261.601,252.012 261.61,252.014 261.619,252.016 261.629,252.019 261.638,252.021 261.647,252.023 261.656,252.026 261.665,252.028 261.674,252.031 261.684,252.033 261.693,252.035 261.702,252.038 261.711,252.04 261.72,252.042 261.73,252.045 261.739,252.047 261.748,252.049 261.757,252.052 261.766,252.054 261.776,252.057 261.785,252.059 261.794,252.061 261.803,252.064 261.812,252.066 261.822,252.068 261.831,252.071 261.84,252.073 261.849,252.075 261.858,252.078 261.867,252.08 261.877,252.083 261.886,252.085 261.895,252.087 261.904,252.09 261.913,252.092 261.923,252.094 261.932,252.097 261.941,252.099 261.95,252.102 261.959,252.104 261.969,252.106 261.978,252.109 261.987,252.111 261.996,252.113 262.005,252.116 262.014,252.118 262.024,252.12 262.033,252.123 262.042,252.125 262.051,252.128 262.06,252.13 262.07,252.132 262.079,252.135 262.088,252.137 262.097,252.139 262.106,252.142 262.116,252.144 262.125,252.147 262.134,252.149 262.143,252.151 262.152,252.154 262.162,252.156 262.171,252.158 262.18,252.161 262.189,252.163 262.198,252.165 262.207,252.168 262.217,252.17 262.226,252.173 262.235,252.175 262.244,252.177 262.253,252.18 262.263,252.182 262.272,252.184 262.281,252.187 262.29,252.189 262.299,252.191 262.309,252.194 262.318,252.196 262.327,252.199 262.336,252.201 262.345,252.203 262.354,252.206 262.364,252.208 262.373,252.21 262.382,252.213 262.391,252.215 262.4,252.218 262.41,252.22 262.419,252.222 262.428,252.225 262.437,252.227 262.446,252.229 262.456,252.232 262.465,252.234 262.474,252.236 262.483,252.239 262.492,252.241 262.502,252.244 262.511,252.246 262.52,252.248 262.529,252.251 262.538,252.253 262.547,252.255 262.557,252.258 262.566,252.26 262.575,252.262 262.584,252.265 262.593,252.267 262.603,252.27 262.612,252.272 262.621,252.274 262.63,252.277 262.639,252.279 262.649,252.281 262.658,252.284 262.667,252.286 262.676,252.288 262.685,252.291 262.695,252.293 262.704,252.296 262.713,252.298 262.722,252.3 262.731,252.303 262.74,252.305 262.75,252.307 262.759,252.31 262.768,252.312 262.777,252.315 262.786,252.317 262.796,252.319 262.805,252.322 262.814,252.324 262.823,252.326 262.832,252.329 262.842,252.331 262.851,252.333 262.86,252.336 262.869,252.338 262.878,252.341 262.887,252.343 262.897,252.345 262.906,252.348 262.915,252.35 262.924,252.352 262.933,252.355 262.943,252.357 262.952,252.359 262.961,252.362 262.97,252.364 262.979,252.367 262.989,252.369 262.998,252.371 263.007,252.374 263.016,252.376 263.025,252.378 263.035,252.381 263.044,252.383 263.053,252.385 263.062,252.388 263.071,252.39 263.08,252.393 263.09,252.395 263.099,252.397 263.108,252.4 263.117,252.402 263.126,252.404 263.136,252.407 263.145,252.409 263.154,252.411 263.163,252.414 263.172,252.416 263.182,252.419 263.191,252.421 263.2,252.423 263.209,252.426 263.218,252.428 263.227,252.43 263.237,252.433 263.246,252.435 263.255,252.438 263.264,252.44 263.273,252.442 263.283,252.445 263.292,252.447 263.301,252.449 263.31,252.452 263.319,252.454 263.329,252.456 263.338,252.459 263.347,252.461 263.356,252.464 263.365,252.466 263.375,252.468 263.384,252.471 263.393,252.473 263.402,252.475 263.411,252.478 263.42,252.48 263.43,252.482 263.439,252.485 263.448,252.487 263.457,252.49 263.466,252.492 263.476,252.494 263.485,252.497 263.494,252.499 263.503,252.501 263.512,252.504 263.522,252.506 263.531,252.508 263.54,252.511 263.549,252.513 263.558,252.516 263.567,252.518 263.577,252.52 263.586,252.523 263.595,252.525 263.604,252.527 263.613,252.53 263.623,252.532 263.632,252.534 263.641,252.537 263.65,252.539 263.659,252.542 263.669,252.544 263.678,252.546 263.687,252.549 263.696,252.551 263.705,252.553 263.715,252.556 263.724,252.558 263.733,252.56 263.742,252.563 263.751,252.565 263.76,252.568 263.77,252.57 263.779,252.572 263.788,252.575 263.797,252.577 263.806,252.579 263.816,252.582 263.825,252.584 263.834,252.586 263.843,252.589 263.852,252.591 263.862,252.594 263.871,252.596 263.88,252.598 263.889,252.601 263.898,252.603 263.907,252.605 263.917,252.608 263.926,252.61 263.935,252.612 263.944,252.615 263.953,252.617 263.963,252.62 263.972,252.622 263.981,252.624 263.99,252.627 263.999,252.629 264.009,252.631 264.018,252.634 264.027,252.636 264.036,252.638 264.045,252.641 264.055,252.643 264.064,252.646 264.073,252.648 264.082,252.65 264.091,252.653 264.1,252.655 264.11,252.657 264.119,252.66 264.128,252.662 264.137,252.664 264.146,252.667 264.156,252.669 264.165,252.672 264.174,252.674 264.183,252.676 264.192,252.679 264.202,252.681 264.211,252.683 264.22,252.686 264.229,252.688 264.238,252.69 264.247,252.693 264.257,252.695 264.266,252.698 264.275,252.7 264.284,252.702 264.293,252.705 264.303,252.707 264.312,252.709 264.321,252.712 264.33,252.714 264.339,252.716 264.349,252.719 264.358,252.721 264.367,252.724 264.376,252.726 264.385,252.728 264.395,252.731 264.404,252.733 264.413,252.735 264.422,252.738 264.431,252.74 264.44,252.742 264.45,252.745 264.459,252.747 264.468,252.749 264.477,252.752 264.486,252.754 264.496,252.757 264.505,252.759 264.514,252.761 264.523,252.764 264.532,252.766 264.542,252.768 264.551,252.771 264.56,252.773 264.569,252.775 264.578,252.778 264.587,252.78 264.597,252.783 264.606,252.785 264.615,252.787 264.624,252.79 264.633,252.792 264.643,252.794 264.652,252.797 264.661,252.799 264.67,252.801 264.679,252.804 264.689,252.806 264.698,252.809 264.707,252.811 264.716,252.813 264.725,252.816 264.735,252.818 264.744,252.82 264.753,252.823 264.762,252.825 264.771,252.827 264.78,252.83 264.79,252.832 264.799,252.835 264.808,252.837 264.817,252.839 264.826,252.842 264.836,252.844 264.845,252.846 264.854,252.849 264.863,252.851 264.872,252.853 264.882,252.856 264.891,252.858 264.9,252.861 264.909,252.863 264.918,252.865 264.927,252.868 264.937,252.87 264.946,252.872 264.955,252.875 264.964,252.877 264.973,252.879 264.983,252.882 264.992,252.884 265.001,252.886 265.01,252.889 265.019,252.891 265.029,252.894 265.038,252.896 265.047,252.898 265.056,252.901 265.065,252.903 265.075,252.905 265.084,252.908 265.093,252.91 265.102,252.912 265.111,252.915 265.12,252.917 265.13,252.92 265.139,252.922 265.148,252.924 265.157,252.927 265.166,252.929 265.176,252.931 265.185,252.934 265.194,252.936 265.203,252.938 265.212,252.941 265.222,252.943 265.231,252.946 265.24,252.948 265.249,252.95 265.258,252.953 265.268,252.955 265.277,252.957 265.286,252.96 265.295,252.962 265.304,252.964 265.313,252.967 265.323,252.969 265.332,252.971 265.341,252.974 265.35,252.976 265.359,252.979 265.369,252.981 265.378,252.983 265.387,252.986 265.396,252.988 265.405,252.99 265.415,252.993 265.424,252.995 265.433,252.997 265.442,253 265.451,253.002 265.46,253.005 265.47,253.007 265.479,253.009 265.488,253.012 265.497,253.014 265.506,253.016 265.516,253.019 265.525,253.021 265.534,253.023 265.543,253.026 265.552,253.028 265.562,253.03 265.571,253.033 265.58,253.035 265.589,253.038 265.598,253.04 265.608,253.042 265.617,253.045 265.626,253.047 265.635,253.049 265.644,253.052 265.653,253.054 265.663,253.056 265.672,253.059 265.681,253.061 265.69,253.064 265.699,253.066 265.709,253.068 265.718,253.071 265.727,253.073 265.736,253.075 265.745,253.078 265.755,253.08 265.764,253.082 265.773,253.085 265.782,253.087 265.791,253.089 265.8,253.092 265.81,253.094 265.819,253.097 265.828,253.099 265.837,253.101 265.846,253.104 265.856,253.106 265.865,253.108 265.874,253.111 265.883,253.113 265.892,253.115 265.902,253.118 265.911,253.12 265.92,253.123 265.929,253.125 265.938,253.127 265.948,253.13 265.957,253.132 265.966,253.134 265.975,253.137 265.984,253.139 265.993,253.141 266.003,253.144 266.012,253.146 266.021,253.148 266.03,253.151 266.039,253.153 266.049,253.156 266.058,253.158 266.067,253.16 266.076,253.163 266.085,253.165 266.095,253.167 266.104,253.17 266.113,253.172 266.122,253.174 266.131,253.177 266.14,253.179 266.15,253.182 266.159,253.184 266.168,253.186 266.177,253.189 266.186,253.191 266.196,253.193 266.205,253.196 266.214,253.198 266.223,253.2 266.232,253.203 266.242,253.205 266.251,253.207 266.26,253.21 266.269,253.212 266.278,253.215 266.288,253.217 266.297,253.219 266.306,253.222 266.315,253.224 266.324,253.226 266.333,253.229 266.343,253.231 266.352,253.233 266.361,253.236 266.37,253.238 266.379,253.24 266.389,253.243 266.398,253.245 266.407,253.248 266.416,253.25 266.425,253.252 266.435,253.255 266.444,253.257 266.453,253.259 266.462,253.262 266.471,253.264 266.48,253.266 266.49,253.269 266.499,253.271 266.508,253.274 266.517,253.276 266.526,253.278 266.536,253.281 266.545,253.283 266.554,253.285 266.563,253.288 266.572,253.29 266.582,253.292 266.591,253.295 266.6,253.297 266.609,253.299 266.618,253.302 266.628,253.304 266.637,253.307 266.646,253.309 266.655,253.311 266.664,253.314 266.673,253.316 266.683,253.318 266.692,253.321 266.701,253.323 266.71,253.325 266.719,253.328 266.729,253.33 266.738,253.332 266.747,253.335 266.756,253.337 266.765,253.34 266.775,253.342 266.784,253.344 266.793,253.347 266.802,253.349 266.811,253.351 266.82,253.354 266.83,253.356 266.839,253.358 266.848,253.361 266.857,253.363 266.866,253.365 266.876,253.368 266.885,253.37 266.894,253.373 266.903,253.375 266.912,253.377 266.922,253.38 266.931,253.382 266.94,253.384 266.949,253.387 266.958,253.389 266.968,253.391 266.977,253.394 266.986,253.396 266.995,253.398 267.004,253.401 267.013,253.403 267.023,253.406 267.032,253.408 267.041,253.41 267.05,253.413 267.059,253.415 267.069,253.417 267.078,253.42 267.087,253.422 267.096,253.424 267.105,253.427 267.115,253.429 267.124,253.431 267.133,253.434 267.142,253.436 267.151,253.439 267.16,253.441 267.17,253.443 267.179,253.446 267.188,253.448 267.197,253.45 267.206,253.453 267.216,253.455 267.225,253.457 267.234,253.46 267.243,253.462 267.252,253.464 267.262,253.467 267.271,253.469 267.28,253.472 267.289,253.474 267.298,253.476 267.308,253.479 267.317,253.481 267.326,253.483 267.335,253.486 267.344,253.488 267.353,253.49 267.363,253.493 267.372,253.495 267.381,253.497 267.39,253.5 267.399,253.502 267.409,253.505 267.418,253.507 267.427,253.509 267.436,253.512 267.445,253.514 267.455,253.516 267.464,253.519 267.473,253.521 267.482,253.523 267.491,253.526 267.501,253.528 267.51,253.53 267.519,253.533 267.528,253.535 267.537,253.538 267.546,253.54 267.556,253.542 267.565,253.545 267.574,253.547 267.583,253.549 267.592,253.552 267.602,253.554 267.611,253.556 267.62,253.559 267.629,253.561 267.638,253.563 267.648,253.566 267.657,253.568 267.666,253.571 267.675,253.573 267.684,253.575 267.693,253.578 267.703,253.58 267.712,253.582 267.721,253.585 267.73,253.587 267.739,253.589 267.749,253.592 267.758,253.594 267.767,253.596 267.776,253.599 267.785,253.601 267.795,253.604 267.804,253.606 267.813,253.608 267.822,253.611 267.831,253.613 267.841,253.615 267.85,253.618 267.859,253.62 267.868,253.622 267.877,253.625 267.886,253.627 267.896,253.629 267.905,253.632 267.914,253.634 267.923,253.636 267.932,253.639 267.942,253.641 267.951,253.644 267.96,253.646 267.969,253.648 267.978,253.651 267.988,253.653 267.997,253.655 268.006,253.658 268.015,253.66 268.024,253.662 268.033,253.665 268.043,253.667 268.052,253.669 268.061,253.672 268.07,253.674 268.079,253.677 268.089,253.679 268.098,253.681 268.107,253.684 268.116,253.686 268.125,253.688 268.135,253.691 268.144,253.693 268.153,253.695 268.162,253.698 268.171,253.7 268.181,253.702 268.19,253.705 268.199,253.707 268.208,253.71 268.217,253.712 268.226,253.714 268.236,253.717 268.245,253.719 268.254,253.721 268.263,253.724 268.272,253.726 268.282,253.728 268.291,253.731 268.3,253.733 268.309,253.735 268.318,253.738 268.328,253.74 268.337,253.742 268.346,253.745 268.355,253.747 268.364,253.75 268.373,253.752 268.383,253.754 268.392,253.757 268.401,253.759 268.41,253.761 268.419,253.764 268.429,253.766 268.438,253.768 268.447,253.771 268.456,253.773 268.465,253.775 268.475,253.778 268.484,253.78 268.493,253.783 268.502,253.785 268.511,253.787 268.521,253.79 268.53,253.792 268.539,253.794 268.548,253.797 268.557,253.799 268.566,253.801 268.576,253.804 268.585,253.806 268.594,253.808 268.603,253.811 268.612,253.813 268.622,253.815 268.631,253.818 268.64,253.82 268.649,253.823 268.658,253.825 268.668,253.827 268.677,253.83 268.686,253.832 268.695,253.834 268.704,253.837 268.713,253.839 268.723,253.841 268.732,253.844 268.741,253.846 268.75,253.848 268.759,253.851 268.769,253.853 268.778,253.856 268.787,253.858 268.796,253.86 268.805,253.863 268.815,253.865 268.824,253.867 268.833,253.87 268.842,253.872 268.851,253.874 268.861,253.877 268.87,253.879 268.879,253.881 268.888,253.884 268.897,253.886 268.906,253.888 268.916,253.891 268.925,253.893 268.934,253.896 268.943,253.898 268.952,253.9 268.962,253.903 268.971,253.905 268.98,253.907 268.989,253.91 268.998,253.912 269.008,253.914 269.017,253.917 269.026,253.919 269.035,253.921 269.044,253.924 269.053,253.926 269.063,253.928 269.072,253.931 269.081,253.933 269.09,253.936 269.099,253.938 269.109,253.94 269.118,253.943 269.127,253.945 269.136,253.947 269.145,253.95 269.155,253.952 269.164,253.954 269.173,253.957 269.182,253.959 269.191,253.961 269.201,253.964 269.21,253.966 269.219,253.968 269.228,253.971 269.237,253.973 269.246,253.976 269.256,253.978 269.265,253.98 269.274,253.983 269.283,253.985 269.292,253.987 269.302,253.99 269.311,253.992 269.32,253.994 269.329,253.997 269.338,253.999 269.348,254.001 269.357,254.004 269.366,254.006 269.375,254.008 269.384,254.011 269.393,254.013 269.403,254.016 269.412,254.018 269.421,254.02 269.43,254.023 269.439,254.025 269.449,254.027 269.458,254.03 269.467,254.032 269.476,254.034 269.485,254.037 269.495,254.039 269.504,254.041 269.513,254.044 269.522,254.046 269.531,254.048 269.541,254.051 269.55,254.053 269.559,254.056 269.568,254.058 269.577,254.06 269.586,254.063 269.596,254.065 269.605,254.067 269.614,254.07 269.623,254.072 269.632,254.074 269.642,254.077 269.651,254.079 269.66,254.081 269.669,254.084 269.678,254.086 269.688,254.088 269.697,254.091 269.706,254.093 269.715,254.096 269.724,254.098 269.733,254.1 269.743,254.103 269.752,254.105 269.761,254.107 269.77,254.11 269.779,254.112 269.789,254.114 269.798,254.117 269.807,254.119 269.816,254.121 269.825,254.124 269.835,254.126 269.844,254.128 269.853,254.131 269.862,254.133 269.871,254.136 269.881,254.138 269.89,254.14 269.899,254.143 269.908,254.145 269.917,254.147 269.926,254.15 269.936,254.152 269.945,254.154 269.954,254.157 269.963,254.159 269.972,254.161 269.982,254.164 269.991,254.166 270,254.168 270.009,254.171 270.018,254.173 270.028,254.176 270.037,254.178 270.046,254.18 270.055,254.183 270.064,254.185 270.074,254.187 270.083,254.19 270.092,254.192 270.101,254.194 270.11,254.197 270.119,254.199 270.129,254.201 270.138,254.204 270.147,254.206 270.156,254.208 270.165,254.211 270.175,254.213 270.184,254.215 270.193,254.218 270.202,254.22 270.211,254.223 270.221,254.225 270.23,254.227 270.239,254.23 270.248,254.232 270.257,254.234 270.266,254.237 270.276,254.239 270.285,254.241 270.294,254.244 270.303,254.246 270.312,254.248 270.322,254.251 270.331,254.253 270.34,254.255 270.349,254.258 270.358,254.26 270.368,254.263 270.377,254.265 270.386,254.267 270.395,254.27 270.404,254.272 270.414,254.274 270.423,254.277 270.432,254.279 270.441,254.281 270.45,254.284 270.459,254.286 270.469,254.288 270.478,254.291 270.487,254.293 270.496,254.295 270.505,254.298 270.515,254.3 270.524,254.302 270.533,254.305 270.542,254.307 270.551,254.31 270.561,254.312 270.57,254.314 270.579,254.317 270.588,254.319 270.597,254.321 270.606,254.324 270.616,254.326 270.625,254.328 270.634,254.331 270.643,254.333 270.652,254.335 270.662,254.338 270.671,254.34 270.68,254.342 270.689,254.345 270.698,254.347 270.708,254.349 270.717,254.352 270.726,254.354 270.735,254.357 270.744,254.359 270.754,254.361 270.763,254.364 270.772,254.366 270.781,254.368 270.79,254.371 270.799,254.373 270.809,254.375 270.818,254.378 270.827,254.38 270.836,254.382 270.845,254.385 270.855,254.387 270.864,254.389 270.873,254.392 270.882,254.394 270.891,254.396 270.901,254.399 270.91,254.401 270.919,254.404 270.928,254.406 270.937,254.408 270.946,254.411 270.956,254.413 270.965,254.415 270.974,254.418 270.983,254.42 270.992,254.422 271.002,254.425 271.011,254.427 271.02,254.429 271.029,254.432 271.038,254.434 271.048,254.436 271.057,254.439 271.066,254.441 271.075,254.443 271.084,254.446 271.094,254.448 271.103,254.451 271.112,254.453 271.121,254.455 271.13,254.458 271.139,254.46 271.149,254.462 271.158,254.465 271.167,254.467 271.176,254.469 271.185,254.472 271.195,254.474 271.204,254.476 271.213,254.479 271.222,254.481 271.231,254.483 271.241,254.486 271.25,254.488 271.259,254.49 271.268,254.493 271.277,254.495 271.286,254.498 271.296,254.5 271.305,254.502 271.314,254.505 271.323,254.507 271.332,254.509 271.342,254.512 271.351,254.514 271.36,254.516 271.369,254.519 271.378,254.521 271.388,254.523 271.397,254.526 271.406,254.528 271.415,254.53 271.424,254.533 271.434,254.535 271.443,254.537 271.452,254.54 271.461,254.542 271.47,254.545 271.479,254.547 271.489,254.549 271.498,254.552 271.507,254.554 271.516,254.556 271.525,254.559 271.535,254.561 271.544,254.563 271.553,254.566 271.562,254.568 271.571,254.57 271.581,254.573 271.59,254.575 271.599,254.577 271.608,254.58 271.617,254.582 271.626,254.584 271.636,254.587 271.645,254.589 271.654,254.591 271.663,254.594 271.672,254.596 271.682,254.599 271.691,254.601 271.7,254.603 271.709,254.606 271.718,254.608 271.728,254.61 271.737,254.613 271.746,254.615 271.755,254.617 271.764,254.62 271.774,254.622 271.783,254.624 271.792,254.627 271.801,254.629 271.81,254.631 271.819,254.634 271.829,254.636 271.838,254.638 271.847,254.641 271.856,254.643 271.865,254.645 271.875,254.648 271.884,254.65 271.893,254.653 271.902,254.655 271.911,254.657 271.921,254.66 271.93,254.662 271.939,254.664 271.948,254.667 271.957,254.669 271.966,254.671 271.976,254.674 271.985,254.676 271.994,254.678 272.003,254.681 272.012,254.683 272.022,254.685 272.031,254.688 272.04,254.69 272.049,254.692 272.058,254.695 272.068,254.697 272.077,254.699 272.086,254.702 272.095,254.704 272.104,254.707 272.114,254.709 272.123,254.711 272.132,254.714 272.141,254.716 272.15,254.718 272.159,254.721 272.169,254.723 272.178,254.725 272.187,254.728 272.196,254.73 272.205,254.732 272.215,254.735 272.224,254.737 272.233,254.739 272.242,254.742 272.251,254.744 272.261,254.746 272.27,254.749 272.279,254.751 272.288,254.753 272.297,254.756 272.306,254.758 272.316,254.761 272.325,254.763 272.334,254.765 272.343,254.768 272.352,254.77 272.362,254.772 272.371,254.775 272.38,254.777 272.389,254.779 272.398,254.782 272.408,254.784 272.417,254.786 272.426,254.789 272.435,254.791 272.444,254.793 272.454,254.796 272.463,254.798 272.472,254.8 272.481,254.803 272.49,254.805 272.499,254.807 272.509,254.81 272.518,254.812 272.527,254.815 272.536,254.817 272.545,254.819 272.555,254.822 272.564,254.824 272.573,254.826 272.582,254.829 272.591,254.831 272.601,254.833 272.61,254.836 272.619,254.838 272.628,254.84 272.637,254.843 272.647,254.845 272.656,254.847 272.665,254.85 272.674,254.852 272.683,254.854 272.692,254.857 272.702,254.859 272.711,254.861 272.72,254.864 272.729,254.866 272.738,254.868 272.748,254.871 272.757,254.873 272.766,254.876 272.775,254.878 272.784,254.88 272.794,254.883 272.803,254.885 272.812,254.887 272.821,254.89 272.83,254.892 272.839,254.894 272.849,254.897 272.858,254.899 272.867,254.901 272.876,254.904 272.885,254.906 272.895,254.908 272.904,254.911 272.913,254.913 272.922,254.915 272.931,254.918 272.941,254.92 272.95,254.922 272.959,254.925 272.968,254.927 272.977,254.929 272.987,254.932 272.996,254.934 273.005,254.937 273.014,254.939 273.023,254.941 273.032,254.944 273.042,254.946 273.051,254.948 273.06,254.951 273.069,254.953 273.078,254.955 273.088,254.958 273.097,254.96 273.106,254.962 273.115,254.965 273.124,254.967 273.134,254.969 273.143,254.972 273.152,254.974 273.161,254.976 273.17,254.979 273.179,254.981 273.189,254.983 273.198,254.986 273.207,254.988 273.216,254.99 273.225,254.993 273.235,254.995 273.244,254.998 273.253,255 273.262,255.002 273.271,255.005 273.281,255.007 273.29,255.009 273.299,255.012 273.308,255.014 273.317,255.016 273.327,255.019 273.336,255.021 273.345,255.023 273.354,255.026 273.363,255.028 273.372,255.03 273.382,255.033 273.391,255.035 273.4,255.037 273.409,255.04 273.418,255.042 273.428,255.044 273.437,255.047 273.446,255.049 273.455,255.051 273.464,255.054 273.474,255.056 273.483,255.059 273.492,255.061 273.501,255.063 273.51,255.066 273.519,255.068 273.529,255.07 273.538,255.073 273.547,255.075 273.556,255.077 273.565,255.08 273.575,255.082 273.584,255.084 273.593,255.087 273.602,255.089 273.611,255.091 273.621,255.094 273.63,255.096 273.639,255.098 273.648,255.101 273.657,255.103 273.667,255.105 273.676,255.108 273.685,255.11 273.694,255.112 273.703,255.115 273.712,255.117 273.722,255.119 273.731,255.122 273.74,255.124 273.749,255.127 273.758,255.129 273.768,255.131 273.777,255.134 273.786,255.136 273.795,255.138 273.804,255.141 273.814,255.143 273.823,255.145 273.832,255.148 273.841,255.15 273.85,255.152 273.859,255.155 273.869,255.157 273.878,255.159 273.887,255.162 273.896,255.164 273.905,255.166 273.915,255.169 273.924,255.171 273.933,255.173 273.942,255.176 273.951,255.178 273.961,255.18 273.97,255.183 273.979,255.185 273.988,255.187 273.997,255.19 274.007,255.192 274.016,255.194 274.025,255.197 274.034,255.199 274.043,255.202 274.052,255.204 274.062,255.206 274.071,255.209 274.08,255.211 274.089,255.213 274.098,255.216 274.108,255.218 274.117,255.22 274.126,255.223 274.135,255.225 274.144,255.227 274.154,255.23 274.163,255.232 274.172,255.234 274.181,255.237 274.19,255.239 274.199,255.241 274.209,255.244 274.218,255.246 274.227,255.248 274.236,255.251 274.245,255.253 274.255,255.255 274.264,255.258 274.273,255.26 274.282,255.262 274.291,255.265 274.301,255.267 274.31,255.269 274.319,255.272 274.328,255.274 274.337,255.277 274.347,255.279 274.356,255.281 274.365,255.284 274.374,255.286 274.383,255.288 274.392,255.291 274.402,255.293 274.411,255.295 274.42,255.298 274.429,255.3 274.438,255.302 274.448,255.305 274.457,255.307 274.466,255.309 274.475,255.312 274.484,255.314 274.494,255.316 274.503,255.319 274.512,255.321 274.521,255.323 274.53,255.326 274.539,255.328 274.549,255.33 274.558,255.333 274.567,255.335 274.576,255.337 274.585,255.34 274.595,255.342 274.604,255.344 274.613,255.347 274.622,255.349 274.631,255.352 274.641,255.354 274.65,255.356 274.659,255.359 274.668,255.361 274.677,255.363 274.687,255.366 274.696,255.368 274.705,255.37 274.714,255.373 274.723,255.375 274.732,255.377 274.742,255.38 274.751,255.382 274.76,255.384 274.769,255.387 274.778,255.389 274.788,255.391 274.797,255.394 274.806,255.396 274.815,255.398 274.824,255.401 274.834,255.403 274.843,255.405 274.852,255.408 274.861,255.41 274.87,255.412 274.88,255.415 274.889,255.417 274.898,255.419 274.907,255.422 274.916,255.424 274.925,255.426 274.935,255.429 274.944,255.431 274.953,255.433 274.962,255.436 274.971,255.438 274.981,255.441 274.99,255.443 274.999,255.445 275.008,255.448 275.017,255.45 275.027,255.452 275.036,255.455 275.045,255.457 275.054,255.459 275.063,255.462 275.072,255.464 275.082,255.466 275.091,255.469 275.1,255.471 275.109,255.473 275.118,255.476 275.128,255.478 275.137,255.48 275.146,255.483 275.155,255.485 275.164,255.487 275.174,255.49 275.183,255.492 275.192,255.494 275.201,255.497 275.21,255.499 275.22,255.501 275.229,255.504 275.238,255.506 275.247,255.508 275.256,255.511 275.265,255.513 275.275,255.515 275.284,255.518 275.293,255.52 275.302,255.522 275.311,255.525 275.321,255.527 275.33,255.53 275.339,255.532 275.348,255.534 275.357,255.537 275.367,255.539 275.376,255.541 275.385,255.544 275.394,255.546 275.403,255.548 275.412,255.551 275.422,255.553 275.431,255.555 275.44,255.558 275.449,255.56 275.458,255.562 275.468,255.565 275.477,255.567 275.486,255.569 275.495,255.572 275.504,255.574 275.514,255.576 275.523,255.579 275.532,255.581 275.541,255.583 275.55,255.586 275.56,255.588 275.569,255.59 275.578,255.593 275.587,255.595 275.596,255.597 275.605,255.6 275.615,255.602 275.624,255.604 275.633,255.607 275.642,255.609 275.651,255.611 275.661,255.614 275.67,255.616 275.679,255.618 275.688,255.621 275.697,255.623 275.707,255.626 275.716,255.628 275.725,255.63 275.734,255.633 275.743,255.635 275.752,255.637 275.762,255.64 275.771,255.642 275.78,255.644 275.789,255.647 275.798,255.649 275.808,255.651 275.817,255.654 275.826,255.656 275.835,255.658 275.844,255.661 275.854,255.663 275.863,255.665 275.872,255.668 275.881,255.67 275.89,255.672 275.9,255.675 275.909,255.677 275.918,255.679 275.927,255.682 275.936,255.684 275.945,255.686 275.955,255.689 275.964,255.691 275.973,255.693 275.982,255.696 275.991,255.698 276.001,255.7 276.01,255.703 276.019,255.705 276.028,255.707 276.037,255.71 276.047,255.712 276.056,255.714 276.065,255.717 276.074,255.719 276.083,255.721 276.092,255.724 276.102,255.726 276.111,255.728 276.12,255.731 276.129,255.733 276.138,255.736 276.148,255.738 276.157,255.74 276.166,255.743 276.175,255.745 276.184,255.747 276.194,255.75 276.203,255.752 276.212,255.754 276.221,255.757 276.23,255.759 276.24,255.761 276.249,255.764 276.258,255.766 276.267,255.768 276.276,255.771 276.285,255.773 276.295,255.775 276.304,255.778 276.313,255.78 276.322,255.782 276.331,255.785 276.341,255.787 276.35,255.789 276.359,255.792 276.368,255.794 276.377,255.796 276.387,255.799 276.396,255.801 276.405,255.803 276.414,255.806 276.423,255.808 276.432,255.81 276.442,255.813 276.451,255.815 276.46,255.817 276.469,255.82 276.478,255.822 276.488,255.824 276.497,255.827 276.506,255.829 276.515,255.831 276.524,255.834 276.534,255.836 276.543,255.838 276.552,255.841 276.561,255.843 276.57,255.845 276.58,255.848 276.589,255.85 276.598,255.852 276.607,255.855 276.616,255.857 276.625,255.86 276.635,255.862 276.644,255.864 276.653,255.867 276.662,255.869 276.671,255.871 276.681,255.874 276.69,255.876 276.699,255.878 276.708,255.881 276.717,255.883 276.727,255.885 276.736,255.888 276.745,255.89 276.754,255.892 276.763,255.895 276.772,255.897 276.782,255.899 276.791,255.902 276.8,255.904 276.809,255.906 276.818,255.909 276.828,255.911 276.837,255.913 276.846,255.916 276.855,255.918 276.864,255.92 276.874,255.923 276.883,255.925 276.892,255.927 276.901,255.93 276.91,255.932 276.92,255.934 276.929,255.937 276.938,255.939 276.947,255.941 276.956,255.944 276.965,255.946 276.975,255.948 276.984,255.951 276.993,255.953 277.002,255.955 277.011,255.958 277.021,255.96 277.03,255.962 277.039,255.965 277.048,255.967 277.057,255.969 277.067,255.972 277.076,255.974 277.085,255.976 277.094,255.979 277.103,255.981 277.112,255.983 277.122,255.986 277.131,255.988 277.14,255.99 277.149,255.993 277.158,255.995 277.168,255.997 277.177,256 277.186,256.002 277.195,256.005 277.204,256.007 277.214,256.009 277.223,256.012 277.232,256.014 277.241,256.016 277.25,256.019 277.26,256.021 277.269,256.023 277.278,256.026 277.287,256.028 277.296,256.03 277.305,256.033 277.315,256.035 277.324,256.037 277.333,256.04 277.342,256.042 277.351,256.044 277.361,256.047 277.37,256.049 277.379,256.051 277.388,256.054 277.397,256.056 277.407,256.058 277.416,256.061 277.425,256.063 277.434,256.065 277.443,256.068 277.453,256.07 277.462,256.072 277.471,256.075 277.48,256.077 277.489,256.079 277.498,256.082 277.508,256.084 277.517,256.086 277.526,256.089 277.535,256.091 277.544,256.093 277.554,256.096 277.563,256.098 277.572,256.1 277.581,256.103 277.59,256.105 277.6,256.107 277.609,256.11 277.618,256.112 277.627,256.114 277.636,256.117 277.645,256.119 277.655,256.121 277.664,256.124 277.673,256.126 277.682,256.128 277.691,256.131 277.701,256.133 277.71,256.135 277.719,256.138 277.728,256.14 277.737,256.142 277.747,256.145 277.756,256.147 277.765,256.149 277.774,256.152 277.783,256.154 277.793,256.156 277.802,256.159 277.811,256.161 277.82,256.163 277.829,256.166 277.838,256.168 277.848,256.17 277.857,256.173 277.866,256.175 277.875,256.177 277.884,256.18 277.894,256.182 277.903,256.184 277.912,256.187 277.921,256.189 277.93,256.191 277.94,256.194 277.949,256.196 277.958,256.199 277.967,256.201 277.976,256.203 277.985,256.206 277.995,256.208 278.004,256.21 278.013,256.213 278.022,256.215 278.031,256.217 278.041,256.22 278.05,256.222 278.059,256.224 278.068,256.227 278.077,256.229 278.087,256.231 278.096,256.234 278.105,256.236 278.114,256.238 278.123,256.241 278.133,256.243 278.142,256.245 278.151,256.248 278.16,256.25 278.169,256.252 278.178,256.255 278.188,256.257 278.197,256.259 278.206,256.262 278.215,256.264 278.224,256.266 278.234,256.269 278.243,256.271 278.252,256.273 278.261,256.276 278.27,256.278 278.28,256.28 278.289,256.283 278.298,256.285 278.307,256.287 278.316,256.29 278.325,256.292 278.335,256.294 278.344,256.297 278.353,256.299 278.362,256.301 278.371,256.304 278.381,256.306 278.39,256.308 278.399,256.311 278.408,256.313 278.417,256.315 278.427,256.318 278.436,256.32 278.445,256.322 278.454,256.325 278.463,256.327 278.473,256.329 278.482,256.332 278.491,256.334 278.5,256.336 278.509,256.339 278.518,256.341 278.528,256.343 278.537,256.346 278.546,256.348 278.555,256.35 278.564,256.353 278.574,256.355 278.583,256.357 278.592,256.36 278.601,256.362 278.61,256.364 278.62,256.367 278.629,256.369 278.638,256.371 278.647,256.374 278.656,256.376 278.665,256.378 278.675,256.381 278.684,256.383 278.693,256.385 278.702,256.388 278.711,256.39 278.721,256.392 278.73,256.395 278.739,256.397 278.748,256.399 278.757,256.402 278.767,256.404 278.776,256.406 278.785,256.409 278.794,256.411 278.803,256.413 278.813,256.416 278.822,256.418 278.831,256.42 278.84,256.423 278.849,256.425 278.858,256.427 278.868,256.43 278.877,256.432 278.886,256.434 278.895,256.437 278.904,256.439 278.914,256.441 278.923,256.444 278.932,256.446 278.941,256.448 278.95,256.451 278.96,256.453 278.969,256.455 278.978,256.458 278.987,256.46 278.996,256.462 279.005,256.465 279.015,256.467 279.024,256.469 279.033,256.472 279.042,256.474 279.051,256.476 279.061,256.479 279.07,256.481 279.079,256.483 279.088,256.486 279.097,256.488 279.107,256.49 279.116,256.493 279.125,256.495 279.134,256.497 279.143,256.5 279.153,256.502 279.162,256.504 279.171,256.507 279.18,256.509 279.189,256.511 279.198,256.514 279.208,256.516 279.217,256.518 279.226,256.521 279.235,256.523 279.244,256.525 279.254,256.528 279.263,256.53 279.272,256.532 279.281,256.535 279.29,256.537 279.3,256.539 279.309,256.542 279.318,256.544 279.327,256.546 279.336,256.549 279.345,256.551 279.355,256.553 279.364,256.556 279.373,256.558 279.382,256.56 279.391,256.563 279.401,256.565 279.41,256.567 279.419,256.57 279.428,256.572 279.437,256.574 279.447,256.577 279.456,256.579 279.465,256.581 279.474,256.584 279.483,256.586 279.493,256.588 279.502,256.591 279.511,256.593 279.52,256.595 279.529,256.598 279.538,256.6 279.548,256.602 279.557,256.605 279.566,256.607 279.575,256.609 279.584,256.612 279.594,256.614 279.603,256.616 279.612,256.619 279.621,256.621 279.63,256.623 279.64,256.626 279.649,256.628 279.658,256.63 279.667,256.633 279.676,256.635 279.685,256.637 279.695,256.64 279.704,256.642 279.713,256.644 279.722,256.647 279.731,256.649 279.741,256.651 279.75,256.654 279.759,256.656 279.768,256.658 279.777,256.661 279.787,256.663 279.796,256.665 279.805,256.668 279.814,256.67 279.823,256.672 279.833,256.675 279.842,256.677 279.851,256.679 279.86,256.682 279.869,256.684 279.878,256.686 279.888,256.689 279.897,256.691 279.906,256.693 279.915,256.696 279.924,256.698 279.934,256.7 279.943,256.703 279.952,256.705 279.961,256.707 279.97,256.71 279.98,256.712 279.989,256.714 279.998,256.717 280.007,256.719 280.016,256.721 280.026,256.724 280.035,256.726 280.044,256.728 280.053,256.731 280.062,256.733 280.071,256.735 280.081,256.738 280.09,256.74 280.099,256.742 280.108,256.745 280.117,256.747 280.127,256.749 280.136,256.752 280.145,256.754 280.154,256.756 280.163,256.759 280.173,256.761 280.182,256.763 280.191,256.766 280.2,256.768 280.209,256.77 280.218,256.773 280.228,256.775 280.237,256.777 280.246,256.78 280.255,256.782 280.264,256.784 280.274,256.787 280.283,256.789 280.292,256.791 280.301,256.794 280.31,256.796 280.32,256.798 280.329,256.801 280.338,256.803 280.347,256.805 280.356,256.808 280.366,256.81 280.375,256.812 280.384,256.815 280.393,256.817 280.402,256.819 280.411,256.822 280.421,256.824 280.43,256.826 280.439,256.829 280.448,256.831 280.457,256.833 280.467,256.836 280.476,256.838 280.485,256.84 280.494,256.843 280.503,256.845 280.513,256.847 280.522,256.85 280.531,256.852 280.54,256.854 280.549,256.857 280.558,256.859 280.568,256.861 280.577,256.864 280.586,256.866 280.595,256.868 280.604,256.871 280.614,256.873 280.623,256.875 280.632,256.878 280.641,256.88 280.65,256.882 280.66,256.885 280.669,256.887 280.678,256.889 280.687,256.892 280.696,256.894 280.706,256.896 280.715,256.899 280.724,256.901 280.733,256.903 280.742,256.906 280.751,256.908 280.761,256.91 280.77,256.913 280.779,256.915 280.788,256.917 280.797,256.92 280.807,256.922 280.816,256.924 280.825,256.927 280.834,256.929 280.843,256.931 280.853,256.934 280.862,256.936 280.871,256.938 280.88,256.941 280.889,256.943 280.898,256.945 280.908,256.948 280.917,256.95 280.926,256.952 280.935,256.955 280.944,256.957 280.954,256.959 280.963,256.962 280.972,256.964 280.981,256.966 280.99,256.969 281,256.971 281.009,256.973 281.018,256.976 281.027,256.978 281.036,256.98 281.046,256.983 281.055,256.985 281.064,256.987 281.073,256.99 281.082,256.992 281.091,256.994 281.101,256.997 281.11,256.999 281.119,257.001 281.128,257.004 281.137,257.006 281.147,257.008 281.156,257.011 281.165,257.013 281.174,257.015 281.183,257.018 281.193,257.02 281.202,257.022 281.211,257.025 281.22,257.027 281.229,257.029 281.238,257.032 281.248,257.034 281.257,257.036 281.266,257.039 281.275,257.041 281.284,257.043 281.294,257.046 281.303,257.048 281.312,257.05 281.321,257.053 281.33,257.055 281.34,257.057 281.349,257.06 281.358,257.062 281.367,257.064 281.376,257.067 281.386,257.069 281.395,257.071 281.404,257.073 281.413,257.076 281.422,257.078 281.431,257.08 281.441,257.083 281.45,257.085 281.459,257.087 281.468,257.09 281.477,257.092 281.487,257.094 281.496,257.097 281.505,257.099 281.514,257.101 281.523,257.104 281.533,257.106 281.542,257.108 281.551,257.111 281.56,257.113 281.569,257.115 281.578,257.118 281.588,257.12 281.597,257.122 281.606,257.125 281.615,257.127 281.624,257.129 281.634,257.132 281.643,257.134 281.652,257.136 281.661,257.139 281.67,257.141 281.68,257.143 281.689,257.146 281.698,257.148 281.707,257.15 281.716,257.153 281.726,257.155 281.735,257.157 281.744,257.16 281.753,257.162 281.762,257.164 281.771,257.167 281.781,257.169 281.79,257.171 281.799,257.174 281.808,257.176 281.817,257.178 281.827,257.181 281.836,257.183 281.845,257.185 281.854,257.188 281.863,257.19 281.873,257.192 281.882,257.195 281.891,257.197 281.9,257.199 281.909,257.202 281.918,257.204 281.928,257.206 281.937,257.209 281.946,257.211 281.955,257.213 281.964,257.216 281.974,257.218 281.983,257.22 281.992,257.223 282.001,257.225 282.01,257.227 282.02,257.23 282.029,257.232 282.038,257.234 282.047,257.237 282.056,257.239 282.066,257.241 282.075,257.244 282.084,257.246 282.093,257.248 282.102,257.251 282.111,257.253 282.121,257.255 282.13,257.258 282.139,257.26 282.148,257.262 282.157,257.265 282.167,257.267 282.176,257.269 282.185,257.271 282.194,257.274 282.203,257.276 282.213,257.278 282.222,257.281 282.231,257.283 282.24,257.285 282.249,257.288 282.259,257.29 282.268,257.292 282.277,257.295 282.286,257.297 282.295,257.299 282.304,257.302 282.314,257.304 282.323,257.306 282.332,257.309 282.341,257.311 282.35,257.313 282.36,257.316 282.369,257.318 282.378,257.32 282.387,257.323 282.396,257.325 282.406,257.327 282.415,257.33 282.424,257.332 282.433,257.334 282.442,257.337 282.451,257.339 282.461,257.341 282.47,257.344 282.479,257.346 282.488,257.348 282.497,257.351 282.507,257.353 282.516,257.355 282.525,257.358 282.534,257.36 282.543,257.362 282.553,257.365 282.562,257.367 282.571,257.369 282.58,257.372 282.589,257.374 282.599,257.376 282.608,257.379 282.617,257.381 282.626,257.383 282.635,257.386 282.644,257.388 282.654,257.39 282.663,257.393 282.672,257.395 282.681,257.397 282.69,257.4 282.7,257.402 282.709,257.404 282.718,257.407 282.727,257.409 282.736,257.411 282.746,257.414 282.755,257.416 282.764,257.418 282.773,257.42 282.782,257.423 282.791,257.425 282.801,257.427 282.81,257.43 282.819,257.432 282.828,257.434 282.837,257.437 282.847,257.439 282.856,257.441 282.865,257.444 282.874,257.446 282.883,257.448 282.893,257.451 282.902,257.453 282.911,257.455 282.92,257.458 282.929,257.46 282.939,257.462 282.948,257.465 282.957,257.467 282.966,257.469 282.975,257.472 282.984,257.474 282.994,257.476 283.003,257.479 283.012,257.481 283.021,257.483 283.03,257.486 283.04,257.488 283.049,257.49 283.058,257.493 283.067,257.495 283.076,257.497 283.086,257.5 283.095,257.502 283.104,257.504 283.113,257.507 283.122,257.509 283.131,257.511 283.141,257.514 283.15,257.516 283.159,257.518 283.168,257.521 283.177,257.523 283.187,257.525 283.196,257.528 283.205,257.53 283.214,257.532 283.223,257.535 283.233,257.537 283.242,257.539 283.251,257.541 283.26,257.544 283.269,257.546 283.279,257.548 283.288,257.551 283.297,257.553 283.306,257.555 283.315,257.558 283.324,257.56 283.334,257.562 283.343,257.565 283.352,257.567 283.361,257.569 283.37,257.572 283.38,257.574 283.389,257.576 283.398,257.579 283.407,257.581 283.416,257.583 283.426,257.586 283.435,257.588 283.444,257.59 283.453,257.593 283.462,257.595 283.471,257.597 283.481,257.6 283.49,257.602 283.499,257.604 283.508,257.607 283.517,257.609 283.527,257.611 283.536,257.614 283.545,257.616 283.554,257.618 283.563,257.621 283.573,257.623 283.582,257.625 283.591,257.628 283.6,257.63 283.609,257.632 283.619,257.635 283.628,257.637 283.637,257.639 283.646,257.642 283.655,257.644 283.664,257.646 283.674,257.648 283.683,257.651 283.692,257.653 283.701,257.655 283.71,257.658 283.72,257.66 283.729,257.662 283.738,257.665 283.747,257.667 283.756,257.669 283.766,257.672 283.775,257.674 283.784,257.676 283.793,257.679 283.802,257.681 283.811,257.683 283.821,257.686 283.83,257.688 283.839,257.69 283.848,257.693 283.857,257.695 283.867,257.697 283.876,257.7 283.885,257.702 283.894,257.704 283.903,257.707 283.913,257.709 283.922,257.711 283.931,257.714 283.94,257.716 283.949,257.718 283.959,257.721 283.968,257.723 283.977,257.725 283.986,257.728 283.995,257.73 284.004,257.732 284.014,257.735 284.023,257.737 284.032,257.739 284.041,257.742 284.05,257.744 284.06,257.746 284.069,257.748 284.078,257.751 284.087,257.753 284.096,257.755 284.106,257.758 284.115,257.76 284.124,257.762 284.133,257.765 284.142,257.767 284.151,257.769 284.161,257.772 284.17,257.774 284.179,257.776 284.188,257.779 284.197,257.781 284.207,257.783 284.216,257.786 284.225,257.788 284.234,257.79 284.243,257.793 284.253,257.795 284.262,257.797 284.271,257.8 284.28,257.802 284.289,257.804 284.299,257.807 284.308,257.809 284.317,257.811 284.326,257.814 284.335,257.816 284.344,257.818 284.354,257.821 284.363,257.823 284.372,257.825 284.381,257.828 284.39,257.83 284.4,257.832 284.409,257.834 284.418,257.837 284.427,257.839 284.436,257.841 284.446,257.844 284.455,257.846 284.464,257.848 284.473,257.851 284.482,257.853 284.491,257.855 284.501,257.858 284.51,257.86 284.519,257.862 284.528,257.865 284.537,257.867 284.547,257.869 284.556,257.872 284.565,257.874 284.574,257.876 284.583,257.879 284.593,257.881 284.602,257.883 284.611,257.886 284.62,257.888 284.629,257.89 284.639,257.893 284.648,257.895 284.657,257.897 284.666,257.9 284.675,257.902 284.684,257.904 284.694,257.907 284.703,257.909 284.712,257.911 284.721,257.914 284.73,257.916 284.74,257.918 284.749,257.92 284.758,257.923 284.767,257.925 284.776,257.927 284.786,257.93 284.795,257.932 284.804,257.934 284.813,257.937 284.822,257.939 284.832,257.941 284.841,257.944 284.85,257.946 284.859,257.948 284.868,257.951 284.877,257.953 284.887,257.955 284.896,257.958 284.905,257.96 284.914,257.962 284.923,257.965 284.933,257.967 284.942,257.969 284.951,257.972 284.96,257.974 284.969,257.976 284.979,257.979 284.988,257.981 284.997,257.983 285.006,257.986 285.015,257.988 285.024,257.99 285.034,257.993 285.043,257.995 285.052,257.997 285.061,257.999 285.07,258.002 285.08,258.004 285.089,258.006 285.098,258.009 285.107,258.011 285.116,258.013 285.126,258.016 285.135,258.018 285.144,258.02 285.153,258.023 285.162,258.025 285.172,258.027 285.181,258.03 285.19,258.032 285.199,258.034 285.208,258.037 285.217,258.039 285.227,258.041 285.236,258.044 285.245,258.046 285.254,258.048 285.263,258.051 285.273,258.053 285.282,258.055 285.291,258.058 285.3,258.06 285.309,258.062 285.319,258.065 285.328,258.067 285.337,258.069 285.346,258.071 285.355,258.074 285.364,258.076 285.374,258.078 285.383,258.081 285.392,258.083 285.401,258.085 285.41,258.088 285.42,258.09 285.429,258.092 285.438,258.095 285.447,258.097 285.456,258.099 285.466,258.102 285.475,258.104 285.484,258.106 285.493,258.109 285.502,258.111 285.512,258.113 285.521,258.116 285.53,258.118 285.539,258.12 285.548,258.123 285.557,258.125 285.567,258.127 285.576,258.13 285.585,258.132 285.594,258.134 285.603,258.137 285.613,258.139 285.622,258.141 285.631,258.143 285.64,258.146 285.649,258.148 285.659,258.15 285.668,258.153 285.677,258.155 285.686,258.157 285.695,258.16 285.704,258.162 285.714,258.164 285.723,258.167 285.732,258.169 285.741,258.171 285.75,258.174 285.76,258.176 285.769,258.178 285.778,258.181 285.787,258.183 285.796,258.185 285.806,258.188 285.815,258.19 285.824,258.192 285.833,258.195 285.842,258.197 285.852,258.199 285.861,258.202 285.87,258.204 285.879,258.206 285.888,258.208 285.897,258.211 285.907,258.213 285.916,258.215 285.925,258.218 285.934,258.22 285.943,258.222 285.953,258.225 285.962,258.227 285.971,258.229 285.98,258.232 285.989,258.234 285.999,258.236 286.008,258.239 286.017,258.241 286.026,258.243 286.035,258.246 286.044,258.248 286.054,258.25 286.063,258.253 286.072,258.255 286.081,258.257 286.09,258.26 286.1,258.262 286.109,258.264 286.118,258.267 286.127,258.269 286.136,258.271 286.146,258.273 286.155,258.276 286.164,258.278 286.173,258.28 286.182,258.283 286.192,258.285 286.201,258.287 286.21,258.29 286.219,258.292 286.228,258.294 286.237,258.297 286.247,258.299 286.256,258.301 286.265,258.304 286.274,258.306 286.283,258.308 286.293,258.311 286.302,258.313 286.311,258.315 286.32,258.318 286.329,258.32 286.339,258.322 286.348,258.325 286.357,258.327 286.366,258.329 286.375,258.332 286.384,258.334 286.394,258.336 286.403,258.338 286.412,258.341 286.421,258.343 286.43,258.345 286.44,258.348 286.449,258.35 286.458,258.352 286.467,258.355 286.476,258.357 286.486,258.359 286.495,258.362 286.504,258.364 286.513,258.366 286.522,258.369 286.532,258.371 286.541,258.373 286.55,258.376 286.559,258.378 286.568,258.38 286.577,258.383 286.587,258.385 286.596,258.387 286.605,258.39 286.614,258.392 286.623,258.394 286.633,258.396 286.642,258.399 286.651,258.401 286.66,258.403 286.669,258.406 286.679,258.408 286.688,258.41 286.697,258.413 286.706,258.415 286.715,258.417 286.724,258.42 286.734,258.422 286.743,258.424 286.752,258.427 286.761,258.429 286.77,258.431 286.78,258.434 286.789,258.436 286.798,258.438 286.807,258.441 286.816,258.443 286.826,258.445 286.835,258.448 286.844,258.45 286.853,258.452 286.862,258.454 286.872,258.457 286.881,258.459 286.89,258.461 286.899,258.464 286.908,258.466 286.917,258.468 286.927,258.471 286.936,258.473 286.945,258.475 286.954,258.478 286.963,258.48 286.973,258.482 286.982,258.485 286.991,258.487 287,258.489 287.009,258.492 287.019,258.494 287.028,258.496 287.037,258.499 287.046,258.501 287.055,258.503 287.064,258.506 287.074,258.508 287.083,258.51 287.092,258.512 287.101,258.515 287.11,258.517 287.12,258.519 287.129,258.522 287.138,258.524 287.147,258.526 287.156,258.529 287.166,258.531 287.175,258.533 287.184,258.536 287.193,258.538 287.202,258.54 287.212,258.543 287.221,258.545 287.23,258.547 287.239,258.55 287.248,258.552 287.257,258.554 287.267,258.557 287.276,258.559 287.285,258.561 287.294,258.563 287.303,258.566 287.313,258.568 287.322,258.57 287.331,258.573 287.34,258.575 287.349,258.577 287.359,258.58 287.368,258.582 287.377,258.584 287.386,258.587 287.395,258.589 287.405,258.591 287.414,258.594 287.423,258.596 287.432,258.598 287.441,258.601 287.45,258.603 287.46,258.605 287.469,258.608 287.478,258.61 287.487,258.612 287.496,258.615 287.506,258.617 287.515,258.619 287.524,258.621 287.533,258.624 287.542,258.626 287.552,258.628 287.561,258.631 287.57,258.633 287.579,258.635 287.588,258.638 287.597,258.64 287.607,258.642 287.616,258.645 287.625,258.647 287.634,258.649 287.643,258.652 287.653,258.654 287.662,258.656 287.671,258.659 287.68,258.661 287.689,258.663 287.699,258.666 287.708,258.668 287.717,258.67 287.726,258.672 287.735,258.675 287.745,258.677 287.754,258.679 287.763,258.682 287.772,258.684 287.781,258.686 287.79,258.689 287.8,258.691 287.809,258.693 287.818,258.696 287.827,258.698 287.836,258.7 287.846,258.703 287.855,258.705 287.864,258.707 287.873,258.71 287.882,258.712 287.892,258.714 287.901,258.717 287.91,258.719 287.919,258.721 287.928,258.723 287.937,258.726 287.947,258.728 287.956,258.73 287.965,258.733 287.974,258.735 287.983,258.737 287.993,258.74 288.002,258.742 288.011,258.744 288.02,258.747 288.029,258.749 288.039,258.751 288.048,258.754 288.057,258.756 288.066,258.758 288.075,258.761 288.085,258.763 288.094,258.765 288.103,258.767 288.112,258.77 288.121,258.772 288.13,258.774 288.14,258.777 288.149,258.779 288.158,258.781 288.167,258.784 288.176,258.786 288.186,258.788 288.195,258.791 288.204,258.793 288.213,258.795 288.222,258.798 288.232,258.8 288.241,258.802 288.25,258.805 288.259,258.807 288.268,258.809 288.277,258.812 288.287,258.814 288.296,258.816 288.305,258.818 288.314,258.821 288.323,258.823 288.333,258.825 288.342,258.828 288.351,258.83 288.36,258.832 288.369,258.835 288.379,258.837 288.388,258.839 288.397,258.842 288.406,258.844 288.415,258.846 288.425,258.849 288.434,258.851 288.443,258.853 288.452,258.856 288.461,258.858 288.47,258.86 288.48,258.862 288.489,258.865 288.498,258.867 288.507,258.869 288.516,258.872 288.526,258.874 288.535,258.876 288.544,258.879 288.553,258.881 288.562,258.883 288.572,258.886 288.581,258.888 288.59,258.89 288.599,258.893 288.608,258.895 288.617,258.897 288.627,258.9 288.636,258.902 288.645,258.904 288.654,258.907 288.663,258.909 288.673,258.911 288.682,258.913 288.691,258.916 288.7,258.918 288.709,258.92 288.719,258.923 288.728,258.925 288.737,258.927 288.746,258.93 288.755,258.932 288.765,258.934 288.774,258.937 288.783,258.939 288.792,258.941 288.801,258.944 288.81,258.946 288.82,258.948 288.829,258.951 288.838,258.953 288.847,258.955 288.856,258.957 288.866,258.96 288.875,258.962 288.884,258.964 288.893,258.967 288.902,258.969 288.912,258.971 288.921,258.974 288.93,258.976 288.939,258.978 288.948,258.981 288.957,258.983 288.967,258.985 288.976,258.988 288.985,258.99 288.994,258.992 289.003,258.995 289.013,258.997 289.022,258.999 289.031,259.001 289.04,259.004 289.049,259.006 289.059,259.008 289.068,259.011 289.077,259.013 289.086,259.015 289.095,259.018 289.105,259.02 289.114,259.022 289.123,259.025 289.132,259.027 289.141,259.029 289.15,259.032 289.16,259.034 289.169,259.036 289.178,259.039 289.187,259.041 289.196,259.043 289.206,259.045 289.215,259.048 289.224,259.05 289.233,259.052 289.242,259.055 289.252,259.057 289.261,259.059 289.27,259.062 289.279,259.064 289.288,259.066 289.297,259.069 289.307,259.071 289.316,259.073 289.325,259.076 289.334,259.078 289.343,259.08 289.353,259.082 289.362,259.085 289.371,259.087 289.38,259.089 289.389,259.092 289.399,259.094 289.408,259.096 289.417,259.099 289.426,259.101 289.435,259.103 289.445,259.106 289.454,259.108 289.463,259.11 289.472,259.113 289.481,259.115 289.49,259.117 289.5,259.12 289.509,259.122 289.518,259.124 289.527,259.126 289.536,259.129 289.546,259.131 289.555,259.133 289.564,259.136 289.573,259.138 289.582,259.14 289.592,259.143 289.601,259.145 289.61,259.147 289.619,259.15 289.628,259.152 289.638,259.154 289.647,259.157 289.656,259.159 289.665,259.161 289.674,259.164 289.683,259.166 289.693,259.168 289.702,259.17 289.711,259.173 289.72,259.175 289.729,259.177 289.739,259.18 289.748,259.182 289.757,259.184 289.766,259.187 289.775,259.189 289.785,259.191 289.794,259.194 289.803,259.196 289.812,259.198 289.821,259.201 289.83,259.203 289.84,259.205 289.849,259.207 289.858,259.21 289.867,259.212 289.876,259.214 289.886,259.217 289.895,259.219 289.904,259.221 289.913,259.224 289.922,259.226 289.932,259.228 289.941,259.231 289.95,259.233 289.959,259.235 289.968,259.238 289.978,259.24 289.987,259.242 289.996,259.245 290.005,259.247 290.014,259.249 290.023,259.251 290.033,259.254 290.042,259.256 290.051,259.258 290.06,259.261 290.069,259.263 290.079,259.265 290.088,259.268 290.097,259.27 290.106,259.272 290.115,259.275 290.125,259.277 290.134,259.279 290.143,259.282 290.152,259.284 290.161,259.286 290.17,259.288 290.18,259.291 290.189,259.293 290.198,259.295 290.207,259.298 290.216,259.3 290.226,259.302 290.235,259.305 290.244,259.307 290.253,259.309 290.262,259.312 290.272,259.314 290.281,259.316 290.29,259.319 290.299,259.321 290.308,259.323 290.318,259.325 290.327,259.328 290.336,259.33 290.345,259.332 290.354,259.335 290.363,259.337 290.373,259.339 290.382,259.342 290.391,259.344 290.4,259.346 290.409,259.349 290.419,259.351 290.428,259.353 290.437,259.356 290.446,259.358 290.455,259.36 290.465,259.362 290.474,259.365 290.483,259.367 290.492,259.369 290.501,259.372 290.51,259.374 290.52,259.376 290.529,259.379 290.538,259.381 290.547,259.383 290.556,259.386 290.566,259.388 290.575,259.39 290.584,259.393 290.593,259.395 290.602,259.397 290.612,259.399 290.621,259.402 290.63,259.404 290.639,259.406 290.648,259.409 290.658,259.411 290.667,259.413 290.676,259.416 290.685,259.418 290.694,259.42 290.703,259.423 290.713,259.425 290.722,259.427 290.731,259.43 290.74,259.432 290.749,259.434 290.759,259.436 290.768,259.439 290.777,259.441 290.786,259.443 290.795,259.446 290.805,259.448 290.814,259.45 290.823,259.453 290.832,259.455 290.841,259.457 290.85,259.46 290.86,259.462 290.869,259.464 290.878,259.467 290.887,259.469 290.896,259.471 290.906,259.473 290.915,259.476 290.924,259.478 290.933,259.48 290.942,259.483 290.952,259.485 290.961,259.487 290.97,259.49 290.979,259.492 290.988,259.494 290.998,259.497 291.007,259.499 291.016,259.501 291.025,259.504 291.034,259.506 291.043,259.508 291.053,259.51 291.062,259.513 291.071,259.515 291.08,259.517 291.089,259.52 291.099,259.522 291.108,259.524 291.117,259.527 291.126,259.529 291.135,259.531 291.145,259.534 291.154,259.536 291.163,259.538 291.172,259.541 291.181,259.543 291.19,259.545 291.2,259.547 291.209,259.55 291.218,259.552 291.227,259.554 291.236,259.557 291.246,259.559 291.255,259.561 291.264,259.564 291.273,259.566 291.282,259.568 291.292,259.571 291.301,259.573 291.31,259.575 291.319,259.578 291.328,259.58 291.338,259.582 291.347,259.584 291.356,259.587 291.365,259.589 291.374,259.591 291.383,259.594 291.393,259.596 291.402,259.598 291.411,259.601 291.42,259.603 291.429,259.605 291.439,259.608 291.448,259.61 291.457,259.612 291.466,259.615 291.475,259.617 291.485,259.619 291.494,259.621 291.503,259.624 291.512,259.626 291.521,259.628 291.53,259.631 291.54,259.633 291.549,259.635 291.558,259.638 291.567,259.64 291.576,259.642 291.586,259.645 291.595,259.647 291.604,259.649 291.613,259.651 291.622,259.654 291.632,259.656 291.641,259.658 291.65,259.661 291.659,259.663 291.668,259.665 291.678,259.668 291.687,259.67 291.696,259.672 291.705,259.675 291.714,259.677 291.723,259.679 291.733,259.682 291.742,259.684 291.751,259.686 291.76,259.688 291.769,259.691 291.779,259.693 291.788,259.695 291.797,259.698 291.806,259.7 291.815,259.702 291.825,259.705 291.834,259.707 291.843,259.709 291.852,259.712 291.861,259.714 291.87,259.716 291.88,259.718 291.889,259.721 291.898,259.723 291.907,259.725 291.916,259.728 291.926,259.73 291.935,259.732 291.944,259.735 291.953,259.737 291.962,259.739 291.972,259.742 291.981,259.744 291.99,259.746 291.999,259.749 292.008,259.751 292.018,259.753 292.027,259.755 292.036,259.758 292.045,259.76 292.054,259.762 292.063,259.765 292.073,259.767 292.082,259.769 292.091,259.772 292.1,259.774 292.109,259.776 292.119,259.779 292.128,259.781 292.137,259.783 292.146,259.785 292.155,259.788 292.165,259.79 292.174,259.792 292.183,259.795 292.192,259.797 292.201,259.799 292.211,259.802 292.22,259.804 292.229,259.806 292.238,259.809 292.247,259.811 292.256,259.813 292.266,259.815 292.275,259.818 292.284,259.82 292.293,259.822 292.302,259.825 292.312,259.827 292.321,259.829 292.33,259.832 292.339,259.834 292.348,259.836 292.358,259.839 292.367,259.841 292.376,259.843 292.385,259.846 292.394,259.848 292.403,259.85 292.413,259.852 292.422,259.855 292.431,259.857 292.44,259.859 292.449,259.862 292.459,259.864 292.468,259.866 292.477,259.869 292.486,259.871 292.495,259.873 292.505,259.876 292.514,259.878 292.523,259.88 292.532,259.882 292.541,259.885 292.551,259.887 292.56,259.889 292.569,259.892 292.578,259.894 292.587,259.896 292.596,259.899 292.606,259.901 292.615,259.903 292.624,259.906 292.633,259.908 292.642,259.91 292.652,259.912 292.661,259.915 292.67,259.917 292.679,259.919 292.688,259.922 292.698,259.924 292.707,259.926 292.716,259.929 292.725,259.931 292.734,259.933 292.743,259.936 292.753,259.938 292.762,259.94 292.771,259.942 292.78,259.945 292.789,259.947 292.799,259.949 292.808,259.952 292.817,259.954 292.826,259.956 292.835,259.959 292.845,259.961 292.854,259.963 292.863,259.966 292.872,259.968 292.881,259.97 292.891,259.973 292.9,259.975 292.909,259.977 292.918,259.979 292.927,259.982 292.936,259.984 292.946,259.986 292.955,259.989 292.964,259.991 292.973,259.993 292.982,259.996 292.992,259.998 293.001,260 293.01,260.003 293.019,260.005 293.028,260.007 293.038,260.009 293.047,260.012 293.056,260.014 293.065,260.016 293.074,260.019 293.083,260.021 293.093,260.023 293.102,260.026 293.111,260.028 293.12,260.03 293.129,260.033 293.139,260.035 293.148,260.037 293.157,260.039 293.166,260.042 293.175,260.044 293.185,260.046 293.194,260.049 293.203,260.051 293.212,260.053 293.221,260.056 293.231,260.058 293.24,260.06 293.249,260.063 293.258,260.065 293.267,260.067 293.276,260.069 293.286,260.072 293.295,260.074 293.304,260.076 293.313,260.079 293.322,260.081 293.332,260.083 293.341,260.086 293.35,260.088 293.359,260.09 293.368,260.093 293.378,260.095 293.387,260.097 293.396,260.099 293.405,260.102 293.414,260.104 293.423,260.106 293.433,260.109 293.442,260.111 293.451,260.113 293.46,260.116 293.469,260.118 293.479,260.12 293.488,260.123 293.497,260.125 293.506,260.127 293.515,260.129 293.525,260.132 293.534,260.134 293.543,260.136 293.552,260.139 293.561,260.141 293.571,260.143 293.58,260.146 293.589,260.148 293.598,260.15 293.607,260.153 293.616,260.155 293.626,260.157 293.635,260.159 293.644,260.162 293.653,260.164 293.662,260.166 293.672,260.169 293.681,260.171 293.69,260.173 293.699,260.176 293.708,260.178 293.718,260.18 293.727,260.183 293.736,260.185 293.745,260.187 293.754,260.189 293.763,260.192 293.773,260.194 293.782,260.196 293.791,260.199 293.8,260.201 293.809,260.203 293.819,260.206 293.828,260.208 293.837,260.21 293.846,260.212 293.855,260.215 293.865,260.217 293.874,260.219 293.883,260.222 293.892,260.224 293.901,260.226 293.911,260.229 293.92,260.231 293.929,260.233 293.938,260.236 293.947,260.238 293.956,260.24 293.966,260.242 293.975,260.245 293.984,260.247 293.993,260.249 294.002,260.252 294.012,260.254 294.021,260.256 294.03,260.259 294.039,260.261 294.048,260.263 294.058,260.266 294.067,260.268 294.076,260.27 294.085,260.272 294.094,260.275 294.103,260.277 294.113,260.279 294.122,260.282 294.131,260.284 294.14,260.286 294.149,260.289 294.159,260.291 294.168,260.293 294.177,260.296 294.186,260.298 294.195,260.3 294.205,260.302 294.214,260.305 294.223,260.307 294.232,260.309 294.241,260.312 294.251,260.314 294.26,260.316 294.269,260.319 294.278,260.321 294.287,260.323 294.296,260.325 294.306,260.328 294.315,260.33 294.324,260.332 294.333,260.335 294.342,260.337 294.352,260.339 294.361,260.342 294.37,260.344 294.379,260.346 294.388,260.349 294.398,260.351 294.407,260.353 294.416,260.355 294.425,260.358 294.434,260.36 294.443,260.362 294.453,260.365 294.462,260.367 294.471,260.369 294.48,260.372 294.489,260.374 294.499,260.376 294.508,260.379 294.517,260.381 294.526,260.383 294.535,260.385 294.545,260.388 294.554,260.39 294.563,260.392 294.572,260.395 294.581,260.397 294.591,260.399 294.6,260.402 294.609,260.404 294.618,260.406 294.627,260.408 294.636,260.411 294.646,260.413 294.655,260.415 294.664,260.418 294.673,260.42 294.682,260.422 294.692,260.425 294.701,260.427 294.71,260.429 294.719,260.432 294.728,260.434 294.738,260.436 294.747,260.438 294.756,260.441 294.765,260.443 294.774,260.445 294.784,260.448 294.793,260.45 294.802,260.452 294.811,260.455 294.82,260.457 294.829,260.459 294.839,260.462 294.848,260.464 294.857,260.466 294.866,260.468 294.875,260.471 294.885,260.473 294.894,260.475 294.903,260.478 294.912,260.48 294.921,260.482 294.931,260.485 294.94,260.487 294.949,260.489 294.958,260.491 294.967,260.494 294.976,260.496 294.986,260.498 294.995,260.501 295.004,260.503 295.013,260.505 295.022,260.508 295.032,260.51 295.041,260.512 295.05,260.515 295.059,260.517 295.068,260.519 295.078,260.521 295.087,260.524 295.096,260.526 295.105,260.528 295.114,260.531 295.124,260.533 295.133,260.535 295.142,260.538 295.151,260.54 295.16,260.542 295.169,260.544 295.179,260.547 295.188,260.549 295.197,260.551 295.206,260.554 295.215,260.556 295.225,260.558 295.234,260.561 295.243,260.563 295.252,260.565 295.261,260.568 295.271,260.57 295.28,260.572 295.289,260.574 295.298,260.577 295.307,260.579 295.316,260.581 295.326,260.584 295.335,260.586 295.344,260.588 295.353,260.591 295.362,260.593 295.372,260.595 295.381,260.597 295.39,260.6 295.399,260.602 295.408,260.604 295.418,260.607 295.427,260.609 295.436,260.611 295.445,260.614 295.454,260.616 295.464,260.618 295.473,260.62 295.482,260.623 295.491,260.625 295.5,260.627 295.509,260.63 295.519,260.632 295.528,260.634 295.537,260.637 295.546,260.639 295.555,260.641 295.565,260.644 295.574,260.646 295.583,260.648 295.592,260.65 295.601,260.653 295.611,260.655 295.62,260.657 295.629,260.66 295.638,260.662 295.647,260.664 295.656,260.667 295.666,260.669 295.675,260.671 295.684,260.673 295.693,260.676 295.702,260.678 295.712,260.68 295.721,260.683 295.73,260.685 295.739,260.687 295.748,260.69 295.758,260.692 295.767,260.694 295.776,260.696 295.785,260.699 295.794,260.701 295.804,260.703 295.813,260.706 295.822,260.708 295.831,260.71 295.84,260.713 295.849,260.715 295.859,260.717 295.868,260.72 295.877,260.722 295.886,260.724 295.895,260.726 295.905,260.729 295.914,260.731 295.923,260.733 295.932,260.736 295.941,260.738 295.951,260.74 295.96,260.743 295.969,260.745 295.978,260.747 295.987,260.749 295.996,260.752 296.006,260.754 296.015,260.756 296.024,260.759 296.033,260.761 296.042,260.763 296.052,260.766 296.061,260.768 296.07,260.77 296.079,260.772 296.088,260.775 296.098,260.777 296.107,260.779 296.116,260.782 296.125,260.784 296.134,260.786 296.144,260.789 296.153,260.791 296.162,260.793 296.171,260.796 296.18,260.798 296.189,260.8 296.199,260.802 296.208,260.805 296.217,260.807 296.226,260.809 296.235,260.812 296.245,260.814 296.254,260.816 296.263,260.819 296.272,260.821 296.281,260.823 296.291,260.825 296.3,260.828 296.309,260.83 296.318,260.832 296.327,260.835 296.336,260.837 296.346,260.839 296.355,260.842 296.364,260.844 296.373,260.846 296.382,260.848 296.392,260.851 296.401,260.853 296.41,260.855 296.419,260.858 296.428,260.86 296.438,260.862 296.447,260.865 296.456,260.867 296.465,260.869 296.474,260.871 296.484,260.874 296.493,260.876 296.502,260.878 296.511,260.881 296.52,260.883 296.529,260.885 296.539,260.888 296.548,260.89 296.557,260.892 296.566,260.894 296.575,260.897 296.585,260.899 296.594,260.901 296.603,260.904 296.612,260.906 296.621,260.908 296.631,260.911 296.64,260.913 296.649,260.915 296.658,260.918 296.667,260.92 296.676,260.922 296.686,260.924 296.695,260.927 296.704,260.929 296.713,260.931 296.722,260.934 296.732,260.936 296.741,260.938 296.75,260.941 296.759,260.943 296.768,260.945 296.778,260.947 296.787,260.95 296.796,260.952 296.805,260.954 296.814,260.957 296.824,260.959 296.833,260.961 296.842,260.964 296.851,260.966 296.86,260.968 296.869,260.97 296.879,260.973 296.888,260.975 296.897,260.977 296.906,260.98 296.915,260.982 296.925,260.984 296.934,260.987 296.943,260.989 296.952,260.991 296.961,260.993 296.971,260.996 296.98,260.998 296.989,261 296.998,261.003 297.007,261.005 297.017,261.007 297.026,261.01 297.035,261.012 297.044,261.014 297.053,261.016 297.062,261.019 297.072,261.021 297.081,261.023 297.09,261.026 297.099,261.028 297.108,261.03 297.118,261.033 297.127,261.035 297.136,261.037 297.145,261.039 297.154,261.042 297.164,261.044 297.173,261.046 297.182,261.049 297.191,261.051 297.2,261.053 297.209,261.056 297.219,261.058 297.228,261.06 297.237,261.062 297.246,261.065 297.255,261.067 297.265,261.069 297.274,261.072 297.283,261.074 297.292,261.076 297.301,261.079 297.311,261.081 297.32,261.083 297.329,261.085 297.338,261.088 297.347,261.09 297.357,261.092 297.366,261.095 297.375,261.097 297.384,261.099 297.393,261.102 297.402,261.104 297.412,261.106 297.421,261.108 297.43,261.111 297.439,261.113 297.448,261.115 297.458,261.118 297.467,261.12 297.476,261.122 297.485,261.125 297.494,261.127 297.504,261.129 297.513,261.131 297.522,261.134 297.531,261.136 297.54,261.138 297.549,261.141 297.559,261.143 297.568,261.145 297.577,261.148 297.586,261.15 297.595,261.152 297.605,261.154 297.614,261.157 297.623,261.159 297.632,261.161 297.641,261.164 297.651,261.166 297.66,261.168 297.669,261.171 297.678,261.173 297.687,261.175 297.697,261.177 297.706,261.18 297.715,261.182 297.724,261.184 297.733,261.187 297.742,261.189 297.752,261.191 297.761,261.194 297.77,261.196 297.779,261.198 297.788,261.2 297.798,261.203 297.807,261.205 297.816,261.207 297.825,261.21 297.834,261.212 297.844,261.214 297.853,261.217 297.862,261.219 297.871,261.221 297.88,261.223 297.889,261.226 297.899,261.228 297.908,261.23 297.917,261.233 297.926,261.235 297.935,261.237 297.945,261.24 297.954,261.242 297.963,261.244 297.972,261.246 297.981,261.249 297.991,261.251 298,261.253 298.009,261.256 298.018,261.258 298.027,261.26 298.037,261.263 298.046,261.265 298.055,261.267 298.064,261.269 298.073,261.272 298.082,261.274 298.092,261.276 298.101,261.279 298.11,261.281 298.119,261.283 298.128,261.285 298.138,261.288 298.147,261.29 298.156,261.292 298.165,261.295 298.174,261.297 298.184,261.299 298.193,261.302 298.202,261.304 298.211,261.306 298.22,261.308 298.229,261.311 298.239,261.313 298.248,261.315 298.257,261.318 298.266,261.32 298.275,261.322 298.285,261.325 298.294,261.327 298.303,261.329 298.312,261.331 298.321,261.334 298.331,261.336 298.34,261.338 298.349,261.341 298.358,261.343 298.367,261.345 298.377,261.348 298.386,261.35 298.395,261.352 298.404,261.354 298.413,261.357 298.422,261.359 298.432,261.361 298.441,261.364 298.45,261.366 298.459,261.368 298.468,261.371 298.478,261.373 298.487,261.375 298.496,261.377 298.505,261.38 298.514,261.382 298.524,261.384 298.533,261.387 298.542,261.389 298.551,261.391 298.56,261.394 298.569,261.396 298.579,261.398 298.588,261.4 298.597,261.403 298.606,261.405 298.615,261.407 298.625,261.41 298.634,261.412 298.643,261.414 298.652,261.416 298.661,261.419 298.671,261.421 298.68,261.423 298.689,261.426 298.698,261.428 298.707,261.43 298.717,261.433 298.726,261.435 298.735,261.437 298.744,261.439 298.753,261.442 298.762,261.444 298.772,261.446 298.781,261.449 298.79,261.451 298.799,261.453 298.808,261.456 298.818,261.458 298.827,261.46 298.836,261.462 298.845,261.465 298.854,261.467 298.864,261.469 298.873,261.472 298.882,261.474 298.891,261.476 298.9,261.479 298.909,261.481 298.919,261.483 298.928,261.485 298.937,261.488 298.946,261.49 298.955,261.492 298.965,261.495 298.974,261.497 298.983,261.499 298.992,261.501 299.001,261.504 299.011,261.506 299.02,261.508 299.029,261.511 299.038,261.513 299.047,261.515 299.057,261.518 299.066,261.52 299.075,261.522 299.084,261.524 299.093,261.527 299.102,261.529 299.112,261.531 299.121,261.534 299.13,261.536 299.139,261.538 299.148,261.541 299.158,261.543 299.167,261.545 299.176,261.547 299.185,261.55 299.194,261.552 299.204,261.554 299.213,261.557 299.222,261.559 299.231,261.561 299.24,261.563 299.249,261.566 299.259,261.568 299.268,261.57 299.277,261.573 299.286,261.575 299.295,261.577 299.305,261.58 299.314,261.582 299.323,261.584 299.332,261.586 299.341,261.589 299.351,261.591 299.36,261.593 299.369,261.596 299.378,261.598 299.387,261.6 299.397,261.603 299.406,261.605 299.415,261.607 299.424,261.609 299.433,261.612 299.442,261.614 299.452,261.616 299.461,261.619 299.47,261.621 299.479,261.623 299.488,261.625 299.498,261.628 299.507,261.63 299.516,261.632 299.525,261.635 299.534,261.637 299.544,261.639 299.553,261.642 299.562,261.644 299.571,261.646 299.58,261.648 299.59,261.651 299.599,261.653 299.608,261.655 299.617,261.658 299.626,261.66 299.635,261.662 299.645,261.665 299.654,261.667 299.663,261.669 299.672,261.671 299.681,261.674 299.691,261.676 299.7,261.678 299.709,261.681 299.718,261.683 299.727,261.685 299.737,261.687 299.746,261.69 299.755,261.692 299.764,261.694 299.773,261.697 299.782,261.699 299.792,261.701 299.801,261.704 299.81,261.706 299.819,261.708 299.828,261.71 299.838,261.713 299.847,261.715 299.856,261.717 299.865,261.72 299.874,261.722 299.884,261.724 299.893,261.727 299.902,261.729 299.911,261.731 299.92,261.733 299.93,261.736 299.939,261.738 299.948,261.74 299.957,261.743 299.966,261.745 299.975,261.747 299.985,261.749 299.994,261.752 300.003,261.754 300.012,261.756 300.021,261.759 300.031,261.761 300.04,261.763 300.049,261.766 300.058,261.768 300.067,261.77 300.077,261.772 300.086,261.775 300.095,261.777 300.104,261.779 300.113,261.782 300.122,261.784 300.132,261.786 300.141,261.788 300.15,261.791 300.159,261.793 300.168,261.795 300.178,261.798 300.187,261.8 300.196,261.802 300.205,261.805 300.214,261.807 300.224,261.809 300.233,261.811 300.242,261.814 300.251,261.816 300.26,261.818 300.27,261.821 300.279,261.823 300.288,261.825 300.297,261.827 300.306,261.83 300.315,261.832 300.325,261.834 300.334,261.837 300.343,261.839 300.352,261.841 300.361,261.844 300.371,261.846 300.38,261.848 300.389,261.85 300.398,261.853 300.407,261.855 300.417,261.857 300.426,261.86 300.435,261.862 300.444,261.864 300.453,261.866 300.462,261.869 300.472,261.871 300.481,261.873 300.49,261.876 300.499,261.878 300.508,261.88 300.518,261.883 300.527,261.885 300.536,261.887 300.545,261.889 300.554,261.892 300.564,261.894 300.573,261.896 300.582,261.899 300.591,261.901 300.6,261.903 300.61,261.905 300.619,261.908 300.628,261.91 300.637,261.912 300.646,261.915 300.655,261.917 300.665,261.919 300.674,261.922 300.683,261.924 300.692,261.926 300.701,261.928 300.711,261.931 300.72,261.933 300.729,261.935 300.738,261.938 300.747,261.94 300.757,261.942 300.766,261.944 300.775,261.947 300.784,261.949 300.793,261.951 300.802,261.954 300.812,261.956 300.821,261.958 300.83,261.961 300.839,261.963 300.848,261.965 300.858,261.967 300.867,261.97 300.876,261.972 300.885,261.974 300.894,261.977 300.904,261.979 300.913,261.981 300.922,261.983 300.931,261.986 300.94,261.988 300.95,261.99 300.959,261.993 300.968,261.995 300.977,261.997 300.986,262 300.995,262.002 301.005,262.004 301.014,262.006 301.023,262.009 301.032,262.011 301.041,262.013 301.051,262.016 301.06,262.018 301.069,262.02 301.078,262.022 301.087,262.025 301.097,262.027 301.106,262.029 301.115,262.032 301.124,262.034 301.133,262.036 301.142,262.039 301.152,262.041 301.161,262.043 301.17,262.045 301.179,262.048 301.188,262.05 301.198,262.052 301.207,262.055 301.216,262.057 301.225,262.059 301.234,262.061 301.244,262.064 301.253,262.066 301.262,262.068 301.271,262.071 301.28,262.073 301.29,262.075 301.299,262.077 301.308,262.08 301.317,262.082 301.326,262.084 301.335,262.087 301.345,262.089 301.354,262.091 301.363,262.094 301.372,262.096 301.381,262.098 301.391,262.1 301.4,262.103 301.409,262.105 301.418,262.107 301.427,262.11 301.437,262.112 301.446,262.114 301.455,262.116 301.464,262.119 301.473,262.121 301.482,262.123 301.492,262.126 301.501,262.128 301.51,262.13 301.519,262.133 301.528,262.135 301.538,262.137 301.547,262.139 301.556,262.142 301.565,262.144 301.574,262.146 301.584,262.149 301.593,262.151 301.602,262.153 301.611,262.155 301.62,262.158 301.63,262.16 301.639,262.162 301.648,262.165 301.657,262.167 301.666,262.169 301.675,262.171 301.685,262.174 301.694,262.176 301.703,262.178 301.712,262.181 301.721,262.183 301.731,262.185 301.74,262.188 301.749,262.19 301.758,262.192 301.767,262.194 301.777,262.197 301.786,262.199 301.795,262.201 301.804,262.204 301.813,262.206 301.822,262.208 301.832,262.21 301.841,262.213 301.85,262.215 301.859,262.217 301.868,262.22 301.878,262.222 301.887,262.224 301.896,262.226 301.905,262.229 301.914,262.231 301.924,262.233 301.933,262.236 301.942,262.238 301.951,262.24 301.96,262.243 301.97,262.245 301.979,262.247 301.988,262.249 301.997,262.252 302.006,262.254 302.015,262.256 302.025,262.259 302.034,262.261 302.043,262.263 302.052,262.265 302.061,262.268 302.071,262.27 302.08,262.272 302.089,262.275 302.098,262.277 302.107,262.279 302.117,262.281 302.126,262.284 302.135,262.286 302.144,262.288 302.153,262.291 302.163,262.293 302.172,262.295 302.181,262.298 302.19,262.3 302.199,262.302 302.208,262.304 302.218,262.307 302.227,262.309 302.236,262.311 302.245,262.314 302.254,262.316 302.264,262.318 302.273,262.32 302.282,262.323 302.291,262.325 302.3,262.327 302.31,262.33 302.319,262.332 302.328,262.334 302.337,262.336 302.346,262.339 302.355,262.341 302.365,262.343 302.374,262.346 302.383,262.348 302.392,262.35 302.401,262.352 302.411,262.355 302.42,262.357 302.429,262.359 302.438,262.362 302.447,262.364 302.457,262.366 302.466,262.369 302.475,262.371 302.484,262.373 302.493,262.375 302.503,262.378 302.512,262.38 302.521,262.382 302.53,262.385 302.539,262.387 302.548,262.389 302.558,262.391 302.567,262.394 302.576,262.396 302.585,262.398 302.594,262.401 302.604,262.403 302.613,262.405 302.622,262.407 302.631,262.41 302.64,262.412 302.65,262.414 302.659,262.417 302.668,262.419 302.677,262.421 302.686,262.423 302.695,262.426 302.705,262.428 302.714,262.43 302.723,262.433 302.732,262.435 302.741,262.437 302.751,262.44 302.76,262.442 302.769,262.444 302.778,262.446 302.787,262.449 302.797,262.451 302.806,262.453 302.815,262.456 302.824,262.458 302.833,262.46 302.843,262.462 302.852,262.465 302.861,262.467 302.87,262.469 302.879,262.472 302.888,262.474 302.898,262.476 302.907,262.478 302.916,262.481 302.925,262.483 302.934,262.485 302.944,262.488 302.953,262.49 302.962,262.492 302.971,262.494 302.98,262.497 302.99,262.499 302.999,262.501 303.008,262.504 303.017,262.506 303.026,262.508 303.035,262.51 303.045,262.513 303.054,262.515 303.063,262.517 303.072,262.52 303.081,262.522 303.091,262.524 303.1,262.527 303.109,262.529 303.118,262.531 303.127,262.533 303.137,262.536 303.146,262.538 303.155,262.54 303.164,262.543 303.173,262.545 303.183,262.547 303.192,262.549 303.201,262.552 303.21,262.554 303.219,262.556 303.228,262.559 303.238,262.561 303.247,262.563 303.256,262.565 303.265,262.568 303.274,262.57 303.284,262.572 303.293,262.575 303.302,262.577 303.311,262.579 303.32,262.581 303.33,262.584 303.339,262.586 303.348,262.588 303.357,262.591 303.366,262.593 303.375,262.595 303.385,262.597 303.394,262.6 303.403,262.602 303.412,262.604 303.421,262.607 303.431,262.609 303.44,262.611 303.449,262.613 303.458,262.616 303.467,262.618 303.477,262.62 303.486,262.623 303.495,262.625 303.504,262.627 303.513,262.63 303.523,262.632 303.532,262.634 303.541,262.636 303.55,262.639 303.559,262.641 303.568,262.643 303.578,262.646 303.587,262.648 303.596,262.65 303.605,262.652 303.614,262.655 303.624,262.657 303.633,262.659 303.642,262.662 303.651,262.664 303.66,262.666 303.67,262.668 303.679,262.671 303.688,262.673 303.697,262.675 303.706,262.678 303.715,262.68 303.725,262.682 303.734,262.684 303.743,262.687 303.752,262.689 303.761,262.691 303.771,262.694 303.78,262.696 303.789,262.698 303.798,262.7 303.807,262.703 303.817,262.705 303.826,262.707 303.835,262.71 303.844,262.712 303.853,262.714 303.863,262.716 303.872,262.719 303.881,262.721 303.89,262.723 303.899,262.726 303.908,262.728 303.918,262.73 303.927,262.732 303.936,262.735 303.945,262.737 303.954,262.739 303.964,262.742 303.973,262.744 303.982,262.746 303.991,262.749 304,262.751 304.01,262.753 304.019,262.755 304.028,262.758 304.037,262.76 304.046,262.762 304.055,262.765 304.065,262.767 304.074,262.769 304.083,262.771 304.092,262.774 304.101,262.776 304.111,262.778 304.12,262.781 304.129,262.783 304.138,262.785 304.147,262.787 304.157,262.79 304.166,262.792 304.175,262.794 304.184,262.797 304.193,262.799 304.203,262.801 304.212,262.803 304.221,262.806 304.23,262.808 304.239,262.81 304.248,262.813 304.258,262.815 304.267,262.817 304.276,262.819 304.285,262.822 304.294,262.824 304.304,262.826 304.313,262.829 304.322,262.831 304.331,262.833 304.34,262.835 304.35,262.838 304.359,262.84 304.368,262.842 304.377,262.845 304.386,262.847 304.395,262.849 304.405,262.851 304.414,262.854 304.423,262.856 304.432,262.858 304.441,262.861 304.451,262.863 304.46,262.865 304.469,262.867 304.478,262.87 304.487,262.872 304.497,262.874 304.506,262.877 304.515,262.879 304.524,262.881 304.533,262.883 304.543,262.886 304.552,262.888 304.561,262.89 304.57,262.893 304.579,262.895 304.588,262.897 304.598,262.899 304.607,262.902 304.616,262.904 304.625,262.906 304.634,262.909 304.644,262.911 304.653,262.913 304.662,262.915 304.671,262.918 304.68,262.92 304.69,262.922 304.699,262.925 304.708,262.927 304.717,262.929 304.726,262.931 304.736,262.934 304.745,262.936 304.754,262.938 304.763,262.941 304.772,262.943 304.781,262.945 304.791,262.947 304.8,262.95 304.809,262.952 304.818,262.954 304.827,262.957 304.837,262.959 304.846,262.961 304.855,262.963 304.864,262.966 304.873,262.968 304.883,262.97 304.892,262.973 304.901,262.975 304.91,262.977 304.919,262.979 304.928,262.982 304.938,262.984 304.947,262.986 304.956,262.989 304.965,262.991 304.974,262.993 304.984,262.995 304.993,262.998 305.002,263 305.011,263.002 305.02,263.005 305.03,263.007 305.039,263.009 305.048,263.011 305.057,263.014 305.066,263.016 305.076,263.018 305.085,263.021 305.094,263.023 305.103,263.025 305.112,263.027 305.121,263.03 305.131,263.032 305.14,263.034 305.149,263.037 305.158,263.039 305.167,263.041 305.177,263.043 305.186,263.046 305.195,263.048 305.204,263.05 305.213,263.053 305.223,263.055 305.232,263.057 305.241,263.059 305.25,263.062 305.259,263.064 305.268,263.066 305.278,263.069 305.287,263.071 305.296,263.073 305.305,263.075 305.314,263.078 305.324,263.08 305.333,263.082 305.342,263.085 305.351,263.087 305.36,263.089 305.37,263.091 305.379,263.094 305.388,263.096 305.397,263.098 305.406,263.101 305.416,263.103 305.425,263.105 305.434,263.107 305.443,263.11 305.452,263.112 305.461,263.114 305.471,263.117 305.48,263.119 305.489,263.121 305.498,263.123 305.507,263.126 305.517,263.128 305.526,263.13 305.535,263.133 305.544,263.135 305.553,263.137 305.563,263.139 305.572,263.142 305.581,263.144 305.59,263.146 305.599,263.149 305.608,263.151 305.618,263.153 305.627,263.155 305.636,263.158 305.645,263.16 305.654,263.162 305.664,263.165 305.673,263.167 305.682,263.169 305.691,263.171 305.7,263.174 305.71,263.176 305.719,263.178 305.728,263.181 305.737,263.183 305.746,263.185 305.756,263.187 305.765,263.19 305.774,263.192 305.783,263.194 305.792,263.197 305.801,263.199 305.811,263.201 305.82,263.203 305.829,263.206 305.838,263.208 305.847,263.21 305.857,263.213 305.866,263.215 305.875,263.217 305.884,263.219 305.893,263.222 305.903,263.224 305.912,263.226 305.921,263.229 305.93,263.231 305.939,263.233 305.948,263.235 305.958,263.238 305.967,263.24 305.976,263.242 305.985,263.245 305.994,263.247 306.004,263.249 306.013,263.251 306.022,263.254 306.031,263.256 306.04,263.258 306.05,263.261 306.059,263.263 306.068,263.265 306.077,263.267 306.086,263.27 306.096,263.272 306.105,263.274 306.114,263.276 306.123,263.279 306.132,263.281 306.141,263.283 306.151,263.286 306.16,263.288 306.169,263.29 306.178,263.292 306.187,263.295 306.197,263.297 306.206,263.299 306.215,263.302 306.224,263.304 306.233,263.306 306.243,263.308 306.252,263.311 306.261,263.313 306.27,263.315 306.279,263.318 306.288,263.32 306.298,263.322 306.307,263.324 306.316,263.327 306.325,263.329 306.334,263.331 306.344,263.334 306.353,263.336 306.362,263.338 306.371,263.34 306.38,263.343 306.39,263.345 306.399,263.347 306.408,263.35 306.417,263.352 306.426,263.354 306.436,263.356 306.445,263.359 306.454,263.361 306.463,263.363 306.472,263.366 306.481,263.368 306.491,263.37 306.5,263.372 306.509,263.375 306.518,263.377 306.527,263.379 306.537,263.382 306.546,263.384 306.555,263.386 306.564,263.388 306.573,263.391 306.583,263.393 306.592,263.395 306.601,263.398 306.61,263.4 306.619,263.402 306.628,263.404 306.638,263.407 306.647,263.409 306.656,263.411 306.665,263.413 306.674,263.416 306.684,263.418 306.693,263.42 306.702,263.423 306.711,263.425 306.72,263.427 306.73,263.429 306.739,263.432 306.748,263.434 306.757,263.436 306.766,263.439 306.776,263.441 306.785,263.443 306.794,263.445 306.803,263.448 306.812,263.45 306.821,263.452 306.831,263.455 306.84,263.457 306.849,263.459 306.858,263.461 306.867,263.464 306.877,263.466 306.886,263.468 306.895,263.471 306.904,263.473 306.913,263.475 306.923,263.477 306.932,263.48 306.941,263.482 306.95,263.484 306.959,263.487 306.969,263.489 306.978,263.491 306.987,263.493 306.996,263.496 307.005,263.498 307.014,263.5 307.024,263.502 307.033,263.505 307.042,263.507 307.051,263.509 307.06,263.512 307.07,263.514 307.079,263.516 307.088,263.518 307.097,263.521 307.106,263.523 307.116,263.525 307.125,263.528 307.134,263.53 307.143,263.532 307.152,263.534 307.161,263.537 307.171,263.539 307.18,263.541 307.189,263.544 307.198,263.546 307.207,263.548 307.217,263.55 307.226,263.553 307.235,263.555 307.244,263.557 307.253,263.56 307.263,263.562 307.272,263.564 307.281,263.566 307.29,263.569 307.299,263.571 307.309,263.573 307.318,263.576 307.327,263.578 307.336,263.58 307.345,263.582 307.354,263.585 307.364,263.587 307.373,263.589 307.382,263.591 307.391,263.594 307.4,263.596 307.41,263.598 307.419,263.601 307.428,263.603 307.437,263.605 307.446,263.607 307.456,263.61 307.465,263.612 307.474,263.614 307.483,263.617 307.492,263.619 307.501,263.621 307.511,263.623 307.52,263.626 307.529,263.628 307.538,263.63 307.547,263.633 307.557,263.635 307.566,263.637 307.575,263.639 307.584,263.642 307.593,263.644 307.603,263.646 307.612,263.649 307.621,263.651 307.63,263.653 307.639,263.655 307.649,263.658 307.658,263.66 307.667,263.662 307.676,263.664 307.685,263.667 307.694,263.669 307.704,263.671 307.713,263.674 307.722,263.676 307.731,263.678 307.74,263.68 307.75,263.683 307.759,263.685 307.768,263.687 307.777,263.69 307.786,263.692 307.796,263.694 307.805,263.696 307.814,263.699 307.823,263.701 307.832,263.703 307.841,263.706 307.851,263.708 307.86,263.71 307.869,263.712 307.878,263.715 307.887,263.717 307.897,263.719 307.906,263.721 307.915,263.724 307.924,263.726 307.933,263.728 307.943,263.731 307.952,263.733 307.961,263.735 307.97,263.737 307.979,263.74 307.989,263.742 307.998,263.744 308.007,263.747 308.016,263.749 308.025,263.751 308.034,263.753 308.044,263.756 308.053,263.758 308.062,263.76 308.071,263.763 308.08,263.765 308.09,263.767 308.099,263.769 308.108,263.772 308.117,263.774 308.126,263.776 308.136,263.778 308.145,263.781 308.154,263.783 308.163,263.785 308.172,263.788 308.181,263.79 308.191,263.792 308.2,263.794 308.209,263.797 308.218,263.799 308.227,263.801 308.237,263.804 308.246,263.806 308.255,263.808 308.264,263.81 308.273,263.813 308.283,263.815 308.292,263.817 308.301,263.82 308.31,263.822 308.319,263.824 308.329,263.826 308.338,263.829 308.347,263.831 308.356,263.833 308.365,263.835 308.374,263.838 308.384,263.84 308.393,263.842 308.402,263.845 308.411,263.847 308.42,263.849 308.43,263.851 308.439,263.854 308.448,263.856 308.457,263.858 308.466,263.861 308.476,263.863 308.485,263.865 308.494,263.867 308.503,263.87 308.512,263.872 308.521,263.874 308.531,263.877 308.54,263.879 308.549,263.881 308.558,263.883 308.567,263.886 308.577,263.888 308.586,263.89 308.595,263.892 308.604,263.895 308.613,263.897 308.623,263.899 308.632,263.902 308.641,263.904 308.65,263.906 308.659,263.908 308.669,263.911 308.678,263.913 308.687,263.915 308.696,263.918 308.705,263.92 308.714,263.922 308.724,263.924 308.733,263.927 308.742,263.929 308.751,263.931 308.76,263.933 308.77,263.936 308.779,263.938 308.788,263.94 308.797,263.943 308.806,263.945 308.816,263.947 308.825,263.949 308.834,263.952 308.843,263.954 308.852,263.956 308.861,263.959 308.871,263.961 308.88,263.963 308.889,263.965 308.898,263.968 308.907,263.97 308.917,263.972 308.926,263.975 308.935,263.977 308.944,263.979 308.953,263.981 308.963,263.984 308.972,263.986 308.981,263.988 308.99,263.99 308.999,263.993 309.009,263.995 309.018,263.997 309.027,264 309.036,264.002 309.045,264.004 309.054,264.006 309.064,264.009 309.073,264.011 309.082,264.013 309.091,264.016 309.1,264.018 309.11,264.02 309.119,264.022 309.128,264.025 309.137,264.027 309.146,264.029 309.156,264.031 309.165,264.034 309.174,264.036 309.183,264.038 309.192,264.041 309.201,264.043 309.211,264.045 309.22,264.047 309.229,264.05 309.238,264.052 309.247,264.054 309.257,264.057 309.266,264.059 309.275,264.061 309.284,264.063 309.293,264.066 309.303,264.068 309.312,264.07 309.321,264.072 309.33,264.075 309.339,264.077 309.349,264.079 309.358,264.082 309.367,264.084 309.376,264.086 309.385,264.088 309.394,264.091 309.404,264.093 309.413,264.095 309.422,264.098 309.431,264.1 309.44,264.102 309.45,264.104 309.459,264.107 309.468,264.109 309.477,264.111 309.486,264.113 309.496,264.116 309.505,264.118 309.514,264.12 309.523,264.123 309.532,264.125 309.542,264.127 309.551,264.129 309.56,264.132 309.569,264.134 309.578,264.136 309.587,264.139 309.597,264.141 309.606,264.143 309.615,264.145 309.624,264.148 309.633,264.15 309.643,264.152 309.652,264.154 309.661,264.157 309.67,264.159 309.679,264.161 309.689,264.164 309.698,264.166 309.707,264.168 309.716,264.17 309.725,264.173 309.734,264.175 309.744,264.177 309.753,264.18 309.762,264.182 309.771,264.184 309.78,264.186 309.79,264.189 309.799,264.191 309.808,264.193 309.817,264.195 309.826,264.198 309.836,264.2 309.845,264.202 309.854,264.205 309.863,264.207 309.872,264.209 309.882,264.211 309.891,264.214 309.9,264.216 309.909,264.218 309.918,264.22 309.927,264.223 309.937,264.225 309.946,264.227 309.955,264.23 309.964,264.232 309.973,264.234 309.983,264.236 309.992,264.239 310.001,264.241 310.01,264.243 310.019,264.246 310.029,264.248 310.038,264.25 310.047,264.252 310.056,264.255 310.065,264.257 310.074,264.259 310.084,264.261 310.093,264.264 310.102,264.266 310.111,264.268 310.12,264.271 310.13,264.273 310.139,264.275 310.148,264.277 310.157,264.28 310.166,264.282 310.176,264.284 310.185,264.287 310.194,264.289 310.203,264.291 310.212,264.293 310.222,264.296 310.231,264.298 310.24,264.3 310.249,264.302 310.258,264.305 310.267,264.307 310.277,264.309 310.286,264.312 310.295,264.314 310.304,264.316 310.313,264.318 310.323,264.321 310.332,264.323 310.341,264.325 310.35,264.327 310.359,264.33 310.369,264.332 310.378,264.334 310.387,264.337 310.396,264.339 310.405,264.341 310.414,264.343 310.424,264.346 310.433,264.348 310.442,264.35 310.451,264.353 310.46,264.355 310.47,264.357 310.479,264.359 310.488,264.362 310.497,264.364 310.506,264.366 310.516,264.368 310.525,264.371 310.534,264.373 310.543,264.375 310.552,264.378 310.562,264.38 310.571,264.382 310.58,264.384 310.589,264.387 310.598,264.389 310.607,264.391 310.617,264.393 310.626,264.396 310.635,264.398 310.644,264.4 310.653,264.403 310.663,264.405 310.672,264.407 310.681,264.409 310.69,264.412 310.699,264.414 310.709,264.416 310.718,264.418 310.727,264.421 310.736,264.423 310.745,264.425 310.754,264.428 310.764,264.43 310.773,264.432 310.782,264.434 310.791,264.437 310.8,264.439 310.81,264.441 310.819,264.444 310.828,264.446 310.837,264.448 310.846,264.45 310.856,264.453 310.865,264.455 310.874,264.457 310.883,264.459 310.892,264.462 310.902,264.464 310.911,264.466 310.92,264.469 310.929,264.471 310.938,264.473 310.947,264.475 310.957,264.478 310.966,264.48 310.975,264.482 310.984,264.484 310.993,264.487 311.003,264.489 311.012,264.491 311.021,264.494 311.03,264.496 311.039,264.498 311.049,264.5 311.058,264.503 311.067,264.505 311.076,264.507 311.085,264.509 311.094,264.512 311.104,264.514 311.113,264.516 311.122,264.519 311.131,264.521 311.14,264.523 311.15,264.525 311.159,264.528 311.168,264.53 311.177,264.532 311.186,264.535 311.196,264.537 311.205,264.539 311.214,264.541 311.223,264.544 311.232,264.546 311.242,264.548 311.251,264.55 311.26,264.553 311.269,264.555 311.278,264.557 311.287,264.56 311.297,264.562 311.306,264.564 311.315,264.566 311.324,264.569 311.333,264.571 311.343,264.573 311.352,264.575 311.361,264.578 311.37,264.58 311.379,264.582 311.389,264.585 311.398,264.587 311.407,264.589 311.416,264.591 311.425,264.594 311.434,264.596 311.444,264.598 311.453,264.6 311.462,264.603 311.471,264.605 311.48,264.607 311.49,264.61 311.499,264.612 311.508,264.614 311.517,264.616 311.526,264.619 311.536,264.621 311.545,264.623 311.554,264.625 311.563,264.628 311.572,264.63 311.582,264.632 311.591,264.635 311.6,264.637 311.609,264.639 311.618,264.641 311.627,264.644 311.637,264.646 311.646,264.648 311.655,264.65 311.664,264.653 311.673,264.655 311.683,264.657 311.692,264.66 311.701,264.662 311.71,264.664 311.719,264.666 311.729,264.669 311.738,264.671 311.747,264.673 311.756,264.675 311.765,264.678 311.774,264.68 311.784,264.682 311.793,264.685 311.802,264.687 311.811,264.689 311.82,264.691 311.83,264.694 311.839,264.696 311.848,264.698 311.857,264.7 311.866,264.703 311.876,264.705 311.885,264.707 311.894,264.71 311.903,264.712 311.912,264.714 311.922,264.716 311.931,264.719 311.94,264.721 311.949,264.723 311.958,264.725 311.967,264.728 311.977,264.73 311.986,264.732 311.995,264.735 312.004,264.737 312.013,264.739 312.023,264.741 312.032,264.744 312.041,264.746 312.05,264.748 312.059,264.75 312.069,264.753 312.078,264.755 312.087,264.757 312.096,264.76 312.105,264.762 312.115,264.764 312.124,264.766 312.133,264.769 312.142,264.771 312.151,264.773 312.16,264.775 312.17,264.778 312.179,264.78 312.188,264.782 312.197,264.785 312.206,264.787 312.216,264.789 312.225,264.791 312.234,264.794 312.243,264.796 312.252,264.798 312.262,264.8 312.271,264.803 312.28,264.805 312.289,264.807 312.298,264.81 312.307,264.812 312.317,264.814 312.326,264.816 312.335,264.819 312.344,264.821 312.353,264.823 312.363,264.825 312.372,264.828 312.381,264.83 312.39,264.832 312.399,264.835 312.409,264.837 312.418,264.839 312.427,264.841 312.436,264.844 312.445,264.846 312.455,264.848 312.464,264.85 312.473,264.853 312.482,264.855 312.491,264.857 312.5,264.86 312.51,264.862 312.519,264.864 312.528,264.866 312.537,264.869 312.546,264.871 312.556,264.873 312.565,264.875 312.574,264.878 312.583,264.88 312.592,264.882 312.602,264.885 312.611,264.887 312.62,264.889 312.629,264.891 312.638,264.894 312.647,264.896 312.657,264.898 312.666,264.9 312.675,264.903 312.684,264.905 312.693,264.907 312.703,264.91 312.712,264.912 312.721,264.914 312.73,264.916 312.739,264.919 312.749,264.921 312.758,264.923 312.767,264.925 312.776,264.928 312.785,264.93 312.795,264.932 312.804,264.935 312.813,264.937 312.822,264.939 312.831,264.941 312.84,264.944 312.85,264.946 312.859,264.948 312.868,264.95 312.877,264.953 312.886,264.955 312.896,264.957 312.905,264.959 312.914,264.962 312.923,264.964 312.932,264.966 312.942,264.969 312.951,264.971 312.96,264.973 312.969,264.975 312.978,264.978 312.987,264.98 312.997,264.982 313.006,264.984 313.015,264.987 313.024,264.989 313.033,264.991 313.043,264.994 313.052,264.996 313.061,264.998 313.07,265 313.079,265.003 313.089,265.005 313.098,265.007 313.107,265.009 313.116,265.012 313.125,265.014 313.135,265.016 313.144,265.019 313.153,265.021 313.162,265.023 313.171,265.025 313.18,265.028 313.19,265.03 313.199,265.032 313.208,265.034 313.217,265.037 313.226,265.039 313.236,265.041 313.245,265.044 313.254,265.046 313.263,265.048 313.272,265.05 313.282,265.053 313.291,265.055 313.3,265.057 313.309,265.059 313.318,265.062 313.327,265.064 313.337,265.066 313.346,265.068 313.355,265.071 313.364,265.073 313.373,265.075 313.383,265.078 313.392,265.08 313.401,265.082 313.41,265.084 313.419,265.087 313.429,265.089 313.438,265.091 313.447,265.093 313.456,265.096 313.465,265.098 313.475,265.1 313.484,265.103 313.493,265.105 313.502,265.107 313.511,265.109 313.52,265.112 313.53,265.114 313.539,265.116 313.548,265.118 313.557,265.121 313.566,265.123 313.576,265.125 313.585,265.128 313.594,265.13 313.603,265.132 313.612,265.134 313.622,265.137 313.631,265.139 313.64,265.141 313.649,265.143 313.658,265.146 313.667,265.148 313.677,265.15 313.686,265.152 313.695,265.155 313.704,265.157 313.713,265.159 313.723,265.162 313.732,265.164 313.741,265.166 313.75,265.168 313.759,265.171 313.769,265.173 313.778,265.175 313.787,265.177 313.796,265.18 313.805,265.182 313.815,265.184 313.824,265.187 313.833,265.189 313.842,265.191 313.851,265.193 313.86,265.196 313.87,265.198 313.879,265.2 313.888,265.202 313.897,265.205 313.906,265.207 313.916,265.209 313.925,265.211 313.934,265.214 313.943,265.216 313.952,265.218 313.962,265.221 313.971,265.223 313.98,265.225 313.989,265.227 313.998,265.23 314.007,265.232 314.017,265.234 314.026,265.236 314.035,265.239 314.044,265.241 314.053,265.243 314.063,265.246 314.072,265.248 314.081,265.25 314.09,265.252 314.099,265.255 314.109,265.257 314.118,265.259 314.127,265.261 314.136,265.264 314.145,265.266 314.155,265.268 314.164,265.27 314.173,265.273 314.182,265.275 314.191,265.277 314.2,265.28 314.21,265.282 314.219,265.284 314.228,265.286 314.237,265.289 314.246,265.291 314.256,265.293 314.265,265.295 314.274,265.298 314.283,265.3 314.292,265.302 314.302,265.305 314.311,265.307 314.32,265.309 314.329,265.311 314.338,265.314 314.348,265.316 314.357,265.318 314.366,265.32 314.375,265.323 314.384,265.325 314.393,265.327 314.403,265.329 314.412,265.332 314.421,265.334 314.43,265.336 314.439,265.339 314.449,265.341 314.458,265.343 314.467,265.345 314.476,265.348 314.485,265.35 314.495,265.352 314.504,265.354 314.513,265.357 314.522,265.359 314.531,265.361 314.54,265.363 314.55,265.366 314.559,265.368 314.568,265.37 314.577,265.373 314.586,265.375 314.596,265.377 314.605,265.379 314.614,265.382 314.623,265.384 314.632,265.386 314.642,265.388 314.651,265.391 314.66,265.393 314.669,265.395 314.678,265.398 314.688,265.4 314.697,265.402 314.706,265.404 314.715,265.407 314.724,265.409 314.733,265.411 314.743,265.413 314.752,265.416 314.761,265.418 314.77,265.42 314.779,265.422 314.789,265.425 314.798,265.427 314.807,265.429 314.816,265.432 314.825,265.434 314.835,265.436 314.844,265.438 314.853,265.441 314.862,265.443 314.871,265.445 314.88,265.447 314.89,265.45 314.899,265.452 314.908,265.454 314.917,265.456 314.926,265.459 314.936,265.461 314.945,265.463 314.954,265.466 314.963,265.468 314.972,265.47 314.982,265.472 314.991,265.475 315,265.477 315.009,265.479 315.018,265.481 315.028,265.484 315.037,265.486 315.046,265.488 315.055,265.49 315.064,265.493 315.073,265.495 315.083,265.497 315.092,265.5 315.101,265.502 315.11,265.504 315.119,265.506 315.129,265.509 315.138,265.511 315.147,265.513 315.156,265.515 315.165,265.518 315.175,265.52 315.184,265.522 315.193,265.524 315.202,265.527 315.211,265.529 315.22,265.531 315.23,265.534 315.239,265.536 315.248,265.538 315.257,265.54 315.266,265.543 315.276,265.545 315.285,265.547 315.294,265.549 315.303,265.552 315.312,265.554 315.322,265.556 315.331,265.558 315.34,265.561 315.349,265.563 315.358,265.565 315.368,265.568 315.377,265.57 315.386,265.572 315.395,265.574 315.404,265.577 315.413,265.579 315.423,265.581 315.432,265.583 315.441,265.586 315.45,265.588 315.459,265.59 315.469,265.592 315.478,265.595 315.487,265.597 315.496,265.599 315.505,265.602 315.515,265.604 315.524,265.606 315.533,265.608 315.542,265.611 315.551,265.613 315.56,265.615 315.57,265.617 315.579,265.62 315.588,265.622 315.597,265.624 315.606,265.626 315.616,265.629 315.625,265.631 315.634,265.633 315.643,265.636 315.652,265.638 315.662,265.64 315.671,265.642 315.68,265.645 315.689,265.647 315.698,265.649 315.708,265.651 315.717,265.654 315.726,265.656 315.735,265.658 315.744,265.66 315.753,265.663 315.763,265.665 315.772,265.667 315.781,265.67 315.79,265.672 315.799,265.674 315.809,265.676 315.818,265.679 315.827,265.681 315.836,265.683 315.845,265.685 315.855,265.688 315.864,265.69 315.873,265.692 315.882,265.694 315.891,265.697 315.9,265.699 315.91,265.701 315.919,265.704 315.928,265.706 315.937,265.708 315.946,265.71 315.956,265.713 315.965,265.715 315.974,265.717 315.983,265.719 315.992,265.722 316.002,265.724 316.011,265.726 316.02,265.728 316.029,265.731 316.038,265.733 316.048,265.735 316.057,265.737 316.066,265.74 316.075,265.742 316.084,265.744 316.093,265.747 316.103,265.749 316.112,265.751 316.121,265.753 316.13,265.756 316.139,265.758 316.149,265.76 316.158,265.762 316.167,265.765 316.176,265.767 316.185,265.769 316.195,265.771 316.204,265.774 316.213,265.776 316.222,265.778 316.231,265.781 316.24,265.783 316.25,265.785 316.259,265.787 316.268,265.79 316.277,265.792 316.286,265.794 316.296,265.796 316.305,265.799 316.314,265.801 316.323,265.803 316.332,265.805 316.342,265.808 316.351,265.81 316.36,265.812 316.369,265.815 316.378,265.817 316.388,265.819 316.397,265.821 316.406,265.824 316.415,265.826 316.424,265.828 316.433,265.83 316.443,265.833 316.452,265.835 316.461,265.837 316.47,265.839 316.479,265.842 316.489,265.844 316.498,265.846 316.507,265.848 316.516,265.851 316.525,265.853 316.535,265.855 316.544,265.858 316.553,265.86 316.562,265.862 316.571,265.864 316.58,265.867 316.59,265.869 316.599,265.871 316.608,265.873 316.617,265.876 316.626,265.878 316.636,265.88 316.645,265.882 316.654,265.885 316.663,265.887 316.672,265.889 316.682,265.891 316.691,265.894 316.7,265.896 316.709,265.898 316.718,265.901 316.728,265.903 316.737,265.905 316.746,265.907 316.755,265.91 316.764,265.912 316.773,265.914 316.783,265.916 316.792,265.919 316.801,265.921 316.81,265.923 316.819,265.925 316.829,265.928 316.838,265.93 316.847,265.932 316.856,265.935 316.865,265.937 316.875,265.939 316.884,265.941 316.893,265.944 316.902,265.946 316.911,265.948 316.921,265.95 316.93,265.953 316.939,265.955 316.948,265.957 316.957,265.959 316.966,265.962 316.976,265.964 316.985,265.966 316.994,265.968 317.003,265.971 317.012,265.973 317.022,265.975 317.031,265.978 317.04,265.98 317.049,265.982 317.058,265.984 317.068,265.987 317.077,265.989 317.086,265.991 317.095,265.993 317.104,265.996 317.113,265.998 317.123,266 317.132,266.002 317.141,266.005 317.15,266.007 317.159,266.009 317.169,266.011 317.178,266.014 317.187,266.016 317.196,266.018 317.205,266.021 317.215,266.023 317.224,266.025 317.233,266.027 317.242,266.03 317.251,266.032 317.261,266.034 317.27,266.036 317.279,266.039 317.288,266.041 317.297,266.043 317.306,266.045 317.316,266.048 317.325,266.05 317.334,266.052 317.343,266.054 317.352,266.057 317.362,266.059 317.371,266.061 317.38,266.064 317.389,266.066 317.398,266.068 317.408,266.07 317.417,266.073 317.426,266.075 317.435,266.077 317.444,266.079 317.453,266.082 317.463,266.084 317.472,266.086 317.481,266.088 317.49,266.091 317.499,266.093 317.509,266.095 317.518,266.097 317.527,266.1 317.536,266.102 317.545,266.104 317.555,266.107 317.564,266.109 317.573,266.111 317.582,266.113 317.591,266.116 317.601,266.118 317.61,266.12 317.619,266.122 317.628,266.125 317.637,266.127 317.646,266.129 317.656,266.131 317.665,266.134 317.674,266.136 317.683,266.138 317.692,266.14 317.702,266.143 317.711,266.145 317.72,266.147 317.729,266.15 317.738,266.152 317.748,266.154 317.757,266.156 317.766,266.159 317.775,266.161 317.784,266.163 317.793,266.165 317.803,266.168 317.812,266.17 317.821,266.172 317.83,266.174 317.839,266.177 317.849,266.179 317.858,266.181 317.867,266.183 317.876,266.186 317.885,266.188 317.895,266.19 317.904,266.192 317.913,266.195 317.922,266.197 317.931,266.199 317.941,266.202 317.95,266.204 317.959,266.206 317.968,266.208 317.977,266.211 317.986,266.213 317.996,266.215 318.005,266.217 318.014,266.22 318.023,266.222 318.032,266.224 318.042,266.226 318.051,266.229 318.06,266.231 318.069,266.233 318.078,266.235 318.088,266.238 318.097,266.24 318.106,266.242 318.115,266.245 318.124,266.247 318.133,266.249 318.143,266.251 318.152,266.254 318.161,266.256 318.17,266.258 318.179,266.26 318.189,266.263 318.198,266.265 318.207,266.267 318.216,266.269 318.225,266.272 318.235,266.274 318.244,266.276 318.253,266.278 318.262,266.281 318.271,266.283 318.281,266.285 318.29,266.287 318.299,266.29 318.308,266.292 318.317,266.294 318.326,266.297 318.336,266.299 318.345,266.301 318.354,266.303 318.363,266.306 318.372,266.308 318.382,266.31 318.391,266.312 318.4,266.315 318.409,266.317 318.418,266.319 318.428,266.321 318.437,266.324 318.446,266.326 318.455,266.328 318.464,266.33 318.473,266.333 318.483,266.335 318.492,266.337 318.501,266.339 318.51,266.342 318.519,266.344 318.529,266.346 318.538,266.349 318.547,266.351 318.556,266.353 318.565,266.355 318.575,266.358 318.584,266.36 318.593,266.362 318.602,266.364 318.611,266.367 318.621,266.369 318.63,266.371 318.639,266.373 318.648,266.376 318.657,266.378 318.666,266.38 318.676,266.382 318.685,266.385 318.694,266.387 318.703,266.389 318.712,266.391 318.722,266.394 318.731,266.396 318.74,266.398 318.749,266.401 318.758,266.403 318.768,266.405 318.777,266.407 318.786,266.41 318.795,266.412 318.804,266.414 318.813,266.416 318.823,266.419 318.832,266.421 318.841,266.423 318.85,266.425 318.859,266.428 318.869,266.43 318.878,266.432 318.887,266.434 318.896,266.437 318.905,266.439 318.915,266.441 318.924,266.443 318.933,266.446 318.942,266.448 318.951,266.45 318.961,266.452 318.97,266.455 318.979,266.457 318.988,266.459 318.997,266.462 319.006,266.464 319.016,266.466 319.025,266.468 319.034,266.471 319.043,266.473 319.052,266.475 319.062,266.477 319.071,266.48 319.08,266.482 319.089,266.484 319.098,266.486 319.108,266.489 319.117,266.491 319.126,266.493 319.135,266.495 319.144,266.498 319.153,266.5 319.163,266.502 319.172,266.504 319.181,266.507 319.19,266.509 319.199,266.511 319.209,266.514 319.218,266.516 319.227,266.518 319.236,266.52 319.245,266.523 319.255,266.525 319.264,266.527 319.273,266.529 319.282,266.532 319.291,266.534 319.301,266.536 319.31,266.538 319.319,266.541 319.328,266.543 319.337,266.545 319.346,266.547 319.356,266.55 319.365,266.552 319.374,266.554 319.383,266.556 319.392,266.559 319.402,266.561 319.411,266.563 319.42,266.565 319.429,266.568 319.438,266.57 319.448,266.572 319.457,266.575 319.466,266.577 319.475,266.579 319.484,266.581 319.494,266.584 319.503,266.586 319.512,266.588 319.521,266.59 319.53,266.593 319.539,266.595 319.549,266.597 319.558,266.599 319.567,266.602 319.576,266.604 319.585,266.606 319.595,266.608 319.604,266.611 319.613,266.613 319.622,266.615 319.631,266.617 319.641,266.62 319.65,266.622 319.659,266.624 319.668,266.626 319.677,266.629 319.686,266.631 319.696,266.633 319.705,266.635 319.714,266.638 319.723,266.64 319.732,266.642 319.742,266.645 319.751,266.647 319.76,266.649 319.769,266.651 319.778,266.654 319.788,266.656 319.797,266.658 319.806,266.66 319.815,266.663 319.824,266.665 319.834,266.667 319.843,266.669 319.852,266.672 319.861,266.674 319.87,266.676 319.879,266.678 319.889,266.681 319.898,266.683 319.907,266.685 319.916,266.687 319.925,266.69 319.935,266.692 319.944,266.694 319.953,266.696 319.962,266.699 319.971,266.701 319.981,266.703 319.99,266.706 319.999,266.708 320.008,266.71 320.017,266.712 320.026,266.715 320.036,266.717 320.045,266.719 320.054,266.721 320.063,266.724 320.072,266.726 320.082,266.728 320.091,266.73 320.1,266.733 320.109,266.735 320.118,266.737 320.128,266.739 320.137,266.742 320.146,266.744 320.155,266.746 320.164,266.748 320.174,266.751 320.183,266.753 320.192,266.755 320.201,266.757 320.21,266.76 320.219,266.762 320.229,266.764 320.238,266.766 320.247,266.769 320.256,266.771 320.265,266.773 320.275,266.775 320.284,266.778 320.293,266.78 320.302,266.782 320.311,266.785 320.321,266.787 320.33,266.789 320.339,266.791 320.348,266.794 320.357,266.796 320.366,266.798 320.376,266.8 320.385,266.803 320.394,266.805 320.403,266.807 320.412,266.809 320.422,266.812 320.431,266.814 320.44,266.816 320.449,266.818 320.458,266.821 320.468,266.823 320.477,266.825 320.486,266.827 320.495,266.83 320.504,266.832 320.514,266.834 320.523,266.836 320.532,266.839 320.541,266.841 320.55,266.843 320.559,266.845 320.569,266.848 320.578,266.85 320.587,266.852 320.596,266.854 320.605,266.857 320.615,266.859 320.624,266.861 320.633,266.864 320.642,266.866 320.651,266.868 320.661,266.87 320.67,266.873 320.679,266.875 320.688,266.877 320.697,266.879 320.706,266.882 320.716,266.884 320.725,266.886 320.734,266.888 320.743,266.891 320.752,266.893 320.762,266.895 320.771,266.897 320.78,266.9 320.789,266.902 320.798,266.904 320.808,266.906 320.817,266.909 320.826,266.911 320.835,266.913 320.844,266.915 320.854,266.918 320.863,266.92 320.872,266.922 320.881,266.924 320.89,266.927 320.899,266.929 320.909,266.931 320.918,266.933 320.927,266.936 320.936,266.938 320.945,266.94 320.955,266.943 320.964,266.945 320.973,266.947 320.982,266.949 320.991,266.952 321.001,266.954 321.01,266.956 321.019,266.958 321.028,266.961 321.037,266.963 321.046,266.965 321.056,266.967 321.065,266.97 321.074,266.972 321.083,266.974 321.092,266.976 321.102,266.979 321.111,266.981 321.12,266.983 321.129,266.985 321.138,266.988 321.148,266.99 321.157,266.992 321.166,266.994 321.175,266.997 321.184,266.999 321.194,267.001 321.203,267.003 321.212,267.006 321.221,267.008 321.23,267.01 321.239,267.012 321.249,267.015 321.258,267.017 321.267,267.019 321.276,267.021 321.285,267.024 321.295,267.026 321.304,267.028 321.313,267.03 321.322,267.033 321.331,267.035 321.341,267.037 321.35,267.04 321.359,267.042 321.368,267.044 321.377,267.046 321.386,267.049 321.396,267.051 321.405,267.053 321.414,267.055 321.423,267.058 321.432,267.06 321.442,267.062 321.451,267.064 321.46,267.067 321.469,267.069 321.478,267.071 321.488,267.073 321.497,267.076 321.506,267.078 321.515,267.08 321.524,267.082 321.534,267.085 321.543,267.087 321.552,267.089 321.561,267.091 321.57,267.094 321.579,267.096 321.589,267.098 321.598,267.1 321.607,267.103 321.616,267.105 321.625,267.107 321.635,267.109 321.644,267.112 321.653,267.114 321.662,267.116 321.671,267.118 321.681,267.121 321.69,267.123 321.699,267.125 321.708,267.127 321.717,267.13 321.727,267.132 321.736,267.134 321.745,267.136 321.754,267.139 321.763,267.141 321.772,267.143 321.782,267.146 321.791,267.148 321.8,267.15 321.809,267.152 321.818,267.155 321.828,267.157 321.837,267.159 321.846,267.161 321.855,267.164 321.864,267.166 321.874,267.168 321.883,267.17 321.892,267.173 321.901,267.175 321.91,267.177 321.919,267.179 321.929,267.182 321.938,267.184 321.947,267.186 321.956,267.188 321.965,267.191 321.975,267.193 321.984,267.195 321.993,267.197 322.002,267.2 322.011,267.202 322.021,267.204 322.03,267.206 322.039,267.209 322.048,267.211 322.057,267.213 322.067,267.215 322.076,267.218 322.085,267.22 322.094,267.222 322.103,267.224 322.112,267.227 322.122,267.229 322.131,267.231 322.14,267.233 322.149,267.236 322.158,267.238 322.168,267.24 322.177,267.242 322.186,267.245 322.195,267.247 322.204,267.249 322.214,267.251 322.223,267.254 322.232,267.256 322.241,267.258 322.25,267.26 322.259,267.263 322.269,267.265 322.278,267.267 322.287,267.269 322.296,267.272 322.305,267.274 322.315,267.276 322.324,267.279 322.333,267.281 322.342,267.283 322.351,267.285 322.361,267.288 322.37,267.29 322.379,267.292 322.388,267.294 322.397,267.297 322.407,267.299 322.416,267.301 322.425,267.303 322.434,267.306 322.443,267.308 322.452,267.31 322.462,267.312 322.471,267.315 322.48,267.317 322.489,267.319 322.498,267.321 322.508,267.324 322.517,267.326 322.526,267.328 322.535,267.33 322.544,267.333 322.554,267.335 322.563,267.337 322.572,267.339 322.581,267.342 322.59,267.344 322.599,267.346 322.609,267.348 322.618,267.351 322.627,267.353 322.636,267.355 322.645,267.357 322.655,267.36 322.664,267.362 322.673,267.364 322.682,267.366 322.691,267.369 322.701,267.371 322.71,267.373 322.719,267.375 322.728,267.378 322.737,267.38 322.747,267.382 322.756,267.384 322.765,267.387 322.774,267.389 322.783,267.391 322.792,267.393 322.802,267.396 322.811,267.398 322.82,267.4 322.829,267.402 322.838,267.405 322.848,267.407 322.857,267.409 322.866,267.411 322.875,267.414 322.884,267.416 322.894,267.418 322.903,267.42 322.912,267.423 322.921,267.425 322.93,267.427 322.939,267.429 322.949,267.432 322.958,267.434 322.967,267.436 322.976,267.438 322.985,267.441 322.995,267.443 323.004,267.445 323.013,267.447 323.022,267.45 323.031,267.452 323.041,267.454 323.05,267.457 323.059,267.459 323.068,267.461 323.077,267.463 323.087,267.466 323.096,267.468 323.105,267.47 323.114,267.472 323.123,267.475 323.132,267.477 323.142,267.479 323.151,267.481 323.16,267.484 323.169,267.486 323.178,267.488 323.188,267.49 323.197,267.493 323.206,267.495 323.215,267.497 323.224,267.499 323.234,267.502 323.243,267.504 323.252,267.506 323.261,267.508 323.27,267.511 323.279,267.513 323.289,267.515 323.298,267.517 323.307,267.52 323.316,267.522 323.325,267.524 323.335,267.526 323.344,267.529 323.353,267.531 323.362,267.533 323.371,267.535 323.381,267.538 323.39,267.54 323.399,267.542 323.408,267.544 323.417,267.547 323.427,267.549 323.436,267.551 323.445,267.553 323.454,267.556 323.463,267.558 323.472,267.56 323.482,267.562 323.491,267.565 323.5,267.567 323.509,267.569 323.518,267.571 323.528,267.574 323.537,267.576 323.546,267.578 323.555,267.58 323.564,267.583 323.574,267.585 323.583,267.587 323.592,267.589 323.601,267.592 323.61,267.594 323.619,267.596 323.629,267.598 323.638,267.601 323.647,267.603 323.656,267.605 323.665,267.607 323.675,267.61 323.684,267.612 323.693,267.614 323.702,267.616 323.711,267.619 323.721,267.621 323.73,267.623 323.739,267.625 323.748,267.628 323.757,267.63 323.767,267.632 323.776,267.634 323.785,267.637 323.794,267.639 323.803,267.641 323.812,267.643 323.822,267.646 323.831,267.648 323.84,267.65 323.849,267.652 323.858,267.655 323.868,267.657 323.877,267.659 323.886,267.661 323.895,267.664 323.904,267.666 323.914,267.668 323.923,267.67 323.932,267.673 323.941,267.675 323.95,267.677 323.959,267.679 323.969,267.682 323.978,267.684 323.987,267.686 323.996,267.688 324.005,267.691 324.015,267.693 324.024,267.695 324.033,267.697 324.042,267.7 324.051,267.702 324.061,267.704 324.07,267.706 324.079,267.709 324.088,267.711 324.097,267.713 324.107,267.715 324.116,267.718 324.125,267.72 324.134,267.722 324.143,267.724 324.152,267.727 324.162,267.729 324.171,267.731 324.18,267.733 324.189,267.736 324.198,267.738 324.208,267.74 324.217,267.742 324.226,267.745 324.235,267.747 324.244,267.749 324.254,267.751 324.263,267.754 324.272,267.756 324.281,267.758 324.29,267.76 324.3,267.763 324.309,267.765 324.318,267.767 324.327,267.769 324.336,267.772 324.345,267.774 324.355,267.776 324.364,267.778 324.373,267.781 324.382,267.783 324.391,267.785 324.401,267.787 324.41,267.79 324.419,267.792 324.428,267.794 324.437,267.796 324.447,267.799 324.456,267.801 324.465,267.803 324.474,267.805 324.483,267.808 324.492,267.81 324.502,267.812 324.511,267.814 324.52,267.817 324.529,267.819 324.538,267.821 324.548,267.823 324.557,267.826 324.566,267.828 324.575,267.83 324.584,267.832 324.594,267.835 324.603,267.837 324.612,267.839 324.621,267.841 324.63,267.844 324.64,267.846 324.649,267.848 324.658,267.85 324.667,267.853 324.676,267.855 324.685,267.857 324.695,267.859 324.704,267.862 324.713,267.864 324.722,267.866 324.731,267.868 324.741,267.871 324.75,267.873 324.759,267.875 324.768,267.877 324.777,267.88 324.787,267.882 324.796,267.884 324.805,267.886 324.814,267.889 324.823,267.891 324.832,267.893 324.842,267.895 324.851,267.898 324.86,267.9 324.869,267.902 324.878,267.904 324.888,267.907 324.897,267.909 324.906,267.911 324.915,267.913 324.924,267.916 324.934,267.918 324.943,267.92 324.952,267.922 324.961,267.925 324.97,267.927 324.98,267.929 324.989,267.931 324.998,267.934 325.007,267.936 325.016,267.938 325.025,267.94 325.035,267.943 325.044,267.945 325.053,267.947 325.062,267.949 325.071,267.952 325.081,267.954 325.09,267.956 325.099,267.958 325.108,267.961 325.117,267.963 325.127,267.965 325.136,267.967 325.145,267.97 325.154,267.972 325.163,267.974 325.172,267.976 325.182,267.979 325.191,267.981 325.2,267.983 325.209,267.985 325.218,267.988 325.228,267.99 325.237,267.992 325.246,267.994 325.255,267.997 325.264,267.999 325.274,268.001 325.283,268.003 325.292,268.006 325.301,268.008 325.31,268.01 325.32,268.012 325.329,268.015 325.338,268.017 325.347,268.019 325.356,268.021 325.365,268.024 325.375,268.026 325.384,268.028 325.393,268.03 325.402,268.033 325.411,268.035 325.421,268.037 325.43,268.039 325.439,268.042 325.448,268.044 325.457,268.046 325.467,268.048 325.476,268.051 325.485,268.053 325.494,268.055 325.503,268.057 325.512,268.06 325.522,268.062 325.531,268.064 325.54,268.066 325.549,268.069 325.558,268.071 325.568,268.073 325.577,268.075 325.586,268.078 325.595,268.08 325.604,268.082 325.614,268.084 325.623,268.087 325.632,268.089 325.641,268.091 325.65,268.093 325.66,268.096 325.669,268.098 325.678,268.1 325.687,268.102 325.696,268.105 325.705,268.107 325.715,268.109 325.724,268.111 325.733,268.114 325.742,268.116 325.751,268.118 325.761,268.12 325.77,268.123 325.779,268.125 325.788,268.127 325.797,268.129 325.807,268.131 325.816,268.134 325.825,268.136 325.834,268.138 325.843,268.14 325.852,268.143 325.862,268.145 325.871,268.147 325.88,268.149 325.889,268.152 325.898,268.154 325.908,268.156 325.917,268.158 325.926,268.161 325.935,268.163 325.944,268.165 325.954,268.167 325.963,268.17 325.972,268.172 325.981,268.174 325.99,268.176 326,268.179 326.009,268.181 326.018,268.183 326.027,268.185 326.036,268.188 326.045,268.19 326.055,268.192 326.064,268.194 326.073,268.197 326.082,268.199 326.091,268.201 326.101,268.203 326.11,268.206 326.119,268.208 326.128,268.21 326.137,268.212 326.147,268.215 326.156,268.217 326.165,268.219 326.174,268.221 326.183,268.224 326.192,268.226 326.202,268.228 326.211,268.23 326.22,268.233 326.229,268.235 326.238,268.237 326.248,268.239 326.257,268.242 326.266,268.244 326.275,268.246 326.284,268.248 326.294,268.251 326.303,268.253 326.312,268.255 326.321,268.257 326.33,268.26 326.34,268.262 326.349,268.264 326.358,268.266 326.367,268.269 326.376,268.271 326.385,268.273 326.395,268.275 326.404,268.278 326.413,268.28 326.422,268.282 326.431,268.284 326.441,268.287 326.45,268.289 326.459,268.291 326.468,268.293 326.477,268.296 326.487,268.298 326.496,268.3 326.505,268.302 326.514,268.304 326.523,268.307 326.532,268.309 326.542,268.311 326.551,268.313 326.56,268.316 326.569,268.318 326.578,268.32 326.588,268.322 326.597,268.325 326.606,268.327 326.615,268.329 326.624,268.331 326.634,268.334 326.643,268.336 326.652,268.338 326.661,268.34 326.67,268.343 326.68,268.345 326.689,268.347 326.698,268.349 326.707,268.352 326.716,268.354 326.725,268.356 326.735,268.358 326.744,268.361 326.753,268.363 326.762,268.365 326.771,268.367 326.781,268.37 326.79,268.372 326.799,268.374 326.808,268.376 326.817,268.379 326.827,268.381 326.836,268.383 326.845,268.385 326.854,268.388 326.863,268.39 326.873,268.392 326.882,268.394 326.891,268.397 326.9,268.399 326.909,268.401 326.918,268.403 326.928,268.406 326.937,268.408 326.946,268.41 326.955,268.412 326.964,268.415 326.974,268.417 326.983,268.419 326.992,268.421 327.001,268.424 327.01,268.426 327.02,268.428 327.029,268.43 327.038,268.432 327.047,268.435 327.056,268.437 327.065,268.439 327.075,268.441 327.084,268.444 327.093,268.446 327.102,268.448 327.111,268.45 327.121,268.453 327.13,268.455 327.139,268.457 327.148,268.459 327.157,268.462 327.167,268.464 327.176,268.466 327.185,268.468 327.194,268.471 327.203,268.473 327.213,268.475 327.222,268.477 327.231,268.48 327.24,268.482 327.249,268.484 327.258,268.486 327.268,268.489 327.277,268.491 327.286,268.493 327.295,268.495 327.304,268.498 327.314,268.5 327.323,268.502 327.332,268.504 327.341,268.507 327.35,268.509 327.36,268.511 327.369,268.513 327.378,268.516 327.387,268.518 327.396,268.52 327.405,268.522 327.415,268.525 327.424,268.527 327.433,268.529 327.442,268.531 327.451,268.534 327.461,268.536 327.47,268.538 327.479,268.54 327.488,268.542 327.497,268.545 327.507,268.547 327.516,268.549 327.525,268.551 327.534,268.554 327.543,268.556 327.553,268.558 327.562,268.56 327.571,268.563 327.58,268.565 327.589,268.567 327.598,268.569 327.608,268.572 327.617,268.574 327.626,268.576 327.635,268.578 327.644,268.581 327.654,268.583 327.663,268.585 327.672,268.587 327.681,268.59 327.69,268.592 327.7,268.594 327.709,268.596 327.718,268.599 327.727,268.601 327.736,268.603 327.745,268.605 327.755,268.608 327.764,268.61 327.773,268.612 327.782,268.614 327.791,268.617 327.801,268.619 327.81,268.621 327.819,268.623 327.828,268.626 327.837,268.628 327.847,268.63 327.856,268.632 327.865,268.634 327.874,268.637 327.883,268.639 327.893,268.641 327.902,268.643 327.911,268.646 327.92,268.648 327.929,268.65 327.938,268.652 327.948,268.655 327.957,268.657 327.966,268.659 327.975,268.661 327.984,268.664 327.994,268.666 328.003,268.668 328.012,268.67 328.021,268.673 328.03,268.675 328.04,268.677 328.049,268.679 328.058,268.682 328.067,268.684 328.076,268.686 328.085,268.688 328.095,268.691 328.104,268.693 328.113,268.695 328.122,268.697 328.131,268.7 328.141,268.702 328.15,268.704 328.159,268.706 328.168,268.709 328.177,268.711 328.187,268.713 328.196,268.715 328.205,268.717 328.214,268.72 328.223,268.722 328.233,268.724 328.242,268.726 328.251,268.729 328.26,268.731 328.269,268.733 328.278,268.735 328.288,268.738 328.297,268.74 328.306,268.742 328.315,268.744 328.324,268.747 328.334,268.749 328.343,268.751 328.352,268.753 328.361,268.756 328.37,268.758 328.38,268.76 328.389,268.762 328.398,268.765 328.407,268.767 328.416,268.769 328.425,268.771 328.435,268.774 328.444,268.776 328.453,268.778 328.462,268.78 328.471,268.783 328.481,268.785 328.49,268.787 328.499,268.789 328.508,268.792 328.517,268.794 328.527,268.796 328.536,268.798 328.545,268.8 328.554,268.803 328.563,268.805 328.573,268.807 328.582,268.809 328.591,268.812 328.6,268.814 328.609,268.816 328.618,268.818 328.628,268.821 328.637,268.823 328.646,268.825 328.655,268.827 328.664,268.83 328.674,268.832 328.683,268.834 328.692,268.836 328.701,268.839 328.71,268.841 328.72,268.843 328.729,268.845 328.738,268.848 328.747,268.85 328.756,268.852 328.765,268.854 328.775,268.857 328.784,268.859 328.793,268.861 328.802,268.863 328.811,268.866 328.821,268.868 328.83,268.87 328.839,268.872 328.848,268.874 328.857,268.877 328.867,268.879 328.876,268.881 328.885,268.883 328.894,268.886 328.903,268.888 328.913,268.89 328.922,268.892 328.931,268.895 328.94,268.897 328.949,268.899 328.958,268.901 328.968,268.904 328.977,268.906 328.986,268.908 328.995,268.91 329.004,268.913 329.014,268.915 329.023,268.917 329.032,268.919 329.041,268.922 329.05,268.924 329.06,268.926 329.069,268.928 329.078,268.931 329.087,268.933 329.096,268.935 329.106,268.937 329.115,268.939 329.124,268.942 329.133,268.944 329.142,268.946 329.151,268.948 329.161,268.951 329.17,268.953 329.179,268.955 329.188,268.957 329.197,268.96 329.207,268.962 329.216,268.964 329.225,268.966 329.234,268.969 329.243,268.971 329.253,268.973 329.262,268.975 329.271,268.978 329.28,268.98 329.289,268.982 329.298,268.984 329.308,268.987 329.317,268.989 329.326,268.991 329.335,268.993 329.344,268.996 329.354,268.998 329.363,269 329.372,269.002 329.381,269.004 329.39,269.007 329.4,269.009 329.409,269.011 329.418,269.013 329.427,269.016 329.436,269.018 329.446,269.02 329.455,269.022 329.464,269.025 329.473,269.027 329.482,269.029 329.491,269.031 329.501,269.034 329.51,269.036 329.519,269.038 329.528,269.04 329.537,269.043 329.547,269.045 329.556,269.047 329.565,269.049 329.574,269.052 329.583,269.054 329.593,269.056 329.602,269.058 329.611,269.06 329.62,269.063 329.629,269.065 329.638,269.067 329.648,269.069 329.657,269.072 329.666,269.074 329.675,269.076 329.684,269.078 329.694,269.081 329.703,269.083 329.712,269.085 329.721,269.087 329.73,269.09 329.74,269.092 329.749,269.094 329.758,269.096 329.767,269.099 329.776,269.101 329.786,269.103 329.795,269.105 329.804,269.108 329.813,269.11 329.822,269.112 329.831,269.114 329.841,269.116 329.85,269.119 329.859,269.121 329.868,269.123 329.877,269.125 329.887,269.128 329.896,269.13 329.905,269.132 329.914,269.134 329.923,269.137 329.933,269.139 329.942,269.141 329.951,269.143 329.96,269.146 329.969,269.148 329.978,269.15 329.988,269.152 329.997,269.155 330.006,269.157 330.015,269.159 330.024,269.161 330.034,269.164 330.043,269.166 330.052,269.168 330.061,269.17 330.07,269.172 330.08,269.175 330.089,269.177 330.098,269.179 330.107,269.181 330.116,269.184 330.126,269.186 330.135,269.188 330.144,269.19 330.153,269.193 330.162,269.195 330.171,269.197 330.181,269.199 330.19,269.202 330.199,269.204 330.208,269.206 330.217,269.208 330.227,269.211 330.236,269.213 330.245,269.215 330.254,269.217 330.263,269.22 330.273,269.222 330.282,269.224 330.291,269.226 330.3,269.228 330.309,269.231 330.318,269.233 330.328,269.235 330.337,269.237 330.346,269.24 330.355,269.242 330.364,269.244 330.374,269.246 330.383,269.249 330.392,269.251 330.401,269.253 330.41,269.255 330.42,269.258 330.429,269.26 330.438,269.262 330.447,269.264 330.456,269.267 330.466,269.269 330.475,269.271 330.484,269.273 330.493,269.275 330.502,269.278 330.511,269.28 330.521,269.282 330.53,269.284 330.539,269.287 330.548,269.289 330.557,269.291 330.567,269.293 330.576,269.296 330.585,269.298 330.594,269.3 330.603,269.302 330.613,269.305 330.622,269.307 330.631,269.309 330.64,269.311 330.649,269.314 330.658,269.316 330.668,269.318 330.677,269.32 330.686,269.323 330.695,269.325 330.704,269.327 330.714,269.329 330.723,269.331 330.732,269.334 330.741,269.336 330.75,269.338 330.76,269.34 330.769,269.343 330.778,269.345 330.787,269.347 330.796,269.349 330.806,269.352 330.815,269.354 330.824,269.356 330.833,269.358 330.842,269.361 330.851,269.363 330.861,269.365 330.87,269.367 330.879,269.37 330.888,269.372 330.897,269.374 330.907,269.376 330.916,269.378 330.925,269.381 330.934,269.383 330.943,269.385 330.953,269.387 330.962,269.39 330.971,269.392 330.98,269.394 330.989,269.396 330.998,269.398 331.008,269.401 331.017,269.403 331.026,269.405 331.035,269.407 331.044,269.409 331.054,269.412 331.063,269.414 331.072,269.416 331.081,269.418 331.09,269.42 331.1,269.422 331.109,269.424 331.118,269.426 331.127,269.428 331.136,269.43 331.146,269.433 331.155,269.435 331.164,269.437 331.173,269.439 331.182,269.441 331.191,269.443 331.201,269.445 331.21,269.447 331.219,269.449 331.228,269.451 331.237,269.453 331.247,269.455 331.256,269.457 331.265,269.459 331.274,269.461 331.283,269.463 331.293,269.465 331.302,269.466 331.311,269.468 331.32,269.47 331.329,269.472 331.338,269.474 331.348,269.476 331.357,269.478 331.366,269.48 331.375,269.482 331.384,269.483 331.394,269.485 331.403,269.487 331.412,269.489 331.421,269.491 331.43,269.493 331.44,269.494 331.449,269.496 331.458,269.498 331.467,269.5 331.476,269.502 331.486,269.503 331.495,269.505 331.504,269.507 331.513,269.509 331.522,269.51 331.531,269.512 331.541,269.514 331.55,269.515 331.559,269.517 331.568,269.519 331.577,269.52 331.587,269.522 331.596,269.524 331.605,269.525 331.614,269.527 331.623,269.529 331.633,269.53 331.642,269.532 331.651,269.534 331.66,269.535 331.669,269.537 331.679,269.538 331.688,269.54 331.697,269.542 331.706,269.543 331.715,269.545 331.724,269.546 331.734,269.548 331.743,269.549 331.752,269.551 331.761,269.552 331.77,269.554 331.78,269.555 331.789,269.557 331.798,269.558 331.807,269.56 331.816,269.561 331.826,269.563 331.835,269.564 331.844,269.566 331.853,269.567 331.862,269.569 331.871,269.57 331.881,269.572 331.89,269.573 331.899,269.574 331.908,269.576 331.917,269.577 331.927,269.578 331.936,269.58 331.945,269.581 331.954,269.583 331.963,269.584 331.973,269.585 331.982,269.587 331.991,269.588 332,269.589 332.009,269.591 332.019,269.592 332.028,269.593 332.037,269.594 332.046,269.596 332.055,269.597 332.064,269.598 332.074,269.599 332.083,269.601 332.092,269.602 332.101,269.603 332.11,269.604 332.12,269.606 332.129,269.607 332.138,269.608 332.147,269.609 332.156,269.61 332.166,269.612 332.175,269.613 332.184,269.614 332.193,269.615 332.202,269.616 332.211,269.617 332.221,269.618 332.23,269.62 332.239,269.621 332.248,269.622 332.257,269.623 332.267,269.624 332.276,269.625 332.285,269.626 332.294,269.627 332.303,269.628 332.313,269.629 332.322,269.63 332.331,269.631 332.34,269.632 332.349,269.633 332.359,269.634 332.368,269.635 332.377,269.636 332.386,269.637 332.395,269.638 332.404,269.639 332.414,269.64 332.423,269.641 332.432,269.642 332.441,269.643 332.45,269.644 332.46,269.645 332.469,269.646 332.478,269.647 332.487,269.648 332.496,269.649 332.506,269.649 332.515,269.65 332.524,269.651 332.533,269.652 332.542,269.653 332.551,269.654 332.561,269.655 332.57,269.655 332.579,269.656 332.588,269.657 332.597,269.658 332.607,269.659 332.616,269.659 332.625,269.66 332.634,269.661 332.643,269.662 332.653,269.663 332.662,269.663 332.671,269.664 332.68,269.665 332.689,269.665 332.699,269.666 332.708,269.667 332.717,269.668 332.726,269.668 332.735,269.669 332.744,269.67 332.754,269.67 332.763,269.671 332.772,269.672 332.781,269.672 332.79,269.673 332.8,269.674 332.809,269.674 332.818,269.675 332.827,269.676 332.836,269.676 332.846,269.677 332.855,269.677 332.864,269.678 332.873,269.678 332.882,269.679 332.891,269.68 332.901,269.68 332.91,269.681 332.919,269.681 332.928,269.682 332.937,269.682 332.947,269.683 332.956,269.683 332.965,269.684 332.974,269.684 332.983,269.685 332.993,269.685 333.002,269.686 333.011,269.686 333.02,269.687 333.029,269.687 333.039,269.688 333.048,269.688 333.057,269.688 333.066,269.689 333.075,269.689 333.084,269.69 333.094,269.69 333.103,269.69 333.112,269.691 333.121,269.691 333.13,269.691 333.14,269.692 333.149,269.692 333.158,269.693 333.167,269.693 333.176,269.693 333.186,269.693 333.195,269.694 333.204,269.694 333.213,269.694 333.222,269.695 333.231,269.695 333.241,269.695 333.25,269.695 333.259,269.696 333.268,269.696 333.277,269.696 333.287,269.696 333.296,269.697 333.305,269.697 333.314,269.697 333.323,269.697 333.333,269.698 333.342,269.698 333.351,269.698 333.36,269.698 333.369,269.698 333.379,269.698 333.388,269.699 333.397,269.699 333.406,269.699 333.415,269.699 333.424,269.699 333.434,269.699 333.443,269.699 333.452,269.699 333.461,269.7 333.47,269.7 333.48,269.7 333.489,269.7 333.498,269.7 333.507,269.7 333.516,269.7 333.526,269.7 333.535,269.7 333.544,269.7 333.553,269.7 333.562,269.7 333.571,269.7 333.581,269.7 333.59,269.7 333.599,269.7 333.608,269.7 333.617,269.7 333.627,269.7 333.636,269.7 333.645,269.7 333.654,269.7 333.663,269.7 333.673,269.7 333.682,269.699 333.691,269.699 333.7,269.699 333.709,269.699 333.719,269.699 333.728,269.699 333.737,269.699 333.746,269.699 333.755,269.699 333.764,269.698 333.774,269.698 333.783,269.698 333.792,269.698 333.801,269.698 333.81,269.698 333.82,269.697 333.829,269.697 333.838,269.697 333.847,269.697 333.856,269.696 333.866,269.696 333.875,269.696 333.884,269.696 333.893,269.695 333.902,269.695 333.911,269.695 333.921,269.695 333.93,269.694 333.939,269.694 333.948,269.694 333.957,269.693 333.967,269.693 333.976,269.693 333.985,269.693 333.994,269.692 334.003,269.692 334.013,269.692 334.022,269.691 334.031,269.691 334.04,269.69 334.049,269.69 334.059,269.69 334.068,269.689 334.077,269.689 334.086,269.688 334.095,269.688 334.104,269.688 334.114,269.687 334.123,269.687 334.132,269.686 334.141,269.686 334.15,269.685 334.16,269.685 334.169,269.684 334.178,269.684 334.187,269.683 334.196,269.683 334.206,269.682 334.215,269.682 334.224,269.681 334.233,269.681 334.242,269.68 334.252,269.68 334.261,269.679 334.27,269.679 334.279,269.678 334.288,269.678 334.297,269.677 334.307,269.676 334.316,269.676 334.325,269.675 334.334,269.675 334.343,269.674 334.353,269.673 334.362,269.673 334.371,269.672 334.38,269.672 334.389,269.671 334.399,269.67 334.408,269.67 334.417,269.669 334.426,269.668 334.435,269.668 334.444,269.667 334.454,269.666 334.463,269.666 334.472,269.665 334.481,269.664 334.49,269.663 334.5,269.663 334.509,269.662 334.518,269.661 334.527,269.66 334.536,269.66 334.546,269.659 334.555,269.658 334.564,269.657 334.573,269.657 334.582,269.656 334.592,269.655 334.601,269.654 334.61,269.653 334.619,269.652 334.628,269.652 334.637,269.651 334.647,269.65 334.656,269.649 334.665,269.648 334.674,269.647 334.683,269.647 334.693,269.646 334.702,269.645 334.711,269.644 334.72,269.643 334.729,269.642 334.739,269.641 334.748,269.64 334.757,269.639 334.766,269.638 334.775,269.637 334.784,269.636 334.794,269.635 334.803,269.635 334.812,269.634 334.821,269.633 334.83,269.632 334.84,269.631 334.849,269.63 334.858,269.629 334.867,269.628 334.876,269.627 334.886,269.626 334.895,269.624 334.904,269.623 334.913,269.622 334.922,269.621 334.932,269.62 334.941,269.619 334.95,269.618 334.959,269.617 334.968,269.616 334.977,269.615 334.987,269.614 334.996,269.613 335.005,269.612 335.014,269.61 335.023,269.609 335.033,269.608 335.042,269.607 335.051,269.606 335.06,269.605 335.069,269.603 335.079,269.602 335.088,269.601 335.097,269.6 335.106,269.599 335.115,269.598 335.124,269.596 335.134,269.595 335.143,269.594 335.152,269.593 335.161,269.591 335.17,269.59 335.18,269.589 335.189,269.588 335.198,269.586 335.207,269.585 335.216,269.584 335.226,269.583 335.235,269.581 335.244,269.58 335.253,269.579 335.262,269.577 335.272,269.576 335.281,269.575 335.29,269.573 335.299,269.572 335.308,269.571 335.317,269.569 335.327,269.568 335.336,269.567 335.345,269.565 335.354,269.564 335.363,269.562 335.373,269.561 335.382,269.56 335.391,269.558 335.4,269.557 335.409,269.555 335.419,269.554 335.428,269.553 335.437,269.551 335.446,269.55 335.455,269.548 335.464,269.547 335.474,269.545 335.483,269.544 335.492,269.542 335.501,269.541 335.51,269.539 335.52,269.538 335.529,269.536 335.538,269.535 335.547,269.533 335.556,269.532 335.566,269.53 335.575,269.529 335.584,269.527 335.593,269.526 335.602,269.524 335.612,269.522 335.621,269.521 335.63,269.519 335.639,269.518 335.648,269.516 335.657,269.514 335.667,269.513 335.676,269.511 335.685,269.51 335.694,269.508 335.703,269.506 335.713,269.505 335.722,269.503 335.731,269.501 335.74,269.5 335.749,269.498 335.759,269.496 335.768,269.495 335.777,269.493 335.786,269.491 335.795,269.49 335.804,269.488 335.814,269.486 335.823,269.484 335.832,269.483 335.841,269.481 335.85,269.479 335.86,269.477 335.869,269.476 335.878,269.474 335.887,269.472 335.896,269.47 335.906,269.469 335.915,269.467 335.924,269.465 335.933,269.463 335.942,269.461 335.952,269.459 335.961,269.458 335.97,269.456 335.979,269.454 335.988,269.452 335.997,269.45 336.007,269.448 336.016,269.447 336.025,269.445 336.034,269.443 336.043,269.441 336.053,269.439 336.062,269.437 336.071,269.435 336.08,269.433 336.089,269.431 336.099,269.429 336.108,269.427 336.117,269.426 336.126,269.424 336.135,269.422 336.144,269.42 336.154,269.418 336.163,269.416 336.172,269.414 336.181,269.412 336.19,269.41 336.2,269.408 336.209,269.406 336.218,269.404 336.227,269.402 336.236,269.4 336.246,269.398 336.255,269.396 336.264,269.394 336.273,269.392 336.282,269.389 336.292,269.387 336.301,269.385 336.31,269.383 336.319,269.381 336.328,269.379 336.337,269.377 336.347,269.375 336.356,269.373 336.365,269.371 336.374,269.369 336.383,269.366 336.393,269.364 336.402,269.362 336.411,269.36 336.42,269.358 336.429,269.356 336.439,269.353 336.448,269.351 336.457,269.349 336.466,269.347 336.475,269.345 336.485,269.342 336.494,269.34 336.503,269.338 336.512,269.336 336.521,269.334 336.53,269.331 336.54,269.329 336.549,269.327 336.558,269.325 336.567,269.322 336.576,269.32 336.586,269.318 336.595,269.316 336.604,269.313 336.613,269.311 336.622,269.309 336.632,269.306 336.641,269.304 336.65,269.302 336.659,269.299 336.668,269.297 336.677,269.295 336.687,269.292 336.696,269.29 336.705,269.288 336.714,269.285 336.723,269.283 336.733,269.281 336.742,269.278 336.751,269.276 336.76,269.273 336.769,269.271 336.779,269.269 336.788,269.266 336.797,269.264 336.806,269.261 336.815,269.259 336.825,269.256 336.834,269.254 336.843,269.251 336.852,269.249 336.861,269.247 336.87,269.244 336.88,269.242 336.889,269.239 336.898,269.237 336.907,269.234 336.916,269.232 336.926,269.229 336.935,269.227 336.944,269.224 336.953,269.221 336.962,269.219 336.972,269.216 336.981,269.214 336.99,269.211 336.999,269.209 337.008,269.206 337.017,269.204 337.027,269.201 337.036,269.198 337.045,269.196 337.054,269.193 337.063,269.191 337.073,269.188 337.082,269.185 337.091,269.183 337.1,269.18 337.109,269.177 337.119,269.175 337.128,269.172 337.137,269.169 337.146,269.167 337.155,269.164 337.165,269.161 337.174,269.159 337.183,269.156 337.192,269.153 337.201,269.151 337.21,269.148 337.22,269.145 337.229,269.143 337.238,269.14 337.247,269.137 337.256,269.134 337.266,269.132 337.275,269.129 337.284,269.126 337.293,269.123 337.302,269.121 337.312,269.118 337.321,269.115 337.33,269.112 337.339,269.109 337.348,269.107 337.357,269.104 337.367,269.101 337.376,269.098 337.385,269.095 337.394,269.092 337.403,269.09 337.413,269.087 337.422,269.084 337.431,269.081 337.44,269.078 337.449,269.075 337.459,269.072 337.468,269.07 337.477,269.067 337.486,269.064 337.495,269.061 337.505,269.058 337.514,269.055 337.523,269.052 337.532,269.049 337.541,269.046 337.55,269.043 337.56,269.04 337.569,269.037 337.578,269.034 337.587,269.031 337.596,269.028 337.606,269.025 337.615,269.022 337.624,269.019 337.633,269.016 337.642,269.013 337.652,269.01 337.661,269.007 337.67,269.004 337.679,269.001 337.688,268.998 337.697,268.995 337.707,268.992 337.716,268.989 337.725,268.986 337.734,268.983 337.743,268.98 337.753,268.977 337.762,268.974 337.771,268.971 337.78,268.968 337.789,268.965 337.799,268.961 337.808,268.958 337.817,268.955 337.826,268.952 337.835,268.949 337.845,268.946 337.854,268.943 337.863,268.94 337.872,268.936 337.881,268.933 337.89,268.93 337.9,268.927 337.909,268.924 337.918,268.92 337.927,268.917 337.936,268.914 337.946,268.911 337.955,268.908 337.964,268.904 337.973,268.901 337.982,268.898 337.992,268.895 338.001,268.892 338.01,268.888 338.019,268.885 338.028,268.882 338.037,268.878 338.047,268.875 338.056,268.872 338.065,268.869 338.074,268.865 338.083,268.862 338.093,268.859 338.102,268.855 338.111,268.852 338.12,268.849 338.129,268.845 338.139,268.842 338.148,268.839 338.157,268.835 338.166,268.832 338.175,268.829 338.185,268.825 338.194,268.822 338.203,268.819 338.212,268.815 338.221,268.812 338.23,268.808 338.24,268.805 338.249,268.802 338.258,268.798 338.267,268.795 338.276,268.791 338.286,268.788 338.295,268.785 338.304,268.781 338.313,268.778 338.322,268.774 338.332,268.771 338.341,268.767 338.35,268.764 338.359,268.76 338.368,268.757 338.377,268.753 338.387,268.75 338.396,268.746 338.405,268.743 338.414,268.739 338.423,268.736 338.433,268.732 338.442,268.729 338.451,268.725 338.46,268.722 338.469,268.718 338.479,268.715 338.488,268.711 338.497,268.707 338.506,268.704 338.515,268.7 338.525,268.697 338.534,268.693 338.543,268.689 338.552,268.686 338.561,268.682 338.57,268.679 338.58,268.675 338.589,268.671 338.598,268.668 338.607,268.664 338.616,268.66 338.626,268.657 338.635,268.653 338.644,268.649 338.653,268.646 338.662,268.642 338.672,268.638 338.681,268.635 338.69,268.631 338.699,268.627 338.708,268.624 338.717,268.62 338.727,268.616 338.736,268.613 338.745,268.609 338.754,268.605 338.763,268.601 338.773,268.598 338.782,268.594 338.791,268.59 338.8,268.586 338.809,268.583 338.819,268.579 338.828,268.575 338.837,268.571 338.846,268.567 338.855,268.564 338.865,268.56 338.874,268.556 338.883,268.552 338.892,268.548 338.901,268.545 338.91,268.541 338.92,268.537 338.929,268.533 338.938,268.529 338.947,268.525 338.956,268.521 338.966,268.518 338.975,268.514 338.984,268.51 338.993,268.506 339.002,268.502 339.012,268.498 339.021,268.494 339.03,268.49 339.039,268.486 339.048,268.483 339.058,268.479 339.067,268.475 339.076,268.471 339.085,268.467 339.094,268.463 339.103,268.459 339.113,268.455 339.122,268.451 339.131,268.447 339.14,268.443 339.149,268.439 339.159,268.435 339.168,268.431 339.177,268.427 339.186,268.423 339.195,268.419 339.205,268.415 339.214,268.411 339.223,268.407 339.232,268.403 339.241,268.399 339.25,268.395 339.26,268.391 339.269,268.387 339.278,268.383 339.287,268.379 339.296,268.374 339.306,268.37 339.315,268.366 339.324,268.362 339.333,268.358 339.342,268.354 339.352,268.35 339.361,268.346 339.37,268.342 339.379,268.338 339.388,268.333 339.398,268.329 339.407,268.325 339.416,268.321 339.425,268.317 339.434,268.313 339.443,268.308 339.453,268.304 339.462,268.3 339.471,268.296 339.48,268.292 339.489,268.288 339.499,268.283 339.508,268.279 339.517,268.275 339.526,268.271 339.535,268.267 339.545,268.262 339.554,268.258 339.563,268.254 339.572,268.25 339.581,268.245 339.59,268.241 339.6,268.237 339.609,268.233 339.618,268.228 339.627,268.224 339.636,268.22 339.646,268.215 339.655,268.211 339.664,268.207 339.673,268.202 339.682,268.198 339.692,268.194 339.701,268.19 339.71,268.185 339.719,268.181 339.728,268.176 339.738,268.172 339.747,268.168 339.756,268.163 339.765,268.159 339.774,268.155 339.783,268.15 339.793,268.146 339.802,268.142 339.811,268.137 339.82,268.133 339.829,268.128 339.839,268.124 339.848,268.12 339.857,268.115 339.866,268.111 339.875,268.106 339.885,268.102 339.894,268.097 339.903,268.093 339.912,268.088 339.921,268.084 339.93,268.08 339.94,268.075 339.949,268.071 339.958,268.066 339.967,268.062 339.976,268.057 339.986,268.053 339.995,268.048 340.004,268.044 340.013,268.039 340.022,268.035 340.032,268.03 340.041,268.026 340.05,268.021 340.059,268.016 340.068,268.012 340.078,268.007 340.087,268.003 340.096,267.998 340.105,267.994 340.114,267.989 340.123,267.985 340.133,267.98 340.142,267.975 340.151,267.971 340.16,267.966 340.169,267.962 340.179,267.957 340.188,267.952 340.197,267.948 340.206,267.943 340.215,267.938 340.225,267.934 340.234,267.929 340.243,267.924 340.252,267.92 340.261,267.915 340.27,267.91 340.28,267.906 340.289,267.901 340.298,267.896 340.307,267.892 340.316,267.887 340.326,267.882 340.335,267.878 340.344,267.873 340.353,267.868 340.362,267.863 340.372,267.859 340.381,267.854 340.39,267.849 340.399,267.845 340.408,267.84 340.418,267.835 340.427,267.83 340.436,267.825 340.445,267.821 340.454,267.816 340.463,267.811 340.473,267.806 340.482,267.802 340.491,267.797 340.5,267.792 340.509,267.787 340.519,267.782 340.528,267.778 340.537,267.773 340.546,267.768 340.555,267.763 340.565,267.758 340.574,267.753 340.583,267.748 340.592,267.744 340.601,267.739 340.61,267.734 340.62,267.729 340.629,267.724 340.638,267.719 340.647,267.714 340.656,267.709 340.666,267.705 340.675,267.7 340.684,267.695 340.693,267.69 340.702,267.685 340.712,267.68 340.721,267.675 340.73,267.67 340.739,267.665 340.748,267.66 340.758,267.655 340.767,267.65 340.776,267.645 340.785,267.64 340.794,267.635 340.803,267.63 340.813,267.625 340.822,267.62 340.831,267.615 340.84,267.61 340.849,267.605 340.859,267.6 340.868,267.595 340.877,267.59 340.886,267.585 340.895,267.58 340.905,267.575 340.914,267.57 340.923,267.565 340.932,267.56 340.941,267.555 340.95,267.55 340.96,267.545 340.969,267.54 340.978,267.535 340.987,267.53 340.996,267.525 341.006,267.519 341.015,267.514 341.024,267.509 341.033,267.504 341.042,267.499 341.052,267.494 341.061,267.489 341.07,267.484 341.079,267.478 341.088,267.473 341.098,267.468 341.107,267.463 341.116,267.458 341.125,267.453 341.134,267.448 341.143,267.442 341.153,267.437 341.162,267.432 341.171,267.427 341.18,267.422 341.189,267.416 341.199,267.411 341.208,267.406 341.217,267.401 341.226,267.396 341.235,267.39 341.245,267.385 341.254,267.38 341.263,267.375 341.272,267.369 341.281,267.364 341.29,267.359 341.3,267.354 341.309,267.348 341.318,267.343 341.327,267.338 341.336,267.332 341.346,267.327 341.355,267.322 341.364,267.317 341.373,267.311 341.382,267.306 341.392,267.301 341.401,267.295 341.41,267.29 341.419,267.285 341.428,267.279 341.438,267.274 341.447,267.269 341.456,267.263 341.465,267.258 341.474,267.253 341.483,267.247 341.493,267.242 341.502,267.236 341.511,267.231 341.52,267.226 341.529,267.22 341.539,267.215 341.548,267.209 341.557,267.204 341.566,267.199 341.575,267.193 341.585,267.188 341.594,267.182 341.603,267.177 341.612,267.171 341.621,267.166 341.631,267.161 341.64,267.155 341.649,267.15 341.658,267.144 341.667,267.139 341.676,267.133 341.686,267.128 341.695,267.122 341.704,267.117 341.713,267.111 341.722,267.106 341.732,267.1 341.741,267.095 341.75,267.089 341.759,267.084 341.768,267.078 341.778,267.073 341.787,267.067 341.796,267.062 341.805,267.056 341.814,267.05 341.823,267.045 341.833,267.039 341.842,267.034 341.851,267.028 341.86,267.023 341.869,267.017 341.879,267.011 341.888,267.006 341.897,267 341.906,266.995 341.915,266.989 341.925,266.983 341.934,266.978 341.943,266.972 341.952,266.967 341.961,266.961 341.971,266.955 341.98,266.95 341.989,266.944 341.998,266.938 342.007,266.933 342.016,266.927 342.026,266.921 342.035,266.916 342.044,266.91 342.053,266.904 342.062,266.899 342.072,266.893 342.081,266.887 342.09,266.881 342.099,266.876 342.108,266.87 342.118,266.864 342.127,266.859 342.136,266.853 342.145,266.847 342.154,266.841 342.163,266.836 342.173,266.83 342.182,266.824 342.191,266.818 342.2,266.813 342.209,266.807 342.219,266.801 342.228,266.795 342.237,266.79 342.246,266.784 342.255,266.778 342.265,266.772 342.274,266.766 342.283,266.761 342.292,266.755 342.301,266.749 342.311,266.743 342.32,266.737 342.329,266.731 342.338,266.726 342.347,266.72 342.356,266.714 342.366,266.708 342.375,266.702 342.384,266.696 342.393,266.69 342.402,266.685 342.412,266.679 342.421,266.673 342.43,266.667 342.439,266.661 342.448,266.655 342.458,266.649 342.467,266.643 342.476,266.637 342.485,266.631 342.494,266.626 342.503,266.62 342.513,266.614 342.522,266.608 342.531,266.602 342.54,266.596 342.549,266.59 342.559,266.584 342.568,266.578 342.577,266.572 342.586,266.566 342.595,266.56 342.605,266.554 342.614,266.548 342.623,266.542 342.632,266.536 342.641,266.53 342.651,266.524 342.66,266.518 342.669,266.512 342.678,266.506 342.687,266.5 342.696,266.494 342.706,266.488 342.715,266.482 342.724,266.476 342.733,266.47 342.742,266.464 342.752,266.458 342.761,266.452 342.77,266.446 342.779,266.44 342.788,266.433 342.798,266.427 342.807,266.421 342.816,266.415 342.825,266.409 342.834,266.403 342.843,266.397 342.853,266.391 342.862,266.385 342.871,266.379 342.88,266.372 342.889,266.366 342.899,266.36 342.908,266.354 342.917,266.348 342.926,266.342 342.935,266.336 342.945,266.329 342.954,266.323 342.963,266.317 342.972,266.311 342.981,266.305 342.991,266.299 343,266.292 343.009,266.286 343.018,266.28 343.027,266.274 343.036,266.268 343.046,266.261 343.055,266.255 343.064,266.249 343.073,266.243 343.082,266.236 343.092,266.23 343.101,266.224 343.11,266.218 343.119,266.211 343.128,266.205 343.138,266.199 343.147,266.193 343.156,266.186 343.165,266.18 343.174,266.174 343.183,266.168 343.193,266.161 343.202,266.155 343.211,266.149 343.22,266.142 343.229,266.136 343.239,266.13 343.248,266.123 343.257,266.117 343.266,266.111 343.275,266.105 343.285,266.098 343.294,266.092 343.303,266.085 343.312,266.079 343.321,266.073 343.331,266.066 343.34,266.06 343.349,266.054 343.358,266.047 343.367,266.041 343.376,266.035 343.386,266.028 343.395,266.022 343.404,266.015 343.413,266.009 343.422,266.003 343.432,265.996 343.441,265.99 343.45,265.983 343.459,265.977 343.468,265.97 343.478,265.964 343.487,265.958 343.496,265.951 343.505,265.945 343.514,265.938 343.523,265.932 343.533,265.925 343.542,265.919 343.551,265.912 343.56,265.906 343.569,265.899 343.579,265.893 343.588,265.886 343.597,265.88 343.606,265.873 343.615,265.867 343.625,265.86 343.634,265.854 343.643,265.847 343.652,265.841 343.661,265.834 343.671,265.828 343.68,265.821 343.689,265.815 343.698,265.808 343.707,265.802 343.716,265.795 343.726,265.789 343.735,265.782 343.744,265.775 343.753,265.769 343.762,265.762 343.772,265.756 343.781,265.749 343.79,265.743 343.799,265.736 343.808,265.729 343.818,265.723 343.827,265.716 343.836,265.71 343.845,265.703 343.854,265.696 343.864,265.69 343.873,265.683 343.882,265.676 343.891,265.67 343.9,265.663 343.909,265.656 343.919,265.65 343.928,265.643 343.937,265.636 343.946,265.63 343.955,265.623 343.965,265.616 343.974,265.61 343.983,265.603 343.992,265.596 344.001,265.59 344.011,265.583 344.02,265.576 344.029,265.57 344.038,265.563 344.047,265.556 344.056,265.549 344.066,265.543 344.075,265.536 344.084,265.529 344.093,265.522 344.102,265.516 344.112,265.509 344.121,265.502 344.13,265.495 344.139,265.489 344.148,265.482 344.158,265.475 344.167,265.468 344.176,265.462 344.185,265.455 344.194,265.448 344.204,265.441 344.213,265.434 344.222,265.428 344.231,265.421 344.24,265.414 344.249,265.407 344.259,265.4 344.268,265.394 344.277,265.387 344.286,265.38 344.295,265.373 344.305,265.366 344.314,265.359 344.323,265.352 344.332,265.346 344.341,265.339 344.351,265.332 344.36,265.325 344.369,265.318 344.378,265.311 344.387,265.304 344.396,265.297 344.406,265.291 344.415,265.284 344.424,265.277 344.433,265.27 344.442,265.263 344.452,265.256 344.461,265.249 344.47,265.242 344.479,265.235 344.488,265.228 344.498,265.221 344.507,265.214 344.516,265.208 344.525,265.201 344.534,265.194 344.544,265.187 344.553,265.18 344.562,265.173 344.571,265.166 344.58,265.159 344.589,265.152 344.599,265.145 344.608,265.138 344.617,265.131 344.626,265.124 344.635,265.117 344.645,265.11 344.654,265.103 344.663,265.096 344.672,265.089 344.681,265.082 344.691,265.075 344.7,265.068 344.709,265.061 344.718,265.054 344.727,265.047 344.736,265.039 344.746,265.032 344.755,265.025 344.764,265.018 344.773,265.011 344.782,265.004 344.792,264.997 344.801,264.99 344.81,264.983 344.819,264.976 344.828,264.969 344.838,264.962 344.847,264.955 344.856,264.947 344.865,264.94 344.874,264.933 344.884,264.926 344.893,264.919 344.902,264.912 344.911,264.905 344.92,264.898 344.929,264.89 344.939,264.883 344.948,264.876 344.957,264.869 344.966,264.862 344.975,264.855 344.985,264.847 344.994,264.84 345.003,264.833 345.012,264.826 345.021,264.819 345.031,264.812 345.04,264.804 345.049,264.797 345.058,264.79 345.067,264.783 345.076,264.775 345.086,264.768 345.095,264.761 345.104,264.754 345.113,264.747 345.122,264.739 345.132,264.732 345.141,264.725 345.15,264.718 345.159,264.71 345.168,264.703 345.178,264.696 345.187,264.689 345.196,264.681 345.205,264.674 345.214,264.667 345.224,264.66 345.233,264.652 345.242,264.645 345.251,264.638 345.26,264.63 345.269,264.623 345.279,264.616 345.288,264.608 345.297,264.601 345.306,264.594 345.315,264.586 345.325,264.579 345.334,264.572 345.343,264.564 345.352,264.557 345.361,264.55 345.371,264.542 345.38,264.535 345.389,264.528 345.398,264.52 345.407,264.513 345.416,264.506 345.426,264.498 345.435,264.491 345.444,264.483 345.453,264.476 345.462,264.469 345.472,264.461 345.481,264.454 345.49,264.447 345.499,264.439 345.508,264.432 345.518,264.424 345.527,264.417 345.536,264.409 345.545,264.402 345.554,264.395 345.564,264.387 345.573,264.38 345.582,264.372 345.591,264.365 345.6,264.357 345.609,264.35 345.619,264.342 345.628,264.335 345.637,264.327 345.646,264.32 345.655,264.313 345.665,264.305 345.674,264.298 345.683,264.29 345.692,264.283 345.701,264.275 345.711,264.268 345.72,264.26 345.729,264.253 345.738,264.245 345.747,264.238 345.756,264.23 345.766,264.222 345.775,264.215 345.784,264.207 345.793,264.2 345.802,264.192 345.812,264.185 345.821,264.177 345.83,264.17 345.839,264.162 345.848,264.155 345.858,264.147 345.867,264.139 345.876,264.132 345.885,264.124 345.894,264.117 345.904,264.109 345.913,264.101 345.922,264.094 345.931,264.086 345.94,264.079 345.949,264.071 345.959,264.063 345.968,264.056 345.977,264.048 345.986,264.041 345.995,264.033 346.005,264.025 346.014,264.018 346.023,264.01 346.032,264.002 346.041,263.995 346.051,263.987 346.06,263.979 346.069,263.972 346.078,263.964 346.087,263.956 346.096,263.949 346.106,263.941 346.115,263.933 346.124,263.926 346.133,263.918 346.142,263.91 346.152,263.903 346.161,263.895 346.17,263.887 346.179,263.879 346.188,263.872 346.198,263.864 346.207,263.856 346.216,263.849 346.225,263.841 346.234,263.833 346.244,263.825 346.253,263.818 346.262,263.81 346.271,263.802 346.28,263.794 346.289,263.787 346.299,263.779 346.308,263.771 346.317,263.763 346.326,263.755 346.335,263.748 346.345,263.74 346.354,263.732 346.363,263.724 346.372,263.716 346.381,263.709 346.391,263.701 346.4,263.693 346.409,263.685 346.418,263.677 346.427,263.67 346.437,263.662 346.446,263.654 346.455,263.646 346.464,263.638 346.473,263.63 346.482,263.623 346.492,263.615 346.501,263.607 346.51,263.599 346.519,263.591 346.528,263.583 346.538,263.575 346.547,263.568 346.556,263.56 346.565,263.552 346.574,263.544 346.584,263.536 346.593,263.528 346.602,263.52 346.611,263.512 346.62,263.504 346.629,263.497 346.639,263.489 346.648,263.481 346.657,263.473 346.666,263.465 346.675,263.457 346.685,263.449 346.694,263.441 346.703,263.433 346.712,263.425 346.721,263.417 346.731,263.409 346.74,263.401 346.749,263.393 346.758,263.385 346.767,263.377 346.777,263.369 346.786,263.361 346.795,263.353 346.804,263.346 346.813,263.338 346.822,263.33 346.832,263.322 346.841,263.314 346.85,263.306 346.859,263.298 346.868,263.29 346.878,263.281 346.887,263.273 346.896,263.265 346.905,263.257 346.914,263.249 346.924,263.241 346.933,263.233 346.942,263.225 346.951,263.217 346.96,263.209 346.969,263.201 346.979,263.193 346.988,263.185 346.997,263.177 347.006,263.169 347.015,263.161 347.025,263.153 347.034,263.145 347.043,263.137 347.052,263.128 347.061,263.12 347.071,263.112 347.08,263.104 347.089,263.096 347.098,263.088 347.107,263.08 347.117,263.072 347.126,263.064 347.135,263.055 347.144,263.047 347.153,263.039 347.162,263.031 347.172,263.023 347.181,263.015 347.19,263.007 347.199,262.999 347.208,262.99 347.218,262.982 347.227,262.974 347.236,262.966 347.245,262.958 347.254,262.95 347.264,262.941 347.273,262.933 347.282,262.925 347.291,262.917 347.3,262.909 347.309,262.9 347.319,262.892 347.328,262.884 347.337,262.876 347.346,262.868 347.355,262.859 347.365,262.851 347.374,262.843 347.383,262.835 347.392,262.826 347.401,262.818 347.411,262.81 347.42,262.802 347.429,262.794 347.438,262.785 347.447,262.777 347.457,262.769 347.466,262.76 347.475,262.752 347.484,262.744 347.493,262.736 347.502,262.727 347.512,262.719 347.521,262.711 347.53,262.703 347.539,262.694 347.548,262.686 347.558,262.678 347.567,262.669 347.576,262.661 347.585,262.653 347.594,262.644 347.604,262.636 347.613,262.628 347.622,262.619 347.631,262.611 347.64,262.603 347.649,262.594 347.659,262.586 347.668,262.578 347.677,262.569 347.686,262.561 347.695,262.553 347.705,262.544 347.714,262.536 347.723,262.528 347.732,262.519 347.741,262.511 347.751,262.503 347.76,262.494 347.769,262.486 347.778,262.477 347.787,262.469 347.797,262.461 347.806,262.452 347.815,262.444 347.824,262.435 347.833,262.427 347.842,262.419 347.852,262.41 347.861,262.402 347.87,262.393 347.879,262.385 347.888,262.376 347.898,262.368 347.907,262.36 347.916,262.351 347.925,262.343 347.934,262.334 347.944,262.326 347.953,262.317 347.962,262.309 347.971,262.3 347.98,262.292 347.989,262.283 347.999,262.275 348.008,262.266 348.017,262.258 348.026,262.25 348.035,262.241 348.045,262.233 348.054,262.224 348.063,262.216 348.072,262.207 348.081,262.199 348.091,262.19 348.1,262.181 348.109,262.173 348.118,262.164 348.127,262.156 348.137,262.147 348.146,262.139 348.155,262.13 348.164,262.122 348.173,262.113 348.182,262.105 348.192,262.096 348.201,262.088 348.21,262.079 348.219,262.07 348.228,262.062 348.238,262.053 348.247,262.045 348.256,262.036 348.265,262.028 348.274,262.019 348.284,262.01 348.293,262.002 348.302,261.993 348.311,261.985 348.32,261.976 348.329,261.967 348.339,261.959 348.348,261.95 348.357,261.942 348.366,261.933 348.375,261.924 348.385,261.916 348.394,261.907 348.403,261.898 348.412,261.89 348.421,261.881 348.431,261.872 348.44,261.864 348.449,261.855 348.458,261.846 348.467,261.838 348.477,261.829 348.486,261.82 348.495,261.812 348.504,261.803 348.513,261.794 348.522,261.786 348.532,261.777 348.541,261.768 348.55,261.76 348.559,261.751 348.568,261.742 348.578,261.734 348.587,261.725 348.596,261.716 348.605,261.707 348.614,261.699 348.624,261.69 348.633,261.681 348.642,261.673 348.651,261.664 348.66,261.655 348.669,261.646 348.679,261.638 348.688,261.629 348.697,261.62 348.706,261.611 348.715,261.603 348.725,261.594 348.734,261.585 348.743,261.576 348.752,261.568 348.761,261.559 348.771,261.55 348.78,261.541 348.789,261.532 348.798,261.524 348.807,261.515 348.817,261.506 348.826,261.497 348.835,261.488 348.844,261.48 348.853,261.471 348.862,261.462 348.872,261.453 348.881,261.444 348.89,261.436 348.899,261.427 348.908,261.418 348.918,261.409 348.927,261.4 348.936,261.391 348.945,261.383 348.954,261.374 348.964,261.365 348.973,261.356 348.982,261.347 348.991,261.338 349,261.329 349.01,261.321 349.019,261.312 349.028,261.303 349.037,261.294 349.046,261.285 349.055,261.276 349.065,261.267 349.074,261.258 349.083,261.249 349.092,261.241 349.101,261.232 349.111,261.223 349.12,261.214 349.129,261.205 349.138,261.196 349.147,261.187 349.157,261.178 349.166,261.169 349.175,261.16 349.184,261.151 349.193,261.142 349.202,261.134 349.212,261.125 349.221,261.116 349.23,261.107 349.239,261.098 349.248,261.089 349.258,261.08 349.267,261.071 349.276,261.062 349.285,261.053 349.294,261.044 349.304,261.035 349.313,261.026 349.322,261.017 349.331,261.008 349.34,260.999 349.35,260.99 349.359,260.981 349.368,260.972 349.377,260.963 349.386,260.954 349.395,260.945 349.405,260.936 349.414,260.927 349.423,260.918 349.432,260.909 349.441,260.9 349.451,260.891 349.46,260.882 349.469,260.873 349.478,260.864 349.487,260.855 349.497,260.846 349.506,260.837 349.515,260.827 349.524,260.818 349.533,260.809 349.542,260.8 349.552,260.791 349.561,260.782 349.57,260.773 349.579,260.764 349.588,260.755 349.598,260.746 349.607,260.737 349.616,260.728 349.625,260.719 349.634,260.709 349.644,260.7 349.653,260.691 349.662,260.682 349.671,260.673 349.68,260.664 349.69,260.655 349.699,260.646 349.708,260.637 349.717,260.627 349.726,260.618 349.735,260.609 349.745,260.6 349.754,260.591 349.763,260.582 349.772,260.573 349.781,260.563 349.791,260.554 349.8,260.545 349.809,260.536 349.818,260.527 349.827,260.518 349.837,260.508 349.846,260.499 349.855,260.49 349.864,260.481 349.873,260.472 349.882,260.462 349.892,260.453 349.901,260.444 349.91,260.435 349.919,260.426 349.928,260.416 349.938,260.407 349.947,260.398 349.956,260.389 349.965,260.38 349.974,260.37 349.984,260.361 349.993,260.352 350.002,260.343 350.011,260.333 350.02,260.324 350.03,260.315 350.039,260.306 350.048,260.296 350.057,260.287 350.066,260.278 350.075,260.269 350.085,260.259 350.094,260.25 350.103,260.241 350.112,260.232 350.121,260.222 350.131,260.213 350.14,260.204 350.149,260.195 350.158,260.185 350.167,260.176 350.177,260.167 350.186,260.157 350.195,260.148 350.204,260.139 350.213,260.129 350.222,260.12 350.232,260.111 350.241,260.102 350.25,260.092 350.259,260.083 350.268,260.074 350.278,260.064 350.287,260.055 350.296,260.046 350.305,260.036 350.314,260.027 350.324,260.018 350.333,260.008 350.342,259.999 350.351,259.989 350.36,259.98 350.37,259.971 350.379,259.961 350.388,259.952 350.397,259.943 350.406,259.933 350.415,259.924 350.425,259.914 350.434,259.905 350.443,259.896 350.452,259.886 350.461,259.877 350.471,259.868 350.48,259.858 350.489,259.849 350.498,259.839 350.507,259.83 350.517,259.821 350.526,259.811 350.535,259.802 350.544,259.792 350.553,259.783 350.562,259.773 350.572,259.764 350.581,259.755 350.59,259.745 350.599,259.736 350.608,259.726 350.618,259.717 350.627,259.707 350.636,259.698 350.645,259.688 350.654,259.679 350.664,259.669 350.673,259.66 350.682,259.651 350.691,259.641 350.7,259.632 350.71,259.622 350.719,259.613 350.728,259.603 350.737,259.594 350.746,259.584 350.755,259.575 350.765,259.565 350.774,259.556 350.783,259.546 350.792,259.537 350.801,259.527 350.811,259.518 350.82,259.508 350.829,259.499 350.838,259.489 350.847,259.48 350.857,259.47 350.866,259.46 350.875,259.451 350.884,259.441 350.893,259.432 350.902,259.422 350.912,259.413 350.921,259.403 350.93,259.394 350.939,259.384 350.948,259.375 350.958,259.365 350.967,259.355 350.976,259.346 350.985,259.336 350.994,259.327 351.004,259.317 351.013,259.308 351.022,259.298 351.031,259.288 351.04,259.279 351.05,259.269 351.059,259.26 351.068,259.25 351.077,259.24 351.086,259.231 351.095,259.221 351.105,259.212 351.114,259.202 351.123,259.192 351.132,259.183 351.141,259.173 351.151,259.163 351.16,259.154 351.169,259.144 351.178,259.135 351.187,259.125 351.197,259.115 351.206,259.106 351.215,259.096 351.224,259.086 351.233,259.077 351.243,259.067 351.252,259.057 351.261,259.048 351.27,259.038 351.279,259.028 351.288,259.019 351.298,259.009 351.307,258.999 351.316,258.99 351.325,258.98 351.334,258.97 351.344,258.961 351.353,258.951 351.362,258.941 351.371,258.931 351.38,258.922 351.39,258.912 351.399,258.902 351.408,258.893 351.417,258.883 351.426,258.873 351.435,258.863 351.445,258.854 351.454,258.844 351.463,258.834 351.472,258.825 351.481,258.815 351.491,258.805 351.5,258.795 351.509,258.786 351.518,258.776 351.527,258.766 351.537,258.756 351.546,258.747 351.555,258.737 351.564,258.727 351.573,258.717 351.583,258.707 351.592,258.698 351.601,258.688 351.61,258.678 351.619,258.668 351.628,258.659 351.638,258.649 351.647,258.639 351.656,258.629 351.665,258.619 351.674,258.61 351.684,258.6 351.693,258.59 351.702,258.58 351.711,258.57 351.72,258.561 351.73,258.551 351.739,258.541 351.748,258.531 351.757,258.521 351.766,258.511 351.775,258.502 351.785,258.492 351.794,258.482 351.803,258.472 351.812,258.462 351.821,258.452 351.831,258.443 351.84,258.433 351.849,258.423 351.858,258.413 351.867,258.403 351.877,258.393 351.886,258.383 351.895,258.374 351.904,258.364 351.913,258.354 351.923,258.344 351.932,258.334 351.941,258.324 351.95,258.314 351.959,258.304 351.968,258.294 351.978,258.285 351.987,258.275 351.996,258.265 352.005,258.255 352.014,258.245 352.024,258.235 352.033,258.225 352.042,258.215 352.051,258.205 352.06,258.195 352.07,258.185 352.079,258.176 352.088,258.166 352.097,258.156 352.106,258.146 352.115,258.136 352.125,258.126 352.134,258.116 352.143,258.106 352.152,258.096 352.161,258.086 352.171,258.076 352.18,258.066 352.189,258.056 352.198,258.046 352.207,258.036 352.217,258.026 352.226,258.016 352.235,258.006 352.244,257.996 352.253,257.986 352.263,257.976 352.272,257.966 352.281,257.956 352.29,257.946 352.299,257.936 352.308,257.926 352.318,257.916 352.327,257.906 352.336,257.896 352.345,257.886 352.354,257.876 352.364,257.866 352.373,257.856 352.382,257.846 352.391,257.836 352.4,257.826 352.41,257.816 352.419,257.806 352.428,257.796 352.437,257.786 352.446,257.776 352.455,257.766 352.465,257.756 352.474,257.746 352.483,257.736 352.492,257.726 352.501,257.716 352.511,257.706 352.52,257.696 352.529,257.686 352.538,257.675 352.547,257.665 352.557,257.655 352.566,257.645 352.575,257.635 352.584,257.625 352.593,257.615 352.603,257.605 352.612,257.595 352.621,257.585 352.63,257.575 352.639,257.565 352.648,257.554 352.658,257.544 352.667,257.534 352.676,257.524 352.685,257.514 352.694,257.504 352.704,257.494 352.713,257.484 352.722,257.473 352.731,257.463 352.74,257.453 352.75,257.443 352.759,257.433 352.768,257.423 352.777,257.413 352.786,257.402 352.795,257.392 352.805,257.382 352.814,257.372 352.823,257.362 352.832,257.352 352.841,257.342 352.851,257.331 352.86,257.321 352.869,257.311 352.878,257.301 352.887,257.291 352.897,257.281 352.906,257.27 352.915,257.26 352.924,257.25 352.933,257.24 352.943,257.23 352.952,257.219 352.961,257.209 352.97,257.199 352.979,257.189 352.988,257.179 352.998,257.168 353.007,257.158 353.016,257.148 353.025,257.138 353.034,257.128 353.044,257.117 353.053,257.107 353.062,257.097 353.071,257.087 353.08,257.076 353.09,257.066 353.099,257.056 353.108,257.046 353.117,257.035 353.126,257.025 353.135,257.015 353.145,257.005 353.154,256.994 353.163,256.984 353.172,256.974 353.181,256.964 353.191,256.953 353.2,256.943 353.209,256.933 353.218,256.923 353.227,256.912 353.237,256.902 353.246,256.892 353.255,256.881 353.264,256.871 353.273,256.861 353.283,256.851 353.292,256.84 353.301,256.83 353.31,256.82 353.319,256.809 353.328,256.799 353.338,256.789 353.347,256.778 353.356,256.768 353.365,256.758 353.374,256.747 353.384,256.737 353.393,256.727 353.402,256.716 353.411,256.706 353.42,256.696 353.43,256.685 353.439,256.675 353.448,256.665 353.457,256.654 353.466,256.644 353.475,256.634 353.485,256.623 353.494,256.613 353.503,256.603 353.512,256.592 353.521,256.582 353.531,256.572 353.54,256.561 353.549,256.551 353.558,256.54 353.567,256.53 353.577,256.52 353.586,256.509 353.595,256.499 353.604,256.489 353.613,256.478 353.623,256.468 353.632,256.457 353.641,256.447 353.65,256.437 353.659,256.426 353.668,256.416 353.678,256.405 353.687,256.395 353.696,256.385 353.705,256.374 353.714,256.364 353.724,256.353 353.733,256.343 353.742,256.332 353.751,256.322 353.76,256.312 353.77,256.301 353.779,256.291 353.788,256.28 353.797,256.27 353.806,256.259 353.816,256.249 353.825,256.239 353.834,256.228 353.843,256.218 353.852,256.207 353.861,256.197 353.871,256.186 353.88,256.176 353.889,256.165 353.898,256.155 353.907,256.144 353.917,256.134 353.926,256.123 353.935,256.113 353.944,256.102 353.953,256.092 353.963,256.081 353.972,256.071 353.981,256.061 353.99,256.05 353.999,256.04 354.008,256.029 354.018,256.019 354.027,256.008 354.036,255.997 354.045,255.987 354.054,255.976 354.064,255.966 354.073,255.955 354.082,255.945 354.091,255.934 354.1,255.924 354.11,255.913 354.119,255.903 354.128,255.892 354.137,255.882 354.146,255.871 354.156,255.861 354.165,255.85 354.174,255.84 354.183,255.829 354.192,255.818 354.201,255.808 354.211,255.797 354.22,255.787 354.229,255.776 354.238,255.766 354.247,255.755 354.257,255.745 354.266,255.734 354.275,255.723 354.284,255.713 354.293,255.702 354.303,255.692 354.312,255.681 354.321,255.67 354.33,255.66 354.339,255.649 354.348,255.639 354.358,255.628 354.367,255.618 354.376,255.607 354.385,255.596 354.394,255.586 354.404,255.575 354.413,255.564 354.422,255.554 354.431,255.543 354.44,255.533 354.45,255.522 354.459,255.511 354.468,255.501 354.477,255.49 354.486,255.479 354.496,255.469 354.505,255.458 354.514,255.448 354.523,255.437 354.532,255.426 354.541,255.416 354.551,255.405 354.56,255.394 354.569,255.384 354.578,255.373 354.587,255.362 354.597,255.352 354.606,255.341 354.615,255.33 354.624,255.32 354.633,255.309 354.643,255.298 354.652,255.288 354.661,255.277 354.67,255.266 354.679,255.256 354.688,255.245 354.698,255.234 354.707,255.224 354.716,255.213 354.725,255.202 354.734,255.192 354.744,255.181 354.753,255.17 354.762,255.159 354.771,255.149 354.78,255.138 354.79,255.127 354.799,255.117 354.808,255.106 354.817,255.095 354.826,255.084 354.836,255.074 354.845,255.063 354.854,255.052 354.863,255.041 354.872,255.031 354.881,255.02 354.891,255.009 354.9,254.999 354.909,254.988 354.918,254.977 354.927,254.966 354.937,254.956 354.946,254.945 354.955,254.934 354.964,254.923 354.973,254.913 354.983,254.902 354.992,254.891 355.001,254.88 355.01,254.869 355.019,254.859 355.028,254.848 355.038,254.837 355.047,254.826 355.056,254.816 355.065,254.805 355.074,254.794 355.084,254.783 355.093,254.772 355.102,254.762 355.111,254.751 355.12,254.74 355.13,254.729 355.139,254.718 355.148,254.708 355.157,254.697 355.166,254.686 355.176,254.675 355.185,254.664 355.194,254.654 355.203,254.643 355.212,254.632 355.221,254.621 355.231,254.61 355.24,254.599 355.249,254.589 355.258,254.578 355.267,254.567 355.277,254.556 355.286,254.545 355.295,254.534 355.304,254.524 355.313,254.513 355.323,254.502 355.332,254.491 355.341,254.48 355.35,254.469 355.359,254.458 355.368,254.448 355.378,254.437 355.387,254.426 355.396,254.415 355.405,254.404 355.414,254.393 355.424,254.382 355.433,254.371 355.442,254.361 355.451,254.35 355.46,254.339 355.47,254.328 355.479,254.317 355.488,254.306 355.497,254.295 355.506,254.284 355.516,254.273 355.525,254.263 355.534,254.252 355.543,254.241 355.552,254.23 355.561,254.219 355.571,254.208 355.58,254.197 355.589,254.186 355.598,254.175 355.607,254.164 355.617,254.153 355.626,254.142 355.635,254.131 355.644,254.121 355.653,254.11 355.663,254.099 355.672,254.088 355.681,254.077 355.69,254.066 355.699,254.055 355.708,254.044 355.718,254.033 355.727,254.022 355.736,254.011 355.745,254 355.754,253.989 355.764,253.978 355.773,253.967 355.782,253.956 355.791,253.945 355.8,253.934 355.81,253.923 355.819,253.912 355.828,253.901 355.837,253.89 355.846,253.879 355.856,253.868 355.865,253.857 355.874,253.847 355.883,253.836 355.892,253.825 355.901,253.814 355.911,253.803 355.92,253.792 355.929,253.781 355.938,253.77 355.947,253.759 355.957,253.747 355.966,253.736 355.975,253.725 355.984,253.714 355.993,253.703 356.003,253.692 356.012,253.681 356.021,253.67 356.03,253.659 356.039,253.648 356.048,253.637 356.058,253.626 356.067,253.615 356.076,253.604 356.085,253.593 356.094,253.582 356.104,253.571 356.113,253.56 356.122,253.549 356.131,253.538 356.14,253.527 356.15,253.516 356.159,253.505 356.168,253.494 356.177,253.483 356.186,253.472 356.196,253.46 356.205,253.449 356.214,253.438 356.223,253.427 356.232,253.416 356.241,253.405 356.251,253.394 356.26,253.383 356.269,253.372 356.278,253.361 356.287,253.35 356.297,253.339 356.306,253.327 356.315,253.316 356.324,253.305 356.333,253.294 356.343,253.283 356.352,253.272 356.361,253.261 356.37,253.25 356.379,253.239 356.389,253.228 356.398,253.216 356.407,253.205 356.416,253.194 356.425,253.183 356.434,253.172 356.444,253.161 356.453,253.15 356.462,253.139 356.471,253.127 356.48,253.116 356.49,253.105 356.499,253.094 356.508,253.083 356.517,253.072 356.526,253.061 356.536,253.049 356.545,253.038 356.554,253.027 356.563,253.016 356.572,253.005 356.581,252.994 356.591,252.982 356.6,252.971 356.609,252.96 356.618,252.949 356.627,252.938 356.637,252.927 356.646,252.915 356.655,252.904 356.664,252.893 356.673,252.882 356.683,252.871 356.692,252.86 356.701,252.848 356.71,252.837 356.719,252.826 356.729,252.815 356.738,252.804 356.747,252.792 356.756,252.781 356.765,252.77 356.774,252.759 356.784,252.748 356.793,252.736 356.802,252.725 356.811,252.714 356.82,252.703 356.83,252.691 356.839,252.68 356.848,252.669 356.857,252.658 356.866,252.647 356.876,252.635 356.885,252.624 356.894,252.613 356.903,252.602 356.912,252.59 356.921,252.579 356.931,252.568 356.94,252.557 356.949,252.545 356.958,252.534 356.967,252.523 356.977,252.512 356.986,252.5 356.995,252.489 357.004,252.478 357.013,252.467 357.023,252.455 357.032,252.444 357.041,252.433 357.05,252.422 357.059,252.41 357.069,252.399 357.078,252.388 357.087,252.377 357.096,252.365 357.105,252.354 357.114,252.343 357.124,252.331 357.133,252.32 357.142,252.309 357.151,252.298 357.16,252.286 357.17,252.275 357.179,252.264 357.188,252.252 357.197,252.241 357.206,252.23 357.216,252.218 357.225,252.207 357.234,252.196 357.243,252.185 357.252,252.173 357.261,252.162 357.271,252.151 357.28,252.139 357.289,252.128 357.298,252.117 357.307,252.105 357.317,252.094 357.326,252.083 357.335,252.071 357.344,252.06 357.353,252.049 357.363,252.037 357.372,252.026 357.381,252.015 357.39,252.003 357.399,251.992 357.409,251.981 357.418,251.969 357.427,251.958 357.436,251.947 357.445,251.935 357.454,251.924 357.464,251.912 357.473,251.901 357.482,251.89 357.491,251.878 357.5,251.867 357.51,251.856 357.519,251.844 357.528,251.833 357.537,251.821 357.546,251.81 357.556,251.799 357.565,251.787 357.574,251.776 357.583,251.765 357.592,251.753 357.601,251.742 357.611,251.73 357.62,251.719 357.629,251.708 357.638,251.696 357.647,251.685 357.657,251.673 357.666,251.662 357.675,251.651 357.684,251.639 357.693,251.628 357.703,251.616 357.712,251.605 357.721,251.594 357.73,251.582 357.739,251.571 357.749,251.559 357.758,251.548 357.767,251.536 357.776,251.525 357.785,251.514 357.794,251.502 357.804,251.491 357.813,251.479 357.822,251.468 357.831,251.456 357.84,251.445 357.85,251.433 357.859,251.422 357.868,251.411 357.877,251.399 357.886,251.388 357.896,251.376 357.905,251.365 357.914,251.353 357.923,251.342 357.932,251.33 357.941,251.319 357.951,251.307 357.96,251.296 357.969,251.285 357.978,251.273 357.987,251.262 357.997,251.25 358.006,251.239 358.015,251.227 358.024,251.216 358.033,251.204 358.043,251.193 358.052,251.181 358.061,251.17 358.07,251.158 358.079,251.147 358.089,251.135 358.098,251.124 358.107,251.112 358.116,251.101 358.125,251.089 358.134,251.078 358.144,251.066 358.153,251.055 358.162,251.043 358.171,251.032 358.18,251.02 358.19,251.009 358.199,250.997 358.208,250.986 358.217,250.974 358.226,250.963 358.236,250.951 358.245,250.94 358.254,250.928 358.263,250.916 358.272,250.905 358.281,250.893 358.291,250.882 358.3,250.87 358.309,250.859 358.318,250.847 358.327,250.836 358.337,250.824 358.346,250.813 358.355,250.801 358.364,250.789 358.373,250.778 358.383,250.766 358.392,250.755 358.401,250.743 358.41,250.732 358.419,250.72 358.429,250.709 358.438,250.697 358.447,250.685 358.456,250.674 358.465,250.662 358.474,250.651 358.484,250.639 358.493,250.628 358.502,250.616 358.511,250.604 358.52,250.593 358.53,250.581 358.539,250.57 358.548,250.558 358.557,250.546 358.566,250.535 358.576,250.523 358.585,250.512 358.594,250.5 358.603,250.488 358.612,250.477 358.621,250.465 358.631,250.454 358.64,250.442 358.649,250.43 358.658,250.419 358.667,250.407 358.677,250.396 358.686,250.384 358.695,250.372 358.704,250.361 358.713,250.349 358.723,250.337 358.732,250.326 358.741,250.314 358.75,250.303 358.759,250.291 358.769,250.279 358.778,250.268 358.787,250.256 358.796,250.244 358.805,250.233 358.814,250.221 358.824,250.209 358.833,250.198 358.842,250.186 358.851,250.175 358.86,250.163 358.87,250.151 358.879,250.14 358.888,250.128 358.897,250.116 358.906,250.105 358.916,250.093 358.925,250.081 358.934,250.07 358.943,250.058 358.952,250.046 358.962,250.035 358.971,250.023 358.98,250.011 358.989,250 358.998,249.988 359.007,249.976 359.017,249.964 359.026,249.953 359.035,249.941 359.044,249.929 359.053,249.918 359.063,249.906 359.072,249.894 359.081,249.883 359.09,249.871 359.099,249.859 359.109,249.848 359.118,249.836 359.127,249.824 359.136,249.812 359.145,249.801 359.154,249.789 359.164,249.777 359.173,249.766 359.182,249.754 359.191,249.742 359.2,249.73 359.21,249.719 359.219,249.707 359.228,249.695 359.237,249.684 359.246,249.672 359.256,249.66 359.265,249.648 359.274,249.637 359.283,249.625 359.292,249.613 359.302,249.601 359.311,249.59 359.32,249.578 359.329,249.566 359.338,249.554 359.347,249.543 359.357,249.531 359.366,249.519 359.375,249.507 359.384,249.496 359.393,249.484 359.403,249.472 359.412,249.46 359.421,249.449 359.43,249.437 359.439,249.425 359.449,249.413 359.458,249.402 359.467,249.39 359.476,249.378 359.485,249.366 359.494,249.354 359.504,249.343 359.513,249.331 359.522,249.319 359.531,249.307 359.54,249.296 359.55,249.284 359.559,249.272 359.568,249.26 359.577,249.248 359.586,249.237 359.596,249.225 359.605,249.213 359.614,249.201 359.623,249.189 359.632,249.178 359.642,249.166 359.651,249.154 359.66,249.142 359.669,249.13 359.678,249.119 359.687,249.107 359.697,249.095 359.706,249.083 359.715,249.071 359.724,249.059 359.733,249.048 359.743,249.036 359.752,249.024 359.761,249.012 359.77,249 359.779,248.989 359.789,248.977 359.798,248.965 359.807,248.953 359.816,248.941 359.825,248.929 359.834,248.918 359.844,248.906 359.853,248.894 359.862,248.882 359.871,248.87 359.88,248.858 359.89,248.846 359.899,248.835 359.908,248.823 359.917,248.811 359.926,248.799 359.936,248.787 359.945,248.775 359.954,248.763 359.963,248.752 359.972,248.74 359.982,248.728 359.991,248.716 360,248.704 360.009,248.692 360.018,248.68 360.027,248.668 360.037,248.657 360.046,248.645 360.055,248.633 360.064,248.621 360.073,248.609 360.083,248.597 360.092,248.585 360.101,248.573 360.11,248.562 360.119,248.55 360.129,248.538 360.138,248.526 360.147,248.514 360.156,248.502 360.165,248.49 360.174,248.478 360.184,248.466 360.193,248.454 360.202,248.443 360.211,248.431 360.22,248.419 360.23,248.407 360.239,248.395 360.248,248.383 360.257,248.371 360.266,248.359 360.276,248.347 360.285,248.335 360.294,248.323 360.303,248.311 360.312,248.3 360.322,248.288 360.331,248.276 360.34,248.264 360.349,248.252 360.358,248.24 360.367,248.228 360.377,248.216 360.386,248.204 360.395,248.192 360.404,248.18 360.413,248.168 360.423,248.156 360.432,248.144 360.441,248.132 360.45,248.12 360.459,248.108 360.469,248.097 360.478,248.085 360.487,248.073 360.496,248.061 360.505,248.049 360.514,248.037 360.524,248.025 360.533,248.013 360.542,248.001 360.551,247.989 360.56,247.977 360.57,247.965 360.579,247.953 360.588,247.941 360.597,247.929 360.606,247.917 360.616,247.905 360.625,247.893 360.634,247.881 360.643,247.869 360.652,247.857 360.662,247.845 360.671,247.833 360.68,247.821 360.689,247.809 360.698,247.797 360.707,247.785 360.717,247.773 360.726,247.761 360.735,247.749 360.744,247.737 360.753,247.725 360.763,247.713 360.772,247.701 360.781,247.689 360.79,247.677 360.799,247.665 360.809,247.653 360.818,247.641 360.827,247.629 360.836,247.617 360.845,247.605 360.854,247.593 360.864,247.581 360.873,247.569 360.882,247.557 360.891,247.545 360.9,247.533 360.91,247.521 360.919,247.509 360.928,247.497 360.937,247.485 360.946,247.473 360.956,247.461 360.965,247.449 360.974,247.437 360.983,247.425 360.992,247.413 361.002,247.4 361.011,247.388 361.02,247.376 361.029,247.364 361.038,247.352 361.047,247.34 361.057,247.328 361.066,247.316 361.075,247.304 361.084,247.292 361.093,247.28 361.103,247.268 361.112,247.256 361.121,247.244 361.13,247.232 361.139,247.22 361.149,247.208 361.158,247.195 361.167,247.183 361.176,247.171 361.185,247.159 361.195,247.147 361.204,247.135 361.213,247.123 361.222,247.111 361.231,247.099 361.24,247.087 361.25,247.075 361.259,247.063 361.268,247.05 361.277,247.038 361.286,247.026 361.296,247.014 361.305,247.002 361.314,246.99 361.323,246.978 361.332,246.966 361.342,246.954 361.351,246.942 361.36,246.929 361.369,246.917 361.378,246.905 361.387,246.893 361.397,246.881 361.406,246.869 361.415,246.857 361.424,246.845 361.433,246.833 361.443,246.82 361.452,246.808 361.461,246.796 361.47,246.784 361.479,246.772 361.489,246.76 361.498,246.748 361.507,246.736 361.516,246.723 361.525,246.711 361.535,246.699 361.544,246.687 361.553,246.675 361.562,246.663 361.571,246.651 361.58,246.639 361.59,246.626 361.599,246.614 361.608,246.602 361.617,246.59 361.626,246.578 361.636,246.566 361.645,246.553 361.654,246.541 361.663,246.529 361.672,246.517 361.682,246.505 361.691,246.493 361.7,246.481 361.709,246.468 361.718,246.456 361.727,246.444 361.737,246.432 361.746,246.42 361.755,246.408 361.764,246.395 361.773,246.383 361.783,246.371 361.792,246.359 361.801,246.347 361.81,246.335 361.819,246.322 361.829,246.31 361.838,246.298 361.847,246.286 361.856,246.274 361.865,246.261 361.875,246.249 361.884,246.237 361.893,246.225 361.902,246.213 361.911,246.2 361.92,246.188 361.93,246.176 361.939,246.164 361.948,246.152 361.957,246.139 361.966,246.127 361.976,246.115 361.985,246.103 361.994,246.091 362.003,246.078 362.012,246.066 362.022,246.054 362.031,246.042 362.04,246.03 362.049,246.017 362.058,246.005 362.067,245.993 362.077,245.981 362.086,245.969 362.095,245.956 362.104,245.944 362.113,245.932 362.123,245.92 362.132,245.907 362.141,245.895 362.15,245.883 362.159,245.871 362.169,245.858 362.178,245.846 362.187,245.834 362.196,245.822 362.205,245.81 362.215,245.797 362.224,245.785 362.233,245.773 362.242,245.761 362.251,245.748 362.26,245.736 362.27,245.724 362.279,245.712 362.288,245.699 362.297,245.687 362.306,245.675 362.316,245.663 362.325,245.65 362.334,245.638 362.343,245.626 362.352,245.614 362.362,245.601 362.371,245.589 362.38,245.577 362.389,245.564 362.398,245.552 362.407,245.54 362.417,245.528 362.426,245.515 362.435,245.503 362.444,245.491 362.453,245.479 362.463,245.466 362.472,245.454 362.481,245.442 362.49,245.429 362.499,245.417 362.509,245.405 362.518,245.393 362.527,245.38 362.536,245.368 362.545,245.356 362.555,245.343 362.564,245.331 362.573,245.319 362.582,245.307 362.591,245.294 362.6,245.282 362.61,245.27 362.619,245.257 362.628,245.245 362.637,245.233 362.646,245.22 362.656,245.208 362.665,245.196 362.674,245.184 362.683,245.171 362.692,245.159 362.702,245.147 362.711,245.134 362.72,245.122 362.729,245.11 362.738,245.097 362.747,245.085 362.757,245.073 362.766,245.06 362.775,245.048 362.784,245.036 362.793,245.023 362.803,245.011 362.812,244.999 362.821,244.986 362.83,244.974 362.839,244.962 362.849,244.949 362.858,244.937 362.867,244.925 362.876,244.912 362.885,244.9 362.895,244.888 362.904,244.875 362.913,244.863 362.922,244.851 362.931,244.838 362.94,244.826 362.95,244.814 362.959,244.801 362.968,244.789 362.977,244.777 362.986,244.764 362.996,244.752 363.005,244.74 363.014,244.727 363.023,244.715 363.032,244.703 363.042,244.69 363.051,244.678 363.06,244.665 363.069,244.653 363.078,244.641 363.087,244.628 363.097,244.616 363.106,244.604 363.115,244.591 363.124,244.579 363.133,244.566 363.143,244.554 363.152,244.542 363.161,244.529 363.17,244.517 363.179,244.505 363.189,244.492 363.198,244.48 363.207,244.467 363.216,244.455 363.225,244.443 363.235,244.43 363.244,244.418 363.253,244.405 363.262,244.393 363.271,244.381 363.28,244.368 363.29,244.356 363.299,244.344 363.308,244.331 363.317,244.319 363.326,244.306 363.336,244.294 363.345,244.282 363.354,244.269 363.363,244.257 363.372,244.244 363.382,244.232 363.391,244.219 363.4,244.207 363.409,244.195 363.418,244.182 363.427,244.17 363.437,244.157 363.446,244.145 363.455,244.133 363.464,244.12 363.473,244.108 363.483,244.095 363.492,244.083 363.501,244.07 363.51,244.058 363.519,244.046 363.529,244.033 363.538,244.021 363.547,244.008 363.556,243.996 363.565,243.983 363.575,243.971 363.584,243.959 363.593,243.946 363.602,243.934 363.611,243.921 363.62,243.909 363.63,243.896 363.639,243.884 363.648,243.872 363.657,243.859 363.666,243.847 363.676,243.834 363.685,243.822 363.694,243.809 363.703,243.797 363.712,243.784 363.722,243.772 363.731,243.759 363.74,243.747 363.749,243.735 363.758,243.722 363.768,243.71 363.777,243.697 363.786,243.685 363.795,243.672 363.804,243.66 363.813,243.647 363.823,243.635 363.832,243.622 363.841,243.61 363.85,243.597 363.859,243.585 363.869,243.572 363.878,243.56 363.887,243.548 363.896,243.535 363.905,243.523 363.915,243.51 363.924,243.498 363.933,243.485 363.942,243.473 363.951,243.46 363.96,243.448 363.97,243.435 363.979,243.423 363.988,243.41 363.997,243.398 364.006,243.385 364.016,243.373 364.025,243.36 364.034,243.348 364.043,243.335 364.052,243.323 364.062,243.31 364.071,243.298 364.08,243.285 364.089,243.273 364.098,243.26 364.108,243.248 364.117,243.235 364.126,243.223 364.135,243.21 364.144,243.198 364.153,243.185 364.163,243.173 364.172,243.16 364.181,243.148 364.19,243.135 364.199,243.123 364.209,243.11 364.218,243.098 364.227,243.085 364.236,243.073 364.245,243.06 364.255,243.048 364.264,243.035 364.273,243.022 364.282,243.01 364.291,242.997 364.3,242.985 364.31,242.972 364.319,242.96 364.328,242.947 364.337,242.935 364.346,242.922 364.356,242.91 364.365,242.897 364.374,242.885 364.383,242.872 364.392,242.86 364.402,242.847 364.411,242.834 364.42,242.822 364.429,242.809 364.438,242.797 364.448,242.784 364.457,242.772 364.466,242.759 364.475,242.747 364.484,242.734 364.493,242.722 364.503,242.709 364.512,242.696 364.521,242.684 364.53,242.671 364.539,242.659 364.549,242.646 364.558,242.634 364.567,242.621 364.576,242.609 364.585,242.596 364.595,242.583 364.604,242.571 364.613,242.558 364.622,242.546 364.631,242.533 364.64,242.521 364.65,242.508 364.659,242.495 364.668,242.483 364.677,242.47 364.686,242.458 364.696,242.445 364.705,242.433 364.714,242.42 364.723,242.407 364.732,242.395 364.742,242.382 364.751,242.37 364.76,242.357 364.769,242.344 364.778,242.332 364.788,242.319 364.797,242.307 364.806,242.294 364.815,242.281 364.824,242.269 364.833,242.256 364.843,242.244 364.852,242.231 364.861,242.219 364.87,242.206 364.879,242.193 364.889,242.181 364.898,242.168 364.907,242.156 364.916,242.143 364.925,242.13 364.935,242.118 364.944,242.105 364.953,242.092 364.962,242.08 364.971,242.067 364.98,242.055 364.99,242.042 364.999,242.029 365.008,242.017 365.017,242.004 365.026,241.992 365.036,241.979 365.045,241.966 365.054,241.954 365.063,241.941 365.072,241.928 365.082,241.916 365.091,241.903 365.1,241.891 365.109,241.878 365.118,241.865 365.128,241.853 365.137,241.84 365.146,241.827 365.155,241.815 365.164,241.802 365.173,241.79 365.183,241.777 365.192,241.764 365.201,241.752 365.21,241.739 365.219,241.726 365.229,241.714 365.238,241.701 365.247,241.688 365.256,241.676 365.265,241.663 365.275,241.651 365.284,241.638 365.293,241.625 365.302,241.613 365.311,241.6 365.32,241.587 365.33,241.575 365.339,241.562 365.348,241.549 365.357,241.537 365.366,241.524 365.376,241.511 365.385,241.499 365.394,241.486 365.403,241.473 365.412,241.461 365.422,241.448 365.431,241.435 365.44,241.423 365.449,241.41 365.458,241.397 365.468,241.385 365.477,241.372 365.486,241.359 365.495,241.347 365.504,241.334 365.513,241.321 365.523,241.309 365.532,241.296 365.541,241.283 365.55,241.271 365.559,241.258 365.569,241.245 365.578,241.233 365.587,241.22 365.596,241.207 365.605,241.195 365.615,241.182 365.624,241.169 365.633,241.157 365.642,241.144 365.651,241.131 365.66,241.118 365.67,241.106 365.679,241.093 365.688,241.08 365.697,241.068 365.706,241.055 365.716,241.042 365.725,241.03 365.734,241.017 365.743,241.004 365.752,240.992 365.762,240.979 365.771,240.966 365.78,240.953 365.789,240.941 365.798,240.928 365.808,240.915 365.817,240.903 365.826,240.89 365.835,240.877 365.844,240.864 365.853,240.852 365.863,240.839 365.872,240.826 365.881,240.814 365.89,240.801 365.899,240.788 365.909,240.776 365.918,240.763 365.927,240.75 365.936,240.737 365.945,240.725 365.955,240.712 365.964,240.699 365.973,240.686 365.982,240.674 365.991,240.661 366,240.648 366.01,240.636 366.019,240.623 366.028,240.61 366.037,240.597 366.046,240.585 366.056,240.572 366.065,240.559 366.074,240.546 366.083,240.534 366.092,240.521 366.102,240.508 366.111,240.496 366.12,240.483 366.129,240.47 366.138,240.457 366.148,240.445 366.157,240.432 366.166,240.419 366.175,240.406 366.184,240.394 366.193,240.381 366.203,240.368 366.212,240.355 366.221,240.343 366.23,240.33 366.239,240.317 366.249,240.304 366.258,240.292 366.267,240.279 366.276,240.266 366.285,240.253 366.295,240.241 366.304,240.228 366.313,240.215 366.322,240.202 366.331,240.19 366.341,240.177 366.35,240.164 366.359,240.151 366.368,240.138 366.377,240.126 366.386,240.113 366.396,240.1 366.405,240.087 366.414,240.075 366.423,240.062 366.432,240.049 366.442,240.036 366.451,240.024 366.46,240.011 366.469,239.998 366.478,239.985 366.488,239.972 366.497,239.96 366.506,239.947 366.515,239.934 366.524,239.921 366.533,239.909 366.543,239.896 366.552,239.883 366.561,239.87 366.57,239.857 366.579,239.845 366.589,239.832 366.598,239.819 366.607,239.806 366.616,239.794 366.625,239.781 366.635,239.768 366.644,239.755 366.653,239.742 366.662,239.73 366.671,239.717 366.681,239.704 366.69,239.691 366.699,239.678 366.708,239.666 366.717,239.653 366.726,239.64 366.736,239.627 366.745,239.614 366.754,239.602 366.763,239.589 366.772,239.576 366.782,239.563 366.791,239.55 366.8,239.538 366.809,239.525 366.818,239.512 366.828,239.499 366.837,239.486 366.846,239.474 366.855,239.461 366.864,239.448 366.873,239.435 366.883,239.422 366.892,239.409 366.901,239.397 366.91,239.384 366.919,239.371 366.929,239.358 366.938,239.345 366.947,239.333 366.956,239.32 366.965,239.307 366.975,239.294 366.984,239.281 366.993,239.268 367.002,239.256 367.011,239.243 367.021,239.23 367.03,239.217 367.039,239.204 367.048,239.191 367.057,239.179 367.066,239.166 367.076,239.153 367.085,239.14 367.094,239.127 367.103,239.114 367.112,239.102 367.122,239.089 367.131,239.076 367.14,239.063 367.149,239.05 367.158,239.037 367.168,239.025 367.177,239.012 367.186,238.999 367.195,238.986 367.204,238.973 367.213,238.96 367.223,238.948 367.232,238.935 367.241,238.922 367.25,238.909 367.259,238.896 367.269,238.883 367.278,238.87 367.287,238.858 367.296,238.845 367.305,238.832 367.315,238.819 367.324,238.806 367.333,238.793 367.342,238.78 367.351,238.768 367.361,238.755 367.37,238.742 367.379,238.729 367.388,238.716 367.397,238.703 367.406,238.69 367.416,238.678 367.425,238.665 367.434,238.652 367.443,238.639 367.452,238.626 367.462,238.613 367.471,238.6 367.48,238.588 367.489,238.575 367.498,238.562 367.508,238.549 367.517,238.536 367.526,238.523 367.535,238.51 367.544,238.497 367.553,238.485 367.563,238.472 367.572,238.459 367.581,238.446 367.59,238.433 367.599,238.42 367.609,238.407 367.618,238.394 367.627,238.381 367.636,238.369 367.645,238.356 367.655,238.343 367.664,238.33 367.673,238.317 367.682,238.304 367.691,238.291 367.701,238.278 367.71,238.266 367.719,238.253 367.728,238.24 367.737,238.227 367.746,238.214 367.756,238.201 367.765,238.188 367.774,238.175 367.783,238.162 367.792,238.149 367.802,238.137 367.811,238.124 367.82,238.111 367.829,238.098 367.838,238.085 367.848,238.072 367.857,238.059 367.866,238.046 367.875,238.033 367.884,238.02 367.893,238.008 367.903,237.995 367.912,237.982 367.921,237.969 367.93,237.956 367.939,237.943 367.949,237.93 367.958,237.917 367.967,237.904 367.976,237.891 367.985,237.878 367.995,237.866 368.004,237.853 368.013,237.84 368.022,237.827 368.031,237.814 368.041,237.801 368.05,237.788 368.059,237.775 368.068,237.762 368.077,237.749 368.086,237.736 368.096,237.723 368.105,237.71 368.114,237.698 368.123,237.685 368.132,237.672 368.142,237.659 368.151,237.646 368.16,237.633 368.169,237.62 368.178,237.607 368.188,237.594 368.197,237.581 368.206,237.568 368.215,237.555 368.224,237.542 368.233,237.529 368.243,237.517 368.252,237.504 368.261,237.491 368.27,237.478 368.279,237.465 368.289,237.452 368.298,237.439 368.307,237.426 368.316,237.413 368.325,237.4 368.335,237.387 368.344,237.374 368.353,237.361 368.362,237.348 368.371,237.335 368.381,237.322 368.39,237.309 368.399,237.297 368.408,237.284 368.417,237.271 368.426,237.258 368.436,237.245 368.445,237.232 368.454,237.219 368.463,237.206 368.472,237.193 368.482,237.18 368.491,237.167 368.5,237.154 368.509,237.141 368.518,237.128 368.528,237.115 368.537,237.102 368.546,237.089 368.555,237.076 368.564,237.063 368.574,237.05 368.583,237.037 368.592,237.024 368.601,237.012 368.61,236.999 368.619,236.986 368.629,236.973 368.638,236.96 368.647,236.947 368.656,236.934 368.665,236.921 368.675,236.908 368.684,236.895 368.693,236.882 368.702,236.869 368.711,236.856 368.721,236.843 368.73,236.83 368.739,236.817 368.748,236.804 368.757,236.791 368.766,236.778 368.776,236.765 368.785,236.752 368.794,236.739 368.803,236.726 368.812,236.713 368.822,236.7 368.831,236.687 368.84,236.674 368.849,236.661 368.858,236.648 368.868,236.635 368.877,236.622 368.886,236.609 368.895,236.596 368.904,236.583 368.914,236.57 368.923,236.557 368.932,236.544 368.941,236.531 368.95,236.518 368.959,236.505 368.969,236.492 368.978,236.479 368.987,236.466 368.996,236.453 369.005,236.44 369.015,236.427 369.024,236.414 369.033,236.401 369.042,236.388 369.051,236.375 369.061,236.362 369.07,236.349 369.079,236.336 369.088,236.323 369.097,236.31 369.106,236.297 369.116,236.284 369.125,236.271 369.134,236.258 369.143,236.245 369.152,236.232 369.162,236.219 369.171,236.206 369.18,236.193 369.189,236.18 369.198,236.167 369.208,236.154 369.217,236.141 369.226,236.128 369.235,236.115 369.244,236.102 369.254,236.089 369.263,236.076 369.272,236.063 369.281,236.05 369.29,236.037 369.299,236.024 369.309,236.011 369.318,235.998 369.327,235.985 369.336,235.972 369.345,235.959 369.355,235.946 369.364,235.933 369.373,235.92 369.382,235.907 369.391,235.894 369.401,235.881 369.41,235.868 369.419,235.855 369.428,235.842 369.437,235.829 369.446,235.816 369.456,235.803 369.465,235.79 369.474,235.777 369.483,235.764 369.492,235.751 369.502,235.738 369.511,235.725 369.52,235.712 369.529,235.699 369.538,235.686 369.548,235.673 369.557,235.66 369.566,235.646 369.575,235.633 369.584,235.62 369.594,235.607 369.603,235.594 369.612,235.581 369.621,235.568 369.63,235.555 369.639,235.542 369.649,235.529 369.658,235.516 369.667,235.503 369.676,235.49 369.685,235.477 369.695,235.464 369.704,235.451 369.713,235.438 369.722,235.425 369.731,235.412 369.741,235.399 369.75,235.386 369.759,235.373 369.768,235.36 369.777,235.347 369.786,235.333 369.796,235.32 369.805,235.307 369.814,235.294 369.823,235.281 369.832,235.268 369.842,235.255 369.851,235.242 369.86,235.229 369.869,235.216 369.878,235.203 369.888,235.19 369.897,235.177 369.906,235.164 369.915,235.151 369.924,235.138 369.934,235.125 369.943,235.112 369.952,235.098 369.961,235.085 369.97,235.072 369.979,235.059 369.989,235.046 369.998,235.033 370.007,235.02 370.016,235.007 370.025,234.994 370.035,234.981 370.044,234.968 370.053,234.955 370.062,234.942 370.071,234.929 370.081,234.916 370.09,234.903 370.099,234.889 370.108,234.876 370.117,234.863 370.126,234.85 370.136,234.837 370.145,234.824 370.154,234.811 370.163,234.798 370.172,234.785 370.182,234.772 370.191,234.759 370.2,234.746 370.209,234.733 370.218,234.719 370.228,234.706 370.237,234.693 370.246,234.68 370.255,234.667 370.264,234.654 370.274,234.641 370.283,234.628 370.292,234.615 370.301,234.602 370.31,234.589 370.319,234.576 370.329,234.563 370.338,234.549 370.347,234.536 370.356,234.523 370.365,234.51 370.375,234.497 370.384,234.484 370.393,234.471 370.402,234.458 370.411,234.445 370.421,234.432 370.43,234.419 370.439,234.405 370.448,234.392 370.457,234.379 370.466,234.366 370.476,234.353 370.485,234.34 370.494,234.327 370.503,234.314 370.512,234.301 370.522,234.288 370.531,234.275 370.54,234.261 370.549,234.248 370.558,234.235 370.568,234.222 370.577,234.209 370.586,234.196 370.595,234.183 370.604,234.17 370.614,234.157 370.623,234.144 370.632,234.13 370.641,234.117 370.65,234.104 370.659,234.091 370.669,234.078 370.678,234.065 370.687,234.052 370.696,234.039 370.705,234.026 370.715,234.013 370.724,233.999 370.733,233.986 370.742,233.973 370.751,233.96 370.761,233.947 370.77,233.934 370.779,233.921 370.788,233.908 370.797,233.895 370.806,233.881 370.816,233.868 370.825,233.855 370.834,233.842 370.843,233.829 370.852,233.816 370.862,233.803 370.871,233.79 370.88,233.776 370.889,233.763 370.898,233.75 370.908,233.737 370.917,233.724 370.926,233.711 370.935,233.698 370.944,233.685 370.954,233.672 370.963,233.658 370.972,233.645 370.981,233.632 370.99,233.619 370.999,233.606 371.009,233.593 371.018,233.58 371.027,233.567 371.036,233.553 371.045,233.54 371.055,233.527 371.064,233.514 371.073,233.501 371.082,233.488 371.091,233.475 371.101,233.462 371.11,233.448 371.119,233.435 371.128,233.422 371.137,233.409 371.147,233.396 371.156,233.383 371.165,233.37 371.174,233.357 371.183,233.343 371.192,233.33 371.202,233.317 371.211,233.304 371.22,233.291 371.229,233.278 371.238,233.265 371.248,233.251 371.257,233.238 371.266,233.225 371.275,233.212 371.284,233.199 371.294,233.186 371.303,233.173 371.312,233.159 371.321,233.146 371.33,233.133 371.339,233.12 371.349,233.107 371.358,233.094 371.367,233.081 371.376,233.067 371.385,233.054 371.395,233.041 371.404,233.028 371.413,233.015 371.422,233.002 371.431,232.989 371.441,232.975 371.45,232.962 371.459,232.949 371.468,232.936 371.477,232.923 371.487,232.91 371.496,232.897 371.505,232.883 371.514,232.87 371.523,232.857 371.532,232.844 371.542,232.831 371.551,232.818 371.56,232.805 371.569,232.791 371.578,232.778 371.588,232.765 371.597,232.752 371.606,232.739 371.615,232.726 371.624,232.712 371.634,232.699 371.643,232.686 371.652,232.673 371.661,232.66 371.67,232.647 371.679,232.633 371.689,232.62 371.698,232.607 371.707,232.594 371.716,232.581 371.725,232.568 371.735,232.555 371.744,232.541 371.753,232.528 371.762,232.515 371.771,232.502 371.781,232.489 371.79,232.476 371.799,232.462 371.808,232.449 371.817,232.436 371.827,232.423 371.836,232.41 371.845,232.397 371.854,232.383 371.863,232.37 371.872,232.357 371.882,232.344 371.891,232.331 371.9,232.318 371.909,232.304 371.918,232.291 371.928,232.278 371.937,232.265 371.946,232.252 371.955,232.239 371.964,232.225 371.974,232.212 371.983,232.199 371.992,232.186 372.001,232.173 372.01,232.16 372.019,232.146 372.029,232.133 372.038,232.12 372.047,232.107 372.056,232.094 372.065,232.08 372.075,232.067 372.084,232.054 372.093,232.041 372.102,232.028 372.111,232.015 372.121,232.001 372.13,231.988 372.139,231.975 372.148,231.962 372.157,231.949 372.167,231.935 372.176,231.922 372.185,231.909 372.194,231.896 372.203,231.883 372.212,231.87 372.222,231.856 372.231,231.843 372.24,231.83 372.249,231.817 372.258,231.804 372.268,231.79 372.277,231.777 372.286,231.764 372.295,231.751 372.304,231.738 372.314,231.725 372.323,231.711 372.332,231.698 372.341,231.685 372.35,231.672 372.359,231.659 372.369,231.645 372.378,231.632 372.387,231.619 372.396,231.606 372.405,231.593 372.415,231.579 372.424,231.566 372.433,231.553 372.442,231.54 372.451,231.527 372.461,231.513 372.47,231.5 372.479,231.487 372.488,231.474 372.497,231.461 372.507,231.447 372.516,231.434 372.525,231.421 372.534,231.408 372.543,231.395 372.552,231.382 372.562,231.368 372.571,231.355 372.58,231.342 372.589,231.329 372.598,231.316 372.608,231.302 372.617,231.289 372.626,231.276 372.635,231.263 372.644,231.25 372.654,231.236 372.663,231.223 372.672,231.21 372.681,231.197 372.69,231.183 372.699,231.17 372.709,231.157 372.718,231.144 372.727,231.131 372.736,231.117 372.745,231.104 372.755,231.091 372.764,231.078 372.773,231.065 372.782,231.051 372.791,231.038 372.801,231.025 372.81,231.012 372.819,230.999 372.828,230.985 372.837,230.972 372.847,230.959 372.856,230.946 372.865,230.933 372.874,230.919 372.883,230.906 372.892,230.893 372.902,230.88 372.911,230.867 372.92,230.853 372.929,230.84 372.938,230.827 372.948,230.814 372.957,230.8 372.966,230.787 372.975,230.774 372.984,230.761 372.994,230.748 373.003,230.734 373.012,230.721 373.021,230.708 373.03,230.695 373.039,230.681 373.049,230.668 373.058,230.655 373.067,230.642 373.076,230.629 373.085,230.615 373.095,230.602 373.104,230.589 373.113,230.576 373.122,230.563 373.131,230.549 373.141,230.536 373.15,230.523 373.159,230.51 373.168,230.496 373.177,230.483 373.187,230.47 373.196,230.457 373.205,230.444 373.214,230.43 373.223,230.417 373.232,230.404 373.242,230.391 373.251,230.377 373.26,230.364 373.269,230.351 373.278,230.338 373.288,230.325 373.297,230.311 373.306,230.298 373.315,230.285 373.324,230.272 373.334,230.258 373.343,230.245 373.352,230.232 373.361,230.219 373.37,230.205 373.379,230.192 373.389,230.179 373.398,230.166 373.407,230.153 373.416,230.139 373.425,230.126 373.435,230.113 373.444,230.1 373.453,230.086 373.462,230.073 373.471,230.06 373.481,230.047 373.49,230.033 373.499,230.02 373.508,230.007 373.517,229.994 373.527,229.981 373.536,229.967 373.545,229.954 373.554,229.941 373.563,229.928 373.572,229.914 373.582,229.901 373.591,229.888 373.6,229.875 373.609,229.861 373.618,229.848 373.628,229.835 373.637,229.822 373.646,229.808 373.655,229.795 373.664,229.782 373.674,229.769 373.683,229.755 373.692,229.742 373.701,229.729 373.71,229.716 373.72,229.703 373.729,229.689 373.738,229.676 373.747,229.663 373.756,229.65 373.765,229.636 373.775,229.623 373.784,229.61 373.793,229.597 373.802,229.583 373.811,229.57 373.821,229.557 373.83,229.544 373.839,229.53 373.848,229.517 373.857,229.504 373.867,229.491 373.876,229.477 373.885,229.464 373.894,229.451 373.903,229.438 373.912,229.424 373.922,229.411 373.931,229.398 373.94,229.385 373.949,229.371 373.958,229.358 373.968,229.345 373.977,229.332 373.986,229.318 373.995,229.305 374.004,229.292 374.014,229.279 374.023,229.265 374.032,229.252 374.041,229.239 374.05,229.226 374.06,229.212 374.069,229.199 374.078,229.186 374.087,229.173 374.096,229.159 374.105,229.146 374.115,229.133 374.124,229.12 374.133,229.106 374.142,229.093 374.151,229.08 374.161,229.067 374.17,229.053 374.179,229.04 374.188,229.027 374.197,229.014 374.207,229 374.216,228.987 374.225,228.974 374.234,228.961 374.243,228.947 374.252,228.934 374.262,228.921 374.271,228.908 374.28,228.894 374.289,228.881 374.298,228.868 374.308,228.855 374.317,228.841 374.326,228.828 374.335,228.815 374.344,228.802 374.354,228.788 374.363,228.775 374.372,228.762 374.381,228.748 374.39,228.735 374.4,228.722 374.409,228.709 374.418,228.695 374.427,228.682 374.436,228.669 374.445,228.656 374.455,228.642 374.464,228.629 374.473,228.616 374.482,228.603 374.491,228.589 374.501,228.576 374.51,228.563 374.519,228.55 374.528,228.536 374.537,228.523 374.547,228.51 374.556,228.496 374.565,228.483 374.574,228.47 374.583,228.457 374.592,228.443 374.602,228.43 374.611,228.417 374.62,228.404 374.629,228.39 374.638,228.377 374.648,228.364 374.657,228.351 374.666,228.337 374.675,228.324 374.684,228.311 374.694,228.297 374.703,228.284 374.712,228.271 374.721,228.258 374.73,228.244 374.74,228.231 374.749,228.218 374.758,228.205 374.767,228.191 374.776,228.178 374.785,228.165 374.795,228.152 374.804,228.138 374.813,228.125 374.822,228.112 374.831,228.098 374.841,228.085 374.85,228.072 374.859,228.059 374.868,228.045 374.877,228.032 374.887,228.019 374.896,228.006 374.905,227.992 374.914,227.979 374.923,227.966 374.932,227.952 374.942,227.939 374.951,227.926 374.96,227.913 374.969,227.899 374.978,227.886 374.988,227.873 374.997,227.86 375.006,227.846 375.015,227.833 375.024,227.82 375.034,227.806 375.043,227.793 375.052,227.78 375.061,227.767 375.07,227.753 375.08,227.74 375.089,227.727 375.098,227.713 375.107,227.7 375.116,227.687 375.125,227.674 375.135,227.66 375.144,227.647 375.153,227.634 375.162,227.621 375.171,227.607 375.181,227.594 375.19,227.581 375.199,227.567 375.208,227.554 375.217,227.541 375.227,227.528 375.236,227.514 375.245,227.501 375.254,227.488 375.263,227.474 375.272,227.461 375.282,227.448 375.291,227.435 375.3,227.421 375.309,227.408 375.318,227.395 375.328,227.382 375.337,227.368 375.346,227.355 375.355,227.342 375.364,227.328 375.374,227.315 375.383,227.302 375.392,227.289 375.401,227.275 375.41,227.262 375.42,227.249 375.429,227.235 375.438,227.222 375.447,227.209 375.456,227.196 375.465,227.182 375.475,227.169 375.484,227.156 375.493,227.142 375.502,227.129 375.511,227.116 375.521,227.103 375.53,227.089 375.539,227.076 375.548,227.063 375.557,227.049 375.567,227.036 375.576,227.023 375.585,227.01 375.594,226.996 375.603,226.983 375.612,226.97 375.622,226.956 375.631,226.943 375.64,226.93 375.649,226.917 375.658,226.903 375.668,226.89 375.677,226.877 375.686,226.863 375.695,226.85 375.704,226.837 375.714,226.824 375.723,226.81 375.732,226.797 375.741,226.784 375.75,226.77 375.76,226.757 375.769,226.744 375.778,226.73 375.787,226.717 375.796,226.704 375.805,226.691 375.815,226.677 375.824,226.664 375.833,226.651 375.842,226.637 375.851,226.624 375.861,226.611 375.87,226.598 375.879,226.584 375.888,226.571 375.897,226.558 375.907,226.544 375.916,226.531 375.925,226.518 375.934,226.505 375.943,226.491 375.953,226.478 375.962,226.465 375.971,226.451 375.98,226.438 375.989,226.425 375.998,226.412 376.008,226.398 376.017,226.385 376.026,226.372 376.035,226.358 376.044,226.345 376.054,226.332 376.063,226.318 376.072,226.305 376.081,226.292 376.09,226.279 376.1,226.265 376.109,226.252 376.118,226.239 376.127,226.225 376.136,226.212 376.145,226.199 376.155,226.185 376.164,226.172 376.173,226.159 376.182,226.146 376.191,226.132 376.201,226.119 376.21,226.106 376.219,226.092 376.228,226.079 376.237,226.066 376.247,226.053 376.256,226.039 376.265,226.026 376.274,226.013 376.283,225.999 376.293,225.986 376.302,225.973 376.311,225.959 376.32,225.946 376.329,225.933 376.338,225.92 376.348,225.906 376.357,225.893 376.366,225.88 376.375,225.866 376.384,225.853 376.394,225.84 376.403,225.826 376.412,225.813 376.421,225.8 376.43,225.787 376.44,225.773 376.449,225.76 376.458,225.747 376.467,225.733 376.476,225.72 376.485,225.707 376.495,225.693 376.504,225.68 376.513,225.667 376.522,225.654 376.531,225.64 376.541,225.627 376.55,225.614 376.559,225.6 376.568,225.587 376.577,225.574 376.587,225.56 376.596,225.547 376.605,225.534 376.614,225.521 376.623,225.507 376.633,225.494 376.642,225.481 376.651,225.467 376.66,225.454 376.669,225.441 376.678,225.427 376.688,225.414 376.697,225.401 376.706,225.388 376.715,225.374 376.724,225.361 376.734,225.348 376.743,225.334 376.752,225.321 376.761,225.308 376.77,225.294 376.78,225.281 376.789,225.268 376.798,225.255 376.807,225.241 376.816,225.228 376.825,225.215 376.835,225.201 376.844,225.188 376.853,225.175 376.862,225.161 376.871,225.148 376.881,225.135 376.89,225.122 376.899,225.108 376.908,225.095 376.917,225.082 376.927,225.068 376.936,225.055 376.945,225.042 376.954,225.028 376.963,225.015 376.973,225.002 376.982,224.988 376.991,224.975 377,224.962 377.009,224.949 377.018,224.935 377.028,224.922 377.037,224.909 377.046,224.895 377.055,224.882 377.064,224.869 377.074,224.855 377.083,224.842 377.092,224.829 377.101,224.816 377.11,224.802 377.12,224.789 377.129,224.776 377.138,224.762 377.147,224.749 377.156,224.736 377.165,224.722 377.175,224.709 377.184,224.696 377.193,224.682 377.202,224.669 377.211,224.656 377.221,224.643 377.23,224.629 377.239,224.616 377.248,224.603 377.257,224.589 377.267,224.576 377.276,224.563 377.285,224.549 377.294,224.536 377.303,224.523 377.313,224.509 377.322,224.496 377.331,224.483 377.34,224.47 377.349,224.456 377.358,224.443 377.368,224.43 377.377,224.416 377.386,224.403 377.395,224.39 377.404,224.376 377.414,224.363 377.423,224.35 377.432,224.337 377.441,224.323 377.45,224.31 377.46,224.297 377.469,224.283 377.478,224.27 377.487,224.257 377.496,224.243 377.505,224.23 377.515,224.217 377.524,224.203 377.533,224.19 377.542,224.177 377.551,224.164 377.561,224.15 377.57,224.137 377.579,224.124 377.588,224.11 377.597,224.097 377.607,224.084 377.616,224.07 377.625,224.057 377.634,224.044 377.643,224.03 377.653,224.017 377.662,224.004 377.671,223.991 377.68,223.977 377.689,223.964 377.698,223.951 377.708,223.937 377.717,223.924 377.726,223.911 377.735,223.897 377.744,223.884 377.754,223.871 377.763,223.857 377.772,223.844 377.781,223.831 377.79,223.818 377.8,223.804 377.809,223.791 377.818,223.778 377.827,223.764 377.836,223.751 377.845,223.738 377.855,223.724 377.864,223.711 377.873,223.698 377.882,223.684 377.891,223.671 377.901,223.658 377.91,223.645 377.919,223.631 377.928,223.618 377.937,223.605 377.947,223.591 377.956,223.578 377.965,223.565 377.974,223.551 377.983,223.538 377.993,223.525 378.002,223.511 378.011,223.498 378.02,223.485 378.029,223.472 378.038,223.458 378.048,223.445 378.057,223.432 378.066,223.418 378.075,223.405 378.084,223.392 378.094,223.378 378.103,223.365 378.112,223.352 378.121,223.338 378.13,223.325 378.14,223.312 378.149,223.299 378.158,223.285 378.167,223.272 378.176,223.259 378.185,223.245 378.195,223.232 378.204,223.219 378.213,223.205 378.222,223.192 378.231,223.179 378.241,223.165 378.25,223.152 378.259,223.139 378.268,223.125 378.277,223.112 378.287,223.099 378.296,223.086 378.305,223.072 378.314,223.059 378.323,223.046 378.333,223.032 378.342,223.019 378.351,223.006 378.36,222.992 378.369,222.979 378.378,222.966 378.388,222.952 378.397,222.939 378.406,222.926 378.415,222.913 378.424,222.899 378.434,222.886 378.443,222.873 378.452,222.859 378.461,222.846 378.47,222.833 378.48,222.819 378.489,222.806 378.498,222.793 378.507,222.779 378.516,222.766 378.526,222.753 378.535,222.74 378.544,222.726 378.553,222.713 378.562,222.7 378.571,222.686 378.581,222.673 378.59,222.66 378.599,222.646 378.608,222.633 378.617,222.62 378.627,222.606 378.636,222.593 378.645,222.58 378.654,222.567 378.663,222.553 378.673,222.54 378.682,222.527 378.691,222.513 378.7,222.5 378.709,222.487 378.718,222.473 378.728,222.46 378.737,222.447 378.746,222.433 378.755,222.42 378.764,222.407 378.774,222.394 378.783,222.38 378.792,222.367 378.801,222.354 378.81,222.34 378.82,222.327 378.829,222.314 378.838,222.3 378.847,222.287 378.856,222.274 378.866,222.261 378.875,222.247 378.884,222.234 378.893,222.221 378.902,222.207 378.911,222.194 378.921,222.181 378.93,222.167 378.939,222.154 378.948,222.141 378.957,222.127 378.967,222.114 378.976,222.101 378.985,222.088 378.994,222.074 379.003,222.061 379.013,222.048 379.022,222.034 379.031,222.021 379.04,222.008 379.049,221.994 379.058,221.981 379.068,221.968 379.077,221.954 379.086,221.941 379.095,221.928 379.104,221.915 379.114,221.901 379.123,221.888 379.132,221.875 379.141,221.861 379.15,221.848 379.16,221.835 379.169,221.821 379.178,221.808 379.187,221.795 379.196,221.782 379.206,221.768 379.215,221.755 379.224,221.742 379.233,221.728 379.242,221.715 379.251,221.702 379.261,221.688 379.27,221.675 379.279,221.662 379.288,221.648 379.297,221.635 379.307,221.622 379.316,221.609 379.325,221.595 379.334,221.582 379.343,221.569 379.353,221.555 379.362,221.542 379.371,221.529 379.38,221.515 379.389,221.502 379.398,221.489 379.408,221.476 379.417,221.462 379.426,221.449 379.435,221.436 379.444,221.422 379.454,221.409 379.463,221.396 379.472,221.382 379.481,221.369 379.49,221.356 379.5,221.342 379.509,221.329 379.518,221.316 379.527,221.303 379.536,221.289 379.546,221.276 379.555,221.263 379.564,221.249 379.573,221.236 379.582,221.223 379.591,221.209 379.601,221.196 379.61,221.183 379.619,221.17 379.628,221.156 379.637,221.143 379.647,221.13 379.656,221.116 379.665,221.103 379.674,221.09 379.683,221.076 379.693,221.063 379.702,221.05 379.711,221.037 379.72,221.023 379.729,221.01 379.738,220.997 379.748,220.983 379.757,220.97 379.766,220.957 379.775,220.943 379.784,220.93 379.794,220.917 379.803,220.904 379.812,220.89 379.821,220.877 379.83,220.864 379.84,220.85 379.849,220.837 379.858,220.824 379.867,220.81 379.876,220.797 379.886,220.784 379.895,220.771 379.904,220.757 379.913,220.744 379.922,220.731 379.931,220.717 379.941,220.704 379.95,220.691 379.959,220.677 379.968,220.664 379.977,220.651 379.987,220.638 379.996,220.624 380.005,220.611 380.014,220.598 380.023,220.584 380.033,220.571 380.042,220.558 380.051,220.545 380.06,220.531 380.069,220.518 380.078,220.505 380.088,220.491 380.097,220.478 380.106,220.465 380.115,220.451 380.124,220.438 380.134,220.425 380.143,220.412 380.152,220.398 380.161,220.385 380.17,220.372 380.18,220.358 380.189,220.345 380.198,220.332 380.207,220.319 380.216,220.305 380.226,220.292 380.235,220.279 380.244,220.265 380.253,220.252 380.262,220.239 380.271,220.225 380.281,220.212 380.29,220.199 380.299,220.186 380.308,220.172 380.317,220.159 380.327,220.146 380.336,220.132 380.345,220.119 380.354,220.106 380.363,220.093 380.373,220.079 380.382,220.066 380.391,220.053 380.4,220.039 380.409,220.026 380.418,220.013 380.428,219.999 380.437,219.986 380.446,219.973 380.455,219.96 380.464,219.946 380.474,219.933 380.483,219.92 380.492,219.906 380.501,219.893 380.51,219.88 380.52,219.867 380.529,219.853 380.538,219.84 380.547,219.827 380.556,219.813 380.566,219.8 380.575,219.787 380.584,219.774 380.593,219.76 380.602,219.747 380.611,219.734 380.621,219.72 380.63,219.707 380.639,219.694 380.648,219.681 380.657,219.667 380.667,219.654 380.676,219.641 380.685,219.627 380.694,219.614 380.703,219.601 380.713,219.587 380.722,219.574 380.731,219.561 380.74,219.548 380.749,219.534 380.758,219.521 380.768,219.508 380.777,219.494 380.786,219.481 380.795,219.468 380.804,219.455 380.814,219.441 380.823,219.428 380.832,219.415 380.841,219.401 380.85,219.388 380.86,219.375 380.869,219.362 380.878,219.348 380.887,219.335 380.896,219.322 380.906,219.309 380.915,219.295 380.924,219.282 380.933,219.269 380.942,219.255 380.951,219.242 380.961,219.229 380.97,219.216 380.979,219.202 380.988,219.189 380.997,219.176 381.007,219.162 381.016,219.149 381.025,219.136 381.034,219.123 381.043,219.109 381.053,219.096 381.062,219.083 381.071,219.069 381.08,219.056 381.089,219.043 381.099,219.03 381.108,219.016 381.117,219.003 381.126,218.99 381.135,218.976 381.144,218.963 381.154,218.95 381.163,218.937 381.172,218.923 381.181,218.91 381.19,218.897 381.2,218.883 381.209,218.87 381.218,218.857 381.227,218.844 381.236,218.83 381.246,218.817 381.255,218.804 381.264,218.791 381.273,218.777 381.282,218.764 381.291,218.751 381.301,218.737 381.31,218.724 381.319,218.711 381.328,218.698 381.337,218.684 381.347,218.671 381.356,218.658 381.365,218.645 381.374,218.631 381.383,218.618 381.393,218.605 381.402,218.591 381.411,218.578 381.42,218.565 381.429,218.552 381.439,218.538 381.448,218.525 381.457,218.512 381.466,218.498 381.475,218.485 381.484,218.472 381.494,218.459 381.503,218.445 381.512,218.432 381.521,218.419 381.53,218.406 381.54,218.392 381.549,218.379 381.558,218.366 381.567,218.352 381.576,218.339 381.586,218.326 381.595,218.313 381.604,218.299 381.613,218.286 381.622,218.273 381.631,218.26 381.641,218.246 381.65,218.233 381.659,218.22 381.668,218.207 381.677,218.193 381.687,218.18 381.696,218.167 381.705,218.153 381.714,218.14 381.723,218.127 381.733,218.114 381.742,218.1 381.751,218.087 381.76,218.074 381.769,218.061 381.779,218.047 381.788,218.034 381.797,218.021 381.806,218.007 381.815,217.994 381.824,217.981 381.834,217.968 381.843,217.954 381.852,217.941 381.861,217.928 381.87,217.915 381.88,217.901 381.889,217.888 381.898,217.875 381.907,217.862 381.916,217.848 381.926,217.835 381.935,217.822 381.944,217.809 381.953,217.795 381.962,217.782 381.971,217.769 381.981,217.755 381.99,217.742 381.999,217.729 382.008,217.716 382.017,217.702 382.027,217.689 382.036,217.676 382.045,217.663 382.054,217.649 382.063,217.636 382.073,217.623 382.082,217.61 382.091,217.596 382.1,217.583 382.109,217.57 382.119,217.557 382.128,217.543 382.137,217.53 382.146,217.517 382.155,217.504 382.164,217.49 382.174,217.477 382.183,217.464 382.192,217.45 382.201,217.437 382.21,217.424 382.22,217.411 382.229,217.397 382.238,217.384 382.247,217.371 382.256,217.358 382.266,217.344 382.275,217.331 382.284,217.318 382.293,217.305 382.302,217.291 382.311,217.278 382.321,217.265 382.33,217.252 382.339,217.238 382.348,217.225 382.357,217.212 382.367,217.199 382.376,217.185 382.385,217.172 382.394,217.159 382.403,217.146 382.413,217.132 382.422,217.119 382.431,217.106 382.44,217.093 382.449,217.079 382.459,217.066 382.468,217.053 382.477,217.04 382.486,217.026 382.495,217.013 382.504,217 382.514,216.987 382.523,216.973 382.532,216.96 382.541,216.947 382.55,216.934 382.56,216.92 382.569,216.907 382.578,216.894 382.587,216.881 382.596,216.867 382.606,216.854 382.615,216.841 382.624,216.828 382.633,216.814 382.642,216.801 382.651,216.788 382.661,216.775 382.67,216.761 382.679,216.748 382.688,216.735 382.697,216.722 382.707,216.708 382.716,216.695 382.725,216.682 382.734,216.669 382.743,216.655 382.753,216.642 382.762,216.629 382.771,216.616 382.78,216.602 382.789,216.589 382.799,216.576 382.808,216.563 382.817,216.55 382.826,216.536 382.835,216.523 382.844,216.51 382.854,216.497 382.863,216.483 382.872,216.47 382.881,216.457 382.89,216.444 382.9,216.43 382.909,216.417 382.918,216.404 382.927,216.391 382.936,216.377 382.946,216.364 382.955,216.351 382.964,216.338 382.973,216.324 382.982,216.311 382.991,216.298 383.001,216.285 383.01,216.271 383.019,216.258 383.028,216.245 383.037,216.232 383.047,216.219 383.056,216.205 383.065,216.192 383.074,216.179 383.083,216.166 383.093,216.152 383.102,216.139 383.111,216.126 383.12,216.113 383.129,216.099 383.139,216.086 383.148,216.073 383.157,216.06 383.166,216.047 383.175,216.033 383.184,216.02 383.194,216.007 383.203,215.994 383.212,215.98 383.221,215.967 383.23,215.954 383.24,215.941 383.249,215.927 383.258,215.914 383.267,215.901 383.276,215.888 383.286,215.875 383.295,215.861 383.304,215.848 383.313,215.835 383.322,215.822 383.332,215.808 383.341,215.795 383.35,215.782 383.359,215.769 383.368,215.755 383.377,215.742 383.387,215.729 383.396,215.716 383.405,215.703 383.414,215.689 383.423,215.676 383.433,215.663 383.442,215.65 383.451,215.636 383.46,215.623 383.469,215.61 383.479,215.597 383.488,215.584 383.497,215.57 383.506,215.557 383.515,215.544 383.524,215.531 383.534,215.517 383.543,215.504 383.552,215.491 383.561,215.478 383.57,215.465 383.58,215.451 383.589,215.438 383.598,215.425 383.607,215.412 383.616,215.398 383.626,215.385 383.635,215.372 383.644,215.359 383.653,215.346 383.662,215.332 383.672,215.319 383.681,215.306 383.69,215.293 383.699,215.28 383.708,215.266 383.717,215.253 383.727,215.24 383.736,215.227 383.745,215.213 383.754,215.2 383.763,215.187 383.773,215.174 383.782,215.161 383.791,215.147 383.8,215.134 383.809,215.121 383.819,215.108 383.828,215.095 383.837,215.081 383.846,215.068 383.855,215.055 383.864,215.042 383.874,215.029 383.883,215.015 383.892,215.002 383.901,214.989 383.91,214.976 383.92,214.962 383.929,214.949 383.938,214.936 383.947,214.923 383.956,214.91 383.966,214.896 383.975,214.883 383.984,214.87 383.993,214.857 384.002,214.844 384.012,214.83 384.021,214.817 384.03,214.804 384.039,214.791 384.048,214.778 384.057,214.764 384.067,214.751 384.076,214.738 384.085,214.725 384.094,214.712 384.103,214.698 384.113,214.685 384.122,214.672 384.131,214.659 384.14,214.646 384.149,214.632 384.159,214.619 384.168,214.606 384.177,214.593 384.186,214.58 384.195,214.566 384.204,214.553 384.214,214.54 384.223,214.527 384.232,214.514 384.241,214.5 384.25,214.487 384.26,214.474 384.269,214.461 384.278,214.448 384.287,214.434 384.296,214.421 384.306,214.408 384.315,214.395 384.324,214.382 384.333,214.368 384.342,214.355 384.352,214.342 384.361,214.329 384.37,214.316 384.379,214.302 384.388,214.289 384.397,214.276 384.407,214.263 384.416,214.25 384.425,214.236 384.434,214.223 384.443,214.21 384.453,214.197 384.462,214.184 384.471,214.171 384.48,214.157 384.489,214.144 384.499,214.131 384.508,214.118 384.517,214.105 384.526,214.091 384.535,214.078 384.544,214.065 384.554,214.052 384.563,214.039 384.572,214.025 384.581,214.012 384.59,213.999 384.6,213.986 384.609,213.973 384.618,213.96 384.627,213.946 384.636,213.933 384.646,213.92 384.655,213.907 384.664,213.894 384.673,213.88 384.682,213.867 384.692,213.854 384.701,213.841 384.71,213.828 384.719,213.815 384.728,213.801 384.737,213.788 384.747,213.775 384.756,213.762 384.765,213.749 384.774,213.735 384.783,213.722 384.793,213.709 384.802,213.696 384.811,213.683 384.82,213.67 384.829,213.656 384.839,213.643 384.848,213.63 384.857,213.617 384.866,213.604 384.875,213.591 384.884,213.577 384.894,213.564 384.903,213.551 384.912,213.538 384.921,213.525 384.93,213.511 384.94,213.498 384.949,213.485 384.958,213.472 384.967,213.459 384.976,213.446 384.986,213.432 384.995,213.419 385.004,213.406 385.013,213.393 385.022,213.38 385.032,213.367 385.041,213.353 385.05,213.34 385.059,213.327 385.068,213.314 385.077,213.301 385.087,213.288 385.096,213.274 385.105,213.261 385.114,213.248 385.123,213.235 385.133,213.222 385.142,213.209 385.151,213.195 385.16,213.182 385.169,213.169 385.179,213.156 385.188,213.143 385.197,213.13 385.206,213.116 385.215,213.103 385.224,213.09 385.234,213.077 385.243,213.064 385.252,213.051 385.261,213.037 385.27,213.024 385.28,213.011 385.289,212.998 385.298,212.985 385.307,212.972 385.316,212.959 385.326,212.945 385.335,212.932 385.344,212.919 385.353,212.906 385.362,212.893 385.372,212.88 385.381,212.866 385.39,212.853 385.399,212.84 385.408,212.827 385.417,212.814 385.427,212.801 385.436,212.788 385.445,212.774 385.454,212.761 385.463,212.748 385.473,212.735 385.482,212.722 385.491,212.709 385.5,212.695 385.509,212.682 385.519,212.669 385.528,212.656 385.537,212.643 385.546,212.63 385.555,212.617 385.564,212.603 385.574,212.59 385.583,212.577 385.592,212.564 385.601,212.551 385.61,212.538 385.62,212.525 385.629,212.511 385.638,212.498 385.647,212.485 385.656,212.472 385.666,212.459 385.675,212.446 385.684,212.433 385.693,212.419 385.702,212.406 385.712,212.393 385.721,212.38 385.73,212.367 385.739,212.354 385.748,212.341 385.757,212.327 385.767,212.314 385.776,212.301 385.785,212.288 385.794,212.275 385.803,212.262 385.813,212.249 385.822,212.235 385.831,212.222 385.84,212.209 385.849,212.196 385.859,212.183 385.868,212.17 385.877,212.157 385.886,212.143 385.895,212.13 385.905,212.117 385.914,212.104 385.923,212.091 385.932,212.078 385.941,212.065 385.95,212.052 385.96,212.038 385.969,212.025 385.978,212.012 385.987,211.999 385.996,211.986 386.006,211.973 386.015,211.96 386.024,211.946 386.033,211.933 386.042,211.92 386.052,211.907 386.061,211.894 386.07,211.881 386.079,211.868 386.088,211.855 386.097,211.841 386.107,211.828 386.116,211.815 386.125,211.802 386.134,211.789 386.143,211.776 386.153,211.763 386.162,211.75 386.171,211.736 386.18,211.723 386.189,211.71 386.199,211.697 386.208,211.684 386.217,211.671 386.226,211.658 386.235,211.645 386.245,211.632 386.254,211.618 386.263,211.605 386.272,211.592 386.281,211.579 386.29,211.566 386.3,211.553 386.309,211.54 386.318,211.527 386.327,211.513 386.336,211.5 386.346,211.487 386.355,211.474 386.364,211.461 386.373,211.448 386.382,211.435 386.392,211.422 386.401,211.409 386.41,211.395 386.419,211.382 386.428,211.369 386.437,211.356 386.447,211.343 386.456,211.33 386.465,211.317 386.474,211.304 386.483,211.291 386.493,211.277 386.502,211.264 386.511,211.251 386.52,211.238 386.529,211.225 386.539,211.212 386.548,211.199 386.557,211.186 386.566,211.173 386.575,211.159 386.585,211.146 386.594,211.133 386.603,211.12 386.612,211.107 386.621,211.094 386.63,211.081 386.64,211.068 386.649,211.055 386.658,211.042 386.667,211.028 386.676,211.015 386.686,211.002 386.695,210.989 386.704,210.976 386.713,210.963 386.722,210.95 386.732,210.937 386.741,210.924 386.75,210.911 386.759,210.897 386.768,210.884 386.777,210.871 386.787,210.858 386.796,210.845 386.805,210.832 386.814,210.819 386.823,210.806 386.833,210.793 386.842,210.78 386.851,210.767 386.86,210.753 386.869,210.74 386.879,210.727 386.888,210.714 386.897,210.701 386.906,210.688 386.915,210.675 386.925,210.662 386.934,210.649 386.943,210.636 386.952,210.623 386.961,210.609 386.97,210.596 386.98,210.583 386.989,210.57 386.998,210.557 387.007,210.544 387.016,210.531 387.026,210.518 387.035,210.505 387.044,210.492 387.053,210.479 387.062,210.466 387.072,210.452 387.081,210.439 387.09,210.426 387.099,210.413 387.108,210.4 387.117,210.387 387.127,210.374 387.136,210.361 387.145,210.348 387.154,210.335 387.163,210.322 387.173,210.309 387.182,210.295 387.191,210.282 387.2,210.269 387.209,210.256 387.219,210.243 387.228,210.23 387.237,210.217 387.246,210.204 387.255,210.191 387.265,210.178 387.274,210.165 387.283,210.152 387.292,210.139 387.301,210.126 387.31,210.112 387.32,210.099 387.329,210.086 387.338,210.073 387.347,210.06 387.356,210.047 387.366,210.034 387.375,210.021 387.384,210.008 387.393,209.995 387.402,209.982 387.412,209.969 387.421,209.956 387.43,209.943 387.439,209.929 387.448,209.916 387.457,209.903 387.467,209.89 387.476,209.877 387.485,209.864 387.494,209.851 387.503,209.838 387.513,209.825 387.522,209.812 387.531,209.799 387.54,209.786 387.549,209.773 387.559,209.76 387.568,209.747 387.577,209.734 387.586,209.721 387.595,209.707 387.605,209.694 387.614,209.681 387.623,209.668 387.632,209.655 387.641,209.642 387.65,209.629 387.66,209.616 387.669,209.603 387.678,209.59 387.687,209.577 387.696,209.564 387.706,209.551 387.715,209.538 387.724,209.525 387.733,209.512 387.742,209.499 387.752,209.486 387.761,209.473 387.77,209.459 387.779,209.446 387.788,209.433 387.797,209.42 387.807,209.407 387.816,209.394 387.825,209.381 387.834,209.368 387.843,209.355 387.853,209.342 387.862,209.329 387.871,209.316 387.88,209.303 387.889,209.29 387.899,209.277 387.908,209.264 387.917,209.251 387.926,209.238 387.935,209.225 387.945,209.212 387.954,209.199 387.963,209.186 387.972,209.173 387.981,209.159 387.99,209.146 388,209.133 388.009,209.12 388.018,209.107 388.027,209.094 388.036,209.081 388.046,209.068 388.055,209.055 388.064,209.042 388.073,209.029 388.082,209.016 388.092,209.003 388.101,208.99 388.11,208.977 388.119,208.964 388.128,208.951 388.137,208.938 388.147,208.925 388.156,208.912 388.165,208.899 388.174,208.886 388.183,208.873 388.193,208.86 388.202,208.847 388.211,208.834 388.22,208.821 388.229,208.808 388.239,208.795 388.248,208.782 388.257,208.769 388.266,208.756 388.275,208.743 388.285,208.729 388.294,208.716 388.303,208.703 388.312,208.69 388.321,208.677 388.33,208.664 388.34,208.651 388.349,208.638 388.358,208.625 388.367,208.612 388.376,208.599 388.386,208.586 388.395,208.573 388.404,208.56 388.413,208.547 388.422,208.534 388.432,208.521 388.441,208.508 388.45,208.495 388.459,208.482 388.468,208.469 388.478,208.456 388.487,208.443 388.496,208.43 388.505,208.417 388.514,208.404 388.523,208.391 388.533,208.378 388.542,208.365 388.551,208.352 388.56,208.339 388.569,208.326 388.579,208.313 388.588,208.3 388.597,208.287 388.606,208.274 388.615,208.261 388.625,208.248 388.634,208.235 388.643,208.222 388.652,208.209 388.661,208.196 388.67,208.183 388.68,208.17 388.689,208.157 388.698,208.144 388.707,208.131 388.716,208.118 388.726,208.105 388.735,208.092 388.744,208.079 388.753,208.066 388.762,208.053 388.772,208.04 388.781,208.027 388.79,208.014 388.799,208.001 388.808,207.988 388.818,207.975 388.827,207.962 388.836,207.949 388.845,207.936 388.854,207.923 388.863,207.91 388.873,207.897 388.882,207.884 388.891,207.871 388.9,207.858 388.909,207.845 388.919,207.832 388.928,207.819 388.937,207.806 388.946,207.793 388.955,207.78 388.965,207.767 388.974,207.754 388.983,207.741 388.992,207.728 389.001,207.715 389.01,207.702 389.02,207.689 389.029,207.676 389.038,207.663 389.047,207.65 389.056,207.637 389.066,207.624 389.075,207.611 389.084,207.598 389.093,207.585 389.102,207.572 389.112,207.559 389.121,207.546 389.13,207.534 389.139,207.521 389.148,207.508 389.158,207.495 389.167,207.482 389.176,207.469 389.185,207.456 389.194,207.443 389.203,207.43 389.213,207.417 389.222,207.404 389.231,207.391 389.24,207.378 389.249,207.365 389.259,207.352 389.268,207.339 389.277,207.326 389.286,207.313 389.295,207.3 389.305,207.287 389.314,207.274 389.323,207.261 389.332,207.248 389.341,207.235 389.35,207.222 389.36,207.209 389.369,207.196 389.378,207.183 389.387,207.17 389.396,207.157 389.406,207.144 389.415,207.131 389.424,207.119 389.433,207.106 389.442,207.093 389.452,207.08 389.461,207.067 389.47,207.054 389.479,207.041 389.488,207.028 389.498,207.015 389.507,207.002 389.516,206.989 389.525,206.976 389.534,206.963 389.543,206.95 389.553,206.937 389.562,206.924 389.571,206.911 389.58,206.898 389.589,206.885 389.599,206.872 389.608,206.859 389.617,206.846 389.626,206.833 389.635,206.821 389.645,206.808 389.654,206.795 389.663,206.782 389.672,206.769 389.681,206.756 389.69,206.743 389.7,206.73 389.709,206.717 389.718,206.704 389.727,206.691 389.736,206.678 389.746,206.665 389.755,206.652 389.764,206.639 389.773,206.626 389.782,206.613 389.792,206.6 389.801,206.588 389.81,206.575 389.819,206.562 389.828,206.549 389.838,206.536 389.847,206.523 389.856,206.51 389.865,206.497 389.874,206.484 389.883,206.471 389.893,206.458 389.902,206.445 389.911,206.432 389.92,206.419 389.929,206.406 389.939,206.394 389.948,206.381 389.957,206.368 389.966,206.355 389.975,206.342 389.985,206.329 389.994,206.316 390.003,206.303 390.012,206.29 390.021,206.277 390.03,206.264 390.04,206.251 390.049,206.238 390.058,206.225 390.067,206.213 390.076,206.2 390.086,206.187 390.095,206.174 390.104,206.161 390.113,206.148 390.122,206.135 390.132,206.122 390.141,206.109 390.15,206.096 390.159,206.083 390.168,206.07 390.178,206.057 390.187,206.045 390.196,206.032 390.205,206.019 390.214,206.006 390.223,205.993 390.233,205.98 390.242,205.967 390.251,205.954 390.26,205.941 390.269,205.928 390.279,205.915 390.288,205.902 390.297,205.89 390.306,205.877 390.315,205.864 390.325,205.851 390.334,205.838 390.343,205.825 390.352,205.812 390.361,205.799 390.37,205.786 390.38,205.773 390.389,205.761 390.398,205.748 390.407,205.735 390.416,205.722 390.426,205.709 390.435,205.696 390.444,205.683 390.453,205.67 390.462,205.657 390.472,205.644 390.481,205.631 390.49,205.619 390.499,205.606 390.508,205.593 390.518,205.58 390.527,205.567 390.536,205.554 390.545,205.541 390.554,205.528 390.563,205.515 390.573,205.503 390.582,205.49 390.591,205.477 390.6,205.464 390.609,205.451 390.619,205.438 390.628,205.425 390.637,205.412 390.646,205.399 390.655,205.386 390.665,205.374 390.674,205.361 390.683,205.348 390.692,205.335 390.701,205.322 390.711,205.309 390.72,205.296 390.729,205.283 390.738,205.27 390.747,205.258 390.756,205.245 390.766,205.232 390.775,205.219 390.784,205.206 390.793,205.193 390.802,205.18 390.812,205.167 390.821,205.155 390.83,205.142 390.839,205.129 390.848,205.116 390.858,205.103 390.867,205.09 390.876,205.077 390.885,205.064 390.894,205.052 390.903,205.039 390.913,205.026 390.922,205.013 390.931,205 390.94,204.987 390.949,204.974 390.959,204.961 390.968,204.949 390.977,204.936 390.986,204.923 390.995,204.91 391.005,204.897 391.014,204.884 391.023,204.871 391.032,204.858 391.041,204.846 391.051,204.833 391.06,204.82 391.069,204.807 391.078,204.794 391.087,204.781 391.096,204.768 391.106,204.756 391.115,204.743 391.124,204.73 391.133,204.717 391.142,204.704 391.152,204.691 391.161,204.678 391.17,204.666 391.179,204.653 391.188,204.64 391.198,204.627 391.207,204.614 391.216,204.601 391.225,204.588 391.234,204.576 391.243,204.563 391.253,204.55 391.262,204.537 391.271,204.524 391.28,204.511 391.289,204.498 391.299,204.486 391.308,204.473 391.317,204.46 391.326,204.447 391.335,204.434 391.345,204.421 391.354,204.409 391.363,204.396 391.372,204.383 391.381,204.37 391.391,204.357 391.4,204.344 391.409,204.331 391.418,204.319 391.427,204.306 391.436,204.293 391.446,204.28 391.455,204.267 391.464,204.254 391.473,204.242 391.482,204.229 391.492,204.216 391.501,204.203 391.51,204.19 391.519,204.177 391.528,204.165 391.538,204.152 391.547,204.139 391.556,204.126 391.565,204.113 391.574,204.1 391.583,204.088 391.593,204.075 391.602,204.062 391.611,204.049 391.62,204.036 391.629,204.023 391.639,204.011 391.648,203.998 391.657,203.985 391.666,203.972 391.675,203.959 391.685,203.946 391.694,203.934 391.703,203.921 391.712,203.908 391.721,203.895 391.731,203.882 391.74,203.869 391.749,203.857 391.758,203.844 391.767,203.831 391.776,203.818 391.786,203.805 391.795,203.793 391.804,203.78 391.813,203.767 391.822,203.754 391.832,203.741 391.841,203.728 391.85,203.716 391.859,203.703 391.868,203.69 391.878,203.677 391.887,203.664 391.896,203.652 391.905,203.639 391.914,203.626 391.923,203.613 391.933,203.6 391.942,203.588 391.951,203.575 391.96,203.562 391.969,203.549 391.979,203.536 391.988,203.523 391.997,203.511 392.006,203.498 392.015,203.485 392.025,203.472 392.034,203.459 392.043,203.447 392.052,203.434 392.061,203.421 392.071,203.408 392.08,203.395 392.089,203.383 392.098,203.37 392.107,203.357 392.116,203.344 392.126,203.331 392.135,203.319 392.144,203.306 392.153,203.293 392.162,203.28 392.172,203.267 392.181,203.255 392.19,203.242 392.199,203.229 392.208,203.216 392.218,203.203 392.227,203.191 392.236,203.178 392.245,203.165 392.254,203.152 392.263,203.14 392.273,203.127 392.282,203.114 392.291,203.101 392.3,203.088 392.309,203.076 392.319,203.063 392.328,203.05 392.337,203.037 392.346,203.024 392.355,203.012 392.365,202.999 392.374,202.986 392.383,202.973 392.392,202.961 392.401,202.948 392.411,202.935 392.42,202.922 392.429,202.909 392.438,202.897 392.447,202.884 392.456,202.871 392.466,202.858 392.475,202.846 392.484,202.833 392.493,202.82 392.502,202.807 392.512,202.794 392.521,202.782 392.53,202.769 392.539,202.756 392.548,202.743 392.558,202.731 392.567,202.718 392.576,202.705 392.585,202.692 392.594,202.68 392.603,202.667 392.613,202.654 392.622,202.641 392.631,202.628 392.64,202.616 392.649,202.603 392.659,202.59 392.668,202.577 392.677,202.565 392.686,202.552 392.695,202.539 392.705,202.526 392.714,202.514 392.723,202.501 392.732,202.488 392.741,202.475 392.751,202.463 392.76,202.45 392.769,202.437 392.778,202.424 392.787,202.412 392.796,202.399 392.806,202.386 392.815,202.373 392.824,202.361 392.833,202.348 392.842,202.335 392.852,202.322 392.861,202.31 392.87,202.297 392.879,202.284 392.888,202.271 392.898,202.259 392.907,202.246 392.916,202.233 392.925,202.22 392.934,202.208 392.943,202.195 392.953,202.182 392.962,202.169 392.971,202.157 392.98,202.144 392.989,202.131 392.999,202.118 393.008,202.106 393.017,202.093 393.026,202.08 393.035,202.067 393.045,202.055 393.054,202.042 393.063,202.029 393.072,202.016 393.081,202.004 393.091,201.991 393.1,201.978 393.109,201.966 393.118,201.953 393.127,201.94 393.136,201.927 393.146,201.915 393.155,201.902 393.164,201.889 393.173,201.876 393.182,201.864 393.192,201.851 393.201,201.838 393.21,201.826 393.219,201.813 393.228,201.8 393.238,201.787 393.247,201.775 393.256,201.762 393.265,201.749 393.274,201.736 393.284,201.724 393.293,201.711 393.302,201.698 393.311,201.686 393.32,201.673 393.329,201.66 393.339,201.647 393.348,201.635 393.357,201.622 393.366,201.609 393.375,201.597 393.385,201.584 393.394,201.571 393.403,201.558 393.412,201.546 393.421,201.533 393.431,201.52 393.44,201.508 393.449,201.495 393.458,201.482 393.467,201.469 393.476,201.457 393.486,201.444 393.495,201.431 393.504,201.419 393.513,201.406 393.522,201.393 393.532,201.381 393.541,201.368 393.55,201.355 393.559,201.342 393.568,201.33 393.578,201.317 393.587,201.304 393.596,201.292 393.605,201.279 393.614,201.266 393.624,201.254 393.633,201.241 393.642,201.228 393.651,201.215 393.66,201.203 393.669,201.19 393.679,201.177 393.688,201.165 393.697,201.152 393.706,201.139 393.715,201.127 393.725,201.114 393.734,201.101 393.743,201.089 393.752,201.076 393.761,201.063 393.771,201.05 393.78,201.038 393.789,201.025 393.798,201.012 393.807,201 393.816,200.987 393.826,200.974 393.835,200.962 393.844,200.949 393.853,200.936 393.862,200.924 393.872,200.911 393.881,200.898 393.89,200.886 393.899,200.873 393.908,200.86 393.918,200.848 393.927,200.835 393.936,200.822 393.945,200.81 393.954,200.797 393.964,200.784 393.973,200.771 393.982,200.759 393.991,200.746 394,200.733 394.009,200.721 394.019,200.708 394.028,200.695 394.037,200.683 394.046,200.67 394.055,200.657 394.065,200.645 394.074,200.632 394.083,200.619 394.092,200.607 394.101,200.594 394.111,200.581 394.12,200.569 394.129,200.556 394.138,200.543 394.147,200.531 394.156,200.518 394.166,200.506 394.175,200.493 394.184,200.48 394.193,200.468 394.202,200.455 394.212,200.442 394.221,200.43 394.23,200.417 394.239,200.404 394.248,200.392 394.258,200.379 394.267,200.366 394.276,200.354 394.285,200.341 394.294,200.328 394.304,200.316 394.313,200.303 394.322,200.29 394.331,200.278 394.34,200.265 394.349,200.252 394.359,200.24 394.368,200.227 394.377,200.215 394.386,200.202 394.395,200.189 394.405,200.177 394.414,200.164 394.423,200.151 394.432,200.139 394.441,200.126 394.451,200.113 394.46,200.101 394.469,200.088 394.478,200.075 394.487,200.063 394.496,200.05 394.506,200.038 394.515,200.025 394.524,200.012 394.533,200 394.542,199.987 394.552,199.974 394.561,199.962 394.57,199.949 394.579,199.936 394.588,199.924 394.598,199.911 394.607,199.899 394.616,199.886 394.625,199.873 394.634,199.861 394.644,199.848 394.653,199.835 394.662,199.823 394.671,199.81 394.68,199.798 394.689,199.785 394.699,199.772 394.708,199.76 394.717,199.747 394.726,199.735 394.735,199.722 394.745,199.709 394.754,199.697 394.763,199.684 394.772,199.671 394.781,199.659 394.791,199.646 394.8,199.634 394.809,199.621 394.818,199.608 394.827,199.596 394.836,199.583 394.846,199.571 394.855,199.558 394.864,199.545 394.873,199.533 394.882,199.52 394.892,199.507 394.901,199.495 394.91,199.482 394.919,199.47 394.928,199.457 394.938,199.444 394.947,199.432 394.956,199.419 394.965,199.407 394.974,199.394 394.984,199.381 394.993,199.369 395.002,199.356 395.011,199.344 395.02,199.331 395.029,199.318 395.039,199.306 395.048,199.293 395.057,199.281 395.066,199.268 395.075,199.255 395.085,199.243 395.094,199.23 395.103,199.218 395.112,199.205 395.121,199.192 395.131,199.18 395.14,199.167 395.149,199.155 395.158,199.142 395.167,199.13 395.176,199.117 395.186,199.104 395.195,199.092 395.204,199.079 395.213,199.067 395.222,199.054 395.232,199.041 395.241,199.029 395.25,199.016 395.259,199.004 395.268,198.991 395.278,198.979 395.287,198.966 395.296,198.953 395.305,198.941 395.314,198.928 395.324,198.916 395.333,198.903 395.342,198.89 395.351,198.878 395.36,198.865 395.369,198.853 395.379,198.84 395.388,198.828 395.397,198.815 395.406,198.802 395.415,198.79 395.425,198.777 395.434,198.765 395.443,198.752 395.452,198.74 395.461,198.727 395.471,198.715 395.48,198.702 395.489,198.689 395.498,198.677 395.507,198.664 395.516,198.652 395.526,198.639 395.535,198.627 395.544,198.614 395.553,198.601 395.562,198.589 395.572,198.576 395.581,198.564 395.59,198.551 395.599,198.539 395.608,198.526 395.618,198.514 395.627,198.501 395.636,198.488 395.645,198.476 395.654,198.463 395.664,198.451 395.673,198.438 395.682,198.426 395.691,198.413 395.7,198.401 395.709,198.388 395.719,198.376 395.728,198.363 395.737,198.35 395.746,198.338 395.755,198.325 395.765,198.313 395.774,198.3 395.783,198.288 395.792,198.275 395.801,198.263 395.811,198.25 395.82,198.238 395.829,198.225 395.838,198.212 395.847,198.2 395.857,198.187 395.866,198.175 395.875,198.162 395.884,198.15 395.893,198.137 395.902,198.125 395.912,198.112 395.921,198.1 395.93,198.087 395.939,198.075 395.948,198.062 395.958,198.05 395.967,198.037 395.976,198.024 395.985,198.012 395.994,197.999 396.004,197.987 396.013,197.974 396.022,197.962 396.031,197.949 396.04,197.937 396.049,197.924 396.059,197.912 396.068,197.899 396.077,197.887 396.086,197.874 396.095,197.862 396.105,197.849 396.114,197.837 396.123,197.824 396.132,197.812 396.141,197.799 396.151,197.787 396.16,197.774 396.169,197.762 396.178,197.749 396.187,197.737 396.197,197.724 396.206,197.712 396.215,197.699 396.224,197.686 396.233,197.674 396.242,197.661 396.252,197.649 396.261,197.636 396.27,197.624 396.279,197.611 396.288,197.599 396.298,197.586 396.307,197.574 396.316,197.561 396.325,197.549 396.334,197.536 396.344,197.524 396.353,197.511 396.362,197.499 396.371,197.486 396.38,197.474 396.389,197.461 396.399,197.449 396.408,197.436 396.417,197.424 396.426,197.411 396.435,197.399 396.445,197.386 396.454,197.374 396.463,197.361 396.472,197.349 396.481,197.337 396.491,197.324 396.5,197.312 396.509,197.299 396.518,197.287 396.527,197.274 396.537,197.262 396.546,197.249 396.555,197.237 396.564,197.224 396.573,197.212 396.582,197.199 396.592,197.187 396.601,197.174 396.61,197.162 396.619,197.149 396.628,197.137 396.638,197.124 396.647,197.112 396.656,197.099 396.665,197.087 396.674,197.074 396.684,197.062 396.693,197.049 396.702,197.037 396.711,197.025 396.72,197.012 396.729,197 396.739,196.987 396.748,196.975 396.757,196.962 396.766,196.95 396.775,196.937 396.785,196.925 396.794,196.912 396.803,196.9 396.812,196.887 396.821,196.875 396.831,196.862 396.84,196.85 396.849,196.838 396.858,196.825 396.867,196.813 396.877,196.8 396.886,196.788 396.895,196.775 396.904,196.763 396.913,196.75 396.922,196.738 396.932,196.725 396.941,196.713 396.95,196.7 396.959,196.688 396.968,196.676 396.978,196.663 396.987,196.651 396.996,196.638 397.005,196.626 397.014,196.613 397.024,196.601 397.033,196.588 397.042,196.576 397.051,196.564 397.06,196.551 397.069,196.539 397.079,196.526 397.088,196.514 397.097,196.501 397.106,196.489 397.115,196.476 397.125,196.464 397.134,196.452 397.143,196.439 397.152,196.427 397.161,196.414 397.171,196.402 397.18,196.389 397.189,196.377 397.198,196.365 397.207,196.352 397.217,196.34 397.226,196.327 397.235,196.315 397.244,196.302 397.253,196.29 397.262,196.277 397.272,196.265 397.281,196.253 397.29,196.24 397.299,196.228 397.308,196.215 397.318,196.203 397.327,196.19 397.336,196.178 397.345,196.166 397.354,196.153 397.364,196.141 397.373,196.128 397.382,196.116 397.391,196.104 397.4,196.091 397.409,196.079 397.419,196.066 397.428,196.054 397.437,196.041 397.446,196.029 397.455,196.017 397.465,196.004 397.474,195.992 397.483,195.979 397.492,195.967 397.501,195.955 397.511,195.942 397.52,195.93 397.529,195.917 397.538,195.905 397.547,195.893 397.557,195.88 397.566,195.868 397.575,195.855 397.584,195.843 397.593,195.831 397.602,195.818 397.612,195.806 397.621,195.793 397.63,195.781 397.639,195.769 397.648,195.756 397.658,195.744 397.667,195.731 397.676,195.719 397.685,195.707 397.694,195.694 397.704,195.682 397.713,195.669 397.722,195.657 397.731,195.645 397.74,195.632 397.749,195.62 397.759,195.607 397.768,195.595 397.777,195.583 397.786,195.57 397.795,195.558 397.805,195.545 397.814,195.533 397.823,195.521 397.832,195.508 397.841,195.496 397.851,195.484 397.86,195.471 397.869,195.459 397.878,195.446 397.887,195.434 397.897,195.422 397.906,195.409 397.915,195.397 397.924,195.384 397.933,195.372 397.942,195.36 397.952,195.347 397.961,195.335 397.97,195.323 397.979,195.31 397.988,195.298 397.998,195.285 398.007,195.273 398.016,195.261 398.025,195.248 398.034,195.236 398.044,195.224 398.053,195.211 398.062,195.199 398.071,195.187 398.08,195.174 398.09,195.162 398.099,195.149 398.108,195.137 398.117,195.125 398.126,195.112 398.135,195.1 398.145,195.088 398.154,195.075 398.163,195.063 398.172,195.051 398.181,195.038 398.191,195.026 398.2,195.013 398.209,195.001 398.218,194.989 398.227,194.976 398.237,194.964 398.246,194.952 398.255,194.939 398.264,194.927 398.273,194.915 398.282,194.902 398.292,194.89 398.301,194.878 398.31,194.865 398.319,194.853 398.328,194.841 398.338,194.828 398.347,194.816 398.356,194.804 398.365,194.791 398.374,194.779 398.384,194.767 398.393,194.754 398.402,194.742 398.411,194.73 398.42,194.717 398.43,194.705 398.439,194.693 398.448,194.68 398.457,194.668 398.466,194.656 398.475,194.643 398.485,194.631 398.494,194.619 398.503,194.606 398.512,194.594 398.521,194.582 398.531,194.569 398.54,194.557 398.549,194.545 398.558,194.532 398.567,194.52 398.577,194.508 398.586,194.495 398.595,194.483 398.604,194.471 398.613,194.458 398.622,194.446 398.632,194.434 398.641,194.421 398.65,194.409 398.659,194.397 398.668,194.384 398.678,194.372 398.687,194.36 398.696,194.347 398.705,194.335 398.714,194.323 398.724,194.31 398.733,194.298 398.742,194.286 398.751,194.274 398.76,194.261 398.77,194.249 398.779,194.237 398.788,194.224 398.797,194.212 398.806,194.2 398.815,194.187 398.825,194.175 398.834,194.163 398.843,194.15 398.852,194.138 398.861,194.126 398.871,194.114 398.88,194.101 398.889,194.089 398.898,194.077 398.907,194.064 398.917,194.052 398.926,194.04 398.935,194.027 398.944,194.015 398.953,194.003 398.962,193.991 398.972,193.978 398.981,193.966 398.99,193.954 398.999,193.941 399.008,193.929 399.018,193.917 399.027,193.905 399.036,193.892 399.045,193.88 399.054,193.868 399.064,193.855 399.073,193.843 399.082,193.831 399.091,193.819 399.1,193.806 399.11,193.794 399.119,193.782 399.128,193.769 399.137,193.757 399.146,193.745 399.155,193.733 399.165,193.72 399.174,193.708 399.183,193.696 399.192,193.683 399.201,193.671 399.211,193.659 399.22,193.647 399.229,193.634 399.238,193.622 399.247,193.61 399.257,193.598 399.266,193.585 399.275,193.573 399.284,193.561 399.293,193.549 399.302,193.536 399.312,193.524 399.321,193.512 399.33,193.499 399.339,193.487 399.348,193.475 399.358,193.463 399.367,193.45 399.376,193.438 399.385,193.426 399.394,193.414 399.404,193.401 399.413,193.389 399.422,193.377 399.431,193.365 399.44,193.352 399.45,193.34 399.459,193.328 399.468,193.316 399.477,193.303 399.486,193.291 399.495,193.279 399.505,193.267 399.514,193.254 399.523,193.242 399.532,193.23 399.541,193.218 399.551,193.205 399.56,193.193 399.569,193.181 399.578,193.169 399.587,193.156 399.597,193.144 399.606,193.132 399.615,193.12 399.624,193.107 399.633,193.095 399.642,193.083 399.652,193.071 399.661,193.058 399.67,193.046 399.679,193.034 399.688,193.022 399.698,193.01 399.707,192.997 399.716,192.985 399.725,192.973 399.734,192.961 399.744,192.948 399.753,192.936 399.762,192.924 399.771,192.912 399.78,192.899 399.79,192.887 399.799,192.875 399.808,192.863 399.817,192.851 399.826,192.838 399.835,192.826 399.845,192.814 399.854,192.802 399.863,192.789 399.872,192.777 399.881,192.765 399.891,192.753 399.9,192.741 399.909,192.728 399.918,192.716 399.927,192.704 399.937,192.692 399.946,192.68 399.955,192.667 399.964,192.655 399.973,192.643 399.982,192.631 399.992,192.618 400.001,192.606 400.01,192.594 400.019,192.582 400.028,192.57 400.038,192.557 400.047,192.545 400.056,192.533 400.065,192.521 400.074,192.509 400.084,192.496 400.093,192.484 400.102,192.472 400.111,192.46 400.12,192.448 400.13,192.435 400.139,192.423 400.148,192.411 400.157,192.399 400.166,192.387 400.175,192.374 400.185,192.362 400.194,192.35 400.203,192.338 400.212,192.326 400.221,192.313 400.231,192.301 400.24,192.289 400.249,192.277 400.258,192.265 400.267,192.253 400.277,192.24 400.286,192.228 400.295,192.216 400.304,192.204 400.313,192.192 400.322,192.179 400.332,192.167 400.341,192.155 400.35,192.143 400.359,192.131 400.368,192.119 400.378,192.106 400.387,192.094 400.396,192.082 400.405,192.07 400.414,192.058 400.424,192.045 400.433,192.033 400.442,192.021 400.451,192.009 400.46,191.997 400.47,191.985 400.479,191.972 400.488,191.96 400.497,191.948 400.506,191.936 400.515,191.924 400.525,191.912 400.534,191.899 400.543,191.887 400.552,191.875 400.561,191.863 400.571,191.851 400.58,191.839 400.589,191.827 400.598,191.814 400.607,191.802 400.617,191.79 400.626,191.778 400.635,191.766 400.644,191.754 400.653,191.741 400.663,191.729 400.672,191.717 400.681,191.705 400.69,191.693 400.699,191.681 400.708,191.669 400.718,191.656 400.727,191.644 400.736,191.632 400.745,191.62 400.754,191.608 400.764,191.596 400.773,191.584 400.782,191.571 400.791,191.559 400.8,191.547 400.81,191.535 400.819,191.523 400.828,191.511 400.837,191.499 400.846,191.486 400.855,191.474 400.865,191.462 400.874,191.45 400.883,191.438 400.892,191.426 400.901,191.414 400.911,191.401 400.92,191.389 400.929,191.377 400.938,191.365 400.947,191.353 400.957,191.341 400.966,191.329 400.975,191.317 400.984,191.304 400.993,191.292 401.003,191.28 401.012,191.268 401.021,191.256 401.03,191.244 401.039,191.232 401.048,191.22 401.058,191.207 401.067,191.195 401.076,191.183 401.085,191.171 401.094,191.159 401.104,191.147 401.113,191.135 401.122,191.123 401.131,191.111 401.14,191.098 401.15,191.086 401.159,191.074 401.168,191.062 401.177,191.05 401.186,191.038 401.195,191.026 401.205,191.014 401.214,191.002 401.223,190.989 401.232,190.977 401.241,190.965 401.251,190.953 401.26,190.941 401.269,190.929 401.278,190.917 401.287,190.905 401.297,190.893 401.306,190.881 401.315,190.868 401.324,190.856 401.333,190.844 401.343,190.832 401.352,190.82 401.361,190.808 401.37,190.796 401.379,190.784 401.388,190.772 401.398,190.76 401.407,190.747 401.416,190.735 401.425,190.723 401.434,190.711 401.444,190.699 401.453,190.687 401.462,190.675 401.471,190.663 401.48,190.651 401.49,190.639 401.499,190.627 401.508,190.615 401.517,190.602 401.526,190.59 401.535,190.578 401.545,190.566 401.554,190.554 401.563,190.542 401.572,190.53 401.581,190.518 401.591,190.506 401.6,190.494 401.609,190.482 401.618,190.47 401.627,190.458 401.637,190.446 401.646,190.433 401.655,190.421 401.664,190.409 401.673,190.397 401.683,190.385 401.692,190.373 401.701,190.361 401.71,190.349 401.719,190.337 401.728,190.325 401.738,190.313 401.747,190.301 401.756,190.289 401.765,190.277 401.774,190.265 401.784,190.253 401.793,190.24 401.802,190.228 401.811,190.216 401.82,190.204 401.83,190.192 401.839,190.18 401.848,190.168 401.857,190.156 401.866,190.144 401.875,190.132 401.885,190.12 401.894,190.108 401.903,190.096 401.912,190.084 401.921,190.072 401.931,190.06 401.94,190.048 401.949,190.036 401.958,190.024 401.967,190.012 401.977,189.999 401.986,189.987 401.995,189.975 402.004,189.963 402.013,189.951 402.023,189.939 402.032,189.927 402.041,189.915 402.05,189.903 402.059,189.891 402.068,189.879 402.078,189.867 402.087,189.855 402.096,189.843 402.105,189.831 402.114,189.819 402.124,189.807 402.133,189.795 402.142,189.783 402.151,189.771 402.16,189.759 402.17,189.747 402.179,189.735 402.188,189.723 402.197,189.711 402.206,189.699 402.215,189.687 402.225,189.675 402.234,189.663 402.243,189.651 402.252,189.639 402.261,189.627 402.271,189.615 402.28,189.603 402.289,189.591 402.298,189.579 402.307,189.567 402.317,189.555 402.326,189.543 402.335,189.531 402.344,189.519 402.353,189.507 402.363,189.495 402.372,189.483 402.381,189.471 402.39,189.458 402.399,189.446 402.408,189.434 402.418,189.422 402.427,189.41 402.436,189.398 402.445,189.386 402.454,189.374 402.464,189.362 402.473,189.35 402.482,189.338 402.491,189.327 402.5,189.315 402.51,189.303 402.519,189.291 402.528,189.279 402.537,189.267 402.546,189.255 402.555,189.243 402.565,189.231 402.574,189.219 402.583,189.207 402.592,189.195 402.601,189.183 402.611,189.171 402.62,189.159 402.629,189.147 402.638,189.135 402.647,189.123 402.657,189.111 402.666,189.099 402.675,189.087 402.684,189.075 402.693,189.063 402.703,189.051 402.712,189.039 402.721,189.027 402.73,189.015 402.739,189.003 402.748,188.991 402.758,188.979 402.767,188.967 402.776,188.955 402.785,188.943 402.794,188.931 402.804,188.919 402.813,188.907 402.822,188.895 402.831,188.883 402.84,188.871 402.85,188.859 402.859,188.847 402.868,188.835 402.877,188.823 402.886,188.811 402.895,188.799 402.905,188.788 402.914,188.776 402.923,188.764 402.932,188.752 402.941,188.74 402.951,188.728 402.96,188.716 402.969,188.704 402.978,188.692 402.987,188.68 402.997,188.668 403.006,188.656 403.015,188.644 403.024,188.632 403.033,188.62 403.043,188.608 403.052,188.596 403.061,188.584 403.07,188.572 403.079,188.56 403.088,188.549 403.098,188.537 403.107,188.525 403.116,188.513 403.125,188.501 403.134,188.489 403.144,188.477 403.153,188.465 403.162,188.453 403.171,188.441 403.18,188.429 403.19,188.417 403.199,188.405 403.208,188.393 403.217,188.381 403.226,188.369 403.236,188.358 403.245,188.346 403.254,188.334 403.263,188.322 403.272,188.31 403.281,188.298 403.291,188.286 403.3,188.274 403.309,188.262 403.318,188.25 403.327,188.238 403.337,188.226 403.346,188.214 403.355,188.203 403.364,188.191 403.373,188.179 403.383,188.167 403.392,188.155 403.401,188.143 403.41,188.131 403.419,188.119 403.428,188.107 403.438,188.095 403.447,188.083 403.456,188.071 403.465,188.06 403.474,188.048 403.484,188.036 403.493,188.024 403.502,188.012 403.511,188 403.52,187.988 403.53,187.976 403.539,187.964 403.548,187.952 403.557,187.94 403.566,187.929 403.576,187.917 403.585,187.905 403.594,187.893 403.603,187.881 403.612,187.869 403.621,187.857 403.631,187.845 403.64,187.833 403.649,187.822 403.658,187.81 403.667,187.798 403.677,187.786 403.686,187.774 403.695,187.762 403.704,187.75 403.713,187.738 403.723,187.726 403.732,187.715 403.741,187.703 403.75,187.691 403.759,187.679 403.768,187.667 403.778,187.655 403.787,187.643 403.796,187.631 403.805,187.619 403.814,187.608 403.824,187.596 403.833,187.584 403.842,187.572 403.851,187.56 403.86,187.548 403.87,187.536 403.879,187.524 403.888,187.513 403.897,187.501 403.906,187.489 403.916,187.477 403.925,187.465 403.934,187.453 403.943,187.441 403.952,187.429 403.961,187.418 403.971,187.406 403.98,187.394 403.989,187.382 403.998,187.37 404.007,187.358 404.017,187.346 404.026,187.335 404.035,187.323 404.044,187.311 404.053,187.299 404.063,187.287 404.072,187.275 404.081,187.263 404.09,187.252 404.099,187.24 404.108,187.228 404.118,187.216 404.127,187.204 404.136,187.192 404.145,187.18 404.154,187.169 404.164,187.157 404.173,187.145 404.182,187.133 404.191,187.121 404.2,187.109 404.21,187.098 404.219,187.086 404.228,187.074 404.237,187.062 404.246,187.05 404.256,187.038 404.265,187.026 404.274,187.015 404.283,187.003 404.292,186.991 404.301,186.979 404.311,186.967 404.32,186.955 404.329,186.944 404.338,186.932 404.347,186.92 404.357,186.908 404.366,186.896 404.375,186.884 404.384,186.873 404.393,186.861 404.403,186.849 404.412,186.837 404.421,186.825 404.43,186.814 404.439,186.802 404.448,186.79 404.458,186.778 404.467,186.766 404.476,186.754 404.485,186.743 404.494,186.731 404.504,186.719 404.513,186.707 404.522,186.695 404.531,186.684 404.54,186.672 404.55,186.66 404.559,186.648 404.568,186.636 404.577,186.624 404.586,186.613 404.596,186.601 404.605,186.589 404.614,186.577 404.623,186.565 404.632,186.554 404.641,186.542 404.651,186.53 404.66,186.518 404.669,186.506 404.678,186.495 404.687,186.483 404.697,186.471 404.706,186.459 404.715,186.447 404.724,186.436 404.733,186.424 404.743,186.412 404.752,186.4 404.761,186.388 404.77,186.377 404.779,186.365 404.788,186.353 404.798,186.341 404.807,186.329 404.816,186.318 404.825,186.306 404.834,186.294 404.844,186.282 404.853,186.271 404.862,186.259 404.871,186.247 404.88,186.235 404.89,186.223 404.899,186.212 404.908,186.2 404.917,186.188 404.926,186.176 404.936,186.164 404.945,186.153 404.954,186.141 404.963,186.129 404.972,186.117 404.981,186.106 404.991,186.094 405,186.082 405.009,186.07 405.018,186.059 405.027,186.047 405.037,186.035 405.046,186.023 405.055,186.011 405.064,186 405.073,185.988 405.083,185.976 405.092,185.964 405.101,185.953 405.11,185.941 405.119,185.929 405.128,185.917 405.138,185.906 405.147,185.894 405.156,185.882 405.165,185.87 405.174,185.859 405.184,185.847 405.193,185.835 405.202,185.823 405.211,185.812 405.22,185.8 405.23,185.788 405.239,185.776 405.248,185.765 405.257,185.753 405.266,185.741 405.276,185.729 405.285,185.718 405.294,185.706 405.303,185.694 405.312,185.682 405.321,185.671 405.331,185.659 405.34,185.647 405.349,185.635 405.358,185.624 405.367,185.612 405.377,185.6 405.386,185.588 405.395,185.577 405.404,185.565 405.413,185.553 405.423,185.541 405.432,185.53 405.441,185.518 405.45,185.506 405.459,185.495 405.469,185.483 405.478,185.471 405.487,185.459 405.496,185.448 405.505,185.436 405.514,185.424 405.524,185.412 405.533,185.401 405.542,185.389 405.551,185.377 405.56,185.366 405.57,185.354 405.579,185.342 405.588,185.33 405.597,185.319 405.606,185.307 405.616,185.295 405.625,185.283 405.634,185.272 405.643,185.26 405.652,185.248 405.661,185.237 405.671,185.225 405.68,185.213 405.689,185.202 405.698,185.19 405.707,185.178 405.717,185.166 405.726,185.155 405.735,185.143 405.744,185.131 405.753,185.12 405.763,185.108 405.772,185.096 405.781,185.084 405.79,185.073 405.799,185.061 405.809,185.049 405.818,185.038 405.827,185.026 405.836,185.014 405.845,185.003 405.854,184.991 405.864,184.979 405.873,184.967 405.882,184.956 405.891,184.944 405.9,184.932 405.91,184.921 405.919,184.909 405.928,184.897 405.937,184.886 405.946,184.874 405.956,184.862 405.965,184.851 405.974,184.839 405.983,184.827 405.992,184.816 406.001,184.804 406.011,184.792 406.02,184.781 406.029,184.769 406.038,184.757 406.047,184.745 406.057,184.734 406.066,184.722 406.075,184.71 406.084,184.699 406.093,184.687 406.103,184.675 406.112,184.664 406.121,184.652 406.13,184.64 406.139,184.629 406.149,184.617 406.158,184.605 406.167,184.594 406.176,184.582 406.185,184.57 406.194,184.559 406.204,184.547 406.213,184.535 406.222,184.524 406.231,184.512 406.24,184.5 406.25,184.489 406.259,184.477 406.268,184.465 406.277,184.454 406.286,184.442 406.296,184.431 406.305,184.419 406.314,184.407 406.323,184.396 406.332,184.384 406.341,184.372 406.351,184.361 406.36,184.349 406.369,184.337 406.378,184.326 406.387,184.314 406.397,184.302 406.406,184.291 406.415,184.279 406.424,184.267 406.433,184.256 406.443,184.244 406.452,184.233 406.461,184.221 406.47,184.209 406.479,184.198 406.489,184.186 406.498,184.174 406.507,184.163 406.516,184.151 406.525,184.139 406.534,184.128 406.544,184.116 406.553,184.105 406.562,184.093 406.571,184.081 406.58,184.07 406.59,184.058 406.599,184.046 406.608,184.035 406.617,184.023 406.626,184.012 406.636,184 406.645,183.988 406.654,183.977 406.663,183.965 406.672,183.953 406.681,183.942 406.691,183.93 406.7,183.919 406.709,183.907 406.718,183.895 406.727,183.884 406.737,183.872 406.746,183.86 406.755,183.849 406.764,183.837 406.773,183.826 406.783,183.814 406.792,183.802 406.801,183.791 406.81,183.779 406.819,183.768 406.829,183.756 406.838,183.744 406.847,183.733 406.856,183.721 406.865,183.71 406.874,183.698 406.884,183.686 406.893,183.675 406.902,183.663 406.911,183.652 406.92,183.64 406.93,183.628 406.939,183.617 406.948,183.605 406.957,183.594 406.966,183.582 406.976,183.57 406.985,183.559 406.994,183.547 407.003,183.536 407.012,183.524 407.021,183.512 407.031,183.501 407.04,183.489 407.049,183.478 407.058,183.466 407.067,183.455 407.077,183.443 407.086,183.431 407.095,183.42 407.104,183.408 407.113,183.397 407.123,183.385 407.132,183.374 407.141,183.362 407.15,183.35 407.159,183.339 407.169,183.327 407.178,183.316 407.187,183.304 407.196,183.293 407.205,183.281 407.214,183.269 407.224,183.258 407.233,183.246 407.242,183.235 407.251,183.223 407.26,183.212 407.27,183.2 407.279,183.188 407.288,183.177 407.297,183.165 407.306,183.154 407.316,183.142 407.325,183.131 407.334,183.119 407.343,183.107 407.352,183.096 407.361,183.084 407.371,183.073 407.38,183.061 407.389,183.05 407.398,183.038 407.407,183.027 407.417,183.015 407.426,183.003 407.435,182.992 407.444,182.98 407.453,182.969 407.463,182.957 407.472,182.946 407.481,182.934 407.49,182.923 407.499,182.911 407.509,182.9 407.518,182.888 407.527,182.877 407.536,182.865 407.545,182.853 407.554,182.842 407.564,182.83 407.573,182.819 407.582,182.807 407.591,182.796 407.6,182.784 407.61,182.773 407.619,182.761 407.628,182.75 407.637,182.738 407.646,182.727 407.656,182.715 407.665,182.704 407.674,182.692 407.683,182.68 407.692,182.669 407.701,182.657 407.711,182.646 407.72,182.634 407.729,182.623 407.738,182.611 407.747,182.6 407.757,182.588 407.766,182.577 407.775,182.565 407.784,182.554 407.793,182.542 407.803,182.531 407.812,182.519 407.821,182.508 407.83,182.496 407.839,182.485 407.849,182.473 407.858,182.462 407.867,182.45 407.876,182.439 407.885,182.427 407.894,182.416 407.904,182.404 407.913,182.393 407.922,182.381 407.931,182.37 407.94,182.358 407.95,182.347 407.959,182.335 407.968,182.324 407.977,182.312 407.986,182.301 407.996,182.289 408.005,182.278 408.014,182.266 408.023,182.255 408.032,182.243 408.042,182.232 408.051,182.22 408.06,182.209 408.069,182.197 408.078,182.186 408.087,182.174 408.097,182.163 408.106,182.151 408.115,182.14 408.124,182.128 408.133,182.117 408.143,182.105 408.152,182.094 408.161,182.082 408.17,182.071 408.179,182.059 408.189,182.048 408.198,182.036 408.207,182.025 408.216,182.013 408.225,182.002 408.234,181.99 408.244,181.979 408.253,181.968 408.262,181.956 408.271,181.945 408.28,181.933 408.29,181.922 408.299,181.91 408.308,181.899 408.317,181.887 408.326,181.876 408.336,181.864 408.345,181.853 408.354,181.841 408.363,181.83 408.372,181.818 408.382,181.807 408.391,181.796 408.4,181.784 408.409,181.773 408.418,181.761 408.427,181.75 408.437,181.738 408.446,181.727 408.455,181.715 408.464,181.704 408.473,181.692 408.483,181.681 408.492,181.67 408.501,181.658 408.51,181.647 408.519,181.635 408.529,181.624 408.538,181.612 408.547,181.601 408.556,181.589 408.565,181.578 408.574,181.567 408.584,181.555 408.593,181.544 408.602,181.532 408.611,181.521 408.62,181.509 408.63,181.498 408.639,181.486 408.648,181.475 408.657,181.464 408.666,181.452 408.676,181.441 408.685,181.429 408.694,181.418 408.703,181.406 408.712,181.395 408.722,181.384 408.731,181.372 408.74,181.361 408.749,181.349 408.758,181.338 408.767,181.326 408.777,181.315 408.786,181.304 408.795,181.292 408.804,181.281 408.813,181.269 408.823,181.258 408.832,181.246 408.841,181.235 408.85,181.224 408.859,181.212 408.869,181.201 408.878,181.189 408.887,181.178 408.896,181.167 408.905,181.155 408.914,181.144 408.924,181.132 408.933,181.121 408.942,181.11 408.951,181.098 408.96,181.087 408.97,181.075 408.979,181.064 408.988,181.052 408.997,181.041 409.006,181.03 409.016,181.018 409.025,181.007 409.034,180.995 409.043,180.984 409.052,180.973 409.062,180.961 409.071,180.95 409.08,180.939 409.089,180.927 409.098,180.916 409.107,180.904 409.117,180.893 409.126,180.882 409.135,180.87 409.144,180.859 409.153,180.847 409.163,180.836 409.172,180.825 409.181,180.813 409.19,180.802 409.199,180.79 409.209,180.779 409.218,180.768 409.227,180.756 409.236,180.745 409.245,180.734 409.254,180.722 409.264,180.711 409.273,180.699 409.282,180.688 409.291,180.677 409.3,180.665 409.31,180.654 409.319,180.643 409.328,180.631 409.337,180.62 409.346,180.608 409.356,180.597 409.365,180.586 409.374,180.574 409.383,180.563 409.392,180.552 409.402,180.54 409.411,180.529 409.42,180.518 409.429,180.506 409.438,180.495 409.447,180.483 409.457,180.472 409.466,180.461 409.475,180.449 409.484,180.438 409.493,180.427 409.503,180.415 409.512,180.404 409.521,180.393 409.53,180.381 409.539,180.37 409.549,180.359 409.558,180.347 409.567,180.336 409.576,180.324 409.585,180.313 409.594,180.302 409.604,180.29 409.613,180.279 409.622,180.268 409.631,180.256 409.64,180.245 409.65,180.234 409.659,180.222 409.668,180.211 409.677,180.2 409.686,180.188 409.696,180.177 409.705,180.166 409.714,180.154 409.723,180.143 409.732,180.132 409.742,180.12 409.751,180.109 409.76,180.098 409.769,180.086 409.778,180.075 409.787,180.064 409.797,180.052 409.806,180.041 409.815,180.03 409.824,180.018 409.833,180.007 409.843,179.996 409.852,179.984 409.861,179.973 409.87,179.962 409.879,179.95 409.889,179.939 409.898,179.928 409.907,179.917 409.916,179.905 409.925,179.894 409.934,179.883 409.944,179.871 409.953,179.86 409.962,179.849 409.971,179.837 409.98,179.826 409.99,179.815 409.999,179.803 410.008,179.792 410.017,179.781 410.026,179.769 410.036,179.758 410.045,179.747 410.054,179.736 410.063,179.724 410.072,179.713 410.082,179.702 410.091,179.69 410.1,179.679 410.109,179.668 410.118,179.656 410.127,179.645 410.137,179.634 410.146,179.623 410.155,179.611 410.164,179.6 410.173,179.589 410.183,179.577 410.192,179.566 410.201,179.555 410.21,179.544 410.219,179.532 410.229,179.521 410.238,179.51 410.247,179.498 410.256,179.487 410.265,179.476 410.274,179.465 410.284,179.453 410.293,179.442 410.302,179.431 410.311,179.419 410.32,179.408 410.33,179.397 410.339,179.386 410.348,179.374 410.357,179.363 410.366,179.352 410.376,179.341 410.385,179.329 410.394,179.318 410.403,179.307 410.412,179.295 410.422,179.284 410.431,179.273 410.44,179.262 410.449,179.25 410.458,179.239 410.467,179.228 410.477,179.217 410.486,179.205 410.495,179.194 410.504,179.183 410.513,179.172 410.523,179.16 410.532,179.149 410.541,179.138 410.55,179.127 410.559,179.115 410.569,179.104 410.578,179.093 410.587,179.081 410.596,179.07 410.605,179.059 410.615,179.048 410.624,179.036 410.633,179.025 410.642,179.014 410.651,179.003 410.66,178.992 410.67,178.98 410.679,178.969 410.688,178.958 410.697,178.947 410.706,178.935 410.716,178.924 410.725,178.913 410.734,178.902 410.743,178.89 410.752,178.879 410.762,178.868 410.771,178.857 410.78,178.845 410.789,178.834 410.798,178.823 410.807,178.812 410.817,178.8 410.826,178.789 410.835,178.778 410.844,178.767 410.853,178.756 410.863,178.744 410.872,178.733 410.881,178.722 410.89,178.711 410.899,178.699 410.909,178.688 410.918,178.677 410.927,178.666 410.936,178.655 410.945,178.643 410.955,178.632 410.964,178.621 410.973,178.61 410.982,178.598 410.991,178.587 411,178.576 411.01,178.565 411.019,178.554 411.028,178.542 411.037,178.531 411.046,178.52 411.056,178.509 411.065,178.498 411.074,178.486 411.083,178.475 411.092,178.464 411.102,178.453 411.111,178.442 411.12,178.43 411.129,178.419 411.138,178.408 411.147,178.397 411.157,178.386 411.166,178.374 411.175,178.363 411.184,178.352 411.193,178.341 411.203,178.33 411.212,178.318 411.221,178.307 411.23,178.296 411.239,178.285 411.249,178.274 411.258,178.262 411.267,178.251 411.276,178.24 411.285,178.229 411.295,178.218 411.304,178.207 411.313,178.195 411.322,178.184 411.331,178.173 411.34,178.162 411.35,178.151 411.359,178.139 411.368,178.128 411.377,178.117 411.386,178.106 411.396,178.095 411.405,178.084 411.414,178.072 411.423,178.061 411.432,178.05 411.442,178.039 411.451,178.028 411.46,178.017 411.469,178.005 411.478,177.994 411.487,177.983 411.497,177.972 411.506,177.961 411.515,177.95 411.524,177.938 411.533,177.927 411.543,177.916 411.552,177.905 411.561,177.894 411.57,177.883 411.579,177.871 411.589,177.86 411.598,177.849 411.607,177.838 411.616,177.827 411.625,177.816 411.635,177.805 411.644,177.793 411.653,177.782 411.662,177.771 411.671,177.76 411.68,177.749 411.69,177.738 411.699,177.726 411.708,177.715 411.717,177.704 411.726,177.693 411.736,177.682 411.745,177.671 411.754,177.66 411.763,177.648 411.772,177.637 411.782,177.626 411.791,177.615 411.8,177.604 411.809,177.593 411.818,177.582 411.827,177.571 411.837,177.559 411.846,177.548 411.855,177.537 411.864,177.526 411.873,177.515 411.883,177.504 411.892,177.493 411.901,177.481 411.91,177.47 411.919,177.459 411.929,177.448 411.938,177.437 411.947,177.426 411.956,177.415 411.965,177.404 411.975,177.393 411.984,177.381 411.993,177.37 412.002,177.359 412.011,177.348 412.02,177.337 412.03,177.326 412.039,177.315 412.048,177.304 412.057,177.292 412.066,177.281 412.076,177.27 412.085,177.259 412.094,177.248 412.103,177.237 412.112,177.226 412.122,177.215 412.131,177.204 412.14,177.193 412.149,177.181 412.158,177.17 412.167,177.159 412.177,177.148 412.186,177.137 412.195,177.126 412.204,177.115 412.213,177.104 412.223,177.093 412.232,177.082 412.241,177.07 412.25,177.059 412.259,177.048 412.269,177.037 412.278,177.026 412.287,177.015 412.296,177.004 412.305,176.993 412.315,176.982 412.324,176.971 412.333,176.96 412.342,176.948 412.351,176.937 412.36,176.926 412.37,176.915 412.379,176.904 412.388,176.893 412.397,176.882 412.406,176.871 412.416,176.86 412.425,176.849 412.434,176.838 412.443,176.827 412.452,176.816 412.462,176.804 412.471,176.793 412.48,176.782 412.489,176.771 412.498,176.76 412.507,176.749 412.517,176.738 412.526,176.727 412.535,176.716 412.544,176.705 412.553,176.694 412.563,176.683 412.572,176.672 412.581,176.661 412.59,176.65 412.599,176.638 412.609,176.627 412.618,176.616 412.627,176.605 412.636,176.594 412.645,176.583 412.655,176.572 412.664,176.561 412.673,176.55 412.682,176.539 412.691,176.528 412.7,176.517 412.71,176.506 412.719,176.495 412.728,176.484 412.737,176.473 412.746,176.462 412.756,176.451 412.765,176.44 412.774,176.429 412.783,176.417 412.792,176.406 412.802,176.395 412.811,176.384 412.82,176.373 412.829,176.362 412.838,176.351 412.847,176.34 412.857,176.329 412.866,176.318 412.875,176.307 412.884,176.296 412.893,176.285 412.903,176.274 412.912,176.263 412.921,176.252 412.93,176.241 412.939,176.23 412.949,176.219 412.958,176.208 412.967,176.197 412.976,176.186 412.985,176.175 412.995,176.164 413.004,176.153 413.013,176.142 413.022,176.131 413.031,176.12 413.04,176.109 413.05,176.098 413.059,176.087 413.068,176.076 413.077,176.065 413.086,176.054 413.096,176.043 413.105,176.032 413.114,176.021 413.123,176.01 413.132,175.999 413.142,175.988 413.151,175.977 413.16,175.966 413.169,175.955 413.178,175.944 413.188,175.933 413.197,175.922 413.206,175.911 413.215,175.9 413.224,175.889 413.233,175.878 413.243,175.867 413.252,175.856 413.261,175.845 413.27,175.834 413.279,175.823 413.289,175.812 413.298,175.801 413.307,175.79 413.316,175.779 413.325,175.768 413.335,175.757 413.344,175.746 413.353,175.735 413.362,175.724 413.371,175.713 413.38,175.702 413.39,175.691 413.399,175.68 413.408,175.669 413.417,175.658 413.426,175.647 413.436,175.636 413.445,175.625 413.454,175.614 413.463,175.603 413.472,175.592 413.482,175.581 413.491,175.57 413.5,175.559 413.509,175.548 413.518,175.537 413.528,175.526 413.537,175.515 413.546,175.504 413.555,175.493 413.564,175.482 413.573,175.471 413.583,175.46 413.592,175.449 413.601,175.438 413.61,175.427 413.619,175.416 413.629,175.405 413.638,175.395 413.647,175.384 413.656,175.373 413.665,175.362 413.675,175.351 413.684,175.34 413.693,175.329 413.702,175.318 413.711,175.307 413.72,175.296 413.73,175.285 413.739,175.274 413.748,175.263 413.757,175.252 413.766,175.241 413.776,175.23 413.785,175.219 413.794,175.208 413.803,175.197 413.812,175.186 413.822,175.176 413.831,175.165 413.84,175.154 413.849,175.143 413.858,175.132 413.868,175.121 413.877,175.11 413.886,175.099 413.895,175.088 413.904,175.077 413.913,175.066 413.923,175.055 413.932,175.044 413.941,175.033 413.95,175.022 413.959,175.012 413.969,175.001 413.978,174.99 413.987,174.979 413.996,174.968 414.005,174.957 414.015,174.946 414.024,174.935 414.033,174.924 414.042,174.913 414.051,174.902 414.06,174.891 414.07,174.88 414.079,174.87 414.088,174.859 414.097,174.848 414.106,174.837 414.116,174.826 414.125,174.815 414.134,174.804 414.143,174.793 414.152,174.782 414.162,174.771 414.171,174.76 414.18,174.75 414.189,174.739 414.198,174.728 414.208,174.717 414.217,174.706 414.226,174.695 414.235,174.684 414.244,174.673 414.253,174.662 414.263,174.651 414.272,174.64 414.281,174.63 414.29,174.619 414.299,174.608 414.309,174.597 414.318,174.586 414.327,174.575 414.336,174.564 414.345,174.553 414.355,174.542 414.364,174.532 414.373,174.521 414.382,174.51 414.391,174.499 414.4,174.488 414.41,174.477 414.419,174.466 414.428,174.455 414.437,174.444 414.446,174.434 414.456,174.423 414.465,174.412 414.474,174.401 414.483,174.39 414.492,174.379 414.502,174.368 414.511,174.357 414.52,174.347 414.529,174.336 414.538,174.325 414.548,174.314 414.557,174.303 414.566,174.292 414.575,174.281 414.584,174.271 414.593,174.26 414.603,174.249 414.612,174.238 414.621,174.227 414.63,174.216 414.639,174.205 414.649,174.194 414.658,174.184 414.667,174.173 414.676,174.162 414.685,174.151 414.695,174.14 414.704,174.129 414.713,174.118 414.722,174.108 414.731,174.097 414.74,174.086 414.75,174.075 414.759,174.064 414.768,174.053 414.777,174.043 414.786,174.032 414.796,174.021 414.805,174.01 414.814,173.999 414.823,173.988 414.832,173.977 414.842,173.967 414.851,173.956 414.86,173.945 414.869,173.934 414.878,173.923 414.888,173.912 414.897,173.902 414.906,173.891 414.915,173.88 414.924,173.869 414.933,173.858 414.943,173.847 414.952,173.837 414.961,173.826 414.97,173.815 414.979,173.804 414.989,173.793 414.998,173.782 415.007,173.772 415.016,173.761 415.025,173.75 415.035,173.739 415.044,173.728 415.053,173.717 415.062,173.707 415.071,173.696 415.08,173.685 415.09,173.674 415.099,173.663 415.108,173.653 415.117,173.642 415.126,173.631 415.136,173.62 415.145,173.609 415.154,173.598 415.163,173.588 415.172,173.577 415.182,173.566 415.191,173.555 415.2,173.544 415.209,173.534 415.218,173.523 415.228,173.512 415.237,173.501 415.246,173.49 415.255,173.48 415.264,173.469 415.273,173.458 415.283,173.447 415.292,173.436 415.301,173.426 415.31,173.415 415.319,173.404 415.329,173.393 415.338,173.382 415.347,173.372 415.356,173.361 415.365,173.35 415.375,173.339 415.384,173.328 415.393,173.318 415.402,173.307 415.411,173.296 415.421,173.285 415.43,173.275 415.439,173.264 415.448,173.253 415.457,173.242 415.466,173.231 415.476,173.221 415.485,173.21 415.494,173.199 415.503,173.188 415.512,173.178 415.522,173.167 415.531,173.156 415.54,173.145 415.549,173.134 415.558,173.124 415.568,173.113 415.577,173.102 415.586,173.091 415.595,173.081 415.604,173.07 415.613,173.059 415.623,173.048 415.632,173.038 415.641,173.027 415.65,173.016 415.659,173.005 415.669,172.994 415.678,172.984 415.687,172.973 415.696,172.962 415.705,172.951 415.715,172.941 415.724,172.93 415.733,172.919 415.742,172.908 415.751,172.898 415.761,172.887 415.77,172.876 415.779,172.865 415.788,172.855 415.797,172.844 415.806,172.833 415.816,172.822 415.825,172.812 415.834,172.801 415.843,172.79 415.852,172.779 415.862,172.769 415.871,172.758 415.88,172.747 415.889,172.736 415.898,172.726 415.908,172.715 415.917,172.704 415.926,172.693 415.935,172.683 415.944,172.672 415.953,172.661 415.963,172.651 415.972,172.64 415.981,172.629 415.99,172.618 415.999,172.608 416.009,172.597 416.018,172.586 416.027,172.575 416.036,172.565 416.045,172.554 416.055,172.543 416.064,172.533 416.073,172.522 416.082,172.511 416.091,172.5 416.101,172.49 416.11,172.479 416.119,172.468 416.128,172.458 416.137,172.447 416.146,172.436 416.156,172.425 416.165,172.415 416.174,172.404 416.183,172.393 416.192,172.383 416.202,172.372 416.211,172.361 416.22,172.35 416.229,172.34 416.238,172.329 416.248,172.318 416.257,172.308 416.266,172.297 416.275,172.286 416.284,172.275 416.293,172.265 416.303,172.254 416.312,172.243 416.321,172.233 416.33,172.222 416.339,172.211 416.349,172.201 416.358,172.19 416.367,172.179 416.376,172.168 416.385,172.158 416.395,172.147 416.404,172.136 416.413,172.126 416.422,172.115 416.431,172.104 416.441,172.094 416.45,172.083 416.459,172.072 416.468,172.062 416.477,172.051 416.486,172.04 416.496,172.03 416.505,172.019 416.514,172.008 416.523,171.998 416.532,171.987 416.542,171.976 416.551,171.966 416.56,171.955 416.569,171.944 416.578,171.933 416.588,171.923 416.597,171.912 416.606,171.901 416.615,171.891 416.624,171.88 416.633,171.869 416.643,171.859 416.652,171.848 416.661,171.837 416.67,171.827 416.679,171.816 416.689,171.805 416.698,171.795 416.707,171.784 416.716,171.773 416.725,171.763 416.735,171.752 416.744,171.742 416.753,171.731 416.762,171.72 416.771,171.71 416.781,171.699 416.79,171.688 416.799,171.678 416.808,171.667 416.817,171.656 416.826,171.646 416.836,171.635 416.845,171.624 416.854,171.614 416.863,171.603 416.872,171.592 416.882,171.582 416.891,171.571 416.9,171.56 416.909,171.55 416.918,171.539 416.928,171.529 416.937,171.518 416.946,171.507 416.955,171.497 416.964,171.486 416.973,171.475 416.983,171.465 416.992,171.454 417.001,171.443 417.01,171.433 417.019,171.422 417.029,171.412 417.038,171.401 417.047,171.39 417.056,171.38 417.065,171.369 417.075,171.358 417.084,171.348 417.093,171.337 417.102,171.327 417.111,171.316 417.121,171.305 417.13,171.295 417.139,171.284 417.148,171.274 417.157,171.263 417.166,171.252 417.176,171.242 417.185,171.231 417.194,171.22 417.203,171.21 417.212,171.199 417.222,171.189 417.231,171.178 417.24,171.167 417.249,171.157 417.258,171.146 417.268,171.136 417.277,171.125 417.286,171.114 417.295,171.104 417.304,171.093 417.313,171.083 417.323,171.072 417.332,171.061 417.341,171.051 417.35,171.04 417.359,171.03 417.369,171.019 417.378,171.008 417.387,170.998 417.396,170.987 417.405,170.977 417.415,170.966 417.424,170.955 417.433,170.945 417.442,170.934 417.451,170.924 417.461,170.913 417.47,170.902 417.479,170.892 417.488,170.881 417.497,170.871 417.506,170.86 417.516,170.85 417.525,170.839 417.534,170.828 417.543,170.818 417.552,170.807 417.562,170.797 417.571,170.786 417.58,170.776 417.589,170.765 417.598,170.754 417.608,170.744 417.617,170.733 417.626,170.723 417.635,170.712 417.644,170.702 417.653,170.691 417.663,170.68 417.672,170.67 417.681,170.659 417.69,170.649 417.699,170.638 417.709,170.628 417.718,170.617 417.727,170.606 417.736,170.596 417.745,170.585 417.755,170.575 417.764,170.564 417.773,170.554 417.782,170.543 417.791,170.533 417.801,170.522 417.81,170.511 417.819,170.501 417.828,170.49 417.837,170.48 417.846,170.469 417.856,170.459 417.865,170.448 417.874,170.438 417.883,170.427 417.892,170.416 417.902,170.406 417.911,170.395 417.92,170.385 417.929,170.374 417.938,170.364 417.948,170.353 417.957,170.343 417.966,170.332 417.975,170.322 417.984,170.311 417.994,170.301 418.003,170.29 418.012,170.279 418.021,170.269 418.03,170.258 418.039,170.248 418.049,170.237 418.058,170.227 418.067,170.216 418.076,170.206 418.085,170.195 418.095,170.185 418.104,170.174 418.113,170.164 418.122,170.153 418.131,170.143 418.141,170.132 418.15,170.122 418.159,170.111 418.168,170.101 418.177,170.09 418.186,170.08 418.196,170.069 418.205,170.059 418.214,170.048 418.223,170.037 418.232,170.027 418.242,170.016 418.251,170.006 418.26,169.995 418.269,169.985 418.278,169.974 418.288,169.964 418.297,169.953 418.306,169.943 418.315,169.932 418.324,169.922 418.334,169.911 418.343,169.901 418.352,169.89 418.361,169.88 418.37,169.869 418.379,169.859 418.389,169.848 418.398,169.838 418.407,169.827 418.416,169.817 418.425,169.806 418.435,169.796 418.444,169.785 418.453,169.775 418.462,169.764 418.471,169.754 418.481,169.743 418.49,169.733 418.499,169.723 418.508,169.712 418.517,169.702 418.526,169.691 418.536,169.681 418.545,169.67 418.554,169.66 418.563,169.649 418.572,169.639 418.582,169.628 418.591,169.618 418.6,169.607 418.609,169.597 418.618,169.586 418.628,169.576 418.637,169.565 418.646,169.555 418.655,169.544 418.664,169.534 418.674,169.523 418.683,169.513 418.692,169.503 418.701,169.492 418.71,169.482 418.719,169.471 418.729,169.461 418.738,169.45 418.747,169.44 418.756,169.429 418.765,169.419 418.775,169.408 418.784,169.398 418.793,169.387 418.802,169.377 418.811,169.367 418.821,169.356 418.83,169.346 418.839,169.335 418.848,169.325 418.857,169.314 418.866,169.304 418.876,169.293 418.885,169.283 418.894,169.273 418.903,169.262 418.912,169.252 418.922,169.241 418.931,169.231 418.94,169.22 418.949,169.21 418.958,169.199 418.968,169.189 418.977,169.179 418.986,169.168 418.995,169.158 419.004,169.147 419.014,169.137 419.023,169.126 419.032,169.116 419.041,169.105 419.05,169.095 419.059,169.085 419.069,169.074 419.078,169.064 419.087,169.053 419.096,169.043 419.105,169.032 419.115,169.022 419.124,169.012 419.133,169.001 419.142,168.991 419.151,168.98 419.161,168.97 419.17,168.96 419.179,168.949 419.188,168.939 419.197,168.928 419.206,168.918 419.216,168.907 419.225,168.897 419.234,168.887 419.243,168.876 419.252,168.866 419.262,168.855 419.271,168.845 419.28,168.835 419.289,168.824 419.298,168.814 419.308,168.803 419.317,168.793 419.326,168.783 419.335,168.772 419.344,168.762 419.354,168.751 419.363,168.741 419.372,168.731 419.381,168.72 419.39,168.71 419.399,168.699 419.409,168.689 419.418,168.679 419.427,168.668 419.436,168.658 419.445,168.647 419.455,168.637 419.464,168.627 419.473,168.616 419.482,168.606 419.491,168.595 419.501,168.585 419.51,168.575 419.519,168.564 419.528,168.554 419.537,168.543 419.546,168.533 419.556,168.523 419.565,168.512 419.574,168.502 419.583,168.492 419.592,168.481 419.602,168.471 419.611,168.46 419.62,168.45 419.629,168.44 419.638,168.429 419.648,168.419 419.657,168.409 419.666,168.398 419.675,168.388 419.684,168.377 419.694,168.367 419.703,168.357 419.712,168.346 419.721,168.336 419.73,168.326 419.739,168.315 419.749,168.305 419.758,168.295 419.767,168.284 419.776,168.274 419.785,168.263 419.795,168.253 419.804,168.243 419.813,168.232 419.822,168.222 419.831,168.212 419.841,168.201 419.85,168.191 419.859,168.181 419.868,168.17 419.877,168.16 419.886,168.15 419.896,168.139 419.905,168.129 419.914,168.119 419.923,168.108 419.932,168.098 419.942,168.087 419.951,168.077 419.96,168.067 419.969,168.056 419.978,168.046 419.988,168.036 419.997,168.025 420.006,168.015 420.015,168.005 420.024,167.994 420.034,167.984 420.043,167.974 420.052,167.963 420.061,167.953 420.07,167.943 420.079,167.932 420.089,167.922 420.098,167.912 420.107,167.901 420.116,167.891 420.125,167.881 420.135,167.87 420.144,167.86 420.153,167.85 420.162,167.839 420.171,167.829 420.181,167.819 420.19,167.809 420.199,167.798 420.208,167.788 420.217,167.778 420.226,167.767 420.236,167.757 420.245,167.747 420.254,167.736 420.263,167.726 420.272,167.716 420.282,167.705 420.291,167.695 420.3,167.685 420.309,167.674 420.318,167.664 420.328,167.654 420.337,167.644 420.346,167.633 420.355,167.623 420.364,167.613 420.374,167.602 420.383,167.592 420.392,167.582 420.401,167.571 420.41,167.561 420.419,167.551 420.429,167.541 420.438,167.53 420.447,167.52 420.456,167.51 420.465,167.499 420.475,167.489 420.484,167.479 420.493,167.468 420.502,167.458 420.511,167.448 420.521,167.438 420.53,167.427 420.539,167.417 420.548,167.407 420.557,167.396 420.567,167.386 420.576,167.376 420.585,167.366 420.594,167.355 420.603,167.345 420.612,167.335 420.622,167.324 420.631,167.314 420.64,167.304 420.649,167.294 420.658,167.283 420.668,167.273 420.677,167.263 420.686,167.253 420.695,167.242 420.704,167.232 420.714,167.222 420.723,167.211 420.732,167.201 420.741,167.191 420.75,167.181 420.759,167.17 420.769,167.16 420.778,167.15 420.787,167.14 420.796,167.129 420.805,167.119 420.815,167.109 420.824,167.099 420.833,167.088 420.842,167.078 420.851,167.068 420.861,167.058 420.87,167.047 420.879,167.037 420.888,167.027 420.897,167.017 420.907,167.006 420.916,166.996 420.925,166.986 420.934,166.976 420.943,166.965 420.952,166.955 420.962,166.945 420.971,166.935 420.98,166.924 420.989,166.914 420.998,166.904 421.008,166.894 421.017,166.883 421.026,166.873 421.035,166.863 421.044,166.853 421.054,166.842 421.063,166.832 421.072,166.822 421.081,166.812 421.09,166.802 421.099,166.791 421.109,166.781 421.118,166.771 421.127,166.761 421.136,166.75 421.145,166.74 421.155,166.73 421.164,166.72 421.173,166.709 421.182,166.699 421.191,166.689 421.201,166.679 421.21,166.669 421.219,166.658 421.228,166.648 421.237,166.638 421.247,166.628 421.256,166.617 421.265,166.607 421.274,166.597 421.283,166.587 421.292,166.577 421.302,166.566 421.311,166.556 421.32,166.546 421.329,166.536 421.338,166.526 421.348,166.515 421.357,166.505 421.366,166.495 421.375,166.485 421.384,166.475 421.394,166.464 421.403,166.454 421.412,166.444 421.421,166.434 421.43,166.424 421.439,166.413 421.449,166.403 421.458,166.393 421.467,166.383 421.476,166.373 421.485,166.362 421.495,166.352 421.504,166.342 421.513,166.332 421.522,166.322 421.531,166.311 421.541,166.301 421.55,166.291 421.559,166.281 421.568,166.271 421.577,166.261 421.587,166.25 421.596,166.24 421.605,166.23 421.614,166.22 421.623,166.21 421.632,166.199 421.642,166.189 421.651,166.179 421.66,166.169 421.669,166.159 421.678,166.149 421.688,166.138 421.697,166.128 421.706,166.118 421.715,166.108 421.724,166.098 421.734,166.088 421.743,166.077 421.752,166.067 421.761,166.057 421.77,166.047 421.779,166.037 421.789,166.027 421.798,166.016 421.807,166.006 421.816,165.996 421.825,165.986 421.835,165.976 421.844,165.966 421.853,165.955 421.862,165.945 421.871,165.935 421.881,165.925 421.89,165.915 421.899,165.905 421.908,165.894 421.917,165.884 421.927,165.874 421.936,165.864 421.945,165.854 421.954,165.844 421.963,165.834 421.972,165.823 421.982,165.813 421.991,165.803 422,165.793 422.009,165.783 422.018,165.773 422.028,165.763 422.037,165.752 422.046,165.742 422.055,165.732 422.064,165.722 422.074,165.712 422.083,165.702 422.092,165.692 422.101,165.681 422.11,165.671 422.119,165.661 422.129,165.651 422.138,165.641 422.147,165.631 422.156,165.621 422.165,165.611 422.175,165.6 422.184,165.59 422.193,165.58 422.202,165.57 422.211,165.56 422.221,165.55 422.23,165.54 422.239,165.53 422.248,165.519 422.257,165.509 422.267,165.499 422.276,165.489 422.285,165.479 422.294,165.469 422.303,165.459 422.312,165.449 422.322,165.439 422.331,165.428 422.34,165.418 422.349,165.408 422.358,165.398 422.368,165.388 422.377,165.378 422.386,165.368 422.395,165.358 422.404,165.348 422.414,165.337 422.423,165.327 422.432,165.317 422.441,165.307 422.45,165.297 422.459,165.287 422.469,165.277 422.478,165.267 422.487,165.257 422.496,165.247 422.505,165.237 422.515,165.226 422.524,165.216 422.533,165.206 422.542,165.196 422.551,165.186 422.561,165.176 422.57,165.166 422.579,165.156 422.588,165.146 422.597,165.136 422.607,165.126 422.616,165.115 422.625,165.105 422.634,165.095 422.643,165.085 422.652,165.075 422.662,165.065 422.671,165.055 422.68,165.045 422.689,165.035 422.698,165.025 422.708,165.015 422.717,165.005 422.726,164.995 422.735,164.984 422.744,164.974 422.754,164.964 422.763,164.954 422.772,164.944 422.781,164.934 422.79,164.924 422.8,164.914 422.809,164.904 422.818,164.894 422.827,164.884 422.836,164.874 422.845,164.864 422.855,164.854 422.864,164.844 422.873,164.833 422.882,164.823 422.891,164.813 422.901,164.803 422.91,164.793 422.919,164.783 422.928,164.773 422.937,164.763 422.947,164.753 422.956,164.743 422.965,164.733 422.974,164.723 422.983,164.713 422.992,164.703 423.002,164.693 423.011,164.683 423.02,164.673 423.029,164.663 423.038,164.653 423.048,164.643 423.057,164.633 423.066,164.622 423.075,164.612 423.084,164.602 423.094,164.592 423.103,164.582 423.112,164.572 423.121,164.562 423.13,164.552 423.14,164.542 423.149,164.532 423.158,164.522 423.167,164.512 423.176,164.502 423.185,164.492 423.195,164.482 423.204,164.472 423.213,164.462 423.222,164.452 423.231,164.442 423.241,164.432 423.25,164.422 423.259,164.412 423.268,164.402 423.277,164.392 423.287,164.382 423.296,164.372 423.305,164.362 423.314,164.352 423.323,164.342 423.332,164.332 423.342,164.322 423.351,164.312 423.36,164.302 423.369,164.292 423.378,164.282 423.388,164.272 423.397,164.262 423.406,164.252 423.415,164.242 423.424,164.232 423.434,164.222 423.443,164.212 423.452,164.202 423.461,164.192 423.47,164.182 423.48,164.172 423.489,164.162 423.498,164.152 423.507,164.142 423.516,164.132 423.525,164.122 423.535,164.112 423.544,164.102 423.553,164.092 423.562,164.082 423.571,164.072 423.581,164.062 423.59,164.052 423.599,164.042 423.608,164.032 423.617,164.022 423.627,164.012 423.636,164.002 423.645,163.992 423.654,163.982 423.663,163.972 423.672,163.962 423.682,163.952 423.691,163.942 423.7,163.932 423.709,163.922 423.718,163.912 423.728,163.902 423.737,163.892 423.746,163.882 423.755,163.872 423.764,163.862 423.774,163.852 423.783,163.842 423.792,163.832 423.801,163.822 423.81,163.812 423.82,163.802 423.829,163.792 423.838,163.782 423.847,163.772 423.856,163.762 423.865,163.753 423.875,163.743 423.884,163.733 423.893,163.723 423.902,163.713 423.911,163.703 423.921,163.693 423.93,163.683 423.939,163.673 423.948,163.663 423.957,163.653 423.967,163.643 423.976,163.633 423.985,163.623 423.994,163.613 424.003,163.603 424.012,163.593 424.022,163.583 424.031,163.573 424.04,163.563 424.049,163.553 424.058,163.544 424.068,163.534 424.077,163.524 424.086,163.514 424.095,163.504 424.104,163.494 424.114,163.484 424.123,163.474 424.132,163.464 424.141,163.454 424.15,163.444 424.16,163.434 424.169,163.424 424.178,163.414 424.187,163.404 424.196,163.395 424.205,163.385 424.215,163.375 424.224,163.365 424.233,163.355 424.242,163.345 424.251,163.335 424.261,163.325 424.27,163.315 424.279,163.305 424.288,163.295 424.297,163.285 424.307,163.275 424.316,163.266 424.325,163.256 424.334,163.246 424.343,163.236 424.352,163.226 424.362,163.216 424.371,163.206 424.38,163.196 424.389,163.186 424.398,163.176 424.408,163.166 424.417,163.156 424.426,163.147 424.435,163.137 424.444,163.127 424.454,163.117 424.463,163.107 424.472,163.097 424.481,163.087 424.49,163.077 424.5,163.067 424.509,163.057 424.518,163.048 424.527,163.038 424.536,163.028 424.545,163.018 424.555,163.008 424.564,162.998 424.573,162.988 424.582,162.978 424.591,162.968 424.601,162.959 424.61,162.949 424.619,162.939 424.628,162.929 424.637,162.919 424.647,162.909 424.656,162.899 424.665,162.889 424.674,162.879 424.683,162.87 424.692,162.86 424.702,162.85 424.711,162.84 424.72,162.83 424.729,162.82 424.738,162.81 424.748,162.8 424.757,162.791 424.766,162.781 424.775,162.771 424.784,162.761 424.794,162.751 424.803,162.741 424.812,162.731 424.821,162.721 424.83,162.712 424.84,162.702 424.849,162.692 424.858,162.682 424.867,162.672 424.876,162.662 424.885,162.652 424.895,162.643 424.904,162.633 424.913,162.623 424.922,162.613 424.931,162.603 424.941,162.593 424.95,162.583 424.959,162.574 424.968,162.564 424.977,162.554 424.987,162.544 424.996,162.534 425.005,162.524 425.014,162.514 425.023,162.505 425.032,162.495 425.042,162.485 425.051,162.475 425.06,162.465 425.069,162.455 425.078,162.445 425.088,162.436 425.097,162.426 425.106,162.416 425.115,162.406 425.124,162.396 425.134,162.386 425.143,162.377 425.152,162.367 425.161,162.357 425.17,162.347 425.18,162.337 425.189,162.327 425.198,162.318 425.207,162.308 425.216,162.298 425.225,162.288 425.235,162.278 425.244,162.268 425.253,162.259 425.262,162.249 425.271,162.239 425.281,162.229 425.29,162.219 425.299,162.21 425.308,162.2 425.317,162.19 425.327,162.18 425.336,162.17 425.345,162.16 425.354,162.151 425.363,162.141 425.373,162.131 425.382,162.121 425.391,162.111 425.4,162.102 425.409,162.092 425.418,162.082 425.428,162.072 425.437,162.062 425.446,162.052 425.455,162.043 425.464,162.033 425.474,162.023 425.483,162.013 425.492,162.003 425.501,161.994 425.51,161.984 425.52,161.974 425.529,161.964 425.538,161.954 425.547,161.945 425.556,161.935 425.565,161.925 425.575,161.915 425.584,161.905 425.593,161.896 425.602,161.886 425.611,161.876 425.621,161.866 425.63,161.857 425.639,161.847 425.648,161.837 425.657,161.827 425.667,161.817 425.676,161.808 425.685,161.798 425.694,161.788 425.703,161.778 425.713,161.768 425.722,161.759 425.731,161.749 425.74,161.739 425.749,161.729 425.758,161.72 425.768,161.71 425.777,161.7 425.786,161.69 425.795,161.68 425.804,161.671 425.814,161.661 425.823,161.651 425.832,161.641 425.841,161.632 425.85,161.622 425.86,161.612 425.869,161.602 425.878,161.593 425.887,161.583 425.896,161.573 425.905,161.563 425.915,161.553 425.924,161.544 425.933,161.534 425.942,161.524 425.951,161.514 425.961,161.505 425.97,161.495 425.979,161.485 425.988,161.475 425.997,161.466 426.007,161.456 426.016,161.446 426.025,161.436 426.034,161.427 426.043,161.417 426.053,161.407 426.062,161.397 426.071,161.388 426.08,161.378 426.089,161.368 426.098,161.358 426.108,161.349 426.117,161.339 426.126,161.329 426.135,161.319 426.144,161.31 426.154,161.3 426.163,161.29 426.172,161.28 426.181,161.271 426.19,161.261 426.2,161.251 426.209,161.242 426.218,161.232 426.227,161.222 426.236,161.212 426.245,161.203 426.255,161.193 426.264,161.183 426.273,161.173 426.282,161.164 426.291,161.154 426.301,161.144 426.31,161.135 426.319,161.125 426.328,161.115 426.337,161.105 426.347,161.096 426.356,161.086 426.365,161.076 426.374,161.066 426.383,161.057 426.393,161.047 426.402,161.037 426.411,161.028 426.42,161.018 426.429,161.008 426.438,160.998 426.448,160.989 426.457,160.979 426.466,160.969 426.475,160.96 426.484,160.95 426.494,160.94 426.503,160.931 426.512,160.921 426.521,160.911 426.53,160.901 426.54,160.892 426.549,160.882 426.558,160.872 426.567,160.863 426.576,160.853 426.585,160.843 426.595,160.834 426.604,160.824 426.613,160.814 426.622,160.804 426.631,160.795 426.641,160.785 426.65,160.775 426.659,160.766 426.668,160.756 426.677,160.746 426.687,160.737 426.696,160.727 426.705,160.717 426.714,160.708 426.723,160.698 426.733,160.688 426.742,160.679 426.751,160.669 426.76,160.659 426.769,160.649 426.778,160.64 426.788,160.63 426.797,160.62 426.806,160.611 426.815,160.601 426.824,160.591 426.834,160.582 426.843,160.572 426.852,160.562 426.861,160.553 426.87,160.543 426.88,160.533 426.889,160.524 426.898,160.514 426.907,160.504 426.916,160.495 426.925,160.485 426.935,160.475 426.944,160.466 426.953,160.456 426.962,160.446 426.971,160.437 426.981,160.427 426.99,160.417 426.999,160.408 427.008,160.398 427.017,160.388 427.027,160.379 427.036,160.369 427.045,160.36 427.054,160.35 427.063,160.34 427.073,160.331 427.082,160.321 427.091,160.311 427.1,160.302 427.109,160.292 427.118,160.282 427.128,160.273 427.137,160.263 427.146,160.253 427.155,160.244 427.164,160.234 427.174,160.224 427.183,160.215 427.192,160.205 427.201,160.196 427.21,160.186 427.22,160.176 427.229,160.167 427.238,160.157 427.247,160.147 427.256,160.138 427.265,160.128 427.275,160.118 427.284,160.109 427.293,160.099 427.302,160.09 427.311,160.08 427.321,160.07 427.33,160.061 427.339,160.051 427.348,160.041 427.357,160.032 427.367,160.022 427.376,160.013 427.385,160.003 427.394,159.993 427.403,159.984 427.413,159.974 427.422,159.964 427.431,159.955 427.44,159.945 427.449,159.936 427.458,159.926 427.468,159.916 427.477,159.907 427.486,159.897 427.495,159.888 427.504,159.878 427.514,159.868 427.523,159.859 427.532,159.849 427.541,159.84 427.55,159.83 427.56,159.82 427.569,159.811 427.578,159.801 427.587,159.792 427.596,159.782 427.605,159.772 427.615,159.763 427.624,159.753 427.633,159.744 427.642,159.734 427.651,159.724 427.661,159.715 427.67,159.705 427.679,159.696 427.688,159.686 427.697,159.676 427.707,159.667 427.716,159.657 427.725,159.648 427.734,159.638 427.743,159.628 427.753,159.619 427.762,159.609 427.771,159.6 427.78,159.59 427.789,159.581 427.798,159.571 427.808,159.561 427.817,159.552 427.826,159.542 427.835,159.533 427.844,159.523 427.854,159.514 427.863,159.504 427.872,159.494 427.881,159.485 427.89,159.475 427.9,159.466 427.909,159.456 427.918,159.447 427.927,159.437 427.936,159.427 427.946,159.418 427.955,159.408 427.964,159.399 427.973,159.389 427.982,159.38 427.991,159.37 428.001,159.36 428.01,159.351 428.019,159.341 428.028,159.332 428.037,159.322 428.047,159.313 428.056,159.303 428.065,159.294 428.074,159.284 428.083,159.274 428.093,159.265 428.102,159.255 428.111,159.246 428.12,159.236 428.129,159.227 428.138,159.217 428.148,159.208 428.157,159.198 428.166,159.188 428.175,159.179 428.184,159.169 428.194,159.16 428.203,159.15 428.212,159.141 428.221,159.131 428.23,159.122 428.24,159.112 428.249,159.103 428.258,159.093 428.267,159.084 428.276,159.074 428.286,159.064 428.295,159.055 428.304,159.045 428.313,159.036 428.322,159.026 428.331,159.017 428.341,159.007 428.35,158.998 428.359,158.988 428.368,158.979 428.377,158.969 428.387,158.96 428.396,158.95 428.405,158.941 428.414,158.931 428.423,158.922 428.433,158.912 428.442,158.903 428.451,158.893 428.46,158.884 428.469,158.874 428.478,158.864 428.488,158.855 428.497,158.845 428.506,158.836 428.515,158.826 428.524,158.817 428.534,158.807 428.543,158.798 428.552,158.788 428.561,158.779 428.57,158.769 428.58,158.76 428.589,158.75 428.598,158.741 428.607,158.731 428.616,158.722 428.626,158.712 428.635,158.703 428.644,158.693 428.653,158.684 428.662,158.674 428.671,158.665 428.681,158.655 428.69,158.646 428.699,158.636 428.708,158.627 428.717,158.617 428.727,158.608 428.736,158.598 428.745,158.589 428.754,158.579 428.763,158.57 428.773,158.56 428.782,158.551 428.791,158.542 428.8,158.532 428.809,158.523 428.818,158.513 428.828,158.504 428.837,158.494 428.846,158.485 428.855,158.475 428.864,158.466 428.874,158.456 428.883,158.447 428.892,158.437 428.901,158.428 428.91,158.418 428.92,158.409 428.929,158.399 428.938,158.39 428.947,158.38 428.956,158.371 428.966,158.361 428.975,158.352 428.984,158.343 428.993,158.333 429.002,158.324 429.011,158.314 429.021,158.305 429.03,158.295 429.039,158.286 429.048,158.276 429.057,158.267 429.067,158.257 429.076,158.248 429.085,158.238 429.094,158.229 429.103,158.22 429.113,158.21 429.122,158.201 429.131,158.191 429.14,158.182 429.149,158.172 429.158,158.163 429.168,158.153 429.177,158.144 429.186,158.134 429.195,158.125 429.204,158.116 429.214,158.106 429.223,158.097 429.232,158.087 429.241,158.078 429.25,158.068 429.26,158.059 429.269,158.049 429.278,158.04 429.287,158.031 429.296,158.021 429.306,158.012 429.315,158.002 429.324,157.993 429.333,157.983 429.342,157.974 429.351,157.965 429.361,157.955 429.37,157.946 429.379,157.936 429.388,157.927 429.397,157.917 429.407,157.908 429.416,157.899 429.425,157.889 429.434,157.88 429.443,157.87 429.453,157.861 429.462,157.851 429.471,157.842 429.48,157.833 429.489,157.823 429.498,157.814 429.508,157.804 429.517,157.795 429.526,157.786 429.535,157.776 429.544,157.767 429.554,157.757 429.563,157.748 429.572,157.738 429.581,157.729 429.59,157.72 429.6,157.71 429.609,157.701 429.618,157.691 429.627,157.682 429.636,157.673 429.646,157.663 429.655,157.654 429.664,157.644 429.673,157.635 429.682,157.626 429.691,157.616 429.701,157.607 429.71,157.597 429.719,157.588 429.728,157.579 429.737,157.569 429.747,157.56 429.756,157.55 429.765,157.541 429.774,157.532 429.783,157.522 429.793,157.513 429.802,157.504 429.811,157.494 429.82,157.485 429.829,157.475 429.838,157.466 429.848,157.457 429.857,157.447 429.866,157.438 429.875,157.428 429.884,157.419 429.894,157.41 429.903,157.4 429.912,157.391 429.921,157.382 429.93,157.372 429.94,157.363 429.949,157.353 429.958,157.344 429.967,157.335 429.976,157.325 429.986,157.316 429.995,157.307 430.004,157.297 430.013,157.288 430.022,157.278 430.031,157.269 430.041,157.26 430.05,157.25 430.059,157.241 430.068,157.232 430.077,157.222 430.087,157.213 430.096,157.204 430.105,157.194 430.114,157.185 430.123,157.175 430.133,157.166 430.142,157.157 430.151,157.147 430.16,157.138 430.169,157.129 430.179,157.119 430.188,157.11 430.197,157.101 430.206,157.091 430.215,157.082 430.224,157.073 430.234,157.063 430.243,157.054 430.252,157.045 430.261,157.035 430.27,157.026 430.28,157.017 430.289,157.007 430.298,156.998 430.307,156.989 430.316,156.979 430.326,156.97 430.335,156.961 430.344,156.951 430.353,156.942 430.362,156.933 430.371,156.923 430.381,156.914 430.39,156.905 430.399,156.895 430.408,156.886 430.417,156.877 430.427,156.867 430.436,156.858 430.445,156.849 430.454,156.839 430.463,156.83 430.473,156.821 430.482,156.811 430.491,156.802 430.5,156.793 430.509,156.783 430.519,156.774 430.528,156.765 430.537,156.755 430.546,156.746 430.555,156.737 430.564,156.727 430.574,156.718 430.583,156.709 430.592,156.699 430.601,156.69 430.61,156.681 430.62,156.671 430.629,156.662 430.638,156.653 430.647,156.644 430.656,156.634 430.666,156.625 430.675,156.616 430.684,156.606 430.693,156.597 430.702,156.588 430.711,156.578 430.721,156.569 430.73,156.56 430.739,156.551 430.748,156.541 430.757,156.532 430.767,156.523 430.776,156.513 430.785,156.504 430.794,156.495 430.803,156.485 430.813,156.476 430.822,156.467 430.831,156.458 430.84,156.448 430.849,156.439 430.859,156.43 430.868,156.42 430.877,156.411 430.886,156.402 430.895,156.393 430.904,156.383 430.914,156.374 430.923,156.365 430.932,156.355 430.941,156.346 430.95,156.337 430.96,156.328 430.969,156.318 430.978,156.309 430.987,156.3 430.996,156.291 431.006,156.281 431.015,156.272 431.024,156.263 431.033,156.253 431.042,156.244 431.051,156.235 431.061,156.226 431.07,156.216 431.079,156.207 431.088,156.198 431.097,156.189 431.107,156.179 431.116,156.17 431.125,156.161 431.134,156.152 431.143,156.142 431.153,156.133 431.162,156.124 431.171,156.114 431.18,156.105 431.189,156.096 431.199,156.087 431.208,156.077 431.217,156.068 431.226,156.059 431.235,156.05 431.244,156.04 431.254,156.031 431.263,156.022 431.272,156.013 431.281,156.003 431.29,155.994 431.3,155.985 431.309,155.976 431.318,155.966 431.327,155.957 431.336,155.948 431.346,155.939 431.355,155.929 431.364,155.92 431.373,155.911 431.382,155.902 431.391,155.893 431.401,155.883 431.41,155.874 431.419,155.865 431.428,155.856 431.437,155.846 431.447,155.837 431.456,155.828 431.465,155.819 431.474,155.809 431.483,155.8 431.493,155.791 431.502,155.782 431.511,155.773 431.52,155.763 431.529,155.754 431.539,155.745 431.548,155.736 431.557,155.726 431.566,155.717 431.575,155.708 431.584,155.699 431.594,155.69 431.603,155.68 431.612,155.671 431.621,155.662 431.63,155.653 431.64,155.643 431.649,155.634 431.658,155.625 431.667,155.616 431.676,155.607 431.686,155.597 431.695,155.588 431.704,155.579 431.713,155.57 431.722,155.561 431.731,155.551 431.741,155.542 431.75,155.533 431.759,155.524 431.768,155.515 431.777,155.505 431.787,155.496 431.796,155.487 431.805,155.478 431.814,155.469 431.823,155.459 431.833,155.45 431.842,155.441 431.851,155.432 431.86,155.423 431.869,155.413 431.879,155.404 431.888,155.395 431.897,155.386 431.906,155.377 431.915,155.367 431.924,155.358 431.934,155.349 431.943,155.34 431.952,155.331 431.961,155.322 431.97,155.312 431.98,155.303 431.989,155.294 431.998,155.285 432.007,155.276 432.016,155.266 432.026,155.257 432.035,155.248 432.044,155.239 432.053,155.23 432.062,155.221 432.071,155.211 432.081,155.202 432.09,155.193 432.099,155.184 432.108,155.175 432.117,155.166 432.127,155.156 432.136,155.147 432.145,155.138 432.154,155.129 432.163,155.12 432.173,155.111 432.182,155.101 432.191,155.092 432.2,155.083 432.209,155.074 432.219,155.065 432.228,155.056 432.237,155.046 432.246,155.037 432.255,155.028 432.264,155.019 432.274,155.01 432.283,155.001 432.292,154.992 432.301,154.982 432.31,154.973 432.32,154.964 432.329,154.955 432.338,154.946 432.347,154.937 432.356,154.927 432.366,154.918 432.375,154.909 432.384,154.9 432.393,154.891 432.402,154.882 432.411,154.873 432.421,154.863 432.43,154.854 432.439,154.845 432.448,154.836 432.457,154.827 432.467,154.818 432.476,154.809 432.485,154.8 432.494,154.79 432.503,154.781 432.513,154.772 432.522,154.763 432.531,154.754 432.54,154.745 432.549,154.736 432.559,154.727 432.568,154.717 432.577,154.708 432.586,154.699 432.595,154.69 432.604,154.681 432.614,154.672 432.623,154.663 432.632,154.654 432.641,154.644 432.65,154.635 432.66,154.626 432.669,154.617 432.678,154.608 432.687,154.599 432.696,154.59 432.706,154.581 432.715,154.571 432.724,154.562 432.733,154.553 432.742,154.544 432.752,154.535 432.761,154.526 432.77,154.517 432.779,154.508 432.788,154.499 432.797,154.49 432.807,154.48 432.816,154.471 432.825,154.462 432.834,154.453 432.843,154.444 432.853,154.435 432.862,154.426 432.871,154.417 432.88,154.408 432.889,154.399 432.899,154.389 432.908,154.38 432.917,154.371 432.926,154.362 432.935,154.353 432.944,154.344 432.954,154.335 432.963,154.326 432.972,154.317 432.981,154.308 432.99,154.299 433,154.289 433.009,154.28 433.018,154.271 433.027,154.262 433.036,154.253 433.046,154.244 433.055,154.235 433.064,154.226 433.073,154.217 433.082,154.208 433.092,154.199 433.101,154.19 433.11,154.18 433.119,154.171 433.128,154.162 433.137,154.153 433.147,154.144 433.156,154.135 433.165,154.126 433.174,154.117 433.183,154.108 433.193,154.099 433.202,154.09 433.211,154.081 433.22,154.072 433.229,154.063 433.239,154.054 433.248,154.044 433.257,154.035 433.266,154.026 433.275,154.017 433.284,154.008 433.294,153.999 433.303,153.99 433.312,153.981 433.321,153.972 433.33,153.963 433.34,153.954 433.349,153.945 433.358,153.936 433.367,153.927 433.376,153.918 433.386,153.909 433.395,153.9 433.404,153.891 433.413,153.882 433.422,153.872 433.432,153.863 433.441,153.854 433.45,153.845 433.459,153.836 433.468,153.827 433.477,153.818 433.487,153.809 433.496,153.8 433.505,153.791 433.514,153.782 433.523,153.773 433.533,153.764 433.542,153.755 433.551,153.746 433.56,153.737 433.569,153.728 433.579,153.719 433.588,153.71 433.597,153.701 433.606,153.692 433.615,153.683 433.624,153.674 433.634,153.665 433.643,153.656 433.652,153.647 433.661,153.638 433.67,153.629 433.68,153.62 433.689,153.611 433.698,153.601 433.707,153.592 433.716,153.583 433.726,153.574 433.735,153.565 433.744,153.556 433.753,153.547 433.762,153.538 433.772,153.529 433.781,153.52 433.79,153.511 433.799,153.502 433.808,153.493 433.817,153.484 433.827,153.475 433.836,153.466 433.845,153.457 433.854,153.448 433.863,153.439 433.873,153.43 433.882,153.421 433.891,153.412 433.9,153.403 433.909,153.394 433.919,153.385 433.928,153.376 433.937,153.367 433.946,153.358 433.955,153.349 433.964,153.34 433.974,153.331 433.983,153.322 433.992,153.313 434.001,153.304 434.01,153.295 434.02,153.286 434.029,153.277 434.038,153.268 434.047,153.259 434.056,153.25 434.066,153.241 434.075,153.232 434.084,153.223 434.093,153.214 434.102,153.205 434.112,153.197 434.121,153.188 434.13,153.179 434.139,153.17 434.148,153.161 434.157,153.152 434.167,153.143 434.176,153.134 434.185,153.125 434.194,153.116 434.203,153.107 434.213,153.098 434.222,153.089 434.231,153.08 434.24,153.071 434.249,153.062 434.259,153.053 434.268,153.044 434.277,153.035 434.286,153.026 434.295,153.017 434.304,153.008 434.314,152.999 434.323,152.99 434.332,152.981 434.341,152.972 434.35,152.963 434.36,152.954 434.369,152.945 434.378,152.936 434.387,152.927 434.396,152.919 434.406,152.91 434.415,152.901 434.424,152.892 434.433,152.883 434.442,152.874 434.452,152.865 434.461,152.856 434.47,152.847 434.479,152.838 434.488,152.829 434.497,152.82 434.507,152.811 434.516,152.802 434.525,152.793 434.534,152.784 434.543,152.775 434.553,152.766 434.562,152.757 434.571,152.749 434.58,152.74 434.589,152.731 434.599,152.722 434.608,152.713 434.617,152.704 434.626,152.695 434.635,152.686 434.644,152.677 434.654,152.668 434.663,152.659 434.672,152.65 434.681,152.641 434.69,152.632 434.7,152.624 434.709,152.615 434.718,152.606 434.727,152.597 434.736,152.588 434.746,152.579 434.755,152.57 434.764,152.561 434.773,152.552 434.782,152.543 434.792,152.534 434.801,152.525 434.81,152.516 434.819,152.508 434.828,152.499 434.837,152.49 434.847,152.481 434.856,152.472 434.865,152.463 434.874,152.454 434.883,152.445 434.893,152.436 434.902,152.427 434.911,152.418 434.92,152.41 434.929,152.401 434.939,152.392 434.948,152.383 434.957,152.374 434.966,152.365 434.975,152.356 434.984,152.347 434.994,152.338 435.003,152.329 435.012,152.321 435.021,152.312 435.03,152.303 435.04,152.294 435.049,152.285 435.058,152.276 435.067,152.267 435.076,152.258 435.086,152.249 435.095,152.24 435.104,152.232 435.113,152.223 435.122,152.214 435.132,152.205 435.141,152.196 435.15,152.187 435.159,152.178 435.168,152.169 435.177,152.161 435.187,152.152 435.196,152.143 435.205,152.134 435.214,152.125 435.223,152.116 435.233,152.107 435.242,152.098 435.251,152.09 435.26,152.081 435.269,152.072 435.279,152.063 435.288,152.054 435.297,152.045 435.306,152.036 435.315,152.027 435.325,152.019 435.334,152.01 435.343,152.001 435.352,151.992 435.361,151.983 435.37,151.974 435.38,151.965 435.389,151.956 435.398,151.948 435.407,151.939 435.416,151.93 435.426,151.921 435.435,151.912 435.444,151.903 435.453,151.894 435.462,151.886 435.472,151.877 435.481,151.868 435.49,151.859 435.499,151.85 435.508,151.841 435.517,151.833 435.527,151.824 435.536,151.815 435.545,151.806 435.554,151.797 435.563,151.788 435.573,151.779 435.582,151.771 435.591,151.762 435.6,151.753 435.609,151.744 435.619,151.735 435.628,151.726 435.637,151.718 435.646,151.709 435.655,151.7 435.665,151.691 435.674,151.682 435.683,151.673 435.692,151.665 435.701,151.656 435.71,151.647 435.72,151.638 435.729,151.629 435.738,151.62 435.747,151.612 435.756,151.603 435.766,151.594 435.775,151.585 435.784,151.576 435.793,151.567 435.802,151.559 435.812,151.55 435.821,151.541 435.83,151.532 435.839,151.523 435.848,151.514 435.857,151.506 435.867,151.497 435.876,151.488 435.885,151.479 435.894,151.47 435.903,151.462 435.913,151.453 435.922,151.444 435.931,151.435 435.94,151.426 435.949,151.418 435.959,151.409 435.968,151.4 435.977,151.391 435.986,151.382 435.995,151.373 436.005,151.365 436.014,151.356 436.023,151.347 436.032,151.338 436.041,151.329 436.05,151.321 436.06,151.312 436.069,151.303 436.078,151.294 436.087,151.285 436.096,151.277 436.106,151.268 436.115,151.259 436.124,151.25 436.133,151.242 436.142,151.233 436.152,151.224 436.161,151.215 436.17,151.206 436.179,151.198 436.188,151.189 436.197,151.18 436.207,151.171 436.216,151.162 436.225,151.154 436.234,151.145 436.243,151.136 436.253,151.127 436.262,151.118 436.271,151.11 436.28,151.101 436.289,151.092 436.299,151.083 436.308,151.075 436.317,151.066 436.326,151.057 436.335,151.048 436.345,151.039 436.354,151.031 436.363,151.022 436.372,151.013 436.381,151.004 436.39,150.996 436.4,150.987 436.409,150.978 436.418,150.969 436.427,150.961 436.436,150.952 436.446,150.943 436.455,150.934 436.464,150.926 436.473,150.917 436.482,150.908 436.492,150.899 436.501,150.89 436.51,150.882 436.519,150.873 436.528,150.864 436.537,150.855 436.547,150.847 436.556,150.838 436.565,150.829 436.574,150.82 436.583,150.812 436.593,150.803 436.602,150.794 436.611,150.785 436.62,150.777 436.629,150.768 436.639,150.759 436.648,150.75 436.657,150.742 436.666,150.733 436.675,150.724 436.685,150.715 436.694,150.707 436.703,150.698 436.712,150.689 436.721,150.681 436.73,150.672 436.74,150.663 436.749,150.654 436.758,150.646 436.767,150.637 436.776,150.628 436.786,150.619 436.795,150.611 436.804,150.602 436.813,150.593 436.822,150.584 436.832,150.576 436.841,150.567 436.85,150.558 436.859,150.55 436.868,150.541 436.877,150.532 436.887,150.523 436.896,150.515 436.905,150.506 436.914,150.497 436.923,150.488 436.933,150.48 436.942,150.471 436.951,150.462 436.96,150.454 436.969,150.445 436.979,150.436 436.988,150.427 436.997,150.419 437.006,150.41 437.015,150.401 437.025,150.393 437.034,150.384 437.043,150.375 437.052,150.366 437.061,150.358 437.07,150.349 437.08,150.34 437.089,150.332 437.098,150.323 437.107,150.314 437.116,150.306 437.126,150.297 437.135,150.288 437.144,150.279 437.153,150.271 437.162,150.262 437.172,150.253 437.181,150.245 437.19,150.236 437.199,150.227 437.208,150.219 437.217,150.21 437.227,150.201 437.236,150.192 437.245,150.184 437.254,150.175 437.263,150.166 437.273,150.158 437.282,150.149 437.291,150.14 437.3,150.132 437.309,150.123 437.319,150.114 437.328,150.106 437.337,150.097 437.346,150.088 437.355,150.08 437.365,150.071 437.374,150.062 437.383,150.054 437.392,150.045 437.401,150.036 437.41,150.028 437.42,150.019 437.429,150.01 437.438,150.001 437.447,149.993 437.456,149.984 437.466,149.975 437.475,149.967 437.484,149.958 437.493,149.949 437.502,149.941 437.512,149.932 437.521,149.923 437.53,149.915 437.539,149.906 437.548,149.897 437.558,149.889 437.567,149.88 437.576,149.871 437.585,149.863 437.594,149.854 437.603,149.846 437.613,149.837 437.622,149.828 437.631,149.82 437.64,149.811 437.649,149.802 437.659,149.794 437.668,149.785 437.677,149.776 437.686,149.768 437.695,149.759 437.705,149.75 437.714,149.742 437.723,149.733 437.732,149.724 437.741,149.716 437.75,149.707 437.76,149.698 437.769,149.69 437.778,149.681 437.787,149.673 437.796,149.664 437.806,149.655 437.815,149.647 437.824,149.638 437.833,149.629 437.842,149.621 437.852,149.612 437.861,149.603 437.87,149.595 437.879,149.586 437.888,149.578 437.898,149.569 437.907,149.56 437.916,149.552 437.925,149.543 437.934,149.534 437.943,149.526 437.953,149.517 437.962,149.509 437.971,149.5 437.98,149.491 437.989,149.483 437.999,149.474 438.008,149.465 438.017,149.457 438.026,149.448 438.035,149.44 438.045,149.431 438.054,149.422 438.063,149.414 438.072,149.405 438.081,149.396 438.09,149.388 438.1,149.379 438.109,149.371 438.118,149.362 438.127,149.353 438.136,149.345 438.146,149.336 438.155,149.328 438.164,149.319 438.173,149.31 438.182,149.302 438.192,149.293 438.201,149.285 438.21,149.276 438.219,149.267 438.228,149.259 438.238,149.25 438.247,149.242 438.256,149.233 438.265,149.224 438.274,149.216 438.283,149.207 438.293,149.199 438.302,149.19 438.311,149.181 438.32,149.173 438.329,149.164 438.339,149.156 438.348,149.147 438.357,149.138 438.366,149.13 438.375,149.121 438.385,149.113 438.394,149.104 438.403,149.095 438.412,149.087 438.421,149.078 438.43,149.07 438.44,149.061 438.449,149.053 438.458,149.044 438.467,149.035 438.476,149.027 438.486,149.018 438.495,149.01 438.504,149.001 438.513,148.993 438.522,148.984 438.532,148.975 438.541,148.967 438.55,148.958 438.559,148.95 438.568,148.941 438.578,148.933 438.587,148.924 438.596,148.915 438.605,148.907 438.614,148.898 438.623,148.89 438.633,148.881 438.642,148.873 438.651,148.864 438.66,148.855 438.669,148.847 438.679,148.838 438.688,148.83 438.697,148.821 438.706,148.813 438.715,148.804 438.725,148.796 438.734,148.787 438.743,148.778 438.752,148.77 438.761,148.761 438.77,148.753 438.78,148.744 438.789,148.736 438.798,148.727 438.807,148.719 438.816,148.71 438.826,148.701 438.835,148.693 438.844,148.684 438.853,148.676 438.862,148.667 438.872,148.659 438.881,148.65 438.89,148.642 438.899,148.633 438.908,148.625 438.918,148.616 438.927,148.608 438.936,148.599 438.945,148.59 438.954,148.582 438.963,148.573 438.973,148.565 438.982,148.556 438.991,148.548 439,148.539 439.009,148.531 439.019,148.522 439.028,148.514 439.037,148.505 439.046,148.497 439.055,148.488 439.065,148.48 439.074,148.471 439.083,148.463 439.092,148.454 439.101,148.445 439.11,148.437 439.12,148.428 439.129,148.42 439.138,148.411 439.147,148.403 439.156,148.394 439.166,148.386 439.175,148.377 439.184,148.369 439.193,148.36 439.202,148.352 439.212,148.343 439.221,148.335 439.23,148.326 439.239,148.318 439.248,148.309 439.258,148.301 439.267,148.292 439.276,148.284 439.285,148.275 439.294,148.267 439.303,148.258 439.313,148.25 439.322,148.241 439.331,148.233 439.34,148.224 439.349,148.216 439.359,148.207 439.368,148.199 439.377,148.19 439.386,148.182 439.395,148.173 439.405,148.165 439.414,148.156 439.423,148.148 439.432,148.139 439.441,148.131 439.45,148.122 439.46,148.114 439.469,148.105 439.478,148.097 439.487,148.088 439.496,148.08 439.506,148.071 439.515,148.063 439.524,148.054 439.533,148.046 439.542,148.037 439.552,148.029 439.561,148.02 439.57,148.012 439.579,148.004 439.588,147.995 439.598,147.987 439.607,147.978 439.616,147.97 439.625,147.961 439.634,147.953 439.643,147.944 439.653,147.936 439.662,147.927 439.671,147.919 439.68,147.91 439.689,147.902 439.699,147.893 439.708,147.885 439.717,147.876 439.726,147.868 439.735,147.86 439.745,147.851 439.754,147.843 439.763,147.834 439.772,147.826 439.781,147.817 439.79,147.809 439.8,147.8 439.809,147.792 439.818,147.783 439.827,147.775 439.836,147.766 439.846,147.758 439.855,147.75 439.864,147.741 439.873,147.733 439.882,147.724 439.892,147.716 439.901,147.707 439.91,147.699 439.919,147.69 439.928,147.682 439.938,147.674 439.947,147.665 439.956,147.657 439.965,147.648 439.974,147.64 439.983,147.631 439.993,147.623 440.002,147.614 440.011,147.606 440.02,147.598 440.029,147.589 440.039,147.581 440.048,147.572 440.057,147.564 440.066,147.555 440.075,147.547 440.085,147.539 440.094,147.53 440.103,147.522 440.112,147.513 440.121,147.505 440.131,147.496 440.14,147.488 440.149,147.479 440.158,147.471 440.167,147.463 440.176,147.454 440.186,147.446 440.195,147.437 440.204,147.429 440.213,147.421 440.222,147.412 440.232,147.404 440.241,147.395 440.25,147.387 440.259,147.378 440.268,147.37 440.278,147.362 440.287,147.353 440.296,147.345 440.305,147.336 440.314,147.328 440.323,147.32 440.333,147.311 440.342,147.303 440.351,147.294 440.36,147.286 440.369,147.278 440.379,147.269 440.388,147.261 440.397,147.252 440.406,147.244 440.415,147.235 440.425,147.227 440.434,147.219 440.443,147.21 440.452,147.202 440.461,147.193 440.471,147.185 440.48,147.177 440.489,147.168 440.498,147.16 440.507,147.151 440.516,147.143 440.526,147.135 440.535,147.126 440.544,147.118 440.553,147.11 440.562,147.101 440.572,147.093 440.581,147.084 440.59,147.076 440.599,147.068 440.608,147.059 440.618,147.051 440.627,147.042 440.636,147.034 440.645,147.026 440.654,147.017 440.663,147.009 440.673,147.001 440.682,146.992 440.691,146.984 440.7,146.975 440.709,146.967 440.719,146.959 440.728,146.95 440.737,146.942 440.746,146.934 440.755,146.925 440.765,146.917 440.774,146.908 440.783,146.9 440.792,146.892 440.801,146.883 440.811,146.875 440.82,146.867 440.829,146.858 440.838,146.85 440.847,146.841 440.856,146.833 440.866,146.825 440.875,146.816 440.884,146.808 440.893,146.8 440.902,146.791 440.912,146.783 440.921,146.775 440.93,146.766 440.939,146.758 440.948,146.75 440.958,146.741 440.967,146.733 440.976,146.724 440.985,146.716 440.994,146.708 441.003,146.699 441.013,146.691 441.022,146.683 441.031,146.674 441.04,146.666 441.049,146.658 441.059,146.649 441.068,146.641 441.077,146.633 441.086,146.624 441.095,146.616 441.105,146.608 441.114,146.599 441.123,146.591 441.132,146.583 441.141,146.574 441.151,146.566 441.16,146.558 441.169,146.549 441.178,146.541 441.187,146.533 441.196,146.524 441.206,146.516 441.215,146.508 441.224,146.499 441.233,146.491 441.242,146.483 441.252,146.474 441.261,146.466 441.27,146.458 441.279,146.449 441.288,146.441 441.298,146.433 441.307,146.424 441.316,146.416 441.325,146.408 441.334,146.399 441.343,146.391 441.353,146.383 441.362,146.374 441.371,146.366 441.38,146.358 441.389,146.349 441.399,146.341 441.408,146.333 441.417,146.325 441.426,146.316 441.435,146.308 441.445,146.3 441.454,146.291 441.463,146.283 441.472,146.275 441.481,146.266 441.491,146.258 441.5,146.25 441.509,146.241 441.518,146.233 441.527,146.225 441.536,146.217 441.546,146.208 441.555,146.2 441.564,146.192 441.573,146.183 441.582,146.175 441.592,146.167 441.601,146.158 441.61,146.15 441.619,146.142 441.628,146.134 441.638,146.125 441.647,146.117 441.656,146.109 441.665,146.1 441.674,146.092 441.683,146.084 441.693,146.075 441.702,146.067 441.711,146.059 441.72,146.051 441.729,146.042 441.739,146.034 441.748,146.026 441.757,146.017 441.766,146.009 441.775,146.001 441.785,145.993 441.794,145.984 441.803,145.976 441.812,145.968 441.821,145.96 441.831,145.951 441.84,145.943 441.849,145.935 441.858,145.926 441.867,145.918 441.876,145.91 441.886,145.902 441.895,145.893 441.904,145.885 441.913,145.877 441.922,145.869 441.932,145.86 441.941,145.852 441.95,145.844 441.959,145.835 441.968,145.827 441.978,145.819 441.987,145.811 441.996,145.802 442.005,145.794 442.014,145.786 442.023,145.778 442.033,145.769 442.042,145.761 442.051,145.753 442.06,145.745 442.069,145.736 442.079,145.728 442.088,145.72 442.097,145.712 442.106,145.703 442.115,145.695 442.125,145.687 442.134,145.679 442.143,145.67 442.152,145.662 442.161,145.654 442.171,145.646 442.18,145.637 442.189,145.629 442.198,145.621 442.207,145.613 442.216,145.604 442.226,145.596 442.235,145.588 442.244,145.58 442.253,145.571 442.262,145.563 442.272,145.555 442.281,145.547 442.29,145.538 442.299,145.53 442.308,145.522 442.318,145.514 442.327,145.506 442.336,145.497 442.345,145.489 442.354,145.481 442.363,145.473 442.373,145.464 442.382,145.456 442.391,145.448 442.4,145.44 442.409,145.432 442.419,145.423 442.428,145.415 442.437,145.407 442.446,145.399 442.455,145.39 442.465,145.382 442.474,145.374 442.483,145.366 442.492,145.358 442.501,145.349 442.511,145.341 442.52,145.333 442.529,145.325 442.538,145.316 442.547,145.308 442.556,145.3 442.566,145.292 442.575,145.284 442.584,145.275 442.593,145.267 442.602,145.259 442.612,145.251 442.621,145.243 442.63,145.234 442.639,145.226 442.648,145.218 442.658,145.21 442.667,145.202 442.676,145.193 442.685,145.185 442.694,145.177 442.704,145.169 442.713,145.161 442.722,145.152 442.731,145.144 442.74,145.136 442.749,145.128 442.759,145.12 442.768,145.111 442.777,145.103 442.786,145.095 442.795,145.087 442.805,145.079 442.814,145.07 442.823,145.062 442.832,145.054 442.841,145.046 442.851,145.038 442.86,145.029 442.869,145.021 442.878,145.013 442.887,145.005 442.896,144.997 442.906,144.989 442.915,144.98 442.924,144.972 442.933,144.964 442.942,144.956 442.952,144.948 442.961,144.939 442.97,144.931 442.979,144.923 442.988,144.915 442.998,144.907 443.007,144.899 443.016,144.89 443.025,144.882 443.034,144.874 443.044,144.866 443.053,144.858 443.062,144.85 443.071,144.841 443.08,144.833 443.089,144.825 443.099,144.817 443.108,144.809 443.117,144.801 443.126,144.792 443.135,144.784 443.145,144.776 443.154,144.768 443.163,144.76 443.172,144.752 443.181,144.744 443.191,144.735 443.2,144.727 443.209,144.719 443.218,144.711 443.227,144.703 443.236,144.695 443.246,144.686 443.255,144.678 443.264,144.67 443.273,144.662 443.282,144.654 443.292,144.646 443.301,144.638 443.31,144.629 443.319,144.621 443.328,144.613 443.338,144.605 443.347,144.597 443.356,144.589 443.365,144.581 443.374,144.572 443.384,144.564 443.393,144.556 443.402,144.548 443.411,144.54 443.42,144.532 443.429,144.524 443.439,144.515 443.448,144.507 443.457,144.499 443.466,144.491 443.475,144.483 443.485,144.475 443.494,144.467 443.503,144.459 443.512,144.45 443.521,144.442 443.531,144.434 443.54,144.426 443.549,144.418 443.558,144.41 443.567,144.402 443.576,144.394 443.586,144.385 443.595,144.377 443.604,144.369 443.613,144.361 443.622,144.353 443.632,144.345 443.641,144.337 443.65,144.329 443.659,144.32 443.668,144.312 443.678,144.304 443.687,144.296 443.696,144.288 443.705,144.28 443.714,144.272 443.724,144.264 443.733,144.256 443.742,144.247 443.751,144.239 443.76,144.231 443.769,144.223 443.779,144.215 443.788,144.207 443.797,144.199 443.806,144.191 443.815,144.183 443.825,144.175 443.834,144.166 443.843,144.158 443.852,144.15 443.861,144.142 443.871,144.134 443.88,144.126 443.889,144.118 443.898,144.11 443.907,144.102 443.916,144.094 443.926,144.085 443.935,144.077 443.944,144.069 443.953,144.061 443.962,144.053 443.972,144.045 443.981,144.037 443.99,144.029 443.999,144.021 444.008,144.013 444.018,144.005 444.027,143.997 444.036,143.988 444.045,143.98 444.054,143.972 444.064,143.964 444.073,143.956 444.082,143.948 444.091,143.94 444.1,143.932 444.109,143.924 444.119,143.916 444.128,143.908 444.137,143.9 444.146,143.892 444.155,143.883 444.165,143.875 444.174,143.867 444.183,143.859 444.192,143.851 444.201,143.843 444.211,143.835 444.22,143.827 444.229,143.819 444.238,143.811 444.247,143.803 444.256,143.795 444.266,143.787 444.275,143.779 444.284,143.771 444.293,143.762 444.302,143.754 444.312,143.746 444.321,143.738 444.33,143.73 444.339,143.722 444.348,143.714 444.358,143.706 444.367,143.698 444.376,143.69 444.385,143.682 444.394,143.674 444.404,143.666 444.413,143.658 444.422,143.65 444.431,143.642 444.44,143.634 444.449,143.626 444.459,143.618 444.468,143.61 444.477,143.601 444.486,143.593 444.495,143.585 444.505,143.577 444.514,143.569 444.523,143.561 444.532,143.553 444.541,143.545 444.551,143.537 444.56,143.529 444.569,143.521 444.578,143.513 444.587,143.505 444.596,143.497 444.606,143.489 444.615,143.481 444.624,143.473 444.633,143.465 444.642,143.457 444.652,143.449 444.661,143.441 444.67,143.433 444.679,143.425 444.688,143.417 444.698,143.409 444.707,143.401 444.716,143.393 444.725,143.385 444.734,143.377 444.744,143.369 444.753,143.361 444.762,143.353 444.771,143.345 444.78,143.336 444.789,143.328 444.799,143.32 444.808,143.312 444.817,143.304 444.826,143.296 444.835,143.288 444.845,143.28 444.854,143.272 444.863,143.264 444.872,143.256 444.881,143.248 444.891,143.24 444.9,143.232 444.909,143.224 444.918,143.216 444.927,143.208 444.937,143.2 444.946,143.192 444.955,143.184 444.964,143.176 444.973,143.168 444.982,143.16 444.992,143.152 445.001,143.144 445.01,143.136 445.019,143.128 445.028,143.12 445.038,143.112 445.047,143.104 445.056,143.096 445.065,143.088 445.074,143.08 445.084,143.072 445.093,143.064 445.102,143.056 445.111,143.048 445.12,143.04 445.129,143.032 445.139,143.024 445.148,143.016 445.157,143.008 445.166,143.001 445.175,142.993 445.185,142.985 445.194,142.977 445.203,142.969 445.212,142.961 445.221,142.953 445.231,142.945 445.24,142.937 445.249,142.929 445.258,142.921 445.267,142.913 445.277,142.905 445.286,142.897 445.295,142.889 445.304,142.881 445.313,142.873 445.322,142.865 445.332,142.857 445.341,142.849 445.35,142.841 445.359,142.833 445.368,142.825 445.378,142.817 445.387,142.809 445.396,142.801 445.405,142.793 445.414,142.785 445.424,142.777 445.433,142.769 445.442,142.761 445.451,142.753 445.46,142.745 445.469,142.738 445.479,142.73 445.488,142.722 445.497,142.714 445.506,142.706 445.515,142.698 445.525,142.69 445.534,142.682 445.543,142.674 445.552,142.666 445.561,142.658 445.571,142.65 445.58,142.642 445.589,142.634 445.598,142.626 445.607,142.618 445.617,142.61 445.626,142.602 445.635,142.594 445.644,142.586 445.653,142.579 445.662,142.571 445.672,142.563 445.681,142.555 445.69,142.547 445.699,142.539 445.708,142.531 445.718,142.523 445.727,142.515 445.736,142.507 445.745,142.499 445.754,142.491 445.764,142.483 445.773,142.475 445.782,142.467 445.791,142.46 445.8,142.452 445.809,142.444 445.819,142.436 445.828,142.428 445.837,142.42 445.846,142.412 445.855,142.404 445.865,142.396 445.874,142.388 445.883,142.38 445.892,142.372 445.901,142.364 445.911,142.357 445.92,142.349 445.929,142.341 445.938,142.333 445.947,142.325 445.957,142.317 445.966,142.309 445.975,142.301 445.984,142.293 445.993,142.285 446.002,142.277 446.012,142.269 446.021,142.262 446.03,142.254 446.039,142.246 446.048,142.238 446.058,142.23 446.067,142.222 446.076,142.214 446.085,142.206 446.094,142.198 446.104,142.19 446.113,142.182 446.122,142.175 446.131,142.167 446.14,142.159 446.149,142.151 446.159,142.143 446.168,142.135 446.177,142.127 446.186,142.119 446.195,142.111 446.205,142.104 446.214,142.096 446.223,142.088 446.232,142.08 446.241,142.072 446.251,142.064 446.26,142.056 446.269,142.048 446.278,142.04 446.287,142.033 446.297,142.025 446.306,142.017 446.315,142.009 446.324,142.001 446.333,141.993 446.342,141.985 446.352,141.977 446.361,141.969 446.37,141.962 446.379,141.954 446.388,141.946 446.398,141.938 446.407,141.93 446.416,141.922 446.425,141.914 446.434,141.906 446.444,141.899 446.453,141.891 446.462,141.883 446.471,141.875 446.48,141.867 446.489,141.859 446.499,141.851 446.508,141.843 446.517,141.836 446.526,141.828 446.535,141.82 446.545,141.812 446.554,141.804 446.563,141.796 446.572,141.788 446.581,141.781 446.591,141.773 446.6,141.765 446.609,141.757 446.618,141.749 446.627,141.741 446.637,141.733 446.646,141.726 446.655,141.718 446.664,141.71 446.673,141.702 446.682,141.694 446.692,141.686 446.701,141.678 446.71,141.671 446.719,141.663 446.728,141.655 446.738,141.647 446.747,141.639 446.756,141.631 446.765,141.624 446.774,141.616 446.784,141.608 446.793,141.6 446.802,141.592 446.811,141.584 446.82,141.576 446.829,141.569 446.839,141.561 446.848,141.553 446.857,141.545 446.866,141.537 446.875,141.529 446.885,141.522 446.894,141.514 446.903,141.506 446.912,141.498 446.921,141.49 446.931,141.482 446.94,141.475 446.949,141.467 446.958,141.459 446.967,141.451 446.977,141.443 446.986,141.435 446.995,141.428 447.004,141.42 447.013,141.412 447.022,141.404 447.032,141.396 447.041,141.389 447.05,141.381 447.059,141.373 447.068,141.365 447.078,141.357 447.087,141.349 447.096,141.342 447.105,141.334 447.114,141.326 447.124,141.318 447.133,141.31 447.142,141.303 447.151,141.295 447.16,141.287 447.169,141.279 447.179,141.271 447.188,141.263 447.197,141.256 447.206,141.248 447.215,141.24 447.225,141.232 447.234,141.224 447.243,141.217 447.252,141.209 447.261,141.201 447.271,141.193 447.28,141.185 447.289,141.178 447.298,141.17 447.307,141.162 447.317,141.154 447.326,141.146 447.335,141.139 447.344,141.131 447.353,141.123 447.362,141.115 447.372,141.107 447.381,141.1 447.39,141.092 447.399,141.084 447.408,141.076 447.418,141.068 447.427,141.061 447.436,141.053 447.445,141.045 447.454,141.037 447.464,141.03 447.473,141.022 447.482,141.014 447.491,141.006 447.5,140.998 447.51,140.991 447.519,140.983 447.528,140.975 447.537,140.967 447.546,140.96 447.555,140.952 447.565,140.944 447.574,140.936 447.583,140.928 447.592,140.921 447.601,140.913 447.611,140.905 447.62,140.897 447.629,140.89 447.638,140.882 447.647,140.874 447.657,140.866 447.666,140.858 447.675,140.851 447.684,140.843 447.693,140.835 447.702,140.827 447.712,140.82 447.721,140.812 447.73,140.804 447.739,140.796 447.748,140.789 447.758,140.781 447.767,140.773 447.776,140.765 447.785,140.758 447.794,140.75 447.804,140.742 447.813,140.734 447.822,140.727 447.831,140.719 447.84,140.711 447.85,140.703 447.859,140.695 447.868,140.688 447.877,140.68 447.886,140.672 447.895,140.664 447.905,140.657 447.914,140.649 447.923,140.641 447.932,140.634 447.941,140.626 447.951,140.618 447.96,140.61 447.969,140.603 447.978,140.595 447.987,140.587 447.997,140.579 448.006,140.572 448.015,140.564 448.024,140.556 448.033,140.548 448.042,140.541 448.052,140.533 448.061,140.525 448.07,140.517 448.079,140.51 448.088,140.502 448.098,140.494 448.107,140.486 448.116,140.479 448.125,140.471 448.134,140.463 448.144,140.456 448.153,140.448 448.162,140.44 448.171,140.432 448.18,140.425 448.19,140.417 448.199,140.409 448.208,140.401 448.217,140.394 448.226,140.386 448.235,140.378 448.245,140.371 448.254,140.363 448.263,140.355 448.272,140.347 448.281,140.34 448.291,140.332 448.3,140.324 448.309,140.317 448.318,140.309 448.327,140.301 448.337,140.293 448.346,140.286 448.355,140.278 448.364,140.27 448.373,140.263 448.382,140.255 448.392,140.247 448.401,140.239 448.41,140.232 448.419,140.224 448.428,140.216 448.438,140.209 448.447,140.201 448.456,140.193 448.465,140.186 448.474,140.178 448.484,140.17 448.493,140.162 448.502,140.155 448.511,140.147 448.52,140.139 448.53,140.132 448.539,140.124 448.548,140.116 448.557,140.109 448.566,140.101 448.575,140.093 448.585,140.086 448.594,140.078 448.603,140.07 448.612,140.062 448.621,140.055 448.631,140.047 448.64,140.039 448.649,140.032 448.658,140.024 448.667,140.016 448.677,140.009 448.686,140.001 448.695,139.993 448.704,139.986 448.713,139.978 448.722,139.97 448.732,139.963 448.741,139.955 448.75,139.947 448.759,139.94 448.768,139.932 448.778,139.924 448.787,139.917 448.796,139.909 448.805,139.901 448.814,139.894 448.824,139.886 448.833,139.878 448.842,139.871 448.851,139.863 448.86,139.855 448.87,139.848 448.879,139.84 448.888,139.832 448.897,139.825 448.906,139.817 448.915,139.809 448.925,139.802 448.934,139.794 448.943,139.786 448.952,139.779 448.961,139.771 448.971,139.763 448.98,139.756 448.989,139.748 448.998,139.74 449.007,139.733 449.017,139.725 449.026,139.717 449.035,139.71 449.044,139.702 449.053,139.694 449.062,139.687 449.072,139.679 449.081,139.671 449.09,139.664 449.099,139.656 449.108,139.648 449.118,139.641 449.127,139.633 449.136,139.626 449.145,139.618 449.154,139.61 449.164,139.603 449.173,139.595 449.182,139.587 449.191,139.58 449.2,139.572 449.21,139.564 449.219,139.557 449.228,139.549 449.237,139.541 449.246,139.534 449.255,139.526 449.265,139.519 449.274,139.511 449.283,139.503 449.292,139.496 449.301,139.488 449.311,139.48 449.32,139.473 449.329,139.465 449.338,139.458 449.347,139.45 449.357,139.442 449.366,139.435 449.375,139.427 449.384,139.419 449.393,139.412 449.402,139.404 449.412,139.397 449.421,139.389 449.43,139.381 449.439,139.374 449.448,139.366 449.458,139.358 449.467,139.351 449.476,139.343 449.485,139.336 449.494,139.328 449.504,139.32 449.513,139.313 449.522,139.305 449.531,139.298 449.54,139.29 449.55,139.282 449.559,139.275 449.568,139.267 449.577,139.259 449.586,139.252 449.595,139.244 449.605,139.237 449.614,139.229 449.623,139.221 449.632,139.214 449.641,139.206 449.651,139.199 449.66,139.191 449.669,139.183 449.678,139.176 449.687,139.168 449.697,139.161 449.706,139.153 449.715,139.145 449.724,139.138 449.733,139.13 449.742,139.123 449.752,139.115 449.761,139.107 449.77,139.1 449.779,139.092 449.788,139.085 449.798,139.077 449.807,139.07 449.816,139.062 449.825,139.054 449.834,139.047 449.844,139.039 449.853,139.032 449.862,139.024 449.871,139.016 449.88,139.009 449.89,139.001 449.899,138.994 449.908,138.986 449.917,138.979 449.926,138.971 449.935,138.963 449.945,138.956 449.954,138.948 449.963,138.941 449.972,138.933 449.981,138.926 449.991,138.918 450,138.91 450.009,138.903 450.018,138.895 450.027,138.888 450.037,138.88 450.046,138.873 450.055,138.865 450.064,138.857 450.073,138.85 450.083,138.842 450.092,138.835 450.101,138.827 450.11,138.82 450.119,138.812 450.128,138.804 450.138,138.797 450.147,138.789 450.156,138.782 450.165,138.774 450.174,138.767 450.184,138.759 450.193,138.752 450.202,138.744 450.211,138.736 450.22,138.729 450.23,138.721 450.239,138.714 450.248,138.706 450.257,138.699 450.266,138.691 450.275,138.684 450.285,138.676 450.294,138.668 450.303,138.661 450.312,138.653 450.321,138.646 450.331,138.638 450.34,138.631 450.349,138.623 450.358,138.616 450.367,138.608 450.377,138.601 450.386,138.593 450.395,138.586 450.404,138.578 450.413,138.57 450.423,138.563 450.432,138.555 450.441,138.548 450.45,138.54 450.459,138.533 450.468,138.525 450.478,138.518 450.487,138.51 450.496,138.503 450.505,138.495 450.514,138.488 450.524,138.48 450.533,138.473 450.542,138.465 450.551,138.457 450.56,138.45 450.57,138.442 450.579,138.435 450.588,138.427 450.597,138.42 450.606,138.412 450.615,138.405 450.625,138.397 450.634,138.39 450.643,138.382 450.652,138.375 450.661,138.367 450.671,138.36 450.68,138.352 450.689,138.345 450.698,138.337 450.707,138.33 450.717,138.322 450.726,138.315 450.735,138.307 450.744,138.3 450.753,138.292 450.763,138.285 450.772,138.277 450.781,138.27 450.79,138.262 450.799,138.255 450.808,138.247 450.818,138.24 450.827,138.232 450.836,138.225 450.845,138.217 450.854,138.21 450.864,138.202 450.873,138.195 450.882,138.187 450.891,138.18 450.9,138.172 450.91,138.165 450.919,138.157 450.928,138.15 450.937,138.142 450.946,138.135 450.955,138.127 450.965,138.12 450.974,138.112 450.983,138.105 450.992,138.097 451.001,138.09 451.011,138.082 451.02,138.075 451.029,138.067 451.038,138.06 451.047,138.052 451.057,138.045 451.066,138.037 451.075,138.03 451.084,138.022 451.093,138.015 451.103,138.007 451.112,138 451.121,137.992 451.13,137.985 451.139,137.977 451.148,137.97 451.158,137.962 451.167,137.955 451.176,137.947 451.185,137.94 451.194,137.933 451.204,137.925 451.213,137.918 451.222,137.91 451.231,137.903 451.24,137.895 451.25,137.888 451.259,137.88 451.268,137.873 451.277,137.865 451.286,137.858 451.295,137.85 451.305,137.843 451.314,137.835 451.323,137.828 451.332,137.821 451.341,137.813 451.351,137.806 451.36,137.798 451.369,137.791 451.378,137.783 451.387,137.776 451.397,137.768 451.406,137.761 451.415,137.753 451.424,137.746 451.433,137.738 451.443,137.731 451.452,137.724 451.461,137.716 451.47,137.709 451.479,137.701 451.488,137.694 451.498,137.686 451.507,137.679 451.516,137.671 451.525,137.664 451.534,137.657 451.544,137.649 451.553,137.642 451.562,137.634 451.571,137.627 451.58,137.619 451.59,137.612 451.599,137.604 451.608,137.597 451.617,137.59 451.626,137.582 451.635,137.575 451.645,137.567 451.654,137.56 451.663,137.552 451.672,137.545 451.681,137.538 451.691,137.53 451.7,137.523 451.709,137.515 451.718,137.508 451.727,137.5 451.737,137.493 451.746,137.486 451.755,137.478 451.764,137.471 451.773,137.463 451.783,137.456 451.792,137.448 451.801,137.441 451.81,137.434 451.819,137.426 451.828,137.419 451.838,137.411 451.847,137.404 451.856,137.396 451.865,137.389 451.874,137.382 451.884,137.374 451.893,137.367 451.902,137.359 451.911,137.352 451.92,137.345 451.93,137.337 451.939,137.33 451.948,137.322 451.957,137.315 451.966,137.307 451.975,137.3 451.985,137.293 451.994,137.285 452.003,137.278 452.012,137.27 452.021,137.263 452.031,137.256 452.04,137.248 452.049,137.241 452.058,137.233 452.067,137.226 452.077,137.219 452.086,137.211 452.095,137.204 452.104,137.196 452.113,137.189 452.123,137.182 452.132,137.174 452.141,137.167 452.15,137.159 452.159,137.152 452.168,137.145 452.178,137.137 452.187,137.13 452.196,137.123 452.205,137.115 452.214,137.108 452.224,137.1 452.233,137.093 452.242,137.086 452.251,137.078 452.26,137.071 452.27,137.063 452.279,137.056 452.288,137.049 452.297,137.041 452.306,137.034 452.316,137.026 452.325,137.019 452.334,137.012 452.343,137.004 452.352,136.997 452.361,136.99 452.371,136.982 452.38,136.975 452.389,136.967 452.398,136.96 452.407,136.953 452.417,136.945 452.426,136.938 452.435,136.931 452.444,136.923 452.453,136.916 452.463,136.909 452.472,136.901 452.481,136.894 452.49,136.886 452.499,136.879 452.508,136.872 452.518,136.864 452.527,136.857 452.536,136.85 452.545,136.842 452.554,136.835 452.564,136.828 452.573,136.82 452.582,136.813 452.591,136.805 452.6,136.798 452.61,136.791 452.619,136.783 452.628,136.776 452.637,136.769 452.646,136.761 452.656,136.754 452.665,136.747 452.674,136.739 452.683,136.732 452.692,136.725 452.701,136.717 452.711,136.71 452.72,136.702 452.729,136.695 452.738,136.688 452.747,136.68 452.757,136.673 452.766,136.666 452.775,136.658 452.784,136.651 452.793,136.644 452.803,136.636 452.812,136.629 452.821,136.622 452.83,136.614 452.839,136.607 452.848,136.6 452.858,136.592 452.867,136.585 452.876,136.578 452.885,136.57 452.894,136.563 452.904,136.556 452.913,136.548 452.922,136.541 452.931,136.534 452.94,136.526 452.95,136.519 452.959,136.512 452.968,136.504 452.977,136.497 452.986,136.49 452.996,136.482 453.005,136.475 453.014,136.468 453.023,136.46 453.032,136.453 453.041,136.446 453.051,136.438 453.06,136.431 453.069,136.424 453.078,136.417 453.087,136.409 453.097,136.402 453.106,136.395 453.115,136.387 453.124,136.38 453.133,136.373 453.143,136.365 453.152,136.358 453.161,136.351 453.17,136.343 453.179,136.336 453.188,136.329 453.198,136.321 453.207,136.314 453.216,136.307 453.225,136.3 453.234,136.292 453.244,136.285 453.253,136.278 453.262,136.27 453.271,136.263 453.28,136.256 453.29,136.248 453.299,136.241 453.308,136.234 453.317,136.226 453.326,136.219 453.336,136.212 453.345,136.205 453.354,136.197 453.363,136.19 453.372,136.183 453.381,136.175 453.391,136.168 453.4,136.161 453.409,136.154 453.418,136.146 453.427,136.139 453.437,136.132 453.446,136.124 453.455,136.117 453.464,136.11 453.473,136.103 453.483,136.095 453.492,136.088 453.501,136.081 453.51,136.073 453.519,136.066 453.528,136.059 453.538,136.052 453.547,136.044 453.556,136.037 453.565,136.03 453.574,136.022 453.584,136.015 453.593,136.008 453.602,136.001 453.611,135.993 453.62,135.986 453.63,135.979 453.639,135.971 453.648,135.964 453.657,135.957 453.666,135.95 453.676,135.942 453.685,135.935 453.694,135.928 453.703,135.921 453.712,135.913 453.721,135.906 453.731,135.899 453.74,135.892 453.749,135.884 453.758,135.877 453.767,135.87 453.777,135.862 453.786,135.855 453.795,135.848 453.804,135.841 453.813,135.833 453.823,135.826 453.832,135.819 453.841,135.812 453.85,135.804 453.859,135.797 453.868,135.79 453.878,135.783 453.887,135.775 453.896,135.768 453.905,135.761 453.914,135.754 453.924,135.746 453.933,135.739 453.942,135.732 453.951,135.725 453.96,135.717 453.97,135.71 453.979,135.703 453.988,135.696 453.997,135.688 454.006,135.681 454.016,135.674 454.025,135.667 454.034,135.659 454.043,135.652 454.052,135.645 454.061,135.638 454.071,135.63 454.08,135.623 454.089,135.616 454.098,135.609 454.107,135.602 454.117,135.594 454.126,135.587 454.135,135.58 454.144,135.573 454.153,135.565 454.163,135.558 454.172,135.551 454.181,135.544 454.19,135.536 454.199,135.529 454.208,135.522 454.218,135.515 454.227,135.508 454.236,135.5 454.245,135.493 454.254,135.486 454.264,135.479 454.273,135.471 454.282,135.464 454.291,135.457 454.3,135.45 454.31,135.443 454.319,135.435 454.328,135.428 454.337,135.421 454.346,135.414 454.356,135.406 454.365,135.399 454.374,135.392 454.383,135.385 454.392,135.378 454.401,135.37 454.411,135.363 454.42,135.356 454.429,135.349 454.438,135.342 454.447,135.334 454.457,135.327 454.466,135.32 454.475,135.313 454.484,135.306 454.493,135.298 454.503,135.291 454.512,135.284 454.521,135.277 454.53,135.27 454.539,135.262 454.548,135.255 454.558,135.248 454.567,135.241 454.576,135.234 454.585,135.226 454.594,135.219 454.604,135.212 454.613,135.205 454.622,135.198 454.631,135.19 454.64,135.183 454.65,135.176 454.659,135.169 454.668,135.162 454.677,135.154 454.686,135.147 454.696,135.14 454.705,135.133 454.714,135.126 454.723,135.118 454.732,135.111 454.741,135.104 454.751,135.097 454.76,135.09 454.769,135.083 454.778,135.075 454.787,135.068 454.797,135.061 454.806,135.054 454.815,135.047 454.824,135.039 454.833,135.032 454.843,135.025 454.852,135.018 454.861,135.011 454.87,135.004 454.879,134.996 454.889,134.989 454.898,134.982 454.907,134.975 454.916,134.968 454.925,134.961 454.934,134.953 454.944,134.946 454.953,134.939 454.962,134.932 454.971,134.925 454.98,134.918 454.99,134.91 454.999,134.903 455.008,134.896 455.017,134.889 455.026,134.882 455.036,134.875 455.045,134.867 455.054,134.86 455.063,134.853 455.072,134.846 455.081,134.839 455.091,134.832 455.1,134.824 455.109,134.817 455.118,134.81 455.127,134.803 455.137,134.796 455.146,134.789 455.155,134.782 455.164,134.774 455.173,134.767 455.183,134.76 455.192,134.753 455.201,134.746 455.21,134.739 455.219,134.731 455.229,134.724 455.238,134.717 455.247,134.71 455.256,134.703 455.265,134.696 455.274,134.689 455.284,134.681 455.293,134.674 455.302,134.667 455.311,134.66 455.32,134.653 455.33,134.646 455.339,134.639 455.348,134.632 455.357,134.624 455.366,134.617 455.376,134.61 455.385,134.603 455.394,134.596 455.403,134.589 455.412,134.582 455.421,134.574 455.431,134.567 455.44,134.56 455.449,134.553 455.458,134.546 455.467,134.539 455.477,134.532 455.486,134.525 455.495,134.517 455.504,134.51 455.513,134.503 455.523,134.496 455.532,134.489 455.541,134.482 455.55,134.475 455.559,134.468 455.569,134.46 455.578,134.453 455.587,134.446 455.596,134.439 455.605,134.432 455.614,134.425 455.624,134.418 455.633,134.411 455.642,134.404 455.651,134.396 455.66,134.389 455.67,134.382 455.679,134.375 455.688,134.368 455.697,134.361 455.706,134.354 455.716,134.347 455.725,134.34 455.734,134.332 455.743,134.325 455.752,134.318 455.761,134.311 455.771,134.304 455.78,134.297 455.789,134.29 455.798,134.283 455.807,134.276 455.817,134.269 455.826,134.261 455.835,134.254 455.844,134.247 455.853,134.24 455.863,134.233 455.872,134.226 455.881,134.219 455.89,134.212 455.899,134.205 455.909,134.198 455.918,134.191 455.927,134.183 455.936,134.176 455.945,134.169 455.954,134.162 455.964,134.155 455.973,134.148 455.982,134.141 455.991,134.134 456,134.127 456.01,134.12 456.019,134.113 456.028,134.105 456.037,134.098 456.046,134.091 456.056,134.084 456.065,134.077 456.074,134.07 456.083,134.063 456.092,134.056 456.101,134.049 456.111,134.042 456.12,134.035 456.129,134.028 456.138,134.021 456.147,134.013 456.157,134.006 456.166,133.999 456.175,133.992 456.184,133.985 456.193,133.978 456.203,133.971 456.212,133.964 456.221,133.957 456.23,133.95 456.239,133.943 456.249,133.936 456.258,133.929 456.267,133.922 456.276,133.915 456.285,133.907 456.294,133.9 456.304,133.893 456.313,133.886 456.322,133.879 456.331,133.872 456.34,133.865 456.35,133.858 456.359,133.851 456.368,133.844 456.377,133.837 456.386,133.83 456.396,133.823 456.405,133.816 456.414,133.809 456.423,133.802 456.432,133.795 456.441,133.788 456.451,133.78 456.46,133.773 456.469,133.766 456.478,133.759 456.487,133.752 456.497,133.745 456.506,133.738 456.515,133.731 456.524,133.724 456.533,133.717 456.543,133.71 456.552,133.703 456.561,133.696 456.57,133.689 456.579,133.682 456.589,133.675 456.598,133.668 456.607,133.661 456.616,133.654 456.625,133.647 456.634,133.64 456.644,133.633 456.653,133.626 456.662,133.619 456.671,133.612 456.68,133.604 456.69,133.597 456.699,133.59 456.708,133.583 456.717,133.576 456.726,133.569 456.736,133.562 456.745,133.555 456.754,133.548 456.763,133.541 456.772,133.534 456.781,133.527 456.791,133.52 456.8,133.513 456.809,133.506 456.818,133.499 456.827,133.492 456.837,133.485 456.846,133.478 456.855,133.471 456.864,133.464 456.873,133.457 456.883,133.45 456.892,133.443 456.901,133.436 456.91,133.429 456.919,133.422 456.929,133.415 456.938,133.408 456.947,133.401 456.956,133.394 456.965,133.387 456.974,133.38 456.984,133.373 456.993,133.366 457.002,133.359 457.011,133.352 457.02,133.345 457.03,133.338 457.039,133.331 457.048,133.324 457.057,133.317 457.066,133.31 457.076,133.303 457.085,133.296 457.094,133.289 457.103,133.282 457.112,133.275 457.121,133.268 457.131,133.261 457.14,133.254 457.149,133.247 457.158,133.24 457.167,133.233 457.177,133.226 457.186,133.219 457.195,133.212 457.204,133.205 457.213,133.198 457.223,133.191 457.232,133.184 457.241,133.177 457.25,133.17 457.259,133.163 457.269,133.156 457.278,133.149 457.287,133.142 457.296,133.135 457.305,133.128 457.314,133.121 457.324,133.114 457.333,133.107 457.342,133.1 457.351,133.093 457.36,133.086 457.37,133.079 457.379,133.072 457.388,133.065 457.397,133.058 457.406,133.051 457.416,133.044 457.425,133.037 457.434,133.03 457.443,133.023 457.452,133.016 457.462,133.01 457.471,133.003 457.48,132.996 457.489,132.989 457.498,132.982 457.507,132.975 457.517,132.968 457.526,132.961 457.535,132.954 457.544,132.947 457.553,132.94 457.563,132.933 457.572,132.926 457.581,132.919 457.59,132.912 457.599,132.905 457.609,132.898 457.618,132.891 457.627,132.884 457.636,132.877 457.645,132.87 457.654,132.863 457.664,132.856 457.673,132.849 457.682,132.842 457.691,132.836 457.7,132.829 457.71,132.822 457.719,132.815 457.728,132.808 457.737,132.801 457.746,132.794 457.756,132.787 457.765,132.78 457.774,132.773 457.783,132.766 457.792,132.759 457.802,132.752 457.811,132.745 457.82,132.738 457.829,132.731 457.838,132.724 457.847,132.717 457.857,132.711 457.866,132.704 457.875,132.697 457.884,132.69 457.893,132.683 457.903,132.676 457.912,132.669 457.921,132.662 457.93,132.655 457.939,132.648 457.949,132.641 457.958,132.634 457.967,132.627 457.976,132.62 457.985,132.613 457.994,132.607 458.004,132.6 458.013,132.593 458.022,132.586 458.031,132.579 458.04,132.572 458.05,132.565 458.059,132.558 458.068,132.551 458.077,132.544 458.086,132.537 458.096,132.53 458.105,132.523 458.114,132.517 458.123,132.51 458.132,132.503 458.142,132.496 458.151,132.489 458.16,132.482 458.169,132.475 458.178,132.468 458.187,132.461 458.197,132.454 458.206,132.447 458.215,132.44 458.224,132.434 458.233,132.427 458.243,132.42 458.252,132.413 458.261,132.406 458.27,132.399 458.279,132.392 458.289,132.385 458.298,132.378 458.307,132.371 458.316,132.365 458.325,132.358 458.334,132.351 458.344,132.344 458.353,132.337 458.362,132.33 458.371,132.323 458.38,132.316 458.39,132.309 458.399,132.302 458.408,132.296 458.417,132.289 458.426,132.282 458.436,132.275 458.445,132.268 458.454,132.261 458.463,132.254 458.472,132.247 458.482,132.24 458.491,132.233 458.5,132.227 458.509,132.22 458.518,132.213 458.527,132.206 458.537,132.199 458.546,132.192 458.555,132.185 458.564,132.178 458.573,132.172 458.583,132.165 458.592,132.158 458.601,132.151 458.61,132.144 458.619,132.137 458.629,132.13 458.638,132.123 458.647,132.116 458.656,132.11 458.665,132.103 458.674,132.096 458.684,132.089 458.693,132.082 458.702,132.075 458.711,132.068 458.72,132.061 458.73,132.055 458.739,132.048 458.748,132.041 458.757,132.034 458.766,132.027 458.776,132.02 458.785,132.013 458.794,132.007 458.803,132 458.812,131.993 458.822,131.986 458.831,131.979 458.84,131.972 458.849,131.965 458.858,131.958 458.867,131.952 458.877,131.945 458.886,131.938 458.895,131.931 458.904,131.924 458.913,131.917 458.923,131.91 458.932,131.904 458.941,131.897 458.95,131.89 458.959,131.883 458.969,131.876 458.978,131.869 458.987,131.863 458.996,131.856 459.005,131.849 459.014,131.842 459.024,131.835 459.033,131.828 459.042,131.821 459.051,131.815 459.06,131.808 459.07,131.801 459.079,131.794 459.088,131.787 459.097,131.78 459.106,131.774 459.116,131.767 459.125,131.76 459.134,131.753 459.143,131.746 459.152,131.739 459.162,131.732 459.171,131.726 459.18,131.719 459.189,131.712 459.198,131.705 459.207,131.698 459.217,131.691 459.226,131.685 459.235,131.678 459.244,131.671 459.253,131.664 459.263,131.657 459.272,131.65 459.281,131.644 459.29,131.637 459.299,131.63 459.309,131.623 459.318,131.616 459.327,131.61 459.336,131.603 459.345,131.596 459.354,131.589 459.364,131.582 459.373,131.575 459.382,131.569 459.391,131.562 459.4,131.555 459.41,131.548 459.419,131.541 459.428,131.534 459.437,131.528 459.446,131.521 459.456,131.514 459.465,131.507 459.474,131.5 459.483,131.494 459.492,131.487 459.502,131.48 459.511,131.473 459.52,131.466 459.529,131.46 459.538,131.453 459.547,131.446 459.557,131.439 459.566,131.432 459.575,131.426 459.584,131.419 459.593,131.412 459.603,131.405 459.612,131.398 459.621,131.391 459.63,131.385 459.639,131.378 459.649,131.371 459.658,131.364 459.667,131.357 459.676,131.351 459.685,131.344 459.695,131.337 459.704,131.33 459.713,131.323 459.722,131.317 459.731,131.31 459.74,131.303 459.75,131.296 459.759,131.29 459.768,131.283 459.777,131.276 459.786,131.269 459.796,131.262 459.805,131.256 459.814,131.249 459.823,131.242 459.832,131.235 459.842,131.228 459.851,131.222 459.86,131.215 459.869,131.208 459.878,131.201 459.887,131.195 459.897,131.188 459.906,131.181 459.915,131.174 459.924,131.167 459.933,131.161 459.943,131.154 459.952,131.147 459.961,131.14 459.97,131.134 459.979,131.127 459.989,131.12 459.998,131.113 460.007,131.106 460.016,131.1 460.025,131.093 460.035,131.086 460.044,131.079 460.053,131.073 460.062,131.066 460.071,131.059 460.08,131.052 460.09,131.045 460.099,131.039 460.108,131.032 460.117,131.025 460.126,131.018 460.136,131.012 460.145,131.005 460.154,130.998 460.163,130.991 460.172,130.985 460.182,130.978 460.191,130.971 460.2,130.964 460.209,130.958 460.218,130.951 460.227,130.944 460.237,130.937 460.246,130.931 460.255,130.924 460.264,130.917 460.273,130.91 460.283,130.904 460.292,130.897 460.301,130.89 460.31,130.883 460.319,130.877 460.329,130.87 460.338,130.863 460.347,130.856 460.356,130.85 460.365,130.843 460.375,130.836 460.384,130.829 460.393,130.823 460.402,130.816 460.411,130.809 460.42,130.802 460.43,130.796 460.439,130.789 460.448,130.782 460.457,130.775 460.466,130.769 460.476,130.762 460.485,130.755 460.494,130.748 460.503,130.742 460.512,130.735 460.522,130.728 460.531,130.722 460.54,130.715 460.549,130.708 460.558,130.701 460.567,130.695 460.577,130.688 460.586,130.681 460.595,130.674 460.604,130.668 460.613,130.661 460.623,130.654 460.632,130.647 460.641,130.641 460.65,130.634 460.659,130.627 460.669,130.621 460.678,130.614 460.687,130.607 460.696,130.6 460.705,130.594 460.715,130.587 460.724,130.58 460.733,130.574 460.742,130.567 460.751,130.56 460.76,130.553 460.77,130.547 460.779,130.54 460.788,130.533 460.797,130.527 460.806,130.52 460.816,130.513 460.825,130.506 460.834,130.5 460.843,130.493 460.852,130.486 460.862,130.48 460.871,130.473 460.88,130.466 460.889,130.459 460.898,130.453 460.907,130.446 460.917,130.439 460.926,130.433 460.935,130.426 460.944,130.419 460.953,130.413 460.963,130.406 460.972,130.399 460.981,130.392 460.99,130.386 460.999,130.379 461.009,130.372 461.018,130.366 461.027,130.359 461.036,130.352 461.045,130.346 461.055,130.339 461.064,130.332 461.073,130.325 461.082,130.319 461.091,130.312 461.1,130.305 461.11,130.299 461.119,130.292 461.128,130.285 461.137,130.279 461.146,130.272 461.156,130.265 461.165,130.259 461.174,130.252 461.183,130.245 461.192,130.239 461.202,130.232 461.211,130.225 461.22,130.219 461.229,130.212 461.238,130.205 461.247,130.198 461.257,130.192 461.266,130.185 461.275,130.178 461.284,130.172 461.293,130.165 461.303,130.158 461.312,130.152 461.321,130.145 461.33,130.138 461.339,130.132 461.349,130.125 461.358,130.118 461.367,130.112 461.376,130.105 461.385,130.098 461.395,130.092 461.404,130.085 461.413,130.078 461.422,130.072 461.431,130.065 461.44,130.058 461.45,130.052 461.459,130.045 461.468,130.038 461.477,130.032 461.486,130.025 461.496,130.018 461.505,130.012 461.514,130.005 461.523,129.998 461.532,129.992 461.542,129.985 461.551,129.978 461.56,129.972 461.569,129.965 461.578,129.958 461.587,129.952 461.597,129.945 461.606,129.939 461.615,129.932 461.624,129.925 461.633,129.919 461.643,129.912 461.652,129.905 461.661,129.899 461.67,129.892 461.679,129.885 461.689,129.879 461.698,129.872 461.707,129.865 461.716,129.859 461.725,129.852 461.735,129.845 461.744,129.839 461.753,129.832 461.762,129.826 461.771,129.819 461.78,129.812 461.79,129.806 461.799,129.799 461.808,129.792 461.817,129.786 461.826,129.779 461.836,129.772 461.845,129.766 461.854,129.759 461.863,129.753 461.872,129.746 461.882,129.739 461.891,129.733 461.9,129.726 461.909,129.719 461.918,129.713 461.927,129.706 461.937,129.7 461.946,129.693 461.955,129.686 461.964,129.68 461.973,129.673 461.983,129.666 461.992,129.66 462.001,129.653 462.01,129.647 462.019,129.64 462.029,129.633 462.038,129.627 462.047,129.62 462.056,129.613 462.065,129.607 462.075,129.6 462.084,129.594 462.093,129.587 462.102,129.58 462.111,129.574 462.12,129.567 462.13,129.561 462.139,129.554 462.148,129.547 462.157,129.541 462.166,129.534 462.176,129.527 462.185,129.521 462.194,129.514 462.203,129.508 462.212,129.501 462.222,129.494 462.231,129.488 462.24,129.481 462.249,129.475 462.258,129.468 462.268,129.461 462.277,129.455 462.286,129.448 462.295,129.442 462.304,129.435 462.313,129.428 462.323,129.422 462.332,129.415 462.341,129.409 462.35,129.402 462.359,129.395 462.369,129.389 462.378,129.382 462.387,129.376 462.396,129.369 462.405,129.362 462.415,129.356 462.424,129.349 462.433,129.343 462.442,129.336 462.451,129.33 462.46,129.323 462.47,129.316 462.479,129.31 462.488,129.303 462.497,129.297 462.506,129.29 462.516,129.283 462.525,129.277 462.534,129.27 462.543,129.264 462.552,129.257 462.562,129.25 462.571,129.244 462.58,129.237 462.589,129.231 462.598,129.224 462.608,129.218 462.617,129.211 462.626,129.204 462.635,129.198 462.644,129.191 462.653,129.185 462.663,129.178 462.672,129.172 462.681,129.165 462.69,129.158 462.699,129.152 462.709,129.145 462.718,129.139 462.727,129.132 462.736,129.126 462.745,129.119 462.755,129.112 462.764,129.106 462.773,129.099 462.782,129.093 462.791,129.086 462.8,129.08 462.81,129.073 462.819,129.067 462.828,129.06 462.837,129.053 462.846,129.047 462.856,129.04 462.865,129.034 462.874,129.027 462.883,129.021 462.892,129.014 462.902,129.008 462.911,129.001 462.92,128.994 462.929,128.988 462.938,128.981 462.948,128.975 462.957,128.968 462.966,128.962 462.975,128.955 462.984,128.949 462.993,128.942 463.003,128.935 463.012,128.929 463.021,128.922 463.03,128.916 463.039,128.909 463.049,128.903 463.058,128.896 463.067,128.89 463.076,128.883 463.085,128.877 463.095,128.87 463.104,128.863 463.113,128.857 463.122,128.85 463.131,128.844 463.14,128.837 463.15,128.831 463.159,128.824 463.168,128.818 463.177,128.811 463.186,128.805 463.196,128.798 463.205,128.792 463.214,128.785 463.223,128.779 463.232,128.772 463.242,128.765 463.251,128.759 463.26,128.752 463.269,128.746 463.278,128.739 463.288,128.733 463.297,128.726 463.306,128.72 463.315,128.713 463.324,128.707 463.333,128.7 463.343,128.694 463.352,128.687 463.361,128.681 463.37,128.674 463.379,128.668 463.389,128.661 463.398,128.655 463.407,128.648 463.416,128.642 463.425,128.635 463.435,128.628 463.444,128.622 463.453,128.615 463.462,128.609 463.471,128.602 463.48,128.596 463.49,128.589 463.499,128.583 463.508,128.576 463.517,128.57 463.526,128.563 463.536,128.557 463.545,128.55 463.554,128.544 463.563,128.537 463.572,128.531 463.582,128.524 463.591,128.518 463.6,128.511 463.609,128.505 463.618,128.498 463.628,128.492 463.637,128.485 463.646,128.479 463.655,128.472 463.664,128.466 463.673,128.459 463.683,128.453 463.692,128.446 463.701,128.44 463.71,128.433 463.719,128.427 463.729,128.42 463.738,128.414 463.747,128.407 463.756,128.401 463.765,128.394 463.775,128.388 463.784,128.381 463.793,128.375 463.802,128.368 463.811,128.362 463.82,128.355 463.83,128.349 463.839,128.342 463.848,128.336 463.857,128.329 463.866,128.323 463.876,128.317 463.885,128.31 463.894,128.304 463.903,128.297 463.912,128.291 463.922,128.284 463.931,128.278 463.94,128.271 463.949,128.265 463.958,128.258 463.968,128.252 463.977,128.245 463.986,128.239 463.995,128.232 464.004,128.226 464.013,128.219 464.023,128.213 464.032,128.206 464.041,128.2 464.05,128.193 464.059,128.187 464.069,128.181 464.078,128.174 464.087,128.168 464.096,128.161 464.105,128.155 464.115,128.148 464.124,128.142 464.133,128.135 464.142,128.129 464.151,128.122 464.16,128.116 464.17,128.109 464.179,128.103 464.188,128.096 464.197,128.09 464.206,128.084 464.216,128.077 464.225,128.071 464.234,128.064 464.243,128.058 464.252,128.051 464.262,128.045 464.271,128.038 464.28,128.032 464.289,128.025 464.298,128.019 464.308,128.013 464.317,128.006 464.326,128 464.335,127.993 464.344,127.987 464.353,127.98 464.363,127.974 464.372,127.967 464.381,127.961 464.39,127.955 464.399,127.948 464.409,127.942 464.418,127.935 464.427,127.929 464.436,127.922 464.445,127.916 464.455,127.909 464.464,127.903 464.473,127.897 464.482,127.89 464.491,127.884 464.5,127.877 464.51,127.871 464.519,127.864 464.528,127.858 464.537,127.851 464.546,127.845 464.556,127.839 464.565,127.832 464.574,127.826 464.583,127.819 464.592,127.813 464.602,127.806 464.611,127.8 464.62,127.794 464.629,127.787 464.638,127.781 464.648,127.774 464.657,127.768 464.666,127.761 464.675,127.755 464.684,127.749 464.693,127.742 464.703,127.736 464.712,127.729 464.721,127.723 464.73,127.717 464.739,127.71 464.749,127.704 464.758,127.697 464.767,127.691 464.776,127.684 464.785,127.678 464.795,127.672 464.804,127.665 464.813,127.659 464.822,127.652 464.831,127.646 464.841,127.64 464.85,127.633 464.859,127.627 464.868,127.62 464.877,127.614 464.886,127.607 464.896,127.601 464.905,127.595 464.914,127.588 464.923,127.582 464.932,127.575 464.942,127.569 464.951,127.563 464.96,127.556 464.969,127.55 464.978,127.543 464.988,127.537 464.997,127.531 465.006,127.524 465.015,127.518 465.024,127.511 465.033,127.505 465.043,127.499 465.052,127.492 465.061,127.486 465.07,127.479 465.079,127.473 465.089,127.467 465.098,127.46 465.107,127.454 465.116,127.447 465.125,127.441 465.135,127.435 465.144,127.428 465.153,127.422 465.162,127.416 465.171,127.409 465.181,127.403 465.19,127.396 465.199,127.39 465.208,127.384 465.217,127.377 465.226,127.371 465.236,127.364 465.245,127.358 465.254,127.352 465.263,127.345 465.272,127.339 465.282,127.333 465.291,127.326 465.3,127.32 465.309,127.313 465.318,127.307 465.328,127.301 465.337,127.294 465.346,127.288 465.355,127.281 465.364,127.275 465.373,127.269 465.383,127.262 465.392,127.256 465.401,127.25 465.41,127.243 465.419,127.237 465.429,127.231 465.438,127.224 465.447,127.218 465.456,127.211 465.465,127.205 465.475,127.199 465.484,127.192 465.493,127.186 465.502,127.18 465.511,127.173 465.521,127.167 465.53,127.16 465.539,127.154 465.548,127.148 465.557,127.141 465.566,127.135 465.576,127.129 465.585,127.122 465.594,127.116 465.603,127.11 465.612,127.103 465.622,127.097 465.631,127.091 465.64,127.084 465.649,127.078 465.658,127.071 465.668,127.065 465.677,127.059 465.686,127.052 465.695,127.046 465.704,127.04 465.713,127.033 465.723,127.027 465.732,127.021 465.741,127.014 465.75,127.008 465.759,127.002 465.769,126.995 465.778,126.989 465.787,126.983 465.796,126.976 465.805,126.97 465.815,126.964 465.824,126.957 465.833,126.951 465.842,126.945 465.851,126.938 465.861,126.932 465.87,126.926 465.879,126.919 465.888,126.913 465.897,126.907 465.906,126.9 465.916,126.894 465.925,126.888 465.934,126.881 465.943,126.875 465.952,126.869 465.962,126.862 465.971,126.856 465.98,126.85 465.989,126.843 465.998,126.837 466.008,126.831 466.017,126.824 466.026,126.818 466.035,126.812 466.044,126.805 466.053,126.799 466.063,126.793 466.072,126.786 466.081,126.78 466.09,126.774 466.099,126.767 466.109,126.761 466.118,126.755 466.127,126.748 466.136,126.742 466.145,126.736 466.155,126.729 466.164,126.723 466.173,126.717 466.182,126.71 466.191,126.704 466.201,126.698 466.21,126.692 466.219,126.685 466.228,126.679 466.237,126.673 466.246,126.666 466.256,126.66 466.265,126.654 466.274,126.647 466.283,126.641 466.292,126.635 466.302,126.628 466.311,126.622 466.32,126.616 466.329,126.609 466.338,126.603 466.348,126.597 466.357,126.591 466.366,126.584 466.375,126.578 466.384,126.572 466.393,126.565 466.403,126.559 466.412,126.553 466.421,126.546 466.43,126.54 466.439,126.534 466.449,126.528 466.458,126.521 466.467,126.515 466.476,126.509 466.485,126.502 466.495,126.496 466.504,126.49 466.513,126.484 466.522,126.477 466.531,126.471 466.541,126.465 466.55,126.458 466.559,126.452 466.568,126.446 466.577,126.44 466.586,126.433 466.596,126.427 466.605,126.421 466.614,126.414 466.623,126.408 466.632,126.402 466.642,126.396 466.651,126.389 466.66,126.383 466.669,126.377 466.678,126.37 466.688,126.364 466.697,126.358 466.706,126.352 466.715,126.345 466.724,126.339 466.733,126.333 466.743,126.326 466.752,126.32 466.761,126.314 466.77,126.308 466.779,126.301 466.789,126.295 466.798,126.289 466.807,126.283 466.816,126.276 466.825,126.27 466.835,126.264 466.844,126.257 466.853,126.251 466.862,126.245 466.871,126.239 466.881,126.232 466.89,126.226 466.899,126.22 466.908,126.214 466.917,126.207 466.926,126.201 466.936,126.195 466.945,126.189 466.954,126.182 466.963,126.176 466.972,126.17 466.982,126.164 466.991,126.157 467,126.151 467.009,126.145 467.018,126.138 467.028,126.132 467.037,126.126 467.046,126.12 467.055,126.113 467.064,126.107 467.074,126.101 467.083,126.095 467.092,126.088 467.101,126.082 467.11,126.076 467.119,126.07 467.129,126.063 467.138,126.057 467.147,126.051 467.156,126.045 467.165,126.038 467.175,126.032 467.184,126.026 467.193,126.02 467.202,126.014 467.211,126.007 467.221,126.001 467.23,125.995 467.239,125.989 467.248,125.982 467.257,125.976 467.266,125.97 467.276,125.964 467.285,125.957 467.294,125.951 467.303,125.945 467.312,125.939 467.322,125.932 467.331,125.926 467.34,125.92 467.349,125.914 467.358,125.907 467.368,125.901 467.377,125.895 467.386,125.889 467.395,125.883 467.404,125.876 467.414,125.87 467.423,125.864 467.432,125.858 467.441,125.851 467.45,125.845 467.459,125.839 467.469,125.833 467.478,125.827 467.487,125.82 467.496,125.814 467.505,125.808 467.515,125.802 467.524,125.795 467.533,125.789 467.542,125.783 467.551,125.777 467.561,125.771 467.57,125.764 467.579,125.758 467.588,125.752 467.597,125.746 467.606,125.739 467.616,125.733 467.625,125.727 467.634,125.721 467.643,125.715 467.652,125.708 467.662,125.702 467.671,125.696 467.68,125.69 467.689,125.684 467.698,125.677 467.708,125.671 467.717,125.665 467.726,125.659 467.735,125.653 467.744,125.646 467.754,125.64 467.763,125.634 467.772,125.628 467.781,125.622 467.79,125.615 467.799,125.609 467.809,125.603 467.818,125.597 467.827,125.591 467.836,125.584 467.845,125.578 467.855,125.572 467.864,125.566 467.873,125.56 467.882,125.553 467.891,125.547 467.901,125.541 467.91,125.535 467.919,125.529 467.928,125.522 467.937,125.516 467.946,125.51 467.956,125.504 467.965,125.498 467.974,125.491 467.983,125.485 467.992,125.479 468.002,125.473 468.011,125.467 468.02,125.461 468.029,125.454 468.038,125.448 468.048,125.442 468.057,125.436 468.066,125.43 468.075,125.423 468.084,125.417 468.094,125.411 468.103,125.405 468.112,125.399 468.121,125.393 468.13,125.386 468.139,125.38 468.149,125.374 468.158,125.368 468.167,125.362 468.176,125.356 468.185,125.349 468.195,125.343 468.204,125.337 468.213,125.331 468.222,125.325 468.231,125.318 468.241,125.312 468.25,125.306 468.259,125.3 468.268,125.294 468.277,125.288 468.286,125.281 468.296,125.275 468.305,125.269 468.314,125.263 468.323,125.257 468.332,125.251 468.342,125.245 468.351,125.238 468.36,125.232 468.369,125.226 468.378,125.22 468.388,125.214 468.397,125.208 468.406,125.201 468.415,125.195 468.424,125.189 468.434,125.183 468.443,125.177 468.452,125.171 468.461,125.164 468.47,125.158 468.479,125.152 468.489,125.146 468.498,125.14 468.507,125.134 468.516,125.128 468.525,125.121 468.535,125.115 468.544,125.109 468.553,125.103 468.562,125.097 468.571,125.091 468.581,125.085 468.59,125.078 468.599,125.072 468.608,125.066 468.617,125.06 468.626,125.054 468.636,125.048 468.645,125.042 468.654,125.035 468.663,125.029 468.672,125.023 468.682,125.017 468.691,125.011 468.7,125.005 468.709,124.999 468.718,124.992 468.728,124.986 468.737,124.98 468.746,124.974 468.755,124.968 468.764,124.962 468.774,124.956 468.783,124.95 468.792,124.943 468.801,124.937 468.81,124.931 468.819,124.925 468.829,124.919 468.838,124.913 468.847,124.907 468.856,124.9 468.865,124.894 468.875,124.888 468.884,124.882 468.893,124.876 468.902,124.87 468.911,124.864 468.921,124.858 468.93,124.851 468.939,124.845 468.948,124.839 468.957,124.833 468.966,124.827 468.976,124.821 468.985,124.815 468.994,124.809 469.003,124.803 469.012,124.796 469.022,124.79 469.031,124.784 469.04,124.778 469.049,124.772 469.058,124.766 469.068,124.76 469.077,124.754 469.086,124.748 469.095,124.741 469.104,124.735 469.114,124.729 469.123,124.723 469.132,124.717 469.141,124.711 469.15,124.705 469.159,124.699 469.169,124.693 469.178,124.686 469.187,124.68 469.196,124.674 469.205,124.668 469.215,124.662 469.224,124.656 469.233,124.65 469.242,124.644 469.251,124.638 469.261,124.632 469.27,124.625 469.279,124.619 469.288,124.613 469.297,124.607 469.306,124.601 469.316,124.595 469.325,124.589 469.334,124.583 469.343,124.577 469.352,124.571 469.362,124.565 469.371,124.558 469.38,124.552 469.389,124.546 469.398,124.54 469.408,124.534 469.417,124.528 469.426,124.522 469.435,124.516 469.444,124.51 469.454,124.504 469.463,124.498 469.472,124.492 469.481,124.485 469.49,124.479 469.499,124.473 469.509,124.467 469.518,124.461 469.527,124.455 469.536,124.449 469.545,124.443 469.555,124.437 469.564,124.431 469.573,124.425 469.582,124.419 469.591,124.413 469.601,124.406 469.61,124.4 469.619,124.394 469.628,124.388 469.637,124.382 469.647,124.376 469.656,124.37 469.665,124.364 469.674,124.358 469.683,124.352 469.692,124.346 469.702,124.34 469.711,124.334 469.72,124.328 469.729,124.321 469.738,124.315 469.748,124.309 469.757,124.303 469.766,124.297 469.775,124.291 469.784,124.285 469.794,124.279 469.803,124.273 469.812,124.267 469.821,124.261 469.83,124.255 469.839,124.249 469.849,124.243 469.858,124.237 469.867,124.231 469.876,124.225 469.885,124.218 469.895,124.212 469.904,124.206 469.913,124.2 469.922,124.194 469.931,124.188 469.941,124.182 469.95,124.176 469.959,124.17 469.968,124.164 469.977,124.158 469.987,124.152 469.996,124.146 470.005,124.14 470.014,124.134 470.023,124.128 470.032,124.122 470.042,124.116 470.051,124.11 470.06,124.104 470.069,124.098 470.078,124.091 470.088,124.085 470.097,124.079 470.106,124.073 470.115,124.067 470.124,124.061 470.134,124.055 470.143,124.049 470.152,124.043 470.161,124.037 470.17,124.031 470.179,124.025 470.189,124.019 470.198,124.013 470.207,124.007 470.216,124.001 470.225,123.995 470.235,123.989 470.244,123.983 470.253,123.977 470.262,123.971 470.271,123.965 470.281,123.959 470.29,123.953 470.299,123.947 470.308,123.941 470.317,123.935 470.327,123.929 470.336,123.923 470.345,123.917 470.354,123.911 470.363,123.905 470.372,123.899 470.382,123.892 470.391,123.886 470.4,123.88 470.409,123.874 470.418,123.868 470.428,123.862 470.437,123.856 470.446,123.85 470.455,123.844 470.464,123.838 470.474,123.832 470.483,123.826 470.492,123.82 470.501,123.814 470.51,123.808 470.519,123.802 470.529,123.796 470.538,123.79 470.547,123.784 470.556,123.778 470.565,123.772 470.575,123.766 470.584,123.76 470.593,123.754 470.602,123.748 470.611,123.742 470.621,123.736 470.63,123.73 470.639,123.724 470.648,123.718 470.657,123.712 470.667,123.706 470.676,123.7 470.685,123.694 470.694,123.688 470.703,123.682 470.712,123.676 470.722,123.67 470.731,123.664 470.74,123.658 470.749,123.652 470.758,123.646 470.768,123.64 470.777,123.634 470.786,123.628 470.795,123.622 470.804,123.616 470.814,123.61 470.823,123.604 470.832,123.598 470.841,123.592 470.85,123.586 470.859,123.58 470.869,123.574 470.878,123.568 470.887,123.562 470.896,123.556 470.905,123.55 470.915,123.544 470.924,123.538 470.933,123.532 470.942,123.526 470.951,123.521 470.961,123.515 470.97,123.509 470.979,123.503 470.988,123.497 470.997,123.491 471.007,123.485 471.016,123.479 471.025,123.473 471.034,123.467 471.043,123.461 471.052,123.455 471.062,123.449 471.071,123.443 471.08,123.437 471.089,123.431 471.098,123.425 471.108,123.419 471.117,123.413 471.126,123.407 471.135,123.401 471.144,123.395 471.154,123.389 471.163,123.383 471.172,123.377 471.181,123.371 471.19,123.365 471.199,123.359 471.209,123.353 471.218,123.347 471.227,123.341 471.236,123.335 471.245,123.329 471.255,123.324 471.264,123.318 471.273,123.312 471.282,123.306 471.291,123.3 471.301,123.294 471.31,123.288 471.319,123.282 471.328,123.276 471.337,123.27 471.347,123.264 471.356,123.258 471.365,123.252 471.374,123.246 471.383,123.24 471.392,123.234 471.402,123.228 471.411,123.222 471.42,123.216 471.429,123.21 471.438,123.204 471.448,123.199 471.457,123.193 471.466,123.187 471.475,123.181 471.484,123.175 471.494,123.169 471.503,123.163 471.512,123.157 471.521,123.151 471.53,123.145 471.539,123.139 471.549,123.133 471.558,123.127 471.567,123.121 471.576,123.115 471.585,123.109 471.595,123.103 471.604,123.098 471.613,123.092 471.622,123.086 471.631,123.08 471.641,123.074 471.65,123.068 471.659,123.062 471.668,123.056 471.677,123.05 471.687,123.044 471.696,123.038 471.705,123.032 471.714,123.026 471.723,123.02 471.732,123.014 471.742,123.009 471.751,123.003 471.76,122.997 471.769,122.991 471.778,122.985 471.788,122.979 471.797,122.973 471.806,122.967 471.815,122.961 471.824,122.955 471.834,122.949 471.843,122.943 471.852,122.937 471.861,122.932 471.87,122.926 471.879,122.92 471.889,122.914 471.898,122.908 471.907,122.902 471.916,122.896 471.925,122.89 471.935,122.884 471.944,122.878 471.953,122.872 471.962,122.867 471.971,122.861 471.981,122.855 471.99,122.849 471.999,122.843 472.008,122.837 472.017,122.831 472.027,122.825 472.036,122.819 472.045,122.813 472.054,122.807 472.063,122.802 472.072,122.796 472.082,122.79 472.091,122.784 472.1,122.778 472.109,122.772 472.118,122.766 472.128,122.76 472.137,122.754 472.146,122.748 472.155,122.743 472.164,122.737 472.174,122.731 472.183,122.725 472.192,122.719 472.201,122.713 472.21,122.707 472.22,122.701 472.229,122.695 472.238,122.689 472.247,122.684 472.256,122.678 472.265,122.672 472.275,122.666 472.284,122.66 472.293,122.654 472.302,122.648 472.311,122.642 472.321,122.636 472.33,122.631 472.339,122.625 472.348,122.619 472.357,122.613 472.367,122.607 472.376,122.601 472.385,122.595 472.394,122.589 472.403,122.584 472.412,122.578 472.422,122.572 472.431,122.566 472.44,122.56 472.449,122.554 472.458,122.548 472.468,122.542 472.477,122.536 472.486,122.531 472.495,122.525 472.504,122.519 472.514,122.513 472.523,122.507 472.532,122.501 472.541,122.495 472.55,122.489 472.56,122.484 472.569,122.478 472.578,122.472 472.587,122.466 472.596,122.46 472.605,122.454 472.615,122.448 472.624,122.443 472.633,122.437 472.642,122.431 472.651,122.425 472.661,122.419 472.67,122.413 472.679,122.407 472.688,122.401 472.697,122.396 472.707,122.39 472.716,122.384 472.725,122.378 472.734,122.372 472.743,122.366 472.752,122.36 472.762,122.355 472.771,122.349 472.78,122.343 472.789,122.337 472.798,122.331 472.808,122.325 472.817,122.319 472.826,122.314 472.835,122.308 472.844,122.302 472.854,122.296 472.863,122.29 472.872,122.284 472.881,122.279 472.89,122.273 472.9,122.267 472.909,122.261 472.918,122.255 472.927,122.249 472.936,122.243 472.945,122.238 472.955,122.232 472.964,122.226 472.973,122.22 472.982,122.214 472.991,122.208 473.001,122.203 473.01,122.197 473.019,122.191 473.028,122.185 473.037,122.179 473.047,122.173 473.056,122.168 473.065,122.162 473.074,122.156 473.083,122.15 473.092,122.144 473.102,122.138 473.111,122.132 473.12,122.127 473.129,122.121 473.138,122.115 473.148,122.109 473.157,122.103 473.166,122.098 473.175,122.092 473.184,122.086 473.194,122.08 473.203,122.074 473.212,122.068 473.221,122.063 473.23,122.057 473.24,122.051 473.249,122.045 473.258,122.039 473.267,122.033 473.276,122.028 473.285,122.022 473.295,122.016 473.304,122.01 473.313,122.004 473.322,121.998 473.331,121.993 473.341,121.987 473.35,121.981 473.359,121.975 473.368,121.969 473.377,121.964 473.387,121.958 473.396,121.952 473.405,121.946 473.414,121.94 473.423,121.935 473.432,121.929 473.442,121.923 473.451,121.917 473.46,121.911 473.469,121.905 473.478,121.9 473.488,121.894 473.497,121.888 473.506,121.882 473.515,121.876 473.524,121.871 473.534,121.865 473.543,121.859 473.552,121.853 473.561,121.847 473.57,121.842 473.58,121.836 473.589,121.83 473.598,121.824 473.607,121.818 473.616,121.813 473.625,121.807 473.635,121.801 473.644,121.795 473.653,121.789 473.662,121.784 473.671,121.778 473.681,121.772 473.69,121.766 473.699,121.76 473.708,121.755 473.717,121.749 473.727,121.743 473.736,121.737 473.745,121.731 473.754,121.726 473.763,121.72 473.772,121.714 473.782,121.708 473.791,121.702 473.8,121.697 473.809,121.691 473.818,121.685 473.828,121.679 473.837,121.674 473.846,121.668 473.855,121.662 473.864,121.656 473.874,121.65 473.883,121.645 473.892,121.639 473.901,121.633 473.91,121.627 473.92,121.622 473.929,121.616 473.938,121.61 473.947,121.604 473.956,121.598 473.965,121.593 473.975,121.587 473.984,121.581 473.993,121.575 474.002,121.57 474.011,121.564 474.021,121.558 474.03,121.552 474.039,121.546 474.048,121.541 474.057,121.535 474.067,121.529 474.076,121.523 474.085,121.518 474.094,121.512 474.103,121.506 474.112,121.5 474.122,121.495 474.131,121.489 474.14,121.483 474.149,121.477 474.158,121.471 474.168,121.466 474.177,121.46 474.186,121.454 474.195,121.448 474.204,121.443 474.214,121.437 474.223,121.431 474.232,121.425 474.241,121.42 474.25,121.414 474.26,121.408 474.269,121.402 474.278,121.397 474.287,121.391 474.296,121.385 474.305,121.379 474.315,121.374 474.324,121.368 474.333,121.362 474.342,121.356 474.351,121.351 474.361,121.345 474.37,121.339 474.379,121.333 474.388,121.328 474.397,121.322 474.407,121.316 474.416,121.31 474.425,121.305 474.434,121.299 474.443,121.293 474.452,121.287 474.462,121.282 474.471,121.276 474.48,121.27 474.489,121.264 474.498,121.259 474.508,121.253 474.517,121.247 474.526,121.241 474.535,121.236 474.544,121.23 474.554,121.224 474.563,121.218 474.572,121.213 474.581,121.207 474.59,121.201 474.6,121.196 474.609,121.19 474.618,121.184 474.627,121.178 474.636,121.173 474.645,121.167 474.655,121.161 474.664,121.155 474.673,121.15 474.682,121.144 474.691,121.138 474.701,121.132 474.71,121.127 474.719,121.121 474.728,121.115 474.737,121.11 474.747,121.104 474.756,121.098 474.765,121.092 474.774,121.087 474.783,121.081 474.793,121.075 474.802,121.07 474.811,121.064 474.82,121.058 474.829,121.052 474.838,121.047 474.848,121.041 474.857,121.035 474.866,121.029 474.875,121.024 474.884,121.018 474.894,121.012 474.903,121.007 474.912,121.001 474.921,120.995 474.93,120.989 474.94,120.984 474.949,120.978 474.958,120.972 474.967,120.967 474.976,120.961 474.985,120.955 474.995,120.95 475.004,120.944 475.013,120.938 475.022,120.932 475.031,120.927 475.041,120.921 475.05,120.915 475.059,120.91 475.068,120.904 475.077,120.898 475.087,120.892 475.096,120.887 475.105,120.881 475.114,120.875 475.123,120.87 475.133,120.864 475.142,120.858 475.151,120.853 475.16,120.847 475.169,120.841 475.178,120.835 475.188,120.83 475.197,120.824 475.206,120.818 475.215,120.813 475.224,120.807 475.234,120.801 475.243,120.796 475.252,120.79 475.261,120.784 475.27,120.779 475.28,120.773 475.289,120.767 475.298,120.761 475.307,120.756 475.316,120.75 475.325,120.744 475.335,120.739 475.344,120.733 475.353,120.727 475.362,120.722 475.371,120.716 475.381,120.71 475.39,120.705 475.399,120.699 475.408,120.693 475.417,120.688 475.427,120.682 475.436,120.676 475.445,120.671 475.454,120.665 475.463,120.659 475.473,120.654 475.482,120.648 475.491,120.642 475.5,120.636 475.509,120.631 475.518,120.625 475.528,120.619 475.537,120.614 475.546,120.608 475.555,120.602 475.564,120.597 475.574,120.591 475.583,120.585 475.592,120.58 475.601,120.574 475.61,120.568 475.62,120.563 475.629,120.557 475.638,120.551 475.647,120.546 475.656,120.54 475.665,120.534 475.675,120.529 475.684,120.523 475.693,120.517 475.702,120.512 475.711,120.506 475.721,120.5 475.73,120.495 475.739,120.489 475.748,120.483 475.757,120.478 475.767,120.472 475.776,120.467 475.785,120.461 475.794,120.455 475.803,120.45 475.813,120.444 475.822,120.438 475.831,120.433 475.84,120.427 475.849,120.421 475.858,120.416 475.868,120.41 475.877,120.404 475.886,120.399 475.895,120.393 475.904,120.387 475.914,120.382 475.923,120.376 475.932,120.37 475.941,120.365 475.95,120.359 475.96,120.353 475.969,120.348 475.978,120.342 475.987,120.337 475.996,120.331 476.005,120.325 476.015,120.32 476.024,120.314 476.033,120.308 476.042,120.303 476.051,120.297 476.061,120.291 476.07,120.286 476.079,120.28 476.088,120.275 476.097,120.269 476.107,120.263 476.116,120.258 476.125,120.252 476.134,120.246 476.143,120.241 476.153,120.235 476.162,120.229 476.171,120.224 476.18,120.218 476.189,120.213 476.198,120.207 476.208,120.201 476.217,120.196 476.226,120.19 476.235,120.184 476.244,120.179 476.254,120.173 476.263,120.168 476.272,120.162 476.281,120.156 476.29,120.151 476.3,120.145 476.309,120.139 476.318,120.134 476.327,120.128 476.336,120.123 476.345,120.117 476.355,120.111 476.364,120.106 476.373,120.1 476.382,120.094 476.391,120.089 476.401,120.083 476.41,120.078 476.419,120.072 476.428,120.066 476.437,120.061 476.447,120.055 476.456,120.05 476.465,120.044 476.474,120.038 476.483,120.033 476.493,120.027 476.502,120.021 476.511,120.016 476.52,120.01 476.529,120.005 476.538,119.999 476.548,119.993 476.557,119.988 476.566,119.982 476.575,119.977 476.584,119.971 476.594,119.965 476.603,119.96 476.612,119.954 476.621,119.949 476.63,119.943 476.64,119.937 476.649,119.932 476.658,119.926 476.667,119.921 476.676,119.915 476.685,119.909 476.695,119.904 476.704,119.898 476.713,119.893 476.722,119.887 476.731,119.881 476.741,119.876 476.75,119.87 476.759,119.865 476.768,119.859 476.777,119.853 476.787,119.848 476.796,119.842 476.805,119.837 476.814,119.831 476.823,119.826 476.833,119.82 476.842,119.814 476.851,119.809 476.86,119.803 476.869,119.798 476.878,119.792 476.888,119.786 476.897,119.781 476.906,119.775 476.915,119.77 476.924,119.764 476.934,119.758 476.943,119.753 476.952,119.747 476.961,119.742 476.97,119.736 476.98,119.731 476.989,119.725 476.998,119.719 477.007,119.714 477.016,119.708 477.026,119.703 477.035,119.697 477.044,119.692 477.053,119.686 477.062,119.68 477.071,119.675 477.081,119.669 477.09,119.664 477.099,119.658 477.108,119.653 477.117,119.647 477.127,119.641 477.136,119.636 477.145,119.63 477.154,119.625 477.163,119.619 477.173,119.614 477.182,119.608 477.191,119.602 477.2,119.597 477.209,119.591 477.218,119.586 477.228,119.58 477.237,119.575 477.246,119.569 477.255,119.564 477.264,119.558 477.274,119.552 477.283,119.547 477.292,119.541 477.301,119.536 477.31,119.53 477.32,119.525 477.329,119.519 477.338,119.513 477.347,119.508 477.356,119.502 477.366,119.497 477.375,119.491 477.384,119.486 477.393,119.48 477.402,119.475 477.411,119.469 477.421,119.464 477.43,119.458 477.439,119.452 477.448,119.447 477.457,119.441 477.467,119.436 477.476,119.43 477.485,119.425 477.494,119.419 477.503,119.414 477.513,119.408 477.522,119.402 477.531,119.397 477.54,119.391 477.549,119.386 477.558,119.38 477.568,119.375 477.577,119.369 477.586,119.364 477.595,119.358 477.604,119.353 477.614,119.347 477.623,119.342 477.632,119.336 477.641,119.33 477.65,119.325 477.66,119.319 477.669,119.314 477.678,119.308 477.687,119.303 477.696,119.297 477.706,119.292 477.715,119.286 477.724,119.281 477.733,119.275 477.742,119.27 477.751,119.264 477.761,119.259 477.77,119.253 477.779,119.247 477.788,119.242 477.797,119.236 477.807,119.231 477.816,119.225 477.825,119.22 477.834,119.214 477.843,119.209 477.853,119.203 477.862,119.198 477.871,119.192 477.88,119.187 477.889,119.181 477.898,119.176 477.908,119.17 477.917,119.165 477.926,119.159 477.935,119.154 477.944,119.148 477.954,119.143 477.963,119.137 477.972,119.132 477.981,119.126 477.99,119.121 478,119.115 478.009,119.11 478.018,119.104 478.027,119.098 478.036,119.093 478.046,119.087 478.055,119.082 478.064,119.076 478.073,119.071 478.082,119.065 478.091,119.06 478.101,119.054 478.11,119.049 478.119,119.043 478.128,119.038 478.137,119.032 478.147,119.027 478.156,119.021 478.165,119.016 478.174,119.01 478.183,119.005 478.193,118.999 478.202,118.994 478.211,118.988 478.22,118.983 478.229,118.977 478.238,118.972 478.248,118.966 478.257,118.961 478.266,118.955 478.275,118.95 478.284,118.944 478.294,118.939 478.303,118.933 478.312,118.928 478.321,118.922 478.33,118.917 478.34,118.911 478.349,118.906 478.358,118.9 478.367,118.895 478.376,118.889 478.386,118.884 478.395,118.878 478.404,118.873 478.413,118.868 478.422,118.862 478.431,118.857 478.441,118.851 478.45,118.846 478.459,118.84 478.468,118.835 478.477,118.829 478.487,118.824 478.496,118.818 478.505,118.813 478.514,118.807 478.523,118.802 478.533,118.796 478.542,118.791 478.551,118.785 478.56,118.78 478.569,118.774 478.578,118.769 478.588,118.763 478.597,118.758 478.606,118.752 478.615,118.747 478.624,118.741 478.634,118.736 478.643,118.731 478.652,118.725 478.661,118.72 478.67,118.714 478.68,118.709 478.689,118.703 478.698,118.698 478.707,118.692 478.716,118.687 478.726,118.681 478.735,118.676 478.744,118.67 478.753,118.665 478.762,118.659 478.771,118.654 478.781,118.649 478.79,118.643 478.799,118.638 478.808,118.632 478.817,118.627 478.827,118.621 478.836,118.616 478.845,118.61 478.854,118.605 478.863,118.599 478.873,118.594 478.882,118.588 478.891,118.583 478.9,118.578 478.909,118.572 478.918,118.567 478.928,118.561 478.937,118.556 478.946,118.55 478.955,118.545 478.964,118.539 478.974,118.534 478.983,118.528 478.992,118.523 479.001,118.518 479.01,118.512 479.02,118.507 479.029,118.501 479.038,118.496 479.047,118.49 479.056,118.485 479.066,118.479 479.075,118.474 479.084,118.469 479.093,118.463 479.102,118.458 479.111,118.452 479.121,118.447 479.13,118.441 479.139,118.436 479.148,118.43 479.157,118.425 479.167,118.42 479.176,118.414 479.185,118.409 479.194,118.403 479.203,118.398 479.213,118.392 479.222,118.387 479.231,118.382 479.24,118.376 479.249,118.371 479.258,118.365 479.268,118.36 479.277,118.354 479.286,118.349 479.295,118.343 479.304,118.338 479.314,118.333 479.323,118.327 479.332,118.322 479.341,118.316 479.35,118.311 479.36,118.305 479.369,118.3 479.378,118.295 479.387,118.289 479.396,118.284 479.406,118.278 479.415,118.273 479.424,118.268 479.433,118.262 479.442,118.257 479.451,118.251 479.461,118.246 479.47,118.24 479.479,118.235 479.488,118.23 479.497,118.224 479.507,118.219 479.516,118.213 479.525,118.208 479.534,118.202 479.543,118.197 479.553,118.192 479.562,118.186 479.571,118.181 479.58,118.175 479.589,118.17 479.599,118.165 479.608,118.159 479.617,118.154 479.626,118.148 479.635,118.143 479.644,118.138 479.654,118.132 479.663,118.127 479.672,118.121 479.681,118.116 479.69,118.111 479.7,118.105 479.709,118.1 479.718,118.094 479.727,118.089 479.736,118.083 479.746,118.078 479.755,118.073 479.764,118.067 479.773,118.062 479.782,118.056 479.791,118.051 479.801,118.046 479.81,118.04 479.819,118.035 479.828,118.029 479.837,118.024 479.847,118.019 479.856,118.013 479.865,118.008 479.874,118.003 479.883,117.997 479.893,117.992 479.902,117.986 479.911,117.981 479.92,117.976 479.929,117.97 479.939,117.965 479.948,117.959 479.957,117.954 479.966,117.949 479.975,117.943 479.984,117.938 479.994,117.932 480.003,117.927 480.012,117.922 480.021,117.916 480.03,117.911 480.04,117.905 480.049,117.9 480.058,117.895 480.067,117.889 480.076,117.884 480.086,117.879 480.095,117.873 480.104,117.868 480.113,117.862 480.122,117.857 480.131,117.852 480.141,117.846 480.15,117.841 480.159,117.836 480.168,117.83 480.177,117.825 480.187,117.819 480.196,117.814 480.205,117.809 480.214,117.803 480.223,117.798 480.233,117.793 480.242,117.787 480.251,117.782 480.26,117.776 480.269,117.771 480.279,117.766 480.288,117.76 480.297,117.755 480.306,117.75 480.315,117.744 480.324,117.739 480.334,117.734 480.343,117.728 480.352,117.723 480.361,117.717 480.37,117.712 480.38,117.707 480.389,117.701 480.398,117.696 480.407,117.691 480.416,117.685 480.426,117.68 480.435,117.675 480.444,117.669 480.453,117.664 480.462,117.658 480.471,117.653 480.481,117.648 480.49,117.642 480.499,117.637 480.508,117.632 480.517,117.626 480.527,117.621 480.536,117.616 480.545,117.61 480.554,117.605 480.563,117.6 480.573,117.594 480.582,117.589 480.591,117.583 480.6,117.578 480.609,117.573 480.619,117.567 480.628,117.562 480.637,117.557 480.646,117.551 480.655,117.546 480.664,117.541 480.674,117.535 480.683,117.53 480.692,117.525 480.701,117.519 480.71,117.514 480.72,117.509 480.729,117.503 480.738,117.498 480.747,117.493 480.756,117.487 480.766,117.482 480.775,117.477 480.784,117.471 480.793,117.466 480.802,117.461 480.811,117.455 480.821,117.45 480.83,117.445 480.839,117.439 480.848,117.434 480.857,117.429 480.867,117.423 480.876,117.418 480.885,117.413 480.894,117.407 480.903,117.402 480.913,117.397 480.922,117.391 480.931,117.386 480.94,117.381 480.949,117.375 480.959,117.37 480.968,117.365 480.977,117.359 480.986,117.354 480.995,117.349 481.004,117.343 481.014,117.338 481.023,117.333 481.032,117.327 481.041,117.322 481.05,117.317 481.06,117.311 481.069,117.306 481.078,117.301 481.087,117.295 481.096,117.29 481.106,117.285 481.115,117.28 481.124,117.274 481.133,117.269 481.142,117.264 481.151,117.258 481.161,117.253 481.17,117.248 481.179,117.242 481.188,117.237 481.197,117.232 481.207,117.226 481.216,117.221 481.225,117.216 481.234,117.21 481.243,117.205 481.253,117.2 481.262,117.195 481.271,117.189 481.28,117.184 481.289,117.179 481.299,117.173 481.308,117.168 481.317,117.163 481.326,117.157 481.335,117.152 481.344,117.147 481.354,117.141 481.363,117.136 481.372,117.131 481.381,117.126 481.39,117.12 481.4,117.115 481.409,117.11 481.418,117.104 481.427,117.099 481.436,117.094 481.446,117.088 481.455,117.083 481.464,117.078 481.473,117.073 481.482,117.067 481.491,117.062 481.501,117.057 481.51,117.051 481.519,117.046 481.528,117.041 481.537,117.036 481.547,117.03 481.556,117.025 481.565,117.02 481.574,117.014 481.583,117.009 481.593,117.004 481.602,116.999 481.611,116.993 481.62,116.988 481.629,116.983 481.639,116.977 481.648,116.972 481.657,116.967 481.666,116.962 481.675,116.956 481.684,116.951 481.694,116.946 481.703,116.94 481.712,116.935 481.721,116.93 481.73,116.925 481.74,116.919 481.749,116.914 481.758,116.909 481.767,116.903 481.776,116.898 481.786,116.893 481.795,116.888 481.804,116.882 481.813,116.877 481.822,116.872 481.831,116.867 481.841,116.861 481.85,116.856 481.859,116.851 481.868,116.845 481.877,116.84 481.887,116.835 481.896,116.83 481.905,116.824 481.914,116.819 481.923,116.814 481.933,116.809 481.942,116.803 481.951,116.798 481.96,116.793 481.969,116.787 481.979,116.782 481.988,116.777 481.997,116.772 482.006,116.766 482.015,116.761 482.024,116.756 482.034,116.751 482.043,116.745 482.052,116.74 482.061,116.735 482.07,116.73 482.08,116.724 482.089,116.719 482.098,116.714 482.107,116.709 482.116,116.703 482.126,116.698 482.135,116.693 482.144,116.688 482.153,116.682 482.162,116.677 482.172,116.672 482.181,116.667 482.19,116.661 482.199,116.656 482.208,116.651 482.217,116.646 482.227,116.64 482.236,116.635 482.245,116.63 482.254,116.625 482.263,116.619 482.273,116.614 482.282,116.609 482.291,116.604 482.3,116.598 482.309,116.593 482.319,116.588 482.328,116.583 482.337,116.577 482.346,116.572 482.355,116.567 482.364,116.562 482.374,116.556 482.383,116.551 482.392,116.546 482.401,116.541 482.41,116.535 482.42,116.53 482.429,116.525 482.438,116.52 482.447,116.515 482.456,116.509 482.466,116.504 482.475,116.499 482.484,116.494 482.493,116.488 482.502,116.483 482.512,116.478 482.521,116.473 482.53,116.467 482.539,116.462 482.548,116.457 482.557,116.452 482.567,116.446 482.576,116.441 482.585,116.436 482.594,116.431 482.603,116.426 482.613,116.42 482.622,116.415 482.631,116.41 482.64,116.405 482.649,116.399 482.659,116.394 482.668,116.389 482.677,116.384 482.686,116.379 482.695,116.373 482.704,116.368 482.714,116.363 482.723,116.358 482.732,116.352 482.741,116.347 482.75,116.342 482.76,116.337 482.769,116.332 482.778,116.326 482.787,116.321 482.796,116.316 482.806,116.311 482.815,116.306 482.824,116.3 482.833,116.295 482.842,116.29 482.852,116.285 482.861,116.279 482.87,116.274 482.879,116.269 482.888,116.264 482.897,116.259 482.907,116.253 482.916,116.248 482.925,116.243 482.934,116.238 482.943,116.233 482.953,116.227 482.962,116.222 482.971,116.217 482.98,116.212 482.989,116.207 482.999,116.201 483.008,116.196 483.017,116.191 483.026,116.186 483.035,116.181 483.044,116.175 483.054,116.17 483.063,116.165 483.072,116.16 483.081,116.155 483.09,116.149 483.1,116.144 483.109,116.139 483.118,116.134 483.127,116.129 483.136,116.123 483.146,116.118 483.155,116.113 483.164,116.108 483.173,116.103 483.182,116.097 483.192,116.092 483.201,116.087 483.21,116.082 483.219,116.077 483.228,116.072 483.237,116.066 483.247,116.061 483.256,116.056 483.265,116.051 483.274,116.046 483.283,116.04 483.293,116.035 483.302,116.03 483.311,116.025 483.32,116.02 483.329,116.015 483.339,116.009 483.348,116.004 483.357,115.999 483.366,115.994 483.375,115.989 483.384,115.983 483.394,115.978 483.403,115.973 483.412,115.968 483.421,115.963 483.43,115.958 483.44,115.952 483.449,115.947 483.458,115.942 483.467,115.937 483.476,115.932 483.486,115.927 483.495,115.921 483.504,115.916 483.513,115.911 483.522,115.906 483.532,115.901 483.541,115.896 483.55,115.89 483.559,115.885 483.568,115.88 483.577,115.875 483.587,115.87 483.596,115.865 483.605,115.859 483.614,115.854 483.623,115.849 483.633,115.844 483.642,115.839 483.651,115.834 483.66,115.828 483.669,115.823 483.679,115.818 483.688,115.813 483.697,115.808 483.706,115.803 483.715,115.797 483.724,115.792 483.734,115.787 483.743,115.782 483.752,115.777 483.761,115.772 483.77,115.766 483.78,115.761 483.789,115.756 483.798,115.751 483.807,115.746 483.816,115.741 483.826,115.736 483.835,115.73 483.844,115.725 483.853,115.72 483.862,115.715 483.872,115.71 483.881,115.705 483.89,115.7 483.899,115.694 483.908,115.689 483.917,115.684 483.927,115.679 483.936,115.674 483.945,115.669 483.954,115.663 483.963,115.658 483.973,115.653 483.982,115.648 483.991,115.643 484,115.638 484.009,115.633 484.019,115.627 484.028,115.622 484.037,115.617 484.046,115.612 484.055,115.607 484.064,115.602 484.074,115.597 484.083,115.592 484.092,115.586 484.101,115.581 484.11,115.576 484.12,115.571 484.129,115.566 484.138,115.561 484.147,115.556 484.156,115.55 484.166,115.545 484.175,115.54 484.184,115.535 484.193,115.53 484.202,115.525 484.212,115.52 484.221,115.515 484.23,115.509 484.239,115.504 484.248,115.499 484.257,115.494 484.267,115.489 484.276,115.484 484.285,115.479 484.294,115.474 484.303,115.468 484.313,115.463 484.322,115.458 484.331,115.453 484.34,115.448 484.349,115.443 484.359,115.438 484.368,115.433 484.377,115.427 484.386,115.422 484.395,115.417 484.405,115.412 484.414,115.407 484.423,115.402 484.432,115.397 484.441,115.392 484.45,115.387 484.46,115.381 484.469,115.376 484.478,115.371 484.487,115.366 484.496,115.361 484.506,115.356 484.515,115.351 484.524,115.346 484.533,115.341 484.542,115.335 484.552,115.33 484.561,115.325 484.57,115.32 484.579,115.315 484.588,115.31 484.597,115.305 484.607,115.3 484.616,115.295 484.625,115.289 484.634,115.284 484.643,115.279 484.653,115.274 484.662,115.269 484.671,115.264 484.68,115.259 484.689,115.254 484.699,115.249 484.708,115.244 484.717,115.238 484.726,115.233 484.735,115.228 484.745,115.223 484.754,115.218 484.763,115.213 484.772,115.208 484.781,115.203 484.79,115.198 484.8,115.193 484.809,115.188 484.818,115.182 484.827,115.177 484.836,115.172 484.846,115.167 484.855,115.162 484.864,115.157 484.873,115.152 484.882,115.147 484.892,115.142 484.901,115.137 484.91,115.132 484.919,115.126 484.928,115.121 484.937,115.116 484.947,115.111 484.956,115.106 484.965,115.101 484.974,115.096 484.983,115.091 484.993,115.086 485.002,115.081 485.011,115.076 485.02,115.071 485.029,115.065 485.039,115.06 485.048,115.055 485.057,115.05 485.066,115.045 485.075,115.04 485.085,115.035 485.094,115.03 485.103,115.025 485.112,115.02 485.121,115.015 485.13,115.01 485.14,115.005 485.149,114.999 485.158,114.994 485.167,114.989 485.176,114.984 485.186,114.979 485.195,114.974 485.204,114.969 485.213,114.964 485.222,114.959 485.232,114.954 485.241,114.949 485.25,114.944 485.259,114.939 485.268,114.934 485.277,114.929 485.287,114.923 485.296,114.918 485.305,114.913 485.314,114.908 485.323,114.903 485.333,114.898 485.342,114.893 485.351,114.888 485.36,114.883 485.369,114.878 485.379,114.873 485.388,114.868 485.397,114.863 485.406,114.858 485.415,114.853 485.425,114.848 485.434,114.843 485.443,114.837 485.452,114.832 485.461,114.827 485.47,114.822 485.48,114.817 485.489,114.812 485.498,114.807 485.507,114.802 485.516,114.797 485.526,114.792 485.535,114.787 485.544,114.782 485.553,114.777 485.562,114.772 485.572,114.767 485.581,114.762 485.59,114.757 485.599,114.752 485.608,114.747 485.617,114.742 485.627,114.736 485.636,114.731 485.645,114.726 485.654,114.721 485.663,114.716 485.673,114.711 485.682,114.706 485.691,114.701 485.7,114.696 485.709,114.691 485.719,114.686 485.728,114.681 485.737,114.676 485.746,114.671 485.755,114.666 485.765,114.661 485.774,114.656 485.783,114.651 485.792,114.646 485.801,114.641 485.81,114.636 485.82,114.631 485.829,114.626 485.838,114.621 485.847,114.616 485.856,114.611 485.866,114.606 485.875,114.6 485.884,114.595 485.893,114.59 485.902,114.585 485.912,114.58 485.921,114.575 485.93,114.57 485.939,114.565 485.948,114.56 485.957,114.555 485.967,114.55 485.976,114.545 485.985,114.54 485.994,114.535 486.003,114.53 486.013,114.525 486.022,114.52 486.031,114.515 486.04,114.51 486.049,114.505 486.059,114.5 486.068,114.495 486.077,114.49 486.086,114.485 486.095,114.48 486.105,114.475 486.114,114.47 486.123,114.465 486.132,114.46 486.141,114.455 486.15,114.45 486.16,114.445 486.169,114.44 486.178,114.435 486.187,114.43 486.196,114.425 486.206,114.42 486.215,114.415 486.224,114.41 486.233,114.405 486.242,114.4 486.252,114.395 486.261,114.39 486.27,114.385 486.279,114.38 486.288,114.375 486.297,114.37 486.307,114.365 486.316,114.36 486.325,114.355 486.334,114.35 486.343,114.345 486.353,114.34 486.362,114.335 486.371,114.33 486.38,114.325 486.389,114.32 486.399,114.315 486.408,114.31 486.417,114.305 486.426,114.3 486.435,114.295 486.445,114.29 486.454,114.285 486.463,114.28 486.472,114.275 486.481,114.27 486.49,114.265 486.5,114.26 486.509,114.255 486.518,114.25 486.527,114.245 486.536,114.24 486.546,114.235 486.555,114.23 486.564,114.225 486.573,114.22 486.582,114.215 486.592,114.21 486.601,114.205 486.61,114.2 486.619,114.195 486.628,114.19 486.637,114.185 486.647,114.18 486.656,114.175 486.665,114.17 486.674,114.165 486.683,114.16 486.693,114.155 486.702,114.15 486.711,114.145 486.72,114.14 486.729,114.135 486.739,114.13 486.748,114.125 486.757,114.12 486.766,114.115 486.775,114.11 486.785,114.105 486.794,114.1 486.803,114.095 486.812,114.09 486.821,114.085 486.83,114.08 486.84,114.075 486.849,114.07 486.858,114.065 486.867,114.061 486.876,114.056 486.886,114.051 486.895,114.046 486.904,114.041 486.913,114.036 486.922,114.031 486.932,114.026 486.941,114.021 486.95,114.016 486.959,114.011 486.968,114.006 486.978,114.001 486.987,113.996 486.996,113.991 487.005,113.986 487.014,113.981 487.023,113.976 487.033,113.971 487.042,113.966 487.051,113.961 487.06,113.956 487.069,113.951 487.079,113.946 487.088,113.941 487.097,113.936 487.106,113.931 487.115,113.926 487.125,113.922 487.134,113.917 487.143,113.912 487.152,113.907 487.161,113.902 487.17,113.897 487.18,113.892 487.189,113.887 487.198,113.882 487.207,113.877 487.216,113.872 487.226,113.867 487.235,113.862 487.244,113.857 487.253,113.852 487.262,113.847 487.272,113.842 487.281,113.837 487.29,113.832 487.299,113.827 487.308,113.823 487.318,113.818 487.327,113.813 487.336,113.808 487.345,113.803 487.354,113.798 487.363,113.793 487.373,113.788 487.382,113.783 487.391,113.778 487.4,113.773 487.409,113.768 487.419,113.763 487.428,113.758 487.437,113.753 487.446,113.748 487.455,113.743 487.465,113.739 487.474,113.734 487.483,113.729 487.492,113.724 487.501,113.719 487.51,113.714 487.52,113.709 487.529,113.704 487.538,113.699 487.547,113.694 487.556,113.689 487.566,113.684 487.575,113.679 487.584,113.674 487.593,113.669 487.602,113.665 487.612,113.66 487.621,113.655 487.63,113.65 487.639,113.645 487.648,113.64 487.658,113.635 487.667,113.63 487.676,113.625 487.685,113.62 487.694,113.615 487.703,113.61 487.713,113.605 487.722,113.601 487.731,113.596 487.74,113.591 487.749,113.586 487.759,113.581 487.768,113.576 487.777,113.571 487.786,113.566 487.795,113.561 487.805,113.556 487.814,113.551 487.823,113.546 487.832,113.542 487.841,113.537 487.85,113.532 487.86,113.527 487.869,113.522 487.878,113.517 487.887,113.512 487.896,113.507 487.906,113.502 487.915,113.497 487.924,113.492 487.933,113.487 487.942,113.483 487.952,113.478 487.961,113.473 487.97,113.468 487.979,113.463 487.988,113.458 487.998,113.453 488.007,113.448 488.016,113.443 488.025,113.438 488.034,113.434 488.043,113.429 488.053,113.424 488.062,113.419 488.071,113.414 488.08,113.409 488.089,113.404 488.099,113.399 488.108,113.394 488.117,113.389 488.126,113.385 488.135,113.38 488.145,113.375 488.154,113.37 488.163,113.365 488.172,113.36 488.181,113.355 488.19,113.35 488.2,113.345 488.209,113.34 488.218,113.336 488.227,113.331 488.236,113.326 488.246,113.321 488.255,113.316 488.264,113.311 488.273,113.306 488.282,113.301 488.292,113.296 488.301,113.292 488.31,113.287 488.319,113.282 488.328,113.277 488.338,113.272 488.347,113.267 488.356,113.262 488.365,113.257 488.374,113.252 488.383,113.248 488.393,113.243 488.402,113.238 488.411,113.233 488.42,113.228 488.429,113.223 488.439,113.218 488.448,113.213 488.457,113.209 488.466,113.204 488.475,113.199 488.485,113.194 488.494,113.189 488.503,113.184 488.512,113.179 488.521,113.174 488.53,113.17 488.54,113.165 488.549,113.16 488.558,113.155 488.567,113.15 488.576,113.145 488.586,113.14 488.595,113.135 488.604,113.131 488.613,113.126 488.622,113.121 488.632,113.116 488.641,113.111 488.65,113.106 488.659,113.101 488.668,113.096 488.678,113.092 488.687,113.087 488.696,113.082 488.705,113.077 488.714,113.072 488.723,113.067 488.733,113.062 488.742,113.058 488.751,113.053 488.76,113.048 488.769,113.043 488.779,113.038 488.788,113.033 488.797,113.028 488.806,113.024 488.815,113.019 488.825,113.014 488.834,113.009 488.843,113.004 488.852,112.999 488.861,112.994 488.87,112.99 488.88,112.985 488.889,112.98 488.898,112.975 488.907,112.97 488.916,112.965 488.926,112.96 488.935,112.956 488.944,112.951 488.953,112.946 488.962,112.941 488.972,112.936 488.981,112.931 488.99,112.926 488.999,112.922 489.008,112.917 489.018,112.912 489.027,112.907 489.036,112.902 489.045,112.897 489.054,112.893 489.063,112.888 489.073,112.883 489.082,112.878 489.091,112.873 489.1,112.868 489.109,112.864 489.119,112.859 489.128,112.854 489.137,112.849 489.146,112.844 489.155,112.839 489.165,112.834 489.174,112.83 489.183,112.825 489.192,112.82 489.201,112.815 489.21,112.81 489.22,112.805 489.229,112.801 489.238,112.796 489.247,112.791 489.256,112.786 489.266,112.781 489.275,112.776 489.284,112.772 489.293,112.767 489.302,112.762 489.312,112.757 489.321,112.752 489.33,112.747 489.339,112.743 489.348,112.738 489.358,112.733 489.367,112.728 489.376,112.723 489.385,112.719 489.394,112.714 489.403,112.709 489.413,112.704 489.422,112.699 489.431,112.694 489.44,112.69 489.449,112.685 489.459,112.68 489.468,112.675 489.477,112.67 489.486,112.665 489.495,112.661 489.505,112.656 489.514,112.651 489.523,112.646 489.532,112.641 489.541,112.637 489.551,112.632 489.56,112.627 489.569,112.622 489.578,112.617 489.587,112.612 489.596,112.608 489.606,112.603 489.615,112.598 489.624,112.593 489.633,112.588 489.642,112.584 489.652,112.579 489.661,112.574 489.67,112.569 489.679,112.564 489.688,112.56 489.698,112.555 489.707,112.55 489.716,112.545 489.725,112.54 489.734,112.536 489.743,112.531 489.753,112.526 489.762,112.521 489.771,112.516 489.78,112.511 489.789,112.507 489.799,112.502 489.808,112.497 489.817,112.492 489.826,112.487 489.835,112.483 489.845,112.478 489.854,112.473 489.863,112.468 489.872,112.463 489.881,112.459 489.891,112.454 489.9,112.449 489.909,112.444 489.918,112.44 489.927,112.435 489.936,112.43 489.946,112.425 489.955,112.42 489.964,112.416 489.973,112.411 489.982,112.406 489.992,112.401 490.001,112.396 490.01,112.392 490.019,112.387 490.028,112.382 490.038,112.377 490.047,112.372 490.056,112.368 490.065,112.363 490.074,112.358 490.083,112.353 490.093,112.348 490.102,112.344 490.111,112.339 490.12,112.334 490.129,112.329 490.139,112.325 490.148,112.32 490.157,112.315 490.166,112.31 490.175,112.305 490.185,112.301 490.194,112.296 490.203,112.291 490.212,112.286 490.221,112.282 490.231,112.277 490.24,112.272 490.249,112.267 490.258,112.262 490.267,112.258 490.276,112.253 490.286,112.248 490.295,112.243 490.304,112.239 490.313,112.234 490.322,112.229 490.332,112.224 490.341,112.219 490.35,112.215 490.359,112.21 490.368,112.205 490.378,112.2 490.387,112.196 490.396,112.191 490.405,112.186 490.414,112.181 490.423,112.177 490.433,112.172 490.442,112.167 490.451,112.162 490.46,112.157 490.469,112.153 490.479,112.148 490.488,112.143 490.497,112.138 490.506,112.134 490.515,112.129 490.525,112.124 490.534,112.119 490.543,112.115 490.552,112.11 490.561,112.105 490.571,112.1 490.58,112.096 490.589,112.091 490.598,112.086 490.607,112.081 490.616,112.077 490.626,112.072 490.635,112.067 490.644,112.062 490.653,112.058 490.662,112.053 490.672,112.048 490.681,112.043 490.69,112.039 490.699,112.034 490.708,112.029 490.718,112.024 490.727,112.02 490.736,112.015 490.745,112.01 490.754,112.005 490.763,112.001 490.773,111.996 490.782,111.991 490.791,111.986 490.8,111.982 490.809,111.977 490.819,111.972 490.828,111.967 490.837,111.963 490.846,111.958 490.855,111.953 490.865,111.948 490.874,111.944 490.883,111.939 490.892,111.934 490.901,111.929 490.911,111.925 490.92,111.92 490.929,111.915 490.938,111.91 490.947,111.906 490.956,111.901 490.966,111.896 490.975,111.891 490.984,111.887 490.993,111.882 491.002,111.877 491.012,111.873 491.021,111.868 491.03,111.863 491.039,111.858 491.048,111.854 491.058,111.849 491.067,111.844 491.076,111.839 491.085,111.835 491.094,111.83 491.103,111.825 491.113,111.821 491.122,111.816 491.131,111.811 491.14,111.806 491.149,111.802 491.159,111.797 491.168,111.792 491.177,111.787 491.186,111.783 491.195,111.778 491.205,111.773 491.214,111.769 491.223,111.764 491.232,111.759 491.241,111.754 491.251,111.75 491.26,111.745 491.269,111.74 491.278,111.735 491.287,111.731 491.296,111.726 491.306,111.721 491.315,111.717 491.324,111.712 491.333,111.707 491.342,111.702 491.352,111.698 491.361,111.693 491.37,111.688 491.379,111.684 491.388,111.679 491.398,111.674 491.407,111.669 491.416,111.665 491.425,111.66 491.434,111.655 491.443,111.651 491.453,111.646 491.462,111.641 491.471,111.637 491.48,111.632 491.489,111.627 491.499,111.622 491.508,111.618 491.517,111.613 491.526,111.608 491.535,111.604 491.545,111.599 491.554,111.594 491.563,111.589 491.572,111.585 491.581,111.58 491.591,111.575 491.6,111.571 491.609,111.566 491.618,111.561 491.627,111.557 491.636,111.552 491.646,111.547 491.655,111.542 491.664,111.538 491.673,111.533 491.682,111.528 491.692,111.524 491.701,111.519 491.71,111.514 491.719,111.51 491.728,111.505 491.738,111.5 491.747,111.496 491.756,111.491 491.765,111.486 491.774,111.481 491.784,111.477 491.793,111.472 491.802,111.467 491.811,111.463 491.82,111.458 491.829,111.453 491.839,111.449 491.848,111.444 491.857,111.439 491.866,111.435 491.875,111.43 491.885,111.425 491.894,111.42 491.903,111.416 491.912,111.411 491.921,111.406 491.931,111.402 491.94,111.397 491.949,111.392 491.958,111.388 491.967,111.383 491.976,111.378 491.986,111.374 491.995,111.369 492.004,111.364 492.013,111.36 492.022,111.355 492.032,111.35 492.041,111.346 492.05,111.341 492.059,111.336 492.068,111.332 492.078,111.327 492.087,111.322 492.096,111.318 492.105,111.313 492.114,111.308 492.124,111.304 492.133,111.299 492.142,111.294 492.151,111.29 492.16,111.285 492.169,111.28 492.179,111.276 492.188,111.271 492.197,111.266 492.206,111.262 492.215,111.257 492.225,111.252 492.234,111.248 492.243,111.243 492.252,111.238 492.261,111.234 492.271,111.229 492.28,111.224 492.289,111.22 492.298,111.215 492.307,111.21 492.316,111.206 492.326,111.201 492.335,111.196 492.344,111.192 492.353,111.187 492.362,111.182 492.372,111.178 492.381,111.173 492.39,111.168 492.399,111.164 492.408,111.159 492.418,111.154 492.427,111.15 492.436,111.145 492.445,111.14 492.454,111.136 492.464,111.131 492.473,111.126 492.482,111.122 492.491,111.117 492.5,111.112 492.509,111.108 492.519,111.103 492.528,111.098 492.537,111.094 492.546,111.089 492.555,111.085 492.565,111.08 492.574,111.075 492.583,111.071 492.592,111.066 492.601,111.061 492.611,111.057 492.62,111.052 492.629,111.047 492.638,111.043 492.647,111.038 492.656,111.033 492.666,111.029 492.675,111.024 492.684,111.02 492.693,111.015 492.702,111.01 492.712,111.006 492.721,111.001 492.73,110.996 492.739,110.992 492.748,110.987 492.758,110.982 492.767,110.978 492.776,110.973 492.785,110.968 492.794,110.964 492.804,110.959 492.813,110.955 492.822,110.95 492.831,110.945 492.84,110.941 492.849,110.936 492.859,110.931 492.868,110.927 492.877,110.922 492.886,110.918 492.895,110.913 492.905,110.908 492.914,110.904 492.923,110.899 492.932,110.894 492.941,110.89 492.951,110.885 492.96,110.881 492.969,110.876 492.978,110.871 492.987,110.867 492.996,110.862 493.006,110.857 493.015,110.853 493.024,110.848 493.033,110.844 493.042,110.839 493.052,110.834 493.061,110.83 493.07,110.825 493.079,110.82 493.088,110.816 493.098,110.811 493.107,110.807 493.116,110.802 493.125,110.797 493.134,110.793 493.144,110.788 493.153,110.783 493.162,110.779 493.171,110.774 493.18,110.77 493.189,110.765 493.199,110.76 493.208,110.756 493.217,110.751 493.226,110.747 493.235,110.742 493.245,110.737 493.254,110.733 493.263,110.728 493.272,110.724 493.281,110.719 493.291,110.714 493.3,110.71 493.309,110.705 493.318,110.701 493.327,110.696 493.336,110.691 493.346,110.687 493.355,110.682 493.364,110.677 493.373,110.673 493.382,110.668 493.392,110.664 493.401,110.659 493.41,110.654 493.419,110.65 493.428,110.645 493.438,110.641 493.447,110.636 493.456,110.631 493.465,110.627 493.474,110.622 493.484,110.618 493.493,110.613 493.502,110.608 493.511,110.604 493.52,110.599 493.529,110.595 493.539,110.59 493.548,110.586 493.557,110.581 493.566,110.576 493.575,110.572 493.585,110.567 493.594,110.563 493.603,110.558 493.612,110.553 493.621,110.549 493.631,110.544 493.64,110.54 493.649,110.535 493.658,110.53 493.667,110.526 493.676,110.521 493.686,110.517 493.695,110.512 493.704,110.508 493.713,110.503 493.722,110.498 493.732,110.494 493.741,110.489 493.75,110.485 493.759,110.48 493.768,110.475 493.778,110.471 493.787,110.466 493.796,110.462 493.805,110.457 493.814,110.453 493.824,110.448 493.833,110.443 493.842,110.439 493.851,110.434 493.86,110.43 493.869,110.425 493.879,110.42 493.888,110.416 493.897,110.411 493.906,110.407 493.915,110.402 493.925,110.398 493.934,110.393 493.943,110.388 493.952,110.384 493.961,110.379 493.971,110.375 493.98,110.37 493.989,110.366 493.998,110.361 494.007,110.356 494.016,110.352 494.026,110.347 494.035,110.343 494.044,110.338 494.053,110.334 494.062,110.329 494.072,110.325 494.081,110.32 494.09,110.315 494.099,110.311 494.108,110.306 494.118,110.302 494.127,110.297 494.136,110.293 494.145,110.288 494.154,110.283 494.164,110.279 494.173,110.274 494.182,110.27 494.191,110.265 494.2,110.261 494.209,110.256 494.219,110.252 494.228,110.247 494.237,110.242 494.246,110.238 494.255,110.233 494.265,110.229 494.274,110.224 494.283,110.22 494.292,110.215 494.301,110.211 494.311,110.206 494.32,110.201 494.329,110.197 494.338,110.192 494.347,110.188 494.357,110.183 494.366,110.179 494.375,110.174 494.384,110.17 494.393,110.165 494.402,110.161 494.412,110.156 494.421,110.151 494.43,110.147 494.439,110.142 494.448,110.138 494.458,110.133 494.467,110.129 494.476,110.124 494.485,110.12 494.494,110.115 494.504,110.111 494.513,110.106 494.522,110.101 494.531,110.097 494.54,110.092 494.549,110.088 494.559,110.083 494.568,110.079 494.577,110.074 494.586,110.07 494.595,110.065 494.605,110.061 494.614,110.056 494.623,110.052 494.632,110.047 494.641,110.042 494.651,110.038 494.66,110.033 494.669,110.029 494.678,110.024 494.687,110.02 494.697,110.015 494.706,110.011 494.715,110.006 494.724,110.002 494.733,109.997 494.742,109.993 494.752,109.988 494.761,109.984 494.77,109.979 494.779,109.975 494.788,109.97 494.798,109.965 494.807,109.961 494.816,109.956 494.825,109.952 494.834,109.947 494.844,109.943 494.853,109.938 494.862,109.934 494.871,109.929 494.88,109.925 494.889,109.92 494.899,109.916 494.908,109.911 494.917,109.907 494.926,109.902 494.935,109.898 494.945,109.893 494.954,109.889 494.963,109.884 494.972,109.88 494.981,109.875 494.991,109.871 495,109.866 495.009,109.861 495.018,109.857 495.027,109.852 495.037,109.848 495.046,109.843 495.055,109.839 495.064,109.834 495.073,109.83 495.082,109.825 495.092,109.821 495.101,109.816 495.11,109.812 495.119,109.807 495.128,109.803 495.138,109.798 495.147,109.794 495.156,109.789 495.165,109.785 495.174,109.78 495.184,109.776 495.193,109.771 495.202,109.767 495.211,109.762 495.22,109.758 495.229,109.753 495.239,109.749 495.248,109.744 495.257,109.74 495.266,109.735 495.275,109.731 495.285,109.726 495.294,109.722 495.303,109.717 495.312,109.713 495.321,109.708 495.331,109.704 495.34,109.699 495.349,109.695 495.358,109.69 495.367,109.686 495.377,109.681 495.386,109.677 495.395,109.672 495.404,109.668 495.413,109.663 495.422,109.659 495.432,109.654 495.441,109.65 495.45,109.645 495.459,109.641 495.468,109.636 495.478,109.632 495.487,109.627 495.496,109.623 495.505,109.618 495.514,109.614 495.524,109.609 495.533,109.605 495.542,109.601 495.551,109.596 495.56,109.592 495.569,109.587 495.579,109.583 495.588,109.578 495.597,109.574 495.606,109.569 495.615,109.565 495.625,109.56 495.634,109.556 495.643,109.551 495.652,109.547 495.661,109.542 495.671,109.538 495.68,109.533 495.689,109.529 495.698,109.524 495.707,109.52 495.717,109.515 495.726,109.511 495.735,109.506 495.744,109.502 495.753,109.497 495.762,109.493 495.772,109.489 495.781,109.484 495.79,109.48 495.799,109.475 495.808,109.471 495.818,109.466 495.827,109.462 495.836,109.457 495.845,109.453 495.854,109.448 495.864,109.444 495.873,109.439 495.882,109.435 495.891,109.43 495.9,109.426 495.909,109.421 495.919,109.417 495.928,109.413 495.937,109.408 495.946,109.404 495.955,109.399 495.965,109.395 495.974,109.39 495.983,109.386 495.992,109.381 496.001,109.377 496.011,109.372 496.02,109.368 496.029,109.363 496.038,109.359 496.047,109.355 496.057,109.35 496.066,109.346 496.075,109.341 496.084,109.337 496.093,109.332 496.102,109.328 496.112,109.323 496.121,109.319 496.13,109.314 496.139,109.31 496.148,109.306 496.158,109.301 496.167,109.297 496.176,109.292 496.185,109.288 496.194,109.283 496.204,109.279 496.213,109.274 496.222,109.27 496.231,109.265 496.24,109.261 496.249,109.257 496.259,109.252 496.268,109.248 496.277,109.243 496.286,109.239 496.295,109.234 496.305,109.23 496.314,109.225 496.323,109.221 496.332,109.217 496.341,109.212 496.351,109.208 496.36,109.203 496.369,109.199 496.378,109.194 496.387,109.19 496.397,109.185 496.406,109.181 496.415,109.177 496.424,109.172 496.433,109.168 496.442,109.163 496.452,109.159 496.461,109.154 496.47,109.15 496.479,109.146 496.488,109.141 496.498,109.137 496.507,109.132 496.516,109.128 496.525,109.123 496.534,109.119 496.544,109.114 496.553,109.11 496.562,109.106 496.571,109.101 496.58,109.097 496.589,109.092 496.599,109.088 496.608,109.083 496.617,109.079 496.626,109.075 496.635,109.07 496.645,109.066 496.654,109.061 496.663,109.057 496.672,109.052 496.681,109.048 496.691,109.044 496.7,109.039 496.709,109.035 496.718,109.03 496.727,109.026 496.737,109.022 496.746,109.017 496.755,109.013 496.764,109.008 496.773,109.004 496.782,108.999 496.792,108.995 496.801,108.991 496.81,108.986 496.819,108.982 496.828,108.977 496.838,108.973 496.847,108.968 496.856,108.964 496.865,108.96 496.874,108.955 496.884,108.951 496.893,108.946 496.902,108.942 496.911,108.938 496.92,108.933 496.93,108.929 496.939,108.924 496.948,108.92 496.957,108.916 496.966,108.911 496.975,108.907 496.985,108.902 496.994,108.898 497.003,108.893 497.012,108.889 497.021,108.885 497.031,108.88 497.04,108.876 497.049,108.871 497.058,108.867 497.067,108.863 497.077,108.858 497.086,108.854 497.095,108.849 497.104,108.845 497.113,108.841 497.122,108.836 497.132,108.832 497.141,108.827 497.15,108.823 497.159,108.819 497.168,108.814 497.178,108.81 497.187,108.805 497.196,108.801 497.205,108.797 497.214,108.792 497.224,108.788 497.233,108.783 497.242,108.779 497.251,108.775 497.26,108.77 497.27,108.766 497.279,108.761 497.288,108.757 497.297,108.753 497.306,108.748 497.315,108.744 497.325,108.74 497.334,108.735 497.343,108.731 497.352,108.726 497.361,108.722 497.371,108.718 497.38,108.713 497.389,108.709 497.398,108.704 497.407,108.7 497.417,108.696 497.426,108.691 497.435,108.687 497.444,108.682 497.453,108.678 497.462,108.674 497.472,108.669 497.481,108.665 497.49,108.661 497.499,108.656 497.508,108.652 497.518,108.647 497.527,108.643 497.536,108.639 497.545,108.634 497.554,108.63 497.564,108.626 497.573,108.621 497.582,108.617 497.591,108.612 497.6,108.608 497.61,108.604 497.619,108.599 497.628,108.595 497.637,108.59 497.646,108.586 497.655,108.582 497.665,108.577 497.674,108.573 497.683,108.569 497.692,108.564 497.701,108.56 497.711,108.556 497.72,108.551 497.729,108.547 497.738,108.542 497.747,108.538 497.757,108.534 497.766,108.529 497.775,108.525 497.784,108.521 497.793,108.516 497.802,108.512 497.812,108.507 497.821,108.503 497.83,108.499 497.839,108.494 497.848,108.49 497.858,108.486 497.867,108.481 497.876,108.477 497.885,108.473 497.894,108.468 497.904,108.464 497.913,108.459 497.922,108.455 497.931,108.451 497.94,108.446 497.95,108.442 497.959,108.438 497.968,108.433 497.977,108.429 497.986,108.425 497.995,108.42 498.005,108.416 498.014,108.412 498.023,108.407 498.032,108.403 498.041,108.398 498.051,108.394 498.06,108.39 498.069,108.385 498.078,108.381 498.087,108.377 498.097,108.372 498.106,108.368 498.115,108.364 498.124,108.359 498.133,108.355 498.142,108.351 498.152,108.346 498.161,108.342 498.17,108.338 498.179,108.333 498.188,108.329 498.198,108.325 498.207,108.32 498.216,108.316 498.225,108.312 498.234,108.307 498.244,108.303 498.253,108.298 498.262,108.294 498.271,108.29 498.28,108.285 498.29,108.281 498.299,108.277 498.308,108.272 498.317,108.268 498.326,108.264 498.335,108.259 498.345,108.255 498.354,108.251 498.363,108.246 498.372,108.242 498.381,108.238 498.391,108.233 498.4,108.229 498.409,108.225 498.418,108.22 498.427,108.216 498.437,108.212 498.446,108.207 498.455,108.203 498.464,108.199 498.473,108.194 498.482,108.19 498.492,108.186 498.501,108.181 498.51,108.177 498.519,108.173 498.528,108.168 498.538,108.164 498.547,108.16 498.556,108.155 498.565,108.151 498.574,108.147 498.584,108.142 498.593,108.138 498.602,108.134 498.611,108.129 498.62,108.125 498.63,108.121 498.639,108.117 498.648,108.112 498.657,108.108 498.666,108.104 498.675,108.099 498.685,108.095 498.694,108.091 498.703,108.086 498.712,108.082 498.721,108.078 498.731,108.073 498.74,108.069 498.749,108.065 498.758,108.06 498.767,108.056 498.777,108.052 498.786,108.047 498.795,108.043 498.804,108.039 498.813,108.034 498.822,108.03 498.832,108.026 498.841,108.022 498.85,108.017 498.859,108.013 498.868,108.009 498.878,108.004 498.887,108 498.896,107.996 498.905,107.991 498.914,107.987 498.924,107.983 498.933,107.978 498.942,107.974 498.951,107.97 498.96,107.966 498.97,107.961 498.979,107.957 498.988,107.953 498.997,107.948 499.006,107.944 499.015,107.94 499.025,107.935 499.034,107.931 499.043,107.927 499.052,107.922 499.061,107.918 499.071,107.914 499.08,107.91 499.089,107.905 499.098,107.901 499.107,107.897 499.117,107.892 499.126,107.888 499.135,107.884 499.144,107.879 499.153,107.875 499.163,107.871 499.172,107.867 499.181,107.862 499.19,107.858 499.199,107.854 499.208,107.849 499.218,107.845 499.227,107.841 499.236,107.837 499.245,107.832 499.254,107.828 499.264,107.824 499.273,107.819 499.282,107.815 499.291,107.811 499.3,107.807 499.31,107.802 499.319,107.798 499.328,107.794 499.337,107.789 499.346,107.785 499.355,107.781 499.365,107.777 499.374,107.772 499.383,107.768 499.392,107.764 499.401,107.759 499.411,107.755 499.42,107.751 499.429,107.747 499.438,107.742 499.447,107.738 499.457,107.734 499.466,107.729 499.475,107.725 499.484,107.721 499.493,107.717 499.503,107.712 499.512,107.708 499.521,107.704 499.53,107.699 499.539,107.695 499.548,107.691 499.558,107.687 499.567,107.682 499.576,107.678 499.585,107.674 499.594,107.67 499.604,107.665 499.613,107.661 499.622,107.657 499.631,107.652 499.64,107.648 499.65,107.644 499.659,107.64 499.668,107.635 499.677,107.631 499.686,107.627 499.695,107.623 499.705,107.618 499.714,107.614 499.723,107.61 499.732,107.606 499.741,107.601 499.751,107.597 499.76,107.593 499.769,107.588 499.778,107.584 499.787,107.58 499.797,107.576 499.806,107.571 499.815,107.567 499.824,107.563 499.833,107.559 499.843,107.554 499.852,107.55 499.861,107.546 499.87,107.542 499.879,107.537 499.888,107.533 499.898,107.529 499.907,107.525 499.916,107.52 499.925,107.516 499.934,107.512 499.944,107.508 499.953,107.503 499.962,107.499 499.971,107.495 499.98,107.49 499.99,107.486 499.999,107.482 500.008,107.478 500.017,107.473 500.026,107.469 500.035,107.465 500.045,107.461 500.054,107.456 500.063,107.452 500.072,107.448 500.081,107.444 500.091,107.439 500.1,107.435 500.109,107.431 500.118,107.427 500.127,107.423 500.137,107.418 500.146,107.414 500.155,107.41 500.164,107.406 500.173,107.401 500.183,107.397 500.192,107.393 500.201,107.389 500.21,107.384 500.219,107.38 500.228,107.376 500.238,107.372 500.247,107.367 500.256,107.363 500.265,107.359 500.274,107.355 500.284,107.35 500.293,107.346 500.302,107.342 500.311,107.338 500.32,107.333 500.33,107.329 500.339,107.325 500.348,107.321 500.357,107.317 500.366,107.312 500.375,107.308 500.385,107.304 500.394,107.3 500.403,107.295 500.412,107.291 500.421,107.287 500.431,107.283 500.44,107.278 500.449,107.274 500.458,107.27 500.467,107.266 500.477,107.261 500.486,107.257 500.495,107.253 500.504,107.249 500.513,107.245 500.523,107.24 500.532,107.236 500.541,107.232 500.55,107.228 500.559,107.223 500.568,107.219 500.578,107.215 500.587,107.211 500.596,107.207 500.605,107.202 500.614,107.198 500.624,107.194 500.633,107.19 500.642,107.185 500.651,107.181 500.66,107.177 500.67,107.173 500.679,107.169 500.688,107.164 500.697,107.16 500.706,107.156 500.715,107.152 500.725,107.148 500.734,107.143 500.743,107.139 500.752,107.135 500.761,107.131 500.771,107.126 500.78,107.122 500.789,107.118 500.798,107.114 500.807,107.11 500.817,107.105 500.826,107.101 500.835,107.097 500.844,107.093 500.853,107.089 500.863,107.084 500.872,107.08 500.881,107.076 500.89,107.072 500.899,107.068 500.908,107.063 500.918,107.059 500.927,107.055 500.936,107.051 500.945,107.046 500.954,107.042 500.964,107.038 500.973,107.034 500.982,107.03 500.991,107.025 501,107.021 501.01,107.017 501.019,107.013 501.028,107.009 501.037,107.004 501.046,107 501.055,106.996 501.065,106.992 501.074,106.988 501.083,106.983 501.092,106.979 501.101,106.975 501.111,106.971 501.12,106.967 501.129,106.962 501.138,106.958 501.147,106.954 501.157,106.95 501.166,106.946 501.175,106.942 501.184,106.937 501.193,106.933 501.203,106.929 501.212,106.925 501.221,106.921 501.23,106.916 501.239,106.912 501.248,106.908 501.258,106.904 501.267,106.9 501.276,106.895 501.285,106.891 501.294,106.887 501.304,106.883 501.313,106.879 501.322,106.874 501.331,106.87 501.34,106.866 501.35,106.862 501.359,106.858 501.368,106.854 501.377,106.849 501.386,106.845 501.395,106.841 501.405,106.837 501.414,106.833 501.423,106.828 501.432,106.824 501.441,106.82 501.451,106.816 501.46,106.812 501.469,106.808 501.478,106.803 501.487,106.799 501.497,106.795 501.506,106.791 501.515,106.787 501.524,106.783 501.533,106.778 501.543,106.774 501.552,106.77 501.561,106.766 501.57,106.762 501.579,106.757 501.588,106.753 501.598,106.749 501.607,106.745 501.616,106.741 501.625,106.737 501.634,106.732 501.644,106.728 501.653,106.724 501.662,106.72 501.671,106.716 501.68,106.712 501.69,106.707 501.699,106.703 501.708,106.699 501.717,106.695 501.726,106.691 501.736,106.687 501.745,106.682 501.754,106.678 501.763,106.674 501.772,106.67 501.781,106.666 501.791,106.662 501.8,106.657 501.809,106.653 501.818,106.649 501.827,106.645 501.837,106.641 501.846,106.637 501.855,106.633 501.864,106.628 501.873,106.624 501.883,106.62 501.892,106.616 501.901,106.612 501.91,106.608 501.919,106.603 501.928,106.599 501.938,106.595 501.947,106.591 501.956,106.587 501.965,106.583 501.974,106.579 501.984,106.574 501.993,106.57 502.002,106.566 502.011,106.562 502.02,106.558 502.03,106.554 502.039,106.549 502.048,106.545 502.057,106.541 502.066,106.537 502.076,106.533 502.085,106.529 502.094,106.525 502.103,106.52 502.112,106.516 502.121,106.512 502.131,106.508 502.14,106.504 502.149,106.5 502.158,106.496 502.167,106.491 502.177,106.487 502.186,106.483 502.195,106.479 502.204,106.475 502.213,106.471 502.223,106.467 502.232,106.462 502.241,106.458 502.25,106.454 502.259,106.45 502.268,106.446 502.278,106.442 502.287,106.438 502.296,106.433 502.305,106.429 502.314,106.425 502.324,106.421 502.333,106.417 502.342,106.413 502.351,106.409 502.36,106.405 502.37,106.4 502.379,106.396 502.388,106.392 502.397,106.388 502.406,106.384 502.416,106.38 502.425,106.376 502.434,106.371 502.443,106.367 502.452,106.363 502.461,106.359 502.471,106.355 502.48,106.351 502.489,106.347 502.498,106.343 502.507,106.338 502.517,106.334 502.526,106.33 502.535,106.326 502.544,106.322 502.553,106.318 502.563,106.314 502.572,106.31 502.581,106.305 502.59,106.301 502.599,106.297 502.608,106.293 502.618,106.289 502.627,106.285 502.636,106.281 502.645,106.277 502.654,106.272 502.664,106.268 502.673,106.264 502.682,106.26 502.691,106.256 502.7,106.252 502.71,106.248 502.719,106.244 502.728,106.24 502.737,106.235 502.746,106.231 502.756,106.227 502.765,106.223 502.774,106.219 502.783,106.215 502.792,106.211 502.801,106.207 502.811,106.203 502.82,106.198 502.829,106.194 502.838,106.19 502.847,106.186 502.857,106.182 502.866,106.178 502.875,106.174 502.884,106.17 502.893,106.166 502.903,106.161 502.912,106.157 502.921,106.153 502.93,106.149 502.939,106.145 502.948,106.141 502.958,106.137 502.967,106.133 502.976,106.129 502.985,106.125 502.994,106.12 503.004,106.116 503.013,106.112 503.022,106.108 503.031,106.104 503.04,106.1 503.05,106.096 503.059,106.092 503.068,106.088 503.077,106.084 503.086,106.079 503.096,106.075 503.105,106.071 503.114,106.067 503.123,106.063 503.132,106.059 503.141,106.055 503.151,106.051 503.16,106.047 503.169,106.043 503.178,106.038 503.187,106.034 503.197,106.03 503.206,106.026 503.215,106.022 503.224,106.018 503.233,106.014 503.243,106.01 503.252,106.006 503.261,106.002 503.27,105.998 503.279,105.994 503.288,105.989 503.298,105.985 503.307,105.981 503.316,105.977 503.325,105.973 503.334,105.969 503.344,105.965 503.353,105.961 503.362,105.957 503.371,105.953 503.38,105.949 503.39,105.944 503.399,105.94 503.408,105.936 503.417,105.932 503.426,105.928 503.436,105.924 503.445,105.92 503.454,105.916 503.463,105.912 503.472,105.908 503.481,105.904 503.491,105.9 503.5,105.896 503.509,105.891 503.518,105.887 503.527,105.883 503.537,105.879 503.546,105.875 503.555,105.871 503.564,105.867 503.573,105.863 503.583,105.859 503.592,105.855 503.601,105.851 503.61,105.847 503.619,105.843 503.628,105.839 503.638,105.834 503.647,105.83 503.656,105.826 503.665,105.822 503.674,105.818 503.684,105.814 503.693,105.81 503.702,105.806 503.711,105.802 503.72,105.798 503.73,105.794 503.739,105.79 503.748,105.786 503.757,105.782 503.766,105.778 503.776,105.773 503.785,105.769 503.794,105.765 503.803,105.761 503.812,105.757 503.821,105.753 503.831,105.749 503.84,105.745 503.849,105.741 503.858,105.737 503.867,105.733 503.877,105.729 503.886,105.725 503.895,105.721 503.904,105.717 503.913,105.713 503.923,105.709 503.932,105.704 503.941,105.7 503.95,105.696 503.959,105.692 503.968,105.688 503.978,105.684 503.987,105.68 503.996,105.676 504.005,105.672 504.014,105.668 504.024,105.664 504.033,105.66 504.042,105.656 504.051,105.652 504.06,105.648 504.07,105.644 504.079,105.64 504.088,105.636 504.097,105.632 504.106,105.627 504.116,105.623 504.125,105.619 504.134,105.615 504.143,105.611 504.152,105.607 504.161,105.603 504.171,105.599 504.18,105.595 504.189,105.591 504.198,105.587 504.207,105.583 504.217,105.579 504.226,105.575 504.235,105.571 504.244,105.567 504.253,105.563 504.263,105.559 504.272,105.555 504.281,105.551 504.29,105.547 504.299,105.543 504.309,105.539 504.318,105.535 504.327,105.53 504.336,105.526 504.345,105.522 504.354,105.518 504.364,105.514 504.373,105.51 504.382,105.506 504.391,105.502 504.4,105.498 504.41,105.494 504.419,105.49 504.428,105.486 504.437,105.482 504.446,105.478 504.456,105.474 504.465,105.47 504.474,105.466 504.483,105.462 504.492,105.458 504.501,105.454 504.511,105.45 504.52,105.446 504.529,105.442 504.538,105.438 504.547,105.434 504.557,105.43 504.566,105.426 504.575,105.422 504.584,105.418 504.593,105.414 504.603,105.41 504.612,105.406 504.621,105.402 504.63,105.398 504.639,105.394 504.649,105.39 504.658,105.385 504.667,105.381 504.676,105.377 504.685,105.373 504.694,105.369 504.704,105.365 504.713,105.361 504.722,105.357 504.731,105.353 504.74,105.349 504.75,105.345 504.759,105.341 504.768,105.337 504.777,105.333 504.786,105.329 504.796,105.325 504.805,105.321 504.814,105.317 504.823,105.313 504.832,105.309 504.841,105.305 504.851,105.301 504.86,105.297 504.869,105.293 504.878,105.289 504.887,105.285 504.897,105.281 504.906,105.277 504.915,105.273 504.924,105.269 504.933,105.265 504.943,105.261 504.952,105.257 504.961,105.253 504.97,105.249 504.979,105.245 504.989,105.241 504.998,105.237 505.007,105.233 505.016,105.229 505.025,105.225 505.034,105.221 505.044,105.217 505.053,105.213 505.062,105.209 505.071,105.205 505.08,105.201 505.09,105.197 505.099,105.193 505.108,105.189 505.117,105.185 505.126,105.181 505.136,105.177 505.145,105.173 505.154,105.169 505.163,105.165 505.172,105.161 505.181,105.157 505.191,105.153 505.2,105.149 505.209,105.145 505.218,105.141 505.227,105.137 505.237,105.133 505.246,105.129 505.255,105.125 505.264,105.121 505.273,105.117 505.283,105.113 505.292,105.109 505.301,105.105 505.31,105.101 505.319,105.097 505.329,105.093 505.338,105.089 505.347,105.085 505.356,105.081 505.365,105.077 505.374,105.073 505.384,105.069 505.393,105.065 505.402,105.061 505.411,105.057 505.42,105.053 505.43,105.049 505.439,105.045 505.448,105.041 505.457,105.037 505.466,105.033 505.476,105.03 505.485,105.026 505.494,105.022 505.503,105.018 505.512,105.014 505.521,105.01 505.531,105.006 505.54,105.002 505.549,104.998 505.558,104.994 505.567,104.99 505.577,104.986 505.586,104.982 505.595,104.978 505.604,104.974 505.613,104.97 505.623,104.966 505.632,104.962 505.641,104.958 505.65,104.954 505.659,104.95 505.669,104.946 505.678,104.942 505.687,104.938 505.696,104.934 505.705,104.93 505.714,104.926 505.724,104.922 505.733,104.918 505.742,104.914 505.751,104.91 505.76,104.906 505.77,104.902 505.779,104.898 505.788,104.894 505.797,104.89 505.806,104.887 505.816,104.883 505.825,104.879 505.834,104.875 505.843,104.871 505.852,104.867 505.861,104.863 505.871,104.859 505.88,104.855 505.889,104.851 505.898,104.847 505.907,104.843 505.917,104.839 505.926,104.835 505.935,104.831 505.944,104.827 505.953,104.823 505.963,104.819 505.972,104.815 505.981,104.811 505.99,104.807 505.999,104.803 506.009,104.799 506.018,104.795 506.027,104.792 506.036,104.788 506.045,104.784 506.054,104.78 506.064,104.776 506.073,104.772 506.082,104.768 506.091,104.764 506.1,104.76 506.11,104.756 506.119,104.752 506.128,104.748 506.137,104.744 506.146,104.74 506.156,104.736 506.165,104.732 506.174,104.728 506.183,104.724 506.192,104.72 506.201,104.716 506.211,104.713 506.22,104.709 506.229,104.705 506.238,104.701 506.247,104.697 506.257,104.693 506.266,104.689 506.275,104.685 506.284,104.681 506.293,104.677 506.303,104.673 506.312,104.669 506.321,104.665 506.33,104.661 506.339,104.657 506.349,104.653 506.358,104.649 506.367,104.646 506.376,104.642 506.385,104.638 506.394,104.634 506.404,104.63 506.413,104.626 506.422,104.622 506.431,104.618 506.44,104.614 506.45,104.61 506.459,104.606 506.468,104.602 506.477,104.598 506.486,104.594 506.496,104.59 506.505,104.587 506.514,104.583 506.523,104.579 506.532,104.575 506.542,104.571 506.551,104.567 506.56,104.563 506.569,104.559 506.578,104.555 506.587,104.551 506.597,104.547 506.606,104.543 506.615,104.539 506.624,104.535 506.633,104.532 506.643,104.528 506.652,104.524 506.661,104.52 506.67,104.516 506.679,104.512 506.689,104.508 506.698,104.504 506.707,104.5 506.716,104.496 506.725,104.492 506.734,104.488 506.744,104.485 506.753,104.481 506.762,104.477 506.771,104.473 506.78,104.469 506.79,104.465 506.799,104.461 506.808,104.457 506.817,104.453 506.826,104.449 506.836,104.445 506.845,104.441 506.854,104.438 506.863,104.434 506.872,104.43 506.882,104.426 506.891,104.422 506.9,104.418 506.909,104.414 506.918,104.41 506.927,104.406 506.937,104.402 506.946,104.398 506.955,104.394 506.964,104.391 506.973,104.387 506.983,104.383 506.992,104.379 507.001,104.375 507.01,104.371 507.019,104.367 507.029,104.363 507.038,104.359 507.047,104.355 507.056,104.352 507.065,104.348 507.074,104.344 507.084,104.34 507.093,104.336 507.102,104.332 507.111,104.328 507.12,104.324 507.13,104.32 507.139,104.316 507.148,104.312 507.157,104.309 507.166,104.305 507.176,104.301 507.185,104.297 507.194,104.293 507.203,104.289 507.212,104.285 507.222,104.281 507.231,104.277 507.24,104.274 507.249,104.27 507.258,104.266 507.267,104.262 507.277,104.258 507.286,104.254 507.295,104.25 507.304,104.246 507.313,104.242 507.323,104.238 507.332,104.235 507.341,104.231 507.35,104.227 507.359,104.223 507.369,104.219 507.378,104.215 507.387,104.211 507.396,104.207 507.405,104.203 507.414,104.2 507.424,104.196 507.433,104.192 507.442,104.188 507.451,104.184 507.46,104.18 507.47,104.176 507.479,104.172 507.488,104.169 507.497,104.165 507.506,104.161 507.516,104.157 507.525,104.153 507.534,104.149 507.543,104.145 507.552,104.141 507.562,104.137 507.571,104.134 507.58,104.13 507.589,104.126 507.598,104.122 507.607,104.118 507.617,104.114 507.626,104.11 507.635,104.106 507.644,104.103 507.653,104.099 507.663,104.095 507.672,104.091 507.681,104.087 507.69,104.083 507.699,104.079 507.709,104.075 507.718,104.072 507.727,104.068 507.736,104.064 507.745,104.06 507.754,104.056 507.764,104.052 507.773,104.048 507.782,104.044 507.791,104.041 507.8,104.037 507.81,104.033 507.819,104.029 507.828,104.025 507.837,104.021 507.846,104.017 507.856,104.014 507.865,104.01 507.874,104.006 507.883,104.002 507.892,103.998 507.902,103.994 507.911,103.99 507.92,103.986 507.929,103.983 507.938,103.979 507.947,103.975 507.957,103.971 507.966,103.967 507.975,103.963 507.984,103.959 507.993,103.956 508.003,103.952 508.012,103.948 508.021,103.944 508.03,103.94 508.039,103.936 508.049,103.932 508.058,103.929 508.067,103.925 508.076,103.921 508.085,103.917 508.094,103.913 508.104,103.909 508.113,103.905 508.122,103.902 508.131,103.898 508.14,103.894 508.15,103.89 508.159,103.886 508.168,103.882 508.177,103.878 508.186,103.875 508.196,103.871 508.205,103.867 508.214,103.863 508.223,103.859 508.232,103.855 508.242,103.852 508.251,103.848 508.26,103.844 508.269,103.84 508.278,103.836 508.287,103.832 508.297,103.828 508.306,103.825 508.315,103.821 508.324,103.817 508.333,103.813 508.343,103.809 508.352,103.805 508.361,103.802 508.37,103.798 508.379,103.794 508.389,103.79 508.398,103.786 508.407,103.782 508.416,103.778 508.425,103.775 508.434,103.771 508.444,103.767 508.453,103.763 508.462,103.759 508.471,103.755 508.48,103.752 508.49,103.748 508.499,103.744 508.508,103.74 508.517,103.736 508.526,103.732 508.536,103.729 508.545,103.725 508.554,103.721 508.563,103.717 508.572,103.713 508.582,103.709 508.591,103.706 508.6,103.702 508.609,103.698 508.618,103.694 508.627,103.69 508.637,103.686 508.646,103.683 508.655,103.679 508.664,103.675 508.673,103.671 508.683,103.667 508.692,103.664 508.701,103.66 508.71,103.656 508.719,103.652 508.729,103.648 508.738,103.644 508.747,103.641 508.756,103.637 508.765,103.633 508.774,103.629 508.784,103.625 508.793,103.621 508.802,103.618 508.811,103.614 508.82,103.61 508.83,103.606 508.839,103.602 508.848,103.599 508.857,103.595 508.866,103.591 508.876,103.587 508.885,103.583 508.894,103.579 508.903,103.576 508.912,103.572 508.922,103.568 508.931,103.564 508.94,103.56 508.949,103.557 508.958,103.553 508.967,103.549 508.977,103.545 508.986,103.541 508.995,103.537 509.004,103.534 509.013,103.53 509.023,103.526 509.032,103.522 509.041,103.518 509.05,103.515 509.059,103.511 509.069,103.507 509.078,103.503 509.087,103.499 509.096,103.496 509.105,103.492 509.115,103.488 509.124,103.484 509.133,103.48 509.142,103.477 509.151,103.473 509.16,103.469 509.17,103.465 509.179,103.461 509.188,103.457 509.197,103.454 509.206,103.45 509.216,103.446 509.225,103.442 509.234,103.438 509.243,103.435 509.252,103.431 509.262,103.427 509.271,103.423 509.28,103.419 509.289,103.416 509.298,103.412 509.307,103.408 509.317,103.404 509.326,103.4 509.335,103.397 509.344,103.393 509.353,103.389 509.363,103.385 509.372,103.382 509.381,103.378 509.39,103.374 509.399,103.37 509.409,103.366 509.418,103.363 509.427,103.359 509.436,103.355 509.445,103.351 509.455,103.347 509.464,103.344 509.473,103.34 509.482,103.336 509.491,103.332 509.5,103.328 509.51,103.325 509.519,103.321 509.528,103.317 509.537,103.313 509.546,103.309 509.556,103.306 509.565,103.302 509.574,103.298 509.583,103.294 509.592,103.291 509.602,103.287 509.611,103.283 509.62,103.279 509.629,103.275 509.638,103.272 509.647,103.268 509.657,103.264 509.666,103.26 509.675,103.257 509.684,103.253 509.693,103.249 509.703,103.245 509.712,103.241 509.721,103.238 509.73,103.234 509.739,103.23 509.749,103.226 509.758,103.222 509.767,103.219 509.776,103.215 509.785,103.211 509.795,103.207 509.804,103.204 509.813,103.2 509.822,103.196 509.831,103.192 509.84,103.189 509.85,103.185 509.859,103.181 509.868,103.177 509.877,103.173 509.886,103.17 509.896,103.166 509.905,103.162 509.914,103.158 509.923,103.155 509.932,103.151 509.942,103.147 509.951,103.143 509.96,103.139 509.969,103.136 509.978,103.132 509.987,103.128 509.997,103.124 510.006,103.121 510.015,103.117 510.024,103.113 510.033,103.109 510.043,103.106 510.052,103.102 510.061,103.098 510.07,103.094 510.079,103.091 510.089,103.087 510.098,103.083 510.107,103.079 510.116,103.076 510.125,103.072 510.135,103.068 510.144,103.064 510.153,103.06 510.162,103.057 510.171,103.053 510.18,103.049 510.19,103.045 510.199,103.042 510.208,103.038 510.217,103.034 510.226,103.03 510.236,103.027 510.245,103.023 510.254,103.019 510.263,103.015 510.272,103.012 510.282,103.008 510.291,103.004 510.3,103 510.309,102.997 510.318,102.993 510.327,102.989 510.337,102.985 510.346,102.982 510.355,102.978 510.364,102.974 510.373,102.97 510.383,102.967 510.392,102.963 510.401,102.959 510.41,102.955 510.419,102.952 510.429,102.948 510.438,102.944 510.447,102.94 510.456,102.937 510.465,102.933 510.475,102.929 510.484,102.925 510.493,102.922 510.502,102.918 510.511,102.914 510.52,102.91 510.53,102.907 510.539,102.903 510.548,102.899 510.557,102.895 510.566,102.892 510.576,102.888 510.585,102.884 510.594,102.881 510.603,102.877 510.612,102.873 510.622,102.869 510.631,102.866 510.64,102.862 510.649,102.858 510.658,102.854 510.667,102.851 510.677,102.847 510.686,102.843 510.695,102.839 510.704,102.836 510.713,102.832 510.723,102.828 510.732,102.825 510.741,102.821 510.75,102.817 510.759,102.813 510.769,102.81 510.778,102.806 510.787,102.802 510.796,102.798 510.805,102.795 510.815,102.791 510.824,102.787 510.833,102.783 510.842,102.78 510.851,102.776 510.86,102.772 510.87,102.769 510.879,102.765 510.888,102.761 510.897,102.757 510.906,102.754 510.916,102.75 510.925,102.746 510.934,102.743 510.943,102.739 510.952,102.735 510.962,102.731 510.971,102.728 510.98,102.724 510.989,102.72 510.998,102.716 511.007,102.713 511.017,102.709 511.026,102.705 511.035,102.702 511.044,102.698 511.053,102.694 511.063,102.69 511.072,102.687 511.081,102.683 511.09,102.679 511.099,102.676 511.109,102.672 511.118,102.668 511.127,102.664 511.136,102.661 511.145,102.657 511.155,102.653 511.164,102.65 511.173,102.646 511.182,102.642 511.191,102.638 511.2,102.635 511.21,102.631 511.219,102.627 511.228,102.624 511.237,102.62 511.246,102.616 511.256,102.612 511.265,102.609 511.274,102.605 511.283,102.601 511.292,102.598 511.302,102.594 511.311,102.59 511.32,102.587 511.329,102.583 511.338,102.579 511.347,102.575 511.357,102.572 511.366,102.568 511.375,102.564 511.384,102.561 511.393,102.557 511.403,102.553 511.412,102.549 511.421,102.546 511.43,102.542 511.439,102.538 511.449,102.535 511.458,102.531 511.467,102.527 511.476,102.524 511.485,102.52 511.495,102.516 511.504,102.513 511.513,102.509 511.522,102.505 511.531,102.501 511.54,102.498 511.55,102.494 511.559,102.49 511.568,102.487 511.577,102.483 511.586,102.479 511.596,102.476 511.605,102.472 511.614,102.468 511.623,102.464 511.632,102.461 511.642,102.457 511.651,102.453 511.66,102.45 511.669,102.446 511.678,102.442 511.688,102.439 511.697,102.435 511.706,102.431 511.715,102.428 511.724,102.424 511.733,102.42 511.743,102.417 511.752,102.413 511.761,102.409 511.77,102.405 511.779,102.402 511.789,102.398 511.798,102.394 511.807,102.391 511.816,102.387 511.825,102.383 511.835,102.38 511.844,102.376 511.853,102.372 511.862,102.369 511.871,102.365 511.88,102.361 511.89,102.358 511.899,102.354 511.908,102.35 511.917,102.347 511.926,102.343 511.936,102.339 511.945,102.336 511.954,102.332 511.963,102.328 511.972,102.325 511.982,102.321 511.991,102.317 512,102.313 512.009,102.31 512.018,102.306 512.028,102.302 512.037,102.299 512.046,102.295 512.055,102.291 512.064,102.288 512.073,102.284 512.083,102.28 512.092,102.277 512.101,102.273 512.11,102.269 512.119,102.266 512.129,102.262 512.138,102.258 512.147,102.255 512.156,102.251 512.165,102.247 512.175,102.244 512.184,102.24 512.193,102.236 512.202,102.233 512.211,102.229 512.22,102.225 512.23,102.222 512.239,102.218 512.248,102.214 512.257,102.211 512.266,102.207 512.276,102.203 512.285,102.2 512.294,102.196 512.303,102.192 512.312,102.189 512.322,102.185 512.331,102.181 512.34,102.178 512.349,102.174 512.358,102.171 512.368,102.167 512.377,102.163 512.386,102.16 512.395,102.156 512.404,102.152 512.413,102.149 512.423,102.145 512.432,102.141 512.441,102.138 512.45,102.134 512.459,102.13 512.469,102.127 512.478,102.123 512.487,102.119 512.496,102.116 512.505,102.112 512.515,102.108 512.524,102.105 512.533,102.101 512.542,102.097 512.551,102.094 512.56,102.09 512.57,102.086 512.579,102.083 512.588,102.079 512.597,102.076 512.606,102.072 512.616,102.068 512.625,102.065 512.634,102.061 512.643,102.057 512.652,102.054 512.662,102.05 512.671,102.046 512.68,102.043 512.689,102.039 512.698,102.035 512.708,102.032 512.717,102.028 512.726,102.025 512.735,102.021 512.744,102.017 512.753,102.014 512.763,102.01 512.772,102.006 512.781,102.003 512.79,101.999 512.799,101.995 512.809,101.992 512.818,101.988 512.827,101.984 512.836,101.981 512.845,101.977 512.855,101.974 512.864,101.97 512.873,101.966 512.882,101.963 512.891,101.959 512.9,101.955 512.91,101.952 512.919,101.948 512.928,101.945 512.937,101.941 512.946,101.937 512.956,101.934 512.965,101.93 512.974,101.926 512.983,101.923 512.992,101.919 513.002,101.915 513.011,101.912 513.02,101.908 513.029,101.905 513.038,101.901 513.048,101.897 513.057,101.894 513.066,101.89 513.075,101.886 513.084,101.883 513.093,101.879 513.103,101.876 513.112,101.872 513.121,101.868 513.13,101.865 513.139,101.861 513.149,101.857 513.158,101.854 513.167,101.85 513.176,101.847 513.185,101.843 513.195,101.839 513.204,101.836 513.213,101.832 513.222,101.828 513.231,101.825 513.24,101.821 513.25,101.818 513.259,101.814 513.268,101.81 513.277,101.807 513.286,101.803 513.296,101.8 513.305,101.796 513.314,101.792 513.323,101.789 513.332,101.785 513.342,101.781 513.351,101.778 513.36,101.774 513.369,101.771 513.378,101.767 513.388,101.763 513.397,101.76 513.406,101.756 513.415,101.753 513.424,101.749 513.433,101.745 513.443,101.742 513.452,101.738 513.461,101.735 513.47,101.731 513.479,101.727 513.489,101.724 513.498,101.72 513.507,101.716 513.516,101.713 513.525,101.709 513.535,101.706 513.544,101.702 513.553,101.698 513.562,101.695 513.571,101.691 513.58,101.688 513.59,101.684 513.599,101.68 513.608,101.677 513.617,101.673 513.626,101.67 513.636,101.666 513.645,101.662 513.654,101.659 513.663,101.655 513.672,101.652 513.682,101.648 513.691,101.644 513.7,101.641 513.709,101.637 513.718,101.634 513.728,101.63 513.737,101.626 513.746,101.623 513.755,101.619 513.764,101.616 513.773,101.612 513.783,101.608 513.792,101.605 513.801,101.601 513.81,101.598 513.819,101.594 513.829,101.591 513.838,101.587 513.847,101.583 513.856,101.58 513.865,101.576 513.875,101.573 513.884,101.569 513.893,101.565 513.902,101.562 513.911,101.558 513.921,101.555 513.93,101.551 513.939,101.547 513.948,101.544 513.957,101.54 513.966,101.537 513.976,101.533 513.985,101.53 513.994,101.526 514.003,101.522 514.012,101.519 514.022,101.515 514.031,101.512 514.04,101.508 514.049,101.504 514.058,101.501 514.068,101.497 514.077,101.494 514.086,101.49 514.095,101.487 514.104,101.483 514.113,101.479 514.123,101.476 514.132,101.472 514.141,101.469 514.15,101.465 514.159,101.461 514.169,101.458 514.178,101.454 514.187,101.451 514.196,101.447 514.205,101.444 514.215,101.44 514.224,101.436 514.233,101.433 514.242,101.429 514.251,101.426 514.261,101.422 514.27,101.419 514.279,101.415 514.288,101.411 514.297,101.408 514.306,101.404 514.316,101.401 514.325,101.397 514.334,101.394 514.343,101.39 514.352,101.386 514.362,101.383 514.371,101.379 514.38,101.376 514.389,101.372 514.398,101.369 514.408,101.365 514.417,101.361 514.426,101.358 514.435,101.354 514.444,101.351 514.453,101.347 514.463,101.344 514.472,101.34 514.481,101.337 514.49,101.333 514.499,101.329 514.509,101.326 514.518,101.322 514.527,101.319 514.536,101.315 514.545,101.312 514.555,101.308 514.564,101.304 514.573,101.301 514.582,101.297 514.591,101.294 514.601,101.29 514.61,101.287 514.619,101.283 514.628,101.28 514.637,101.276 514.646,101.272 514.656,101.269 514.665,101.265 514.674,101.262 514.683,101.258 514.692,101.255 514.702,101.251 514.711,101.248 514.72,101.244 514.729,101.24 514.738,101.237 514.748,101.233 514.757,101.23 514.766,101.226 514.775,101.223 514.784,101.219 514.793,101.216 514.803,101.212 514.812,101.209 514.821,101.205 514.83,101.201 514.839,101.198 514.849,101.194 514.858,101.191 514.867,101.187 514.876,101.184 514.885,101.18 514.895,101.177 514.904,101.173 514.913,101.17 514.922,101.166 514.931,101.162 514.941,101.159 514.95,101.155 514.959,101.152 514.968,101.148 514.977,101.145 514.986,101.141 514.996,101.138 515.005,101.134 515.014,101.131 515.023,101.127 515.032,101.123 515.042,101.12 515.051,101.116 515.06,101.113 515.069,101.109 515.078,101.106 515.088,101.102 515.097,101.099 515.106,101.095 515.115,101.092 515.124,101.088 515.133,101.085 515.143,101.081 515.152,101.077 515.161,101.074 515.17,101.07 515.179,101.067 515.189,101.063 515.198,101.06 515.207,101.056 515.216,101.053 515.225,101.049 515.235,101.046 515.244,101.042 515.253,101.039 515.262,101.035 515.271,101.032 515.281,101.028 515.29,101.025 515.299,101.021 515.308,101.017 515.317,101.014 515.326,101.01 515.336,101.007 515.345,101.003 515.354,101 515.363,100.996 515.372,100.993 515.382,100.989 515.391,100.986 515.4,100.982 515.409,100.979 515.418,100.975 515.428,100.972 515.437,100.968 515.446,100.965 515.455,100.961 515.464,100.958 515.473,100.954 515.483,100.951 515.492,100.947 515.501,100.944 515.51,100.94 515.519,100.936 515.529,100.933 515.538,100.929 515.547,100.926 515.556,100.922 515.565,100.919 515.575,100.915 515.584,100.912 515.593,100.908 515.602,100.905 515.611,100.901 515.621,100.898 515.63,100.894 515.639,100.891 515.648,100.887 515.657,100.884 515.666,100.88 515.676,100.877 515.685,100.873 515.694,100.87 515.703,100.866 515.712,100.863 515.722,100.859 515.731,100.856 515.74,100.852 515.749,100.849 515.758,100.845 515.768,100.842 515.777,100.838 515.786,100.835 515.795,100.831 515.804,100.828 515.813,100.824 515.823,100.821 515.832,100.817 515.841,100.814 515.85,100.81 515.859,100.807 515.869,100.803 515.878,100.8 515.887,100.796 515.896,100.793 515.905,100.789 515.915,100.786 515.924,100.782 515.933,100.779 515.942,100.775 515.951,100.772 515.961,100.768 515.97,100.765 515.979,100.761 515.988,100.758 515.997,100.754 516.006,100.751 516.016,100.747 516.025,100.744 516.034,100.74 516.043,100.737 516.052,100.733 516.062,100.73 516.071,100.726 516.08,100.723 516.089,100.719 516.098,100.716 516.108,100.712 516.117,100.709 516.126,100.705 516.135,100.702 516.144,100.698 516.153,100.695 516.163,100.691 516.172,100.688 516.181,100.684 516.19,100.681 516.199,100.677 516.209,100.674 516.218,100.67 516.227,100.667 516.236,100.663 516.245,100.66 516.255,100.656 516.264,100.653 516.273,100.649 516.282,100.646 516.291,100.642 516.301,100.639 516.31,100.635 516.319,100.632 516.328,100.629 516.337,100.625 516.346,100.622 516.356,100.618 516.365,100.615 516.374,100.611 516.383,100.608 516.392,100.604 516.402,100.601 516.411,100.597 516.42,100.594 516.429,100.59 516.438,100.587 516.448,100.583 516.457,100.58 516.466,100.576 516.475,100.573 516.484,100.569 516.494,100.566 516.503,100.562 516.512,100.559 516.521,100.555 516.53,100.552 516.539,100.549 516.549,100.545 516.558,100.542 516.567,100.538 516.576,100.535 516.585,100.531 516.595,100.528 516.604,100.524 516.613,100.521 516.622,100.517 516.631,100.514 516.641,100.51 516.65,100.507 516.659,100.503 516.668,100.5 516.677,100.496 516.686,100.493 516.696,100.49 516.705,100.486 516.714,100.483 516.723,100.479 516.732,100.476 516.742,100.472 516.751,100.469 516.76,100.465 516.769,100.462 516.778,100.458 516.788,100.455 516.797,100.451 516.806,100.448 516.815,100.445 516.824,100.441 516.834,100.438 516.843,100.434 516.852,100.431 516.861,100.427 516.87,100.424 516.879,100.42 516.889,100.417 516.898,100.413 516.907,100.41 516.916,100.406 516.925,100.403 516.935,100.4 516.944,100.396 516.953,100.393 516.962,100.389 516.971,100.386 516.981,100.382 516.99,100.379 516.999,100.375 517.008,100.372 517.017,100.368 517.026,100.365 517.036,100.362 517.045,100.358 517.054,100.355 517.063,100.351 517.072,100.348 517.082,100.344 517.091,100.341 517.1,100.337 517.109,100.334 517.118,100.331 517.128,100.327 517.137,100.324 517.146,100.32 517.155,100.317 517.164,100.313 517.174,100.31 517.183,100.306 517.192,100.303 517.201,100.3 517.21,100.296 517.219,100.293 517.229,100.289 517.238,100.286 517.247,100.282 517.256,100.279 517.265,100.275 517.275,100.272 517.284,100.269 517.293,100.265 517.302,100.262 517.311,100.258 517.321,100.255 517.33,100.251 517.339,100.248 517.348,100.244 517.357,100.241 517.366,100.238 517.376,100.234 517.385,100.231 517.394,100.227 517.403,100.224 517.412,100.22 517.422,100.217 517.431,100.214 517.44,100.21 517.449,100.207 517.458,100.203 517.468,100.2 517.477,100.196 517.486,100.193 517.495,100.19 517.504,100.186 517.514,100.183 517.523,100.179 517.532,100.176 517.541,100.172 517.55,100.169 517.559,100.165 517.569,100.162 517.578,100.159 517.587,100.155 517.596,100.152 517.605,100.148 517.615,100.145 517.624,100.142 517.633,100.138 517.642,100.135 517.651,100.131 517.661,100.128 517.67,100.124 517.679,100.121 517.688,100.118 517.697,100.114 517.706,100.111 517.716,100.107 517.725,100.104 517.734,100.1 517.743,100.097 517.752,100.094 517.762,100.09 517.771,100.087 517.78,100.083 517.789,100.08 517.798,100.076 517.808,100.073 517.817,100.07 517.826,100.066 517.835,100.063 517.844,100.059 517.854,100.056 517.863,100.053 517.872,100.049 517.881,100.046 517.89,100.042 517.899,100.039 517.909,100.035 517.918,100.032 517.927,100.029 517.936,100.025 517.945,100.022 517.955,100.018 517.964,100.015 517.973,100.012 517.982,100.008 517.991,100.005 518.001,100.001 518.01,99.998 518.019,99.9945 518.028,99.9911 518.037,99.9877 518.046,99.9843 518.056,99.9809 518.065,99.9775 518.074,99.9741 518.083,99.9707 518.092,99.9673 518.102,99.9639 518.111,99.9605 518.12,99.9571 518.129,99.9537 518.138,99.9503 518.148,99.9469 518.157,99.9435 518.166,99.94 518.175,99.9366 518.184,99.9332 518.194,99.9298 518.203,99.9264 518.212,99.923 518.221,99.9196 518.23,99.9162 518.239,99.9128 518.249,99.9094 518.258,99.906 518.267,99.9026 518.276,99.8992 518.285,99.8958 518.295,99.8924 518.304,99.889 518.313,99.8857 518.322,99.8823 518.331,99.8789 518.341,99.8755 518.35,99.8721 518.359,99.8687 518.368,99.8653 518.377,99.8619 518.386,99.8585 518.396,99.8551 518.405,99.8517 518.414,99.8483 518.423,99.8449 518.432,99.8415 518.442,99.8381 518.451,99.8347 518.46,99.8314 518.469,99.828 518.478,99.8246 518.488,99.8212 518.497,99.8178 518.506,99.8144 518.515,99.811 518.524,99.8076 518.534,99.8042 518.543,99.8009 518.552,99.7975 518.561,99.7941 518.57,99.7907 518.579,99.7873 518.589,99.7839 518.598,99.7805 518.607,99.7772 518.616,99.7738 518.625,99.7704 518.635,99.767 518.644,99.7636 518.653,99.7602 518.662,99.7569 518.671,99.7535 518.681,99.7501 518.69,99.7467 518.699,99.7433 518.708,99.74 518.717,99.7366 518.726,99.7332 518.736,99.7298 518.745,99.7264 518.754,99.7231 518.763,99.7197 518.772,99.7163 518.782,99.7129 518.791,99.7096 518.8,99.7062 518.809,99.7028 518.818,99.6994 518.828,99.6961 518.837,99.6927 518.846,99.6893 518.855,99.6859 518.864,99.6826 518.874,99.6792 518.883,99.6758 518.892,99.6724 518.901,99.6691 518.91,99.6657 518.919,99.6623 518.929,99.659 518.938,99.6556 518.947,99.6522 518.956,99.6488 518.965,99.6455 518.975,99.6421 518.984,99.6387 518.993,99.6354 519.002,99.632 519.011,99.6286 519.021,99.6253 519.03,99.6219 519.039,99.6185 519.048,99.6152 519.057,99.6118 519.067,99.6084 519.076,99.6051 519.085,99.6017 519.094,99.5984 519.103,99.595 519.112,99.5916 519.122,99.5883 519.131,99.5849 519.14,99.5815 519.149,99.5782 519.158,99.5748 519.168,99.5715 519.177,99.5681 519.186,99.5647 519.195,99.5614 519.204,99.558 519.214,99.5547 519.223,99.5513 519.232,99.5479 519.241,99.5446 519.25,99.5412 519.259,99.5379 519.269,99.5345 519.278,99.5312 519.287,99.5278 519.296,99.5245 519.305,99.5211 519.315,99.5177 519.324,99.5144 519.333,99.511 519.342,99.5077 519.351,99.5043 519.361,99.501 519.37,99.4976 519.379,99.4943 519.388,99.4909 519.397,99.4876 519.407,99.4842 519.416,99.4809 519.425,99.4775 519.434,99.4742 519.443,99.4708 519.452,99.4675 519.462,99.4641 519.471,99.4608 519.48,99.4574 519.489,99.4541 519.498,99.4507 519.508,99.4474 519.517,99.444 519.526,99.4407 519.535,99.4374 519.544,99.434 519.554,99.4307 519.563,99.4273 519.572,99.424 519.581,99.4206 519.59,99.4173 519.599,99.414 519.609,99.4106 519.618,99.4073 519.627,99.4039 519.636,99.4006 519.645,99.3972 519.655,99.3939 519.664,99.3906 519.673,99.3872 519.682,99.3839 519.691,99.3805 519.701,99.3772 519.71,99.3739 519.719,99.3705 519.728,99.3672 519.737,99.3639 519.747,99.3605 519.756,99.3572 519.765,99.3539 519.774,99.3505 519.783,99.3472 519.792,99.3439 519.802,99.3405 519.811,99.3372 519.82,99.3339 519.829,99.3305 519.838,99.3272 519.848,99.3239 519.857,99.3205 519.866,99.3172 519.875,99.3139 519.884,99.3105 519.894,99.3072 519.903,99.3039 519.912,99.3005 519.921,99.2972 519.93,99.2939 519.939,99.2906 519.949,99.2872 519.958,99.2839 519.967,99.2806 519.976,99.2772 519.985,99.2739 519.995,99.2706 520.004,99.2673 520.013,99.2639 520.022,99.2606 520.031,99.2573 520.041,99.254 520.05,99.2507 520.059,99.2473 520.068,99.244 520.077,99.2407 520.087,99.2374 520.096,99.234 520.105,99.2307 520.114,99.2274 520.123,99.2241 520.132,99.2208 520.142,99.2174 520.151,99.2141 520.16,99.2108 520.169,99.2075 520.178,99.2042 520.188,99.2008 520.197,99.1975 520.206,99.1942 520.215,99.1909 520.224,99.1876 520.234,99.1843 520.243,99.181 520.252,99.1776 520.261,99.1743 520.27,99.171 520.279,99.1677 520.289,99.1644 520.298,99.1611 520.307,99.1578 520.316,99.1544 520.325,99.1511 520.335,99.1478 520.344,99.1445 520.353,99.1412 520.362,99.1379 520.371,99.1346 520.381,99.1313 520.39,99.128 520.399,99.1246 520.408,99.1213 520.417,99.118 520.427,99.1147 520.436,99.1114 520.445,99.1081 520.454,99.1048 520.463,99.1015 520.472,99.0982 520.482,99.0949 520.491,99.0916 520.5,99.0883 520.509,99.085 520.518,99.0817 520.528,99.0784 520.537,99.0751 520.546,99.0718 520.555,99.0685 520.564,99.0652 520.574,99.0619 520.583,99.0586 520.592,99.0553 520.601,99.052 520.61,99.0487 520.619,99.0454 520.629,99.0421 520.638,99.0388 520.647,99.0355 520.656,99.0322 520.665,99.0289 520.675,99.0256 520.684,99.0223 520.693,99.019 520.702,99.0157 520.711,99.0124 520.721,99.0091 520.73,99.0058 520.739,99.0025 520.748,98.9992 520.757,98.9959 520.767,98.9926 520.776,98.9893 520.785,98.986 520.794,98.9827 520.803,98.9794 520.812,98.9762 520.822,98.9729 520.831,98.9696 520.84,98.9663 520.849,98.963 520.858,98.9597 520.868,98.9564 520.877,98.9531 520.886,98.9498 520.895,98.9465 520.904,98.9433 520.914,98.94 520.923,98.9367 520.932,98.9334 520.941,98.9301 520.95,98.9268 520.959,98.9235 520.969,98.9203 520.978,98.917 520.987,98.9137 520.996,98.9104 521.005,98.9071 521.015,98.9038 521.024,98.9006 521.033,98.8973 521.042,98.894 521.051,98.8907 521.061,98.8874 521.07,98.8841 521.079,98.8809 521.088,98.8776 521.097,98.8743 521.107,98.871 521.116,98.8677 521.125,98.8645 521.134,98.8612 521.143,98.8579 521.152,98.8546 521.162,98.8514 521.171,98.8481 521.18,98.8448 521.189,98.8415 521.198,98.8383 521.208,98.835 521.217,98.8317 521.226,98.8284 521.235,98.8252 521.244,98.8219 521.254,98.8186 521.263,98.8153 521.272,98.8121 521.281,98.8088 521.29,98.8055 521.3,98.8022 521.309,98.799 521.318,98.7957 521.327,98.7924 521.336,98.7892 521.345,98.7859 521.355,98.7826 521.364,98.7794 521.373,98.7761 521.382,98.7728 521.391,98.7696 521.401,98.7663 521.41,98.763 521.419,98.7598 521.428,98.7565 521.437,98.7532 521.447,98.75 521.456,98.7467 521.465,98.7434 521.474,98.7402 521.483,98.7369 521.492,98.7336 521.502,98.7304 521.511,98.7271 521.52,98.7239 521.529,98.7206 521.538,98.7173 521.548,98.7141 521.557,98.7108 521.566,98.7075 521.575,98.7043 521.584,98.701 521.594,98.6978 521.603,98.6945 521.612,98.6913 521.621,98.688 521.63,98.6847 521.64,98.6815 521.649,98.6782 521.658,98.675 521.667,98.6717 521.676,98.6685 521.685,98.6652 521.695,98.6619 521.704,98.6587 521.713,98.6554 521.722,98.6522 521.731,98.6489 521.741,98.6457 521.75,98.6424 521.759,98.6392 521.768,98.6359 521.777,98.6327 521.787,98.6294 521.796,98.6262 521.805,98.6229 521.814,98.6197 521.823,98.6164 521.832,98.6132 521.842,98.6099 521.851,98.6067 521.86,98.6034 521.869,98.6002 521.878,98.5969 521.888,98.5937 521.897,98.5904 521.906,98.5872 521.915,98.5839 521.924,98.5807 521.934,98.5774 521.943,98.5742 521.952,98.571 521.961,98.5677 521.97,98.5645 521.98,98.5612 521.989,98.558 521.998,98.5547 522.007,98.5515 522.016,98.5483 522.025,98.545 522.035,98.5418 522.044,98.5385 522.053,98.5353 522.062,98.5321 522.071,98.5288 522.081,98.5256 522.09,98.5223 522.099,98.5191 522.108,98.5159 522.117,98.5126 522.127,98.5094 522.136,98.5061 522.145,98.5029 522.154,98.4997 522.163,98.4964 522.172,98.4932 522.182,98.49 522.191,98.4867 522.2,98.4835 522.209,98.4803 522.218,98.477 522.228,98.4738 522.237,98.4706 522.246,98.4673 522.255,98.4641 522.264,98.4609 522.274,98.4576 522.283,98.4544 522.292,98.4512 522.301,98.448 522.31,98.4447 522.32,98.4415 522.329,98.4383 522.338,98.435 522.347,98.4318 522.356,98.4286 522.365,98.4254 522.375,98.4221 522.384,98.4189 522.393,98.4157 522.402,98.4124 522.411,98.4092 522.421,98.406 522.43,98.4028 522.439,98.3995 522.448,98.3963 522.457,98.3931 522.467,98.3899 522.476,98.3867 522.485,98.3834 522.494,98.3802 522.503,98.377 522.512,98.3738 522.522,98.3705 522.531,98.3673 522.54,98.3641 522.549,98.3609 522.558,98.3577 522.568,98.3544 522.577,98.3512 522.586,98.348 522.595,98.3448 522.604,98.3416 522.614,98.3384 522.623,98.3351 522.632,98.3319 522.641,98.3287 522.65,98.3255 522.66,98.3223 522.669,98.3191 522.678,98.3158 522.687,98.3126 522.696,98.3094 522.705,98.3062 522.715,98.303 522.724,98.2998 522.733,98.2966 522.742,98.2934 522.751,98.2901 522.761,98.2869 522.77,98.2837 522.779,98.2805 522.788,98.2773 522.797,98.2741 522.807,98.2709 522.816,98.2677 522.825,98.2645 522.834,98.2613 522.843,98.258 522.852,98.2548 522.862,98.2516 522.871,98.2484 522.88,98.2452 522.889,98.242 522.898,98.2388 522.908,98.2356 522.917,98.2324 522.926,98.2292 522.935,98.226 522.944,98.2228 522.954,98.2196 522.963,98.2164 522.972,98.2132 522.981,98.21 522.99,98.2068 523,98.2036 523.009,98.2004 523.018,98.1972 523.027,98.194 523.036,98.1908 523.045,98.1876 523.055,98.1844 523.064,98.1812 523.073,98.178 523.082,98.1748 523.091,98.1716 523.101,98.1684 523.11,98.1652 523.119,98.162 523.128,98.1588 523.137,98.1556 523.147,98.1524 523.156,98.1492 523.165,98.146 523.174,98.1428 523.183,98.1396 523.192,98.1364 523.202,98.1332 523.211,98.13 523.22,98.1268 523.229,98.1237 523.238,98.1205 523.248,98.1173 523.257,98.1141 523.266,98.1109 523.275,98.1077 523.284,98.1045 523.294,98.1013 523.303,98.0981 523.312,98.0949 523.321,98.0918 523.33,98.0886 523.34,98.0854 523.349,98.0822 523.358,98.079 523.367,98.0758 523.376,98.0726 523.385,98.0694 523.395,98.0663 523.404,98.0631 523.413,98.0599 523.422,98.0567 523.431,98.0535 523.441,98.0503 523.45,98.0472 523.459,98.044 523.468,98.0408 523.477,98.0376 523.487,98.0344 523.496,98.0312 523.505,98.0281 523.514,98.0249 523.523,98.0217 523.532,98.0185 523.542,98.0153 523.551,98.0122 523.56,98.009 523.569,98.0058 523.578,98.0026 523.588,97.9995 523.597,97.9963 523.606,97.9931 523.615,97.9899 523.624,97.9867 523.634,97.9836 523.643,97.9804 523.652,97.9772 523.661,97.974 523.67,97.9709 523.68,97.9677 523.689,97.9645 523.698,97.9614 523.707,97.9582 523.716,97.955 523.725,97.9518 523.735,97.9487 523.744,97.9455 523.753,97.9423 523.762,97.9392 523.771,97.936 523.781,97.9328 523.79,97.9296 523.799,97.9265 523.808,97.9233 523.817,97.9201 523.827,97.917 523.836,97.9138 523.845,97.9106 523.854,97.9075 523.863,97.9043 523.873,97.9011 523.882,97.898 523.891,97.8948 523.9,97.8916 523.909,97.8885 523.918,97.8853 523.928,97.8821 523.937,97.879 523.946,97.8758 523.955,97.8727 523.964,97.8695 523.974,97.8663 523.983,97.8632 523.992,97.86 524.001,97.8569 524.01,97.8537 524.02,97.8505 524.029,97.8474 524.038,97.8442 524.047,97.8411 524.056,97.8379 524.065,97.8347 524.075,97.8316 524.084,97.8284 524.093,97.8253 524.102,97.8221 524.111,97.819 524.121,97.8158 524.13,97.8126 524.139,97.8095 524.148,97.8063 524.157,97.8032 524.167,97.8 524.176,97.7969 524.185,97.7937 524.194,97.7906 524.203,97.7874 524.213,97.7843 524.222,97.7811 524.231,97.778 524.24,97.7748 524.249,97.7716 524.258,97.7685 524.268,97.7653 524.277,97.7622 524.286,97.759 524.295,97.7559 524.304,97.7528 524.314,97.7496 524.323,97.7465 524.332,97.7433 524.341,97.7402 524.35,97.737 524.36,97.7339 524.369,97.7307 524.378,97.7276 524.387,97.7244 524.396,97.7213 524.405,97.7181 524.415,97.715 524.424,97.7119 524.433,97.7087 524.442,97.7056 524.451,97.7024 524.461,97.6993 524.47,97.6961 524.479,97.693 524.488,97.6899 524.497,97.6867 524.507,97.6836 524.516,97.6804 524.525,97.6773 524.534,97.6742 524.543,97.671 524.553,97.6679 524.562,97.6647 524.571,97.6616 524.58,97.6585 524.589,97.6553 524.598,97.6522 524.608,97.6491 524.617,97.6459 524.626,97.6428 524.635,97.6396 524.644,97.6365 524.654,97.6334 524.663,97.6302 524.672,97.6271 524.681,97.624 524.69,97.6208 524.7,97.6177 524.709,97.6146 524.718,97.6114 524.727,97.6083 524.736,97.6052 524.745,97.6021 524.755,97.5989 524.764,97.5958 524.773,97.5927 524.782,97.5895 524.791,97.5864 524.801,97.5833 524.81,97.5801 524.819,97.577 524.828,97.5739 524.837,97.5708 524.847,97.5676 524.856,97.5645 524.865,97.5614 524.874,97.5583 524.883,97.5551 524.893,97.552 524.902,97.5489 524.911,97.5458 524.92,97.5426 524.929,97.5395 524.938,97.5364 524.948,97.5333 524.957,97.5301 524.966,97.527 524.975,97.5239 524.984,97.5208 524.994,97.5177 525.003,97.5145 525.012,97.5114 525.021,97.5083 525.03,97.5052 525.04,97.5021 525.049,97.4989 525.058,97.4958 525.067,97.4927 525.076,97.4896 525.085,97.4865 525.095,97.4834 525.104,97.4802 525.113,97.4771 525.122,97.474 525.131,97.4709 525.141,97.4678 525.15,97.4647 525.159,97.4615 525.168,97.4584 525.177,97.4553 525.187,97.4522 525.196,97.4491 525.205,97.446 525.214,97.4429 525.223,97.4398 525.233,97.4366 525.242,97.4335 525.251,97.4304 525.26,97.4273 525.269,97.4242 525.278,97.4211 525.288,97.418 525.297,97.4149 525.306,97.4118 525.315,97.4087 525.324,97.4055 525.334,97.4024 525.343,97.3993 525.352,97.3962 525.361,97.3931 525.37,97.39 525.38,97.3869 525.389,97.3838 525.398,97.3807 525.407,97.3776 525.416,97.3745 525.425,97.3714 525.435,97.3683 525.444,97.3652 525.453,97.3621 525.462,97.359 525.471,97.3559 525.481,97.3528 525.49,97.3497 525.499,97.3466 525.508,97.3435 525.517,97.3404 525.527,97.3373 525.536,97.3342 525.545,97.3311 525.554,97.328 525.563,97.3249 525.573,97.3218 525.582,97.3187 525.591,97.3156 525.6,97.3125 525.609,97.3094 525.618,97.3063 525.628,97.3032 525.637,97.3001 525.646,97.297 525.655,97.2939 525.664,97.2908 525.674,97.2877 525.683,97.2846 525.692,97.2815 525.701,97.2784 525.71,97.2754 525.72,97.2723 525.729,97.2692 525.738,97.2661 525.747,97.263 525.756,97.2599 525.765,97.2568 525.775,97.2537 525.784,97.2506 525.793,97.2475 525.802,97.2444 525.811,97.2414 525.821,97.2383 525.83,97.2352 525.839,97.2321 525.848,97.229 525.857,97.2259 525.867,97.2228 525.876,97.2198 525.885,97.2167 525.894,97.2136 525.903,97.2105 525.913,97.2074 525.922,97.2043 525.931,97.2012 525.94,97.1982 525.949,97.1951 525.958,97.192 525.968,97.1889 525.977,97.1858 525.986,97.1828 525.995,97.1797 526.004,97.1766 526.014,97.1735 526.023,97.1704 526.032,97.1673 526.041,97.1643 526.05,97.1612 526.06,97.1581 526.069,97.155 526.078,97.152 526.087,97.1489 526.096,97.1458 526.105,97.1427 526.115,97.1396 526.124,97.1366 526.133,97.1335 526.142,97.1304 526.151,97.1273 526.161,97.1243 526.17,97.1212 526.179,97.1181 526.188,97.1151 526.197,97.112 526.207,97.1089 526.216,97.1058 526.225,97.1028 526.234,97.0997 526.243,97.0966 526.253,97.0935 526.262,97.0905 526.271,97.0874 526.28,97.0843 526.289,97.0813 526.298,97.0782 526.308,97.0751 526.317,97.0721 526.326,97.069 526.335,97.0659 526.344,97.0629 526.354,97.0598 526.363,97.0567 526.372,97.0537 526.381,97.0506 526.39,97.0475 526.4,97.0445 526.409,97.0414 526.418,97.0383 526.427,97.0353 526.436,97.0322 526.446,97.0291 526.455,97.0261 526.464,97.023 526.473,97.02 526.482,97.0169 526.491,97.0138 526.501,97.0108 526.51,97.0077 526.519,97.0046 526.528,97.0016 526.537,96.9985 526.547,96.9955 526.556,96.9924 526.565,96.9894 526.574,96.9863 526.583,96.9832 526.593,96.9802 526.602,96.9771 526.611,96.9741 526.62,96.971 526.629,96.968 526.638,96.9649 526.648,96.9618 526.657,96.9588 526.666,96.9557 526.675,96.9527 526.684,96.9496 526.694,96.9466 526.703,96.9435 526.712,96.9405 526.721,96.9374 526.73,96.9344 526.74,96.9313 526.749,96.9283 526.758,96.9252 526.767,96.9222 526.776,96.9191 526.786,96.9161 526.795,96.913 526.804,96.91 526.813,96.9069 526.822,96.9039 526.831,96.9008 526.841,96.8978 526.85,96.8947 526.859,96.8917 526.868,96.8886 526.877,96.8856 526.887,96.8825 526.896,96.8795 526.905,96.8764 526.914,96.8734 526.923,96.8703 526.933,96.8673 526.942,96.8643 526.951,96.8612 526.96,96.8582 526.969,96.8551 526.978,96.8521 526.988,96.849 526.997,96.846 527.006,96.843 527.015,96.8399 527.024,96.8369 527.034,96.8338 527.043,96.8308 527.052,96.8278 527.061,96.8247 527.07,96.8217 527.08,96.8186 527.089,96.8156 527.098,96.8126 527.107,96.8095 527.116,96.8065 527.126,96.8035 527.135,96.8004 527.144,96.7974 527.153,96.7944 527.162,96.7913 527.171,96.7883 527.181,96.7852 527.19,96.7822 527.199,96.7792 527.208,96.7761 527.217,96.7731 527.227,96.7701 527.236,96.767 527.245,96.764 527.254,96.761 527.263,96.758 527.273,96.7549 527.282,96.7519 527.291,96.7489 527.3,96.7458 527.309,96.7428 527.318,96.7398 527.328,96.7367 527.337,96.7337 527.346,96.7307 527.355,96.7277 527.364,96.7246 527.374,96.7216 527.383,96.7186 527.392,96.7156 527.401,96.7125 527.41,96.7095 527.42,96.7065 527.429,96.7035 527.438,96.7004 527.447,96.6974 527.456,96.6944 527.466,96.6914 527.475,96.6883 527.484,96.6853 527.493,96.6823 527.502,96.6793 527.511,96.6762 527.521,96.6732 527.53,96.6702 527.539,96.6672 527.548,96.6642 527.557,96.6611 527.567,96.6581 527.576,96.6551 527.585,96.6521 527.594,96.6491 527.603,96.6461 527.613,96.643 527.622,96.64 527.631,96.637 527.64,96.634 527.649,96.631 527.658,96.628 527.668,96.6249 527.677,96.6219 527.686,96.6189 527.695,96.6159 527.704,96.6129 527.714,96.6099 527.723,96.6069 527.732,96.6038 527.741,96.6008 527.75,96.5978 527.76,96.5948 527.769,96.5918 527.778,96.5888 527.787,96.5858 527.796,96.5828 527.806,96.5798 527.815,96.5767 527.824,96.5737 527.833,96.5707 527.842,96.5677 527.851,96.5647 527.861,96.5617 527.87,96.5587 527.879,96.5557 527.888,96.5527 527.897,96.5497 527.907,96.5467 527.916,96.5437 527.925,96.5407 527.934,96.5376 527.943,96.5346 527.953,96.5316 527.962,96.5286 527.971,96.5256 527.98,96.5226 527.989,96.5196 527.998,96.5166 528.008,96.5136 528.017,96.5106 528.026,96.5076 528.035,96.5046 528.044,96.5016 528.054,96.4986 528.063,96.4956 528.072,96.4926 528.081,96.4896 528.09,96.4866 528.1,96.4836 528.109,96.4806 528.118,96.4776 528.127,96.4746 528.136,96.4716 528.146,96.4686 528.155,96.4656 528.164,96.4626 528.173,96.4596 528.182,96.4566 528.191,96.4537 528.201,96.4507 528.21,96.4477 528.219,96.4447 528.228,96.4417 528.237,96.4387 528.247,96.4357 528.256,96.4327 528.265,96.4297 528.274,96.4267 528.283,96.4237 528.293,96.4207 528.302,96.4177 528.311,96.4148 528.32,96.4118 528.329,96.4088 528.338,96.4058 528.348,96.4028 528.357,96.3998 528.366,96.3968 528.375,96.3938 528.384,96.3908 528.394,96.3879 528.403,96.3849 528.412,96.3819 528.421,96.3789 528.43,96.3759 528.44,96.3729 528.449,96.3699 528.458,96.367 528.467,96.364 528.476,96.361 528.486,96.358 528.495,96.355 528.504,96.352 528.513,96.3491 528.522,96.3461 528.531,96.3431 528.541,96.3401 528.55,96.3371 528.559,96.3341 528.568,96.3312 528.577,96.3282 528.587,96.3252 528.596,96.3222 528.605,96.3192 528.614,96.3163 528.623,96.3133 528.633,96.3103 528.642,96.3073 528.651,96.3044 528.66,96.3014 528.669,96.2984 528.678,96.2954 528.688,96.2925 528.697,96.2895 528.706,96.2865 528.715,96.2835 528.724,96.2806 528.734,96.2776 528.743,96.2746 528.752,96.2716 528.761,96.2687 528.77,96.2657 528.78,96.2627 528.789,96.2597 528.798,96.2568 528.807,96.2538 528.816,96.2508 528.826,96.2479 528.835,96.2449 528.844,96.2419 528.853,96.239 528.862,96.236 528.871,96.233 528.881,96.23 528.89,96.2271 528.899,96.2241 528.908,96.2211 528.917,96.2182 528.927,96.2152 528.936,96.2122 528.945,96.2093 528.954,96.2063 528.963,96.2033 528.973,96.2004 528.982,96.1974 528.991,96.1945 529,96.1915 529.009,96.1885 529.019,96.1856 529.028,96.1826 529.037,96.1796 529.046,96.1767 529.055,96.1737 529.064,96.1708 529.074,96.1678 529.083,96.1648 529.092,96.1619 529.101,96.1589 529.11,96.156 529.12,96.153 529.129,96.15 529.138,96.1471 529.147,96.1441 529.156,96.1412 529.166,96.1382 529.175,96.1352 529.184,96.1323 529.193,96.1293 529.202,96.1264 529.211,96.1234 529.221,96.1205 529.23,96.1175 529.239,96.1146 529.248,96.1116 529.257,96.1086 529.267,96.1057 529.276,96.1027 529.285,96.0998 529.294,96.0968 529.303,96.0939 529.313,96.0909 529.322,96.088 529.331,96.085 529.34,96.0821 529.349,96.0791 529.359,96.0762 529.368,96.0732 529.377,96.0703 529.386,96.0673 529.395,96.0644 529.404,96.0614 529.414,96.0585 529.423,96.0555 529.432,96.0526 529.441,96.0496 529.45,96.0467 529.46,96.0438 529.469,96.0408 529.478,96.0379 529.487,96.0349 529.496,96.032 529.506,96.029 529.515,96.0261 529.524,96.0231 529.533,96.0202 529.542,96.0173 529.551,96.0143 529.561,96.0114 529.57,96.0084 529.579,96.0055 529.588,96.0025 529.597,95.9996 529.607,95.9967 529.616,95.9937 529.625,95.9908 529.634,95.9878 529.643,95.9849 529.653,95.982 529.662,95.979 529.671,95.9761 529.68,95.9732 529.689,95.9702 529.699,95.9673 529.708,95.9643 529.717,95.9614 529.726,95.9585 529.735,95.9555 529.744,95.9526 529.754,95.9497 529.763,95.9467 529.772,95.9438 529.781,95.9409 529.79,95.9379 529.8,95.935 529.809,95.9321 529.818,95.9291 529.827,95.9262 529.836,95.9233 529.846,95.9203 529.855,95.9174 529.864,95.9145 529.873,95.9115 529.882,95.9086 529.891,95.9057 529.901,95.9028 529.91,95.8998 529.919,95.8969 529.928,95.894 529.937,95.891 529.947,95.8881 529.956,95.8852 529.965,95.8823 529.974,95.8793 529.983,95.8764 529.993,95.8735 530.002,95.8706 530.011,95.8676 530.02,95.8647 530.029,95.8618 530.039,95.8589 530.048,95.8559 530.057,95.853 530.066,95.8501 530.075,95.8472 530.084,95.8442 530.094,95.8413 530.103,95.8384 530.112,95.8355 530.121,95.8326 530.13,95.8296 530.14,95.8267 530.149,95.8238 530.158,95.8209 530.167,95.818 530.176,95.815 530.186,95.8121 530.195,95.8092 530.204,95.8063 530.213,95.8034 530.222,95.8005 530.231,95.7975 530.241,95.7946 530.25,95.7917 530.259,95.7888 530.268,95.7859 530.277,95.783 530.287,95.78 530.296,95.7771 530.305,95.7742 530.314,95.7713 530.323,95.7684 530.333,95.7655 530.342,95.7626 530.351,95.7597 530.36,95.7567 530.369,95.7538 530.379,95.7509 530.388,95.748 530.397,95.7451 530.406,95.7422 530.415,95.7393 530.424,95.7364 530.434,95.7335 530.443,95.7306 530.452,95.7276 530.461,95.7247 530.47,95.7218 530.48,95.7189 530.489,95.716 530.498,95.7131 530.507,95.7102 530.516,95.7073 530.526,95.7044 530.535,95.7015 530.544,95.6986 530.553,95.6957 530.562,95.6928 530.571,95.6899 530.581,95.687 530.59,95.6841 530.599,95.6812 530.608,95.6783 530.617,95.6754 530.627,95.6725 530.636,95.6696 530.645,95.6667 530.654,95.6638 530.663,95.6609 530.673,95.658 530.682,95.6551 530.691,95.6522 530.7,95.6493 530.709,95.6464 530.719,95.6435 530.728,95.6406 530.737,95.6377 530.746,95.6348 530.755,95.6319 530.764,95.629 530.774,95.6261 530.783,95.6232 530.792,95.6203 530.801,95.6174 530.81,95.6145 530.82,95.6116 530.829,95.6087 530.838,95.6058 530.847,95.6029 530.856,95.6 530.866,95.5971 530.875,95.5942 530.884,95.5914 530.893,95.5885 530.902,95.5856 530.911,95.5827 530.921,95.5798 530.93,95.5769 530.939,95.574 530.948,95.5711 530.957,95.5682 530.967,95.5653 530.976,95.5625 530.985,95.5596 530.994,95.5567 531.003,95.5538 531.013,95.5509 531.022,95.548 531.031,95.5451 531.04,95.5422 531.049,95.5394 531.059,95.5365 531.068,95.5336 531.077,95.5307 531.086,95.5278 531.095,95.5249 531.104,95.5221 531.114,95.5192 531.123,95.5163 531.132,95.5134 531.141,95.5105 531.15,95.5076 531.16,95.5048 531.169,95.5019 531.178,95.499 531.187,95.4961 531.196,95.4932 531.206,95.4904 531.215,95.4875 531.224,95.4846 531.233,95.4817 531.242,95.4788 531.252,95.476 531.261,95.4731 531.27,95.4702 531.279,95.4673 531.288,95.4645 531.297,95.4616 531.307,95.4587 531.316,95.4558 531.325,95.453 531.334,95.4501 531.343,95.4472 531.353,95.4443 531.362,95.4415 531.371,95.4386 531.38,95.4357 531.389,95.4328 531.399,95.43 531.408,95.4271 531.417,95.4242 531.426,95.4213 531.435,95.4185 531.444,95.4156 531.454,95.4127 531.463,95.4099 531.472,95.407 531.481,95.4041 531.49,95.4013 531.5,95.3984 531.509,95.3955 531.518,95.3927 531.527,95.3898 531.536,95.3869 531.546,95.3841 531.555,95.3812 531.564,95.3783 531.573,95.3755 531.582,95.3726 531.592,95.3697 531.601,95.3669 531.61,95.364 531.619,95.3611 531.628,95.3583 531.637,95.3554 531.647,95.3525 531.656,95.3497 531.665,95.3468 531.674,95.344 531.683,95.3411 531.693,95.3382 531.702,95.3354 531.711,95.3325 531.72,95.3296 531.729,95.3268 531.739,95.3239 531.748,95.3211 531.757,95.3182 531.766,95.3154 531.775,95.3125 531.784,95.3096 531.794,95.3068 531.803,95.3039 531.812,95.3011 531.821,95.2982 531.83,95.2954 531.84,95.2925 531.849,95.2896 531.858,95.2868 531.867,95.2839 531.876,95.2811 531.886,95.2782 531.895,95.2754 531.904,95.2725 531.913,95.2697 531.922,95.2668 531.932,95.264 531.941,95.2611 531.95,95.2583 531.959,95.2554 531.968,95.2526 531.977,95.2497 531.987,95.2468 531.996,95.244 532.005,95.2411 532.014,95.2383 532.023,95.2355 532.033,95.2326 532.042,95.2298 532.051,95.2269 532.06,95.2241 532.069,95.2212 532.079,95.2184 532.088,95.2155 532.097,95.2127 532.106,95.2098 532.115,95.207 532.124,95.2041 532.134,95.2013 532.143,95.1984 532.152,95.1956 532.161,95.1928 532.17,95.1899 532.18,95.1871 532.189,95.1842 532.198,95.1814 532.207,95.1785 532.216,95.1757 532.226,95.1729 532.235,95.17 532.244,95.1672 532.253,95.1643 532.262,95.1615 532.272,95.1587 532.281,95.1558 532.29,95.153 532.299,95.1501 532.308,95.1473 532.317,95.1445 532.327,95.1416 532.336,95.1388 532.345,95.136 532.354,95.1331 532.363,95.1303 532.373,95.1274 532.382,95.1246 532.391,95.1218 532.4,95.1189 532.409,95.1161 532.419,95.1133 532.428,95.1104 532.437,95.1076 532.446,95.1048 532.455,95.1019 532.464,95.0991 532.474,95.0963 532.483,95.0934 532.492,95.0906 532.501,95.0878 532.51,95.085 532.52,95.0821 532.529,95.0793 532.538,95.0765 532.547,95.0736 532.556,95.0708 532.566,95.068 532.575,95.0651 532.584,95.0623 532.593,95.0595 532.602,95.0567 532.612,95.0538 532.621,95.051 532.63,95.0482 532.639,95.0454 532.648,95.0425 532.657,95.0397 532.667,95.0369 532.676,95.0341 532.685,95.0312 532.694,95.0284 532.703,95.0256 532.713,95.0228 532.722,95.0199 532.731,95.0171 532.74,95.0143 532.749,95.0115 532.759,95.0087 532.768,95.0058 532.777,95.003 532.786,95.0002 532.795,94.9974 532.804,94.9945 532.814,94.9917 532.823,94.9889 532.832,94.9861 532.841,94.9833 532.85,94.9805 532.86,94.9776 532.869,94.9748 532.878,94.972 532.887,94.9692 532.896,94.9664 532.906,94.9636 532.915,94.9607 532.924,94.9579 532.933,94.9551 532.942,94.9523 532.952,94.9495 532.961,94.9467 532.97,94.9439 532.979,94.941 532.988,94.9382 532.997,94.9354 533.007,94.9326 533.016,94.9298 533.025,94.927 533.034,94.9242 533.043,94.9214 533.053,94.9185 533.062,94.9157 533.071,94.9129 533.08,94.9101 533.089,94.9073 533.099,94.9045 533.108,94.9017 533.117,94.8989 533.126,94.8961 533.135,94.8933 533.144,94.8905 533.154,94.8877 533.163,94.8848 533.172,94.882 533.181,94.8792 533.19,94.8764 533.2,94.8736 533.209,94.8708 533.218,94.868 533.227,94.8652 533.236,94.8624 533.246,94.8596 533.255,94.8568 533.264,94.854 533.273,94.8512 533.282,94.8484 533.292,94.8456 533.301,94.8428 533.31,94.84 533.319,94.8372 533.328,94.8344 533.337,94.8316 533.347,94.8288 533.356,94.826 533.365,94.8232 533.374,94.8204 533.383,94.8176 533.393,94.8148 533.402,94.812 533.411,94.8092 533.42,94.8064 533.429,94.8036 533.439,94.8008 533.448,94.798 533.457,94.7952 533.466,94.7924 533.475,94.7896 533.484,94.7868 533.494,94.784 533.503,94.7812 533.512,94.7785 533.521,94.7757 533.53,94.7729 533.54,94.7701 533.549,94.7673 533.558,94.7645 533.567,94.7617 533.576,94.7589 533.586,94.7561 533.595,94.7533 533.604,94.7505 533.613,94.7477 533.622,94.745 533.632,94.7422 533.641,94.7394 533.65,94.7366 533.659,94.7338 533.668,94.731 533.677,94.7282 533.687,94.7254 533.696,94.7227 533.705,94.7199 533.714,94.7171 533.723,94.7143 533.733,94.7115 533.742,94.7087 533.751,94.7059 533.76,94.7032 533.769,94.7004 533.779,94.6976 533.788,94.6948 533.797,94.692 533.806,94.6892 533.815,94.6865 533.825,94.6837 533.834,94.6809 533.843,94.6781 533.852,94.6753 533.861,94.6725 533.87,94.6698 533.88,94.667 533.889,94.6642 533.898,94.6614 533.907,94.6586 533.916,94.6559 533.926,94.6531 533.935,94.6503 533.944,94.6475 533.953,94.6448 533.962,94.642 533.972,94.6392 533.981,94.6364 533.99,94.6337 533.999,94.6309 534.008,94.6281 534.017,94.6253 534.027,94.6226 534.036,94.6198 534.045,94.617 534.054,94.6142 534.063,94.6115 534.073,94.6087 534.082,94.6059 534.091,94.6031 534.1,94.6004 534.109,94.5976 534.119,94.5948 534.128,94.5921 534.137,94.5893 534.146,94.5865 534.155,94.5837 534.165,94.581 534.174,94.5782 534.183,94.5754 534.192,94.5727 534.201,94.5699 534.21,94.5671 534.22,94.5644 534.229,94.5616 534.238,94.5588 534.247,94.5561 534.256,94.5533 534.266,94.5505 534.275,94.5478 534.284,94.545 534.293,94.5422 534.302,94.5395 534.312,94.5367 534.321,94.5339 534.33,94.5312 534.339,94.5284 534.348,94.5257 534.357,94.5229 534.367,94.5201 534.376,94.5174 534.385,94.5146 534.394,94.5118 534.403,94.5091 534.413,94.5063 534.422,94.5036 534.431,94.5008 534.44,94.498 534.449,94.4953 534.459,94.4925 534.468,94.4898 534.477,94.487 534.486,94.4843 534.495,94.4815 534.505,94.4787 534.514,94.476 534.523,94.4732 534.532,94.4705 534.541,94.4677 534.55,94.465 534.56,94.4622 534.569,94.4595 534.578,94.4567 534.587,94.4539 534.596,94.4512 534.606,94.4484 534.615,94.4457 534.624,94.4429 534.633,94.4402 534.642,94.4374 534.652,94.4347 534.661,94.4319 534.67,94.4292 534.679,94.4264 534.688,94.4237 534.697,94.4209 534.707,94.4182 534.716,94.4154 534.725,94.4127 534.734,94.4099 534.743,94.4072 534.753,94.4044 534.762,94.4017 534.771,94.3989 534.78,94.3962 534.789,94.3934 534.799,94.3907 534.808,94.3879 534.817,94.3852 534.826,94.3825 534.835,94.3797 534.845,94.377 534.854,94.3742 534.863,94.3715 534.872,94.3687 534.881,94.366 534.89,94.3632 534.9,94.3605 534.909,94.3578 534.918,94.355 534.927,94.3523 534.936,94.3495 534.946,94.3468 534.955,94.3441 534.964,94.3413 534.973,94.3386 534.982,94.3358 534.992,94.3331 535.001,94.3304 535.01,94.3276 535.019,94.3249 535.028,94.3221 535.037,94.3194 535.047,94.3167 535.056,94.3139 535.065,94.3112 535.074,94.3085 535.083,94.3057 535.093,94.303 535.102,94.3003 535.111,94.2975 535.12,94.2948 535.129,94.2921 535.139,94.2893 535.148,94.2866 535.157,94.2839 535.166,94.2811 535.175,94.2784 535.185,94.2757 535.194,94.2729 535.203,94.2702 535.212,94.2675 535.221,94.2647 535.23,94.262 535.24,94.2593 535.249,94.2565 535.258,94.2538 535.267,94.2511 535.276,94.2483 535.286,94.2456 535.295,94.2429 535.304,94.2402 535.313,94.2374 535.322,94.2347 535.332,94.232 535.341,94.2293 535.35,94.2265 535.359,94.2238 535.368,94.2211 535.377,94.2184 535.387,94.2156 535.396,94.2129 535.405,94.2102 535.414,94.2075 535.423,94.2047 535.433,94.202 535.442,94.1993 535.451,94.1966 535.46,94.1938 535.469,94.1911 535.479,94.1884 535.488,94.1857 535.497,94.183 535.506,94.1802 535.515,94.1775 535.525,94.1748 535.534,94.1721 535.543,94.1694 535.552,94.1666 535.561,94.1639 535.57,94.1612 535.58,94.1585 535.589,94.1558 535.598,94.153 535.607,94.1503 535.616,94.1476 535.626,94.1449 535.635,94.1422 535.644,94.1395 535.653,94.1368 535.662,94.134 535.672,94.1313 535.681,94.1286 535.69,94.1259 535.699,94.1232 535.708,94.1205 535.717,94.1178 535.727,94.115 535.736,94.1123 535.745,94.1096 535.754,94.1069 535.763,94.1042 535.773,94.1015 535.782,94.0988 535.791,94.0961 535.8,94.0934 535.809,94.0906 535.819,94.0879 535.828,94.0852 535.837,94.0825 535.846,94.0798 535.855,94.0771 535.865,94.0744 535.874,94.0717 535.883,94.069 535.892,94.0663 535.901,94.0636 535.91,94.0609 535.92,94.0582 535.929,94.0555 535.938,94.0527 535.947,94.05 535.956,94.0473 535.966,94.0446 535.975,94.0419 535.984,94.0392 535.993,94.0365 536.002,94.0338 536.012,94.0311 536.021,94.0284 536.03,94.0257 536.039,94.023 536.048,94.0203 536.057,94.0176 536.067,94.0149 536.076,94.0122 536.085,94.0095 536.094,94.0068 536.103,94.0041 536.113,94.0014 536.122,93.9987 536.131,93.996 536.14,93.9933 536.149,93.9906 536.159,93.9879 536.168,93.9852 536.177,93.9825 536.186,93.9798 536.195,93.9771 536.205,93.9745 536.214,93.9718 536.223,93.9691 536.232,93.9664 536.241,93.9637 536.25,93.961 536.26,93.9583 536.269,93.9556 536.278,93.9529 536.287,93.9502 536.296,93.9475 536.306,93.9448 536.315,93.9421 536.324,93.9394 536.333,93.9368 536.342,93.9341 536.352,93.9314 536.361,93.9287 536.37,93.926 536.379,93.9233 536.388,93.9206 536.398,93.9179 536.407,93.9152 536.416,93.9126 536.425,93.9099 536.434,93.9072 536.443,93.9045 536.453,93.9018 536.462,93.8991 536.471,93.8964 536.48,93.8937 536.489,93.8911 536.499,93.8884 536.508,93.8857 536.517,93.883 536.526,93.8803 536.535,93.8776 536.545,93.875 536.554,93.8723 536.563,93.8696 536.572,93.8669 536.581,93.8642 536.59,93.8616 536.6,93.8589 536.609,93.8562 536.618,93.8535 536.627,93.8508 536.636,93.8481 536.646,93.8455 536.655,93.8428 536.664,93.8401 536.673,93.8374 536.682,93.8348 536.692,93.8321 536.701,93.8294 536.71,93.8267 536.719,93.824 536.728,93.8214 536.738,93.8187 536.747,93.816 536.756,93.8133 536.765,93.8107 536.774,93.808 536.783,93.8053 536.793,93.8026 536.802,93.8 536.811,93.7973 536.82,93.7946 536.829,93.792 536.839,93.7893 536.848,93.7866 536.857,93.7839 536.866,93.7813 536.875,93.7786 536.885,93.7759 536.894,93.7733 536.903,93.7706 536.912,93.7679 536.921,93.7652 536.93,93.7626 536.94,93.7599 536.949,93.7572 536.958,93.7546 536.967,93.7519 536.976,93.7492 536.986,93.7466 536.995,93.7439 537.004,93.7412 537.013,93.7386 537.022,93.7359 537.032,93.7332 537.041,93.7306 537.05,93.7279 537.059,93.7252 537.068,93.7226 537.078,93.7199 537.087,93.7172 537.096,93.7146 537.105,93.7119 537.114,93.7093 537.123,93.7066 537.133,93.7039 537.142,93.7013 537.151,93.6986 537.16,93.696 537.169,93.6933 537.179,93.6906 537.188,93.688 537.197,93.6853 537.206,93.6827 537.215,93.68 537.225,93.6773 537.234,93.6747 537.243,93.672 537.252,93.6694 537.261,93.6667 537.27,93.664 537.28,93.6614 537.289,93.6587 537.298,93.6561 537.307,93.6534 537.316,93.6508 537.326,93.6481 537.335,93.6455 537.344,93.6428 537.353,93.6401 537.362,93.6375 537.372,93.6348 537.381,93.6322 537.39,93.6295 537.399,93.6269 537.408,93.6242 537.418,93.6216 537.427,93.6189 537.436,93.6163 537.445,93.6136 537.454,93.611 537.463,93.6083 537.473,93.6057 537.482,93.603 537.491,93.6004 537.5,93.5977 537.509,93.5951 537.519,93.5924 537.528,93.5898 537.537,93.5871 537.546,93.5845 537.555,93.5818 537.565,93.5792 537.574,93.5765 537.583,93.5739 537.592,93.5713 537.601,93.5686 537.61,93.566 537.62,93.5633 537.629,93.5607 537.638,93.558 537.647,93.5554 537.656,93.5527 537.666,93.5501 537.675,93.5475 537.684,93.5448 537.693,93.5422 537.702,93.5395 537.712,93.5369 537.721,93.5343 537.73,93.5316 537.739,93.529 537.748,93.5263 537.758,93.5237 537.767,93.5211 537.776,93.5184 537.785,93.5158 537.794,93.5131 537.803,93.5105 537.813,93.5079 537.822,93.5052 537.831,93.5026 537.84,93.5 537.849,93.4973 537.859,93.4947 537.868,93.492 537.877,93.4894 537.886,93.4868 537.895,93.4841 537.905,93.4815 537.914,93.4789 537.923,93.4762 537.932,93.4736 537.941,93.471 537.95,93.4683 537.96,93.4657 537.969,93.4631 537.978,93.4604 537.987,93.4578 537.996,93.4552 538.006,93.4525 538.015,93.4499 538.024,93.4473 538.033,93.4447 538.042,93.442 538.052,93.4394 538.061,93.4368 538.07,93.4341 538.079,93.4315 538.088,93.4289 538.098,93.4263 538.107,93.4236 538.116,93.421 538.125,93.4184 538.134,93.4158 538.143,93.4131 538.153,93.4105 538.162,93.4079 538.171,93.4053 538.18,93.4026 538.189,93.4 538.199,93.3974 538.208,93.3948 538.217,93.3921 538.226,93.3895 538.235,93.3869 538.245,93.3843 538.254,93.3816 538.263,93.379 538.272,93.3764 538.281,93.3738 538.29,93.3712 538.3,93.3685 538.309,93.3659 538.318,93.3633 538.327,93.3607 538.336,93.3581 538.346,93.3554 538.355,93.3528 538.364,93.3502 538.373,93.3476 538.382,93.345 538.392,93.3424 538.401,93.3397 538.41,93.3371 538.419,93.3345 538.428,93.3319 538.438,93.3293 538.447,93.3267 538.456,93.324 538.465,93.3214 538.474,93.3188 538.483,93.3162 538.493,93.3136 538.502,93.311 538.511,93.3084 538.52,93.3057 538.529,93.3031 538.539,93.3005 538.548,93.2979 538.557,93.2953 538.566,93.2927 538.575,93.2901 538.585,93.2875 538.594,93.2849 538.603,93.2822 538.612,93.2796 538.621,93.277 538.631,93.2744 538.64,93.2718 538.649,93.2692 538.658,93.2666 538.667,93.264 538.676,93.2614 538.686,93.2588 538.695,93.2562 538.704,93.2536 538.713,93.251 538.722,93.2484 538.732,93.2457 538.741,93.2431 538.75,93.2405 538.759,93.2379 538.768,93.2353 538.778,93.2327 538.787,93.2301 538.796,93.2275 538.805,93.2249 538.814,93.2223 538.823,93.2197 538.833,93.2171 538.842,93.2145 538.851,93.2119 538.86,93.2093 538.869,93.2067 538.879,93.2041 538.888,93.2015 538.897,93.1989 538.906,93.1963 538.915,93.1937 538.925,93.1911 538.934,93.1885 538.943,93.1859 538.952,93.1833 538.961,93.1807 538.971,93.1781 538.98,93.1755 538.989,93.1729 538.998,93.1703 539.007,93.1677 539.016,93.1651 539.026,93.1626 539.035,93.16 539.044,93.1574 539.053,93.1548 539.062,93.1522 539.072,93.1496 539.081,93.147 539.09,93.1444 539.099,93.1418 539.108,93.1392 539.118,93.1366 539.127,93.134 539.136,93.1314 539.145,93.1289 539.154,93.1263 539.163,93.1237 539.173,93.1211 539.182,93.1185 539.191,93.1159 539.2,93.1133 539.209,93.1107 539.219,93.1081 539.228,93.1056 539.237,93.103 539.246,93.1004 539.255,93.0978 539.265,93.0952 539.274,93.0926 539.283,93.09 539.292,93.0874 539.301,93.0849 539.311,93.0823 539.32,93.0797 539.329,93.0771 539.338,93.0745 539.347,93.0719 539.356,93.0694 539.366,93.0668 539.375,93.0642 539.384,93.0616 539.393,93.059 539.402,93.0564 539.412,93.0539 539.421,93.0513 539.43,93.0487 539.439,93.0461 539.448,93.0435 539.458,93.041 539.467,93.0384 539.476,93.0358 539.485,93.0332 539.494,93.0307 539.503,93.0281 539.513,93.0255 539.522,93.0229 539.531,93.0203 539.54,93.0178 539.549,93.0152 539.559,93.0126 539.568,93.01 539.577,93.0075 539.586,93.0049 539.595,93.0023 539.605,92.9997 539.614,92.9972 539.623,92.9946 539.632,92.992 539.641,92.9894 539.651,92.9869 539.66,92.9843 539.669,92.9817 539.678,92.9792 539.687,92.9766 539.696,92.974 539.706,92.9714 539.715,92.9689 539.724,92.9663 539.733,92.9637 539.742,92.9612 539.752,92.9586 539.761,92.956 539.77,92.9535 539.779,92.9509 539.788,92.9483 539.798,92.9457 539.807,92.9432 539.816,92.9406 539.825,92.938 539.834,92.9355 539.843,92.9329 539.853,92.9303 539.862,92.9278 539.871,92.9252 539.88,92.9227 539.889,92.9201 539.899,92.9175 539.908,92.915 539.917,92.9124 539.926,92.9098 539.935,92.9073 539.945,92.9047 539.954,92.9021 539.963,92.8996 539.972,92.897 539.981,92.8945 539.991,92.8919 540,92.8893 540.009,92.8868 540.018,92.8842 540.027,92.8817 540.036,92.8791 540.046,92.8765 540.055,92.874 540.064,92.8714 540.073,92.8689 540.082,92.8663 540.092,92.8638 540.101,92.8612 540.11,92.8586 540.119,92.8561 540.128,92.8535 540.138,92.851 540.147,92.8484 540.156,92.8459 540.165,92.8433 540.174,92.8408 540.183,92.8382 540.193,92.8356 540.202,92.8331 540.211,92.8305 540.22,92.828 540.229,92.8254 540.239,92.8229 540.248,92.8203 540.257,92.8178 540.266,92.8152 540.275,92.8127 540.285,92.8101 540.294,92.8076 540.303,92.805 540.312,92.8025 540.321,92.7999 540.331,92.7974 540.34,92.7948 540.349,92.7923 540.358,92.7897 540.367,92.7872 540.376,92.7846 540.386,92.7821 540.395,92.7795 540.404,92.777 540.413,92.7744 540.422,92.7719 540.432,92.7694 540.441,92.7668 540.45,92.7643 540.459,92.7617 540.468,92.7592 540.478,92.7566 540.487,92.7541 540.496,92.7515 540.505,92.749 540.514,92.7465 540.523,92.7439 540.533,92.7414 540.542,92.7388 540.551,92.7363 540.56,92.7338 540.569,92.7312 540.579,92.7287 540.588,92.7261 540.597,92.7236 540.606,92.7211 540.615,92.7185 540.625,92.716 540.634,92.7134 540.643,92.7109 540.652,92.7084 540.661,92.7058 540.671,92.7033 540.68,92.7007 540.689,92.6982 540.698,92.6957 540.707,92.6931 540.716,92.6906 540.726,92.6881 540.735,92.6855 540.744,92.683 540.753,92.6805 540.762,92.6779 540.772,92.6754 540.781,92.6729 540.79,92.6703 540.799,92.6678 540.808,92.6653 540.818,92.6627 540.827,92.6602 540.836,92.6577 540.845,92.6551 540.854,92.6526 540.863,92.6501 540.873,92.6475 540.882,92.645 540.891,92.6425 540.9,92.64 540.909,92.6374 540.919,92.6349 540.928,92.6324 540.937,92.6298 540.946,92.6273 540.955,92.6248 540.965,92.6223 540.974,92.6197 540.983,92.6172 540.992,92.6147 541.001,92.6122 541.011,92.6096 541.02,92.6071 541.029,92.6046 541.038,92.6021 541.047,92.5995 541.056,92.597 541.066,92.5945 541.075,92.592 541.084,92.5894 541.093,92.5869 541.102,92.5844 541.112,92.5819 541.121,92.5793 541.13,92.5768 541.139,92.5743 541.148,92.5718 541.158,92.5693 541.167,92.5667 541.176,92.5642 541.185,92.5617 541.194,92.5592 541.204,92.5567 541.213,92.5541 541.222,92.5516 541.231,92.5491 541.24,92.5466 541.249,92.5441 541.259,92.5416 541.268,92.539 541.277,92.5365 541.286,92.534 541.295,92.5315 541.305,92.529 541.314,92.5265 541.323,92.524 541.332,92.5214 541.341,92.5189 541.351,92.5164 541.36,92.5139 541.369,92.5114 541.378,92.5089 541.387,92.5064 541.396,92.5038 541.406,92.5013 541.415,92.4988 541.424,92.4963 541.433,92.4938 541.442,92.4913 541.452,92.4888 541.461,92.4863 541.47,92.4838 541.479,92.4813 541.488,92.4787 541.498,92.4762 541.507,92.4737 541.516,92.4712 541.525,92.4687 541.534,92.4662 541.544,92.4637 541.553,92.4612 541.562,92.4587 541.571,92.4562 541.58,92.4537 541.589,92.4512 541.599,92.4487 541.608,92.4462 541.617,92.4436 541.626,92.4411 541.635,92.4386 541.645,92.4361 541.654,92.4336 541.663,92.4311 541.672,92.4286 541.681,92.4261 541.691,92.4236 541.7,92.4211 541.709,92.4186 541.718,92.4161 541.727,92.4136 541.736,92.4111 541.746,92.4086 541.755,92.4061 541.764,92.4036 541.773,92.4011 541.782,92.3986 541.792,92.3961 541.801,92.3936 541.81,92.3911 541.819,92.3886 541.828,92.3861 541.838,92.3836 541.847,92.3811 541.856,92.3786 541.865,92.3761 541.874,92.3736 541.884,92.3712 541.893,92.3687 541.902,92.3662 541.911,92.3637 541.92,92.3612 541.929,92.3587 541.939,92.3562 541.948,92.3537 541.957,92.3512 541.966,92.3487 541.975,92.3462 541.985,92.3437 541.994,92.3412 542.003,92.3387 542.012,92.3363 542.021,92.3338 542.031,92.3313 542.04,92.3288 542.049,92.3263 542.058,92.3238 542.067,92.3213 542.076,92.3188 542.086,92.3163 542.095,92.3138 542.104,92.3114 542.113,92.3089 542.122,92.3064 542.132,92.3039 542.141,92.3014 542.15,92.2989 542.159,92.2964 542.168,92.294 542.178,92.2915 542.187,92.289 542.196,92.2865 542.205,92.284 542.214,92.2815 542.224,92.279 542.233,92.2766 542.242,92.2741 542.251,92.2716 542.26,92.2691 542.269,92.2666 542.279,92.2642 542.288,92.2617 542.297,92.2592 542.306,92.2567 542.315,92.2542 542.325,92.2517 542.334,92.2493 542.343,92.2468 542.352,92.2443 542.361,92.2418 542.371,92.2394 542.38,92.2369 542.389,92.2344 542.398,92.2319 542.407,92.2294 542.416,92.227 542.426,92.2245 542.435,92.222 542.444,92.2195 542.453,92.2171 542.462,92.2146 542.472,92.2121 542.481,92.2096 542.49,92.2072 542.499,92.2047 542.508,92.2022 542.518,92.1997 542.527,92.1973 542.536,92.1948 542.545,92.1923 542.554,92.1898 542.564,92.1874 542.573,92.1849 542.582,92.1824 542.591,92.18 542.6,92.1775 542.609,92.175 542.619,92.1725 542.628,92.1701 542.637,92.1676 542.646,92.1651 542.655,92.1627 542.665,92.1602 542.674,92.1577 542.683,92.1553 542.692,92.1528 542.701,92.1503 542.711,92.1479 542.72,92.1454 542.729,92.1429 542.738,92.1405 542.747,92.138 542.756,92.1355 542.766,92.1331 542.775,92.1306 542.784,92.1281 542.793,92.1257 542.802,92.1232 542.812,92.1207 542.821,92.1183 542.83,92.1158 542.839,92.1134 542.848,92.1109 542.858,92.1084 542.867,92.106 542.876,92.1035 542.885,92.101 542.894,92.0986 542.904,92.0961 542.913,92.0937 542.922,92.0912 542.931,92.0887 542.94,92.0863 542.949,92.0838 542.959,92.0814 542.968,92.0789 542.977,92.0765 542.986,92.074 542.995,92.0715 543.005,92.0691 543.014,92.0666 543.023,92.0642 543.032,92.0617 543.041,92.0593 543.051,92.0568 543.06,92.0543 543.069,92.0519 543.078,92.0494 543.087,92.047 543.096,92.0445 543.106,92.0421 543.115,92.0396 543.124,92.0372 543.133,92.0347 543.142,92.0323 543.152,92.0298 543.161,92.0274 543.17,92.0249 543.179,92.0225 543.188,92.02 543.198,92.0176 543.207,92.0151 543.216,92.0127 543.225,92.0102 543.234,92.0078 543.244,92.0053 543.253,92.0029 543.262,92.0004 543.271,91.998 543.28,91.9955 543.289,91.9931 543.299,91.9906 543.308,91.9882 543.317,91.9857 543.326,91.9833 543.335,91.9808 543.345,91.9784 543.354,91.9759 543.363,91.9735 543.372,91.9711 543.381,91.9686 543.391,91.9662 543.4,91.9637 543.409,91.9613 543.418,91.9588 543.427,91.9564 543.436,91.9539 543.446,91.9515 543.455,91.9491 543.464,91.9466 543.473,91.9442 543.482,91.9417 543.492,91.9393 543.501,91.9369 543.51,91.9344 543.519,91.932 543.528,91.9295 543.538,91.9271 543.547,91.9247 543.556,91.9222 543.565,91.9198 543.574,91.9174 543.584,91.9149 543.593,91.9125 543.602,91.91 543.611,91.9076 543.62,91.9052 543.629,91.9027 543.639,91.9003 543.648,91.8979 543.657,91.8954 543.666,91.893 543.675,91.8906 543.685,91.8881 543.694,91.8857 543.703,91.8833 543.712,91.8808 543.721,91.8784 543.731,91.876 543.74,91.8735 543.749,91.8711 543.758,91.8687 543.767,91.8662 543.777,91.8638 543.786,91.8614 543.795,91.8589 543.804,91.8565 543.813,91.8541 543.822,91.8516 543.832,91.8492 543.841,91.8468 543.85,91.8444 543.859,91.8419 543.868,91.8395 543.878,91.8371 543.887,91.8347 543.896,91.8322 543.905,91.8298 543.914,91.8274 543.924,91.8249 543.933,91.8225 543.942,91.8201 543.951,91.8177 543.96,91.8152 543.969,91.8128 543.979,91.8104 543.988,91.808 543.997,91.8056 544.006,91.8031 544.015,91.8007 544.025,91.7983 544.034,91.7959 544.043,91.7934 544.052,91.791 544.061,91.7886 544.071,91.7862 544.08,91.7838 544.089,91.7813 544.098,91.7789 544.107,91.7765 544.117,91.7741 544.126,91.7717 544.135,91.7692 544.144,91.7668 544.153,91.7644 544.162,91.762 544.172,91.7596 544.181,91.7571 544.19,91.7547 544.199,91.7523 544.208,91.7499 544.218,91.7475 544.227,91.7451 544.236,91.7427 544.245,91.7402 544.254,91.7378 544.264,91.7354 544.273,91.733 544.282,91.7306 544.291,91.7282 544.3,91.7258 544.309,91.7233 544.319,91.7209 544.328,91.7185 544.337,91.7161 544.346,91.7137 544.355,91.7113 544.365,91.7089 544.374,91.7065 544.383,91.704 544.392,91.7016 544.401,91.6992 544.411,91.6968 544.42,91.6944 544.429,91.692 544.438,91.6896 544.447,91.6872 544.457,91.6848 544.466,91.6824 544.475,91.68 544.484,91.6776 544.493,91.6751 544.502,91.6727 544.512,91.6703 544.521,91.6679 544.53,91.6655 544.539,91.6631 544.548,91.6607 544.558,91.6583 544.567,91.6559 544.576,91.6535 544.585,91.6511 544.594,91.6487 544.604,91.6463 544.613,91.6439 544.622,91.6415 544.631,91.6391 544.64,91.6367 544.649,91.6343 544.659,91.6319 544.668,91.6295 544.677,91.6271 544.686,91.6247 544.695,91.6223 544.705,91.6199 544.714,91.6175 544.723,91.6151 544.732,91.6127 544.741,91.6103 544.751,91.6079 544.76,91.6055 544.769,91.6031 544.778,91.6007 544.787,91.5983 544.797,91.5959 544.806,91.5935 544.815,91.5911 544.824,91.5887 544.833,91.5863 544.842,91.5839 544.852,91.5815 544.861,91.5791 544.87,91.5767 544.879,91.5743 544.888,91.5719 544.898,91.5696 544.907,91.5672 544.916,91.5648 544.925,91.5624 544.934,91.56 544.944,91.5576 544.953,91.5552 544.962,91.5528 544.971,91.5504 544.98,91.548 544.989,91.5456 544.999,91.5433 545.008,91.5409 545.017,91.5385 545.026,91.5361 545.035,91.5337 545.045,91.5313 545.054,91.5289 545.063,91.5265 545.072,91.5241 545.081,91.5218 545.091,91.5194 545.1,91.517 545.109,91.5146 545.118,91.5122 545.127,91.5098 545.137,91.5074 545.146,91.5051 545.155,91.5027 545.164,91.5003 545.173,91.4979 545.182,91.4955 545.192,91.4931 545.201,91.4908 545.21,91.4884 545.219,91.486 545.228,91.4836 545.238,91.4812 545.247,91.4788 545.256,91.4765 545.265,91.4741 545.274,91.4717 545.284,91.4693 545.293,91.4669 545.302,91.4646 545.311,91.4622 545.32,91.4598 545.329,91.4574 545.339,91.455 545.348,91.4527 545.357,91.4503 545.366,91.4479 545.375,91.4455 545.385,91.4432 545.394,91.4408 545.403,91.4384 545.412,91.436 545.421,91.4337 545.431,91.4313 545.44,91.4289 545.449,91.4265 545.458,91.4242 545.467,91.4218 545.477,91.4194 545.486,91.417 545.495,91.4147 545.504,91.4123 545.513,91.4099 545.522,91.4075 545.532,91.4052 545.541,91.4028 545.55,91.4004 545.559,91.3981 545.568,91.3957 545.578,91.3933 545.587,91.3909 545.596,91.3886 545.605,91.3862 545.614,91.3838 545.624,91.3815 545.633,91.3791 545.642,91.3767 545.651,91.3744 545.66,91.372 545.669,91.3696 545.679,91.3673 545.688,91.3649 545.697,91.3625 545.706,91.3602 545.715,91.3578 545.725,91.3554 545.734,91.3531 545.743,91.3507 545.752,91.3483 545.761,91.346 545.771,91.3436 545.78,91.3412 545.789,91.3389 545.798,91.3365 545.807,91.3342 545.817,91.3318 545.826,91.3294 545.835,91.3271 545.844,91.3247 545.853,91.3223 545.862,91.32 545.872,91.3176 545.881,91.3153 545.89,91.3129 545.899,91.3105 545.908,91.3082 545.918,91.3058 545.927,91.3035 545.936,91.3011 545.945,91.2987 545.954,91.2964 545.964,91.294 545.973,91.2917 545.982,91.2893 545.991,91.287 546,91.2846 546.01,91.2823 546.019,91.2799 546.028,91.2775 546.037,91.2752 546.046,91.2728 546.055,91.2705 546.065,91.2681 546.074,91.2658 546.083,91.2634 546.092,91.2611 546.101,91.2587 546.111,91.2564 546.12,91.254 546.129,91.2516 546.138,91.2493 546.147,91.2469 546.157,91.2446 546.166,91.2422 546.175,91.2399 546.184,91.2375 546.193,91.2352 546.202,91.2328 546.212,91.2305 546.221,91.2281 546.23,91.2258 546.239,91.2234 546.248,91.2211 546.258,91.2188 546.267,91.2164 546.276,91.2141 546.285,91.2117 546.294,91.2094 546.304,91.207 546.313,91.2047 546.322,91.2023 546.331,91.2 546.34,91.1976 546.35,91.1953 546.359,91.1929 546.368,91.1906 546.377,91.1883 546.386,91.1859 546.395,91.1836 546.405,91.1812 546.414,91.1789 546.423,91.1765 546.432,91.1742 546.441,91.1719 546.451,91.1695 546.46,91.1672 546.469,91.1648 546.478,91.1625 546.487,91.1602 546.497,91.1578 546.506,91.1555 546.515,91.1531 546.524,91.1508 546.533,91.1485 546.542,91.1461 546.552,91.1438 546.561,91.1414 546.57,91.1391 546.579,91.1368 546.588,91.1344 546.598,91.1321 546.607,91.1298 546.616,91.1274 546.625,91.1251 546.634,91.1228 546.644,91.1204 546.653,91.1181 546.662,91.1157 546.671,91.1134 546.68,91.1111 546.69,91.1087 546.699,91.1064 546.708,91.1041 546.717,91.1017 546.726,91.0994 546.735,91.0971 546.745,91.0948 546.754,91.0924 546.763,91.0901 546.772,91.0878 546.781,91.0854 546.791,91.0831 546.8,91.0808 546.809,91.0784 546.818,91.0761 546.827,91.0738 546.837,91.0715 546.846,91.0691 546.855,91.0668 546.864,91.0645 546.873,91.0621 546.882,91.0598 546.892,91.0575 546.901,91.0552 546.91,91.0528 546.919,91.0505 546.928,91.0482 546.938,91.0459 546.947,91.0435 546.956,91.0412 546.965,91.0389 546.974,91.0366 546.984,91.0342 546.993,91.0319 547.002,91.0296 547.011,91.0273 547.02,91.0249 547.03,91.0226 547.039,91.0203 547.048,91.018 547.057,91.0157 547.066,91.0133 547.075,91.011 547.085,91.0087 547.094,91.0064 547.103,91.0041 547.112,91.0017 547.121,90.9994 547.131,90.9971 547.14,90.9948 547.149,90.9925 547.158,90.9901 547.167,90.9878 547.177,90.9855 547.186,90.9832 547.195,90.9809 547.204,90.9786 547.213,90.9762 547.222,90.9739 547.232,90.9716 547.241,90.9693 547.25,90.967 547.259,90.9647 547.268,90.9623 547.278,90.96 547.287,90.9577 547.296,90.9554 547.305,90.9531 547.314,90.9508 547.324,90.9485 547.333,90.9462 547.342,90.9438 547.351,90.9415 547.36,90.9392 547.37,90.9369 547.379,90.9346 547.388,90.9323 547.397,90.93 547.406,90.9277 547.415,90.9254 547.425,90.923 547.434,90.9207 547.443,90.9184 547.452,90.9161 547.461,90.9138 547.471,90.9115 547.48,90.9092 547.489,90.9069 547.498,90.9046 547.507,90.9023 547.517,90.9 547.526,90.8977 547.535,90.8954 547.544,90.8931 547.553,90.8907 547.562,90.8884 547.572,90.8861 547.581,90.8838 547.59,90.8815 547.599,90.8792 547.608,90.8769 547.618,90.8746 547.627,90.8723 547.636,90.87 547.645,90.8677 547.654,90.8654 547.664,90.8631 547.673,90.8608 547.682,90.8585 547.691,90.8562 547.7,90.8539 547.71,90.8516 547.719,90.8493 547.728,90.847 547.737,90.8447 547.746,90.8424 547.755,90.8401 547.765,90.8378 547.774,90.8355 547.783,90.8332 547.792,90.8309 547.801,90.8286 547.811,90.8263 547.82,90.824 547.829,90.8217 547.838,90.8194 547.847,90.8171 547.857,90.8148 547.866,90.8126 547.875,90.8103 547.884,90.808 547.893,90.8057 547.902,90.8034 547.912,90.8011 547.921,90.7988 547.93,90.7965 547.939,90.7942 547.948,90.7919 547.958,90.7896 547.967,90.7873 547.976,90.785 547.985,90.7827 547.994,90.7805 548.004,90.7782 548.013,90.7759 548.022,90.7736 548.031,90.7713 548.04,90.769 548.05,90.7667 548.059,90.7644 548.068,90.7621 548.077,90.7599 548.086,90.7576 548.095,90.7553 548.105,90.753 548.114,90.7507 548.123,90.7484 548.132,90.7461 548.141,90.7438 548.151,90.7416 548.16,90.7393 548.169,90.737 548.178,90.7347 548.187,90.7324 548.197,90.7301 548.206,90.7279 548.215,90.7256 548.224,90.7233 548.233,90.721 548.242,90.7187 548.252,90.7164 548.261,90.7142 548.27,90.7119 548.279,90.7096 548.288,90.7073 548.298,90.705 548.307,90.7028 548.316,90.7005 548.325,90.6982 548.334,90.6959 548.344,90.6936 548.353,90.6914 548.362,90.6891 548.371,90.6868 548.38,90.6845 548.39,90.6822 548.399,90.68 548.408,90.6777 548.417,90.6754 548.426,90.6731 548.435,90.6709 548.445,90.6686 548.454,90.6663 548.463,90.664 548.472,90.6618 548.481,90.6595 548.491,90.6572 548.5,90.6549 548.509,90.6527 548.518,90.6504 548.527,90.6481 548.537,90.6458 548.546,90.6436 548.555,90.6413 548.564,90.639 548.573,90.6367 548.583,90.6345 548.592,90.6322 548.601,90.6299 548.61,90.6277 548.619,90.6254 548.628,90.6231 548.638,90.6209 548.647,90.6186 548.656,90.6163 548.665,90.614 548.674,90.6118 548.684,90.6095 548.693,90.6072 548.702,90.605 548.711,90.6027 548.72,90.6004 548.73,90.5982 548.739,90.5959 548.748,90.5936 548.757,90.5914 548.766,90.5891 548.775,90.5868 548.785,90.5846 548.794,90.5823 548.803,90.58 548.812,90.5778 548.821,90.5755 548.831,90.5733 548.84,90.571 548.849,90.5687 548.858,90.5665 548.867,90.5642 548.877,90.5619 548.886,90.5597 548.895,90.5574 548.904,90.5552 548.913,90.5529 548.923,90.5506 548.932,90.5484 548.941,90.5461 548.95,90.5439 548.959,90.5416 548.968,90.5393 548.978,90.5371 548.987,90.5348 548.996,90.5326 549.005,90.5303 549.014,90.5281 549.024,90.5258 549.033,90.5235 549.042,90.5213 549.051,90.519 549.06,90.5168 549.07,90.5145 549.079,90.5123 549.088,90.51 549.097,90.5077 549.106,90.5055 549.115,90.5032 549.125,90.501 549.134,90.4987 549.143,90.4965 549.152,90.4942 549.161,90.492 549.171,90.4897 549.18,90.4875 549.189,90.4852 549.198,90.483 549.207,90.4807 549.217,90.4785 549.226,90.4762 549.235,90.474 549.244,90.4717 549.253,90.4695 549.263,90.4672 549.272,90.465 549.281,90.4627 549.29,90.4605 549.299,90.4582 549.308,90.456 549.318,90.4537 549.327,90.4515 549.336,90.4492 549.345,90.447 549.354,90.4447 549.364,90.4425 549.373,90.4402 549.382,90.438 549.391,90.4358 549.4,90.4335 549.41,90.4313 549.419,90.429 549.428,90.4268 549.437,90.4245 549.446,90.4223 549.455,90.42 549.465,90.4178 549.474,90.4156 549.483,90.4133 549.492,90.4111 549.501,90.4088 549.511,90.4066 549.52,90.4044 549.529,90.4021 549.538,90.3999 549.547,90.3976 549.557,90.3954 549.566,90.3931 549.575,90.3909 549.584,90.3887 549.593,90.3864 549.603,90.3842 549.612,90.382 549.621,90.3797 549.63,90.3775 549.639,90.3752 549.648,90.373 549.658,90.3708 549.667,90.3685 549.676,90.3663 549.685,90.3641 549.694,90.3618 549.704,90.3596 549.713,90.3574 549.722,90.3551 549.731,90.3529 549.74,90.3507 549.75,90.3484 549.759,90.3462 549.768,90.344 549.777,90.3417 549.786,90.3395 549.795,90.3373 549.805,90.335 549.814,90.3328 549.823,90.3306 549.832,90.3283 549.841,90.3261 549.851,90.3239 549.86,90.3216 549.869,90.3194 549.878,90.3172 549.887,90.3149 549.897,90.3127 549.906,90.3105 549.915,90.3083 549.924,90.306 549.933,90.3038 549.943,90.3016 549.952,90.2994 549.961,90.2971 549.97,90.2949 549.979,90.2927 549.988,90.2904 549.998,90.2882 550.007,90.286 550.016,90.2838 550.025,90.2815 550.034,90.2793 550.044,90.2771 550.053,90.2749 550.062,90.2727 550.071,90.2704 550.08,90.2682 550.09,90.266 550.099,90.2638 550.108,90.2615 550.117,90.2593 550.126,90.2571 550.135,90.2549 550.145,90.2527 550.154,90.2504 550.163,90.2482 550.172,90.246 550.181,90.2438 550.191,90.2416 550.2,90.2393 550.209,90.2371 550.218,90.2349 550.227,90.2327 550.237,90.2305 550.246,90.2282 550.255,90.226 550.264,90.2238 550.273,90.2216 550.283,90.2194 550.292,90.2172 550.301,90.2149 550.31,90.2127 550.319,90.2105 550.328,90.2083 550.338,90.2061 550.347,90.2039 550.356,90.2017 550.365,90.1994 550.374,90.1972 550.384,90.195 550.393,90.1928 550.402,90.1906 550.411,90.1884 550.42,90.1862 550.43,90.1839 550.439,90.1817 550.448,90.1795 550.457,90.1773 550.466,90.1751 550.475,90.1729 550.485,90.1707 550.494,90.1685 550.503,90.1663 550.512,90.1641 550.521,90.1618 550.531,90.1596 550.54,90.1574 550.549,90.1552 550.558,90.153 550.567,90.1508 550.577,90.1486 550.586,90.1464 550.595,90.1442 550.604,90.142 550.613,90.1398 550.623,90.1376 550.632,90.1354 550.641,90.1332 550.65,90.131 550.659,90.1287 550.668,90.1265 550.678,90.1243 550.687,90.1221 550.696,90.1199 550.705,90.1177 550.714,90.1155 550.724,90.1133 550.733,90.1111 550.742,90.1089 550.751,90.1067 550.76,90.1045 550.77,90.1023 550.779,90.1001 550.788,90.0979 550.797,90.0957 550.806,90.0935 550.815,90.0913 550.825,90.0891 550.834,90.0869 550.843,90.0847 550.852,90.0825 550.861,90.0803 550.871,90.0781 550.88,90.0759 550.889,90.0737 550.898,90.0715 550.907,90.0693 550.917,90.0671 550.926,90.0649 550.935,90.0628 550.944,90.0606 550.953,90.0584 550.963,90.0562 550.972,90.054 550.981,90.0518 550.99,90.0496 550.999,90.0474 551.008,90.0452 551.018,90.043 551.027,90.0408 551.036,90.0386 551.045,90.0364 551.054,90.0342 551.064,90.032 551.073,90.0299 551.082,90.0277 551.091,90.0255 551.1,90.0233 551.11,90.0211 551.119,90.0189 551.128,90.0167 551.137,90.0145 551.146,90.0123 551.156,90.0101 551.165,90.008 551.174,90.0058 551.183,90.0036 551.192,90.0014 551.201,89.9992 551.211,89.997 551.22,89.9948 551.229,89.9926 551.238,89.9905 551.247,89.9883 551.257,89.9861 551.266,89.9839 551.275,89.9817 551.284,89.9795 551.293,89.9774 551.303,89.9752 551.312,89.973 551.321,89.9708 551.33,89.9686 551.339,89.9664 551.348,89.9643 551.358,89.9621 551.367,89.9599 551.376,89.9577 551.385,89.9555 551.394,89.9533 551.404,89.9512 551.413,89.949 551.422,89.9468 551.431,89.9446 551.44,89.9424 551.45,89.9403 551.459,89.9381 551.468,89.9359 551.477,89.9337 551.486,89.9316 551.496,89.9294 551.505,89.9272 551.514,89.925 551.523,89.9228 551.532,89.9207 551.541,89.9185 551.551,89.9163 551.56,89.9141 551.569,89.912 551.578,89.9098 551.587,89.9076 551.597,89.9054 551.606,89.9033 551.615,89.9011 551.624,89.8989 551.633,89.8967 551.643,89.8946 551.652,89.8924 551.661,89.8902 551.67,89.8881 551.679,89.8859 551.688,89.8837 551.698,89.8815 551.707,89.8794 551.716,89.8772 551.725,89.875 551.734,89.8729 551.744,89.8707 551.753,89.8685 551.762,89.8663 551.771,89.8642 551.78,89.862 551.79,89.8598 551.799,89.8577 551.808,89.8555 551.817,89.8533 551.826,89.8512 551.836,89.849 551.845,89.8468 551.854,89.8447 551.863,89.8425 551.872,89.8403 551.881,89.8382 551.891,89.836 551.9,89.8338 551.909,89.8317 551.918,89.8295 551.927,89.8274 551.937,89.8252 551.946,89.823 551.955,89.8209 551.964,89.8187 551.973,89.8165 551.983,89.8144 551.992,89.8122 552.001,89.81 552.01,89.8079 552.019,89.8057 552.028,89.8036 552.038,89.8014 552.047,89.7992 552.056,89.7971 552.065,89.7949 552.074,89.7928 552.084,89.7906 552.093,89.7884 552.102,89.7863 552.111,89.7841 552.12,89.782 552.13,89.7798 552.139,89.7777 552.148,89.7755 552.157,89.7733 552.166,89.7712 552.176,89.769 552.185,89.7669 552.194,89.7647 552.203,89.7626 552.212,89.7604 552.221,89.7583 552.231,89.7561 552.24,89.7539 552.249,89.7518 552.258,89.7496 552.267,89.7475 552.277,89.7453 552.286,89.7432 552.295,89.741 552.304,89.7389 552.313,89.7367 552.323,89.7346 552.332,89.7324 552.341,89.7303 552.35,89.7281 552.359,89.726 552.368,89.7238 552.378,89.7217 552.387,89.7195 552.396,89.7174 552.405,89.7152 552.414,89.7131 552.424,89.7109 552.433,89.7088 552.442,89.7066 552.451,89.7045 552.46,89.7023 552.47,89.7002 552.479,89.698 552.488,89.6959 552.497,89.6938 552.506,89.6916 552.516,89.6895 552.525,89.6873 552.534,89.6852 552.543,89.683 552.552,89.6809 552.561,89.6787 552.571,89.6766 552.58,89.6745 552.589,89.6723 552.598,89.6702 552.607,89.668 552.617,89.6659 552.626,89.6637 552.635,89.6616 552.644,89.6595 552.653,89.6573 552.663,89.6552 552.672,89.653 552.681,89.6509 552.69,89.6488 552.699,89.6466 552.708,89.6445 552.718,89.6423 552.727,89.6402 552.736,89.6381 552.745,89.6359 552.754,89.6338 552.764,89.6316 552.773,89.6295 552.782,89.6274 552.791,89.6252 552.8,89.6231 552.81,89.621 552.819,89.6188 552.828,89.6167 552.837,89.6146 552.846,89.6124 552.856,89.6103 552.865,89.6082 552.874,89.606 552.883,89.6039 552.892,89.6018 552.901,89.5996 552.911,89.5975 552.92,89.5954 552.929,89.5932 552.938,89.5911 552.947,89.589 552.957,89.5868 552.966,89.5847 552.975,89.5826 552.984,89.5804 552.993,89.5783 553.003,89.5762 553.012,89.574 553.021,89.5719 553.03,89.5698 553.039,89.5677 553.048,89.5655 553.058,89.5634 553.067,89.5613 553.076,89.5591 553.085,89.557 553.094,89.5549 553.104,89.5528 553.113,89.5506 553.122,89.5485 553.131,89.5464 553.14,89.5443 553.15,89.5421 553.159,89.54 553.168,89.5379 553.177,89.5358 553.186,89.5336 553.196,89.5315 553.205,89.5294 553.214,89.5273 553.223,89.5251 553.232,89.523 553.241,89.5209 553.251,89.5188 553.26,89.5167 553.269,89.5145 553.278,89.5124 553.287,89.5103 553.297,89.5082 553.306,89.506 553.315,89.5039 553.324,89.5018 553.333,89.4997 553.343,89.4976 553.352,89.4954 553.361,89.4933 553.37,89.4912 553.379,89.4891 553.389,89.487 553.398,89.4849 553.407,89.4827 553.416,89.4806 553.425,89.4785 553.434,89.4764 553.444,89.4743 553.453,89.4722 553.462,89.47 553.471,89.4679 553.48,89.4658 553.49,89.4637 553.499,89.4616 553.508,89.4595 553.517,89.4574 553.526,89.4552 553.536,89.4531 553.545,89.451 553.554,89.4489 553.563,89.4468 553.572,89.4447 553.581,89.4426 553.591,89.4405 553.6,89.4383 553.609,89.4362 553.618,89.4341 553.627,89.432 553.637,89.4299 553.646,89.4278 553.655,89.4257 553.664,89.4236 553.673,89.4215 553.683,89.4194 553.692,89.4172 553.701,89.4151 553.71,89.413 553.719,89.4109 553.729,89.4088 553.738,89.4067 553.747,89.4046 553.756,89.4025 553.765,89.4004 553.774,89.3983 553.784,89.3962 553.793,89.3941 553.802,89.392 553.811,89.3899 553.82,89.3878 553.83,89.3857 553.839,89.3836 553.848,89.3814 553.857,89.3793 553.866,89.3772 553.876,89.3751 553.885,89.373 553.894,89.3709 553.903,89.3688 553.912,89.3667 553.921,89.3646 553.931,89.3625 553.94,89.3604 553.949,89.3583 553.958,89.3562 553.967,89.3541 553.977,89.352 553.986,89.3499 553.995,89.3478 554.004,89.3457 554.013,89.3436 554.023,89.3415 554.032,89.3394 554.041,89.3373 554.05,89.3352 554.059,89.3331 554.069,89.3311 554.078,89.329 554.087,89.3269 554.096,89.3248 554.105,89.3227 554.114,89.3206 554.124,89.3185 554.133,89.3164 554.142,89.3143 554.151,89.3122 554.16,89.3101 554.17,89.308 554.179,89.3059 554.188,89.3038 554.197,89.3017 554.206,89.2996 554.216,89.2975 554.225,89.2955 554.234,89.2934 554.243,89.2913 554.252,89.2892 554.261,89.2871 554.271,89.285 554.28,89.2829 554.289,89.2808 554.298,89.2787 554.307,89.2766 554.317,89.2746 554.326,89.2725 554.335,89.2704 554.344,89.2683 554.353,89.2662 554.363,89.2641 554.372,89.262 554.381,89.2599 554.39,89.2579 554.399,89.2558 554.409,89.2537 554.418,89.2516 554.427,89.2495 554.436,89.2474 554.445,89.2453 554.454,89.2433 554.464,89.2412 554.473,89.2391 554.482,89.237 554.491,89.2349 554.5,89.2328 554.51,89.2308 554.519,89.2287 554.528,89.2266 554.537,89.2245 554.546,89.2224 554.556,89.2203 554.565,89.2183 554.574,89.2162 554.583,89.2141 554.592,89.212 554.601,89.2099 554.611,89.2079 554.62,89.2058 554.629,89.2037 554.638,89.2016 554.647,89.1996 554.657,89.1975 554.666,89.1954 554.675,89.1933 554.684,89.1912 554.693,89.1892 554.703,89.1871 554.712,89.185 554.721,89.1829 554.73,89.1809 554.739,89.1788 554.749,89.1767 554.758,89.1746 554.767,89.1726 554.776,89.1705 554.785,89.1684 554.794,89.1663 554.804,89.1643 554.813,89.1622 554.822,89.1601 554.831,89.158 554.84,89.156 554.85,89.1539 554.859,89.1518 554.868,89.1498 554.877,89.1477 554.886,89.1456 554.896,89.1435 554.905,89.1415 554.914,89.1394 554.923,89.1373 554.932,89.1353 554.941,89.1332 554.951,89.1311 554.96,89.1291 554.969,89.127 554.978,89.1249 554.987,89.1228 554.997,89.1208 555.006,89.1187 555.015,89.1166 555.024,89.1146 555.033,89.1125 555.043,89.1104 555.052,89.1084 555.061,89.1063 555.07,89.1043 555.079,89.1022 555.089,89.1001 555.098,89.0981 555.107,89.096 555.116,89.0939 555.125,89.0919 555.134,89.0898 555.144,89.0877 555.153,89.0857 555.162,89.0836 555.171,89.0816 555.18,89.0795 555.19,89.0774 555.199,89.0754 555.208,89.0733 555.217,89.0712 555.226,89.0692 555.236,89.0671 555.245,89.0651 555.254,89.063 555.263,89.0609 555.272,89.0589 555.281,89.0568 555.291,89.0548 555.3,89.0527 555.309,89.0507 555.318,89.0486 555.327,89.0465 555.337,89.0445 555.346,89.0424 555.355,89.0404 555.364,89.0383 555.373,89.0363 555.383,89.0342 555.392,89.0321 555.401,89.0301 555.41,89.028 555.419,89.026 555.429,89.0239 555.438,89.0219 555.447,89.0198 555.456,89.0178 555.465,89.0157 555.474,89.0137 555.484,89.0116 555.493,89.0096 555.502,89.0075 555.511,89.0055 555.52,89.0034 555.53,89.0013 555.539,88.9993 555.548,88.9972 555.557,88.9952 555.566,88.9931 555.576,88.9911 555.585,88.989 555.594,88.987 555.603,88.9849 555.612,88.9829 555.621,88.9809 555.631,88.9788 555.64,88.9768 555.649,88.9747 555.658,88.9727 555.667,88.9706 555.677,88.9686 555.686,88.9665 555.695,88.9645 555.704,88.9624 555.713,88.9604 555.723,88.9583 555.732,88.9563 555.741,88.9543 555.75,88.9522 555.759,88.9502 555.769,88.9481 555.778,88.9461 555.787,88.944 555.796,88.942 555.805,88.9399 555.814,88.9379 555.824,88.9359 555.833,88.9338 555.842,88.9318 555.851,88.9297 555.86,88.9277 555.87,88.9257 555.879,88.9236 555.888,88.9216 555.897,88.9195 555.906,88.9175 555.916,88.9155 555.925,88.9134 555.934,88.9114 555.943,88.9093 555.952,88.9073 555.962,88.9053 555.971,88.9032 555.98,88.9012 555.989,88.8992 555.998,88.8971 556.007,88.8951 556.017,88.893 556.026,88.891 556.035,88.889 556.044,88.8869 556.053,88.8849 556.063,88.8829 556.072,88.8808 556.081,88.8788 556.09,88.8768 556.099,88.8747 556.109,88.8727 556.118,88.8707 556.127,88.8686 556.136,88.8666 556.145,88.8646 556.154,88.8625 556.164,88.8605 556.173,88.8585 556.182,88.8564 556.191,88.8544 556.2,88.8524 556.21,88.8504 556.219,88.8483 556.228,88.8463 556.237,88.8443 556.246,88.8422 556.256,88.8402 556.265,88.8382 556.274,88.8362 556.283,88.8341 556.292,88.8321 556.302,88.8301 556.311,88.828 556.32,88.826 556.329,88.824 556.338,88.822 556.347,88.8199 556.357,88.8179 556.366,88.8159 556.375,88.8139 556.384,88.8118 556.393,88.8098 556.403,88.8078 556.412,88.8058 556.421,88.8037 556.43,88.8017 556.439,88.7997 556.449,88.7977 556.458,88.7957 556.467,88.7936 556.476,88.7916 556.485,88.7896 556.494,88.7876 556.504,88.7855 556.513,88.7835 556.522,88.7815 556.531,88.7795 556.54,88.7775 556.55,88.7754 556.559,88.7734 556.568,88.7714 556.577,88.7694 556.586,88.7674 556.596,88.7654 556.605,88.7633 556.614,88.7613 556.623,88.7593 556.632,88.7573 556.642,88.7553 556.651,88.7532 556.66,88.7512 556.669,88.7492 556.678,88.7472 556.687,88.7452 556.697,88.7432 556.706,88.7412 556.715,88.7391 556.724,88.7371 556.733,88.7351 556.743,88.7331 556.752,88.7311 556.761,88.7291 556.77,88.7271 556.779,88.725 556.789,88.723 556.798,88.721 556.807,88.719 556.816,88.717 556.825,88.715 556.834,88.713 556.844,88.711 556.853,88.709 556.862,88.7069 556.871,88.7049 556.88,88.7029 556.89,88.7009 556.899,88.6989 556.908,88.6969 556.917,88.6949 556.926,88.6929 556.936,88.6909 556.945,88.6889 556.954,88.6869 556.963,88.6849 556.972,88.6829 556.982,88.6808 556.991,88.6788 557,88.6768 557.009,88.6748 557.018,88.6728 557.027,88.6708 557.037,88.6688 557.046,88.6668 557.055,88.6648 557.064,88.6628 557.073,88.6608 557.083,88.6588 557.092,88.6568 557.101,88.6548 557.11,88.6528 557.119,88.6508 557.129,88.6488 557.138,88.6468 557.147,88.6448 557.156,88.6428 557.165,88.6408 557.174,88.6388 557.184,88.6368 557.193,88.6348 557.202,88.6328 557.211,88.6308 557.22,88.6288 557.23,88.6268 557.239,88.6248 557.248,88.6228 557.257,88.6208 557.266,88.6188 557.276,88.6168 557.285,88.6148 557.294,88.6128 557.303,88.6108 557.312,88.6088 557.322,88.6068 557.331,88.6048 557.34,88.6028 557.349,88.6008 557.358,88.5988 557.367,88.5968 557.377,88.5948 557.386,88.5928 557.395,88.5909 557.404,88.5889 557.413,88.5869 557.423,88.5849 557.432,88.5829 557.441,88.5809 557.45,88.5789 557.459,88.5769 557.469,88.5749 557.478,88.5729 557.487,88.5709 557.496,88.5689 557.505,88.567 557.514,88.565 557.524,88.563 557.533,88.561 557.542,88.559 557.551,88.557 557.56,88.555 557.57,88.553 557.579,88.551 557.588,88.5491 557.597,88.5471 557.606,88.5451 557.616,88.5431 557.625,88.5411 557.634,88.5391 557.643,88.5371 557.652,88.5351 557.662,88.5332 557.671,88.5312 557.68,88.5292 557.689,88.5272 557.698,88.5252 557.707,88.5232 557.717,88.5213 557.726,88.5193 557.735,88.5173 557.744,88.5153 557.753,88.5133 557.763,88.5113 557.772,88.5094 557.781,88.5074 557.79,88.5054 557.799,88.5034 557.809,88.5014 557.818,88.4994 557.827,88.4975 557.836,88.4955 557.845,88.4935 557.854,88.4915 557.864,88.4895 557.873,88.4876 557.882,88.4856 557.891,88.4836 557.9,88.4816 557.91,88.4797 557.919,88.4777 557.928,88.4757 557.937,88.4737 557.946,88.4717 557.956,88.4698 557.965,88.4678 557.974,88.4658 557.983,88.4638 557.992,88.4619 558.002,88.4599 558.011,88.4579 558.02,88.4559 558.029,88.454 558.038,88.452 558.047,88.45 558.057,88.448 558.066,88.4461 558.075,88.4441 558.084,88.4421 558.093,88.4402 558.103,88.4382 558.112,88.4362 558.121,88.4342 558.13,88.4323 558.139,88.4303 558.149,88.4283 558.158,88.4264 558.167,88.4244 558.176,88.4224 558.185,88.4205 558.194,88.4185 558.204,88.4165 558.213,88.4145 558.222,88.4126 558.231,88.4106 558.24,88.4086 558.25,88.4067 558.259,88.4047 558.268,88.4027 558.277,88.4008 558.286,88.3988 558.296,88.3968 558.305,88.3949 558.314,88.3929 558.323,88.3909 558.332,88.389 558.342,88.387 558.351,88.385 558.36,88.3831 558.369,88.3811 558.378,88.3792 558.387,88.3772 558.397,88.3752 558.406,88.3733 558.415,88.3713 558.424,88.3693 558.433,88.3674 558.443,88.3654 558.452,88.3635 558.461,88.3615 558.47,88.3595 558.479,88.3576 558.489,88.3556 558.498,88.3537 558.507,88.3517 558.516,88.3497 558.525,88.3478 558.535,88.3458 558.544,88.3439 558.553,88.3419 558.562,88.3399 558.571,88.338 558.58,88.336 558.59,88.3341 558.599,88.3321 558.608,88.3302 558.617,88.3282 558.626,88.3262 558.636,88.3243 558.645,88.3223 558.654,88.3204 558.663,88.3184 558.672,88.3165 558.682,88.3145 558.691,88.3126 558.7,88.3106 558.709,88.3087 558.718,88.3067 558.727,88.3047 558.737,88.3028 558.746,88.3008 558.755,88.2989 558.764,88.2969 558.773,88.295 558.783,88.293 558.792,88.2911 558.801,88.2891 558.81,88.2872 558.819,88.2852 558.829,88.2833 558.838,88.2813 558.847,88.2794 558.856,88.2774 558.865,88.2755 558.875,88.2735 558.884,88.2716 558.893,88.2696 558.902,88.2677 558.911,88.2657 558.92,88.2638 558.93,88.2618 558.939,88.2599 558.948,88.258 558.957,88.256 558.966,88.2541 558.976,88.2521 558.985,88.2502 558.994,88.2482 559.003,88.2463 559.012,88.2443 559.022,88.2424 559.031,88.2405 559.04,88.2385 559.049,88.2366 559.058,88.2346 559.067,88.2327 559.077,88.2307 559.086,88.2288 559.095,88.2269 559.104,88.2249 559.113,88.223 559.123,88.221 559.132,88.2191 559.141,88.2171 559.15,88.2152 559.159,88.2133 559.169,88.2113 559.178,88.2094 559.187,88.2075 559.196,88.2055 559.205,88.2036 559.215,88.2016 559.224,88.1997 559.233,88.1978 559.242,88.1958 559.251,88.1939 559.26,88.1919 559.27,88.19 559.279,88.1881 559.288,88.1861 559.297,88.1842 559.306,88.1823 559.316,88.1803 559.325,88.1784 559.334,88.1765 559.343,88.1745 559.352,88.1726 559.362,88.1707 559.371,88.1687 559.38,88.1668 559.389,88.1649 559.398,88.1629 559.407,88.161 559.417,88.1591 559.426,88.1571 559.435,88.1552 559.444,88.1533 559.453,88.1513 559.463,88.1494 559.472,88.1475 559.481,88.1455 559.49,88.1436 559.499,88.1417 559.509,88.1398 559.518,88.1378 559.527,88.1359 559.536,88.134 559.545,88.132 559.555,88.1301 559.564,88.1282 559.573,88.1263 559.582,88.1243 559.591,88.1224 559.6,88.1205 559.61,88.1186 559.619,88.1166 559.628,88.1147 559.637,88.1128 559.646,88.1109 559.656,88.1089 559.665,88.107 559.674,88.1051 559.683,88.1032 559.692,88.1012 559.702,88.0993 559.711,88.0974 559.72,88.0955 559.729,88.0935 559.738,88.0916 559.747,88.0897 559.757,88.0878 559.766,88.0858 559.775,88.0839 559.784,88.082 559.793,88.0801 559.803,88.0782 559.812,88.0762 559.821,88.0743 559.83,88.0724 559.839,88.0705 559.849,88.0686 559.858,88.0666 559.867,88.0647 559.876,88.0628 559.885,88.0609 559.895,88.059 559.904,88.0571 559.913,88.0551 559.922,88.0532 559.931,88.0513 559.94,88.0494 559.95,88.0475 559.959,88.0456 559.968,88.0436 559.977,88.0417 559.986,88.0398 559.996,88.0379 560.005,88.036 560.014,88.0341 560.023,88.0322 560.032,88.0302 560.042,88.0283 560.051,88.0264 560.06,88.0245 560.069,88.0226 560.078,88.0207 560.087,88.0188 560.097,88.0169 560.106,88.0149 560.115,88.013 560.124,88.0111 560.133,88.0092 560.143,88.0073 560.152,88.0054 560.161,88.0035 560.17,88.0016 560.179,87.9997 560.189,87.9978 560.198,87.9958 560.207,87.9939 560.216,87.992 560.225,87.9901 560.235,87.9882 560.244,87.9863 560.253,87.9844 560.262,87.9825 560.271,87.9806 560.28,87.9787 560.29,87.9768 560.299,87.9749 560.308,87.973 560.317,87.9711 560.326,87.9692 560.336,87.9673 560.345,87.9653 560.354,87.9634 560.363,87.9615 560.372,87.9596 560.382,87.9577 560.391,87.9558 560.4,87.9539 560.409,87.952 560.418,87.9501 560.427,87.9482 560.437,87.9463 560.446,87.9444 560.455,87.9425 560.464,87.9406 560.473,87.9387 560.483,87.9368 560.492,87.9349 560.501,87.933 560.51,87.9311 560.519,87.9292 560.529,87.9273 560.538,87.9254 560.547,87.9235 560.556,87.9216 560.565,87.9197 560.575,87.9178 560.584,87.9159 560.593,87.914 560.602,87.9121 560.611,87.9102 560.62,87.9084 560.63,87.9065 560.639,87.9046 560.648,87.9027 560.657,87.9008 560.666,87.8989 560.676,87.897 560.685,87.8951 560.694,87.8932 560.703,87.8913 560.712,87.8894 560.722,87.8875 560.731,87.8856 560.74,87.8837 560.749,87.8818 560.758,87.8799 560.768,87.8781 560.777,87.8762 560.786,87.8743 560.795,87.8724 560.804,87.8705 560.813,87.8686 560.823,87.8667 560.832,87.8648 560.841,87.8629 560.85,87.861 560.859,87.8592 560.869,87.8573 560.878,87.8554 560.887,87.8535 560.896,87.8516 560.905,87.8497 560.915,87.8478 560.924,87.8459 560.933,87.8441 560.942,87.8422 560.951,87.8403 560.96,87.8384 560.97,87.8365 560.979,87.8346 560.988,87.8327 560.997,87.8309 561.006,87.829 561.016,87.8271 561.025,87.8252 561.034,87.8233 561.043,87.8214 561.052,87.8196 561.062,87.8177 561.071,87.8158 561.08,87.8139 561.089,87.812 561.098,87.8101 561.108,87.8083 561.117,87.8064 561.126,87.8045 561.135,87.8026 561.144,87.8007 561.153,87.7989 561.163,87.797 561.172,87.7951 561.181,87.7932 561.19,87.7913 561.199,87.7895 561.209,87.7876 561.218,87.7857 561.227,87.7838 561.236,87.782 561.245,87.7801 561.255,87.7782 561.264,87.7763 561.273,87.7745 561.282,87.7726 561.291,87.7707 561.3,87.7688 561.31,87.767 561.319,87.7651 561.328,87.7632 561.337,87.7613 561.346,87.7595 561.356,87.7576 561.365,87.7557 561.374,87.7538 561.383,87.752 561.392,87.7501 561.402,87.7482 561.411,87.7463 561.42,87.7445 561.429,87.7426 561.438,87.7407 561.448,87.7389 561.457,87.737 561.466,87.7351 561.475,87.7332 561.484,87.7314 561.493,87.7295 561.503,87.7276 561.512,87.7258 561.521,87.7239 561.53,87.722 561.539,87.7202 561.549,87.7183 561.558,87.7164 561.567,87.7146 561.576,87.7127 561.585,87.7108 561.595,87.709 561.604,87.7071 561.613,87.7052 561.622,87.7034 561.631,87.7015 561.64,87.6996 561.65,87.6978 561.659,87.6959 561.668,87.694 561.677,87.6922 561.686,87.6903 561.696,87.6884 561.705,87.6866 561.714,87.6847 561.723,87.6829 561.732,87.681 561.742,87.6791 561.751,87.6773 561.76,87.6754 561.769,87.6735 561.778,87.6717 561.788,87.6698 561.797,87.668 561.806,87.6661 561.815,87.6642 561.824,87.6624 561.833,87.6605 561.843,87.6587 561.852,87.6568 561.861,87.6549 561.87,87.6531 561.879,87.6512 561.889,87.6494 561.898,87.6475 561.907,87.6457 561.916,87.6438 561.925,87.6419 561.935,87.6401 561.944,87.6382 561.953,87.6364 561.962,87.6345 561.971,87.6327 561.98,87.6308 561.99,87.629 561.999,87.6271 562.008,87.6252 562.017,87.6234 562.026,87.6215 562.036,87.6197 562.045,87.6178 562.054,87.616 562.063,87.6141 562.072,87.6123 562.082,87.6104 562.091,87.6086 562.1,87.6067 562.109,87.6049 562.118,87.603 562.128,87.6012 562.137,87.5993 562.146,87.5975 562.155,87.5956 562.164,87.5938 562.173,87.5919 562.183,87.5901 562.192,87.5882 562.201,87.5864 562.21,87.5845 562.219,87.5827 562.229,87.5808 562.238,87.579 562.247,87.5771 562.256,87.5753 562.265,87.5734 562.275,87.5716 562.284,87.5697 562.293,87.5679 562.302,87.566 562.311,87.5642 562.32,87.5624 562.33,87.5605 562.339,87.5587 562.348,87.5568 562.357,87.555 562.366,87.5531 562.376,87.5513 562.385,87.5495 562.394,87.5476 562.403,87.5458 562.412,87.5439 562.422,87.5421 562.431,87.5402 562.44,87.5384 562.449,87.5366 562.458,87.5347 562.468,87.5329 562.477,87.531 562.486,87.5292 562.495,87.5274 562.504,87.5255 562.513,87.5237 562.523,87.5218 562.532,87.52 562.541,87.5182 562.55,87.5163 562.559,87.5145 562.569,87.5126 562.578,87.5108 562.587,87.509 562.596,87.5071 562.605,87.5053 562.615,87.5035 562.624,87.5016 562.633,87.4998 562.642,87.498 562.651,87.4961 562.66,87.4943 562.67,87.4925 562.679,87.4906 562.688,87.4888 562.697,87.4869 562.706,87.4851 562.716,87.4833 562.725,87.4815 562.734,87.4796 562.743,87.4778 562.752,87.476 562.762,87.4741 562.771,87.4723 562.78,87.4705 562.789,87.4686 562.798,87.4668 562.808,87.465 562.817,87.4631 562.826,87.4613 562.835,87.4595 562.844,87.4576 562.853,87.4558 562.863,87.454 562.872,87.4522 562.881,87.4503 562.89,87.4485 562.899,87.4467 562.909,87.4448 562.918,87.443 562.927,87.4412 562.936,87.4394 562.945,87.4375 562.955,87.4357 562.964,87.4339 562.973,87.4321 562.982,87.4302 562.991,87.4284 563,87.4266 563.01,87.4248 563.019,87.4229 563.028,87.4211 563.037,87.4193 563.046,87.4175 563.056,87.4156 563.065,87.4138 563.074,87.412 563.083,87.4102 563.092,87.4084 563.102,87.4065 563.111,87.4047 563.12,87.4029 563.129,87.4011 563.138,87.3992 563.148,87.3974 563.157,87.3956 563.166,87.3938 563.175,87.392 563.184,87.3902 563.193,87.3883 563.203,87.3865 563.212,87.3847 563.221,87.3829 563.23,87.3811 563.239,87.3792 563.249,87.3774 563.258,87.3756 563.267,87.3738 563.276,87.372 563.285,87.3702 563.295,87.3683 563.304,87.3665 563.313,87.3647 563.322,87.3629 563.331,87.3611 563.341,87.3593 563.35,87.3574 563.359,87.3556 563.368,87.3538 563.377,87.352 563.386,87.3502 563.396,87.3484 563.405,87.3466 563.414,87.3448 563.423,87.3429 563.432,87.3411 563.442,87.3393 563.451,87.3375 563.46,87.3357 563.469,87.3339 563.478,87.3321 563.488,87.3303 563.497,87.3285 563.506,87.3266 563.515,87.3248 563.524,87.323 563.533,87.3212 563.543,87.3194 563.552,87.3176 563.561,87.3158 563.57,87.314 563.579,87.3122 563.589,87.3104 563.598,87.3086 563.607,87.3068 563.616,87.3049 563.625,87.3031 563.635,87.3013 563.644,87.2995 563.653,87.2977 563.662,87.2959 563.671,87.2941 563.681,87.2923 563.69,87.2905 563.699,87.2887 563.708,87.2869 563.717,87.2851 563.726,87.2833 563.736,87.2815 563.745,87.2797 563.754,87.2779 563.763,87.2761 563.772,87.2743 563.782,87.2725 563.791,87.2707 563.8,87.2689 563.809,87.2671 563.818,87.2653 563.828,87.2635 563.837,87.2617 563.846,87.2599 563.855,87.2581 563.864,87.2563 563.873,87.2545 563.883,87.2527 563.892,87.2509 563.901,87.2491 563.91,87.2473 563.919,87.2455 563.929,87.2437 563.938,87.2419 563.947,87.2401 563.956,87.2383 563.965,87.2365 563.975,87.2347 563.984,87.2329 563.993,87.2311 564.002,87.2293 564.011,87.2275 564.021,87.2257 564.03,87.2239 564.039,87.2221 564.048,87.2203 564.057,87.2186 564.066,87.2168 564.076,87.215 564.085,87.2132 564.094,87.2114 564.103,87.2096 564.112,87.2078 564.122,87.206 564.131,87.2042 564.14,87.2024 564.149,87.2006 564.158,87.1988 564.168,87.1971 564.177,87.1953 564.186,87.1935 564.195,87.1917 564.204,87.1899 564.213,87.1881 564.223,87.1863 564.232,87.1845 564.241,87.1827 564.25,87.181 564.259,87.1792 564.269,87.1774 564.278,87.1756 564.287,87.1738 564.296,87.172 564.305,87.1702 564.315,87.1684 564.324,87.1667 564.333,87.1649 564.342,87.1631 564.351,87.1613 564.361,87.1595 564.37,87.1577 564.379,87.156 564.388,87.1542 564.397,87.1524 564.406,87.1506 564.416,87.1488 564.425,87.147 564.434,87.1453 564.443,87.1435 564.452,87.1417 564.462,87.1399 564.471,87.1381 564.48,87.1363 564.489,87.1346 564.498,87.1328 564.508,87.131 564.517,87.1292 564.526,87.1274 564.535,87.1257 564.544,87.1239 564.553,87.1221 564.563,87.1203 564.572,87.1186 564.581,87.1168 564.59,87.115 564.599,87.1132 564.609,87.1114 564.618,87.1097 564.627,87.1079 564.636,87.1061 564.645,87.1043 564.655,87.1026 564.664,87.1008 564.673,87.099 564.682,87.0972 564.691,87.0955 564.701,87.0937 564.71,87.0919 564.719,87.0901 564.728,87.0884 564.737,87.0866 564.746,87.0848 564.756,87.083 564.765,87.0813 564.774,87.0795 564.783,87.0777 564.792,87.076 564.802,87.0742 564.811,87.0724 564.82,87.0706 564.829,87.0689 564.838,87.0671 564.848,87.0653 564.857,87.0636 564.866,87.0618 564.875,87.06 564.884,87.0583 564.893,87.0565 564.903,87.0547 564.912,87.0529 564.921,87.0512 564.93,87.0494 564.939,87.0476 564.949,87.0459 564.958,87.0441 564.967,87.0423 564.976,87.0406 564.985,87.0388 564.995,87.037 565.004,87.0353 565.013,87.0335 565.022,87.0317 565.031,87.03 565.041,87.0282 565.05,87.0265 565.059,87.0247 565.068,87.0229 565.077,87.0212 565.086,87.0194 565.096,87.0176 565.105,87.0159 565.114,87.0141 565.123,87.0124 565.132,87.0106 565.142,87.0088 565.151,87.0071 565.16,87.0053 565.169,87.0035 565.178,87.0018 565.188,87 565.197,86.9983 565.206,86.9965 565.215,86.9947 565.224,86.993 565.233,86.9912 565.243,86.9895 565.252,86.9877 565.261,86.986 565.27,86.9842 565.279,86.9824 565.289,86.9807 565.298,86.9789 565.307,86.9772 565.316,86.9754 565.325,86.9737 565.335,86.9719 565.344,86.9701 565.353,86.9684 565.362,86.9666 565.371,86.9649 565.381,86.9631 565.39,86.9614 565.399,86.9596 565.408,86.9579 565.417,86.9561 565.426,86.9544 565.436,86.9526 565.445,86.9508 565.454,86.9491 565.463,86.9473 565.472,86.9456 565.482,86.9438 565.491,86.9421 565.5,86.9403 565.509,86.9386 565.518,86.9368 565.528,86.9351 565.537,86.9333 565.546,86.9316 565.555,86.9298 565.564,86.9281 565.573,86.9263 565.583,86.9246 565.592,86.9228 565.601,86.9211 565.61,86.9193 565.619,86.9176 565.629,86.9159 565.638,86.9141 565.647,86.9124 565.656,86.9106 565.665,86.9089 565.675,86.9071 565.684,86.9054 565.693,86.9036 565.702,86.9019 565.711,86.9001 565.721,86.8984 565.73,86.8967 565.739,86.8949 565.748,86.8932 565.757,86.8914 565.766,86.8897 565.776,86.8879 565.785,86.8862 565.794,86.8845 565.803,86.8827 565.812,86.881 565.822,86.8792 565.831,86.8775 565.84,86.8757 565.849,86.874 565.858,86.8723 565.868,86.8705 565.877,86.8688 565.886,86.867 565.895,86.8653 565.904,86.8636 565.914,86.8618 565.923,86.8601 565.932,86.8583 565.941,86.8566 565.95,86.8549 565.959,86.8531 565.969,86.8514 565.978,86.8497 565.987,86.8479 565.996,86.8462 566.005,86.8445 566.015,86.8427 566.024,86.841 566.033,86.8392 566.042,86.8375 566.051,86.8358 566.061,86.834 566.07,86.8323 566.079,86.8306 566.088,86.8288 566.097,86.8271 566.106,86.8254 566.116,86.8236 566.125,86.8219 566.134,86.8202 566.143,86.8184 566.152,86.8167 566.162,86.815 566.171,86.8132 566.18,86.8115 566.189,86.8098 566.198,86.8081 566.208,86.8063 566.217,86.8046 566.226,86.8029 566.235,86.8011 566.244,86.7994 566.254,86.7977 566.263,86.7959 566.272,86.7942 566.281,86.7925 566.29,86.7908 566.299,86.789 566.309,86.7873 566.318,86.7856 566.327,86.7839 566.336,86.7821 566.345,86.7804 566.355,86.7787 566.364,86.777 566.373,86.7752 566.382,86.7735 566.391,86.7718 566.401,86.7701 566.41,86.7683 566.419,86.7666 566.428,86.7649 566.437,86.7632 566.446,86.7614 566.456,86.7597 566.465,86.758 566.474,86.7563 566.483,86.7545 566.492,86.7528 566.502,86.7511 566.511,86.7494 566.52,86.7477 566.529,86.7459 566.538,86.7442 566.548,86.7425 566.557,86.7408 566.566,86.7391 566.575,86.7373 566.584,86.7356 566.594,86.7339 566.603,86.7322 566.612,86.7305 566.621,86.7287 566.63,86.727 566.639,86.7253 566.649,86.7236 566.658,86.7219 566.667,86.7202 566.676,86.7184 566.685,86.7167 566.695,86.715 566.704,86.7133 566.713,86.7116 566.722,86.7099 566.731,86.7081 566.741,86.7064 566.75,86.7047 566.759,86.703 566.768,86.7013 566.777,86.6996 566.786,86.6979 566.796,86.6961 566.805,86.6944 566.814,86.6927 566.823,86.691 566.832,86.6893 566.842,86.6876 566.851,86.6859 566.86,86.6842 566.869,86.6825 566.878,86.6807 566.888,86.679 566.897,86.6773 566.906,86.6756 566.915,86.6739 566.924,86.6722 566.934,86.6705 566.943,86.6688 566.952,86.6671 566.961,86.6654 566.97,86.6637 566.979,86.6619 566.989,86.6602 566.998,86.6585 567.007,86.6568 567.016,86.6551 567.025,86.6534 567.035,86.6517 567.044,86.65 567.053,86.6483 567.062,86.6466 567.071,86.6449 567.081,86.6432 567.09,86.6415 567.099,86.6398 567.108,86.6381 567.117,86.6364 567.126,86.6347 567.136,86.633 567.145,86.6313 567.154,86.6295 567.163,86.6278 567.172,86.6261 567.182,86.6244 567.191,86.6227 567.2,86.621 567.209,86.6193 567.218,86.6176 567.228,86.6159 567.237,86.6142 567.246,86.6125 567.255,86.6108 567.264,86.6091 567.274,86.6074 567.283,86.6057 567.292,86.604 567.301,86.6023 567.31,86.6006 567.319,86.5989 567.329,86.5972 567.338,86.5956 567.347,86.5939 567.356,86.5922 567.365,86.5905 567.375,86.5888 567.384,86.5871 567.393,86.5854 567.402,86.5837 567.411,86.582 567.421,86.5803 567.43,86.5786 567.439,86.5769 567.448,86.5752 567.457,86.5735 567.466,86.5718 567.476,86.5701 567.485,86.5684 567.494,86.5667 567.503,86.565 567.512,86.5634 567.522,86.5617 567.531,86.56 567.54,86.5583 567.549,86.5566 567.558,86.5549 567.568,86.5532 567.577,86.5515 567.586,86.5498 567.595,86.5481 567.604,86.5464 567.614,86.5448 567.623,86.5431 567.632,86.5414 567.641,86.5397 567.65,86.538 567.659,86.5363 567.669,86.5346 567.678,86.5329 567.687,86.5313 567.696,86.5296 567.705,86.5279 567.715,86.5262 567.724,86.5245 567.733,86.5228 567.742,86.5211 567.751,86.5195 567.761,86.5178 567.77,86.5161 567.779,86.5144 567.788,86.5127 567.797,86.511 567.806,86.5093 567.816,86.5077 567.825,86.506 567.834,86.5043 567.843,86.5026 567.852,86.5009 567.862,86.4993 567.871,86.4976 567.88,86.4959 567.889,86.4942 567.898,86.4925 567.908,86.4908 567.917,86.4892 567.926,86.4875 567.935,86.4858 567.944,86.4841 567.954,86.4824 567.963,86.4808 567.972,86.4791 567.981,86.4774 567.99,86.4757 567.999,86.4741 568.009,86.4724 568.018,86.4707 568.027,86.469 568.036,86.4673 568.045,86.4657 568.055,86.464 568.064,86.4623 568.073,86.4606 568.082,86.459 568.091,86.4573 568.101,86.4556 568.11,86.4539 568.119,86.4523 568.128,86.4506 568.137,86.4489 568.147,86.4472 568.156,86.4456 568.165,86.4439 568.174,86.4422 568.183,86.4406 568.192,86.4389 568.202,86.4372 568.211,86.4355 568.22,86.4339 568.229,86.4322 568.238,86.4305 568.248,86.4289 568.257,86.4272 568.266,86.4255 568.275,86.4238 568.284,86.4222 568.294,86.4205 568.303,86.4188 568.312,86.4172 568.321,86.4155 568.33,86.4138 568.339,86.4122 568.349,86.4105 568.358,86.4088 568.367,86.4072 568.376,86.4055 568.385,86.4038 568.395,86.4022 568.404,86.4005 568.413,86.3988 568.422,86.3972 568.431,86.3955 568.441,86.3938 568.45,86.3922 568.459,86.3905 568.468,86.3888 568.477,86.3872 568.487,86.3855 568.496,86.3838 568.505,86.3822 568.514,86.3805 568.523,86.3789 568.532,86.3772 568.542,86.3755 568.551,86.3739 568.56,86.3722 568.569,86.3705 568.578,86.3689 568.588,86.3672 568.597,86.3656 568.606,86.3639 568.615,86.3622 568.624,86.3606 568.634,86.3589 568.643,86.3573 568.652,86.3556 568.661,86.3539 568.67,86.3523 568.679,86.3506 568.689,86.349 568.698,86.3473 568.707,86.3457 568.716,86.344 568.725,86.3423 568.735,86.3407 568.744,86.339 568.753,86.3374 568.762,86.3357 568.771,86.3341 568.781,86.3324 568.79,86.3308 568.799,86.3291 568.808,86.3274 568.817,86.3258 568.827,86.3241 568.836,86.3225 568.845,86.3208 568.854,86.3192 568.863,86.3175 568.872,86.3159 568.882,86.3142 568.891,86.3126 568.9,86.3109 568.909,86.3093 568.918,86.3076 568.928,86.306 568.937,86.3043 568.946,86.3027 568.955,86.301 568.964,86.2994 568.974,86.2977 568.983,86.2961 568.992,86.2944 569.001,86.2928 569.01,86.2911 569.019,86.2895 569.029,86.2878 569.038,86.2862 569.047,86.2845 569.056,86.2829 569.065,86.2812 569.075,86.2796 569.084,86.2779 569.093,86.2763 569.102,86.2746 569.111,86.273 569.121,86.2714 569.13,86.2697 569.139,86.2681 569.148,86.2664 569.157,86.2648 569.167,86.2631 569.176,86.2615 569.185,86.2598 569.194,86.2582 569.203,86.2566 569.212,86.2549 569.222,86.2533 569.231,86.2516 569.24,86.25 569.249,86.2483 569.258,86.2467 569.268,86.2451 569.277,86.2434 569.286,86.2418 569.295,86.2401 569.304,86.2385 569.314,86.2369 569.323,86.2352 569.332,86.2336 569.341,86.2319 569.35,86.2303 569.359,86.2287 569.369,86.227 569.378,86.2254 569.387,86.2238 569.396,86.2221 569.405,86.2205 569.415,86.2188 569.424,86.2172 569.433,86.2156 569.442,86.2139 569.451,86.2123 569.461,86.2107 569.47,86.209 569.479,86.2074 569.488,86.2058 569.497,86.2041 569.507,86.2025 569.516,86.2009 569.525,86.1992 569.534,86.1976 569.543,86.196 569.552,86.1943 569.562,86.1927 569.571,86.1911 569.58,86.1894 569.589,86.1878 569.598,86.1862 569.608,86.1845 569.617,86.1829 569.626,86.1813 569.635,86.1796 569.644,86.178 569.654,86.1764 569.663,86.1747 569.672,86.1731 569.681,86.1715 569.69,86.1699 569.699,86.1682 569.709,86.1666 569.718,86.165 569.727,86.1633 569.736,86.1617 569.745,86.1601 569.755,86.1585 569.764,86.1568 569.773,86.1552 569.782,86.1536 569.791,86.152 569.801,86.1503 569.81,86.1487 569.819,86.1471 569.828,86.1455 569.837,86.1438 569.847,86.1422 569.856,86.1406 569.865,86.139 569.874,86.1373 569.883,86.1357 569.892,86.1341 569.902,86.1325 569.911,86.1308 569.92,86.1292 569.929,86.1276 569.938,86.126 569.948,86.1244 569.957,86.1227 569.966,86.1211 569.975,86.1195 569.984,86.1179 569.994,86.1163 570.003,86.1146 570.012,86.113 570.021,86.1114 570.03,86.1098 570.039,86.1082 570.049,86.1065 570.058,86.1049 570.067,86.1033 570.076,86.1017 570.085,86.1001 570.095,86.0985 570.104,86.0968 570.113,86.0952 570.122,86.0936 570.131,86.092 570.141,86.0904 570.15,86.0888 570.159,86.0871 570.168,86.0855 570.177,86.0839 570.187,86.0823 570.196,86.0807 570.205,86.0791 570.214,86.0775 570.223,86.0758 570.232,86.0742 570.242,86.0726 570.251,86.071 570.26,86.0694 570.269,86.0678 570.278,86.0662 570.288,86.0646 570.297,86.0629 570.306,86.0613 570.315,86.0597 570.324,86.0581 570.334,86.0565 570.343,86.0549 570.352,86.0533 570.361,86.0517 570.37,86.0501 570.379,86.0485 570.389,86.0468 570.398,86.0452 570.407,86.0436 570.416,86.042 570.425,86.0404 570.435,86.0388 570.444,86.0372 570.453,86.0356 570.462,86.034 570.471,86.0324 570.481,86.0308 570.49,86.0292 570.499,86.0276 570.508,86.026 570.517,86.0244 570.527,86.0228 570.536,86.0211 570.545,86.0195 570.554,86.0179 570.563,86.0163 570.572,86.0147 570.582,86.0131 570.591,86.0115 570.6,86.0099 570.609,86.0083 570.618,86.0067 570.628,86.0051 570.637,86.0035 570.646,86.0019 570.655,86.0003 570.664,85.9987 570.674,85.9971 570.683,85.9955 570.692,85.9939 570.701,85.9923 570.71,85.9907 570.72,85.9891 570.729,85.9875 570.738,85.9859 570.747,85.9843 570.756,85.9827 570.765,85.9811 570.775,85.9795 570.784,85.9779 570.793,85.9763 570.802,85.9747 570.811,85.9731 570.821,85.9715 570.83,85.9699 570.839,85.9684 570.848,85.9668 570.857,85.9652 570.867,85.9636 570.876,85.962 570.885,85.9604 570.894,85.9588 570.903,85.9572 570.912,85.9556 570.922,85.954 570.931,85.9524 570.94,85.9508 570.949,85.9492 570.958,85.9476 570.968,85.946 570.977,85.9444 570.986,85.9429 570.995,85.9413 571.004,85.9397 571.014,85.9381 571.023,85.9365 571.032,85.9349 571.041,85.9333 571.05,85.9317 571.06,85.9301 571.069,85.9285 571.078,85.927 571.087,85.9254 571.096,85.9238 571.105,85.9222 571.115,85.9206 571.124,85.919 571.133,85.9174 571.142,85.9158 571.151,85.9143 571.161,85.9127 571.17,85.9111 571.179,85.9095 571.188,85.9079 571.197,85.9063 571.207,85.9047 571.216,85.9032 571.225,85.9016 571.234,85.9 571.243,85.8984 571.252,85.8968 571.262,85.8952 571.271,85.8937 571.28,85.8921 571.289,85.8905 571.298,85.8889 571.308,85.8873 571.317,85.8857 571.326,85.8842 571.335,85.8826 571.344,85.881 571.354,85.8794 571.363,85.8778 571.372,85.8763 571.381,85.8747 571.39,85.8731 571.4,85.8715 571.409,85.8699 571.418,85.8684 571.427,85.8668 571.436,85.8652 571.445,85.8636 571.455,85.862 571.464,85.8605 571.473,85.8589 571.482,85.8573 571.491,85.8557 571.501,85.8542 571.51,85.8526 571.519,85.851 571.528,85.8494 571.537,85.8479 571.547,85.8463 571.556,85.8447 571.565,85.8431 571.574,85.8416 571.583,85.84 571.592,85.8384 571.602,85.8368 571.611,85.8353 571.62,85.8337 571.629,85.8321 571.638,85.8305 571.648,85.829 571.657,85.8274 571.666,85.8258 571.675,85.8243 571.684,85.8227 571.694,85.8211 571.703,85.8195 571.712,85.818 571.721,85.8164 571.73,85.8148 571.74,85.8133 571.749,85.8117 571.758,85.8101 571.767,85.8086 571.776,85.807 571.785,85.8054 571.795,85.8039 571.804,85.8023 571.813,85.8007 571.822,85.7992 571.831,85.7976 571.841,85.796 571.85,85.7945 571.859,85.7929 571.868,85.7913 571.877,85.7898 571.887,85.7882 571.896,85.7866 571.905,85.7851 571.914,85.7835 571.923,85.7819 571.932,85.7804 571.942,85.7788 571.951,85.7772 571.96,85.7757 571.969,85.7741 571.978,85.7726 571.988,85.771 571.997,85.7694 572.006,85.7679 572.015,85.7663 572.024,85.7647 572.034,85.7632 572.043,85.7616 572.052,85.7601 572.061,85.7585 572.07,85.7569 572.08,85.7554 572.089,85.7538 572.098,85.7523 572.107,85.7507 572.116,85.7491 572.125,85.7476 572.135,85.746 572.144,85.7445 572.153,85.7429 572.162,85.7414 572.171,85.7398 572.181,85.7382 572.19,85.7367 572.199,85.7351 572.208,85.7336 572.217,85.732 572.227,85.7305 572.236,85.7289 572.245,85.7273 572.254,85.7258 572.263,85.7242 572.272,85.7227 572.282,85.7211 572.291,85.7196 572.3,85.718 572.309,85.7165 572.318,85.7149 572.328,85.7134 572.337,85.7118 572.346,85.7103 572.355,85.7087 572.364,85.7072 572.374,85.7056 572.383,85.7041 572.392,85.7025 572.401,85.701 572.41,85.6994 572.42,85.6979 572.429,85.6963 572.438,85.6948 572.447,85.6932 572.456,85.6917 572.465,85.6901 572.475,85.6886 572.484,85.687 572.493,85.6855 572.502,85.6839 572.511,85.6824 572.521,85.6808 572.53,85.6793 572.539,85.6777 572.548,85.6762 572.557,85.6746 572.567,85.6731 572.576,85.6715 572.585,85.67 572.594,85.6685 572.603,85.6669 572.612,85.6654 572.622,85.6638 572.631,85.6623 572.64,85.6607 572.649,85.6592 572.658,85.6576 572.668,85.6561 572.677,85.6546 572.686,85.653 572.695,85.6515 572.704,85.6499 572.714,85.6484 572.723,85.6469 572.732,85.6453 572.741,85.6438 572.75,85.6422 572.76,85.6407 572.769,85.6391 572.778,85.6376 572.787,85.6361 572.796,85.6345 572.805,85.633 572.815,85.6315 572.824,85.6299 572.833,85.6284 572.842,85.6268 572.851,85.6253 572.861,85.6238 572.87,85.6222 572.879,85.6207 572.888,85.6192 572.897,85.6176 572.907,85.6161 572.916,85.6145 572.925,85.613 572.934,85.6115 572.943,85.6099 572.952,85.6084 572.962,85.6069 572.971,85.6053 572.98,85.6038 572.989,85.6023 572.998,85.6007 573.008,85.5992 573.017,85.5977 573.026,85.5961 573.035,85.5946 573.044,85.5931 573.054,85.5915 573.063,85.59 573.072,85.5885 573.081,85.5869 573.09,85.5854 573.1,85.5839 573.109,85.5824 573.118,85.5808 573.127,85.5793 573.136,85.5778 573.145,85.5762 573.155,85.5747 573.164,85.5732 573.173,85.5717 573.182,85.5701 573.191,85.5686 573.201,85.5671 573.21,85.5655 573.219,85.564 573.228,85.5625 573.237,85.561 573.247,85.5594 573.256,85.5579 573.265,85.5564 573.274,85.5549 573.283,85.5533 573.293,85.5518 573.302,85.5503 573.311,85.5488 573.32,85.5472 573.329,85.5457 573.338,85.5442 573.348,85.5427 573.357,85.5411 573.366,85.5396 573.375,85.5381 573.384,85.5366 573.394,85.5351 573.403,85.5335 573.412,85.532 573.421,85.5305 573.43,85.529 573.44,85.5274 573.449,85.5259 573.458,85.5244 573.467,85.5229 573.476,85.5214 573.485,85.5198 573.495,85.5183 573.504,85.5168 573.513,85.5153 573.522,85.5138 573.531,85.5123 573.541,85.5107 573.55,85.5092 573.559,85.5077 573.568,85.5062 573.577,85.5047 573.587,85.5032 573.596,85.5016 573.605,85.5001 573.614,85.4986 573.623,85.4971 573.633,85.4956 573.642,85.4941 573.651,85.4925 573.66,85.491 573.669,85.4895 573.678,85.488 573.688,85.4865 573.697,85.485 573.706,85.4835 573.715,85.482 573.724,85.4804 573.734,85.4789 573.743,85.4774 573.752,85.4759 573.761,85.4744 573.77,85.4729 573.78,85.4714 573.789,85.4699 573.798,85.4683 573.807,85.4668 573.816,85.4653 573.825,85.4638 573.835,85.4623 573.844,85.4608 573.853,85.4593 573.862,85.4578 573.871,85.4563 573.881,85.4548 573.89,85.4533 573.899,85.4518 573.908,85.4502 573.917,85.4487 573.927,85.4472 573.936,85.4457 573.945,85.4442 573.954,85.4427 573.963,85.4412 573.973,85.4397 573.982,85.4382 573.991,85.4367 574,85.4352 574.009,85.4337 574.018,85.4322 574.028,85.4307 574.037,85.4292 574.046,85.4277 574.055,85.4262 574.064,85.4247 574.074,85.4232 574.083,85.4217 574.092,85.4202 574.101,85.4187 574.11,85.4172 574.12,85.4157 574.129,85.4142 574.138,85.4127 574.147,85.4112 574.156,85.4097 574.165,85.4082 574.175,85.4067 574.184,85.4052 574.193,85.4037 574.202,85.4022 574.211,85.4007 574.221,85.3992 574.23,85.3977 574.239,85.3962 574.248,85.3947 574.257,85.3932 574.267,85.3917 574.276,85.3902 574.285,85.3887 574.294,85.3872 574.303,85.3857 574.313,85.3842 574.322,85.3827 574.331,85.3812 574.34,85.3797 574.349,85.3782 574.358,85.3767 574.368,85.3752 574.377,85.3737 574.386,85.3722 574.395,85.3707 574.404,85.3693 574.414,85.3678 574.423,85.3663 574.432,85.3648 574.441,85.3633 574.45,85.3618 574.46,85.3603 574.469,85.3588 574.478,85.3573 574.487,85.3558 574.496,85.3543 574.505,85.3529 574.515,85.3514 574.524,85.3499 574.533,85.3484 574.542,85.3469 574.551,85.3454 574.561,85.3439 574.57,85.3424 574.579,85.3409 574.588,85.3395 574.597,85.338 574.607,85.3365 574.616,85.335 574.625,85.3335 574.634,85.332 574.643,85.3305 574.653,85.329 574.662,85.3276 574.671,85.3261 574.68,85.3246 574.689,85.3231 574.698,85.3216 574.708,85.3201 574.717,85.3187 574.726,85.3172 574.735,85.3157 574.744,85.3142 574.754,85.3127 574.763,85.3112 574.772,85.3098 574.781,85.3083 574.79,85.3068 574.8,85.3053 574.809,85.3038 574.818,85.3024 574.827,85.3009 574.836,85.2994 574.845,85.2979 574.855,85.2964 574.864,85.2949 574.873,85.2935 574.882,85.292 574.891,85.2905 574.901,85.289 574.91,85.2876 574.919,85.2861 574.928,85.2846 574.937,85.2831 574.947,85.2816 574.956,85.2802 574.965,85.2787 574.974,85.2772 574.983,85.2757 574.993,85.2743 575.002,85.2728 575.011,85.2713 575.02,85.2698 575.029,85.2684 575.038,85.2669 575.048,85.2654 575.057,85.2639 575.066,85.2625 575.075,85.261 575.084,85.2595 575.094,85.258 575.103,85.2566 575.112,85.2551 575.121,85.2536 575.13,85.2522 575.14,85.2507 575.149,85.2492 575.158,85.2477 575.167,85.2463 575.176,85.2448 575.185,85.2433 575.195,85.2419 575.204,85.2404 575.213,85.2389 575.222,85.2375 575.231,85.236 575.241,85.2345 575.25,85.233 575.259,85.2316 575.268,85.2301 575.277,85.2286 575.287,85.2272 575.296,85.2257 575.305,85.2242 575.314,85.2228 575.323,85.2213 575.333,85.2198 575.342,85.2184 575.351,85.2169 575.36,85.2154 575.369,85.214 575.378,85.2125 575.388,85.211 575.397,85.2096 575.406,85.2081 575.415,85.2067 575.424,85.2052 575.434,85.2037 575.443,85.2023 575.452,85.2008 575.461,85.1993 575.47,85.1979 575.48,85.1964 575.489,85.195 575.498,85.1935 575.507,85.192 575.516,85.1906 575.526,85.1891 575.535,85.1877 575.544,85.1862 575.553,85.1847 575.562,85.1833 575.571,85.1818 575.581,85.1804 575.59,85.1789 575.599,85.1774 575.608,85.176 575.617,85.1745 575.627,85.1731 575.636,85.1716 575.645,85.1701 575.654,85.1687 575.663,85.1672 575.673,85.1658 575.682,85.1643 575.691,85.1629 575.7,85.1614 575.709,85.16 575.718,85.1585 575.728,85.157 575.737,85.1556 575.746,85.1541 575.755,85.1527 575.764,85.1512 575.774,85.1498 575.783,85.1483 575.792,85.1469 575.801,85.1454 575.81,85.144 575.82,85.1425 575.829,85.1411 575.838,85.1396 575.847,85.1382 575.856,85.1367 575.866,85.1353 575.875,85.1338 575.884,85.1324 575.893,85.1309 575.902,85.1295 575.911,85.128 575.921,85.1266 575.93,85.1251 575.939,85.1237 575.948,85.1222 575.957,85.1208 575.967,85.1193 575.976,85.1179 575.985,85.1164 575.994,85.115 576.003,85.1135 576.013,85.1121 576.022,85.1106 576.031,85.1092 576.04,85.1077 576.049,85.1063 576.058,85.1049 576.068,85.1034 576.077,85.102 576.086,85.1005 576.095,85.0991 576.104,85.0976 576.114,85.0962 576.123,85.0947 576.132,85.0933 576.141,85.0919 576.15,85.0904 576.16,85.089 576.169,85.0875 576.178,85.0861 576.187,85.0846 576.196,85.0832 576.206,85.0818 576.215,85.0803 576.224,85.0789 576.233,85.0774 576.242,85.076 576.251,85.0746 576.261,85.0731 576.27,85.0717 576.279,85.0702 576.288,85.0688 576.297,85.0674 576.307,85.0659 576.316,85.0645 576.325,85.0631 576.334,85.0616 576.343,85.0602 576.353,85.0587 576.362,85.0573 576.371,85.0559 576.38,85.0544 576.389,85.053 576.398,85.0516 576.408,85.0501 576.417,85.0487 576.426,85.0473 576.435,85.0458 576.444,85.0444 576.454,85.043 576.463,85.0415 576.472,85.0401 576.481,85.0387 576.49,85.0372 576.5,85.0358 576.509,85.0344 576.518,85.0329 576.527,85.0315 576.536,85.0301 576.546,85.0286 576.555,85.0272 576.564,85.0258 576.573,85.0243 576.582,85.0229 576.591,85.0215 576.601,85.02 576.61,85.0186 576.619,85.0172 576.628,85.0158 576.637,85.0143 576.647,85.0129 576.656,85.0115 576.665,85.01 576.674,85.0086 576.683,85.0072 576.693,85.0058 576.702,85.0043 576.711,85.0029 576.72,85.0015 576.729,85.0001 576.738,84.9986 576.748,84.9972 576.757,84.9958 576.766,84.9944 576.775,84.9929 576.784,84.9915 576.794,84.9901 576.803,84.9887 576.812,84.9872 576.821,84.9858 576.83,84.9844 576.84,84.983 576.849,84.9815 576.858,84.9801 576.867,84.9787 576.876,84.9773 576.886,84.9759 576.895,84.9744 576.904,84.973 576.913,84.9716 576.922,84.9702 576.931,84.9688 576.941,84.9673 576.95,84.9659 576.959,84.9645 576.968,84.9631 576.977,84.9617 576.987,84.9602 576.996,84.9588 577.005,84.9574 577.014,84.956 577.023,84.9546 577.033,84.9532 577.042,84.9517 577.051,84.9503 577.06,84.9489 577.069,84.9475 577.078,84.9461 577.088,84.9447 577.097,84.9432 577.106,84.9418 577.115,84.9404 577.124,84.939 577.134,84.9376 577.143,84.9362 577.152,84.9348 577.161,84.9333 577.17,84.9319 577.18,84.9305 577.189,84.9291 577.198,84.9277 577.207,84.9263 577.216,84.9249 577.226,84.9235 577.235,84.922 577.244,84.9206 577.253,84.9192 577.262,84.9178 577.271,84.9164 577.281,84.915 577.29,84.9136 577.299,84.9122 577.308,84.9108 577.317,84.9094 577.327,84.9079 577.336,84.9065 577.345,84.9051 577.354,84.9037 577.363,84.9023 577.373,84.9009 577.382,84.8995 577.391,84.8981 577.4,84.8967 577.409,84.8953 577.418,84.8939 577.428,84.8925 577.437,84.8911 577.446,84.8897 577.455,84.8883 577.464,84.8868 577.474,84.8854 577.483,84.884 577.492,84.8826 577.501,84.8812 577.51,84.8798 577.52,84.8784 577.529,84.877 577.538,84.8756 577.547,84.8742 577.556,84.8728 577.566,84.8714 577.575,84.87 577.584,84.8686 577.593,84.8672 577.602,84.8658 577.611,84.8644 577.621,84.863 577.63,84.8616 577.639,84.8602 577.648,84.8588 577.657,84.8574 577.667,84.856 577.676,84.8546 577.685,84.8532 577.694,84.8518 577.703,84.8504 577.713,84.849 577.722,84.8476 577.731,84.8462 577.74,84.8448 577.749,84.8434 577.758,84.842 577.768,84.8406 577.777,84.8392 577.786,84.8378 577.795,84.8365 577.804,84.8351 577.814,84.8337 577.823,84.8323 577.832,84.8309 577.841,84.8295 577.85,84.8281 577.86,84.8267 577.869,84.8253 577.878,84.8239 577.887,84.8225 577.896,84.8211 577.906,84.8197 577.915,84.8183 577.924,84.8169 577.933,84.8156 577.942,84.8142 577.951,84.8128 577.961,84.8114 577.97,84.81 577.979,84.8086 577.988,84.8072 577.997,84.8058 578.007,84.8044 578.016,84.803 578.025,84.8017 578.034,84.8003 578.043,84.7989 578.053,84.7975 578.062,84.7961 578.071,84.7947 578.08,84.7933 578.089,84.7919 578.099,84.7906 578.108,84.7892 578.117,84.7878 578.126,84.7864 578.135,84.785 578.144,84.7836 578.154,84.7822 578.163,84.7809 578.172,84.7795 578.181,84.7781 578.19,84.7767 578.2,84.7753 578.209,84.7739 578.218,84.7726 578.227,84.7712 578.236,84.7698 578.246,84.7684 578.255,84.767 578.264,84.7656 578.273,84.7643 578.282,84.7629 578.291,84.7615 578.301,84.7601 578.31,84.7587 578.319,84.7574 578.328,84.756 578.337,84.7546 578.347,84.7532 578.356,84.7518 578.365,84.7505 578.374,84.7491 578.383,84.7477 578.393,84.7463 578.402,84.745 578.411,84.7436 578.42,84.7422 578.429,84.7408 578.439,84.7394 578.448,84.7381 578.457,84.7367 578.466,84.7353 578.475,84.7339 578.484,84.7326 578.494,84.7312 578.503,84.7298 578.512,84.7284 578.521,84.7271 578.53,84.7257 578.54,84.7243 578.549,84.7229 578.558,84.7216 578.567,84.7202 578.576,84.7188 578.586,84.7175 578.595,84.7161 578.604,84.7147 578.613,84.7133 578.622,84.712 578.631,84.7106 578.641,84.7092 578.65,84.7079 578.659,84.7065 578.668,84.7051 578.677,84.7037 578.687,84.7024 578.696,84.701 578.705,84.6996 578.714,84.6983 578.723,84.6969 578.733,84.6955 578.742,84.6942 578.751,84.6928 578.76,84.6914 578.769,84.6901 578.779,84.6887 578.788,84.6873 578.797,84.686 578.806,84.6846 578.815,84.6832 578.824,84.6819 578.834,84.6805 578.843,84.6791 578.852,84.6778 578.861,84.6764 578.87,84.675 578.88,84.6737 578.889,84.6723 578.898,84.671 578.907,84.6696 578.916,84.6682 578.926,84.6669 578.935,84.6655 578.944,84.6641 578.953,84.6628 578.962,84.6614 578.971,84.6601 578.981,84.6587 578.99,84.6573 578.999,84.656 579.008,84.6546 579.017,84.6533 579.027,84.6519 579.036,84.6505 579.045,84.6492 579.054,84.6478 579.063,84.6465 579.073,84.6451 579.082,84.6437 579.091,84.6424 579.1,84.641 579.109,84.6397 579.119,84.6383 579.128,84.637 579.137,84.6356 579.146,84.6342 579.155,84.6329 579.164,84.6315 579.174,84.6302 579.183,84.6288 579.192,84.6275 579.201,84.6261 579.21,84.6248 579.22,84.6234 579.229,84.622 579.238,84.6207 579.247,84.6193 579.256,84.618 579.266,84.6166 579.275,84.6153 579.284,84.6139 579.293,84.6126 579.302,84.6112 579.311,84.6099 579.321,84.6085 579.33,84.6072 579.339,84.6058 579.348,84.6045 579.357,84.6031 579.367,84.6018 579.376,84.6004 579.385,84.5991 579.394,84.5977 579.403,84.5964 579.413,84.595 579.422,84.5937 579.431,84.5923 579.44,84.591 579.449,84.5896 579.459,84.5883 579.468,84.5869 579.477,84.5856 579.486,84.5842 579.495,84.5829 579.504,84.5816 579.514,84.5802 579.523,84.5789 579.532,84.5775 579.541,84.5762 579.55,84.5748 579.56,84.5735 579.569,84.5721 579.578,84.5708 579.587,84.5695 579.596,84.5681 579.606,84.5668 579.615,84.5654 579.624,84.5641 579.633,84.5627 579.642,84.5614 579.651,84.5601 579.661,84.5587 579.67,84.5574 579.679,84.556 579.688,84.5547 579.697,84.5534 579.707,84.552 579.716,84.5507 579.725,84.5493 579.734,84.548 579.743,84.5467 579.753,84.5453 579.762,84.544 579.771,84.5426 579.78,84.5413 579.789,84.54 579.799,84.5386 579.808,84.5373 579.817,84.536 579.826,84.5346 579.835,84.5333 579.844,84.5319 579.854,84.5306 579.863,84.5293 579.872,84.5279 579.881,84.5266 579.89,84.5253 579.9,84.5239 579.909,84.5226 579.918,84.5213 579.927,84.5199 579.936,84.5186 579.946,84.5173 579.955,84.5159 579.964,84.5146 579.973,84.5133 579.982,84.5119 579.991,84.5106 580.001,84.5093 580.01,84.5079 580.019,84.5066 580.028,84.5053 580.037,84.504 580.047,84.5026 580.056,84.5013 580.065,84.5 580.074,84.4986 580.083,84.4973 580.093,84.496 580.102,84.4946 580.111,84.4933 580.12,84.492 580.129,84.4907 580.139,84.4893 580.148,84.488 580.157,84.4867 580.166,84.4854 580.175,84.484 580.184,84.4827 580.194,84.4814 580.203,84.48 580.212,84.4787 580.221,84.4774 580.23,84.4761 580.24,84.4747 580.249,84.4734 580.258,84.4721 580.267,84.4708 580.276,84.4695 580.286,84.4681 580.295,84.4668 580.304,84.4655 580.313,84.4642 580.322,84.4628 580.331,84.4615 580.341,84.4602 580.35,84.4589 580.359,84.4576 580.368,84.4562 580.377,84.4549 580.387,84.4536 580.396,84.4523 580.405,84.451 580.414,84.4496 580.423,84.4483 580.433,84.447 580.442,84.4457 580.451,84.4444 580.46,84.443 580.469,84.4417 580.479,84.4404 580.488,84.4391 580.497,84.4378 580.506,84.4365 580.515,84.4351 580.524,84.4338 580.534,84.4325 580.543,84.4312 580.552,84.4299 580.561,84.4286 580.57,84.4272 580.58,84.4259 580.589,84.4246 580.598,84.4233 580.607,84.422 580.616,84.4207 580.626,84.4194 580.635,84.418 580.644,84.4167 580.653,84.4154 580.662,84.4141 580.672,84.4128 580.681,84.4115 580.69,84.4102 580.699,84.4089 580.708,84.4075 580.717,84.4062 580.727,84.4049 580.736,84.4036 580.745,84.4023 580.754,84.401 580.763,84.3997 580.773,84.3984 580.782,84.3971 580.791,84.3958 580.8,84.3945 580.809,84.3931 580.819,84.3918 580.828,84.3905 580.837,84.3892 580.846,84.3879 580.855,84.3866 580.864,84.3853 580.874,84.384 580.883,84.3827 580.892,84.3814 580.901,84.3801 580.91,84.3788 580.92,84.3775 580.929,84.3762 580.938,84.3749 580.947,84.3736 580.956,84.3723 580.966,84.371 580.975,84.3696 580.984,84.3683 580.993,84.367 581.002,84.3657 581.012,84.3644 581.021,84.3631 581.03,84.3618 581.039,84.3605 581.048,84.3592 581.057,84.3579 581.067,84.3566 581.076,84.3553 581.085,84.354 581.094,84.3527 581.103,84.3514 581.113,84.3501 581.122,84.3488 581.131,84.3475 581.14,84.3462 581.149,84.3449 581.159,84.3436 581.168,84.3423 581.177,84.341 581.186,84.3397 581.195,84.3385 581.204,84.3372 581.214,84.3359 581.223,84.3346 581.232,84.3333 581.241,84.332 581.25,84.3307 581.26,84.3294 581.269,84.3281 581.278,84.3268 581.287,84.3255 581.296,84.3242 581.306,84.3229 581.315,84.3216 581.324,84.3203 581.333,84.319 581.342,84.3177 581.352,84.3164 581.361,84.3152 581.37,84.3139 581.379,84.3126 581.388,84.3113 581.397,84.31 581.407,84.3087 581.416,84.3074 581.425,84.3061 581.434,84.3048 581.443,84.3035 581.453,84.3022 581.462,84.301 581.471,84.2997 581.48,84.2984 581.489,84.2971 581.499,84.2958 581.508,84.2945 581.517,84.2932 581.526,84.2919 581.535,84.2907 581.544,84.2894 581.554,84.2881 581.563,84.2868 581.572,84.2855 581.581,84.2842 581.59,84.2829 581.6,84.2817 581.609,84.2804 581.618,84.2791 581.627,84.2778 581.636,84.2765 581.646,84.2752 581.655,84.274 581.664,84.2727 581.673,84.2714 581.682,84.2701 581.692,84.2688 581.701,84.2675 581.71,84.2663 581.719,84.265 581.728,84.2637 581.737,84.2624 581.747,84.2611 581.756,84.2599 581.765,84.2586 581.774,84.2573 581.783,84.256 581.793,84.2547 581.802,84.2535 581.811,84.2522 581.82,84.2509 581.829,84.2496 581.839,84.2483 581.848,84.2471 581.857,84.2458 581.866,84.2445 581.875,84.2432 581.884,84.242 581.894,84.2407 581.903,84.2394 581.912,84.2381 581.921,84.2368 581.93,84.2356 581.94,84.2343 581.949,84.233 581.958,84.2317 581.967,84.2305 581.976,84.2292 581.986,84.2279 581.995,84.2267 582.004,84.2254 582.013,84.2241 582.022,84.2228 582.032,84.2216 582.041,84.2203 582.05,84.219 582.059,84.2177 582.068,84.2165 582.077,84.2152 582.087,84.2139 582.096,84.2127 582.105,84.2114 582.114,84.2101 582.123,84.2089 582.133,84.2076 582.142,84.2063 582.151,84.205 582.16,84.2038 582.169,84.2025 582.179,84.2012 582.188,84.2 582.197,84.1987 582.206,84.1974 582.215,84.1962 582.224,84.1949 582.234,84.1936 582.243,84.1924 582.252,84.1911 582.261,84.1898 582.27,84.1886 582.28,84.1873 582.289,84.186 582.298,84.1848 582.307,84.1835 582.316,84.1822 582.326,84.181 582.335,84.1797 582.344,84.1785 582.353,84.1772 582.362,84.1759 582.372,84.1747 582.381,84.1734 582.39,84.1721 582.399,84.1709 582.408,84.1696 582.417,84.1684 582.427,84.1671 582.436,84.1658 582.445,84.1646 582.454,84.1633 582.463,84.1621 582.473,84.1608 582.482,84.1595 582.491,84.1583 582.5,84.157 582.509,84.1558 582.519,84.1545 582.528,84.1532 582.537,84.152 582.546,84.1507 582.555,84.1495 582.564,84.1482 582.574,84.147 582.583,84.1457 582.592,84.1445 582.601,84.1432 582.61,84.1419 582.62,84.1407 582.629,84.1394 582.638,84.1382 582.647,84.1369 582.656,84.1357 582.666,84.1344 582.675,84.1332 582.684,84.1319 582.693,84.1307 582.702,84.1294 582.712,84.1281 582.721,84.1269 582.73,84.1256 582.739,84.1244 582.748,84.1231 582.757,84.1219 582.767,84.1206 582.776,84.1194 582.785,84.1181 582.794,84.1169 582.803,84.1156 582.813,84.1144 582.822,84.1131 582.831,84.1119 582.84,84.1106 582.849,84.1094 582.859,84.1081 582.868,84.1069 582.877,84.1056 582.886,84.1044 582.895,84.1032 582.905,84.1019 582.914,84.1007 582.923,84.0994 582.932,84.0982 582.941,84.0969 582.95,84.0957 582.96,84.0944 582.969,84.0932 582.978,84.0919 582.987,84.0907 582.996,84.0894 583.006,84.0882 583.015,84.087 583.024,84.0857 583.033,84.0845 583.042,84.0832 583.052,84.082 583.061,84.0807 583.07,84.0795 583.079,84.0783 583.088,84.077 583.097,84.0758 583.107,84.0745 583.116,84.0733 583.125,84.0721 583.134,84.0708 583.143,84.0696 583.153,84.0683 583.162,84.0671 583.171,84.0659 583.18,84.0646 583.189,84.0634 583.199,84.0621 583.208,84.0609 583.217,84.0597 583.226,84.0584 583.235,84.0572 583.245,84.056 583.254,84.0547 583.263,84.0535 583.272,84.0522 583.281,84.051 583.29,84.0498 583.3,84.0485 583.309,84.0473 583.318,84.0461 583.327,84.0448 583.336,84.0436 583.346,84.0424 583.355,84.0411 583.364,84.0399 583.373,84.0387 583.382,84.0374 583.392,84.0362 583.401,84.035 583.41,84.0337 583.419,84.0325 583.428,84.0313 583.437,84.03 583.447,84.0288 583.456,84.0276 583.465,84.0264 583.474,84.0251 583.483,84.0239 583.493,84.0227 583.502,84.0214 583.511,84.0202 583.52,84.019 583.529,84.0177 583.539,84.0165 583.548,84.0153 583.557,84.0141 583.566,84.0128 583.575,84.0116 583.585,84.0104 583.594,84.0092 583.603,84.0079 583.612,84.0067 583.621,84.0055 583.63,84.0042 583.64,84.003 583.649,84.0018 583.658,84.0006 583.667,83.9993 583.676,83.9981 583.686,83.9969 583.695,83.9957 583.704,83.9945 583.713,83.9932 583.722,83.992 583.732,83.9908 583.741,83.9896 583.75,83.9883 583.759,83.9871 583.768,83.9859 583.777,83.9847 583.787,83.9835 583.796,83.9822 583.805,83.981 583.814,83.9798 583.823,83.9786 583.833,83.9774 583.842,83.9761 583.851,83.9749 583.86,83.9737 583.869,83.9725 583.879,83.9713 583.888,83.97 583.897,83.9688 583.906,83.9676 583.915,83.9664 583.925,83.9652 583.934,83.964 583.943,83.9627 583.952,83.9615 583.961,83.9603 583.97,83.9591 583.98,83.9579 583.989,83.9567 583.998,83.9554 584.007,83.9542 584.016,83.953 584.026,83.9518 584.035,83.9506 584.044,83.9494 584.053,83.9482 584.062,83.947 584.072,83.9457 584.081,83.9445 584.09,83.9433 584.099,83.9421 584.108,83.9409 584.117,83.9397 584.127,83.9385 584.136,83.9373 584.145,83.936 584.154,83.9348 584.163,83.9336 584.173,83.9324 584.182,83.9312 584.191,83.93 584.2,83.9288 584.209,83.9276 584.219,83.9264 584.228,83.9252 584.237,83.924 584.246,83.9227 584.255,83.9215 584.265,83.9203 584.274,83.9191 584.283,83.9179 584.292,83.9167 584.301,83.9155 584.31,83.9143 584.32,83.9131 584.329,83.9119 584.338,83.9107 584.347,83.9095 584.356,83.9083 584.366,83.9071 584.375,83.9059 584.384,83.9047 584.393,83.9035 584.402,83.9023 584.412,83.9011 584.421,83.8999 584.43,83.8987 584.439,83.8975 584.448,83.8963 584.457,83.8951 584.467,83.8939 584.476,83.8927 584.485,83.8914 584.494,83.8902 584.503,83.889 584.513,83.8879 584.522,83.8867 584.531,83.8855 584.54,83.8843 584.549,83.8831 584.559,83.8819 584.568,83.8807 584.577,83.8795 584.586,83.8783 584.595,83.8771 584.605,83.8759 584.614,83.8747 584.623,83.8735 584.632,83.8723 584.641,83.8711 584.65,83.8699 584.66,83.8687 584.669,83.8675 584.678,83.8663 584.687,83.8651 584.696,83.8639 584.706,83.8627 584.715,83.8615 584.724,83.8603 584.733,83.8591 584.742,83.8579 584.752,83.8568 584.761,83.8556 584.77,83.8544 584.779,83.8532 584.788,83.852 584.797,83.8508 584.807,83.8496 584.816,83.8484 584.825,83.8472 584.834,83.846 584.843,83.8448 584.853,83.8437 584.862,83.8425 584.871,83.8413 584.88,83.8401 584.889,83.8389 584.899,83.8377 584.908,83.8365 584.917,83.8353 584.926,83.8341 584.935,83.833 584.945,83.8318 584.954,83.8306 584.963,83.8294 584.972,83.8282 584.981,83.827 584.99,83.8258 585,83.8247 585.009,83.8235 585.018,83.8223 585.027,83.8211 585.036,83.8199 585.046,83.8187 585.055,83.8176 585.064,83.8164 585.073,83.8152 585.082,83.814 585.092,83.8128 585.101,83.8116 585.11,83.8105 585.119,83.8093 585.128,83.8081 585.137,83.8069 585.147,83.8057 585.156,83.8046 585.165,83.8034 585.174,83.8022 585.183,83.801 585.193,83.7998 585.202,83.7987 585.211,83.7975 585.22,83.7963 585.229,83.7951 585.239,83.7939 585.248,83.7928 585.257,83.7916 585.266,83.7904 585.275,83.7892 585.285,83.7881 585.294,83.7869 585.303,83.7857 585.312,83.7845 585.321,83.7833 585.33,83.7822 585.34,83.781 585.349,83.7798 585.358,83.7786 585.367,83.7775 585.376,83.7763 585.386,83.7751 585.395,83.774 585.404,83.7728 585.413,83.7716 585.422,83.7704 585.432,83.7693 585.441,83.7681 585.45,83.7669 585.459,83.7657 585.468,83.7646 585.478,83.7634 585.487,83.7622 585.496,83.7611 585.505,83.7599 585.514,83.7587 585.523,83.7576 585.533,83.7564 585.542,83.7552 585.551,83.754 585.56,83.7529 585.569,83.7517 585.579,83.7505 585.588,83.7494 585.597,83.7482 585.606,83.747 585.615,83.7459 585.625,83.7447 585.634,83.7435 585.643,83.7424 585.652,83.7412 585.661,83.74 585.67,83.7389 585.68,83.7377 585.689,83.7365 585.698,83.7354 585.707,83.7342 585.716,83.7331 585.726,83.7319 585.735,83.7307 585.744,83.7296 585.753,83.7284 585.762,83.7272 585.772,83.7261 585.781,83.7249 585.79,83.7238 585.799,83.7226 585.808,83.7214 585.818,83.7203 585.827,83.7191 585.836,83.7179 585.845,83.7168 585.854,83.7156 585.863,83.7145 585.873,83.7133 585.882,83.7122 585.891,83.711 585.9,83.7098 585.909,83.7087 585.919,83.7075 585.928,83.7064 585.937,83.7052 585.946,83.704 585.955,83.7029 585.965,83.7017 585.974,83.7006 585.983,83.6994 585.992,83.6983 586.001,83.6971 586.01,83.696 586.02,83.6948 586.029,83.6936 586.038,83.6925 586.047,83.6913 586.056,83.6902 586.066,83.689 586.075,83.6879 586.084,83.6867 586.093,83.6856 586.102,83.6844 586.112,83.6833 586.121,83.6821 586.13,83.681 586.139,83.6798 586.148,83.6787 586.158,83.6775 586.167,83.6764 586.176,83.6752 586.185,83.6741 586.194,83.6729 586.203,83.6718 586.213,83.6706 586.222,83.6695 586.231,83.6683 586.24,83.6672 586.249,83.666 586.259,83.6649 586.268,83.6637 586.277,83.6626 586.286,83.6614 586.295,83.6603 586.305,83.6591 586.314,83.658 586.323,83.6568 586.332,83.6557 586.341,83.6546 586.35,83.6534 586.36,83.6523 586.369,83.6511 586.378,83.65 586.387,83.6488 586.396,83.6477 586.406,83.6465 586.415,83.6454 586.424,83.6443 586.433,83.6431 586.442,83.642 586.452,83.6408 586.461,83.6397 586.47,83.6385 586.479,83.6374 586.488,83.6363 586.498,83.6351 586.507,83.634 586.516,83.6328 586.525,83.6317 586.534,83.6306 586.543,83.6294 586.553,83.6283 586.562,83.6271 586.571,83.626 586.58,83.6249 586.589,83.6237 586.599,83.6226 586.608,83.6215 586.617,83.6203 586.626,83.6192 586.635,83.618 586.645,83.6169 586.654,83.6158 586.663,83.6146 586.672,83.6135 586.681,83.6124 586.69,83.6112 586.7,83.6101 586.709,83.609 586.718,83.6078 586.727,83.6067 586.736,83.6056 586.746,83.6044 586.755,83.6033 586.764,83.6022 586.773,83.601 586.782,83.5999 586.792,83.5988 586.801,83.5976 586.81,83.5965 586.819,83.5954 586.828,83.5942 586.838,83.5931 586.847,83.592 586.856,83.5909 586.865,83.5897 586.874,83.5886 586.883,83.5875 586.893,83.5863 586.902,83.5852 586.911,83.5841 586.92,83.583 586.929,83.5818 586.939,83.5807 586.948,83.5796 586.957,83.5784 586.966,83.5773 586.975,83.5762 586.985,83.5751 586.994,83.5739 587.003,83.5728 587.012,83.5717 587.021,83.5706 587.03,83.5694 587.04,83.5683 587.049,83.5672 587.058,83.5661 587.067,83.5649 587.076,83.5638 587.086,83.5627 587.095,83.5616 587.104,83.5605 587.113,83.5593 587.122,83.5582 587.132,83.5571 587.141,83.556 587.15,83.5548 587.159,83.5537 587.168,83.5526 587.178,83.5515 587.187,83.5504 587.196,83.5492 587.205,83.5481 587.214,83.547 587.223,83.5459 587.233,83.5448 587.242,83.5437 587.251,83.5425 587.26,83.5414 587.269,83.5403 587.279,83.5392 587.288,83.5381 587.297,83.5369 587.306,83.5358 587.315,83.5347 587.325,83.5336 587.334,83.5325 587.343,83.5314 587.352,83.5303 587.361,83.5291 587.37,83.528 587.38,83.5269 587.389,83.5258 587.398,83.5247 587.407,83.5236 587.416,83.5225 587.426,83.5213 587.435,83.5202 587.444,83.5191 587.453,83.518 587.462,83.5169 587.472,83.5158 587.481,83.5147 587.49,83.5136 587.499,83.5125 587.508,83.5113 587.518,83.5102 587.527,83.5091 587.536,83.508 587.545,83.5069 587.554,83.5058 587.563,83.5047 587.573,83.5036 587.582,83.5025 587.591,83.5014 587.6,83.5003 587.609,83.4991 587.619,83.498 587.628,83.4969 587.637,83.4958 587.646,83.4947 587.655,83.4936 587.665,83.4925 587.674,83.4914 587.683,83.4903 587.692,83.4892 587.701,83.4881 587.71,83.487 587.72,83.4859 587.729,83.4848 587.738,83.4837 587.747,83.4826 587.756,83.4815 587.766,83.4804 587.775,83.4793 587.784,83.4782 587.793,83.4771 587.802,83.476 587.812,83.4749 587.821,83.4738 587.83,83.4727 587.839,83.4716 587.848,83.4705 587.858,83.4694 587.867,83.4683 587.876,83.4672 587.885,83.4661 587.894,83.465 587.903,83.4639 587.913,83.4628 587.922,83.4617 587.931,83.4606 587.94,83.4595 587.949,83.4584 587.959,83.4573 587.968,83.4562 587.977,83.4551 587.986,83.454 587.995,83.4529 588.005,83.4518 588.014,83.4507 588.023,83.4496 588.032,83.4485 588.041,83.4474 588.051,83.4463 588.06,83.4452 588.069,83.4441 588.078,83.4431 588.087,83.442 588.096,83.4409 588.106,83.4398 588.115,83.4387 588.124,83.4376 588.133,83.4365 588.142,83.4354 588.152,83.4343 588.161,83.4332 588.17,83.4321 588.179,83.431 588.188,83.43 588.198,83.4289 588.207,83.4278 588.216,83.4267 588.225,83.4256 588.234,83.4245 588.243,83.4234 588.253,83.4223 588.262,83.4212 588.271,83.4202 588.28,83.4191 588.289,83.418 588.299,83.4169 588.308,83.4158 588.317,83.4147 588.326,83.4136 588.335,83.4126 588.345,83.4115 588.354,83.4104 588.363,83.4093 588.372,83.4082 588.381,83.4071 588.391,83.4061 588.4,83.405 588.409,83.4039 588.418,83.4028 588.427,83.4017 588.436,83.4006 588.446,83.3996 588.455,83.3985 588.464,83.3974 588.473,83.3963 588.482,83.3952 588.492,83.3942 588.501,83.3931 588.51,83.392 588.519,83.3909 588.528,83.3898 588.538,83.3888 588.547,83.3877 588.556,83.3866 588.565,83.3855 588.574,83.3844 588.583,83.3834 588.593,83.3823 588.602,83.3812 588.611,83.3801 588.62,83.3791 588.629,83.378 588.639,83.3769 588.648,83.3758 588.657,83.3748 588.666,83.3737 588.675,83.3726 588.685,83.3715 588.694,83.3705 588.703,83.3694 588.712,83.3683 588.721,83.3672 588.731,83.3662 588.74,83.3651 588.749,83.364 588.758,83.3629 588.767,83.3619 588.776,83.3608 588.786,83.3597 588.795,83.3587 588.804,83.3576 588.813,83.3565 588.822,83.3554 588.832,83.3544 588.841,83.3533 588.85,83.3522 588.859,83.3512 588.868,83.3501 588.878,83.349 588.887,83.348 588.896,83.3469 588.905,83.3458 588.914,83.3448 588.923,83.3437 588.933,83.3426 588.942,83.3416 588.951,83.3405 588.96,83.3394 588.969,83.3384 588.979,83.3373 588.988,83.3362 588.997,83.3352 589.006,83.3341 589.015,83.333 589.025,83.332 589.034,83.3309 589.043,83.3298 589.052,83.3288 589.061,83.3277 589.071,83.3267 589.08,83.3256 589.089,83.3245 589.098,83.3235 589.107,83.3224 589.116,83.3213 589.126,83.3203 589.135,83.3192 589.144,83.3182 589.153,83.3171 589.162,83.316 589.172,83.315 589.181,83.3139 589.19,83.3129 589.199,83.3118 589.208,83.3107 589.218,83.3097 589.227,83.3086 589.236,83.3076 589.245,83.3065 589.254,83.3055 589.263,83.3044 589.273,83.3033 589.282,83.3023 589.291,83.3012 589.3,83.3002 589.309,83.2991 589.319,83.2981 589.328,83.297 589.337,83.296 589.346,83.2949 589.355,83.2938 589.365,83.2928 589.374,83.2917 589.383,83.2907 589.392,83.2896 589.401,83.2886 589.411,83.2875 589.42,83.2865 589.429,83.2854 589.438,83.2844 589.447,83.2833 589.456,83.2823 589.466,83.2812 589.475,83.2802 589.484,83.2791 589.493,83.2781 589.502,83.277 589.512,83.276 589.521,83.2749 589.53,83.2739 589.539,83.2728 589.548,83.2718 589.558,83.2707 589.567,83.2697 589.576,83.2686 589.585,83.2676 589.594,83.2665 589.603,83.2655 589.613,83.2644 589.622,83.2634 589.631,83.2624 589.64,83.2613 589.649,83.2603 589.659,83.2592 589.668,83.2582 589.677,83.2571 589.686,83.2561 589.695,83.255 589.705,83.254 589.714,83.253 589.723,83.2519 589.732,83.2509 589.741,83.2498 589.751,83.2488 589.76,83.2477 589.769,83.2467 589.778,83.2457 589.787,83.2446 589.796,83.2436 589.806,83.2425 589.815,83.2415 589.824,83.2405 589.833,83.2394 589.842,83.2384 589.852,83.2373 589.861,83.2363 589.87,83.2353 589.879,83.2342 589.888,83.2332 589.898,83.2322 589.907,83.2311 589.916,83.2301 589.925,83.229 589.934,83.228 589.943,83.227 589.953,83.2259 589.962,83.2249 589.971,83.2239 589.98,83.2228 589.989,83.2218 589.999,83.2208 590.008,83.2197 590.017,83.2187 590.026,83.2177 590.035,83.2166 590.045,83.2156 590.054,83.2146 590.063,83.2135 590.072,83.2125 590.081,83.2115 590.091,83.2104 590.1,83.2094 590.109,83.2084 590.118,83.2073 590.127,83.2063 590.136,83.2053 590.146,83.2043 590.155,83.2032 590.164,83.2022 590.173,83.2012 590.182,83.2001 590.192,83.1991 590.201,83.1981 590.21,83.1971 590.219,83.196 590.228,83.195 590.238,83.194 590.247,83.1929 590.256,83.1919 590.265,83.1909 590.274,83.1899 590.283,83.1888 590.293,83.1878 590.302,83.1868 590.311,83.1858 590.32,83.1847 590.329,83.1837 590.339,83.1827 590.348,83.1817 590.357,83.1807 590.366,83.1796 590.375,83.1786 590.385,83.1776 590.394,83.1766 590.403,83.1755 590.412,83.1745 590.421,83.1735 590.431,83.1725 590.44,83.1715 590.449,83.1704 590.458,83.1694 590.467,83.1684 590.476,83.1674 590.486,83.1664 590.495,83.1653 590.504,83.1643 590.513,83.1633 590.522,83.1623 590.532,83.1613 590.541,83.1602 590.55,83.1592 590.559,83.1582 590.568,83.1572 590.578,83.1562 590.587,83.1552 590.596,83.1541 590.605,83.1531 590.614,83.1521 590.624,83.1511 590.633,83.1501 590.642,83.1491 590.651,83.1481 590.66,83.147 590.669,83.146 590.679,83.145 590.688,83.144 590.697,83.143 590.706,83.142 590.715,83.141 590.725,83.14 590.734,83.1389 590.743,83.1379 590.752,83.1369 590.761,83.1359 590.771,83.1349 590.78,83.1339 590.789,83.1329 590.798,83.1319 590.807,83.1309 590.816,83.1299 590.826,83.1288 590.835,83.1278 590.844,83.1268 590.853,83.1258 590.862,83.1248 590.872,83.1238 590.881,83.1228 590.89,83.1218 590.899,83.1208 590.908,83.1198 590.918,83.1188 590.927,83.1178 590.936,83.1168 590.945,83.1158 590.954,83.1148 590.964,83.1138 590.973,83.1127 590.982,83.1117 590.991,83.1107 591,83.1097 591.009,83.1087 591.019,83.1077 591.028,83.1067 591.037,83.1057 591.046,83.1047 591.055,83.1037 591.065,83.1027 591.074,83.1017 591.083,83.1007 591.092,83.0997 591.101,83.0987 591.111,83.0977 591.12,83.0967 591.129,83.0957 591.138,83.0947 591.147,83.0937 591.156,83.0927 591.166,83.0917 591.175,83.0907 591.184,83.0897 591.193,83.0887 591.202,83.0877 591.212,83.0867 591.221,83.0857 591.23,83.0848 591.239,83.0838 591.248,83.0828 591.258,83.0818 591.267,83.0808 591.276,83.0798 591.285,83.0788 591.294,83.0778 591.304,83.0768 591.313,83.0758 591.322,83.0748 591.331,83.0738 591.34,83.0728 591.349,83.0718 591.359,83.0708 591.368,83.0698 591.377,83.0689 591.386,83.0679 591.395,83.0669 591.405,83.0659 591.414,83.0649 591.423,83.0639 591.432,83.0629 591.441,83.0619 591.451,83.0609 591.46,83.0599 591.469,83.059 591.478,83.058 591.487,83.057 591.496,83.056 591.506,83.055 591.515,83.054 591.524,83.053 591.533,83.052 591.542,83.0511 591.552,83.0501 591.561,83.0491 591.57,83.0481 591.579,83.0471 591.588,83.0461 591.598,83.0451 591.607,83.0442 591.616,83.0432 591.625,83.0422 591.634,83.0412 591.644,83.0402 591.653,83.0392 591.662,83.0383 591.671,83.0373 591.68,83.0363 591.689,83.0353 591.699,83.0343 591.708,83.0334 591.717,83.0324 591.726,83.0314 591.735,83.0304 591.745,83.0294 591.754,83.0285 591.763,83.0275 591.772,83.0265 591.781,83.0255 591.791,83.0245 591.8,83.0236 591.809,83.0226 591.818,83.0216 591.827,83.0206 591.836,83.0197 591.846,83.0187 591.855,83.0177 591.864,83.0167 591.873,83.0157 591.882,83.0148 591.892,83.0138 591.901,83.0128 591.91,83.0118 591.919,83.0109 591.928,83.0099 591.938,83.0089 591.947,83.008 591.956,83.007 591.965,83.006 591.974,83.005 591.984,83.0041 591.993,83.0031 592.002,83.0021 592.011,83.0011 592.02,83.0002 592.029,82.9992 592.039,82.9982 592.048,82.9973 592.057,82.9963 592.066,82.9953 592.075,82.9944 592.085,82.9934 592.094,82.9924 592.103,82.9914 592.112,82.9905 592.121,82.9895 592.131,82.9885 592.14,82.9876 592.149,82.9866 592.158,82.9856 592.167,82.9847 592.176,82.9837 592.186,82.9827 592.195,82.9818 592.204,82.9808 592.213,82.9798 592.222,82.9789 592.232,82.9779 592.241,82.977 592.25,82.976 592.259,82.975 592.268,82.9741 592.278,82.9731 592.287,82.9721 592.296,82.9712 592.305,82.9702 592.314,82.9693 592.324,82.9683 592.333,82.9673 592.342,82.9664 592.351,82.9654 592.36,82.9644 592.369,82.9635 592.379,82.9625 592.388,82.9616 592.397,82.9606 592.406,82.9596 592.415,82.9587 592.425,82.9577 592.434,82.9568 592.443,82.9558 592.452,82.9549 592.461,82.9539 592.471,82.9529 592.48,82.952 592.489,82.951 592.498,82.9501 592.507,82.9491 592.516,82.9482 592.526,82.9472 592.535,82.9463 592.544,82.9453 592.553,82.9443 592.562,82.9434 592.572,82.9424 592.581,82.9415 592.59,82.9405 592.599,82.9396 592.608,82.9386 592.618,82.9377 592.627,82.9367 592.636,82.9358 592.645,82.9348 592.654,82.9339 592.664,82.9329 592.673,82.932 592.682,82.931 592.691,82.9301 592.7,82.9291 592.709,82.9282 592.719,82.9272 592.728,82.9263 592.737,82.9253 592.746,82.9244 592.755,82.9234 592.765,82.9225 592.774,82.9215 592.783,82.9206 592.792,82.9196 592.801,82.9187 592.811,82.9177 592.82,82.9168 592.829,82.9159 592.838,82.9149 592.847,82.914 592.857,82.913 592.866,82.9121 592.875,82.9111 592.884,82.9102 592.893,82.9092 592.902,82.9083 592.912,82.9074 592.921,82.9064 592.93,82.9055 592.939,82.9045 592.948,82.9036 592.958,82.9026 592.967,82.9017 592.976,82.9008 592.985,82.8998 592.994,82.8989 593.004,82.8979 593.013,82.897 593.022,82.8961 593.031,82.8951 593.04,82.8942 593.049,82.8932 593.059,82.8923 593.068,82.8914 593.077,82.8904 593.086,82.8895 593.095,82.8886 593.105,82.8876 593.114,82.8867 593.123,82.8857 593.132,82.8848 593.141,82.8839 593.151,82.8829 593.16,82.882 593.169,82.8811 593.178,82.8801 593.187,82.8792 593.197,82.8783 593.206,82.8773 593.215,82.8764 593.224,82.8755 593.233,82.8745 593.242,82.8736 593.252,82.8727 593.261,82.8717 593.27,82.8708 593.279,82.8699 593.288,82.8689 593.298,82.868 593.307,82.8671 593.316,82.8662 593.325,82.8652 593.334,82.8643 593.344,82.8634 593.353,82.8624 593.362,82.8615 593.371,82.8606 593.38,82.8597 593.389,82.8587 593.399,82.8578 593.408,82.8569 593.417,82.8559 593.426,82.855 593.435,82.8541 593.445,82.8532 593.454,82.8522 593.463,82.8513 593.472,82.8504 593.481,82.8495 593.491,82.8485 593.5,82.8476 593.509,82.8467 593.518,82.8458 593.527,82.8449 593.537,82.8439 593.546,82.843 593.555,82.8421 593.564,82.8412 593.573,82.8402 593.582,82.8393 593.592,82.8384 593.601,82.8375 593.61,82.8366 593.619,82.8356 593.628,82.8347 593.638,82.8338 593.647,82.8329 593.656,82.832 593.665,82.831 593.674,82.8301 593.684,82.8292 593.693,82.8283 593.702,82.8274 593.711,82.8264 593.72,82.8255 593.729,82.8246 593.739,82.8237 593.748,82.8228 593.757,82.8219 593.766,82.821 593.775,82.82 593.785,82.8191 593.794,82.8182 593.803,82.8173 593.812,82.8164 593.821,82.8155 593.831,82.8146 593.84,82.8136 593.849,82.8127 593.858,82.8118 593.867,82.8109 593.877,82.81 593.886,82.8091 593.895,82.8082 593.904,82.8073 593.913,82.8063 593.922,82.8054 593.932,82.8045 593.941,82.8036 593.95,82.8027 593.959,82.8018 593.968,82.8009 593.978,82.8 593.987,82.7991 593.996,82.7982 594.005,82.7973 594.014,82.7963 594.024,82.7954 594.033,82.7945 594.042,82.7936 594.051,82.7927 594.06,82.7918 594.069,82.7909 594.079,82.79 594.088,82.7891 594.097,82.7882 594.106,82.7873 594.115,82.7864 594.125,82.7855 594.134,82.7846 594.143,82.7837 594.152,82.7828 594.161,82.7819 594.171,82.781 594.18,82.7801 594.189,82.7792 594.198,82.7783 594.207,82.7774 594.217,82.7765 594.226,82.7756 594.235,82.7747 594.244,82.7738 594.253,82.7729 594.262,82.772 594.272,82.7711 594.281,82.7702 594.29,82.7693 594.299,82.7684 594.308,82.7675 594.318,82.7666 594.327,82.7657 594.336,82.7648 594.345,82.7639 594.354,82.763 594.364,82.7621 594.373,82.7612 594.382,82.7603 594.391,82.7594 594.4,82.7585 594.409,82.7576 594.419,82.7567 594.428,82.7558 594.437,82.7549 594.446,82.754 594.455,82.7531 594.465,82.7522 594.474,82.7514 594.483,82.7505 594.492,82.7496 594.501,82.7487 594.511,82.7478 594.52,82.7469 594.529,82.746 594.538,82.7451 594.547,82.7442 594.557,82.7433 594.566,82.7424 594.575,82.7416 594.584,82.7407 594.593,82.7398 594.602,82.7389 594.612,82.738 594.621,82.7371 594.63,82.7362 594.639,82.7353 594.648,82.7345 594.658,82.7336 594.667,82.7327 594.676,82.7318 594.685,82.7309 594.694,82.73 594.704,82.7291 594.713,82.7283 594.722,82.7274 594.731,82.7265 594.74,82.7256 594.749,82.7247 594.759,82.7238 594.768,82.723 594.777,82.7221 594.786,82.7212 594.795,82.7203 594.805,82.7194 594.814,82.7185 594.823,82.7177 594.832,82.7168 594.841,82.7159 594.851,82.715 594.86,82.7141 594.869,82.7133 594.878,82.7124 594.887,82.7115 594.897,82.7106 594.906,82.7097 594.915,82.7089 594.924,82.708 594.933,82.7071 594.942,82.7062 594.952,82.7054 594.961,82.7045 594.97,82.7036 594.979,82.7027 594.988,82.7019 594.998,82.701 595.007,82.7001 595.016,82.6992 595.025,82.6984 595.034,82.6975 595.044,82.6966 595.053,82.6957 595.062,82.6949 595.071,82.694 595.08,82.6931 595.089,82.6922 595.099,82.6914 595.108,82.6905 595.117,82.6896 595.126,82.6888 595.135,82.6879 595.145,82.687 595.154,82.6861 595.163,82.6853 595.172,82.6844 595.181,82.6835 595.191,82.6827 595.2,82.6818 595.209,82.6809 595.218,82.6801 595.227,82.6792 595.237,82.6783 595.246,82.6775 595.255,82.6766 595.264,82.6757 595.273,82.6749 595.282,82.674 595.292,82.6731 595.301,82.6723 595.31,82.6714 595.319,82.6705 595.328,82.6697 595.338,82.6688 595.347,82.6679 595.356,82.6671 595.365,82.6662 595.374,82.6653 595.384,82.6645 595.393,82.6636 595.402,82.6628 595.411,82.6619 595.42,82.661 595.43,82.6602 595.439,82.6593 595.448,82.6585 595.457,82.6576 595.466,82.6567 595.475,82.6559 595.485,82.655 595.494,82.6542 595.503,82.6533 595.512,82.6524 595.521,82.6516 595.531,82.6507 595.54,82.6499 595.549,82.649 595.558,82.6481 595.567,82.6473 595.577,82.6464 595.586,82.6456 595.595,82.6447 595.604,82.6439 595.613,82.643 595.622,82.6422 595.632,82.6413 595.641,82.6405 595.65,82.6396 595.659,82.6387 595.668,82.6379 595.678,82.637 595.687,82.6362 595.696,82.6353 595.705,82.6345 595.714,82.6336 595.724,82.6328 595.733,82.6319 595.742,82.6311 595.751,82.6302 595.76,82.6294 595.77,82.6285 595.779,82.6277 595.788,82.6268 595.797,82.626 595.806,82.6251 595.815,82.6243 595.825,82.6234 595.834,82.6226 595.843,82.6217 595.852,82.6209 595.861,82.62 595.871,82.6192 595.88,82.6183 595.889,82.6175 595.898,82.6167 595.907,82.6158 595.917,82.615 595.926,82.6141 595.935,82.6133 595.944,82.6124 595.953,82.6116 595.962,82.6107 595.972,82.6099 595.981,82.6091 595.99,82.6082 595.999,82.6074 596.008,82.6065 596.018,82.6057 596.027,82.6049 596.036,82.604 596.045,82.6032 596.054,82.6023 596.064,82.6015 596.073,82.6006 596.082,82.5998 596.091,82.599 596.1,82.5981 596.11,82.5973 596.119,82.5965 596.128,82.5956 596.137,82.5948 596.146,82.5939 596.155,82.5931 596.165,82.5923 596.174,82.5914 596.183,82.5906 596.192,82.5898 596.201,82.5889 596.211,82.5881 596.22,82.5873 596.229,82.5864 596.238,82.5856 596.247,82.5847 596.257,82.5839 596.266,82.5831 596.275,82.5822 596.284,82.5814 596.293,82.5806 596.302,82.5798 596.312,82.5789 596.321,82.5781 596.33,82.5773 596.339,82.5764 596.348,82.5756 596.358,82.5748 596.367,82.5739 596.376,82.5731 596.385,82.5723 596.394,82.5714 596.404,82.5706 596.413,82.5698 596.422,82.569 596.431,82.5681 596.44,82.5673 596.45,82.5665 596.459,82.5657 596.468,82.5648 596.477,82.564 596.486,82.5632 596.495,82.5623 596.505,82.5615 596.514,82.5607 596.523,82.5599 596.532,82.559 596.541,82.5582 596.551,82.5574 596.56,82.5566 596.569,82.5558 596.578,82.5549 596.587,82.5541 596.597,82.5533 596.606,82.5525 596.615,82.5516 596.624,82.5508 596.633,82.55 596.642,82.5492 596.652,82.5484 596.661,82.5475 596.67,82.5467 596.679,82.5459 596.688,82.5451 596.698,82.5443 596.707,82.5434 596.716,82.5426 596.725,82.5418 596.734,82.541 596.744,82.5402 596.753,82.5394 596.762,82.5385 596.771,82.5377 596.78,82.5369 596.79,82.5361 596.799,82.5353 596.808,82.5345 596.817,82.5336 596.826,82.5328 596.835,82.532 596.845,82.5312 596.854,82.5304 596.863,82.5296 596.872,82.5288 596.881,82.5279 596.891,82.5271 596.9,82.5263 596.909,82.5255 596.918,82.5247 596.927,82.5239 596.937,82.5231 596.946,82.5223 596.955,82.5215 596.964,82.5206 596.973,82.5198 596.982,82.519 596.992,82.5182 597.001,82.5174 597.01,82.5166 597.019,82.5158 597.028,82.515 597.038,82.5142 597.047,82.5134 597.056,82.5126 597.065,82.5118 597.074,82.511 597.084,82.5101 597.093,82.5093 597.102,82.5085 597.111,82.5077 597.12,82.5069 597.13,82.5061 597.139,82.5053 597.148,82.5045 597.157,82.5037 597.166,82.5029 597.175,82.5021 597.185,82.5013 597.194,82.5005 597.203,82.4997 597.212,82.4989 597.221,82.4981 597.231,82.4973 597.24,82.4965 597.249,82.4957 597.258,82.4949 597.267,82.4941 597.277,82.4933 597.286,82.4925 597.295,82.4917 597.304,82.4909 597.313,82.4901 597.322,82.4893 597.332,82.4885 597.341,82.4877 597.35,82.4869 597.359,82.4861 597.368,82.4853 597.378,82.4845 597.387,82.4837 597.396,82.4829 597.405,82.4821 597.414,82.4813 597.424,82.4806 597.433,82.4798 597.442,82.479 597.451,82.4782 597.46,82.4774 597.47,82.4766 597.479,82.4758 597.488,82.475 597.497,82.4742 597.506,82.4734 597.515,82.4726 597.525,82.4718 597.534,82.471 597.543,82.4703 597.552,82.4695 597.561,82.4687 597.571,82.4679 597.58,82.4671 597.589,82.4663 597.598,82.4655 597.607,82.4647 597.617,82.4639 597.626,82.4632 597.635,82.4624 597.644,82.4616 597.653,82.4608 597.662,82.46 597.672,82.4592 597.681,82.4584 597.69,82.4577 597.699,82.4569 597.708,82.4561 597.718,82.4553 597.727,82.4545 597.736,82.4537 597.745,82.4529 597.754,82.4522 597.764,82.4514 597.773,82.4506 597.782,82.4498 597.791,82.449 597.8,82.4483 597.81,82.4475 597.819,82.4467 597.828,82.4459 597.837,82.4451 597.846,82.4444 597.855,82.4436 597.865,82.4428 597.874,82.442 597.883,82.4412 597.892,82.4405 597.901,82.4397 597.911,82.4389 597.92,82.4381 597.929,82.4373 597.938,82.4366 597.947,82.4358 597.957,82.435 597.966,82.4342 597.975,82.4335 597.984,82.4327 597.993,82.4319 598.003,82.4311 598.012,82.4304 598.021,82.4296 598.03,82.4288 598.039,82.428 598.048,82.4273 598.058,82.4265 598.067,82.4257 598.076,82.425 598.085,82.4242 598.094,82.4234 598.104,82.4226 598.113,82.4219 598.122,82.4211 598.131,82.4203 598.14,82.4196 598.15,82.4188 598.159,82.418 598.168,82.4173 598.177,82.4165 598.186,82.4157 598.195,82.415 598.205,82.4142 598.214,82.4134 598.223,82.4127 598.232,82.4119 598.241,82.4111 598.251,82.4104 598.26,82.4096 598.269,82.4088 598.278,82.4081 598.287,82.4073 598.297,82.4065 598.306,82.4058 598.315,82.405 598.324,82.4042 598.333,82.4035 598.343,82.4027 598.352,82.4019 598.361,82.4012 598.37,82.4004 598.379,82.3997 598.388,82.3989 598.398,82.3981 598.407,82.3974 598.416,82.3966 598.425,82.3959 598.434,82.3951 598.444,82.3943 598.453,82.3936 598.462,82.3928 598.471,82.3921 598.48,82.3913 598.49,82.3906 598.499,82.3898 598.508,82.389 598.517,82.3883 598.526,82.3875 598.535,82.3868 598.545,82.386 598.554,82.3853 598.563,82.3845 598.572,82.3837 598.581,82.383 598.591,82.3822 598.6,82.3815 598.609,82.3807 598.618,82.38 598.627,82.3792 598.637,82.3785 598.646,82.3777 598.655,82.377 598.664,82.3762 598.673,82.3755 598.683,82.3747 598.692,82.374 598.701,82.3732 598.71,82.3725 598.719,82.3717 598.728,82.371 598.738,82.3702 598.747,82.3695 598.756,82.3687 598.765,82.368 598.774,82.3672 598.784,82.3665 598.793,82.3657 598.802,82.365 598.811,82.3642 598.82,82.3635 598.83,82.3627 598.839,82.362 598.848,82.3613 598.857,82.3605 598.866,82.3598 598.875,82.359 598.885,82.3583 598.894,82.3575 598.903,82.3568 598.912,82.356 598.921,82.3553 598.931,82.3546 598.94,82.3538 598.949,82.3531 598.958,82.3523 598.967,82.3516 598.977,82.3509 598.986,82.3501 598.995,82.3494 599.004,82.3486 599.013,82.3479 599.023,82.3472 599.032,82.3464 599.041,82.3457 599.05,82.3449 599.059,82.3442 599.068,82.3435 599.078,82.3427 599.087,82.342 599.096,82.3413 599.105,82.3405 599.114,82.3398 599.124,82.339 599.133,82.3383 599.142,82.3376 599.151,82.3368 599.16,82.3361 599.17,82.3354 599.179,82.3346 599.188,82.3339 599.197,82.3332 599.206,82.3324 599.215,82.3317 599.225,82.331 599.234,82.3302 599.243,82.3295 599.252,82.3288 599.261,82.3281 599.271,82.3273 599.28,82.3266 599.289,82.3259 599.298,82.3251 599.307,82.3244 599.317,82.3237 599.326,82.3229 599.335,82.3222 599.344,82.3215 599.353,82.3208 599.363,82.32 599.372,82.3193 599.381,82.3186 599.39,82.3179 599.399,82.3171 599.408,82.3164 599.418,82.3157 599.427,82.315 599.436,82.3142 599.445,82.3135 599.454,82.3128 599.464,82.3121 599.473,82.3113 599.482,82.3106 599.491,82.3099 599.5,82.3092 599.51,82.3084 599.519,82.3077 599.528,82.307 599.537,82.3063 599.546,82.3056 599.555,82.3048 599.565,82.3041 599.574,82.3034 599.583,82.3027 599.592,82.302 599.601,82.3012 599.611,82.3005 599.62,82.2998 599.629,82.2991 599.638,82.2984 599.647,82.2977 599.657,82.2969 599.666,82.2962 599.675,82.2955 599.684,82.2948 599.693,82.2941 599.703,82.2934 599.712,82.2927 599.721,82.2919 599.73,82.2912 599.739,82.2905 599.748,82.2898 599.758,82.2891 599.767,82.2884 599.776,82.2877 599.785,82.2869 599.794,82.2862 599.804,82.2855 599.813,82.2848 599.822,82.2841 599.831,82.2834 599.84,82.2827 599.85,82.282 599.859,82.2813 599.868,82.2805 599.877,82.2798 599.886,82.2791 599.895,82.2784 599.905,82.2777 599.914,82.277 599.923,82.2763 599.932,82.2756 599.941,82.2749 599.951,82.2742 599.96,82.2735 599.969,82.2728 599.978,82.2721 599.987,82.2714 599.997,82.2707 600.006,82.27 600.015,82.2692 600.024,82.2685 600.033,82.2678 600.043,82.2671 600.052,82.2664 600.061,82.2657 600.07,82.265 600.079,82.2643 600.088,82.2636 600.098,82.2629 600.107,82.2622 600.116,82.2615 600.125,82.2608 600.134,82.2601 600.144,82.2594 600.153,82.2587 600.162,82.258 600.171,82.2573 600.18,82.2566 600.19,82.2559 600.199,82.2552 600.208,82.2545 600.217,82.2538 600.226,82.2531 600.236,82.2525 600.245,82.2518 600.254,82.2511 600.263,82.2504 600.272,82.2497 600.281,82.249 600.291,82.2483 600.3,82.2476 600.309,82.2469 600.318,82.2462 600.327,82.2455 600.337,82.2448 600.346,82.2441 600.355,82.2434 600.364,82.2427 600.373,82.242 600.383,82.2414 600.392,82.2407 600.401,82.24 600.41,82.2393 600.419,82.2386 600.428,82.2379 600.438,82.2372 600.447,82.2365 600.456,82.2358 600.465,82.2352 600.474,82.2345 600.484,82.2338 600.493,82.2331 600.502,82.2324 600.511,82.2317 600.52,82.231 600.53,82.2304 600.539,82.2297 600.548,82.229 600.557,82.2283 600.566,82.2276 600.576,82.2269 600.585,82.2262 600.594,82.2256 600.603,82.2249 600.612,82.2242 600.621,82.2235 600.631,82.2228 600.64,82.2222 600.649,82.2215 600.658,82.2208 600.667,82.2201 600.677,82.2194 600.686,82.2187 600.695,82.2181 600.704,82.2174 600.713,82.2167 600.723,82.216 600.732,82.2154 600.741,82.2147 600.75,82.214 600.759,82.2133 600.768,82.2126 600.778,82.212 600.787,82.2113 600.796,82.2106 600.805,82.2099 600.814,82.2093 600.824,82.2086 600.833,82.2079 600.842,82.2072 600.851,82.2066 600.86,82.2059 600.87,82.2052 600.879,82.2045 600.888,82.2039 600.897,82.2032 600.906,82.2025 600.916,82.2019 600.925,82.2012 600.934,82.2005 600.943,82.1998 600.952,82.1992 600.961,82.1985 600.971,82.1978 600.98,82.1972 600.989,82.1965 600.998,82.1958 601.007,82.1952 601.017,82.1945 601.026,82.1938 601.035,82.1932 601.044,82.1925 601.053,82.1918 601.063,82.1912 601.072,82.1905 601.081,82.1898 601.09,82.1892 601.099,82.1885 601.108,82.1878 601.118,82.1872 601.127,82.1865 601.136,82.1858 601.145,82.1852 601.154,82.1845 601.164,82.1839 601.173,82.1832 601.182,82.1825 601.191,82.1819 601.2,82.1812 601.21,82.1805 601.219,82.1799 601.228,82.1792 601.237,82.1786 601.246,82.1779 601.256,82.1772 601.265,82.1766 601.274,82.1759 601.283,82.1753 601.292,82.1746 601.301,82.174 601.311,82.1733 601.32,82.1726 601.329,82.172 601.338,82.1713 601.347,82.1707 601.357,82.17 601.366,82.1694 601.375,82.1687 601.384,82.1681 601.393,82.1674 601.403,82.1667 601.412,82.1661 601.421,82.1654 601.43,82.1648 601.439,82.1641 601.448,82.1635 601.458,82.1628 601.467,82.1622 601.476,82.1615 601.485,82.1609 601.494,82.1602 601.504,82.1596 601.513,82.1589 601.522,82.1583 601.531,82.1576 601.54,82.157 601.55,82.1563 601.559,82.1557 601.568,82.155 601.577,82.1544 601.586,82.1537 601.596,82.1531 601.605,82.1525 601.614,82.1518 601.623,82.1512 601.632,82.1505 601.641,82.1499 601.651,82.1492 601.66,82.1486 601.669,82.1479 601.678,82.1473 601.687,82.1467 601.697,82.146 601.706,82.1454 601.715,82.1447 601.724,82.1441 601.733,82.1434 601.743,82.1428 601.752,82.1422 601.761,82.1415 601.77,82.1409 601.779,82.1402 601.788,82.1396 601.798,82.139 601.807,82.1383 601.816,82.1377 601.825,82.137 601.834,82.1364 601.844,82.1358 601.853,82.1351 601.862,82.1345 601.871,82.1339 601.88,82.1332 601.89,82.1326 601.899,82.1319 601.908,82.1313 601.917,82.1307 601.926,82.13 601.936,82.1294 601.945,82.1288 601.954,82.1281 601.963,82.1275 601.972,82.1269 601.981,82.1262 601.991,82.1256 602,82.125 602.009,82.1244 602.018,82.1237 602.027,82.1231 602.037,82.1225 602.046,82.1218 602.055,82.1212 602.064,82.1206 602.073,82.1199 602.083,82.1193 602.092,82.1187 602.101,82.1181 602.11,82.1174 602.119,82.1168 602.128,82.1162 602.138,82.1155 602.147,82.1149 602.156,82.1143 602.165,82.1137 602.174,82.113 602.184,82.1124 602.193,82.1118 602.202,82.1112 602.211,82.1105 602.22,82.1099 602.23,82.1093 602.239,82.1087 602.248,82.1081 602.257,82.1074 602.266,82.1068 602.276,82.1062 602.285,82.1056 602.294,82.1049 602.303,82.1043 602.312,82.1037 602.321,82.1031 602.331,82.1025 602.34,82.1018 602.349,82.1012 602.358,82.1006 602.367,82.1 602.377,82.0994 602.386,82.0988 602.395,82.0981 602.404,82.0975 602.413,82.0969 602.423,82.0963 602.432,82.0957 602.441,82.0951 602.45,82.0944 602.459,82.0938 602.468,82.0932 602.478,82.0926 602.487,82.092 602.496,82.0914 602.505,82.0908 602.514,82.0902 602.524,82.0895 602.533,82.0889 602.542,82.0883 602.551,82.0877 602.56,82.0871 602.57,82.0865 602.579,82.0859 602.588,82.0853 602.597,82.0847 602.606,82.084 602.616,82.0834 602.625,82.0828 602.634,82.0822 602.643,82.0816 602.652,82.081 602.661,82.0804 602.671,82.0798 602.68,82.0792 602.689,82.0786 602.698,82.078 602.707,82.0774 602.717,82.0768 602.726,82.0762 602.735,82.0756 602.744,82.075 602.753,82.0743 602.763,82.0737 602.772,82.0731 602.781,82.0725 602.79,82.0719 602.799,82.0713 602.809,82.0707 602.818,82.0701 602.827,82.0695 602.836,82.0689 602.845,82.0683 602.854,82.0677 602.864,82.0671 602.873,82.0665 602.882,82.0659 602.891,82.0653 602.9,82.0647 602.91,82.0641 602.919,82.0635 602.928,82.0629 602.937,82.0624 602.946,82.0618 602.956,82.0612 602.965,82.0606 602.974,82.06 602.983,82.0594 602.992,82.0588 603.001,82.0582 603.011,82.0576 603.02,82.057 603.029,82.0564 603.038,82.0558 603.047,82.0552 603.057,82.0546 603.066,82.054 603.075,82.0534 603.084,82.0529 603.093,82.0523 603.103,82.0517 603.112,82.0511 603.121,82.0505 603.13,82.0499 603.139,82.0493 603.149,82.0487 603.158,82.0481 603.167,82.0476 603.176,82.047 603.185,82.0464 603.194,82.0458 603.204,82.0452 603.213,82.0446 603.222,82.044 603.231,82.0434 603.24,82.0429 603.25,82.0423 603.259,82.0417 603.268,82.0411 603.277,82.0405 603.286,82.0399 603.296,82.0394 603.305,82.0388 603.314,82.0382 603.323,82.0376 603.332,82.037 603.341,82.0364 603.351,82.0359 603.36,82.0353 603.369,82.0347 603.378,82.0341 603.387,82.0335 603.397,82.033 603.406,82.0324 603.415,82.0318 603.424,82.0312 603.433,82.0307 603.443,82.0301 603.452,82.0295 603.461,82.0289 603.47,82.0284 603.479,82.0278 603.489,82.0272 603.498,82.0266 603.507,82.026 603.516,82.0255 603.525,82.0249 603.534,82.0243 603.544,82.0238 603.553,82.0232 603.562,82.0226 603.571,82.022 603.58,82.0215 603.59,82.0209 603.599,82.0203 603.608,82.0197 603.617,82.0192 603.626,82.0186 603.636,82.018 603.645,82.0175 603.654,82.0169 603.663,82.0163 603.672,82.0158 603.681,82.0152 603.691,82.0146 603.7,82.0141 603.709,82.0135 603.718,82.0129 603.727,82.0124 603.737,82.0118 603.746,82.0112 603.755,82.0107 603.764,82.0101 603.773,82.0095 603.783,82.009 603.792,82.0084 603.801,82.0078 603.81,82.0073 603.819,82.0067 603.829,82.0062 603.838,82.0056 603.847,82.005 603.856,82.0045 603.865,82.0039 603.874,82.0033 603.884,82.0028 603.893,82.0022 603.902,82.0017 603.911,82.0011 603.92,82.0005 603.93,82 603.939,81.9994 603.948,81.9989 603.957,81.9983 603.966,81.9978 603.976,81.9972 603.985,81.9966 603.994,81.9961 604.003,81.9955 604.012,81.995 604.021,81.9944 604.031,81.9939 604.04,81.9933 604.049,81.9928 604.058,81.9922 604.067,81.9917 604.077,81.9911 604.086,81.9905 604.095,81.99 604.104,81.9894 604.113,81.9889 604.123,81.9883 604.132,81.9878 604.141,81.9872 604.15,81.9867 604.159,81.9861 604.169,81.9856 604.178,81.985 604.187,81.9845 604.196,81.9839 604.205,81.9834 604.214,81.9828 604.224,81.9823 604.233,81.9818 604.242,81.9812 604.251,81.9807 604.26,81.9801 604.27,81.9796 604.279,81.979 604.288,81.9785 604.297,81.9779 604.306,81.9774 604.316,81.9769 604.325,81.9763 604.334,81.9758 604.343,81.9752 604.352,81.9747 604.361,81.9741 604.371,81.9736 604.38,81.9731 604.389,81.9725 604.398,81.972 604.407,81.9714 604.417,81.9709 604.426,81.9704 604.435,81.9698 604.444,81.9693 604.453,81.9687 604.463,81.9682 604.472,81.9677 604.481,81.9671 604.49,81.9666 604.499,81.9661 604.509,81.9655 604.518,81.965 604.527,81.9644 604.536,81.9639 604.545,81.9634 604.554,81.9628 604.564,81.9623 604.573,81.9618 604.582,81.9612 604.591,81.9607 604.6,81.9602 604.61,81.9596 604.619,81.9591 604.628,81.9586 604.637,81.9581 604.646,81.9575 604.656,81.957 604.665,81.9565 604.674,81.9559 604.683,81.9554 604.692,81.9549 604.701,81.9543 604.711,81.9538 604.72,81.9533 604.729,81.9528 604.738,81.9522 604.747,81.9517 604.757,81.9512 604.766,81.9507 604.775,81.9501 604.784,81.9496 604.793,81.9491 604.803,81.9486 604.812,81.948 604.821,81.9475 604.83,81.947 604.839,81.9465 604.849,81.9459 604.858,81.9454 604.867,81.9449 604.876,81.9444 604.885,81.9439 604.894,81.9433 604.904,81.9428 604.913,81.9423 604.922,81.9418 604.931,81.9413 604.94,81.9407 604.95,81.9402 604.959,81.9397 604.968,81.9392 604.977,81.9387 604.986,81.9381 604.996,81.9376 605.005,81.9371 605.014,81.9366 605.023,81.9361 605.032,81.9356 605.041,81.9351 605.051,81.9345 605.06,81.934 605.069,81.9335 605.078,81.933 605.087,81.9325 605.097,81.932 605.106,81.9315 605.115,81.9309 605.124,81.9304 605.133,81.9299 605.143,81.9294 605.152,81.9289 605.161,81.9284 605.17,81.9279 605.179,81.9274 605.189,81.9269 605.198,81.9264 605.207,81.9258 605.216,81.9253 605.225,81.9248 605.234,81.9243 605.244,81.9238 605.253,81.9233 605.262,81.9228 605.271,81.9223 605.28,81.9218 605.29,81.9213 605.299,81.9208 605.308,81.9203 605.317,81.9198 605.326,81.9193 605.336,81.9188 605.345,81.9183 605.354,81.9178 605.363,81.9173 605.372,81.9168 605.382,81.9163 605.391,81.9158 605.4,81.9153 605.409,81.9148 605.418,81.9143 605.427,81.9138 605.437,81.9133 605.446,81.9128 605.455,81.9123 605.464,81.9118 605.473,81.9113 605.483,81.9108 605.492,81.9103 605.501,81.9098 605.51,81.9093 605.519,81.9088 605.529,81.9083 605.538,81.9078 605.547,81.9073 605.556,81.9068 605.565,81.9063 605.574,81.9058 605.584,81.9053 605.593,81.9048 605.602,81.9043 605.611,81.9038 605.62,81.9033 605.63,81.9029 605.639,81.9024 605.648,81.9019 605.657,81.9014 605.666,81.9009 605.676,81.9004 605.685,81.8999 605.694,81.8994 605.703,81.8989 605.712,81.8985 605.722,81.898 605.731,81.8975 605.74,81.897 605.749,81.8965 605.758,81.896 605.767,81.8955 605.777,81.895 605.786,81.8946 605.795,81.8941 605.804,81.8936 605.813,81.8931 605.823,81.8926 605.832,81.8921 605.841,81.8917 605.85,81.8912 605.859,81.8907 605.869,81.8902 605.878,81.8897 605.887,81.8892 605.896,81.8888 605.905,81.8883 605.914,81.8878 605.924,81.8873 605.933,81.8868 605.942,81.8864 605.951,81.8859 605.96,81.8854 605.97,81.8849 605.979,81.8845 605.988,81.884 605.997,81.8835 606.006,81.883 606.016,81.8826 606.025,81.8821 606.034,81.8816 606.043,81.8811 606.052,81.8807 606.062,81.8802 606.071,81.8797 606.08,81.8792 606.089,81.8788 606.098,81.8783 606.107,81.8778 606.117,81.8773 606.126,81.8769 606.135,81.8764 606.144,81.8759 606.153,81.8755 606.163,81.875 606.172,81.8745 606.181,81.8741 606.19,81.8736 606.199,81.8731 606.209,81.8726 606.218,81.8722 606.227,81.8717 606.236,81.8712 606.245,81.8708 606.254,81.8703 606.264,81.8698 606.273,81.8694 606.282,81.8689 606.291,81.8685 606.3,81.868 606.31,81.8675 606.319,81.8671 606.328,81.8666 606.337,81.8661 606.346,81.8657 606.356,81.8652 606.365,81.8647 606.374,81.8643 606.383,81.8638 606.392,81.8634 606.402,81.8629 606.411,81.8624 606.42,81.862 606.429,81.8615 606.438,81.8611 606.447,81.8606 606.457,81.8602 606.466,81.8597 606.475,81.8592 606.484,81.8588 606.493,81.8583 606.503,81.8579 606.512,81.8574 606.521,81.857 606.53,81.8565 606.539,81.8561 606.549,81.8556 606.558,81.8551 606.567,81.8547 606.576,81.8542 606.585,81.8538 606.594,81.8533 606.604,81.8529 606.613,81.8524 606.622,81.852 606.631,81.8515 606.64,81.8511 606.65,81.8506 606.659,81.8502 606.668,81.8497 606.677,81.8493 606.686,81.8488 606.696,81.8484 606.705,81.8479 606.714,81.8475 606.723,81.847 606.732,81.8466 606.742,81.8462 606.751,81.8457 606.76,81.8453 606.769,81.8448 606.778,81.8444 606.787,81.8439 606.797,81.8435 606.806,81.843 606.815,81.8426 606.824,81.8422 606.833,81.8417 606.843,81.8413 606.852,81.8408 606.861,81.8404 606.87,81.8399 606.879,81.8395 606.889,81.8391 606.898,81.8386 606.907,81.8382 606.916,81.8377 606.925,81.8373 606.934,81.8369 606.944,81.8364 606.953,81.836 606.962,81.8356 606.971,81.8351 606.98,81.8347 606.99,81.8343 606.999,81.8338 607.008,81.8334 607.017,81.8329 607.026,81.8325 607.036,81.8321 607.045,81.8316 607.054,81.8312 607.063,81.8308 607.072,81.8303 607.082,81.8299 607.091,81.8295 607.1,81.8291 607.109,81.8286 607.118,81.8282 607.127,81.8278 607.137,81.8273 607.146,81.8269 607.155,81.8265 607.164,81.826 607.173,81.8256 607.183,81.8252 607.192,81.8248 607.201,81.8243 607.21,81.8239 607.219,81.8235 607.229,81.8231 607.238,81.8226 607.247,81.8222 607.256,81.8218 607.265,81.8214 607.274,81.8209 607.284,81.8205 607.293,81.8201 607.302,81.8197 607.311,81.8192 607.32,81.8188 607.33,81.8184 607.339,81.818 607.348,81.8176 607.357,81.8171 607.366,81.8167 607.376,81.8163 607.385,81.8159 607.394,81.8155 607.403,81.815 607.412,81.8146 607.422,81.8142 607.431,81.8138 607.44,81.8134 607.449,81.813 607.458,81.8125 607.467,81.8121 607.477,81.8117 607.486,81.8113 607.495,81.8109 607.504,81.8105 607.513,81.81 607.523,81.8096 607.532,81.8092 607.541,81.8088 607.55,81.8084 607.559,81.808 607.569,81.8076 607.578,81.8072 607.587,81.8068 607.596,81.8063 607.605,81.8059 607.615,81.8055 607.624,81.8051 607.633,81.8047 607.642,81.8043 607.651,81.8039 607.66,81.8035 607.67,81.8031 607.679,81.8027 607.688,81.8023 607.697,81.8019 607.706,81.8015 607.716,81.801 607.725,81.8006 607.734,81.8002 607.743,81.7998 607.752,81.7994 607.762,81.799 607.771,81.7986 607.78,81.7982 607.789,81.7978 607.798,81.7974 607.807,81.797 607.817,81.7966 607.826,81.7962 607.835,81.7958 607.844,81.7954 607.853,81.795 607.863,81.7946 607.872,81.7942 607.881,81.7938 607.89,81.7934 607.899,81.793 607.909,81.7926 607.918,81.7922 607.927,81.7918 607.936,81.7914 607.945,81.791 607.955,81.7906 607.964,81.7903 607.973,81.7899 607.982,81.7895 607.991,81.7891 608,81.7887 608.01,81.7883 608.019,81.7879 608.028,81.7875 608.037,81.7871 608.046,81.7867 608.056,81.7863 608.065,81.7859 608.074,81.7855 608.083,81.7852 608.092,81.7848 608.102,81.7844 608.111,81.784 608.12,81.7836 608.129,81.7832 608.138,81.7828 608.147,81.7824 608.157,81.7821 608.166,81.7817 608.175,81.7813 608.184,81.7809 608.193,81.7805 608.203,81.7801 608.212,81.7797 608.221,81.7794 608.23,81.779 608.239,81.7786 608.249,81.7782 608.258,81.7778 608.267,81.7774 608.276,81.7771 608.285,81.7767 608.295,81.7763 608.304,81.7759 608.313,81.7755 608.322,81.7752 608.331,81.7748 608.34,81.7744 608.35,81.774 608.359,81.7737 608.368,81.7733 608.377,81.7729 608.386,81.7725 608.396,81.7721 608.405,81.7718 608.414,81.7714 608.423,81.771 608.432,81.7706 608.442,81.7703 608.451,81.7699 608.46,81.7695 608.469,81.7692 608.478,81.7688 608.487,81.7684 608.497,81.768 608.506,81.7677 608.515,81.7673 608.524,81.7669 608.533,81.7666 608.543,81.7662 608.552,81.7658 608.561,81.7654 608.57,81.7651 608.579,81.7647 608.589,81.7643 608.598,81.764 608.607,81.7636 608.616,81.7632 608.625,81.7629 608.635,81.7625 608.644,81.7621 608.653,81.7618 608.662,81.7614 608.671,81.761 608.68,81.7607 608.69,81.7603 608.699,81.76 608.708,81.7596 608.717,81.7592 608.726,81.7589 608.736,81.7585 608.745,81.7581 608.754,81.7578 608.763,81.7574 608.772,81.7571 608.782,81.7567 608.791,81.7564 608.8,81.756 608.809,81.7556 608.818,81.7553 608.827,81.7549 608.837,81.7546 608.846,81.7542 608.855,81.7538 608.864,81.7535 608.873,81.7531 608.883,81.7528 608.892,81.7524 608.901,81.7521 608.91,81.7517 608.919,81.7514 608.929,81.751 608.938,81.7507 608.947,81.7503 608.956,81.75 608.965,81.7496 608.975,81.7493 608.984,81.7489 608.993,81.7486 609.002,81.7482 609.011,81.7479 609.02,81.7475 609.03,81.7472 609.039,81.7468 609.048,81.7465 609.057,81.7461 609.066,81.7458 609.076,81.7454 609.085,81.7451 609.094,81.7447 609.103,81.7444 609.112,81.744 609.122,81.7437 609.131,81.7434 609.14,81.743 609.149,81.7427 609.158,81.7423 609.167,81.742 609.177,81.7416 609.186,81.7413 609.195,81.741 609.204,81.7406 609.213,81.7403 609.223,81.7399 609.232,81.7396 609.241,81.7393 609.25,81.7389 609.259,81.7386 609.269,81.7382 609.278,81.7379 609.287,81.7376 609.296,81.7372 609.305,81.7369 609.315,81.7366 609.324,81.7362 609.333,81.7359 609.342,81.7356 609.351,81.7352 609.36,81.7349 609.37,81.7345 609.379,81.7342 609.388,81.7339 609.397,81.7336 609.406,81.7332 609.416,81.7329 609.425,81.7326 609.434,81.7322 609.443,81.7319 609.452,81.7316 609.462,81.7312 609.471,81.7309 609.48,81.7306 609.489,81.7302 609.498,81.7299 609.507,81.7296 609.517,81.7293 609.526,81.7289 609.535,81.7286 609.544,81.7283 609.553,81.728 609.563,81.7276 609.572,81.7273 609.581,81.727 609.59,81.7267 609.599,81.7263 609.609,81.726 609.618,81.7257 609.627,81.7254 609.636,81.7251 609.645,81.7247 609.655,81.7244 609.664,81.7241 609.673,81.7238 609.682,81.7235 609.691,81.7231 609.7,81.7228 609.71,81.7225 609.719,81.7222 609.728,81.7219 609.737,81.7215 609.746,81.7212 609.756,81.7209 609.765,81.7206 609.774,81.7203 609.783,81.72 609.792,81.7196 609.802,81.7193 609.811,81.719 609.82,81.7187 609.829,81.7184 609.838,81.7181 609.847,81.7178 609.857,81.7175 609.866,81.7171 609.875,81.7168 609.884,81.7165 609.893,81.7162 609.903,81.7159 609.912,81.7156 609.921,81.7153 609.93,81.715 609.939,81.7147 609.949,81.7144 609.958,81.7141 609.967,81.7137 609.976,81.7134 609.985,81.7131 609.995,81.7128 610.004,81.7125 610.013,81.7122 610.022,81.7119 610.031,81.7116 610.04,81.7113 610.05,81.711 610.059,81.7107 610.068,81.7104 610.077,81.7101 610.086,81.7098 610.096,81.7095 610.105,81.7092 610.114,81.7089 610.123,81.7086 610.132,81.7083 610.142,81.708 610.151,81.7077 610.16,81.7074 610.169,81.7071 610.178,81.7068 610.188,81.7065 610.197,81.7062 610.206,81.7059 610.215,81.7056 610.224,81.7053 610.233,81.705 610.243,81.7047 610.252,81.7044 610.261,81.7042 610.27,81.7039 610.279,81.7036 610.289,81.7033 610.298,81.703 610.307,81.7027 610.316,81.7024 610.325,81.7021 610.335,81.7018 610.344,81.7015 610.353,81.7012 610.362,81.7009 610.371,81.7007 610.38,81.7004 610.39,81.7001 610.399,81.6998 610.408,81.6995 610.417,81.6992 610.426,81.6989 610.436,81.6987 610.445,81.6984 610.454,81.6981 610.463,81.6978 610.472,81.6975 610.482,81.6972 610.491,81.6969 610.5,81.6967 610.509,81.6964 610.518,81.6961 610.528,81.6958 610.537,81.6955 610.546,81.6953 610.555,81.695 610.564,81.6947 610.573,81.6944 610.583,81.6941 610.592,81.6939 610.601,81.6936 610.61,81.6933 610.619,81.693 610.629,81.6928 610.638,81.6925 610.647,81.6922 610.656,81.6919 610.665,81.6917 610.675,81.6914 610.684,81.6911 610.693,81.6908 610.702,81.6906 610.711,81.6903 610.72,81.69 610.73,81.6897 610.739,81.6895 610.748,81.6892 610.757,81.6889 610.766,81.6887 610.776,81.6884 610.785,81.6881 610.794,81.6878 610.803,81.6876 610.812,81.6873 610.822,81.687 610.831,81.6868 610.84,81.6865 610.849,81.6862 610.858,81.686 610.868,81.6857 610.877,81.6854 610.886,81.6852 610.895,81.6849 610.904,81.6846 610.913,81.6844 610.923,81.6841 610.932,81.6839 610.941,81.6836 610.95,81.6833 610.959,81.6831 610.969,81.6828 610.978,81.6826 610.987,81.6823 610.996,81.682 611.005,81.6818 611.015,81.6815 611.024,81.6813 611.033,81.681 611.042,81.6807 611.051,81.6805 611.06,81.6802 611.07,81.68 611.079,81.6797 611.088,81.6795 611.097,81.6792 611.106,81.6789 611.116,81.6787 611.125,81.6784 611.134,81.6782 611.143,81.6779 611.152,81.6777 611.162,81.6774 611.171,81.6772 611.18,81.6769 611.189,81.6767 611.198,81.6764 611.208,81.6762 611.217,81.6759 611.226,81.6757 611.235,81.6754 611.244,81.6752 611.253,81.6749 611.263,81.6747 611.272,81.6744 611.281,81.6742 611.29,81.6739 611.299,81.6737 611.309,81.6735 611.318,81.6732 611.327,81.673 611.336,81.6727 611.345,81.6725 611.355,81.6722 611.364,81.672 611.373,81.6717 611.382,81.6715 611.391,81.6713 611.4,81.671 611.41,81.6708 611.419,81.6705 611.428,81.6703 611.437,81.6701 611.446,81.6698 611.456,81.6696 611.465,81.6694 611.474,81.6691 611.483,81.6689 611.492,81.6686 611.502,81.6684 611.511,81.6682 611.52,81.6679 611.529,81.6677 611.538,81.6675 611.548,81.6672 611.557,81.667 611.566,81.6668 611.575,81.6665 611.584,81.6663 611.593,81.6661 611.603,81.6658 611.612,81.6656 611.621,81.6654 611.63,81.6651 611.639,81.6649 611.649,81.6647 611.658,81.6645 611.667,81.6642 611.676,81.664 611.685,81.6638 611.695,81.6635 611.704,81.6633 611.713,81.6631 611.722,81.6629 611.731,81.6626 611.74,81.6624 611.75,81.6622 611.759,81.662 611.768,81.6617 611.777,81.6615 611.786,81.6613 611.796,81.6611 611.805,81.6609 611.814,81.6606 611.823,81.6604 611.832,81.6602 611.842,81.66 611.851,81.6598 611.86,81.6595 611.869,81.6593 611.878,81.6591 611.888,81.6589 611.897,81.6587 611.906,81.6584 611.915,81.6582 611.924,81.658 611.933,81.6578 611.943,81.6576 611.952,81.6574 611.961,81.6571 611.97,81.6569 611.979,81.6567 611.989,81.6565 611.998,81.6563 612.007,81.6561 612.016,81.6559 612.025,81.6557 612.035,81.6554 612.044,81.6552 612.053,81.655 612.062,81.6548 612.071,81.6546 612.08,81.6544 612.09,81.6542 612.099,81.654 612.108,81.6538 612.117,81.6536 612.126,81.6534 612.136,81.6532 612.145,81.653 612.154,81.6527 612.163,81.6525 612.172,81.6523 612.182,81.6521 612.191,81.6519 612.2,81.6517 612.209,81.6515 612.218,81.6513 612.228,81.6511 612.237,81.6509 612.246,81.6507 612.255,81.6505 612.264,81.6503 612.273,81.6501 612.283,81.6499 612.292,81.6497 612.301,81.6495 612.31,81.6493 612.319,81.6491 612.329,81.6489 612.338,81.6487 612.347,81.6485 612.356,81.6483 612.365,81.6482 612.375,81.648 612.384,81.6478 612.393,81.6476 612.402,81.6474 612.411,81.6472 612.42,81.647 612.43,81.6468 612.439,81.6466 612.448,81.6464 612.457,81.6462 612.466,81.646 612.476,81.6458 612.485,81.6457 612.494,81.6455 612.503,81.6453 612.512,81.6451 612.522,81.6449 612.531,81.6447 612.54,81.6445 612.549,81.6443 612.558,81.6442 612.568,81.644 612.577,81.6438 612.586,81.6436 612.595,81.6434 612.604,81.6432 612.613,81.6431 612.623,81.6429 612.632,81.6427 612.641,81.6425 612.65,81.6423 612.659,81.6421 612.669,81.642 612.678,81.6418 612.687,81.6416 612.696,81.6414 612.705,81.6412 612.715,81.6411 612.724,81.6409 612.733,81.6407 612.742,81.6405 612.751,81.6404 612.761,81.6402 612.77,81.64 612.779,81.6398 612.788,81.6397 612.797,81.6395 612.806,81.6393 612.816,81.6391 612.825,81.639 612.834,81.6388 612.843,81.6386 612.852,81.6385 612.862,81.6383 612.871,81.6381 612.88,81.6379 612.889,81.6378 612.898,81.6376 612.908,81.6374 612.917,81.6373 612.926,81.6371 612.935,81.6369 612.944,81.6368 612.953,81.6366 612.963,81.6364 612.972,81.6363 612.981,81.6361 612.99,81.6359 612.999,81.6358 613.009,81.6356 613.018,81.6354 613.027,81.6353 613.036,81.6351 613.045,81.635 613.055,81.6348 613.064,81.6346 613.073,81.6345 613.082,81.6343 613.091,81.6342 613.101,81.634 613.11,81.6338 613.119,81.6337 613.128,81.6335 613.137,81.6334 613.146,81.6332 613.156,81.6331 613.165,81.6329 613.174,81.6327 613.183,81.6326 613.192,81.6324 613.202,81.6323 613.211,81.6321 613.22,81.632 613.229,81.6318 613.238,81.6317 613.248,81.6315 613.257,81.6314 613.266,81.6312 613.275,81.6311 613.284,81.6309 613.293,81.6308 613.303,81.6306 613.312,81.6305 613.321,81.6303 613.33,81.6302 613.339,81.63 613.349,81.6299 613.358,81.6297 613.367,81.6296 613.376,81.6294 613.385,81.6293 613.395,81.6291 613.404,81.629 613.413,81.6289 613.422,81.6287 613.431,81.6286 613.441,81.6284 613.45,81.6283 613.459,81.6281 613.468,81.628 613.477,81.6279 613.486,81.6277 613.496,81.6276 613.505,81.6274 613.514,81.6273 613.523,81.6272 613.532,81.627 613.542,81.6269 613.551,81.6268 613.56,81.6266 613.569,81.6265 613.578,81.6263 613.588,81.6262 613.597,81.6261 613.606,81.6259 613.615,81.6258 613.624,81.6257 613.633,81.6255 613.643,81.6254 613.652,81.6253 613.661,81.6251 613.67,81.625 613.679,81.6249 613.689,81.6248 613.698,81.6246 613.707,81.6245 613.716,81.6244 613.725,81.6242 613.735,81.6241 613.744,81.624 613.753,81.6239 613.762,81.6237 613.771,81.6236 613.781,81.6235 613.79,81.6234 613.799,81.6232 613.808,81.6231 613.817,81.623 613.826,81.6229 613.836,81.6227 613.845,81.6226 613.854,81.6225 613.863,81.6224 613.872,81.6223 613.882,81.6221 613.891,81.622 613.9,81.6219 613.909,81.6218 613.918,81.6217 613.928,81.6215 613.937,81.6214 613.946,81.6213 613.955,81.6212 613.964,81.6211 613.973,81.621 613.983,81.6208 613.992,81.6207 614.001,81.6206 614.01,81.6205 614.019,81.6204 614.029,81.6203 614.038,81.6202 614.047,81.6201 614.056,81.6199 614.065,81.6198 614.075,81.6197 614.084,81.6196 614.093,81.6195 614.102,81.6194 614.111,81.6193 614.121,81.6192 614.13,81.6191 614.139,81.619 614.148,81.6189 614.157,81.6187 614.166,81.6186 614.176,81.6185 614.185,81.6184 614.194,81.6183 614.203,81.6182 614.212,81.6181 614.222,81.618 614.231,81.6179 614.24,81.6178 614.249,81.6177 614.258,81.6176 614.268,81.6175 614.277,81.6174 614.286,81.6173 614.295,81.6172 614.304,81.6171 614.313,81.617 614.323,81.6169 614.332,81.6168 614.341,81.6167 614.35,81.6166 614.359,81.6165 614.369,81.6164 614.378,81.6163 614.387,81.6162 614.396,81.6162 614.405,81.6161 614.415,81.616 614.424,81.6159 614.433,81.6158 614.442,81.6157 614.451,81.6156 614.461,81.6155 614.47,81.6154 614.479,81.6153 614.488,81.6152 614.497,81.6152 614.506,81.6151 614.516,81.615 614.525,81.6149 614.534,81.6148 614.543,81.6147 614.552,81.6146 614.562,81.6145 614.571,81.6145 614.58,81.6144 614.589,81.6143 614.598,81.6142 614.608,81.6141 614.617,81.614 614.626,81.614 614.635,81.6139 614.644,81.6138 614.653,81.6137 614.663,81.6136 614.672,81.6136 614.681,81.6135 614.69,81.6134 614.699,81.6133 614.709,81.6132 614.718,81.6132 614.727,81.6131 614.736,81.613 614.745,81.6129 614.755,81.6129 614.764,81.6128 614.773,81.6127 614.782,81.6126 614.791,81.6126 614.801,81.6125 614.81,81.6124 614.819,81.6123 614.828,81.6123 614.837,81.6122 614.846,81.6121 614.856,81.6121 614.865,81.612 614.874,81.6119 614.883,81.6118 614.892,81.6118 614.902,81.6117 614.911,81.6116 614.92,81.6116 614.929,81.6115 614.938,81.6114 614.948,81.6114 614.957,81.6113 614.966,81.6113 614.975,81.6112 614.984,81.6111 614.994,81.6111 615.003,81.611 615.012,81.6109 615.021,81.6109 615.03,81.6108 615.039,81.6108 615.049,81.6107 615.058,81.6106 615.067,81.6106 615.076,81.6105 615.085,81.6105 615.095,81.6104 615.104,81.6103 615.113,81.6103 615.122,81.6102 615.131,81.6102 615.141,81.6101 615.15,81.6101 615.159,81.61 615.168,81.61 615.177,81.6099 615.186,81.6098 615.196,81.6098 615.205,81.6097 615.214,81.6097 615.223,81.6096 615.232,81.6096 615.242,81.6095 615.251,81.6095 615.26,81.6094 615.269,81.6094 615.278,81.6093 615.288,81.6093 615.297,81.6093 615.306,81.6092 615.315,81.6092 615.324,81.6091 615.334,81.6091 615.343,81.609 615.352,81.609 615.361,81.6089 615.37,81.6089 615.379,81.6088 615.389,81.6088 615.398,81.6088 615.407,81.6087 615.416,81.6087 615.425,81.6086 615.435,81.6086 615.444,81.6086 615.453,81.6085 615.462,81.6085 615.471,81.6084 615.481,81.6084 615.49,81.6084 615.499,81.6083 615.508,81.6083 615.517,81.6083 615.526,81.6082 615.536,81.6082 615.545,81.6082 615.554,81.6081 615.563,81.6081 615.572,81.6081 615.582,81.608 615.591,81.608 615.6,81.608 615.609,81.6079 615.618,81.6079 615.628,81.6079 615.637,81.6078 615.646,81.6078 615.655,81.6078 615.664,81.6078 615.674,81.6077 615.683,81.6077 615.692,81.6077 615.701,81.6077 615.71,81.6076 615.719,81.6076 615.729,81.6076 615.738,81.6076 615.747,81.6075 615.756,81.6075 615.765,81.6075 615.775,81.6075 615.784,81.6075 615.793,81.6074 615.802,81.6074 615.811,81.6074 615.821,81.6074 615.83,81.6074 615.839,81.6073 615.848,81.6073 615.857,81.6073 615.866,81.6073 615.876,81.6073 615.885,81.6072 615.894,81.6072 615.903,81.6072 615.912,81.6072 615.922,81.6072 615.931,81.6072 615.94,81.6072 615.949,81.6072 615.958,81.6071 615.968,81.6071 615.977,81.6071 615.986,81.6071 615.995,81.6071 616.004,81.6071 616.014,81.6071 616.023,81.6071 616.032,81.6071 616.041,81.6071 616.05,81.6071 616.059,81.607 616.069,81.607 616.078,81.607 616.087,81.607 616.096,81.607 616.105,81.607 616.115,81.607 616.124,81.607 616.133,81.607 616.142,81.607 616.151,81.607 616.161,81.607 616.17,81.607 616.179,81.607 616.188,81.607 616.197,81.607 616.206,81.607 616.216,81.607 616.225,81.607 616.234,81.607 616.243,81.607 616.252,81.607 616.262,81.607 616.271,81.607 616.28,81.607 616.289,81.607 616.298,81.6071 616.308,81.6071 616.317,81.6071 616.326,81.6071 616.335,81.6071 616.344,81.6071 616.354,81.6071 616.363,81.6071 616.372,81.6071 616.381,81.6071 616.39,81.6071 616.399,81.6072 616.409,81.6072 616.418,81.6072 616.427,81.6072 616.436,81.6072 616.445,81.6072 616.455,81.6072 616.464,81.6073 616.473,81.6073 616.482,81.6073 616.491,81.6073 616.501,81.6073 616.51,81.6073 616.519,81.6074 616.528,81.6074 616.537,81.6074 616.546,81.6074 616.556,81.6074 616.565,81.6075 616.574,81.6075 616.583,81.6075 616.592,81.6075 616.602,81.6076 616.611,81.6076 616.62,81.6076 616.629,81.6076 616.638,81.6076 616.648,81.6077 616.657,81.6077 616.666,81.6077 616.675,81.6078 616.684,81.6078 616.694,81.6078 616.703,81.6078 616.712,81.6079 616.721,81.6079 616.73,81.6079 616.739,81.608 616.749,81.608 616.758,81.608 616.767,81.6081 616.776,81.6081 616.785,81.6081 616.795,81.6082 616.804,81.6082 616.813,81.6082 616.822,81.6083 616.831,81.6083 616.841,81.6083 616.85,81.6084 616.859,81.6084 616.868,81.6084 616.877,81.6085 616.886,81.6085 616.896,81.6086 616.905,81.6086 616.914,81.6086 616.923,81.6087 616.932,81.6087 616.942,81.6088 616.951,81.6088 616.96,81.6089 616.969,81.6089 616.978,81.6089 616.988,81.609 616.997,81.609 617.006,81.6091 617.015,81.6091 617.024,81.6092 617.034,81.6092 617.043,81.6093 617.052,81.6093 617.061,81.6094 617.07,81.6094 617.079,81.6095 617.089,81.6095 617.098,81.6096 617.107,81.6096 617.116,81.6097 617.125,81.6097 617.135,81.6098 617.144,81.6098 617.153,81.6099 617.162,81.6099 617.171,81.61 617.181,81.61 617.19,81.6101 617.199,81.6101 617.208,81.6102 617.217,81.6103 617.226,81.6103 617.236,81.6104 617.245,81.6104 617.254,81.6105 617.263,81.6106 617.272,81.6106 617.282,81.6107 617.291,81.6107 617.3,81.6108 617.309,81.6109 617.318,81.6109 617.328,81.611 617.337,81.6111 617.346,81.6111 617.355,81.6112 617.364,81.6113 617.374,81.6113 617.383,81.6114 617.392,81.6115 617.401,81.6115 617.41,81.6116 617.419,81.6117 617.429,81.6117 617.438,81.6118 617.447,81.6119 617.456,81.6119 617.465,81.612 617.475,81.6121 617.484,81.6122 617.493,81.6122 617.502,81.6123 617.511,81.6124 617.521,81.6124 617.53,81.6125 617.539,81.6126 617.548,81.6127 617.557,81.6128 617.567,81.6128 617.576,81.6129 617.585,81.613 617.594,81.6131 617.603,81.6131 617.612,81.6132 617.622,81.6133 617.631,81.6134 617.64,81.6135 617.649,81.6135 617.658,81.6136 617.668,81.6137 617.677,81.6138 617.686,81.6139 617.695,81.614 617.704,81.614 617.714,81.6141 617.723,81.6142 617.732,81.6143 617.741,81.6144 617.75,81.6145 617.759,81.6146 617.769,81.6147 617.778,81.6147 617.787,81.6148 617.796,81.6149 617.805,81.615 617.815,81.6151 617.824,81.6152 617.833,81.6153 617.842,81.6154 617.851,81.6155 617.861,81.6156 617.87,81.6157 617.879,81.6158 617.888,81.6159 617.897,81.616 617.907,81.616 617.916,81.6161 617.925,81.6162 617.934,81.6163 617.943,81.6164 617.952,81.6165 617.962,81.6166 617.971,81.6167 617.98,81.6168 617.989,81.6169 617.998,81.617 618.008,81.6171 618.017,81.6172 618.026,81.6174 618.035,81.6175 618.044,81.6176 618.054,81.6177 618.063,81.6178 618.072,81.6179 618.081,81.618 618.09,81.6181 618.099,81.6182 618.109,81.6183 618.118,81.6184 618.127,81.6185 618.136,81.6186 618.145,81.6187 618.155,81.6189 618.164,81.619 618.173,81.6191 618.182,81.6192 618.191,81.6193 618.201,81.6194 618.21,81.6195 618.219,81.6196 618.228,81.6198 618.237,81.6199 618.247,81.62 618.256,81.6201 618.265,81.6202 618.274,81.6203 618.283,81.6205 618.292,81.6206 618.302,81.6207 618.311,81.6208 618.32,81.6209 618.329,81.6211 618.338,81.6212 618.348,81.6213 618.357,81.6214 618.366,81.6216 618.375,81.6217 618.384,81.6218 618.394,81.6219 618.403,81.622 618.412,81.6222 618.421,81.6223 618.43,81.6224 618.439,81.6226 618.449,81.6227 618.458,81.6228 618.467,81.6229 618.476,81.6231 618.485,81.6232 618.495,81.6233 618.504,81.6235 618.513,81.6236 618.522,81.6237 618.531,81.6239 618.541,81.624 618.55,81.6241 618.559,81.6243 618.568,81.6244 618.577,81.6245 618.587,81.6247 618.596,81.6248 618.605,81.6249 618.614,81.6251 618.623,81.6252 618.632,81.6254 618.642,81.6255 618.651,81.6256 618.66,81.6258 618.669,81.6259 618.678,81.6261 618.688,81.6262 618.697,81.6263 618.706,81.6265 618.715,81.6266 618.724,81.6268 618.734,81.6269 618.743,81.6271 618.752,81.6272 618.761,81.6274 618.77,81.6275 618.779,81.6276 618.789,81.6278 618.798,81.6279 618.807,81.6281 618.816,81.6282 618.825,81.6284 618.835,81.6285 618.844,81.6287 618.853,81.6288 618.862,81.629 618.871,81.6292 618.881,81.6293 618.89,81.6295 618.899,81.6296 618.908,81.6298 618.917,81.6299 618.927,81.6301 618.936,81.6302 618.945,81.6304 618.954,81.6306 618.963,81.6307 618.972,81.6309 618.982,81.631 618.991,81.6312 619,81.6313 619.009,81.6315 619.018,81.6317 619.028,81.6318 619.037,81.632 619.046,81.6322 619.055,81.6323 619.064,81.6325 619.074,81.6327 619.083,81.6328 619.092,81.633 619.101,81.6332 619.11,81.6333 619.119,81.6335 619.129,81.6337 619.138,81.6338 619.147,81.634 619.156,81.6342 619.165,81.6343 619.175,81.6345 619.184,81.6347 619.193,81.6348 619.202,81.635 619.211,81.6352 619.221,81.6354 619.23,81.6355 619.239,81.6357 619.248,81.6359 619.257,81.6361 619.267,81.6362 619.276,81.6364 619.285,81.6366 619.294,81.6368 619.303,81.637 619.312,81.6371 619.322,81.6373 619.331,81.6375 619.34,81.6377 619.349,81.6379 619.358,81.638 619.368,81.6382 619.377,81.6384 619.386,81.6386 619.395,81.6388 619.404,81.639 619.414,81.6391 619.423,81.6393 619.432,81.6395 619.441,81.6397 619.45,81.6399 619.459,81.6401 619.469,81.6403 619.478,81.6405 619.487,81.6406 619.496,81.6408 619.505,81.641 619.515,81.6412 619.524,81.6414 619.533,81.6416 619.542,81.6418 619.551,81.642 619.561,81.6422 619.57,81.6424 619.579,81.6426 619.588,81.6428 619.597,81.643 619.607,81.6432 619.616,81.6434 619.625,81.6436 619.634,81.6438 619.643,81.644 619.652,81.6442 619.662,81.6444 619.671,81.6446 619.68,81.6448 619.689,81.645 619.698,81.6452 619.708,81.6454 619.717,81.6456 619.726,81.6458 619.735,81.646 619.744,81.6462 619.754,81.6464 619.763,81.6466 619.772,81.6468 619.781,81.647 619.79,81.6472 619.799,81.6474 619.809,81.6476 619.818,81.6478 619.827,81.6481 619.836,81.6483 619.845,81.6485 619.855,81.6487 619.864,81.6489 619.873,81.6491 619.882,81.6493 619.891,81.6495 619.901,81.6498 619.91,81.65 619.919,81.6502 619.928,81.6504 619.937,81.6506 619.947,81.6508 619.956,81.6511 619.965,81.6513 619.974,81.6515 619.983,81.6517 619.992,81.6519 620.002,81.6522 620.011,81.6524 620.02,81.6526 620.029,81.6528 620.038,81.6531 620.048,81.6533 620.057,81.6535 620.066,81.6537 620.075,81.654 620.084,81.6542 620.094,81.6544 620.103,81.6546 620.112,81.6549 620.121,81.6551 620.13,81.6553 620.14,81.6555 620.149,81.6558 620.158,81.656 620.167,81.6562 620.176,81.6565 620.185,81.6567 620.195,81.6569 620.204,81.6572 620.213,81.6574 620.222,81.6576 620.231,81.6579 620.241,81.6581 620.25,81.6583 620.259,81.6586 620.268,81.6588 620.277,81.6591 620.287,81.6593 620.296,81.6595 620.305,81.6598 620.314,81.66 620.323,81.6603 620.332,81.6605 620.342,81.6607 620.351,81.661 620.36,81.6612 620.369,81.6615 620.378,81.6617 620.388,81.662 620.397,81.6622 620.406,81.6625 620.415,81.6627 620.424,81.663 620.434,81.6632 620.443,81.6634 620.452,81.6637 620.461,81.6639 620.47,81.6642 620.48,81.6644 620.489,81.6647 620.498,81.665 620.507,81.6652 620.516,81.6655 620.525,81.6657 620.535,81.666 620.544,81.6662 620.553,81.6665 620.562,81.6667 620.571,81.667 620.581,81.6672 620.59,81.6675 620.599,81.6678 620.608,81.668 620.617,81.6683 620.627,81.6685 620.636,81.6688 620.645,81.6691 620.654,81.6693 620.663,81.6696 620.672,81.6698 620.682,81.6701 620.691,81.6704 620.7,81.6706 620.709,81.6709 620.718,81.6712 620.728,81.6714 620.737,81.6717 620.746,81.672 620.755,81.6722 620.764,81.6725 620.774,81.6728 620.783,81.6731 620.792,81.6733 620.801,81.6736 620.81,81.6739 620.82,81.6741 620.829,81.6744 620.838,81.6747 620.847,81.675 620.856,81.6752 620.865,81.6755 620.875,81.6758 620.884,81.6761 620.893,81.6763 620.902,81.6766 620.911,81.6769 620.921,81.6772 620.93,81.6774 620.939,81.6777 620.948,81.678 620.957,81.6783 620.967,81.6786 620.976,81.6789 620.985,81.6791 620.994,81.6794 621.003,81.6797 621.012,81.68 621.022,81.6803 621.031,81.6806 621.04,81.6808 621.049,81.6811 621.058,81.6814 621.068,81.6817 621.077,81.682 621.086,81.6823 621.095,81.6826 621.104,81.6829 621.114,81.6832 621.123,81.6835 621.132,81.6837 621.141,81.684 621.15,81.6843 621.16,81.6846 621.169,81.6849 621.178,81.6852 621.187,81.6855 621.196,81.6858 621.205,81.6861 621.215,81.6864 621.224,81.6867 621.233,81.687 621.242,81.6873 621.251,81.6876 621.261,81.6879 621.27,81.6882 621.279,81.6885 621.288,81.6888 621.297,81.6891 621.307,81.6894 621.316,81.6897 621.325,81.69 621.334,81.6903 621.343,81.6906 621.352,81.6909 621.362,81.6912 621.371,81.6915 621.38,81.6919 621.389,81.6922 621.398,81.6925 621.408,81.6928 621.417,81.6931 621.426,81.6934 621.435,81.6937 621.444,81.694 621.454,81.6943 621.463,81.6947 621.472,81.695 621.481,81.6953 621.49,81.6956 621.5,81.6959 621.509,81.6962 621.518,81.6966 621.527,81.6969 621.536,81.6972 621.545,81.6975 621.555,81.6978 621.564,81.6981 621.573,81.6985 621.582,81.6988 621.591,81.6991 621.601,81.6994 621.61,81.6998 621.619,81.7001 621.628,81.7004 621.637,81.7007 621.647,81.7011 621.656,81.7014 621.665,81.7017 621.674,81.702 621.683,81.7024 621.692,81.7027 621.702,81.703 621.711,81.7033 621.72,81.7037 621.729,81.704 621.738,81.7043 621.748,81.7047 621.757,81.705 621.766,81.7053 621.775,81.7057 621.784,81.706 621.794,81.7063 621.803,81.7067 621.812,81.707 621.821,81.7074 621.83,81.7077 621.84,81.708 621.849,81.7084 621.858,81.7087 621.867,81.709 621.876,81.7094 621.885,81.7097 621.895,81.7101 621.904,81.7104 621.913,81.7108 621.922,81.7111 621.931,81.7114 621.941,81.7118 621.95,81.7121 621.959,81.7125 621.968,81.7128 621.977,81.7132 621.987,81.7135 621.996,81.7139 622.005,81.7142 622.014,81.7146 622.023,81.7149 622.032,81.7153 622.042,81.7156 622.051,81.716 622.06,81.7163 622.069,81.7167 622.078,81.717 622.088,81.7174 622.097,81.7177 622.106,81.7181 622.115,81.7185 622.124,81.7188 622.134,81.7192 622.143,81.7195 622.152,81.7199 622.161,81.7202 622.17,81.7206 622.18,81.721 622.189,81.7213 622.198,81.7217 622.207,81.7221 622.216,81.7224 622.225,81.7228 622.235,81.7231 622.244,81.7235 622.253,81.7239 622.262,81.7242 622.271,81.7246 622.281,81.725 622.29,81.7253 622.299,81.7257 622.308,81.7261 622.317,81.7264 622.327,81.7268 622.336,81.7272 622.345,81.7276 622.354,81.7279 622.363,81.7283 622.373,81.7287 622.382,81.7291 622.391,81.7294 622.4,81.7298 622.409,81.7302 622.418,81.7306 622.428,81.7309 622.437,81.7313 622.446,81.7317 622.455,81.7321 622.464,81.7325 622.474,81.7328 622.483,81.7332 622.492,81.7336 622.501,81.734 622.51,81.7344 622.52,81.7347 622.529,81.7351 622.538,81.7355 622.547,81.7359 622.556,81.7363 622.565,81.7367 622.575,81.7371 622.584,81.7374 622.593,81.7378 622.602,81.7382 622.611,81.7386 622.621,81.739 622.63,81.7394 622.639,81.7398 622.648,81.7402 622.657,81.7406 622.667,81.741 622.676,81.7414 622.685,81.7417 622.694,81.7421 622.703,81.7425 622.713,81.7429 622.722,81.7433 622.731,81.7437 622.74,81.7441 622.749,81.7445 622.758,81.7449 622.768,81.7453 622.777,81.7457 622.786,81.7461 622.795,81.7465 622.804,81.7469 622.814,81.7473 622.823,81.7477 622.832,81.7481 622.841,81.7486 622.85,81.749 622.86,81.7494 622.869,81.7498 622.878,81.7502 622.887,81.7506 622.896,81.751 622.905,81.7514 622.915,81.7518 622.924,81.7522 622.933,81.7526 622.942,81.753 622.951,81.7535 622.961,81.7539 622.97,81.7543 622.979,81.7547 622.988,81.7551 622.997,81.7555 623.007,81.756 623.016,81.7564 623.025,81.7568 623.034,81.7572 623.043,81.7576 623.053,81.758 623.062,81.7585 623.071,81.7589 623.08,81.7593 623.089,81.7597 623.098,81.7602 623.108,81.7606 623.117,81.761 623.126,81.7614 623.135,81.7618 623.144,81.7623 623.154,81.7627 623.163,81.7631 623.172,81.7636 623.181,81.764 623.19,81.7644 623.2,81.7648 623.209,81.7653 623.218,81.7657 623.227,81.7661 623.236,81.7666 623.245,81.767 623.255,81.7674 623.264,81.7679 623.273,81.7683 623.282,81.7687 623.291,81.7692 623.301,81.7696 623.31,81.7701 623.319,81.7705 623.328,81.7709 623.337,81.7714 623.347,81.7718 623.356,81.7722 623.365,81.7727 623.374,81.7731 623.383,81.7736 623.393,81.774 623.402,81.7745 623.411,81.7749 623.42,81.7753 623.429,81.7758 623.438,81.7762 623.448,81.7767 623.457,81.7771 623.466,81.7776 623.475,81.778 623.484,81.7785 623.494,81.7789 623.503,81.7794 623.512,81.7798 623.521,81.7803 623.53,81.7807 623.54,81.7812 623.549,81.7816 623.558,81.7821 623.567,81.7826 623.576,81.783 623.585,81.7835 623.595,81.7839 623.604,81.7844 623.613,81.7848 623.622,81.7853 623.631,81.7858 623.641,81.7862 623.65,81.7867 623.659,81.7871 623.668,81.7876 623.677,81.7881 623.687,81.7885 623.696,81.789 623.705,81.7895 623.714,81.7899 623.723,81.7904 623.733,81.7909 623.742,81.7913 623.751,81.7918 623.76,81.7923 623.769,81.7927 623.778,81.7932 623.788,81.7937 623.797,81.7941 623.806,81.7946 623.815,81.7951 623.824,81.7956 623.834,81.796 623.843,81.7965 623.852,81.797 623.861,81.7975 623.87,81.7979 623.88,81.7984 623.889,81.7989 623.898,81.7994 623.907,81.7999 623.916,81.8003 623.925,81.8008 623.935,81.8013 623.944,81.8018 623.953,81.8023 623.962,81.8027 623.971,81.8032 623.981,81.8037 623.99,81.8042 623.999,81.8047 624.008,81.8052 624.017,81.8057 624.027,81.8061 624.036,81.8066 624.045,81.8071 624.054,81.8076 624.063,81.8081 624.073,81.8086 624.082,81.8091 624.091,81.8096 624.1,81.8101 624.109,81.8106 624.118,81.8111 624.128,81.8116 624.137,81.812 624.146,81.8125 624.155,81.813 624.164,81.8135 624.174,81.814 624.183,81.8145 624.192,81.815 624.201,81.8155 624.21,81.816 624.22,81.8165 624.229,81.817 624.238,81.8175 624.247,81.818 624.256,81.8185 624.265,81.8191 624.275,81.8196 624.284,81.8201 624.293,81.8206 624.302,81.8211 624.311,81.8216 624.321,81.8221 624.33,81.8226 624.339,81.8231 624.348,81.8236 624.357,81.8241 624.367,81.8246 624.376,81.8252 624.385,81.8257 624.394,81.8262 624.403,81.8267 624.413,81.8272 624.422,81.8277 624.431,81.8283 624.44,81.8288 624.449,81.8293 624.458,81.8298 624.468,81.8303 624.477,81.8308 624.486,81.8314 624.495,81.8319 624.504,81.8324 624.514,81.8329 624.523,81.8335 624.532,81.834 624.541,81.8345 624.55,81.835 624.56,81.8356 624.569,81.8361 624.578,81.8366 624.587,81.8371 624.596,81.8377 624.605,81.8382 624.615,81.8387 624.624,81.8393 624.633,81.8398 624.642,81.8403 624.651,81.8408 624.661,81.8414 624.67,81.8419 624.679,81.8425 624.688,81.843 624.697,81.8435 624.707,81.8441 624.716,81.8446 624.725,81.8451 624.734,81.8457 624.743,81.8462 624.753,81.8468 624.762,81.8473 624.771,81.8478 624.78,81.8484 624.789,81.8489 624.798,81.8495 624.808,81.85 624.817,81.8506 624.826,81.8511 624.835,81.8516 624.844,81.8522 624.854,81.8527 624.863,81.8533 624.872,81.8538 624.881,81.8544 624.89,81.8549 624.9,81.8555 624.909,81.856 624.918,81.8566 624.927,81.8571 624.936,81.8577 624.946,81.8582 624.955,81.8588 624.964,81.8594 624.973,81.8599 624.982,81.8605 624.991,81.861 625.001,81.8616 625.01,81.8621 625.019,81.8627 625.028,81.8633 625.037,81.8638 625.047,81.8644 625.056,81.8649 625.065,81.8655 625.074,81.8661 625.083,81.8666 625.093,81.8672 625.102,81.8678 625.111,81.8683 625.12,81.8689 625.129,81.8695 625.138,81.87 625.148,81.8706 625.157,81.8712 625.166,81.8717 625.175,81.8723 625.184,81.8729 625.194,81.8735 625.203,81.874 625.212,81.8746 625.221,81.8752 625.23,81.8758 625.24,81.8763 625.249,81.8769 625.258,81.8775 625.267,81.8781 625.276,81.8786 625.286,81.8792 625.295,81.8798 625.304,81.8804 625.313,81.881 625.322,81.8815 625.331,81.8821 625.341,81.8827 625.35,81.8833 625.359,81.8839 625.368,81.8845 625.377,81.8851 625.387,81.8856 625.396,81.8862 625.405,81.8868 625.414,81.8874 625.423,81.888 625.433,81.8886 625.442,81.8892 625.451,81.8898 625.46,81.8904 625.469,81.891 625.478,81.8915 625.488,81.8921 625.497,81.8927 625.506,81.8933 625.515,81.8939 625.524,81.8945 625.534,81.8951 625.543,81.8957 625.552,81.8963 625.561,81.8969 625.57,81.8975 625.58,81.8981 625.589,81.8987 625.598,81.8993 625.607,81.8999 625.616,81.9005 625.626,81.9011 625.635,81.9017 625.644,81.9024 625.653,81.903 625.662,81.9036 625.671,81.9042 625.681,81.9048 625.69,81.9054 625.699,81.906 625.708,81.9066 625.717,81.9072 625.727,81.9078 625.736,81.9085 625.745,81.9091 625.754,81.9097 625.763,81.9103 625.773,81.9109 625.782,81.9115 625.791,81.9121 625.8,81.9128 625.809,81.9134 625.818,81.914 625.828,81.9146 625.837,81.9152 625.846,81.9159 625.855,81.9165 625.864,81.9171 625.874,81.9177 625.883,81.9184 625.892,81.919 625.901,81.9196 625.91,81.9202 625.92,81.9209 625.929,81.9215 625.938,81.9221 625.947,81.9227 625.956,81.9234 625.966,81.924 625.975,81.9246 625.984,81.9253 625.993,81.9259 626.002,81.9265 626.011,81.9272 626.021,81.9278 626.03,81.9284 626.039,81.9291 626.048,81.9297 626.057,81.9303 626.067,81.931 626.076,81.9316 626.085,81.9323 626.094,81.9329 626.103,81.9335 626.113,81.9342 626.122,81.9348 626.131,81.9355 626.14,81.9361 626.149,81.9368 626.158,81.9374 626.168,81.9381 626.177,81.9387 626.186,81.9393 626.195,81.94 626.204,81.9406 626.214,81.9413 626.223,81.9419 626.232,81.9426 626.241,81.9432 626.25,81.9439 626.26,81.9446 626.269,81.9452 626.278,81.9459 626.287,81.9465 626.296,81.9472 626.306,81.9478 626.315,81.9485 626.324,81.9491 626.333,81.9498 626.342,81.9505 626.351,81.9511 626.361,81.9518 626.37,81.9524 626.379,81.9531 626.388,81.9538 626.397,81.9544 626.407,81.9551 626.416,81.9558 626.425,81.9564 626.434,81.9571 626.443,81.9578 626.453,81.9584 626.462,81.9591 626.471,81.9598 626.48,81.9604 626.489,81.9611 626.498,81.9618 626.508,81.9625 626.517,81.9631 626.526,81.9638 626.535,81.9645 626.544,81.9652 626.554,81.9658 626.563,81.9665 626.572,81.9672 626.581,81.9679 626.59,81.9685 626.6,81.9692 626.609,81.9699 626.618,81.9706 626.627,81.9713 626.636,81.9719 626.646,81.9726 626.655,81.9733 626.664,81.974 626.673,81.9747 626.682,81.9754 626.691,81.9761 626.701,81.9767 626.71,81.9774 626.719,81.9781 626.728,81.9788 626.737,81.9795 626.747,81.9802 626.756,81.9809 626.765,81.9816 626.774,81.9823 626.783,81.983 626.793,81.9837 626.802,81.9844 626.811,81.985 626.82,81.9857 626.829,81.9864 626.838,81.9871 626.848,81.9878 626.857,81.9885 626.866,81.9892 626.875,81.9899 626.884,81.9906 626.894,81.9913 626.903,81.992 626.912,81.9928 626.921,81.9935 626.93,81.9942 626.94,81.9949 626.949,81.9956 626.958,81.9963 626.967,81.997 626.976,81.9977 626.986,81.9984 626.995,81.9991 627.004,81.9998 627.013,82.0005 627.022,82.0013 627.031,82.002 627.041,82.0027 627.05,82.0034 627.059,82.0041 627.068,82.0048 627.077,82.0055 627.087,82.0063 627.096,82.007 627.105,82.0077 627.114,82.0084 627.123,82.0091 627.133,82.0099 627.142,82.0106 627.151,82.0113 627.16,82.012 627.169,82.0128 627.178,82.0135 627.188,82.0142 627.197,82.0149 627.206,82.0157 627.215,82.0164 627.224,82.0171 627.234,82.0179 627.243,82.0186 627.252,82.0193 627.261,82.02 627.27,82.0208 627.28,82.0215 627.289,82.0222 627.298,82.023 627.307,82.0237 627.316,82.0245 627.326,82.0252 627.335,82.0259 627.344,82.0267 627.353,82.0274 627.362,82.0281 627.371,82.0289 627.381,82.0296 627.39,82.0304 627.399,82.0311 627.408,82.0319 627.417,82.0326 627.427,82.0333 627.436,82.0341 627.445,82.0348 627.454,82.0356 627.463,82.0363 627.473,82.0371 627.482,82.0378 627.491,82.0386 627.5,82.0393 627.509,82.0401 627.519,82.0408 627.528,82.0416 627.537,82.0423 627.546,82.0431 627.555,82.0439 627.564,82.0446 627.574,82.0454 627.583,82.0461 627.592,82.0469 627.601,82.0476 627.61,82.0484 627.62,82.0492 627.629,82.0499 627.638,82.0507 627.647,82.0515 627.656,82.0522 627.666,82.053 627.675,82.0537 627.684,82.0545 627.693,82.0553 627.702,82.056 627.711,82.0568 627.721,82.0576 627.73,82.0584 627.739,82.0591 627.748,82.0599 627.757,82.0607 627.767,82.0614 627.776,82.0622 627.785,82.063 627.794,82.0638 627.803,82.0645 627.813,82.0653 627.822,82.0661 627.831,82.0669 627.84,82.0677 627.849,82.0684 627.859,82.0692 627.868,82.07 627.877,82.0708 627.886,82.0716 627.895,82.0723 627.904,82.0731 627.914,82.0739 627.923,82.0747 627.932,82.0755 627.941,82.0763 627.95,82.0771 627.96,82.0778 627.969,82.0786 627.978,82.0794 627.987,82.0802 627.996,82.081 628.006,82.0818 628.015,82.0826 628.024,82.0834 628.033,82.0842 628.042,82.085 628.051,82.0858 628.061,82.0866 628.07,82.0874 628.079,82.0882 628.088,82.089 628.097,82.0898 628.107,82.0906 628.116,82.0914 628.125,82.0922 628.134,82.093 628.143,82.0938 628.153,82.0946 628.162,82.0954 628.171,82.0962 628.18,82.097 628.189,82.0978 628.199,82.0986 628.208,82.0994 628.217,82.1002 628.226,82.101 628.235,82.1019 628.244,82.1027 628.254,82.1035 628.263,82.1043 628.272,82.1051 628.281,82.1059 628.29,82.1067 628.3,82.1076 628.309,82.1084 628.318,82.1092 628.327,82.11 628.336,82.1108 628.346,82.1116 628.355,82.1125 628.364,82.1133 628.373,82.1141 628.382,82.1149 628.391,82.1158 628.401,82.1166 628.41,82.1174 628.419,82.1182 628.428,82.1191 628.437,82.1199 628.447,82.1207 628.456,82.1216 628.465,82.1224 628.474,82.1232 628.483,82.124 628.493,82.1249 628.502,82.1257 628.511,82.1266 628.52,82.1274 628.529,82.1282 628.539,82.1291 628.548,82.1299 628.557,82.1307 628.566,82.1316 628.575,82.1324 628.584,82.1333 628.594,82.1341 628.603,82.1349 628.612,82.1358 628.621,82.1366 628.63,82.1375 628.64,82.1383 628.649,82.1392 628.658,82.14 628.667,82.1409 628.676,82.1417 628.686,82.1426 628.695,82.1434 628.704,82.1443 628.713,82.1451 628.722,82.146 628.731,82.1468 628.741,82.1477 628.75,82.1485 628.759,82.1494 628.768,82.1502 628.777,82.1511 628.787,82.1519 628.796,82.1528 628.805,82.1537 628.814,82.1545 628.823,82.1554 628.833,82.1562 628.842,82.1571 628.851,82.158 628.86,82.1588 628.869,82.1597 628.879,82.1606 628.888,82.1614 628.897,82.1623 628.906,82.1632 628.915,82.164 628.924,82.1649 628.934,82.1658 628.943,82.1666 628.952,82.1675 628.961,82.1684 628.97,82.1693 628.98,82.1701 628.989,82.171 628.998,82.1719 629.007,82.1728 629.016,82.1736 629.026,82.1745 629.035,82.1754 629.044,82.1763 629.053,82.1772 629.062,82.178 629.071,82.1789 629.081,82.1798 629.09,82.1807 629.099,82.1816 629.108,82.1825 629.117,82.1833 629.127,82.1842 629.136,82.1851 629.145,82.186 629.154,82.1869 629.163,82.1878 629.173,82.1887 629.182,82.1896 629.191,82.1905 629.2,82.1914 629.209,82.1922 629.219,82.1931 629.228,82.194 629.237,82.1949 629.246,82.1958 629.255,82.1967 629.264,82.1976 629.274,82.1985 629.283,82.1994 629.292,82.2003 629.301,82.2012 629.31,82.2021 629.32,82.203 629.329,82.2039 629.338,82.2048 629.347,82.2057 629.356,82.2067 629.366,82.2076 629.375,82.2085 629.384,82.2094 629.393,82.2103 629.402,82.2112 629.411,82.2121 629.421,82.213 629.43,82.2139 629.439,82.2148 629.448,82.2158 629.457,82.2167 629.467,82.2176 629.476,82.2185 629.485,82.2194 629.494,82.2203 629.503,82.2213 629.513,82.2222 629.522,82.2231 629.531,82.224 629.54,82.225 629.549,82.2259 629.559,82.2268 629.568,82.2277 629.577,82.2287 629.586,82.2296 629.595,82.2305 629.604,82.2314 629.614,82.2324 629.623,82.2333 629.632,82.2342 629.641,82.2352 629.65,82.2361 629.66,82.237 629.669,82.238 629.678,82.2389 629.687,82.2398 629.696,82.2408 629.706,82.2417 629.715,82.2426 629.724,82.2436 629.733,82.2445 629.742,82.2455 629.752,82.2464 629.761,82.2473 629.77,82.2483 629.779,82.2492 629.788,82.2502 629.797,82.2511 629.807,82.2521 629.816,82.253 629.825,82.254 629.834,82.2549 629.843,82.2559 629.853,82.2568 629.862,82.2578 629.871,82.2587 629.88,82.2597 629.889,82.2606 629.899,82.2616 629.908,82.2625 629.917,82.2635 629.926,82.2644 629.935,82.2654 629.944,82.2663 629.954,82.2673 629.963,82.2683 629.972,82.2692 629.981,82.2702 629.99,82.2712 630,82.2721 630.009,82.2731 630.018,82.274 630.027,82.275 630.036,82.276 630.046,82.2769 630.055,82.2779 630.064,82.2789 630.073,82.2798 630.082,82.2808 630.092,82.2818 630.101,82.2828 630.11,82.2837 630.119,82.2847 630.128,82.2857 630.137,82.2867 630.147,82.2876 630.156,82.2886 630.165,82.2896 630.174,82.2906 630.183,82.2915 630.193,82.2925 630.202,82.2935 630.211,82.2945 630.22,82.2955 630.229,82.2965 630.239,82.2974 630.248,82.2984 630.257,82.2994 630.266,82.3004 630.275,82.3014 630.284,82.3024 630.294,82.3034 630.303,82.3044 630.312,82.3053 630.321,82.3063 630.33,82.3073 630.34,82.3083 630.349,82.3093 630.358,82.3103 630.367,82.3113 630.376,82.3123 630.386,82.3133 630.395,82.3143 630.404,82.3153 630.413,82.3163 630.422,82.3173 630.432,82.3183 630.441,82.3193 630.45,82.3203 630.459,82.3213 630.468,82.3223 630.477,82.3233 630.487,82.3243 630.496,82.3253 630.505,82.3263 630.514,82.3274 630.523,82.3284 630.533,82.3294 630.542,82.3304 630.551,82.3314 630.56,82.3324 630.569,82.3334 630.579,82.3344 630.588,82.3355 630.597,82.3365 630.606,82.3375 630.615,82.3385 630.624,82.3395 630.634,82.3406 630.643,82.3416 630.652,82.3426 630.661,82.3436 630.67,82.3446 630.68,82.3457 630.689,82.3467 630.698,82.3477 630.707,82.3487 630.716,82.3498 630.726,82.3508 630.735,82.3518 630.744,82.3529 630.753,82.3539 630.762,82.3549 630.772,82.356 630.781,82.357 630.79,82.358 630.799,82.3591 630.808,82.3601 630.817,82.3611 630.827,82.3622 630.836,82.3632 630.845,82.3643 630.854,82.3653 630.863,82.3663 630.873,82.3674 630.882,82.3684 630.891,82.3695 630.9,82.3705 630.909,82.3716 630.919,82.3726 630.928,82.3736 630.937,82.3747 630.946,82.3757 630.955,82.3768 630.964,82.3778 630.974,82.3789 630.983,82.3799 630.992,82.381 631.001,82.3821 631.01,82.3831 631.02,82.3842 631.029,82.3852 631.038,82.3863 631.047,82.3873 631.056,82.3884 631.066,82.3895 631.075,82.3905 631.084,82.3916 631.093,82.3926 631.102,82.3937 631.112,82.3948 631.121,82.3958 631.13,82.3969 631.139,82.398 631.148,82.399 631.157,82.4001 631.167,82.4012 631.176,82.4022 631.185,82.4033 631.194,82.4044 631.203,82.4055 631.213,82.4065 631.222,82.4076 631.231,82.4087 631.24,82.4098 631.249,82.4108 631.259,82.4119 631.268,82.413 631.277,82.4141 631.286,82.4151 631.295,82.4162 631.304,82.4173 631.314,82.4184 631.323,82.4195 631.332,82.4206 631.341,82.4216 631.35,82.4227 631.36,82.4238 631.369,82.4249 631.378,82.426 631.387,82.4271 631.396,82.4282 631.406,82.4293 631.415,82.4304 631.424,82.4315 631.433,82.4325 631.442,82.4336 631.452,82.4347 631.461,82.4358 631.47,82.4369 631.479,82.438 631.488,82.4391 631.497,82.4402 631.507,82.4413 631.516,82.4424 631.525,82.4435 631.534,82.4446 631.543,82.4457 631.553,82.4469 631.562,82.448 631.571,82.4491 631.58,82.4502 631.589,82.4513 631.599,82.4524 631.608,82.4535 631.617,82.4546 631.626,82.4557 631.635,82.4568 631.644,82.458 631.654,82.4591 631.663,82.4602 631.672,82.4613 631.681,82.4624 631.69,82.4635 631.7,82.4647 631.709,82.4658 631.718,82.4669 631.727,82.468 631.736,82.4691 631.746,82.4703 631.755,82.4714 631.764,82.4725 631.773,82.4736 631.782,82.4748 631.792,82.4759 631.801,82.477 631.81,82.4782 631.819,82.4793 631.828,82.4804 631.837,82.4815 631.847,82.4827 631.856,82.4838 631.865,82.485 631.874,82.4861 631.883,82.4872 631.893,82.4884 631.902,82.4895 631.911,82.4906 631.92,82.4918 631.929,82.4929 631.939,82.4941 631.948,82.4952 631.957,82.4964 631.966,82.4975 631.975,82.4986 631.984,82.4998 631.994,82.5009 632.003,82.5021 632.012,82.5032 632.021,82.5044 632.03,82.5055 632.04,82.5067 632.049,82.5078 632.058,82.509 632.067,82.5101 632.076,82.5113 632.086,82.5125 632.095,82.5136 632.104,82.5148 632.113,82.5159 632.122,82.5171 632.132,82.5183 632.141,82.5194 632.15,82.5206 632.159,82.5217 632.168,82.5229 632.177,82.5241 632.187,82.5252 632.196,82.5264 632.205,82.5276 632.214,82.5287 632.223,82.5299 632.233,82.5311 632.242,82.5322 632.251,82.5334 632.26,82.5346 632.269,82.5358 632.279,82.5369 632.288,82.5381 632.297,82.5393 632.306,82.5405 632.315,82.5417 632.325,82.5428 632.334,82.544 632.343,82.5452 632.352,82.5464 632.361,82.5476 632.37,82.5487 632.38,82.5499 632.389,82.5511 632.398,82.5523 632.407,82.5535 632.416,82.5547 632.426,82.5559 632.435,82.5571 632.444,82.5582 632.453,82.5594 632.462,82.5606 632.472,82.5618 632.481,82.563 632.49,82.5642 632.499,82.5654 632.508,82.5666 632.517,82.5678 632.527,82.569 632.536,82.5702 632.545,82.5714 632.554,82.5726 632.563,82.5738 632.573,82.575 632.582,82.5762 632.591,82.5774 632.6,82.5786 632.609,82.5798 632.619,82.581 632.628,82.5823 632.637,82.5835 632.646,82.5847 632.655,82.5859 632.665,82.5871 632.674,82.5883 632.683,82.5895 632.692,82.5907 632.701,82.592 632.71,82.5932 632.72,82.5944 632.729,82.5956 632.738,82.5968 632.747,82.5981 632.756,82.5993 632.766,82.6005 632.775,82.6017 632.784,82.6029 632.793,82.6042 632.802,82.6054 632.812,82.6066 632.821,82.6079 632.83,82.6091 632.839,82.6103 632.848,82.6115 632.857,82.6128 632.867,82.614 632.876,82.6152 632.885,82.6165 632.894,82.6177 632.903,82.6189 632.913,82.6202 632.922,82.6214 632.931,82.6227 632.94,82.6239 632.949,82.6251 632.959,82.6264 632.968,82.6276 632.977,82.6289 632.986,82.6301 632.995,82.6314 633.005,82.6326 633.014,82.6339 633.023,82.6351 633.032,82.6364 633.041,82.6376 633.05,82.6389 633.06,82.6401 633.069,82.6414 633.078,82.6426 633.087,82.6439 633.096,82.6451 633.106,82.6464 633.115,82.6476 633.124,82.6489 633.133,82.6502 633.142,82.6514 633.152,82.6527 633.161,82.6539 633.17,82.6552 633.179,82.6565 633.188,82.6577 633.197,82.659 633.207,82.6603 633.216,82.6615 633.225,82.6628 633.234,82.6641 633.243,82.6653 633.253,82.6666 633.262,82.6679 633.271,82.6692 633.28,82.6704 633.289,82.6717 633.299,82.673 633.308,82.6743 633.317,82.6755 633.326,82.6768 633.335,82.6781 633.345,82.6794 633.354,82.6807 633.363,82.6819 633.372,82.6832 633.381,82.6845 633.39,82.6858 633.4,82.6871 633.409,82.6884 633.418,82.6896 633.427,82.6909 633.436,82.6922 633.446,82.6935 633.455,82.6948 633.464,82.6961 633.473,82.6974 633.482,82.6987 633.492,82.7 633.501,82.7013 633.51,82.7026 633.519,82.7039 633.528,82.7052 633.537,82.7065 633.547,82.7078 633.556,82.7091 633.565,82.7104 633.574,82.7117 633.583,82.713 633.593,82.7143 633.602,82.7156 633.611,82.7169 633.62,82.7182 633.629,82.7195 633.639,82.7208 633.648,82.7222 633.657,82.7235 633.666,82.7248 633.675,82.7261 633.685,82.7274 633.694,82.7287 633.703,82.73 633.712,82.7314 633.721,82.7327 633.73,82.734 633.74,82.7353 633.749,82.7366 633.758,82.738 633.767,82.7393 633.776,82.7406 633.786,82.7419 633.795,82.7433 633.804,82.7446 633.813,82.7459 633.822,82.7473 633.832,82.7486 633.841,82.7499 633.85,82.7512 633.859,82.7526 633.868,82.7539 633.877,82.7552 633.887,82.7566 633.896,82.7579 633.905,82.7593 633.914,82.7606 633.923,82.7619 633.933,82.7633 633.942,82.7646 633.951,82.766 633.96,82.7673 633.969,82.7687 633.979,82.77 633.988,82.7713 633.997,82.7727 634.006,82.774 634.015,82.7754 634.025,82.7767 634.034,82.7781 634.043,82.7794 634.052,82.7808 634.061,82.7822 634.07,82.7835 634.08,82.7849 634.089,82.7862 634.098,82.7876 634.107,82.7889 634.116,82.7903 634.126,82.7917 634.135,82.793 634.144,82.7944 634.153,82.7957 634.162,82.7971 634.172,82.7985 634.181,82.7998 634.19,82.8012 634.199,82.8026 634.208,82.8039 634.217,82.8053 634.227,82.8067 634.236,82.8081 634.245,82.8094 634.254,82.8108 634.263,82.8122 634.273,82.8136 634.282,82.8149 634.291,82.8163 634.3,82.8177 634.309,82.8191 634.319,82.8205 634.328,82.8218 634.337,82.8232 634.346,82.8246 634.355,82.826 634.365,82.8274 634.374,82.8288 634.383,82.8302 634.392,82.8315 634.401,82.8329 634.41,82.8343 634.42,82.8357 634.429,82.8371 634.438,82.8385 634.447,82.8399 634.456,82.8413 634.466,82.8427 634.475,82.8441 634.484,82.8455 634.493,82.8469 634.502,82.8483 634.512,82.8497 634.521,82.8511 634.53,82.8525 634.539,82.8539 634.548,82.8553 634.557,82.8567 634.567,82.8581 634.576,82.8595 634.585,82.8609 634.594,82.8623 634.603,82.8638 634.613,82.8652 634.622,82.8666 634.631,82.868 634.64,82.8694 634.649,82.8708 634.659,82.8722 634.668,82.8737 634.677,82.8751 634.686,82.8765 634.695,82.8779 634.705,82.8793 634.714,82.8808 634.723,82.8822 634.732,82.8836 634.741,82.885 634.75,82.8865 634.76,82.8879 634.769,82.8893 634.778,82.8908 634.787,82.8922 634.796,82.8936 634.806,82.895 634.815,82.8965 634.824,82.8979 634.833,82.8994 634.842,82.9008 634.852,82.9022 634.861,82.9037 634.87,82.9051 634.879,82.9065 634.888,82.908 634.898,82.9094 634.907,82.9109 634.916,82.9123 634.925,82.9138 634.934,82.9152 634.943,82.9167 634.953,82.9181 634.962,82.9196 634.971,82.921 634.98,82.9225 634.989,82.9239 634.999,82.9254 635.008,82.9268 635.017,82.9283 635.026,82.9297 635.035,82.9312 635.045,82.9326 635.054,82.9341 635.063,82.9356 635.072,82.937 635.081,82.9385 635.09,82.94 635.1,82.9414 635.109,82.9429 635.118,82.9444 635.127,82.9458 635.136,82.9473 635.146,82.9488 635.155,82.9502 635.164,82.9517 635.173,82.9532 635.182,82.9546 635.192,82.9561 635.201,82.9576 635.21,82.9591 635.219,82.9605 635.228,82.962 635.238,82.9635 635.247,82.965 635.256,82.9665 635.265,82.9679 635.274,82.9694 635.283,82.9709 635.293,82.9724 635.302,82.9739 635.311,82.9754 635.32,82.9769 635.329,82.9784 635.339,82.9798 635.348,82.9813 635.357,82.9828 635.366,82.9843 635.375,82.9858 635.385,82.9873 635.394,82.9888 635.403,82.9903 635.412,82.9918 635.421,82.9933 635.43,82.9948 635.44,82.9963 635.449,82.9978 635.458,82.9993 635.467,83.0008 635.476,83.0023 635.486,83.0038 635.495,83.0053 635.504,83.0068 635.513,83.0084 635.522,83.0099 635.532,83.0114 635.541,83.0129 635.55,83.0144 635.559,83.0159 635.568,83.0174 635.578,83.019 635.587,83.0205 635.596,83.022 635.605,83.0235 635.614,83.025 635.623,83.0266 635.633,83.0281 635.642,83.0296 635.651,83.0311 635.66,83.0327 635.669,83.0342 635.679,83.0357 635.688,83.0372 635.697,83.0388 635.706,83.0403 635.715,83.0418 635.725,83.0434 635.734,83.0449 635.743,83.0464 635.752,83.048 635.761,83.0495 635.77,83.051 635.78,83.0526 635.789,83.0541 635.798,83.0557 635.807,83.0572 635.816,83.0587 635.826,83.0603 635.835,83.0618 635.844,83.0634 635.853,83.0649 635.862,83.0665 635.872,83.068 635.881,83.0696 635.89,83.0711 635.899,83.0727 635.908,83.0742 635.918,83.0758 635.927,83.0773 635.936,83.0789 635.945,83.0805 635.954,83.082 635.963,83.0836 635.973,83.0851 635.982,83.0867 635.991,83.0883 636,83.0898 636.009,83.0914 636.019,83.093 636.028,83.0945 636.037,83.0961 636.046,83.0977 636.055,83.0992 636.065,83.1008 636.074,83.1024 636.083,83.104 636.092,83.1055 636.101,83.1071 636.11,83.1087 636.12,83.1103 636.129,83.1118 636.138,83.1134 636.147,83.115 636.156,83.1166 636.166,83.1182 636.175,83.1197 636.184,83.1213 636.193,83.1229 636.202,83.1245 636.212,83.1261 636.221,83.1277 636.23,83.1293 636.239,83.1309 636.248,83.1324 636.258,83.134 636.267,83.1356 636.276,83.1372 636.285,83.1388 636.294,83.1404 636.303,83.142 636.313,83.1436 636.322,83.1452 636.331,83.1468 636.34,83.1484 636.349,83.15 636.359,83.1516 636.368,83.1532 636.377,83.1548 636.386,83.1565 636.395,83.1581 636.405,83.1597 636.414,83.1613 636.423,83.1629 636.432,83.1645 636.441,83.1661 636.45,83.1677 636.46,83.1694 636.469,83.171 636.478,83.1726 636.487,83.1742 636.496,83.1758 636.506,83.1774 636.515,83.1791 636.524,83.1807 636.533,83.1823 636.542,83.1839 636.552,83.1856 636.561,83.1872 636.57,83.1888 636.579,83.1905 636.588,83.1921 636.598,83.1937 636.607,83.1953 636.616,83.197 636.625,83.1986 636.634,83.2003 636.643,83.2019 636.653,83.2035 636.662,83.2052 636.671,83.2068 636.68,83.2085 636.689,83.2101 636.699,83.2117 636.708,83.2134 636.717,83.215 636.726,83.2167 636.735,83.2183 636.745,83.22 636.754,83.2216 636.763,83.2233 636.772,83.2249 636.781,83.2266 636.79,83.2282 636.8,83.2299 636.809,83.2315 636.818,83.2332 636.827,83.2349 636.836,83.2365 636.846,83.2382 636.855,83.2398 636.864,83.2415 636.873,83.2432 636.882,83.2448 636.892,83.2465 636.901,83.2482 636.91,83.2498 636.919,83.2515 636.928,83.2532 636.938,83.2548 636.947,83.2565 636.956,83.2582 636.965,83.2599 636.974,83.2615 636.983,83.2632 636.993,83.2649 637.002,83.2666 637.011,83.2682 637.02,83.2699 637.029,83.2716 637.039,83.2733 637.048,83.275 637.057,83.2767 637.066,83.2783 637.075,83.28 637.085,83.2817 637.094,83.2834 637.103,83.2851 637.112,83.2868 637.121,83.2885 637.131,83.2902 637.14,83.2919 637.149,83.2936 637.158,83.2953 637.167,83.297 637.176,83.2987 637.186,83.3004 637.195,83.3021 637.204,83.3038 637.213,83.3055 637.222,83.3072 637.232,83.3089 637.241,83.3106 637.25,83.3123 637.259,83.314 637.268,83.3157 637.278,83.3174 637.287,83.3191 637.296,83.3209 637.305,83.3226 637.314,83.3243 637.323,83.326 637.333,83.3277 637.342,83.3294 637.351,83.3312 637.36,83.3329 637.369,83.3346 637.379,83.3363 637.388,83.338 637.397,83.3398 637.406,83.3415 637.415,83.3432 637.425,83.345 637.434,83.3467 637.443,83.3484 637.452,83.3501 637.461,83.3519 637.471,83.3536 637.48,83.3553 637.489,83.3571 637.498,83.3588 637.507,83.3606 637.516,83.3623 637.526,83.364 637.535,83.3658 637.544,83.3675 637.553,83.3693 637.562,83.371 637.572,83.3728 637.581,83.3745 637.59,83.3763 637.599,83.378 637.608,83.3798 637.618,83.3815 637.627,83.3833 637.636,83.385 637.645,83.3868 637.654,83.3885 637.663,83.3903 637.673,83.392 637.682,83.3938 637.691,83.3956 637.7,83.3973 637.709,83.3991 637.719,83.4008 637.728,83.4026 637.737,83.4044 637.746,83.4061 637.755,83.4079 637.765,83.4097 637.774,83.4115 637.783,83.4132 637.792,83.415 637.801,83.4168 637.811,83.4185 637.82,83.4203 637.829,83.4221 637.838,83.4239 637.847,83.4257 637.856,83.4274 637.866,83.4292 637.875,83.431 637.884,83.4328 637.893,83.4346 637.902,83.4364 637.912,83.4381 637.921,83.4399 637.93,83.4417 637.939,83.4435 637.948,83.4453 637.958,83.4471 637.967,83.4489 637.976,83.4507 637.985,83.4525 637.994,83.4543 638.003,83.4561 638.013,83.4579 638.022,83.4597 638.031,83.4615 638.04,83.4633 638.049,83.4651 638.059,83.4669 638.068,83.4687 638.077,83.4705 638.086,83.4723 638.095,83.4741 638.105,83.4759 638.114,83.4777 638.123,83.4795 638.132,83.4814 638.141,83.4832 638.151,83.485 638.16,83.4868 638.169,83.4886 638.178,83.4904 638.187,83.4923 638.196,83.4941 638.206,83.4959 638.215,83.4977 638.224,83.4996 638.233,83.5014 638.242,83.5032 638.252,83.505 638.261,83.5069 638.27,83.5087 638.279,83.5105 638.288,83.5124 638.298,83.5142 638.307,83.516 638.316,83.5179 638.325,83.5197 638.334,83.5215 638.343,83.5234 638.353,83.5252 638.362,83.5271 638.371,83.5289 638.38,83.5308 638.389,83.5326 638.399,83.5344 638.408,83.5363 638.417,83.5381 638.426,83.54 638.435,83.5418 638.445,83.5437 638.454,83.5456 638.463,83.5474 638.472,83.5493 638.481,83.5511 638.491,83.553 638.5,83.5548 638.509,83.5567 638.518,83.5586 638.527,83.5604 638.536,83.5623 638.546,83.5641 638.555,83.566 638.564,83.5679 638.573,83.5697 638.582,83.5716 638.592,83.5735 638.601,83.5754 638.61,83.5772 638.619,83.5791 638.628,83.581 638.638,83.5829 638.647,83.5847 638.656,83.5866 638.665,83.5885 638.674,83.5904 638.683,83.5923 638.693,83.5941 638.702,83.596 638.711,83.5979 638.72,83.5998 638.729,83.6017 638.739,83.6036 638.748,83.6055 638.757,83.6074 638.766,83.6092 638.775,83.6111 638.785,83.613 638.794,83.6149 638.803,83.6168 638.812,83.6187 638.821,83.6206 638.831,83.6225 638.84,83.6244 638.849,83.6263 638.858,83.6282 638.867,83.6301 638.876,83.632 638.886,83.6339 638.895,83.6359 638.904,83.6378 638.913,83.6397 638.922,83.6416 638.932,83.6435 638.941,83.6454 638.95,83.6473 638.959,83.6492 638.968,83.6512 638.978,83.6531 638.987,83.655 638.996,83.6569 639.005,83.6588 639.014,83.6608 639.023,83.6627 639.033,83.6646 639.042,83.6665 639.051,83.6685 639.06,83.6704 639.069,83.6723 639.079,83.6743 639.088,83.6762 639.097,83.6781 639.106,83.6801 639.115,83.682 639.125,83.6839 639.134,83.6859 639.143,83.6878 639.152,83.6898 639.161,83.6917 639.171,83.6936 639.18,83.6956 639.189,83.6975 639.198,83.6995 639.207,83.7014 639.216,83.7034 639.226,83.7053 639.235,83.7073 639.244,83.7092 639.253,83.7112 639.262,83.7131 639.272,83.7151 639.281,83.7171 639.29,83.719 639.299,83.721 639.308,83.7229 639.318,83.7249 639.327,83.7269 639.336,83.7288 639.345,83.7308 639.354,83.7328 639.363,83.7347 639.373,83.7367 639.382,83.7387 639.391,83.7406 639.4,83.7426 639.409,83.7446 639.419,83.7466 639.428,83.7485 639.437,83.7505 639.446,83.7525 639.455,83.7545 639.465,83.7565 639.474,83.7584 639.483,83.7604 639.492,83.7624 639.501,83.7644 639.511,83.7664 639.52,83.7684 639.529,83.7704 639.538,83.7723 639.547,83.7743 639.556,83.7763 639.566,83.7783 639.575,83.7803 639.584,83.7823 639.593,83.7843 639.602,83.7863 639.612,83.7883 639.621,83.7903 639.63,83.7923 639.639,83.7943 639.648,83.7963 639.658,83.7983 639.667,83.8003 639.676,83.8023 639.685,83.8044 639.694,83.8064 639.704,83.8084 639.713,83.8104 639.722,83.8124 639.731,83.8144 639.74,83.8164 639.749,83.8185 639.759,83.8205 639.768,83.8225 639.777,83.8245 639.786,83.8265 639.795,83.8286 639.805,83.8306 639.814,83.8326 639.823,83.8346 639.832,83.8367 639.841,83.8387 639.851,83.8407 639.86,83.8428 639.869,83.8448 639.878,83.8468 639.887,83.8489 639.896,83.8509 639.906,83.8529 639.915,83.855 639.924,83.857 639.933,83.8591 639.942,83.8611 639.952,83.8632 639.961,83.8652 639.97,83.8672 639.979,83.8693 639.988,83.8713 639.998,83.8734 640.007,83.8754 640.016,83.8775 640.025,83.8796 640.034,83.8816 640.044,83.8837 640.053,83.8857 640.062,83.8878 640.071,83.8898 640.08,83.8919 640.089,83.894 640.099,83.896 640.108,83.8981 640.117,83.9002 640.126,83.9022 640.135,83.9043 640.145,83.9064 640.154,83.9084 640.163,83.9105 640.172,83.9126 640.181,83.9147 640.191,83.9167 640.2,83.9188 640.209,83.9209 640.218,83.923 640.227,83.925 640.236,83.9271 640.246,83.9292 640.255,83.9313 640.264,83.9334 640.273,83.9355 640.282,83.9376 640.292,83.9396 640.301,83.9417 640.31,83.9438 640.319,83.9459 640.328,83.948 640.338,83.9501 640.347,83.9522 640.356,83.9543 640.365,83.9564 640.374,83.9585 640.384,83.9606 640.393,83.9627 640.402,83.9648 640.411,83.9669 640.42,83.969 640.429,83.9711 640.439,83.9732 640.448,83.9754 640.457,83.9775 640.466,83.9796 640.475,83.9817 640.485,83.9838 640.494,83.9859 640.503,83.988 640.512,83.9902 640.521,83.9923 640.531,83.9944 640.54,83.9965 640.549,83.9986 640.558,84.0008 640.567,84.0029 640.576,84.005 640.586,84.0072 640.595,84.0093 640.604,84.0114 640.613,84.0135 640.622,84.0157 640.632,84.0178 640.641,84.0199 640.65,84.0221 640.659,84.0242 640.668,84.0264 640.678,84.0285 640.687,84.0306 640.696,84.0328 640.705,84.0349 640.714,84.0371 640.724,84.0392 640.733,84.0414 640.742,84.0435 640.751,84.0457 640.76,84.0478 640.769,84.05 640.779,84.0521 640.788,84.0543 640.797,84.0565 640.806,84.0586 640.815,84.0608 640.825,84.0629 640.834,84.0651 640.843,84.0673 640.852,84.0694 640.861,84.0716 640.871,84.0738 640.88,84.0759 640.889,84.0781 640.898,84.0803 640.907,84.0824 640.916,84.0846 640.926,84.0868 640.935,84.089 640.944,84.0911 640.953,84.0933 640.962,84.0955 640.972,84.0977 640.981,84.0999 640.99,84.102 640.999,84.1042 641.008,84.1064 641.018,84.1086 641.027,84.1108 641.036,84.113 641.045,84.1152 641.054,84.1174 641.064,84.1196 641.073,84.1218 641.082,84.1239 641.091,84.1261 641.1,84.1283 641.109,84.1305 641.119,84.1327 641.128,84.1349 641.137,84.1372 641.146,84.1394 641.155,84.1416 641.165,84.1438 641.174,84.146 641.183,84.1482 641.192,84.1504 641.201,84.1526 641.211,84.1548 641.22,84.157 641.229,84.1593 641.238,84.1615 641.247,84.1637 641.256,84.1659 641.266,84.1681 641.275,84.1704 641.284,84.1726 641.293,84.1748 641.302,84.177 641.312,84.1793 641.321,84.1815 641.33,84.1837 641.339,84.186 641.348,84.1882 641.358,84.1904 641.367,84.1927 641.376,84.1949 641.385,84.1971 641.394,84.1994 641.404,84.2016 641.413,84.2039 641.422,84.2061 641.431,84.2083 641.44,84.2106 641.449,84.2128 641.459,84.2151 641.468,84.2173 641.477,84.2196 641.486,84.2218 641.495,84.2241 641.505,84.2263 641.514,84.2286 641.523,84.2309 641.532,84.2331 641.541,84.2354 641.551,84.2376 641.56,84.2399 641.569,84.2422 641.578,84.2444 641.587,84.2467 641.596,84.249 641.606,84.2512 641.615,84.2535 641.624,84.2558 641.633,84.258 641.642,84.2603 641.652,84.2626 641.661,84.2649 641.67,84.2671 641.679,84.2694 641.688,84.2717 641.698,84.274 641.707,84.2763 641.716,84.2786 641.725,84.2808 641.734,84.2831 641.744,84.2854 641.753,84.2877 641.762,84.29 641.771,84.2923 641.78,84.2946 641.789,84.2969 641.799,84.2992 641.808,84.3015 641.817,84.3038 641.826,84.3061 641.835,84.3084 641.845,84.3107 641.854,84.313 641.863,84.3153 641.872,84.3176 641.881,84.3199 641.891,84.3222 641.9,84.3245 641.909,84.3268 641.918,84.3291 641.927,84.3315 641.936,84.3338 641.946,84.3361 641.955,84.3384 641.964,84.3407 641.973,84.343 641.982,84.3454 641.992,84.3477 642.001,84.35 642.01,84.3523 642.019,84.3547 642.028,84.357 642.038,84.3593 642.047,84.3617 642.056,84.364 642.065,84.3663 642.074,84.3687 642.084,84.371 642.093,84.3733 642.102,84.3757 642.111,84.378 642.12,84.3804 642.129,84.3827 642.139,84.385 642.148,84.3874 642.157,84.3897 642.166,84.3921 642.175,84.3944 642.185,84.3968 642.194,84.3991 642.203,84.4015 642.212,84.4038 642.221,84.4062 642.231,84.4086 642.24,84.4109 642.249,84.4133 642.258,84.4156 642.267,84.418 642.277,84.4204 642.286,84.4227 642.295,84.4251 642.304,84.4275 642.313,84.4298 642.322,84.4322 642.332,84.4346 642.341,84.4369 642.35,84.4393 642.359,84.4417 642.368,84.4441 642.378,84.4465 642.387,84.4488 642.396,84.4512 642.405,84.4536 642.414,84.456 642.424,84.4584 642.433,84.4608 642.442,84.4631 642.451,84.4655 642.46,84.4679 642.469,84.4703 642.479,84.4727 642.488,84.4751 642.497,84.4775 642.506,84.4799 642.515,84.4823 642.525,84.4847 642.534,84.4871 642.543,84.4895 642.552,84.4919 642.561,84.4943 642.571,84.4967 642.58,84.4991 642.589,84.5015 642.598,84.5039 642.607,84.5064 642.617,84.5088 642.626,84.5112 642.635,84.5136 642.644,84.516 642.653,84.5184 642.662,84.5209 642.672,84.5233 642.681,84.5257 642.69,84.5281 642.699,84.5305 642.708,84.533 642.718,84.5354 642.727,84.5378 642.736,84.5403 642.745,84.5427 642.754,84.5451 642.764,84.5476 642.773,84.55 642.782,84.5524 642.791,84.5549 642.8,84.5573 642.809,84.5598 642.819,84.5622 642.828,84.5646 642.837,84.5671 642.846,84.5695 642.855,84.572 642.865,84.5744 642.874,84.5769 642.883,84.5793 642.892,84.5818 642.901,84.5842 642.911,84.5867 642.92,84.5892 642.929,84.5916 642.938,84.5941 642.947,84.5965 642.957,84.599 642.966,84.6015 642.975,84.6039 642.984,84.6064 642.993,84.6089 643.002,84.6113 643.012,84.6138 643.021,84.6163 643.03,84.6188 643.039,84.6212 643.048,84.6237 643.058,84.6262 643.067,84.6287 643.076,84.6312 643.085,84.6336 643.094,84.6361 643.104,84.6386 643.113,84.6411 643.122,84.6436 643.131,84.6461 643.14,84.6486 643.149,84.6511 643.159,84.6535 643.168,84.656 643.177,84.6585 643.186,84.661 643.195,84.6635 643.205,84.666 643.214,84.6685 643.223,84.671 643.232,84.6735 643.241,84.676 643.251,84.6786 643.26,84.6811 643.269,84.6836 643.278,84.6861 643.287,84.6886 643.297,84.6911 643.306,84.6936 643.315,84.6961 643.324,84.6987 643.333,84.7012 643.342,84.7037 643.352,84.7062 643.361,84.7087 643.37,84.7113 643.379,84.7138 643.388,84.7163 643.398,84.7189 643.407,84.7214 643.416,84.7239 643.425,84.7265 643.434,84.729 643.444,84.7315 643.453,84.7341 643.462,84.7366 643.471,84.7391 643.48,84.7417 643.489,84.7442 643.499,84.7468 643.508,84.7493 643.517,84.7519 643.526,84.7544 643.535,84.757 643.545,84.7595 643.554,84.7621 643.563,84.7646 643.572,84.7672 643.581,84.7697 643.591,84.7723 643.6,84.7748 643.609,84.7774 643.618,84.78 643.627,84.7825 643.637,84.7851 643.646,84.7877 643.655,84.7902 643.664,84.7928 643.673,84.7954 643.682,84.7979 643.692,84.8005 643.701,84.8031 643.71,84.8057 643.719,84.8083 643.728,84.8108 643.738,84.8134 643.747,84.816 643.756,84.8186 643.765,84.8212 643.774,84.8237 643.784,84.8263 643.793,84.8289 643.802,84.8315 643.811,84.8341 643.82,84.8367 643.829,84.8393 643.839,84.8419 643.848,84.8445 643.857,84.8471 643.866,84.8497 643.875,84.8523 643.885,84.8549 643.894,84.8575 643.903,84.8601 643.912,84.8627 643.921,84.8653 643.931,84.8679 643.94,84.8705 643.949,84.8732 643.958,84.8758 643.967,84.8784 643.977,84.881 643.986,84.8836 643.995,84.8862 644.004,84.8889 644.013,84.8915 644.022,84.8941 644.032,84.8967 644.041,84.8994 644.05,84.902 644.059,84.9046 644.068,84.9073 644.078,84.9099 644.087,84.9125 644.096,84.9152 644.105,84.9178 644.114,84.9204 644.124,84.9231 644.133,84.9257 644.142,84.9284 644.151,84.931 644.16,84.9336 644.169,84.9363 644.179,84.9389 644.188,84.9416 644.197,84.9442 644.206,84.9469 644.215,84.9495 644.225,84.9522 644.234,84.9549 644.243,84.9575 644.252,84.9602 644.261,84.9628 644.271,84.9655 644.28,84.9682 644.289,84.9708 644.298,84.9735 644.307,84.9762 644.317,84.9788 644.326,84.9815 644.335,84.9842 644.344,84.9869 644.353,84.9895 644.362,84.9922 644.372,84.9949 644.381,84.9976 644.39,85.0002 644.399,85.0029 644.408,85.0056 644.418,85.0083 644.427,85.011 644.436,85.0137 644.445,85.0164 644.454,85.0191 644.464,85.0218 644.473,85.0244 644.482,85.0271 644.491,85.0298 644.5,85.0325 644.509,85.0352 644.519,85.0379 644.528,85.0406 644.537,85.0433 644.546,85.0461 644.555,85.0488 644.565,85.0515 644.574,85.0542 644.583,85.0569 644.592,85.0596 644.601,85.0623 644.611,85.065 644.62,85.0678 644.629,85.0705 644.638,85.0732 644.647,85.0759 644.657,85.0786 644.666,85.0814 644.675,85.0841 644.684,85.0868 644.693,85.0895 644.702,85.0923 644.712,85.095 644.721,85.0977 644.73,85.1005 644.739,85.1032 644.748,85.1059 644.758,85.1087 644.767,85.1114 644.776,85.1142 644.785,85.1169 644.794,85.1197 644.804,85.1224 644.813,85.1252 644.822,85.1279 644.831,85.1307 644.84,85.1334 644.85,85.1362 644.859,85.1389 644.868,85.1417 644.877,85.1444 644.886,85.1472 644.895,85.15 644.905,85.1527 644.914,85.1555 644.923,85.1582 644.932,85.161 644.941,85.1638 644.951,85.1666 644.96,85.1693 644.969,85.1721 644.978,85.1749 644.987,85.1776 644.997,85.1804 645.006,85.1832 645.015,85.186 645.024,85.1888 645.033,85.1915 645.042,85.1943 645.052,85.1971 645.061,85.1999 645.07,85.2027 645.079,85.2055 645.088,85.2083 645.098,85.2111 645.107,85.2139 645.116,85.2167 645.125,85.2195 645.134,85.2223 645.144,85.2251 645.153,85.2279 645.162,85.2307 645.171,85.2335 645.18,85.2363 645.19,85.2391 645.199,85.2419 645.208,85.2447 645.217,85.2475 645.226,85.2503 645.235,85.2532 645.245,85.256 645.254,85.2588 645.263,85.2616 645.272,85.2644 645.281,85.2673 645.291,85.2701 645.3,85.2729 645.309,85.2757 645.318,85.2786 645.327,85.2814 645.337,85.2842 645.346,85.2871 645.355,85.2899 645.364,85.2927 645.373,85.2956 645.382,85.2984 645.392,85.3013 645.401,85.3041 645.41,85.3069 645.419,85.3098 645.428,85.3126 645.438,85.3155 645.447,85.3183 645.456,85.3212 645.465,85.324 645.474,85.3269 645.484,85.3297 645.493,85.3326 645.502,85.3355 645.511,85.3383 645.52,85.3412 645.53,85.3441 645.539,85.3469 645.548,85.3498 645.557,85.3527 645.566,85.3555 645.575,85.3584 645.585,85.3613 645.594,85.3641 645.603,85.367 645.612,85.3699 645.621,85.3728 645.631,85.3757 645.64,85.3785 645.649,85.3814 645.658,85.3843 645.667,85.3872 645.677,85.3901 645.686,85.393 645.695,85.3959 645.704,85.3987 645.713,85.4016 645.722,85.4045 645.732,85.4074 645.741,85.4103 645.75,85.4132 645.759,85.4161 645.768,85.419 645.778,85.4219 645.787,85.4248 645.796,85.4278 645.805,85.4307 645.814,85.4336 645.824,85.4365 645.833,85.4394 645.842,85.4423 645.851,85.4452 645.86,85.4481 645.87,85.4511 645.879,85.454 645.888,85.4569 645.897,85.4598 645.906,85.4628 645.915,85.4657 645.925,85.4686 645.934,85.4716 645.943,85.4745 645.952,85.4774 645.961,85.4804 645.971,85.4833 645.98,85.4862 645.989,85.4892 645.998,85.4921 646.007,85.495 646.017,85.498 646.026,85.5009 646.035,85.5039 646.044,85.5068 646.053,85.5098 646.062,85.5127 646.072,85.5157 646.081,85.5186 646.09,85.5216 646.099,85.5246 646.108,85.5275 646.118,85.5305 646.127,85.5334 646.136,85.5364 646.145,85.5394 646.154,85.5423 646.164,85.5453 646.173,85.5483 646.182,85.5512 646.191,85.5542 646.2,85.5572 646.21,85.5602 646.219,85.5632 646.228,85.5661 646.237,85.5691 646.246,85.5721 646.255,85.5751 646.265,85.5781 646.274,85.5811 646.283,85.584 646.292,85.587 646.301,85.59 646.311,85.593 646.32,85.596 646.329,85.599 646.338,85.602 646.347,85.605 646.357,85.608 646.366,85.611 646.375,85.614 646.384,85.617 646.393,85.62 646.402,85.623 646.412,85.626 646.421,85.6291 646.43,85.6321 646.439,85.6351 646.448,85.6381 646.458,85.6411 646.467,85.6441 646.476,85.6472 646.485,85.6502 646.494,85.6532 646.504,85.6562 646.513,85.6593 646.522,85.6623 646.531,85.6653 646.54,85.6684 646.55,85.6714 646.559,85.6744 646.568,85.6775 646.577,85.6805 646.586,85.6835 646.595,85.6866 646.605,85.6896 646.614,85.6927 646.623,85.6957 646.632,85.6988 646.641,85.7018 646.651,85.7049 646.66,85.7079 646.669,85.711 646.678,85.714 646.687,85.7171 646.697,85.7201 646.706,85.7232 646.715,85.7263 646.724,85.7293 646.733,85.7324 646.742,85.7355 646.752,85.7385 646.761,85.7416 646.77,85.7447 646.779,85.7478 646.788,85.7508 646.798,85.7539 646.807,85.757 646.816,85.7601 646.825,85.7631 646.834,85.7662 646.844,85.7693 646.853,85.7724 646.862,85.7755 646.871,85.7786 646.88,85.7817 646.89,85.7848 646.899,85.7878 646.908,85.7909 646.917,85.794 646.926,85.7971 646.935,85.8002 646.945,85.8033 646.954,85.8064 646.963,85.8095 646.972,85.8127 646.981,85.8158 646.991,85.8189 647,85.822 647.009,85.8251 647.018,85.8282 647.027,85.8313 647.037,85.8344 647.046,85.8376 647.055,85.8407 647.064,85.8438 647.073,85.8469 647.083,85.8501 647.092,85.8532 647.101,85.8563 647.11,85.8594 647.119,85.8626 647.128,85.8657 647.138,85.8688 647.147,85.872 647.156,85.8751 647.165,85.8783 647.174,85.8814 647.184,85.8845 647.193,85.8877 647.202,85.8908 647.211,85.894 647.22,85.8971 647.23,85.9003 647.239,85.9034 647.248,85.9066 647.257,85.9097 647.266,85.9129 647.275,85.9161 647.285,85.9192 647.294,85.9224 647.303,85.9256 647.312,85.9287 647.321,85.9319 647.331,85.9351 647.34,85.9382 647.349,85.9414 647.358,85.9446 647.367,85.9477 647.377,85.9509 647.386,85.9541 647.395,85.9573 647.404,85.9605 647.413,85.9636 647.423,85.9668 647.432,85.97 647.441,85.9732 647.45,85.9764 647.459,85.9796 647.468,85.9828 647.478,85.986 647.487,85.9892 647.496,85.9924 647.505,85.9956 647.514,85.9988 647.524,86.002 647.533,86.0052 647.542,86.0084 647.551,86.0116 647.56,86.0148 647.57,86.018 647.579,86.0212 647.588,86.0244 647.597,86.0277 647.606,86.0309 647.615,86.0341 647.625,86.0373 647.634,86.0405 647.643,86.0438 647.652,86.047 647.661,86.0502 647.671,86.0534 647.68,86.0567 647.689,86.0599 647.698,86.0631 647.707,86.0664 647.717,86.0696 647.726,86.0729 647.735,86.0761 647.744,86.0793 647.753,86.0826 647.763,86.0858 647.772,86.0891 647.781,86.0923 647.79,86.0956 647.799,86.0988 647.808,86.1021 647.818,86.1053 647.827,86.1086 647.836,86.1118 647.845,86.1151 647.854,86.1184 647.864,86.1216 647.873,86.1249 647.882,86.1282 647.891,86.1314 647.9,86.1347 647.91,86.138 647.919,86.1412 647.928,86.1445 647.937,86.1478 647.946,86.1511 647.955,86.1544 647.965,86.1576 647.974,86.1609 647.983,86.1642 647.992,86.1675 648.001,86.1708 648.011,86.1741 648.02,86.1774 648.029,86.1807 648.038,86.1839 648.047,86.1872 648.057,86.1905 648.066,86.1938 648.075,86.1971 648.084,86.2004 648.093,86.2038 648.103,86.2071 648.112,86.2104 648.121,86.2137 648.13,86.217 648.139,86.2203 648.148,86.2236 648.158,86.2269 648.167,86.2303 648.176,86.2336 648.185,86.2369 648.194,86.2402 648.204,86.2435 648.213,86.2469 648.222,86.2502 648.231,86.2535 648.24,86.2569 648.25,86.2602 648.259,86.2635 648.268,86.2669 648.277,86.2702 648.286,86.2735 648.295,86.2769 648.305,86.2802 648.314,86.2836 648.323,86.2869 648.332,86.2903 648.341,86.2936 648.351,86.297 648.36,86.3003 648.369,86.3037 648.378,86.307 648.387,86.3104 648.397,86.3137 648.406,86.3171 648.415,86.3205 648.424,86.3238 648.433,86.3272 648.443,86.3306 648.452,86.3339 648.461,86.3373 648.47,86.3407 648.479,86.3441 648.488,86.3474 648.498,86.3508 648.507,86.3542 648.516,86.3576 648.525,86.361 648.534,86.3643 648.544,86.3677 648.553,86.3711 648.562,86.3745 648.571,86.3779 648.58,86.3813 648.59,86.3847 648.599,86.3881 648.608,86.3915 648.617,86.3949 648.626,86.3983 648.635,86.4017 648.645,86.4051 648.654,86.4085 648.663,86.4119 648.672,86.4153 648.681,86.4187 648.691,86.4221 648.7,86.4255 648.709,86.4289 648.718,86.4323 648.727,86.4357 648.737,86.4391 648.746,86.4425 648.755,86.4459 648.764,86.4493 648.773,86.4527 648.783,86.4562 648.792,86.4596 648.801,86.463 648.81,86.4664 648.819,86.4698 648.828,86.4732 648.838,86.4766 648.847,86.48 648.856,86.4834 648.865,86.4868 648.874,86.4902 648.884,86.4936 648.893,86.497 648.902,86.5004 648.911,86.5038 648.92,86.5072 648.93,86.5106 648.939,86.514 648.948,86.5174 648.957,86.5208 648.966,86.5242 648.975,86.5276 648.985,86.531 648.994,86.5344 649.003,86.5378 649.012,86.5412 649.021,86.5446 649.031,86.548 649.04,86.5514 649.049,86.5548 649.058,86.5582 649.067,86.5616 649.077,86.565 649.086,86.5684 649.095,86.5718 649.104,86.5752 649.113,86.5787 649.123,86.5821 649.132,86.5855 649.141,86.5889 649.15,86.5923 649.159,86.5957 649.168,86.5991 649.178,86.6025 649.187,86.6059 649.196,86.6093 649.205,86.6127 649.214,86.6161 649.224,86.6195 649.233,86.6229 649.242,86.6263 649.251,86.6297 649.26,86.6331 649.27,86.6365 649.279,86.6399 649.288,86.6433 649.297,86.6467 649.306,86.6501 649.315,86.6535 649.325,86.6569 649.334,86.6603 649.343,86.6637 649.352,86.6671 649.361,86.6705 649.371,86.6739 649.38,86.6773 649.389,86.6807 649.398,86.6841 649.407,86.6875 649.417,86.6909 649.426,86.6943 649.435,86.6977 649.444,86.7011 649.453,86.7045 649.463,86.7079 649.472,86.7113 649.481,86.7147 649.49,86.7181 649.499,86.7215 649.508,86.7249 649.518,86.7283 649.527,86.7317 649.536,86.7351 649.545,86.7385 649.554,86.7419 649.564,86.7453 649.573,86.7487 649.582,86.7521 649.591,86.7555 649.6,86.7589 649.61,86.7623 649.619,86.7657 649.628,86.7691 649.637,86.7725 649.646,86.7759 649.656,86.7793 649.665,86.7827 649.674,86.7861 649.683,86.7895 649.692,86.7929 649.701,86.7963 649.711,86.7998 649.72,86.8032 649.729,86.8066 649.738,86.81 649.747,86.8134 649.757,86.8168 649.766,86.8202 649.775,86.8236 649.784,86.827 649.793,86.8304 649.803,86.8338 649.812,86.8372 649.821,86.8406 649.83,86.844 649.839,86.8474 649.848,86.8508 649.858,86.8542 649.867,86.8576 649.876,86.861 649.885,86.8644 649.894,86.8678 649.904,86.8712 649.913,86.8746 649.922,86.878 649.931,86.8814 649.94,86.8848 649.95,86.8882 649.959,86.8916 649.968,86.895 649.977,86.8984 649.986,86.9018 649.996,86.9052 650.005,86.9086 650.014,86.912 650.023,86.9154 650.032,86.9188 650.041,86.9222 650.051,86.9256 650.06,86.929 650.069,86.9324 650.078,86.9358 650.087,86.9392 650.097,86.9426 650.106,86.946 650.115,86.9494 650.124,86.9528 650.133,86.9562 650.143,86.9596 650.152,86.963 650.161,86.9664 650.17,86.9698 650.179,86.9732 650.188,86.9766 650.198,86.98 650.207,86.9834 650.216,86.9868 650.225,86.9901 650.234,86.9935 650.244,86.9969 650.253,87.0003 650.262,87.0037 650.271,87.0071 650.28,87.0105 650.29,87.0139 650.299,87.0173 650.308,87.0207 650.317,87.0241 650.326,87.0275 650.336,87.0309 650.345,87.0343 650.354,87.0377 650.363,87.0411 650.372,87.0445 650.381,87.0479 650.391,87.0513 650.4,87.0547 650.409,87.0581 650.418,87.0615 650.427,87.0649 650.437,87.0683 650.446,87.0717 650.455,87.0751 650.464,87.0785 650.473,87.0819 650.483,87.0853 650.492,87.0887 650.501,87.0921 650.51,87.0955 650.519,87.0989 650.528,87.1023 650.538,87.1057 650.547,87.1091 650.556,87.1125 650.565,87.1159 650.574,87.1193 650.584,87.1227 650.593,87.1261 650.602,87.1295 650.611,87.1329 650.62,87.1363 650.63,87.1397 650.639,87.1431 650.648,87.1465 650.657,87.1499 650.666,87.1533 650.676,87.1567 650.685,87.1601 650.694,87.1635 650.703,87.1669 650.712,87.1703 650.721,87.1737 650.731,87.1771 650.74,87.1805 650.749,87.1839 650.758,87.1873 650.767,87.1907 650.777,87.1941 650.786,87.1975 650.795,87.2009 650.804,87.2043 650.813,87.2077 650.823,87.211 650.832,87.2144 650.841,87.2178 650.85,87.2212 650.859,87.2246 650.868,87.228 650.878,87.2314 650.887,87.2348 650.896,87.2382 650.905,87.2416 650.914,87.245 650.924,87.2484 650.933,87.2518 650.942,87.2552 650.951,87.2586 650.96,87.262 650.97,87.2654 650.979,87.2688 650.988,87.2722 650.997,87.2756 651.006,87.279 651.016,87.2824 651.025,87.2858 651.034,87.2892 651.043,87.2926 651.052,87.296 651.061,87.2994 651.071,87.3028 651.08,87.3062 651.089,87.3096 651.098,87.313 651.107,87.3164 651.117,87.3198 651.126,87.3232 651.135,87.3266 651.144,87.33 651.153,87.3333 651.163,87.3367 651.172,87.3401 651.181,87.3435 651.19,87.3469 651.199,87.3503 651.208,87.3537 651.218,87.3571 651.227,87.3605 651.236,87.3639 651.245,87.3673 651.254,87.3707 651.264,87.3741 651.273,87.3775 651.282,87.3809 651.291,87.3843 651.3,87.3877 651.31,87.3911 651.319,87.3945 651.328,87.3979 651.337,87.4013 651.346,87.4047 651.356,87.4081 651.365,87.4115 651.374,87.4149 651.383,87.4183 651.392,87.4217 651.401,87.425 651.411,87.4284 651.42,87.4318 651.429,87.4352 651.438,87.4386 651.447,87.442 651.457,87.4454 651.466,87.4488 651.475,87.4522 651.484,87.4556 651.493,87.459 651.503,87.4624 651.512,87.4658 651.521,87.4692 651.53,87.4726 651.539,87.476 651.548,87.4794 651.558,87.4828 651.567,87.4862 651.576,87.4896 651.585,87.493 651.594,87.4964 651.604,87.4998 651.613,87.5032 651.622,87.5065 651.631,87.5099 651.64,87.5133 651.65,87.5167 651.659,87.5201 651.668,87.5235 651.677,87.5269 651.686,87.5303 651.696,87.5337 651.705,87.5371 651.714,87.5405 651.723,87.5439 651.732,87.5473 651.741,87.5507 651.751,87.5541 651.76,87.5575 651.769,87.5609 651.778,87.5643 651.787,87.5677 651.797,87.5711 651.806,87.5744 651.815,87.5778 651.824,87.5812 651.833,87.5846 651.843,87.588 651.852,87.5914 651.861,87.5948 651.87,87.5982 651.879,87.6016 651.888,87.605 651.898,87.6084 651.907,87.6118 651.916,87.6152 651.925,87.6186 651.934,87.622 651.944,87.6254 651.953,87.6288 651.962,87.6322 651.971,87.6356 651.98,87.6389 651.99,87.6423 651.999,87.6457 652.008,87.6491 652.017,87.6525 652.026,87.6559 652.036,87.6593 652.045,87.6627 652.054,87.6661 652.063,87.6695 652.072,87.6729 652.081,87.6763 652.091,87.6797 652.1,87.6831 652.109,87.6865 652.118,87.6899 652.127,87.6933 652.137,87.6966 652.146,87.7 652.155,87.7034 652.164,87.7068 652.173,87.7102 652.183,87.7136 652.192,87.717 652.201,87.7204 652.21,87.7238 652.219,87.7272 652.229,87.7306 652.238,87.734 652.247,87.7374 652.256,87.7408 652.265,87.7442 652.274,87.7476 652.284,87.751 652.293,87.7543 652.302,87.7577 652.311,87.7611 652.32,87.7645 652.33,87.7679 652.339,87.7713 652.348,87.7747 652.357,87.7781 652.366,87.7815 652.376,87.7849 652.385,87.7883 652.394,87.7917 652.403,87.7951 652.412,87.7985 652.421,87.8019 652.431,87.8052 652.44,87.8086 652.449,87.812 652.458,87.8154 652.467,87.8188 652.477,87.8222 652.486,87.8256 652.495,87.829 652.504,87.8324 652.513,87.8358 652.523,87.8392 652.532,87.8426 652.541,87.846 652.55,87.8494 652.559,87.8527 652.569,87.8561 652.578,87.8595 652.587,87.8629 652.596,87.8663 652.605,87.8697 652.614,87.8731 652.624,87.8765 652.633,87.8799 652.642,87.8833 652.651,87.8867 652.66,87.8901 652.67,87.8935 652.679,87.8969 652.688,87.9002 652.697,87.9036 652.706,87.907 652.716,87.9104 652.725,87.9138 652.734,87.9172 652.743,87.9206 652.752,87.924 652.761,87.9274 652.771,87.9308 652.78,87.9342 652.789,87.9376 652.798,87.941 652.807,87.9443 652.817,87.9477 652.826,87.9511 652.835,87.9545 652.844,87.9579 652.853,87.9613 652.863,87.9647 652.872,87.9681 652.881,87.9715 652.89,87.9749 652.899,87.9783 652.909,87.9817 652.918,87.985 652.927,87.9884 652.936,87.9918 652.945,87.9952 652.954,87.9986 652.964,88.002 652.973,88.0054 652.982,88.0088 652.991,88.0122 653,88.0156 653.01,88.019 653.019,88.0224 653.028,88.0257 653.037,88.0291 653.046,88.0325 653.056,88.0359 653.065,88.0393 653.074,88.0427 653.083,88.0461 653.092,88.0495 653.101,88.0529 653.111,88.0563 653.12,88.0597 653.129,88.0631 653.138,88.0664 653.147,88.0698 653.157,88.0732 653.166,88.0766 653.175,88.08 653.184,88.0834 653.193,88.0868 653.203,88.0902 653.212,88.0936 653.221,88.097 653.23,88.1004 653.239,88.1037 653.249,88.1071 653.258,88.1105 653.267,88.1139 653.276,88.1173 653.285,88.1207 653.294,88.1241 653.304,88.1275 653.313,88.1309 653.322,88.1343 653.331,88.1377 653.34,88.141 653.35,88.1444 653.359,88.1478 653.368,88.1512 653.377,88.1546 653.386,88.158 653.396,88.1614 653.405,88.1648 653.414,88.1682 653.423,88.1716 653.432,88.175 653.441,88.1783 653.451,88.1817 653.46,88.1851 653.469,88.1885 653.478,88.1919 653.487,88.1953 653.497,88.1987 653.506,88.2021 653.515,88.2055 653.524,88.2089 653.533,88.2122 653.543,88.2156 653.552,88.219 653.561,88.2224 653.57,88.2258 653.579,88.2292 653.589,88.2326 653.598,88.236 653.607,88.2394 653.616,88.2428 653.625,88.2461 653.634,88.2495 653.644,88.2529 653.653,88.2563 653.662,88.2597 653.671,88.2631 653.68,88.2665 653.69,88.2699 653.699,88.2733 653.708,88.2767 653.717,88.28 653.726,88.2834 653.736,88.2868 653.745,88.2902 653.754,88.2936 653.763,88.297 653.772,88.3004 653.781,88.3038 653.791,88.3072 653.8,88.3105 653.809,88.3139 653.818,88.3173 653.827,88.3207 653.837,88.3241 653.846,88.3275 653.855,88.3309 653.864,88.3343 653.873,88.3377 653.883,88.3411 653.892,88.3444 653.901,88.3478 653.91,88.3512 653.919,88.3546 653.929,88.358 653.938,88.3614 653.947,88.3648 653.956,88.3682 653.965,88.3716 653.974,88.3749 653.984,88.3783 653.993,88.3817 654.002,88.3851 654.011,88.3885 654.02,88.3919 654.03,88.3953 654.039,88.3987 654.048,88.4021 654.057,88.4054 654.066,88.4088 654.076,88.4122 654.085,88.4156 654.094,88.419 654.103,88.4224 654.112,88.4258 654.121,88.4292 654.131,88.4325 654.14,88.4359 654.149,88.4393 654.158,88.4427 654.167,88.4461 654.177,88.4495 654.186,88.4529 654.195,88.4563 654.204,88.4597 654.213,88.463 654.223,88.4664 654.232,88.4698 654.241,88.4732 654.25,88.4766 654.259,88.48 654.269,88.4834 654.278,88.4868 654.287,88.4902 654.296,88.4935 654.305,88.4969 654.314,88.5003 654.324,88.5037 654.333,88.5071 654.342,88.5105 654.351,88.5139 654.36,88.5173 654.37,88.5206 654.379,88.524 654.388,88.5274 654.397,88.5308 654.406,88.5342 654.416,88.5376 654.425,88.541 654.434,88.5444 654.443,88.5477 654.452,88.5511 654.462,88.5545 654.471,88.5579 654.48,88.5613 654.489,88.5647 654.498,88.5681 654.507,88.5715 654.517,88.5748 654.526,88.5782 654.535,88.5816 654.544,88.585 654.553,88.5884 654.563,88.5918 654.572,88.5952 654.581,88.5986 654.59,88.6019 654.599,88.6053 654.609,88.6087 654.618,88.6121 654.627,88.6155 654.636,88.6189 654.645,88.6223 654.654,88.6257 654.664,88.629 654.673,88.6324 654.682,88.6358 654.691,88.6392 654.7,88.6426 654.71,88.646 654.719,88.6494 654.728,88.6527 654.737,88.6561 654.746,88.6595 654.756,88.6629 654.765,88.6663 654.774,88.6697 654.783,88.6731 654.792,88.6765 654.802,88.6798 654.811,88.6832 654.82,88.6866 654.829,88.69 654.838,88.6934 654.847,88.6968 654.857,88.7002 654.866,88.7035 654.875,88.7069 654.884,88.7103 654.893,88.7137 654.903,88.7171 654.912,88.7205 654.921,88.7239 654.93,88.7273 654.939,88.7306 654.949,88.734 654.958,88.7374 654.967,88.7408 654.976,88.7442 654.985,88.7476 654.994,88.751 655.004,88.7543 655.013,88.7577 655.022,88.7611 655.031,88.7645 655.04,88.7679 655.05,88.7713 655.059,88.7747 655.068,88.778 655.077,88.7814 655.086,88.7848 655.096,88.7882 655.105,88.7916 655.114,88.795 655.123,88.7984 655.132,88.8017 655.142,88.8051 655.151,88.8085 655.16,88.8119 655.169,88.8153 655.178,88.8187 655.187,88.8221 655.197,88.8254 655.206,88.8288 655.215,88.8322 655.224,88.8356 655.233,88.839 655.243,88.8424 655.252,88.8458 655.261,88.8491 655.27,88.8525 655.279,88.8559 655.289,88.8593 655.298,88.8627 655.307,88.8661 655.316,88.8695 655.325,88.8728 655.334,88.8762 655.344,88.8796 655.353,88.883 655.362,88.8864 655.371,88.8898 655.38,88.8932 655.39,88.8965 655.399,88.8999 655.408,88.9033 655.417,88.9067 655.426,88.9101 655.436,88.9135 655.445,88.9168 655.454,88.9202 655.463,88.9236 655.472,88.927 655.482,88.9304 655.491,88.9338 655.5,88.9372 655.509,88.9405 655.518,88.9439 655.527,88.9473 655.537,88.9507 655.546,88.9541 655.555,88.9575 655.564,88.9608 655.573,88.9642 655.583,88.9676 655.592,88.971 655.601,88.9744 655.61,88.9778 655.619,88.9812 655.629,88.9845 655.638,88.9879 655.647,88.9913 655.656,88.9947 655.665,88.9981 655.674,89.0015 655.684,89.0048 655.693,89.0082 655.702,89.0116 655.711,89.015 655.72,89.0184 655.73,89.0218 655.739,89.0251 655.748,89.0285 655.757,89.0319 655.766,89.0353 655.776,89.0387 655.785,89.0421 655.794,89.0455 655.803,89.0488 655.812,89.0522 655.822,89.0556 655.831,89.059 655.84,89.0624 655.849,89.0658 655.858,89.0691 655.867,89.0725 655.877,89.0759 655.886,89.0793 655.895,89.0827 655.904,89.0861 655.913,89.0894 655.923,89.0928 655.932,89.0962 655.941,89.0996 655.95,89.103 655.959,89.1064 655.969,89.1097 655.978,89.1131 655.987,89.1165 655.996,89.1199 656.005,89.1233 656.014,89.1267 656.024,89.13 656.033,89.1334 656.042,89.1368 656.051,89.1402 656.06,89.1436 656.07,89.147 656.079,89.1503 656.088,89.1537 656.097,89.1571 656.106,89.1605 656.116,89.1639 656.125,89.1673 656.134,89.1706 656.143,89.174 656.152,89.1774 656.162,89.1808 656.171,89.1842 656.18,89.1876 656.189,89.1909 656.198,89.1943 656.207,89.1977 656.217,89.2011 656.226,89.2045 656.235,89.2079 656.244,89.2112 656.253,89.2146 656.263,89.218 656.272,89.2214 656.281,89.2248 656.29,89.2281 656.299,89.2315 656.309,89.2349 656.318,89.2383 656.327,89.2417 656.336,89.2451 656.345,89.2484 656.354,89.2518 656.364,89.2552 656.373,89.2586 656.382,89.262 656.391,89.2654 656.4,89.2687 656.41,89.2721 656.419,89.2755 656.428,89.2789 656.437,89.2823 656.446,89.2856 656.456,89.289 656.465,89.2924 656.474,89.2958 656.483,89.2992 656.492,89.3026 656.502,89.3059 656.511,89.3093 656.52,89.3127 656.529,89.3161 656.538,89.3195 656.547,89.3228 656.557,89.3262 656.566,89.3296 656.575,89.333 656.584,89.3364 656.593,89.3398 656.603,89.3431 656.612,89.3465 656.621,89.3499 656.63,89.3533 656.639,89.3567 656.649,89.36 656.658,89.3634 656.667,89.3668 656.676,89.3702 656.685,89.3736 656.694,89.377 656.704,89.3803 656.713,89.3837 656.722,89.3871 656.731,89.3905 656.74,89.3939 656.75,89.3972 656.759,89.4006 656.768,89.404 656.777,89.4074 656.786,89.4108 656.796,89.4141 656.805,89.4175 656.814,89.4209 656.823,89.4243 656.832,89.4277 656.842,89.4311 656.851,89.4344 656.86,89.4378 656.869,89.4412 656.878,89.4446 656.887,89.448 656.897,89.4513 656.906,89.4547 656.915,89.4581 656.924,89.4615 656.933,89.4649 656.943,89.4682 656.952,89.4716 656.961,89.475 656.97,89.4784 656.979,89.4818 656.989,89.4851 656.998,89.4885 657.007,89.4919 657.016,89.4953 657.025,89.4987 657.035,89.5021 657.044,89.5054 657.053,89.5088 657.062,89.5122 657.071,89.5156 657.08,89.519 657.09,89.5223 657.099,89.5257 657.108,89.5291 657.117,89.5325 657.126,89.5359 657.136,89.5392 657.145,89.5426 657.154,89.546 657.163,89.5494 657.172,89.5528 657.182,89.5561 657.191,89.5595 657.2,89.5629 657.209,89.5663 657.218,89.5697 657.227,89.573 657.237,89.5764 657.246,89.5798 657.255,89.5832 657.264,89.5866 657.273,89.5899 657.283,89.5933 657.292,89.5967 657.301,89.6001 657.31,89.6035 657.319,89.6068 657.329,89.6102 657.338,89.6136 657.347,89.617 657.356,89.6204 657.365,89.6237 657.375,89.6271 657.384,89.6305 657.393,89.6339 657.402,89.6373 657.411,89.6406 657.42,89.644 657.43,89.6474 657.439,89.6508 657.448,89.6541 657.457,89.6575 657.466,89.6609 657.476,89.6643 657.485,89.6677 657.494,89.671 657.503,89.6744 657.512,89.6778 657.522,89.6812 657.531,89.6846 657.54,89.6879 657.549,89.6913 657.558,89.6947 657.567,89.6981 657.577,89.7015 657.586,89.7048 657.595,89.7082 657.604,89.7116 657.613,89.715 657.623,89.7184 657.632,89.7217 657.641,89.7251 657.65,89.7285 657.659,89.7319 657.669,89.7352 657.678,89.7386 657.687,89.742 657.696,89.7454 657.705,89.7488 657.715,89.7521 657.724,89.7555 657.733,89.7589 657.742,89.7623 657.751,89.7657 657.76,89.769 657.77,89.7724 657.779,89.7758 657.788,89.7792 657.797,89.7825 657.806,89.7859 657.816,89.7893 657.825,89.7927 657.834,89.7961 657.843,89.7994 657.852,89.8028 657.862,89.8062 657.871,89.8096 657.88,89.813 657.889,89.8163 657.898,89.8197 657.907,89.8231 657.917,89.8265 657.926,89.8298 657.935,89.8332 657.944,89.8366 657.953,89.84 657.963,89.8434 657.972,89.8467 657.981,89.8501 657.99,89.8535 657.999,89.8569 658.009,89.8602 658.018,89.8636 658.027,89.867 658.036,89.8704 658.045,89.8738 658.055,89.8771 658.064,89.8805 658.073,89.8839 658.082,89.8873 658.091,89.8906 658.1,89.894 658.11,89.8974 658.119,89.9008 658.128,89.9042 658.137,89.9075 658.146,89.9109 658.156,89.9143 658.165,89.9177 658.174,89.921 658.183,89.9244 658.192,89.9278 658.202,89.9312 658.211,89.9345 658.22,89.9379 658.229,89.9413 658.238,89.9447 658.247,89.9481 658.257,89.9514 658.266,89.9548 658.275,89.9582 658.284,89.9616 658.293,89.9649 658.303,89.9683 658.312,89.9717 658.321,89.9751 658.33,89.9785 658.339,89.9818 658.349,89.9852 658.358,89.9886 658.367,89.992 658.376,89.9953 658.385,89.9987 658.395,90.0021 658.404,90.0055 658.413,90.0088 658.422,90.0122 658.431,90.0156 658.44,90.019 658.45,90.0223 658.459,90.0257 658.468,90.0291 658.477,90.0325 658.486,90.0359 658.496,90.0392 658.505,90.0426 658.514,90.046 658.523,90.0494 658.532,90.0527 658.542,90.0561 658.551,90.0595 658.56,90.0629 658.569,90.0662 658.578,90.0696 658.587,90.073 658.597,90.0764 658.606,90.0797 658.615,90.0831 658.624,90.0865 658.633,90.0899 658.643,90.0933 658.652,90.0966 658.661,90.1 658.67,90.1034 658.679,90.1068 658.689,90.1101 658.698,90.1135 658.707,90.1169 658.716,90.1203 658.725,90.1236 658.735,90.127 658.744,90.1304 658.753,90.1338 658.762,90.1371 658.771,90.1405 658.78,90.1439 658.79,90.1473 658.799,90.1506 658.808,90.154 658.817,90.1574 658.826,90.1608 658.836,90.1641 658.845,90.1675 658.854,90.1709 658.863,90.1743 658.872,90.1776 658.882,90.181 658.891,90.1844 658.9,90.1878 658.909,90.1911 658.918,90.1945 658.927,90.1979 658.937,90.2013 658.946,90.2046 658.955,90.208 658.964,90.2114 658.973,90.2148 658.983,90.2182 658.992,90.2215 659.001,90.2249 659.01,90.2283 659.019,90.2317 659.029,90.235 659.038,90.2384 659.047,90.2418 659.056,90.2452 659.065,90.2485 659.075,90.2519 659.084,90.2553 659.093,90.2587 659.102,90.262 659.111,90.2654 659.12,90.2688 659.13,90.2721 659.139,90.2755 659.148,90.2789 659.157,90.2823 659.166,90.2856 659.176,90.289 659.185,90.2924 659.194,90.2958 659.203,90.2991 659.212,90.3025 659.222,90.3059 659.231,90.3093 659.24,90.3126 659.249,90.316 659.258,90.3194 659.267,90.3228 659.277,90.3261 659.286,90.3295 659.295,90.3329 659.304,90.3363 659.313,90.3396 659.323,90.343 659.332,90.3464 659.341,90.3498 659.35,90.3531 659.359,90.3565 659.369,90.3599 659.378,90.3633 659.387,90.3666 659.396,90.37 659.405,90.3734 659.415,90.3768 659.424,90.3801 659.433,90.3835 659.442,90.3869 659.451,90.3902 659.46,90.3936 659.47,90.397 659.479,90.4004 659.488,90.4037 659.497,90.4071 659.506,90.4105 659.516,90.4139 659.525,90.4172 659.534,90.4206 659.543,90.424 659.552,90.4274 659.562,90.4307 659.571,90.4341 659.58,90.4375 659.589,90.4409 659.598,90.4442 659.608,90.4476 659.617,90.451 659.626,90.4543 659.635,90.4577 659.644,90.4611 659.653,90.4645 659.663,90.4678 659.672,90.4712 659.681,90.4746 659.69,90.478 659.699,90.4813 659.709,90.4847 659.718,90.4881 659.727,90.4915 659.736,90.4948 659.745,90.4982 659.755,90.5016 659.764,90.5049 659.773,90.5083 659.782,90.5117 659.791,90.5151 659.8,90.5184 659.81,90.5218 659.819,90.5252 659.828,90.5286 659.837,90.5319 659.846,90.5353 659.856,90.5387 659.865,90.542 659.874,90.5454 659.883,90.5488 659.892,90.5522 659.902,90.5555 659.911,90.5589 659.92,90.5623 659.929,90.5657 659.938,90.569 659.948,90.5724 659.957,90.5758 659.966,90.5791 659.975,90.5825 659.984,90.5859 659.993,90.5893 660.003,90.5926 660.012,90.596 660.021,90.5994 660.03,90.6028 660.039,90.6061 660.049,90.6095 660.058,90.6129 660.067,90.6162 660.076,90.6196 660.085,90.623 660.095,90.6264 660.104,90.6297 660.113,90.6331 660.122,90.6365 660.131,90.6398 660.14,90.6432 660.15,90.6466 660.159,90.65 660.168,90.6533 660.177,90.6567 660.186,90.6601 660.196,90.6635 660.205,90.6668 660.214,90.6702 660.223,90.6736 660.232,90.6769 660.242,90.6803 660.251,90.6837 660.26,90.6871 660.269,90.6904 660.278,90.6938 660.288,90.6972 660.297,90.7005 660.306,90.7039 660.315,90.7073 660.324,90.7107 660.333,90.714 660.343,90.7174 660.352,90.7208 660.361,90.7241 660.37,90.7275 660.379,90.7309 660.389,90.7343 660.398,90.7376 660.407,90.741 660.416,90.7444 660.425,90.7477 660.435,90.7511 660.444,90.7545 660.453,90.7579 660.462,90.7612 660.471,90.7646 660.48,90.768 660.49,90.7713 660.499,90.7747 660.508,90.7781 660.517,90.7814 660.526,90.7848 660.536,90.7882 660.545,90.7916 660.554,90.7949 660.563,90.7983 660.572,90.8017 660.582,90.805 660.591,90.8084 660.6,90.8118 660.609,90.8152 660.618,90.8185 660.628,90.8219 660.637,90.8253 660.646,90.8286 660.655,90.832 660.664,90.8354 660.673,90.8388 660.683,90.8421 660.692,90.8455 660.701,90.8489 660.71,90.8522 660.719,90.8556 660.729,90.859 660.738,90.8623 660.747,90.8657 660.756,90.8691 660.765,90.8725 660.775,90.8758 660.784,90.8792 660.793,90.8826 660.802,90.8859 660.811,90.8893 660.82,90.8927 660.83,90.896 660.839,90.8994 660.848,90.9028 660.857,90.9062 660.866,90.9095 660.876,90.9129 660.885,90.9163 660.894,90.9196 660.903,90.923 660.912,90.9264 660.922,90.9297 660.931,90.9331 660.94,90.9365 660.949,90.9399 660.958,90.9432 660.968,90.9466 660.977,90.95 660.986,90.9533 660.995,90.9567 661.004,90.9601 661.013,90.9634 661.023,90.9668 661.032,90.9702 661.041,90.9736 661.05,90.9769 661.059,90.9803 661.069,90.9837 661.078,90.987 661.087,90.9904 661.096,90.9938 661.105,90.9971 661.115,91.0005 661.124,91.0039 661.133,91.0072 661.142,91.0106 661.151,91.014 661.16,91.0174 661.17,91.0207 661.179,91.0241 661.188,91.0275 661.197,91.0308 661.206,91.0342 661.216,91.0376 661.225,91.0409 661.234,91.0443 661.243,91.0477 661.252,91.051 661.262,91.0544 661.271,91.0578 661.28,91.0612 661.289,91.0645 661.298,91.0679 661.308,91.0713 661.317,91.0746 661.326,91.078 661.335,91.0814 661.344,91.0847 661.353,91.0881 661.363,91.0915 661.372,91.0948 661.381,91.0982 661.39,91.1016 661.399,91.1049 661.409,91.1083 661.418,91.1117 661.427,91.115 661.436,91.1184 661.445,91.1218 661.455,91.1252 661.464,91.1285 661.473,91.1319 661.482,91.1353 661.491,91.1386 661.5,91.142 661.51,91.1454 661.519,91.1487 661.528,91.1521 661.537,91.1555 661.546,91.1588 661.556,91.1622 661.565,91.1656 661.574,91.1689 661.583,91.1723 661.592,91.1757 661.602,91.179 661.611,91.1824 661.62,91.1858 661.629,91.1891 661.638,91.1925 661.648,91.1959 661.657,91.1993 661.666,91.2026 661.675,91.206 661.684,91.2094 661.693,91.2127 661.703,91.2161 661.712,91.2195 661.721,91.2228 661.73,91.2262 661.739,91.2296 661.749,91.2329 661.758,91.2363 661.767,91.2397 661.776,91.243 661.785,91.2464 661.795,91.2498 661.804,91.2531 661.813,91.2565 661.822,91.2599 661.831,91.2632 661.841,91.2666 661.85,91.27 661.859,91.2733 661.868,91.2767 661.877,91.2801 661.886,91.2834 661.896,91.2868 661.905,91.2902 661.914,91.2935 661.923,91.2969 661.932,91.3003 661.942,91.3036 661.951,91.307 661.96,91.3104 661.969,91.3137 661.978,91.3171 661.988,91.3205 661.997,91.3238 662.006,91.3272 662.015,91.3306 662.024,91.3339 662.033,91.3373 662.043,91.3407 662.052,91.344 662.061,91.3474 662.07,91.3508 662.079,91.3541 662.089,91.3575 662.098,91.3609 662.107,91.3642 662.116,91.3676 662.125,91.371 662.135,91.3743 662.144,91.3777 662.153,91.3811 662.162,91.3844 662.171,91.3878 662.181,91.3912 662.19,91.3945 662.199,91.3979 662.208,91.4013 662.217,91.4046 662.226,91.408 662.236,91.4114 662.245,91.4147 662.254,91.4181 662.263,91.4215 662.272,91.4248 662.282,91.4282 662.291,91.4316 662.3,91.4349 662.309,91.4383 662.318,91.4417 662.328,91.445 662.337,91.4484 662.346,91.4518 662.355,91.4551 662.364,91.4585 662.373,91.4619 662.383,91.4652 662.392,91.4686 662.401,91.472 662.41,91.4753 662.419,91.4787 662.429,91.4821 662.438,91.4854 662.447,91.4888 662.456,91.4922 662.465,91.4955 662.475,91.4989 662.484,91.5023 662.493,91.5056 662.502,91.509 662.511,91.5124 662.521,91.5157 662.53,91.5191 662.539,91.5224 662.548,91.5258 662.557,91.5292 662.566,91.5325 662.576,91.5359 662.585,91.5393 662.594,91.5426 662.603,91.546 662.612,91.5494 662.622,91.5527 662.631,91.5561 662.64,91.5595 662.649,91.5628 662.658,91.5662 662.668,91.5696 662.677,91.5729 662.686,91.5763 662.695,91.5797 662.704,91.583 662.713,91.5864 662.723,91.5897 662.732,91.5931 662.741,91.5965 662.75,91.5998 662.759,91.6032 662.769,91.6066 662.778,91.6099 662.787,91.6133 662.796,91.6167 662.805,91.62 662.815,91.6234 662.824,91.6268 662.833,91.6301 662.842,91.6335 662.851,91.6369 662.861,91.6402 662.87,91.6436 662.879,91.6469 662.888,91.6503 662.897,91.6537 662.906,91.657 662.916,91.6604 662.925,91.6638 662.934,91.6671 662.943,91.6705 662.952,91.6739 662.962,91.6772 662.971,91.6806 662.98,91.684 662.989,91.6873 662.998,91.6907 663.008,91.694 663.017,91.6974 663.026,91.7008 663.035,91.7041 663.044,91.7075 663.053,91.7109 663.063,91.7142 663.072,91.7176 663.081,91.721 663.09,91.7243 663.099,91.7277 663.109,91.7311 663.118,91.7344 663.127,91.7378 663.136,91.7411 663.145,91.7445 663.155,91.7479 663.164,91.7512 663.173,91.7546 663.182,91.758 663.191,91.7613 663.201,91.7647 663.21,91.7681 663.219,91.7714 663.228,91.7748 663.237,91.7781 663.246,91.7815 663.256,91.7849 663.265,91.7882 663.274,91.7916 663.283,91.795 663.292,91.7983 663.302,91.8017 663.311,91.8051 663.32,91.8084 663.329,91.8118 663.338,91.8151 663.348,91.8185 663.357,91.8219 663.366,91.8252 663.375,91.8286 663.384,91.832 663.393,91.8353 663.403,91.8387 663.412,91.842 663.421,91.8454 663.43,91.8488 663.439,91.8521 663.449,91.8555 663.458,91.8589 663.467,91.8622 663.476,91.8656 663.485,91.869 663.495,91.8723 663.504,91.8757 663.513,91.879 663.522,91.8824 663.531,91.8858 663.541,91.8891 663.55,91.8925 663.559,91.8959 663.568,91.8992 663.577,91.9026 663.586,91.9059 663.596,91.9093 663.605,91.9127 663.614,91.916 663.623,91.9194 663.632,91.9228 663.642,91.9261 663.651,91.9295 663.66,91.9328 663.669,91.9362 663.678,91.9396 663.688,91.9429 663.697,91.9463 663.706,91.9497 663.715,91.953 663.724,91.9564 663.733,91.9597 663.743,91.9631 663.752,91.9665 663.761,91.9698 663.77,91.9732 663.779,91.9765 663.789,91.9799 663.798,91.9833 663.807,91.9866 663.816,91.99 663.825,91.9934 663.835,91.9967 663.844,92.0001 663.853,92.0034 663.862,92.0068 663.871,92.0102 663.881,92.0135 663.89,92.0169 663.899,92.0203 663.908,92.0236 663.917,92.027 663.926,92.0303 663.936,92.0337 663.945,92.0371 663.954,92.0404 663.963,92.0438 663.972,92.0471 663.982,92.0505 663.991,92.0539 664,92.0572 664.009,92.0606 664.018,92.064 664.028,92.0673 664.037,92.0707 664.046,92.074 664.055,92.0774 664.064,92.0808 664.073,92.0841 664.083,92.0875 664.092,92.0908 664.101,92.0942 664.11,92.0976 664.119,92.1009 664.129,92.1043 664.138,92.1076 664.147,92.111 664.156,92.1144 664.165,92.1177 664.175,92.1211 664.184,92.1245 664.193,92.1278 664.202,92.1312 664.211,92.1345 664.221,92.1379 664.23,92.1413 664.239,92.1446 664.248,92.148 664.257,92.1513 664.266,92.1547 664.276,92.1581 664.285,92.1614 664.294,92.1648 664.303,92.1681 664.312,92.1715 664.322,92.1749 664.331,92.1782 664.34,92.1816 664.349,92.1849 664.358,92.1883 664.368,92.1917 664.377,92.195 664.386,92.1984 664.395,92.2017 664.404,92.2051 664.414,92.2085 664.423,92.2118 664.432,92.2152 664.441,92.2185 664.45,92.2219 664.459,92.2253 664.469,92.2286 664.478,92.232 664.487,92.2353 664.496,92.2387 664.505,92.2421 664.515,92.2454 664.524,92.2488 664.533,92.2521 664.542,92.2555 664.551,92.2589 664.561,92.2622 664.57,92.2656 664.579,92.2689 664.588,92.2723 664.597,92.2757 664.606,92.279 664.616,92.2824 664.625,92.2857 664.634,92.2891 664.643,92.2925 664.652,92.2958 664.662,92.2992 664.671,92.3025 664.68,92.3059 664.689,92.3093 664.698,92.3126 664.708,92.316 664.717,92.3193 664.726,92.3227 664.735,92.3261 664.744,92.3294 664.754,92.3328 664.763,92.3361 664.772,92.3395 664.781,92.3429 664.79,92.3462 664.799,92.3496 664.809,92.3529 664.818,92.3563 664.827,92.3597 664.836,92.363 664.845,92.3664 664.855,92.3697 664.864,92.3731 664.873,92.3764 664.882,92.3798 664.891,92.3832 664.901,92.3865 664.91,92.3899 664.919,92.3932 664.928,92.3966 664.937,92.4 664.946,92.4033 664.956,92.4067 664.965,92.41 664.974,92.4134 664.983,92.4168 664.992,92.4201 665.002,92.4235 665.011,92.4268 665.02,92.4302 665.029,92.4335 665.038,92.4369 665.048,92.4403 665.057,92.4436 665.066,92.447 665.075,92.4503 665.084,92.4537 665.094,92.4571 665.103,92.4604 665.112,92.4638 665.121,92.4671 665.13,92.4705 665.139,92.4738 665.149,92.4772 665.158,92.4806 665.167,92.4839 665.176,92.4873 665.185,92.4906 665.195,92.494 665.204,92.4974 665.213,92.5007 665.222,92.5041 665.231,92.5074 665.241,92.5108 665.25,92.5141 665.259,92.5175 665.268,92.5209 665.277,92.5242 665.286,92.5276 665.296,92.5309 665.305,92.5343 665.314,92.5377 665.323,92.541 665.332,92.5444 665.342,92.5477 665.351,92.5511 665.36,92.5544 665.369,92.5578 665.378,92.5612 665.388,92.5645 665.397,92.5679 665.406,92.5712 665.415,92.5746 665.424,92.5779 665.434,92.5813 665.443,92.5847 665.452,92.588 665.461,92.5914 665.47,92.5947 665.479,92.5981 665.489,92.6014 665.498,92.6048 665.507,92.6082 665.516,92.6115 665.525,92.6149 665.535,92.6182 665.544,92.6216 665.553,92.6249 665.562,92.6283 665.571,92.6317 665.581,92.635 665.59,92.6384 665.599,92.6417 665.608,92.6451 665.617,92.6484 665.626,92.6518 665.636,92.6552 665.645,92.6585 665.654,92.6619 665.663,92.6652 665.672,92.6686 665.682,92.6719 665.691,92.6753 665.7,92.6787 665.709,92.682 665.718,92.6854 665.728,92.6887 665.737,92.6921 665.746,92.6954 665.755,92.6988 665.764,92.7022 665.774,92.7055 665.783,92.7089 665.792,92.7122 665.801,92.7156 665.81,92.7189 665.819,92.7223 665.829,92.7257 665.838,92.729 665.847,92.7324 665.856,92.7357 665.865,92.7391 665.875,92.7424 665.884,92.7458 665.893,92.7491 665.902,92.7525 665.911,92.7559 665.921,92.7592 665.93,92.7626 665.939,92.7659 665.948,92.7693 665.957,92.7726 665.966,92.776 665.976,92.7794 665.985,92.7827 665.994,92.7861 666.003,92.7894 666.012,92.7928 666.022,92.7961 666.031,92.7995 666.04,92.8028 666.049,92.8062 666.058,92.8096 666.068,92.8129 666.077,92.8163 666.086,92.8196 666.095,92.823 666.104,92.8263 666.114,92.8297 666.123,92.833 666.132,92.8364 666.141,92.8398 666.15,92.8431 666.159,92.8465 666.169,92.8498 666.178,92.8532 666.187,92.8565 666.196,92.8599 666.205,92.8632 666.215,92.8666 666.224,92.87 666.233,92.8733 666.242,92.8767 666.251,92.88 666.261,92.8834 666.27,92.8867 666.279,92.8901 666.288,92.8934 666.297,92.8968 666.306,92.9002 666.316,92.9035 666.325,92.9069 666.334,92.9102 666.343,92.9136 666.352,92.9169 666.362,92.9203 666.371,92.9236 666.38,92.927 666.389,92.9303 666.398,92.9337 666.408,92.9371 666.417,92.9404 666.426,92.9438 666.435,92.9471 666.444,92.9505 666.454,92.9538 666.463,92.9572 666.472,92.9605 666.481,92.9639 666.49,92.9672 666.499,92.9706 666.509,92.974 666.518,92.9773 666.527,92.9807 666.536,92.984 666.545,92.9874 666.555,92.9907 666.564,92.9941 666.573,92.9974 666.582,93.0008 666.591,93.0041 666.601,93.0075 666.61,93.0109 666.619,93.0142 666.628,93.0176 666.637,93.0209 666.646,93.0243 666.656,93.0276 666.665,93.031 666.674,93.0343 666.683,93.0377 666.692,93.041 666.702,93.0444 666.711,93.0478 666.72,93.0511 666.729,93.0545 666.738,93.0578 666.748,93.0612 666.757,93.0645 666.766,93.0679 666.775,93.0712 666.784,93.0746 666.794,93.0779 666.803,93.0813 666.812,93.0846 666.821,93.088 666.83,93.0914 666.839,93.0947 666.849,93.0981 666.858,93.1014 666.867,93.1048 666.876,93.1081 666.885,93.1115 666.895,93.1148 666.904,93.1182 666.913,93.1215 666.922,93.1249 666.931,93.1282 666.941,93.1316 666.95,93.1349 666.959,93.1383 666.968,93.1417 666.977,93.145 666.987,93.1484 666.996,93.1517 667.005,93.1551 667.014,93.1584 667.023,93.1618 667.032,93.1651 667.042,93.1685 667.051,93.1718 667.06,93.1752 667.069,93.1785 667.078,93.1819 667.088,93.1852 667.097,93.1886 667.106,93.192 667.115,93.1953 667.124,93.1987 667.134,93.202 667.143,93.2054 667.152,93.2087 667.161,93.2121 667.17,93.2154 667.179,93.2188 667.189,93.2221 667.198,93.2255 667.207,93.2288 667.216,93.2322 667.225,93.2355 667.235,93.2389 667.244,93.2422 667.253,93.2456 667.262,93.2489 667.271,93.2523 667.281,93.2557 667.29,93.259 667.299,93.2624 667.308,93.2657 667.317,93.2691 667.327,93.2724 667.336,93.2758 667.345,93.2791 667.354,93.2825 667.363,93.2858 667.372,93.2892 667.382,93.2925 667.391,93.2959 667.4,93.2992 667.409,93.3026 667.418,93.3059 667.428,93.3093 667.437,93.3126 667.446,93.316 667.455,93.3193 667.464,93.3227 667.474,93.326 667.483,93.3294 667.492,93.3328 667.501,93.3361 667.51,93.3395 667.519,93.3428 667.529,93.3462 667.538,93.3495 667.547,93.3529 667.556,93.3562 667.565,93.3596 667.575,93.3629 667.584,93.3663 667.593,93.3696 667.602,93.373 667.611,93.3763 667.621,93.3797 667.63,93.383 667.639,93.3864 667.648,93.3897 667.657,93.3931 667.667,93.3964 667.676,93.3998 667.685,93.4031 667.694,93.4065 667.703,93.4098 667.712,93.4132 667.722,93.4165 667.731,93.4199 667.74,93.4232 667.749,93.4266 667.758,93.4299 667.768,93.4333 667.777,93.4366 667.786,93.44 667.795,93.4433 667.804,93.4467 667.814,93.4501 667.823,93.4534 667.832,93.4568 667.841,93.4601 667.85,93.4635 667.859,93.4668 667.869,93.4702 667.878,93.4735 667.887,93.4769 667.896,93.4802 667.905,93.4836 667.915,93.4869 667.924,93.4903 667.933,93.4936 667.942,93.497 667.951,93.5003 667.961,93.5037 667.97,93.507 667.979,93.5104 667.988,93.5137 667.997,93.5171 668.007,93.5204 668.016,93.5238 668.025,93.5271 668.034,93.5305 668.043,93.5338 668.052,93.5372 668.062,93.5405 668.071,93.5439 668.08,93.5472 668.089,93.5506 668.098,93.5539 668.108,93.5573 668.117,93.5606 668.126,93.564 668.135,93.5673 668.144,93.5707 668.154,93.574 668.163,93.5774 668.172,93.5807 668.181,93.5841 668.19,93.5874 668.199,93.5908 668.209,93.5941 668.218,93.5975 668.227,93.6008 668.236,93.6042 668.245,93.6075 668.255,93.6109 668.264,93.6142 668.273,93.6176 668.282,93.6209 668.291,93.6243 668.301,93.6276 668.31,93.631 668.319,93.6343 668.328,93.6377 668.337,93.641 668.347,93.6444 668.356,93.6477 668.365,93.6511 668.374,93.6544 668.383,93.6578 668.392,93.6611 668.402,93.6645 668.411,93.6678 668.42,93.6712 668.429,93.6745 668.438,93.6779 668.448,93.6812 668.457,93.6846 668.466,93.6879 668.475,93.6913 668.484,93.6946 668.494,93.698 668.503,93.7013 668.512,93.7047 668.521,93.708 668.53,93.7114 668.539,93.7147 668.549,93.7181 668.558,93.7214 668.567,93.7247 668.576,93.7281 668.585,93.7314 668.595,93.7348 668.604,93.7381 668.613,93.7415 668.622,93.7448 668.631,93.7482 668.641,93.7515 668.65,93.7549 668.659,93.7582 668.668,93.7616 668.677,93.7649 668.687,93.7683 668.696,93.7716 668.705,93.775 668.714,93.7783 668.723,93.7817 668.732,93.785 668.742,93.7884 668.751,93.7917 668.76,93.7951 668.769,93.7984 668.778,93.8018 668.788,93.8051 668.797,93.8085 668.806,93.8118 668.815,93.8152 668.824,93.8185 668.834,93.8219 668.843,93.8252 668.852,93.8286 668.861,93.8319 668.87,93.8353 668.879,93.8386 668.889,93.8419 668.898,93.8453 668.907,93.8486 668.916,93.852 668.925,93.8553 668.935,93.8587 668.944,93.862 668.953,93.8654 668.962,93.8687 668.971,93.8721 668.981,93.8754 668.99,93.8788 668.999,93.8821 669.008,93.8855 669.017,93.8888 669.027,93.8922 669.036,93.8955 669.045,93.8989 669.054,93.9022 669.063,93.9056 669.072,93.9089 669.082,93.9123 669.091,93.9156 669.1,93.9189 669.109,93.9223 669.118,93.9256 669.128,93.929 669.137,93.9323 669.146,93.9357 669.155,93.939 669.164,93.9424 669.174,93.9457 669.183,93.9491 669.192,93.9524 669.201,93.9558 669.21,93.9591 669.22,93.9625 669.229,93.9658 669.238,93.9692 669.247,93.9725 669.256,93.9759 669.265,93.9792 669.275,93.9825 669.284,93.9859 669.293,93.9892 669.302,93.9926 669.311,93.9959 669.321,93.9993 669.33,94.0026 669.339,94.006 669.348,94.0093 669.357,94.0127 669.367,94.016 669.376,94.0194 669.385,94.0227 669.394,94.0261 669.403,94.0294 669.412,94.0327 669.422,94.0361 669.431,94.0394 669.44,94.0428 669.449,94.0461 669.458,94.0495 669.468,94.0528 669.477,94.0562 669.486,94.0595 669.495,94.0629 669.504,94.0662 669.514,94.0696 669.523,94.0729 669.532,94.0763 669.541,94.0796 669.55,94.0829 669.56,94.0863 669.569,94.0896 669.578,94.093 669.587,94.0963 669.596,94.0997 669.605,94.103 669.615,94.1064 669.624,94.1097 669.633,94.1131 669.642,94.1164 669.651,94.1198 669.661,94.1231 669.67,94.1264 669.679,94.1298 669.688,94.1331 669.697,94.1365 669.707,94.1398 669.716,94.1432 669.725,94.1465 669.734,94.1499 669.743,94.1532 669.752,94.1566 669.762,94.1599 669.771,94.1632 669.78,94.1666 669.789,94.1699 669.798,94.1733 669.808,94.1766 669.817,94.18 669.826,94.1833 669.835,94.1867 669.844,94.19 669.854,94.1934 669.863,94.1967 669.872,94.2 669.881,94.2034 669.89,94.2067 669.9,94.2101 669.909,94.2134 669.918,94.2168 669.927,94.2201 669.936,94.2235 669.945,94.2268 669.955,94.2302 669.964,94.2335 669.973,94.2368 669.982,94.2402 669.991,94.2435 670.001,94.2469 670.01,94.2502 670.019,94.2536 670.028,94.2569 670.037,94.2603 670.047,94.2636 670.056,94.267 670.065,94.2703 670.074,94.2736 670.083,94.277 670.092,94.2803 670.102,94.2837 670.111,94.287 670.12,94.2904 670.129,94.2937 670.138,94.2971 670.148,94.3004 670.157,94.3037 670.166,94.3071 670.175,94.3104 670.184,94.3138 670.194,94.3171 670.203,94.3205 670.212,94.3238 670.221,94.3272 670.23,94.3305 670.24,94.3338 670.249,94.3372 670.258,94.3405 670.267,94.3439 670.276,94.3472 670.285,94.3506 670.295,94.3539 670.304,94.3573 670.313,94.3606 670.322,94.3639 670.331,94.3673 670.341,94.3706 670.35,94.374 670.359,94.3773 670.368,94.3807 670.377,94.384 670.387,94.3874 670.396,94.3907 670.405,94.394 670.414,94.3974 670.423,94.4007 670.432,94.4041 670.442,94.4074 670.451,94.4108 670.46,94.4141 670.469,94.4174 670.478,94.4208 670.488,94.4241 670.497,94.4275 670.506,94.4308 670.515,94.4342 670.524,94.4375 670.534,94.4409 670.543,94.4442 670.552,94.4475 670.561,94.4509 670.57,94.4542 670.58,94.4576 670.589,94.4609 670.598,94.4643 670.607,94.4676 670.616,94.4709 670.625,94.4743 670.635,94.4776 670.644,94.481 670.653,94.4843 670.662,94.4877 670.671,94.491 670.681,94.4943 670.69,94.4977 670.699,94.501 670.708,94.5044 670.717,94.5077 670.727,94.5111 670.736,94.5144 670.745,94.5177 670.754,94.5211 670.763,94.5244 670.772,94.5278 670.782,94.5311 670.791,94.5345 670.8,94.5378 670.809,94.5411 670.818,94.5445 670.828,94.5478 670.837,94.5512 670.846,94.5545 670.855,94.5579 670.864,94.5612 670.874,94.5645 670.883,94.5679 670.892,94.5712 670.901,94.5746 670.91,94.5779 670.92,94.5813 670.929,94.5846 670.938,94.5879 670.947,94.5913 670.956,94.5946 670.965,94.598 670.975,94.6013 670.984,94.6047 670.993,94.608 671.002,94.6113 671.011,94.6147 671.021,94.618 671.03,94.6214 671.039,94.6247 671.048,94.6281 671.057,94.6314 671.067,94.6347 671.076,94.6381 671.085,94.6414 671.094,94.6448 671.103,94.6481 671.112,94.6514 671.122,94.6548 671.131,94.6581 671.14,94.6615 671.149,94.6648 671.158,94.6682 671.168,94.6715 671.177,94.6748 671.186,94.6782 671.195,94.6815 671.204,94.6849 671.214,94.6882 671.223,94.6916 671.232,94.6949 671.241,94.6982 671.25,94.7016 671.26,94.7049 671.269,94.7083 671.278,94.7116 671.287,94.7149 671.296,94.7183 671.305,94.7216 671.315,94.725 671.324,94.7283 671.333,94.7316 671.342,94.735 671.351,94.7383 671.361,94.7417 671.37,94.745 671.379,94.7484 671.388,94.7517 671.397,94.755 671.407,94.7584 671.416,94.7617 671.425,94.7651 671.434,94.7684 671.443,94.7717 671.452,94.7751 671.462,94.7784 671.471,94.7818 671.48,94.7851 671.489,94.7885 671.498,94.7918 671.508,94.7951 671.517,94.7985 671.526,94.8018 671.535,94.8052 671.544,94.8085 671.554,94.8118 671.563,94.8152 671.572,94.8185 671.581,94.8219 671.59,94.8252 671.6,94.8285 671.609,94.8319 671.618,94.8352 671.627,94.8386 671.636,94.8419 671.645,94.8452 671.655,94.8486 671.664,94.8519 671.673,94.8553 671.682,94.8586 671.691,94.8619 671.701,94.8653 671.71,94.8686 671.719,94.872 671.728,94.8753 671.737,94.8786 671.747,94.882 671.756,94.8853 671.765,94.8887 671.774,94.892 671.783,94.8953 671.793,94.8987 671.802,94.902 671.811,94.9054 671.82,94.9087 671.829,94.9121 671.838,94.9154 671.848,94.9187 671.857,94.9221 671.866,94.9254 671.875,94.9288 671.884,94.9321 671.894,94.9354 671.903,94.9388 671.912,94.9421 671.921,94.9454 671.93,94.9488 671.94,94.9521 671.949,94.9555 671.958,94.9588 671.967,94.9621 671.976,94.9655 671.985,94.9688 671.995,94.9722 672.004,94.9755 672.013,94.9788 672.022,94.9822 672.031,94.9855 672.041,94.9889 672.05,94.9922 672.059,94.9955 672.068,94.9989 672.077,95.0022 672.087,95.0056 672.096,95.0089 672.105,95.0122 672.114,95.0156 672.123,95.0189 672.133,95.0223 672.142,95.0256 672.151,95.0289 672.16,95.0323 672.169,95.0356 672.178,95.039 672.188,95.0423 672.197,95.0456 672.206,95.049 672.215,95.0523 672.224,95.0557 672.234,95.059 672.243,95.0623 672.252,95.0657 672.261,95.069 672.27,95.0723 672.28,95.0757 672.289,95.079 672.298,95.0824 672.307,95.0857 672.316,95.089 672.325,95.0924 672.335,95.0957 672.344,95.0991 672.353,95.1024 672.362,95.1057 672.371,95.1091 672.381,95.1124 672.39,95.1157 672.399,95.1191 672.408,95.1224 672.417,95.1258 672.427,95.1291 672.436,95.1324 672.445,95.1358 672.454,95.1391 672.463,95.1425 672.473,95.1458 672.482,95.1491 672.491,95.1525 672.5,95.1558 672.509,95.1591 672.518,95.1625 672.528,95.1658 672.537,95.1692 672.546,95.1725 672.555,95.1758 672.564,95.1792 672.574,95.1825 672.583,95.1859 672.592,95.1892 672.601,95.1925 672.61,95.1959 672.62,95.1992 672.629,95.2025 672.638,95.2059 672.647,95.2092 672.656,95.2126 672.665,95.2159 672.675,95.2192 672.684,95.2226 672.693,95.2259 672.702,95.2292 672.711,95.2326 672.721,95.2359 672.73,95.2393 672.739,95.2426 672.748,95.2459 672.757,95.2493 672.767,95.2526 672.776,95.2559 672.785,95.2593 672.794,95.2626 672.803,95.266 672.813,95.2693 672.822,95.2726 672.831,95.276 672.84,95.2793 672.849,95.2826 672.858,95.286 672.868,95.2893 672.877,95.2927 672.886,95.296 672.895,95.2993 672.904,95.3027 672.914,95.306 672.923,95.3093 672.932,95.3127 672.941,95.316 672.95,95.3194 672.96,95.3227 672.969,95.326 672.978,95.3294 672.987,95.3327 672.996,95.336 673.005,95.3394 673.015,95.3427 673.024,95.346 673.033,95.3494 673.042,95.3527 673.051,95.3561 673.061,95.3594 673.07,95.3627 673.079,95.3661 673.088,95.3694 673.097,95.3727 673.107,95.3761 673.116,95.3794 673.125,95.3828 673.134,95.3861 673.143,95.3894 673.153,95.3928 673.162,95.3961 673.171,95.3994 673.18,95.4028 673.189,95.4061 673.198,95.4094 673.208,95.4128 673.217,95.4161 673.226,95.4195 673.235,95.4228 673.244,95.4261 673.254,95.4295 673.263,95.4328 673.272,95.4361 673.281,95.4395 673.29,95.4428 673.3,95.4461 673.309,95.4495 673.318,95.4528 673.327,95.4562 673.336,95.4595 673.345,95.4628 673.355,95.4662 673.364,95.4695 673.373,95.4728 673.382,95.4762 673.391,95.4795 673.401,95.4828 673.41,95.4862 673.419,95.4895 673.428,95.4928 673.437,95.4962 673.447,95.4995 673.456,95.5029 673.465,95.5062 673.474,95.5095 673.483,95.5129 673.493,95.5162 673.502,95.5195 673.511,95.5229 673.52,95.5262 673.529,95.5295 673.538,95.5329 673.548,95.5362 673.557,95.5395 673.566,95.5429 673.575,95.5462 673.584,95.5495 673.594,95.5529 673.603,95.5562 673.612,95.5596 673.621,95.5629 673.63,95.5662 673.64,95.5696 673.649,95.5729 673.658,95.5762 673.667,95.5796 673.676,95.5829 673.685,95.5862 673.695,95.5896 673.704,95.5929 673.713,95.5962 673.722,95.5996 673.731,95.6029 673.741,95.6062 673.75,95.6096 673.759,95.6129 673.768,95.6163 673.777,95.6196 673.787,95.6229 673.796,95.6263 673.805,95.6296 673.814,95.6329 673.823,95.6363 673.833,95.6396 673.842,95.6429 673.851,95.6463 673.86,95.6496 673.869,95.6529 673.878,95.6563 673.888,95.6596 673.897,95.6629 673.906,95.6663 673.915,95.6696 673.924,95.6729 673.934,95.6763 673.943,95.6796 673.952,95.6829 673.961,95.6863 673.97,95.6896 673.98,95.6929 673.989,95.6963 673.998,95.6996 674.007,95.7029 674.016,95.7063 674.025,95.7096 674.035,95.7129 674.044,95.7163 674.053,95.7196 674.062,95.723 674.071,95.7263 674.081,95.7296 674.09,95.733 674.099,95.7363 674.108,95.7396 674.117,95.743 674.127,95.7463 674.136,95.7496 674.145,95.753 674.154,95.7563 674.163,95.7596 674.173,95.763 674.182,95.7663 674.191,95.7696 674.2,95.773 674.209,95.7763 674.218,95.7796 674.228,95.783 674.237,95.7863 674.246,95.7896 674.255,95.793 674.264,95.7963 674.274,95.7996 674.283,95.803 674.292,95.8063 674.301,95.8096 674.31,95.813 674.32,95.8163 674.329,95.8196 674.338,95.823 674.347,95.8263 674.356,95.8296 674.366,95.833 674.375,95.8363 674.384,95.8396 674.393,95.843 674.402,95.8463 674.411,95.8496 674.421,95.853 674.43,95.8563 674.439,95.8596 674.448,95.863 674.457,95.8663 674.467,95.8696 674.476,95.873 674.485,95.8763 674.494,95.8796 674.503,95.883 674.513,95.8863 674.522,95.8896 674.531,95.893 674.54,95.8963 674.549,95.8996 674.558,95.903 674.568,95.9063 674.577,95.9096 674.586,95.913 674.595,95.9163 674.604,95.9196 674.614,95.9229 674.623,95.9263 674.632,95.9296 674.641,95.9329 674.65,95.9363 674.66,95.9396 674.669,95.9429 674.678,95.9463 674.687,95.9496 674.696,95.9529 674.706,95.9563 674.715,95.9596 674.724,95.9629 674.733,95.9663 674.742,95.9696 674.751,95.9729 674.761,95.9763 674.77,95.9796 674.779,95.9829 674.788,95.9863 674.797,95.9896 674.807,95.9929 674.816,95.9963 674.825,95.9996 674.834,96.0029 674.843,96.0063 674.853,96.0096 674.862,96.0129 674.871,96.0162 674.88,96.0196 674.889,96.0229 674.898,96.0262 674.908,96.0296 674.917,96.0329 674.926,96.0362 674.935,96.0396 674.944,96.0429 674.954,96.0462 674.963,96.0496 674.972,96.0529 674.981,96.0562 674.99,96.0596 675,96.0629 675.009,96.0662 675.018,96.0696 675.027,96.0729 675.036,96.0762 675.046,96.0795 675.055,96.0829 675.064,96.0862 675.073,96.0895 675.082,96.0929 675.091,96.0962 675.101,96.0995 675.11,96.1029 675.119,96.1062 675.128,96.1095 675.137,96.1129 675.147,96.1162 675.156,96.1195 675.165,96.1229 675.174,96.1262 675.183,96.1295 675.193,96.1328 675.202,96.1362 675.211,96.1395 675.22,96.1428 675.229,96.1462 675.238,96.1495 675.248,96.1528 675.257,96.1562 675.266,96.1595 675.275,96.1628 675.284,96.1662 675.294,96.1695 675.303,96.1728 675.312,96.1761 675.321,96.1795 675.33,96.1828 675.34,96.1861 675.349,96.1895 675.358,96.1928 675.367,96.1961 675.376,96.1995 675.386,96.2028 675.395,96.2061 675.404,96.2095 675.413,96.2128 675.422,96.2161 675.431,96.2194 675.441,96.2228 675.45,96.2261 675.459,96.2294 675.468,96.2328 675.477,96.2361 675.487,96.2394 675.496,96.2428 675.505,96.2461 675.514,96.2494 675.523,96.2527 675.533,96.2561 675.542,96.2594 675.551,96.2627 675.56,96.2661 675.569,96.2694 675.578,96.2727 675.588,96.2761 675.597,96.2794 675.606,96.2827 675.615,96.286 675.624,96.2894 675.634,96.2927 675.643,96.296 675.652,96.2994 675.661,96.3027 675.67,96.306 675.68,96.3094 675.689,96.3127 675.698,96.316 675.707,96.3193 675.716,96.3227 675.726,96.326 675.735,96.3293 675.744,96.3327 675.753,96.336 675.762,96.3393 675.771,96.3426 675.781,96.346 675.79,96.3493 675.799,96.3526 675.808,96.356 675.817,96.3593 675.827,96.3626 675.836,96.366 675.845,96.3693 675.854,96.3726 675.863,96.3759 675.873,96.3793 675.882,96.3826 675.891,96.3859 675.9,96.3893 675.909,96.3926 675.918,96.3959 675.928,96.3992 675.937,96.4026 675.946,96.4059 675.955,96.4092 675.964,96.4126 675.974,96.4159 675.983,96.4192 675.992,96.4225 676.001,96.4259 676.01,96.4292 676.02,96.4325 676.029,96.4359 676.038,96.4392 676.047,96.4425 676.056,96.4458 676.066,96.4492 676.075,96.4525 676.084,96.4558 676.093,96.4592 676.102,96.4625 676.111,96.4658 676.121,96.4691 676.13,96.4725 676.139,96.4758 676.148,96.4791 676.157,96.4825 676.167,96.4858 676.176,96.4891 676.185,96.4924 676.194,96.4958 676.203,96.4991 676.213,96.5024 676.222,96.5058 676.231,96.5091 676.24,96.5124 676.249,96.5157 676.258,96.5191 676.268,96.5224 676.277,96.5257 676.286,96.5291 676.295,96.5324 676.304,96.5357 676.314,96.539 676.323,96.5424 676.332,96.5457 676.341,96.549 676.35,96.5523 676.36,96.5557 676.369,96.559 676.378,96.5623 676.387,96.5657 676.396,96.569 676.406,96.5723 676.415,96.5756 676.424,96.579 676.433,96.5823 676.442,96.5856 676.451,96.589 676.461,96.5923 676.47,96.5956 676.479,96.5989 676.488,96.6023 676.497,96.6056 676.507,96.6089 676.516,96.6122 676.525,96.6156 676.534,96.6189 676.543,96.6222 676.553,96.6256 676.562,96.6289 676.571,96.6322 676.58,96.6355 676.589,96.6389 676.599,96.6422 676.608,96.6455 676.617,96.6488 676.626,96.6522 676.635,96.6555 676.644,96.6588 676.654,96.6622 676.663,96.6655 676.672,96.6688 676.681,96.6721 676.69,96.6755 676.7,96.6788 676.709,96.6821 676.718,96.6854 676.727,96.6888 676.736,96.6921 676.746,96.6954 676.755,96.6987 676.764,96.7021 676.773,96.7054 676.782,96.7087 676.791,96.7121 676.801,96.7154 676.81,96.7187 676.819,96.722 676.828,96.7254 676.837,96.7287 676.847,96.732 676.856,96.7353 676.865,96.7387 676.874,96.742 676.883,96.7453 676.893,96.7486 676.902,96.752 676.911,96.7553 676.92,96.7586 676.929,96.762 676.939,96.7653 676.948,96.7686 676.957,96.7719 676.966,96.7753 676.975,96.7786 676.984,96.7819 676.994,96.7852 677.003,96.7886 677.012,96.7919 677.021,96.7952 677.03,96.7985 677.04,96.8019 677.049,96.8052 677.058,96.8085 677.067,96.8118 677.076,96.8152 677.086,96.8185 677.095,96.8218 677.104,96.8251 677.113,96.8285 677.122,96.8318 677.131,96.8351 677.141,96.8385 677.15,96.8418 677.159,96.8451 677.168,96.8484 677.177,96.8518 677.187,96.8551 677.196,96.8584 677.205,96.8617 677.214,96.8651 677.223,96.8684 677.233,96.8717 677.242,96.875 677.251,96.8784 677.26,96.8817 677.269,96.885 677.279,96.8883 677.288,96.8917 677.297,96.895 677.306,96.8983 677.315,96.9016 677.324,96.905 677.334,96.9083 677.343,96.9116 677.352,96.9149 677.361,96.9183 677.37,96.9216 677.38,96.9249 677.389,96.9282 677.398,96.9316 677.407,96.9349 677.416,96.9382 677.426,96.9415 677.435,96.9449 677.444,96.9482 677.453,96.9515 677.462,96.9548 677.471,96.9582 677.481,96.9615 677.49,96.9648 677.499,96.9681 677.508,96.9715 677.517,96.9748 677.527,96.9781 677.536,96.9814 677.545,96.9848 677.554,96.9881 677.563,96.9914 677.573,96.9947 677.582,96.9981 677.591,97.0014 677.6,97.0047 677.609,97.008 677.619,97.0114 677.628,97.0147 677.637,97.018 677.646,97.0213 677.655,97.0246 677.664,97.028 677.674,97.0313 677.683,97.0346 677.692,97.0379 677.701,97.0413 677.71,97.0446 677.72,97.0479 677.729,97.0512 677.738,97.0546 677.747,97.0579 677.756,97.0612 677.766,97.0645 677.775,97.0679 677.784,97.0712 677.793,97.0745 677.802,97.0778 677.811,97.0812 677.821,97.0845 677.83,97.0878 677.839,97.0911 677.848,97.0945 677.857,97.0978 677.867,97.1011 677.876,97.1044 677.885,97.1077 677.894,97.1111 677.903,97.1144 677.913,97.1177 677.922,97.121 677.931,97.1244 677.94,97.1277 677.949,97.131 677.959,97.1343 677.968,97.1377 677.977,97.141 677.986,97.1443 677.995,97.1476 678.004,97.151 678.014,97.1543 678.023,97.1576 678.032,97.1609 678.041,97.1642 678.05,97.1676 678.06,97.1709 678.069,97.1742 678.078,97.1775 678.087,97.1809 678.096,97.1842 678.106,97.1875 678.115,97.1908 678.124,97.1942 678.133,97.1975 678.142,97.2008 678.151,97.2041 678.161,97.2074 678.17,97.2108 678.179,97.2141 678.188,97.2174 678.197,97.2207 678.207,97.2241 678.216,97.2274 678.225,97.2307 678.234,97.234 678.243,97.2374 678.253,97.2407 678.262,97.244 678.271,97.2473 678.28,97.2506 678.289,97.254 678.299,97.2573 678.308,97.2606 678.317,97.2639 678.326,97.2673 678.335,97.2706 678.344,97.2739 678.354,97.2772 678.363,97.2805 678.372,97.2839 678.381,97.2872 678.39,97.2905 678.4,97.2938 678.409,97.2972 678.418,97.3005 678.427,97.3038 678.436,97.3071 678.446,97.3104 678.455,97.3138 678.464,97.3171 678.473,97.3204 678.482,97.3237 678.491,97.3271 678.501,97.3304 678.51,97.3337 678.519,97.337 678.528,97.3403 678.537,97.3437 678.547,97.347 678.556,97.3503 678.565,97.3536 678.574,97.357 678.583,97.3603 678.593,97.3636 678.602,97.3669 678.611,97.3702 678.62,97.3736 678.629,97.3769 678.639,97.3802 678.648,97.3835 678.657,97.3868 678.666,97.3902 678.675,97.3935 678.684,97.3968 678.694,97.4001 678.703,97.4035 678.712,97.4068 678.721,97.4101 678.73,97.4134 678.74,97.4167 678.749,97.4201 678.758,97.4234 678.767,97.4267 678.776,97.43 678.786,97.4333 678.795,97.4367 678.804,97.44 678.813,97.4433 678.822,97.4466 678.831,97.45 678.841,97.4533 678.85,97.4566 678.859,97.4599 678.868,97.4632 678.877,97.4666 678.887,97.4699 678.896,97.4732 678.905,97.4765 678.914,97.4798 678.923,97.4832 678.933,97.4865 678.942,97.4898 678.951,97.4931 678.96,97.4964 678.969,97.4998 678.979,97.5031 678.988,97.5064 678.997,97.5097 679.006,97.5131 679.015,97.5164 679.024,97.5197 679.034,97.523 679.043,97.5263 679.052,97.5297 679.061,97.533 679.07,97.5363 679.08,97.5396 679.089,97.5429 679.098,97.5463 679.107,97.5496 679.116,97.5529 679.126,97.5562 679.135,97.5595 679.144,97.5629 679.153,97.5662 679.162,97.5695 679.172,97.5728 679.181,97.5761 679.19,97.5795 679.199,97.5828 679.208,97.5861 679.217,97.5894 679.227,97.5927 679.236,97.5961 679.245,97.5994 679.254,97.6027 679.263,97.606 679.273,97.6093 679.282,97.6127 679.291,97.616 679.3,97.6193 679.309,97.6226 679.319,97.6259 679.328,97.6293 679.337,97.6326 679.346,97.6359 679.355,97.6392 679.364,97.6425 679.374,97.6459 679.383,97.6492 679.392,97.6525 679.401,97.6558 679.41,97.6591 679.42,97.6625 679.429,97.6658 679.438,97.6691 679.447,97.6724 679.456,97.6757 679.466,97.6791 679.475,97.6824 679.484,97.6857 679.493,97.689 679.502,97.6923 679.512,97.6956 679.521,97.699 679.53,97.7023 679.539,97.7056 679.548,97.7089 679.557,97.7122 679.567,97.7156 679.576,97.7189 679.585,97.7222 679.594,97.7255 679.603,97.7288 679.613,97.7322 679.622,97.7355 679.631,97.7388 679.64,97.7421 679.649,97.7454 679.659,97.7488 679.668,97.7521 679.677,97.7554 679.686,97.7587 679.695,97.762 679.704,97.7653 679.714,97.7687 679.723,97.772 679.732,97.7753 679.741,97.7786 679.75,97.7819 679.76,97.7853 679.769,97.7886 679.778,97.7919 679.787,97.7952 679.796,97.7985 679.806,97.8019 679.815,97.8052 679.824,97.8085 679.833,97.8118 679.842,97.8151 679.852,97.8184 679.861,97.8218 679.87,97.8251 679.879,97.8284 679.888,97.8317 679.897,97.835 679.907,97.8384 679.916,97.8417 679.925,97.845 679.934,97.8483 679.943,97.8516 679.953,97.8549 679.962,97.8583 679.971,97.8616 679.98,97.8649 679.989,97.8682 679.999,97.8715 680.008,97.8749 680.017,97.8782 680.026,97.8815 680.035,97.8848 680.044,97.8881 680.054,97.8914 680.063,97.8948 680.072,97.8981 680.081,97.9014 680.09,97.9047 680.1,97.908 680.109,97.9113 680.118,97.9147 680.127,97.918 680.136,97.9213 680.146,97.9246 680.155,97.9279 680.164,97.9313 680.173,97.9346 680.182,97.9379 680.192,97.9412 680.201,97.9445 680.21,97.9478 680.219,97.9512 680.228,97.9545 680.237,97.9578 680.247,97.9611 680.256,97.9644 680.265,97.9677 680.274,97.9711 680.283,97.9744 680.293,97.9777 680.302,97.981 680.311,97.9843 680.32,97.9876 680.329,97.991 680.339,97.9943 680.348,97.9976 680.357,98.0009 680.366,98.0042 680.375,98.0076 680.384,98.0109 680.394,98.0142 680.403,98.0175 680.412,98.0208 680.421,98.0241 680.43,98.0275 680.44,98.0308 680.449,98.0341 680.458,98.0374 680.467,98.0407 680.476,98.044 680.486,98.0474 680.495,98.0507 680.504,98.054 680.513,98.0573 680.522,98.0606 680.532,98.0639 680.541,98.0673 680.55,98.0706 680.559,98.0739 680.568,98.0772 680.577,98.0805 680.587,98.0838 680.596,98.0872 680.605,98.0905 680.614,98.0938 680.623,98.0971 680.633,98.1004 680.642,98.1037 680.651,98.107 680.66,98.1104 680.669,98.1137 680.679,98.117 680.688,98.1203 680.697,98.1236 680.706,98.1269 680.715,98.1303 680.724,98.1336 680.734,98.1369 680.743,98.1402 680.752,98.1435 680.761,98.1468 680.77,98.1502 680.78,98.1535 680.789,98.1568 680.798,98.1601 680.807,98.1634 680.816,98.1667 680.826,98.1701 680.835,98.1734 680.844,98.1767 680.853,98.18 680.862,98.1833 680.872,98.1866 680.881,98.1899 680.89,98.1933 680.899,98.1966 680.908,98.1999 680.917,98.2032 680.927,98.2065 680.936,98.2098 680.945,98.2132 680.954,98.2165 680.963,98.2198 680.973,98.2231 680.982,98.2264 680.991,98.2297 681,98.233 681.009,98.2364 681.019,98.2397 681.028,98.243 681.037,98.2463 681.046,98.2496 681.055,98.2529 681.064,98.2563 681.074,98.2596 681.083,98.2629 681.092,98.2662 681.101,98.2695 681.11,98.2728 681.12,98.2761 681.129,98.2795 681.138,98.2828 681.147,98.2861 681.156,98.2894 681.166,98.2927 681.175,98.296 681.184,98.2993 681.193,98.3027 681.202,98.306 681.212,98.3093 681.221,98.3126 681.23,98.3159 681.239,98.3192 681.248,98.3225 681.257,98.3259 681.267,98.3292 681.276,98.3325 681.285,98.3358 681.294,98.3391 681.303,98.3424 681.313,98.3457 681.322,98.3491 681.331,98.3524 681.34,98.3557 681.349,98.359 681.359,98.3623 681.368,98.3656 681.377,98.369 681.386,98.3723 681.395,98.3756 681.404,98.3789 681.414,98.3822 681.423,98.3855 681.432,98.3888 681.441,98.3921 681.45,98.3955 681.46,98.3988 681.469,98.4021 681.478,98.4054 681.487,98.4087 681.496,98.412 681.506,98.4153 681.515,98.4187 681.524,98.422 681.533,98.4253 681.542,98.4286 681.552,98.4319 681.561,98.4352 681.57,98.4385 681.579,98.4419 681.588,98.4452 681.597,98.4485 681.607,98.4518 681.616,98.4551 681.625,98.4584 681.634,98.4617 681.643,98.4651 681.653,98.4684 681.662,98.4717 681.671,98.475 681.68,98.4783 681.689,98.4816 681.699,98.4849 681.708,98.4882 681.717,98.4916 681.726,98.4949 681.735,98.4982 681.745,98.5015 681.754,98.5048 681.763,98.5081 681.772,98.5114 681.781,98.5148 681.79,98.5181 681.8,98.5214 681.809,98.5247 681.818,98.528 681.827,98.5313 681.836,98.5346 681.846,98.5379 681.855,98.5413 681.864,98.5446 681.873,98.5479 681.882,98.5512 681.892,98.5545 681.901,98.5578 681.91,98.5611 681.919,98.5644 681.928,98.5678 681.937,98.5711 681.947,98.5744 681.956,98.5777 681.965,98.581 681.974,98.5843 681.983,98.5876 681.993,98.5909 682.002,98.5943 682.011,98.5976 682.02,98.6009 682.029,98.6042 682.039,98.6075 682.048,98.6108 682.057,98.6141 682.066,98.6174 682.075,98.6208 682.085,98.6241 682.094,98.6274 682.103,98.6307 682.112,98.634 682.121,98.6373 682.13,98.6406 682.14,98.6439 682.149,98.6473 682.158,98.6506 682.167,98.6539 682.176,98.6572 682.186,98.6605 682.195,98.6638 682.204,98.6671 682.213,98.6704 682.222,98.6738 682.232,98.6771 682.241,98.6804 682.25,98.6837 682.259,98.687 682.268,98.6903 682.277,98.6936 682.287,98.6969 682.296,98.7003 682.305,98.7036 682.314,98.7069 682.323,98.7102 682.333,98.7135 682.342,98.7168 682.351,98.7201 682.36,98.7234 682.369,98.7267 682.379,98.7301 682.388,98.7334 682.397,98.7367 682.406,98.74 682.415,98.7433 682.425,98.7466 682.434,98.7499 682.443,98.7532 682.452,98.7565 682.461,98.7599 682.47,98.7632 682.48,98.7665 682.489,98.7698 682.498,98.7731 682.507,98.7764 682.516,98.7797 682.526,98.783 682.535,98.7863 682.544,98.7897 682.553,98.793 682.562,98.7963 682.572,98.7996 682.581,98.8029 682.59,98.8062 682.599,98.8095 682.608,98.8128 682.617,98.8161 682.627,98.8195 682.636,98.8228 682.645,98.8261 682.654,98.8294 682.663,98.8327 682.673,98.836 682.682,98.8393 682.691,98.8426 682.7,98.8459 682.709,98.8493 682.719,98.8526 682.728,98.8559 682.737,98.8592 682.746,98.8625 682.755,98.8658 682.765,98.8691 682.774,98.8724 682.783,98.8757 682.792,98.879 682.801,98.8824 682.81,98.8857 682.82,98.889 682.829,98.8923 682.838,98.8956 682.847,98.8989 682.856,98.9022 682.866,98.9055 682.875,98.9088 682.884,98.9122 682.893,98.9155 682.902,98.9188 682.912,98.9221 682.921,98.9254 682.93,98.9287 682.939,98.932 682.948,98.9353 682.957,98.9386 682.967,98.9419 682.976,98.9453 682.985,98.9486 682.994,98.9519 683.003,98.9552 683.013,98.9585 683.022,98.9618 683.031,98.9651 683.04,98.9684 683.049,98.9717 683.059,98.975 683.068,98.9784 683.077,98.9817 683.086,98.985 683.095,98.9883 683.105,98.9916 683.114,98.9949 683.123,98.9982 683.132,99.0015 683.141,99.0048 683.15,99.0081 683.16,99.0114 683.169,99.0148 683.178,99.0181 683.187,99.0214 683.196,99.0247 683.206,99.028 683.215,99.0313 683.224,99.0346 683.233,99.0379 683.242,99.0412 683.252,99.0445 683.261,99.0478 683.27,99.0512 683.279,99.0545 683.288,99.0578 683.297,99.0611 683.307,99.0644 683.316,99.0677 683.325,99.071 683.334,99.0743 683.343,99.0776 683.353,99.0809 683.362,99.0842 683.371,99.0876 683.38,99.0909 683.389,99.0942 683.399,99.0975 683.408,99.1008 683.417,99.1041 683.426,99.1074 683.435,99.1107 683.445,99.114 683.454,99.1173 683.463,99.1206 683.472,99.124 683.481,99.1273 683.49,99.1306 683.5,99.1339 683.509,99.1372 683.518,99.1405 683.527,99.1438 683.536,99.1471 683.546,99.1504 683.555,99.1537 683.564,99.157 683.573,99.1603 683.582,99.1637 683.592,99.167 683.601,99.1703 683.61,99.1736 683.619,99.1769 683.628,99.1802 683.637,99.1835 683.647,99.1868 683.656,99.1901 683.665,99.1934 683.674,99.1967 683.683,99.2 683.693,99.2034 683.702,99.2067 683.711,99.21 683.72,99.2133 683.729,99.2166 683.739,99.2199 683.748,99.2232 683.757,99.2265 683.766,99.2298 683.775,99.2331 683.785,99.2364 683.794,99.2397 683.803,99.243 683.812,99.2464 683.821,99.2497 683.83,99.253 683.84,99.2563 683.849,99.2596 683.858,99.2629 683.867,99.2662 683.876,99.2695 683.886,99.2728 683.895,99.2761 683.904,99.2794 683.913,99.2827 683.922,99.286 683.932,99.2894 683.941,99.2927 683.95,99.296 683.959,99.2993 683.968,99.3026 683.978,99.3059 683.987,99.3092 683.996,99.3125 684.005,99.3158 684.014,99.3191 684.023,99.3224 684.033,99.3257 684.042,99.329 684.051,99.3323 684.06,99.3357 684.069,99.339 684.079,99.3423 684.088,99.3456 684.097,99.3489 684.106,99.3522 684.115,99.3555 684.125,99.3588 684.134,99.3621 684.143,99.3654 684.152,99.3687 684.161,99.372 684.17,99.3753 684.18,99.3786 684.189,99.3819 684.198,99.3853 684.207,99.3886 684.216,99.3919 684.226,99.3952 684.235,99.3985 684.244,99.4018 684.253,99.4051 684.262,99.4084 684.272,99.4117 684.281,99.415 684.29,99.4183 684.299,99.4216 684.308,99.4249 684.318,99.4282 684.327,99.4315 684.336,99.4349 684.345,99.4382 684.354,99.4415 684.363,99.4448 684.373,99.4481 684.382,99.4514 684.391,99.4547 684.4,99.458 684.409,99.4613 684.419,99.4646 684.428,99.4679 684.437,99.4712 684.446,99.4745 684.455,99.4778 684.465,99.4811 684.474,99.4844 684.483,99.4878 684.492,99.4911 684.501,99.4944 684.51,99.4977 684.52,99.501 684.529,99.5043 684.538,99.5076 684.547,99.5109 684.556,99.5142 684.566,99.5175 684.575,99.5208 684.584,99.5241 684.593,99.5274 684.602,99.5307 684.612,99.534 684.621,99.5373 684.63,99.5406 684.639,99.5439 684.648,99.5473 684.658,99.5506 684.667,99.5539 684.676,99.5572 684.685,99.5605 684.694,99.5638 684.703,99.5671 684.713,99.5704 684.722,99.5737 684.731,99.577 684.74,99.5803 684.749,99.5836 684.759,99.5869 684.768,99.5902 684.777,99.5935 684.786,99.5968 684.795,99.6001 684.805,99.6034 684.814,99.6067 684.823,99.6101 684.832,99.6134 684.841,99.6167 684.85,99.62 684.86,99.6233 684.869,99.6266 684.878,99.6299 684.887,99.6332 684.896,99.6365 684.906,99.6398 684.915,99.6431 684.924,99.6464 684.933,99.6497 684.942,99.653 684.952,99.6563 684.961,99.6596 684.97,99.6629 684.979,99.6662 684.988,99.6695 684.998,99.6728 685.007,99.6761 685.016,99.6794 685.025,99.6828 685.034,99.6861 685.043,99.6894 685.053,99.6927 685.062,99.696 685.071,99.6993 685.08,99.7026 685.089,99.7059 685.099,99.7092 685.108,99.7125 685.117,99.7158 685.126,99.7191 685.135,99.7224 685.145,99.7257 685.154,99.729 685.163,99.7323 685.172,99.7356 685.181,99.7389 685.19,99.7422 685.2,99.7455 685.209,99.7488 685.218,99.7521 685.227,99.7554 685.236,99.7587 685.246,99.7621 685.255,99.7654 685.264,99.7687 685.273,99.772 685.282,99.7753 685.292,99.7786 685.301,99.7819 685.31,99.7852 685.319,99.7885 685.328,99.7918 685.338,99.7951 685.347,99.7984 685.356,99.8017 685.365,99.805 685.374,99.8083 685.383,99.8116 685.393,99.8149 685.402,99.8182 685.411,99.8215 685.42,99.8248 685.429,99.8281 685.439,99.8314 685.448,99.8347 685.457,99.838 685.466,99.8413 685.475,99.8446 685.485,99.8479 685.494,99.8512 685.503,99.8546 685.512,99.8579 685.521,99.8612 685.53,99.8645 685.54,99.8678 685.549,99.8711 685.558,99.8744 685.567,99.8777 685.576,99.881 685.586,99.8843 685.595,99.8876 685.604,99.8909 685.613,99.8942 685.622,99.8975 685.632,99.9008 685.641,99.9041 685.65,99.9074 685.659,99.9107 685.668,99.914 685.678,99.9173 685.687,99.9206 685.696,99.9239 685.705,99.9272 685.714,99.9305 685.723,99.9338 685.733,99.9371 685.742,99.9404 685.751,99.9437 685.76,99.947 685.769,99.9503 685.779,99.9536 685.788,99.9569 685.797,99.9602 685.806,99.9635 685.815,99.9668 685.825,99.9701 685.834,99.9734 685.843,99.9768 685.852,99.9801 685.861,99.9834 685.87,99.9867 685.88,99.99 685.889,99.9933 685.898,99.9966 685.907,99.9999 685.916,100.003 685.926,100.006 685.935,100.01 685.944,100.013 685.953,100.016 685.962,100.02 685.972,100.023 685.981,100.026 685.99,100.03 685.999,100.033 686.008,100.036 686.018,100.039 686.027,100.043 686.036,100.046 686.045,100.049 686.054,100.053 686.063,100.056 686.073,100.059 686.082,100.063 686.091,100.066 686.1,100.069 686.109,100.073 686.119,100.076 686.128,100.079 686.137,100.082 686.146,100.086 686.155,100.089 686.165,100.092 686.174,100.096 686.183,100.099 686.192,100.102 686.201,100.106 686.21,100.109 686.22,100.112 686.229,100.115 686.238,100.119 686.247,100.122 686.256,100.125 686.266,100.129 686.275,100.132 686.284,100.135 686.293,100.139 686.302,100.142 686.312,100.145 686.321,100.148 686.33,100.152 686.339,100.155 686.348,100.158 686.358,100.162 686.367,100.165 686.376,100.168 686.385,100.172 686.394,100.175 686.403,100.178 686.413,100.181 686.422,100.185 686.431,100.188 686.44,100.191 686.449,100.195 686.459,100.198 686.468,100.201 686.477,100.205 686.486,100.208 686.495,100.211 686.505,100.214 686.514,100.218 686.523,100.221 686.532,100.224 686.541,100.228 686.551,100.231 686.56,100.234 686.569,100.238 686.578,100.241 686.587,100.244 686.596,100.247 686.606,100.251 686.615,100.254 686.624,100.257 686.633,100.261 686.642,100.264 686.652,100.267 686.661,100.271 686.67,100.274 686.679,100.277 686.688,100.28 686.698,100.284 686.707,100.287 686.716,100.29 686.725,100.294 686.734,100.297 686.743,100.3 686.753,100.304 686.762,100.307 686.771,100.31 686.78,100.313 686.789,100.317 686.799,100.32 686.808,100.323 686.817,100.327 686.826,100.33 686.835,100.333 686.845,100.337 686.854,100.34 686.863,100.343 686.872,100.346 686.881,100.35 686.891,100.353 686.9,100.356 686.909,100.36 686.918,100.363 686.927,100.366 686.936,100.37 686.946,100.373 686.955,100.376 686.964,100.379 686.973,100.383 686.982,100.386 686.992,100.389 687.001,100.393 687.01,100.396 687.019,100.399 687.028,100.403 687.038,100.406 687.047,100.409 687.056,100.412 687.065,100.416 687.074,100.419 687.083,100.422 687.093,100.426 687.102,100.429 687.111,100.432 687.12,100.436 687.129,100.439 687.139,100.442 687.148,100.445 687.157,100.449 687.166,100.452 687.175,100.455 687.185,100.459 687.194,100.462 687.203,100.465 687.212,100.469 687.221,100.472 687.231,100.475 687.24,100.478 687.249,100.482 687.258,100.485 687.267,100.488 687.276,100.492 687.286,100.495 687.295,100.498 687.304,100.501 687.313,100.505 687.322,100.508 687.332,100.511 687.341,100.515 687.35,100.518 687.359,100.521 687.368,100.525 687.378,100.528 687.387,100.531 687.396,100.534 687.405,100.538 687.414,100.541 687.423,100.544 687.433,100.548 687.442,100.551 687.451,100.554 687.46,100.558 687.469,100.561 687.479,100.564 687.488,100.567 687.497,100.571 687.506,100.574 687.515,100.577 687.525,100.581 687.534,100.584 687.543,100.587 687.552,100.591 687.561,100.594 687.571,100.597 687.58,100.6 687.589,100.604 687.598,100.607 687.607,100.61 687.616,100.614 687.626,100.617 687.635,100.62 687.644,100.624 687.653,100.627 687.662,100.63 687.672,100.633 687.681,100.637 687.69,100.64 687.699,100.643 687.708,100.647 687.718,100.65 687.727,100.653 687.736,100.656 687.745,100.66 687.754,100.663 687.763,100.666 687.773,100.67 687.782,100.673 687.791,100.676 687.8,100.68 687.809,100.683 687.819,100.686 687.828,100.689 687.837,100.693 687.846,100.696 687.855,100.699 687.865,100.703 687.874,100.706 687.883,100.709 687.892,100.713 687.901,100.716 687.911,100.719 687.92,100.722 687.929,100.726 687.938,100.729 687.947,100.732 687.956,100.736 687.966,100.739 687.975,100.742 687.984,100.745 687.993,100.749 688.002,100.752 688.012,100.755 688.021,100.759 688.03,100.762 688.039,100.765 688.048,100.769 688.058,100.772 688.067,100.775 688.076,100.778 688.085,100.782 688.094,100.785 688.103,100.788 688.113,100.792 688.122,100.795 688.131,100.798 688.14,100.802 688.149,100.805 688.159,100.808 688.168,100.811 688.177,100.815 688.186,100.818 688.195,100.821 688.205,100.825 688.214,100.828 688.223,100.831 688.232,100.834 688.241,100.838 688.251,100.841 688.26,100.844 688.269,100.848 688.278,100.851 688.287,100.854 688.296,100.858 688.306,100.861 688.315,100.864 688.324,100.867 688.333,100.871 688.342,100.874 688.352,100.877 688.361,100.881 688.37,100.884 688.379,100.887 688.388,100.891 688.398,100.894 688.407,100.897 688.416,100.9 688.425,100.904 688.434,100.907 688.443,100.91 688.453,100.914 688.462,100.917 688.471,100.92 688.48,100.923 688.489,100.927 688.499,100.93 688.508,100.933 688.517,100.937 688.526,100.94 688.535,100.943 688.545,100.947 688.554,100.95 688.563,100.953 688.572,100.956 688.581,100.96 688.591,100.963 688.6,100.966 688.609,100.97 688.618,100.973 688.627,100.976 688.636,100.979 688.646,100.983 688.655,100.986 688.664,100.989 688.673,100.993 688.682,100.996 688.692,100.999 688.701,101.003 688.71,101.006 688.719,101.009 688.728,101.012 688.738,101.016 688.747,101.019 688.756,101.022 688.765,101.026 688.774,101.029 688.783,101.032 688.793,101.035 688.802,101.039 688.811,101.042 688.82,101.045 688.829,101.049 688.839,101.052 688.848,101.055 688.857,101.059 688.866,101.062 688.875,101.065 688.885,101.068 688.894,101.072 688.903,101.075 688.912,101.078 688.921,101.082 688.931,101.085 688.94,101.088 688.949,101.091 688.958,101.095 688.967,101.098 688.976,101.101 688.986,101.105 688.995,101.108 689.004,101.111 689.013,101.115 689.022,101.118 689.032,101.121 689.041,101.124 689.05,101.128 689.059,101.131 689.068,101.134 689.078,101.138 689.087,101.141 689.096,101.144 689.105,101.147 689.114,101.151 689.124,101.154 689.133,101.157 689.142,101.161 689.151,101.164 689.16,101.167 689.169,101.171 689.179,101.174 689.188,101.177 689.197,101.18 689.206,101.184 689.215,101.187 689.225,101.19 689.234,101.194 689.243,101.197 689.252,101.2 689.261,101.203 689.271,101.207 689.28,101.21 689.289,101.213 689.298,101.217 689.307,101.22 689.316,101.223 689.326,101.227 689.335,101.23 689.344,101.233 689.353,101.236 689.362,101.24 689.372,101.243 689.381,101.246 689.39,101.25 689.399,101.253 689.408,101.256 689.418,101.259 689.427,101.263 689.436,101.266 689.445,101.269 689.454,101.273 689.464,101.276 689.473,101.279 689.482,101.282 689.491,101.286 689.5,101.289 689.509,101.292 689.519,101.296 689.528,101.299 689.537,101.302 689.546,101.306 689.555,101.309 689.565,101.312 689.574,101.315 689.583,101.319 689.592,101.322 689.601,101.325 689.611,101.329 689.62,101.332 689.629,101.335 689.638,101.338 689.647,101.342 689.656,101.345 689.666,101.348 689.675,101.352 689.684,101.355 689.693,101.358 689.702,101.362 689.712,101.365 689.721,101.368 689.73,101.371 689.739,101.375 689.748,101.378 689.758,101.381 689.767,101.385 689.776,101.388 689.785,101.391 689.794,101.394 689.804,101.398 689.813,101.401 689.822,101.404 689.831,101.408 689.84,101.411 689.849,101.414 689.859,101.417 689.868,101.421 689.877,101.424 689.886,101.427 689.895,101.431 689.905,101.434 689.914,101.437 689.923,101.441 689.932,101.444 689.941,101.447 689.951,101.45 689.96,101.454 689.969,101.457 689.978,101.46 689.987,101.464 689.996,101.467 690.006,101.47 690.015,101.473 690.024,101.477 690.033,101.48 690.042,101.483 690.052,101.487 690.061,101.49 690.07,101.493 690.079,101.496 690.088,101.5 690.098,101.503 690.107,101.506 690.116,101.51 690.125,101.513 690.134,101.516 690.144,101.519 690.153,101.523 690.162,101.526 690.171,101.529 690.18,101.533 690.189,101.536 690.199,101.539 690.208,101.543 690.217,101.546 690.226,101.549 690.235,101.552 690.245,101.556 690.254,101.559 690.263,101.562 690.272,101.566 690.281,101.569 690.291,101.572 690.3,101.575 690.309,101.579 690.318,101.582 690.327,101.585 690.336,101.589 690.346,101.592 690.355,101.595 690.364,101.598 690.373,101.602 690.382,101.605 690.392,101.608 690.401,101.612 690.41,101.615 690.419,101.618 690.428,101.621 690.438,101.625 690.447,101.628 690.456,101.631 690.465,101.635 690.474,101.638 690.484,101.641 690.493,101.645 690.502,101.648 690.511,101.651 690.52,101.654 690.529,101.658 690.539,101.661 690.548,101.664 690.557,101.668 690.566,101.671 690.575,101.674 690.585,101.677 690.594,101.681 690.603,101.684 690.612,101.687 690.621,101.691 690.631,101.694 690.64,101.697 690.649,101.7 690.658,101.704 690.667,101.707 690.676,101.71 690.686,101.714 690.695,101.717 690.704,101.72 690.713,101.723 690.722,101.727 690.732,101.73 690.741,101.733 690.75,101.737 690.759,101.74 690.768,101.743 690.778,101.746 690.787,101.75 690.796,101.753 690.805,101.756 690.814,101.76 690.824,101.763 690.833,101.766 690.842,101.77 690.851,101.773 690.86,101.776 690.869,101.779 690.879,101.783 690.888,101.786 690.897,101.789 690.906,101.793 690.915,101.796 690.925,101.799 690.934,101.802 690.943,101.806 690.952,101.809 690.961,101.812 690.971,101.816 690.98,101.819 690.989,101.822 690.998,101.825 691.007,101.829 691.016,101.832 691.026,101.835 691.035,101.839 691.044,101.842 691.053,101.845 691.062,101.848 691.072,101.852 691.081,101.855 691.09,101.858 691.099,101.862 691.108,101.865 691.118,101.868 691.127,101.871 691.136,101.875 691.145,101.878 691.154,101.881 691.164,101.885 691.173,101.888 691.182,101.891 691.191,101.894 691.2,101.898 691.209,101.901 691.219,101.904 691.228,101.908 691.237,101.911 691.246,101.914 691.255,101.917 691.265,101.921 691.274,101.924 691.283,101.927 691.292,101.931 691.301,101.934 691.311,101.937 691.32,101.941 691.329,101.944 691.338,101.947 691.347,101.95 691.357,101.954 691.366,101.957 691.375,101.96 691.384,101.964 691.393,101.967 691.402,101.97 691.412,101.973 691.421,101.977 691.43,101.98 691.439,101.983 691.448,101.987 691.458,101.99 691.467,101.993 691.476,101.996 691.485,102 691.494,102.003 691.504,102.006 691.513,102.01 691.522,102.013 691.531,102.016 691.54,102.019 691.549,102.023 691.559,102.026 691.568,102.029 691.577,102.033 691.586,102.036 691.595,102.039 691.605,102.042 691.614,102.046 691.623,102.049 691.632,102.052 691.641,102.056 691.651,102.059 691.66,102.062 691.669,102.065 691.678,102.069 691.687,102.072 691.697,102.075 691.706,102.079 691.715,102.082 691.724,102.085 691.733,102.088 691.742,102.092 691.752,102.095 691.761,102.098 691.77,102.102 691.779,102.105 691.788,102.108 691.798,102.111 691.807,102.115 691.816,102.118 691.825,102.121 691.834,102.125 691.844,102.128 691.853,102.131 691.862,102.134 691.871,102.138 691.88,102.141 691.889,102.144 691.899,102.148 691.908,102.151 691.917,102.154 691.926,102.157 691.935,102.161 691.945,102.164 691.954,102.167 691.963,102.171 691.972,102.174 691.981,102.177 691.991,102.18 692,102.184 692.009,102.187 692.018,102.19 692.027,102.194 692.037,102.197 692.046,102.2 692.055,102.203 692.064,102.207 692.073,102.21 692.082,102.213 692.092,102.217 692.101,102.22 692.11,102.223 692.119,102.226 692.128,102.23 692.138,102.233 692.147,102.236 692.156,102.24 692.165,102.243 692.174,102.246 692.184,102.249 692.193,102.253 692.202,102.256 692.211,102.259 692.22,102.263 692.229,102.266 692.239,102.269 692.248,102.272 692.257,102.276 692.266,102.279 692.275,102.282 692.285,102.286 692.294,102.289 692.303,102.292 692.312,102.295 692.321,102.299 692.331,102.302 692.34,102.305 692.349,102.309 692.358,102.312 692.367,102.315 692.377,102.318 692.386,102.322 692.395,102.325 692.404,102.328 692.413,102.332 692.422,102.335 692.432,102.338 692.441,102.341 692.45,102.345 692.459,102.348 692.468,102.351 692.478,102.355 692.487,102.358 692.496,102.361 692.505,102.364 692.514,102.368 692.524,102.371 692.533,102.374 692.542,102.378 692.551,102.381 692.56,102.384 692.569,102.387 692.579,102.391 692.588,102.394 692.597,102.397 692.606,102.401 692.615,102.404 692.625,102.407 692.634,102.41 692.643,102.414 692.652,102.417 692.661,102.42 692.671,102.424 692.68,102.427 692.689,102.43 692.698,102.433 692.707,102.437 692.717,102.44 692.726,102.443 692.735,102.446 692.744,102.45 692.753,102.453 692.762,102.456 692.772,102.46 692.781,102.463 692.79,102.466 692.799,102.469 692.808,102.473 692.818,102.476 692.827,102.479 692.836,102.483 692.845,102.486 692.854,102.489 692.864,102.492 692.873,102.496 692.882,102.499 692.891,102.502 692.9,102.506 692.909,102.509 692.919,102.512 692.928,102.515 692.937,102.519 692.946,102.522 692.955,102.525 692.965,102.529 692.974,102.532 692.983,102.535 692.992,102.538 693.001,102.542 693.011,102.545 693.02,102.548 693.029,102.552 693.038,102.555 693.047,102.558 693.057,102.561 693.066,102.565 693.075,102.568 693.084,102.571 693.093,102.575 693.102,102.578 693.112,102.581 693.121,102.584 693.13,102.588 693.139,102.591 693.148,102.594 693.158,102.598 693.167,102.601 693.176,102.604 693.185,102.607 693.194,102.611 693.204,102.614 693.213,102.617 693.222,102.62 693.231,102.624 693.24,102.627 693.249,102.63 693.259,102.634 693.268,102.637 693.277,102.64 693.286,102.643 693.295,102.647 693.305,102.65 693.314,102.653 693.323,102.657 693.332,102.66 693.341,102.663 693.351,102.666 693.36,102.67 693.369,102.673 693.378,102.676 693.387,102.68 693.397,102.683 693.406,102.686 693.415,102.689 693.424,102.693 693.433,102.696 693.442,102.699 693.452,102.703 693.461,102.706 693.47,102.709 693.479,102.712 693.488,102.716 693.498,102.719 693.507,102.722 693.516,102.726 693.525,102.729 693.534,102.732 693.544,102.735 693.553,102.739 693.562,102.742 693.571,102.745 693.58,102.748 693.589,102.752 693.599,102.755 693.608,102.758 693.617,102.762 693.626,102.765 693.635,102.768 693.645,102.771 693.654,102.775 693.663,102.778 693.672,102.781 693.681,102.785 693.691,102.788 693.7,102.791 693.709,102.794 693.718,102.798 693.727,102.801 693.737,102.804 693.746,102.808 693.755,102.811 693.764,102.814 693.773,102.817 693.782,102.821 693.792,102.824 693.801,102.827 693.81,102.831 693.819,102.834 693.828,102.837 693.838,102.84 693.847,102.844 693.856,102.847 693.865,102.85 693.874,102.853 693.884,102.857 693.893,102.86 693.902,102.863 693.911,102.867 693.92,102.87 693.93,102.873 693.939,102.876 693.948,102.88 693.957,102.883 693.966,102.886 693.975,102.89 693.985,102.893 693.994,102.896 694.003,102.899 694.012,102.903 694.021,102.906 694.031,102.909 694.04,102.913 694.049,102.916 694.058,102.919 694.067,102.922 694.077,102.926 694.086,102.929 694.095,102.932 694.104,102.936 694.113,102.939 694.122,102.942 694.132,102.945 694.141,102.949 694.15,102.952 694.159,102.955 694.168,102.958 694.178,102.962 694.187,102.965 694.196,102.968 694.205,102.972 694.214,102.975 694.224,102.978 694.233,102.981 694.242,102.985 694.251,102.988 694.26,102.991 694.27,102.995 694.279,102.998 694.288,103.001 694.297,103.004 694.306,103.008 694.315,103.011 694.325,103.014 694.334,103.017 694.343,103.021 694.352,103.024 694.361,103.027 694.371,103.031 694.38,103.034 694.389,103.037 694.398,103.04 694.407,103.044 694.417,103.047 694.426,103.05 694.435,103.054 694.444,103.057 694.453,103.06 694.462,103.063 694.472,103.067 694.481,103.07 694.49,103.073 694.499,103.077 694.508,103.08 694.518,103.083 694.527,103.086 694.536,103.09 694.545,103.093 694.554,103.096 694.564,103.099 694.573,103.103 694.582,103.106 694.591,103.109 694.6,103.113 694.61,103.116 694.619,103.119 694.628,103.122 694.637,103.126 694.646,103.129 694.655,103.132 694.665,103.136 694.674,103.139 694.683,103.142 694.692,103.145 694.701,103.149 694.711,103.152 694.72,103.155 694.729,103.158 694.738,103.162 694.747,103.165 694.757,103.168 694.766,103.172 694.775,103.175 694.784,103.178 694.793,103.181 694.802,103.185 694.812,103.188 694.821,103.191 694.83,103.195 694.839,103.198 694.848,103.201 694.858,103.204 694.867,103.208 694.876,103.211 694.885,103.214 694.894,103.218 694.904,103.221 694.913,103.224 694.922,103.227 694.931,103.231 694.94,103.234 694.95,103.237 694.959,103.24 694.968,103.244 694.977,103.247 694.986,103.25 694.995,103.254 695.005,103.257 695.014,103.26 695.023,103.263 695.032,103.267 695.041,103.27 695.051,103.273 695.06,103.277 695.069,103.28 695.078,103.283 695.087,103.286 695.097,103.29 695.106,103.293 695.115,103.296 695.124,103.299 695.133,103.303 695.142,103.306 695.152,103.309 695.161,103.313 695.17,103.316 695.179,103.319 695.188,103.322 695.198,103.326 695.207,103.329 695.216,103.332 695.225,103.335 695.234,103.339 695.244,103.342 695.253,103.345 695.262,103.349 695.271,103.352 695.28,103.355 695.29,103.358 695.299,103.362 695.308,103.365 695.317,103.368 695.326,103.372 695.335,103.375 695.345,103.378 695.354,103.381 695.363,103.385 695.372,103.388 695.381,103.391 695.391,103.394 695.4,103.398 695.409,103.401 695.418,103.404 695.427,103.408 695.437,103.411 695.446,103.414 695.455,103.417 695.464,103.421 695.473,103.424 695.482,103.427 695.492,103.431 695.501,103.434 695.51,103.437 695.519,103.44 695.528,103.444 695.538,103.447 695.547,103.45 695.556,103.453 695.565,103.457 695.574,103.46 695.584,103.463 695.593,103.467 695.602,103.47 695.611,103.473 695.62,103.476 695.63,103.48 695.639,103.483 695.648,103.486 695.657,103.489 695.666,103.493 695.675,103.496 695.685,103.499 695.694,103.503 695.703,103.506 695.712,103.509 695.721,103.512 695.731,103.516 695.74,103.519 695.749,103.522 695.758,103.526 695.767,103.529 695.777,103.532 695.786,103.535 695.795,103.539 695.804,103.542 695.813,103.545 695.822,103.548 695.832,103.552 695.841,103.555 695.85,103.558 695.859,103.562 695.868,103.565 695.878,103.568 695.887,103.571 695.896,103.575 695.905,103.578 695.914,103.581 695.924,103.584 695.933,103.588 695.942,103.591 695.951,103.594 695.96,103.598 695.97,103.601 695.979,103.604 695.988,103.607 695.997,103.611 696.006,103.614 696.015,103.617 696.025,103.621 696.034,103.624 696.043,103.627 696.052,103.63 696.061,103.634 696.071,103.637 696.08,103.64 696.089,103.643 696.098,103.647 696.107,103.65 696.117,103.653 696.126,103.657 696.135,103.66 696.144,103.663 696.153,103.666 696.162,103.67 696.172,103.673 696.181,103.676 696.19,103.679 696.199,103.683 696.208,103.686 696.218,103.689 696.227,103.693 696.236,103.696 696.245,103.699 696.254,103.702 696.264,103.706 696.273,103.709 696.282,103.712 696.291,103.715 696.3,103.719 696.31,103.722 696.319,103.725 696.328,103.729 696.337,103.732 696.346,103.735 696.355,103.738 696.365,103.742 696.374,103.745 696.383,103.748 696.392,103.751 696.401,103.755 696.411,103.758 696.42,103.761 696.429,103.765 696.438,103.768 696.447,103.771 696.457,103.774 696.466,103.778 696.475,103.781 696.484,103.784 696.493,103.788 696.503,103.791 696.512,103.794 696.521,103.797 696.53,103.801 696.539,103.804 696.548,103.807 696.558,103.81 696.567,103.814 696.576,103.817 696.585,103.82 696.594,103.824 696.604,103.827 696.613,103.83 696.622,103.833 696.631,103.837 696.64,103.84 696.65,103.843 696.659,103.846 696.668,103.85 696.677,103.853 696.686,103.856 696.695,103.86 696.705,103.863 696.714,103.866 696.723,103.869 696.732,103.873 696.741,103.876 696.751,103.879 696.76,103.882 696.769,103.886 696.778,103.889 696.787,103.892 696.797,103.896 696.806,103.899 696.815,103.902 696.824,103.905 696.833,103.909 696.843,103.912 696.852,103.915 696.861,103.918 696.87,103.922 696.879,103.925 696.888,103.928 696.898,103.932 696.907,103.935 696.916,103.938 696.925,103.941 696.934,103.945 696.944,103.948 696.953,103.951 696.962,103.954 696.971,103.958 696.98,103.961 696.99,103.964 696.999,103.968 697.008,103.971 697.017,103.974 697.026,103.977 697.035,103.981 697.045,103.984 697.054,103.987 697.063,103.99 697.072,103.994 697.081,103.997 697.091,104 697.1,104.004 697.109,104.007 697.118,104.01 697.127,104.013 697.137,104.017 697.146,104.02 697.155,104.023 697.164,104.026 697.173,104.03 697.183,104.033 697.192,104.036 697.201,104.04 697.21,104.043 697.219,104.046 697.228,104.049 697.238,104.053 697.247,104.056 697.256,104.059 697.265,104.062 697.274,104.066 697.284,104.069 697.293,104.072 697.302,104.075 697.311,104.079 697.32,104.082 697.33,104.085 697.339,104.089 697.348,104.092 697.357,104.095 697.366,104.098 697.375,104.102 697.385,104.105 697.394,104.108 697.403,104.111 697.412,104.115 697.421,104.118 697.431,104.121 697.44,104.125 697.449,104.128 697.458,104.131 697.467,104.134 697.477,104.138 697.486,104.141 697.495,104.144 697.504,104.147 697.513,104.151 697.523,104.154 697.532,104.157 697.541,104.161 697.55,104.164 697.559,104.167 697.568,104.17 697.578,104.174 697.587,104.177 697.596,104.18 697.605,104.183 697.614,104.187 697.624,104.19 697.633,104.193 697.642,104.197 697.651,104.2 697.66,104.203 697.67,104.206 697.679,104.21 697.688,104.213 697.697,104.216 697.706,104.219 697.715,104.223 697.725,104.226 697.734,104.229 697.743,104.233 697.752,104.236 697.761,104.239 697.771,104.242 697.78,104.246 697.789,104.249 697.798,104.252 697.807,104.255 697.817,104.259 697.826,104.262 697.835,104.265 697.844,104.268 697.853,104.272 697.863,104.275 697.872,104.278 697.881,104.282 697.89,104.285 697.899,104.288 697.908,104.291 697.918,104.295 697.927,104.298 697.936,104.301 697.945,104.304 697.954,104.308 697.964,104.311 697.973,104.314 697.982,104.318 697.991,104.321 698,104.324 698.01,104.327 698.019,104.331 698.028,104.334 698.037,104.337 698.046,104.34 698.055,104.344 698.065,104.347 698.074,104.35 698.083,104.353 698.092,104.357 698.101,104.36 698.111,104.363 698.12,104.367 698.129,104.37 698.138,104.373 698.147,104.376 698.157,104.38 698.166,104.383 698.175,104.386 698.184,104.389 698.193,104.393 698.203,104.396 698.212,104.399 698.221,104.403 698.23,104.406 698.239,104.409 698.248,104.412 698.258,104.416 698.267,104.419 698.276,104.422 698.285,104.425 698.294,104.429 698.304,104.432 698.313,104.435 698.322,104.438 698.331,104.442 698.34,104.445 698.35,104.448 698.359,104.452 698.368,104.455 698.377,104.458 698.386,104.461 698.395,104.465 698.405,104.468 698.414,104.471 698.423,104.474 698.432,104.478 698.441,104.481 698.451,104.484 698.46,104.488 698.469,104.491 698.478,104.494 698.487,104.497 698.497,104.501 698.506,104.504 698.515,104.507 698.524,104.51 698.533,104.514 698.543,104.517 698.552,104.52 698.561,104.523 698.57,104.527 698.579,104.53 698.588,104.533 698.598,104.537 698.607,104.54 698.616,104.543 698.625,104.546 698.634,104.55 698.644,104.553 698.653,104.556 698.662,104.559 698.671,104.563 698.68,104.566 698.69,104.569 698.699,104.572 698.708,104.576 698.717,104.579 698.726,104.582 698.736,104.586 698.745,104.589 698.754,104.592 698.763,104.595 698.772,104.599 698.781,104.602 698.791,104.605 698.8,104.608 698.809,104.612 698.818,104.615 698.827,104.618 698.837,104.622 698.846,104.625 698.855,104.628 698.864,104.631 698.873,104.635 698.883,104.638 698.892,104.641 698.901,104.644 698.91,104.648 698.919,104.651 698.928,104.654 698.938,104.657 698.947,104.661 698.956,104.664 698.965,104.667 698.974,104.671 698.984,104.674 698.993,104.677 699.002,104.68 699.011,104.684 699.02,104.687 699.03,104.69 699.039,104.693 699.048,104.697 699.057,104.7 699.066,104.703 699.076,104.706 699.085,104.71 699.094,104.713 699.103,104.716 699.112,104.72 699.121,104.723 699.131,104.726 699.14,104.729 699.149,104.733 699.158,104.736 699.167,104.739 699.177,104.742 699.186,104.746 699.195,104.749 699.204,104.752 699.213,104.755 699.223,104.759 699.232,104.762 699.241,104.765 699.25,104.769 699.259,104.772 699.268,104.775 699.278,104.778 699.287,104.782 699.296,104.785 699.305,104.788 699.314,104.791 699.324,104.795 699.333,104.798 699.342,104.801 699.351,104.804 699.36,104.808 699.37,104.811 699.379,104.814 699.388,104.818 699.397,104.821 699.406,104.824 699.416,104.827 699.425,104.831 699.434,104.834 699.443,104.837 699.452,104.84 699.461,104.844 699.471,104.847 699.48,104.85 699.489,104.853 699.498,104.857 699.507,104.86 699.517,104.863 699.526,104.867 699.535,104.87 699.544,104.873 699.553,104.876 699.563,104.88 699.572,104.883 699.581,104.886 699.59,104.889 699.599,104.893 699.608,104.896 699.618,104.899 699.627,104.902 699.636,104.906 699.645,104.909 699.654,104.912 699.664,104.915 699.673,104.919 699.682,104.922 699.691,104.925 699.7,104.929 699.71,104.932 699.719,104.935 699.728,104.938 699.737,104.942 699.746,104.945 699.756,104.948 699.765,104.951 699.774,104.955 699.783,104.958 699.792,104.961 699.801,104.964 699.811,104.968 699.82,104.971 699.829,104.974 699.838,104.978 699.847,104.981 699.857,104.984 699.866,104.987 699.875,104.991 699.884,104.994 699.893,104.997 699.903,105 699.912,105.004 699.921,105.007 699.93,105.01 699.939,105.013 699.948,105.017 699.958,105.02 699.967,105.023 699.976,105.026 699.985,105.03 699.994,105.033 700.004,105.036 700.013,105.04 700.022,105.043 700.031,105.046 700.04,105.049 700.05,105.053 700.059,105.056 700.068,105.059 700.077,105.062 700.086,105.066 700.096,105.069 700.105,105.072 700.114,105.075 700.123,105.079 700.132,105.082 700.141,105.085 700.151,105.089 700.16,105.092 700.169,105.095 700.178,105.098 700.187,105.102 700.197,105.105 700.206,105.108 700.215,105.111 700.224,105.115 700.233,105.118 700.243,105.121 700.252,105.124 700.261,105.128 700.27,105.131 700.279,105.134 700.288,105.137 700.298,105.141 700.307,105.144 700.316,105.147 700.325,105.151 700.334,105.154 700.344,105.157 700.353,105.16 700.362,105.164 700.371,105.167 700.38,105.17 700.39,105.173 700.399,105.177 700.408,105.18 700.417,105.183 700.426,105.186 700.436,105.19 700.445,105.193 700.454,105.196 700.463,105.199 700.472,105.203 700.481,105.206 700.491,105.209 700.5,105.213 700.509,105.216 700.518,105.219 700.527,105.222 700.537,105.226 700.546,105.229 700.555,105.232 700.564,105.235 700.573,105.239 700.583,105.242 700.592,105.245 700.601,105.248 700.61,105.252 700.619,105.255 700.628,105.258 700.638,105.261 700.647,105.265 700.656,105.268 700.665,105.271 700.674,105.275 700.684,105.278 700.693,105.281 700.702,105.284 700.711,105.288 700.72,105.291 700.73,105.294 700.739,105.297 700.748,105.301 700.757,105.304 700.766,105.307 700.776,105.31 700.785,105.314 700.794,105.317 700.803,105.32 700.812,105.323 700.821,105.327 700.831,105.33 700.84,105.333 700.849,105.337 700.858,105.34 700.867,105.343 700.877,105.346 700.886,105.35 700.895,105.353 700.904,105.356 700.913,105.359 700.923,105.363 700.932,105.366 700.941,105.369 700.95,105.372 700.959,105.376 700.968,105.379 700.978,105.382 700.987,105.385 700.996,105.389 701.005,105.392 701.014,105.395 701.024,105.398 701.033,105.402 701.042,105.405 701.051,105.408 701.06,105.412 701.07,105.415 701.079,105.418 701.088,105.421 701.097,105.425 701.106,105.428 701.116,105.431 701.125,105.434 701.134,105.438 701.143,105.441 701.152,105.444 701.161,105.447 701.171,105.451 701.18,105.454 701.189,105.457 701.198,105.46 701.207,105.464 701.217,105.467 701.226,105.47 701.235,105.474 701.244,105.477 701.253,105.48 701.263,105.483 701.272,105.487 701.281,105.49 701.29,105.493 701.299,105.496 701.309,105.5 701.318,105.503 701.327,105.506 701.336,105.509 701.345,105.513 701.354,105.516 701.364,105.519 701.373,105.522 701.382,105.526 701.391,105.529 701.4,105.532 701.41,105.535 701.419,105.539 701.428,105.542 701.437,105.545 701.446,105.549 701.456,105.552 701.465,105.555 701.474,105.558 701.483,105.562 701.492,105.565 701.501,105.568 701.511,105.571 701.52,105.575 701.529,105.578 701.538,105.581 701.547,105.584 701.557,105.588 701.566,105.591 701.575,105.594 701.584,105.597 701.593,105.601 701.603,105.604 701.612,105.607 701.621,105.61 701.63,105.614 701.639,105.617 701.649,105.62 701.658,105.623 701.667,105.627 701.676,105.63 701.685,105.633 701.694,105.637 701.704,105.64 701.713,105.643 701.722,105.646 701.731,105.65 701.74,105.653 701.75,105.656 701.759,105.659 701.768,105.663 701.777,105.666 701.786,105.669 701.796,105.672 701.805,105.676 701.814,105.679 701.823,105.682 701.832,105.685 701.841,105.689 701.851,105.692 701.86,105.695 701.869,105.698 701.878,105.702 701.887,105.705 701.897,105.708 701.906,105.712 701.915,105.715 701.924,105.718 701.933,105.721 701.943,105.725 701.952,105.728 701.961,105.731 701.97,105.734 701.979,105.738 701.989,105.741 701.998,105.744 702.007,105.747 702.016,105.751 702.025,105.754 702.034,105.757 702.044,105.76 702.053,105.764 702.062,105.767 702.071,105.77 702.08,105.773 702.09,105.777 702.099,105.78 702.108,105.783 702.117,105.786 702.126,105.79 702.136,105.793 702.145,105.796 702.154,105.799 702.163,105.803 702.172,105.806 702.181,105.809 702.191,105.813 702.2,105.816 702.209,105.819 702.218,105.822 702.227,105.826 702.237,105.829 702.246,105.832 702.255,105.835 702.264,105.839 702.273,105.842 702.283,105.845 702.292,105.848 702.301,105.852 702.31,105.855 702.319,105.858 702.329,105.861 702.338,105.865 702.347,105.868 702.356,105.871 702.365,105.874 702.374,105.878 702.384,105.881 702.393,105.884 702.402,105.887 702.411,105.891 702.42,105.894 702.43,105.897 702.439,105.901 702.448,105.904 702.457,105.907 702.466,105.91 702.476,105.914 702.485,105.917 702.494,105.92 702.503,105.923 702.512,105.927 702.521,105.93 702.531,105.933 702.54,105.936 702.549,105.94 702.558,105.943 702.567,105.946 702.577,105.949 702.586,105.953 702.595,105.956 702.604,105.959 702.613,105.962 702.623,105.966 702.632,105.969 702.641,105.972 702.65,105.975 702.659,105.979 702.669,105.982 702.678,105.985 702.687,105.988 702.696,105.992 702.705,105.995 702.714,105.998 702.724,106.001 702.733,106.005 702.742,106.008 702.751,106.011 702.76,106.015 702.77,106.018 702.779,106.021 702.788,106.024 702.797,106.028 702.806,106.031 702.816,106.034 702.825,106.037 702.834,106.041 702.843,106.044 702.852,106.047 702.861,106.05 702.871,106.054 702.88,106.057 702.889,106.06 702.898,106.063 702.907,106.067 702.917,106.07 702.926,106.073 702.935,106.076 702.944,106.08 702.953,106.083 702.963,106.086 702.972,106.089 702.981,106.093 702.99,106.096 702.999,106.099 703.009,106.102 703.018,106.106 703.027,106.109 703.036,106.112 703.045,106.115 703.054,106.119 703.064,106.122 703.073,106.125 703.082,106.129 703.091,106.132 703.1,106.135 703.11,106.138 703.119,106.142 703.128,106.145 703.137,106.148 703.146,106.151 703.156,106.155 703.165,106.158 703.174,106.161 703.183,106.164 703.192,106.168 703.201,106.171 703.211,106.174 703.22,106.177 703.229,106.181 703.238,106.184 703.247,106.187 703.257,106.19 703.266,106.194 703.275,106.197 703.284,106.2 703.293,106.203 703.303,106.207 703.312,106.21 703.321,106.213 703.33,106.216 703.339,106.22 703.349,106.223 703.358,106.226 703.367,106.229 703.376,106.233 703.385,106.236 703.394,106.239 703.404,106.242 703.413,106.246 703.422,106.249 703.431,106.252 703.44,106.255 703.45,106.259 703.459,106.262 703.468,106.265 703.477,106.269 703.486,106.272 703.496,106.275 703.505,106.278 703.514,106.282 703.523,106.285 703.532,106.288 703.541,106.291 703.551,106.295 703.56,106.298 703.569,106.301 703.578,106.304 703.587,106.308 703.597,106.311 703.606,106.314 703.615,106.317 703.624,106.321 703.633,106.324 703.643,106.327 703.652,106.33 703.661,106.334 703.67,106.337 703.679,106.34 703.689,106.343 703.698,106.347 703.707,106.35 703.716,106.353 703.725,106.356 703.734,106.36 703.744,106.363 703.753,106.366 703.762,106.369 703.771,106.373 703.78,106.376 703.79,106.379 703.799,106.382 703.808,106.386 703.817,106.389 703.826,106.392 703.836,106.395 703.845,106.399 703.854,106.402 703.863,106.405 703.872,106.408 703.882,106.412 703.891,106.415 703.9,106.418 703.909,106.421 703.918,106.425 703.927,106.428 703.937,106.431 703.946,106.434 703.955,106.438 703.964,106.441 703.973,106.444 703.983,106.448 703.992,106.451 704.001,106.454 704.01,106.457 704.019,106.461 704.029,106.464 704.038,106.467 704.047,106.47 704.056,106.474 704.065,106.477 704.074,106.48 704.084,106.483 704.093,106.487 704.102,106.49 704.111,106.493 704.12,106.496 704.13,106.5 704.139,106.503 704.148,106.506 704.157,106.509 704.166,106.513 704.176,106.516 704.185,106.519 704.194,106.522 704.203,106.526 704.212,106.529 704.222,106.532 704.231,106.535 704.24,106.539 704.249,106.542 704.258,106.545 704.267,106.548 704.277,106.552 704.286,106.555 704.295,106.558 704.304,106.561 704.313,106.565 704.323,106.568 704.332,106.571 704.341,106.574 704.35,106.578 704.359,106.581 704.369,106.584 704.378,106.587 704.387,106.591 704.396,106.594 704.405,106.597 704.414,106.6 704.424,106.604 704.433,106.607 704.442,106.61 704.451,106.613 704.46,106.617 704.47,106.62 704.479,106.623 704.488,106.626 704.497,106.63 704.506,106.633 704.516,106.636 704.525,106.639 704.534,106.643 704.543,106.646 704.552,106.649 704.562,106.652 704.571,106.656 704.58,106.659 704.589,106.662 704.598,106.665 704.607,106.669 704.617,106.672 704.626,106.675 704.635,106.678 704.644,106.682 704.653,106.685 704.663,106.688 704.672,106.691 704.681,106.695 704.69,106.698 704.699,106.701 704.709,106.704 704.718,106.708 704.727,106.711 704.736,106.714 704.745,106.717 704.754,106.721 704.764,106.724 704.773,106.727 704.782,106.73 704.791,106.734 704.8,106.737 704.81,106.74 704.819,106.744 704.828,106.747 704.837,106.75 704.846,106.753 704.856,106.757 704.865,106.76 704.874,106.763 704.883,106.766 704.892,106.77 704.902,106.773 704.911,106.776 704.92,106.779 704.929,106.783 704.938,106.786 704.947,106.789 704.957,106.792 704.966,106.796 704.975,106.799 704.984,106.802 704.993,106.805 705.003,106.809 705.012,106.812 705.021,106.815 705.03,106.818 705.039,106.822 705.049,106.825 705.058,106.828 705.067,106.831 705.076,106.835 705.085,106.838 705.094,106.841 705.104,106.844 705.113,106.848 705.122,106.851 705.131,106.854 705.14,106.857 705.15,106.861 705.159,106.864 705.168,106.867 705.177,106.87 705.186,106.874 705.196,106.877 705.205,106.88 705.214,106.883 705.223,106.887 705.232,106.89 705.242,106.893 705.251,106.896 705.26,106.9 705.269,106.903 705.278,106.906 705.287,106.909 705.297,106.913 705.306,106.916 705.315,106.919 705.324,106.922 705.333,106.926 705.343,106.929 705.352,106.932 705.361,106.935 705.37,106.939 705.379,106.942 705.389,106.945 705.398,106.948 705.407,106.952 705.416,106.955 705.425,106.958 705.434,106.961 705.444,106.965 705.453,106.968 705.462,106.971 705.471,106.974 705.48,106.978 705.49,106.981 705.499,106.984 705.508,106.987 705.517,106.991 705.526,106.994 705.536,106.997 705.545,107 705.554,107.004 705.563,107.007 705.572,107.01 705.582,107.013 705.591,107.017 705.6,107.02 705.609,107.023 705.618,107.026 705.627,107.03 705.637,107.033 705.646,107.036 705.655,107.039 705.664,107.043 705.673,107.046 705.683,107.049 705.692,107.052 705.701,107.056 705.71,107.059 705.719,107.062 705.729,107.065 705.738,107.069 705.747,107.072 705.756,107.075 705.765,107.078 705.774,107.082 705.784,107.085 705.793,107.088 705.802,107.091 705.811,107.095 705.82,107.098 705.83,107.101 705.839,107.104 705.848,107.108 705.857,107.111 705.866,107.114 705.876,107.117 705.885,107.121 705.894,107.124 705.903,107.127 705.912,107.13 705.922,107.134 705.931,107.137 705.94,107.14 705.949,107.143 705.958,107.147 705.967,107.15 705.977,107.153 705.986,107.156 705.995,107.16 706.004,107.163 706.013,107.166 706.023,107.169 706.032,107.173 706.041,107.176 706.05,107.179 706.059,107.182 706.069,107.186 706.078,107.189 706.087,107.192 706.096,107.195 706.105,107.198 706.114,107.202 706.124,107.205 706.133,107.208 706.142,107.211 706.151,107.215 706.16,107.218 706.17,107.221 706.179,107.224 706.188,107.228 706.197,107.231 706.206,107.234 706.216,107.237 706.225,107.241 706.234,107.244 706.243,107.247 706.252,107.25 706.262,107.254 706.271,107.257 706.28,107.26 706.289,107.263 706.298,107.267 706.307,107.27 706.317,107.273 706.326,107.276 706.335,107.28 706.344,107.283 706.353,107.286 706.363,107.289 706.372,107.293 706.381,107.296 706.39,107.299 706.399,107.302 706.409,107.306 706.418,107.309 706.427,107.312 706.436,107.315 706.445,107.319 706.455,107.322 706.464,107.325 706.473,107.328 706.482,107.332 706.491,107.335 706.5,107.338 706.51,107.341 706.519,107.345 706.528,107.348 706.537,107.351 706.546,107.354 706.556,107.358 706.565,107.361 706.574,107.364 706.583,107.367 706.592,107.371 706.602,107.374 706.611,107.377 706.62,107.38 706.629,107.384 706.638,107.387 706.647,107.39 706.657,107.393 706.666,107.397 706.675,107.4 706.684,107.403 706.693,107.406 706.703,107.41 706.712,107.413 706.721,107.416 706.73,107.419 706.739,107.423 706.749,107.426 706.758,107.429 706.767,107.432 706.776,107.436 706.785,107.439 706.795,107.442 706.804,107.445 706.813,107.449 706.822,107.452 706.831,107.455 706.84,107.458 706.85,107.462 706.859,107.465 706.868,107.468 706.877,107.471 706.886,107.475 706.896,107.478 706.905,107.481 706.914,107.484 706.923,107.487 706.932,107.491 706.942,107.494 706.951,107.497 706.96,107.5 706.969,107.504 706.978,107.507 706.987,107.51 706.997,107.513 707.006,107.517 707.015,107.52 707.024,107.523 707.033,107.526 707.043,107.53 707.052,107.533 707.061,107.536 707.07,107.539 707.079,107.543 707.089,107.546 707.098,107.549 707.107,107.552 707.116,107.556 707.125,107.559 707.135,107.562 707.144,107.565 707.153,107.569 707.162,107.572 707.171,107.575 707.18,107.578 707.19,107.582 707.199,107.585 707.208,107.588 707.217,107.591 707.226,107.595 707.236,107.598 707.245,107.601 707.254,107.604 707.263,107.608 707.272,107.611 707.282,107.614 707.291,107.617 707.3,107.621 707.309,107.624 707.318,107.627 707.327,107.63 707.337,107.634 707.346,107.637 707.355,107.64 707.364,107.643 707.373,107.647 707.383,107.65 707.392,107.653 707.401,107.656 707.41,107.66 707.419,107.663 707.429,107.666 707.438,107.669 707.447,107.672 707.456,107.676 707.465,107.679 707.475,107.682 707.484,107.685 707.493,107.689 707.502,107.692 707.511,107.695 707.52,107.698 707.53,107.702 707.539,107.705 707.548,107.708 707.557,107.711 707.566,107.715 707.576,107.718 707.585,107.721 707.594,107.724 707.603,107.728 707.612,107.731 707.622,107.734 707.631,107.737 707.64,107.741 707.649,107.744 707.658,107.747 707.667,107.75 707.677,107.754 707.686,107.757 707.695,107.76 707.704,107.763 707.713,107.767 707.723,107.77 707.732,107.773 707.741,107.776 707.75,107.78 707.759,107.783 707.769,107.786 707.778,107.789 707.787,107.793 707.796,107.796 707.805,107.799 707.815,107.802 707.824,107.805 707.833,107.809 707.842,107.812 707.851,107.815 707.86,107.818 707.87,107.822 707.879,107.825 707.888,107.828 707.897,107.831 707.906,107.835 707.916,107.838 707.925,107.841 707.934,107.844 707.943,107.848 707.952,107.851 707.962,107.854 707.971,107.857 707.98,107.861 707.989,107.864 707.998,107.867 708.007,107.87 708.017,107.874 708.026,107.877 708.035,107.88 708.044,107.883 708.053,107.887 708.063,107.89 708.072,107.893 708.081,107.896 708.09,107.9 708.099,107.903 708.109,107.906 708.118,107.909 708.127,107.913 708.136,107.916 708.145,107.919 708.155,107.922 708.164,107.925 708.173,107.929 708.182,107.932 708.191,107.935 708.2,107.938 708.21,107.942 708.219,107.945 708.228,107.948 708.237,107.951 708.246,107.955 708.256,107.958 708.265,107.961 708.274,107.964 708.283,107.968 708.292,107.971 708.302,107.974 708.311,107.977 708.32,107.981 708.329,107.984 708.338,107.987 708.347,107.99 708.357,107.994 708.366,107.997 708.375,108 708.384,108.003 708.393,108.007 708.403,108.01 708.412,108.013 708.421,108.016 708.43,108.02 708.439,108.023 708.449,108.026 708.458,108.029 708.467,108.032 708.476,108.036 708.485,108.039 708.495,108.042 708.504,108.045 708.513,108.049 708.522,108.052 708.531,108.055 708.54,108.058 708.55,108.062 708.559,108.065 708.568,108.068 708.577,108.071 708.586,108.075 708.596,108.078 708.605,108.081 708.614,108.084 708.623,108.088 708.632,108.091 708.642,108.094 708.651,108.097 708.66,108.101 708.669,108.104 708.678,108.107 708.688,108.11 708.697,108.114 708.706,108.117 708.715,108.12 708.724,108.123 708.733,108.127 708.743,108.13 708.752,108.133 708.761,108.136 708.77,108.139 708.779,108.143 708.789,108.146 708.798,108.149 708.807,108.152 708.816,108.156 708.825,108.159 708.835,108.162 708.844,108.165 708.853,108.169 708.862,108.172 708.871,108.175 708.88,108.178 708.89,108.182 708.899,108.185 708.908,108.188 708.917,108.191 708.926,108.195 708.936,108.198 708.945,108.201 708.954,108.204 708.963,108.208 708.972,108.211 708.982,108.214 708.991,108.217 709,108.22 709.009,108.224 709.018,108.227 709.028,108.23 709.037,108.233 709.046,108.237 709.055,108.24 709.064,108.243 709.073,108.246 709.083,108.25 709.092,108.253 709.101,108.256 709.11,108.259 709.119,108.263 709.129,108.266 709.138,108.269 709.147,108.272 709.156,108.276 709.165,108.279 709.175,108.282 709.184,108.285 709.193,108.289 709.202,108.292 709.211,108.295 709.22,108.298 709.23,108.302 709.239,108.305 709.248,108.308 709.257,108.311 709.266,108.314 709.276,108.318 709.285,108.321 709.294,108.324 709.303,108.327 709.312,108.331 709.322,108.334 709.331,108.337 709.34,108.34 709.349,108.344 709.358,108.347 709.368,108.35 709.377,108.353 709.386,108.357 709.395,108.36 709.404,108.363 709.413,108.366 709.423,108.37 709.432,108.373 709.441,108.376 709.45,108.379 709.459,108.382 709.469,108.386 709.478,108.389 709.487,108.392 709.496,108.395 709.505,108.399 709.515,108.402 709.524,108.405 709.533,108.408 709.542,108.412 709.551,108.415 709.56,108.418 709.57,108.421 709.579,108.425 709.588,108.428 709.597,108.431 709.606,108.434 709.616,108.438 709.625,108.441 709.634,108.444 709.643,108.447 709.652,108.451 709.662,108.454 709.671,108.457 709.68,108.46 709.689,108.463 709.698,108.467 709.708,108.47 709.717,108.473 709.726,108.476 709.735,108.48 709.744,108.483 709.753,108.486 709.763,108.489 709.772,108.493 709.781,108.496 709.79,108.499 709.799,108.502 709.809,108.506 709.818,108.509 709.827,108.512 709.836,108.515 709.845,108.519 709.855,108.522 709.864,108.525 709.873,108.528 709.882,108.531 709.891,108.535 709.9,108.538 709.91,108.541 709.919,108.544 709.928,108.548 709.937,108.551 709.946,108.554 709.956,108.557 709.965,108.561 709.974,108.564 709.983,108.567 709.992,108.57 710.002,108.574 710.011,108.577 710.02,108.58 710.029,108.583 710.038,108.587 710.048,108.59 710.057,108.593 710.066,108.596 710.075,108.599 710.084,108.603 710.093,108.606 710.103,108.609 710.112,108.612 710.121,108.616 710.13,108.619 710.139,108.622 710.149,108.625 710.158,108.629 710.167,108.632 710.176,108.635 710.185,108.638 710.195,108.642 710.204,108.645 710.213,108.648 710.222,108.651 710.231,108.655 710.24,108.658 710.25,108.661 710.259,108.664 710.268,108.667 710.277,108.671 710.286,108.674 710.296,108.677 710.305,108.68 710.314,108.684 710.323,108.687 710.332,108.69 710.342,108.693 710.351,108.697 710.36,108.7 710.369,108.703 710.378,108.706 710.388,108.71 710.397,108.713 710.406,108.716 710.415,108.719 710.424,108.723 710.433,108.726 710.443,108.729 710.452,108.732 710.461,108.735 710.47,108.739 710.479,108.742 710.489,108.745 710.498,108.748 710.507,108.752 710.516,108.755 710.525,108.758 710.535,108.761 710.544,108.765 710.553,108.768 710.562,108.771 710.571,108.774 710.58,108.778 710.59,108.781 710.599,108.784 710.608,108.787 710.617,108.79 710.626,108.794 710.636,108.797 710.645,108.8 710.654,108.803 710.663,108.807 710.672,108.81 710.682,108.813 710.691,108.816 710.7,108.82 710.709,108.823 710.718,108.826 710.728,108.829 710.737,108.833 710.746,108.836 710.755,108.839 710.764,108.842 710.773,108.845 710.783,108.849 710.792,108.852 710.801,108.855 710.81,108.858 710.819,108.862 710.829,108.865 710.838,108.868 710.847,108.871 710.856,108.875 710.865,108.878 710.875,108.881 710.884,108.884 710.893,108.888 710.902,108.891 710.911,108.894 710.92,108.897 710.93,108.9 710.939,108.904 710.948,108.907 710.957,108.91 710.966,108.913 710.976,108.917 710.985,108.92 710.994,108.923 711.003,108.926 711.012,108.93 711.022,108.933 711.031,108.936 711.04,108.939 711.049,108.943 711.058,108.946 711.068,108.949 711.077,108.952 711.086,108.955 711.095,108.959 711.104,108.962 711.113,108.965 711.123,108.968 711.132,108.972 711.141,108.975 711.15,108.978 711.159,108.981 711.169,108.985 711.178,108.988 711.187,108.991 711.196,108.994 711.205,108.998 711.215,109.001 711.224,109.004 711.233,109.007 711.242,109.01 711.251,109.014 711.261,109.017 711.27,109.02 711.279,109.023 711.288,109.027 711.297,109.03 711.306,109.033 711.316,109.036 711.325,109.04 711.334,109.043 711.343,109.046 711.352,109.049 711.362,109.053 711.371,109.056 711.38,109.059 711.389,109.062 711.398,109.065 711.408,109.069 711.417,109.072 711.426,109.075 711.435,109.078 711.444,109.082 711.453,109.085 711.463,109.088 711.472,109.091 711.481,109.095 711.49,109.098 711.499,109.101 711.509,109.104 711.518,109.108 711.527,109.111 711.536,109.114 711.545,109.117 711.555,109.12 711.564,109.124 711.573,109.127 711.582,109.13 711.591,109.133 711.601,109.137 711.61,109.14 711.619,109.143 711.628,109.146 711.637,109.15 711.646,109.153 711.656,109.156 711.665,109.159 711.674,109.162 711.683,109.166 711.692,109.169 711.702,109.172 711.711,109.175 711.72,109.179 711.729,109.182 711.738,109.185 711.748,109.188 711.757,109.192 711.766,109.195 711.775,109.198 711.784,109.201 711.793,109.205 711.803,109.208 711.812,109.211 711.821,109.214 711.83,109.217 711.839,109.221 711.849,109.224 711.858,109.227 711.867,109.23 711.876,109.234 711.885,109.237 711.895,109.24 711.904,109.243 711.913,109.247 711.922,109.25 711.931,109.253 711.941,109.256 711.95,109.259 711.959,109.263 711.968,109.266 711.977,109.269 711.986,109.272 711.996,109.276 712.005,109.279 712.014,109.282 712.023,109.285 712.032,109.289 712.042,109.292 712.051,109.295 712.06,109.298 712.069,109.302 712.078,109.305 712.088,109.308 712.097,109.311 712.106,109.314 712.115,109.318 712.124,109.321 712.133,109.324 712.143,109.327 712.152,109.331 712.161,109.334 712.17,109.337 712.179,109.34 712.189,109.344 712.198,109.347 712.207,109.35 712.216,109.353 712.225,109.356 712.235,109.36 712.244,109.363 712.253,109.366 712.262,109.369 712.271,109.373 712.281,109.376 712.29,109.379 712.299,109.382 712.308,109.386 712.317,109.389 712.326,109.392 712.336,109.395 712.345,109.398 712.354,109.402 712.363,109.405 712.372,109.408 712.382,109.411 712.391,109.415 712.4,109.418 712.409,109.421 712.418,109.424 712.428,109.428 712.437,109.431 712.446,109.434 712.455,109.437 712.464,109.44 712.473,109.444 712.483,109.447 712.492,109.45 712.501,109.453 712.51,109.457 712.519,109.46 712.529,109.463 712.538,109.466 712.547,109.47 712.556,109.473 712.565,109.476 712.575,109.479 712.584,109.482 712.593,109.486 712.602,109.489 712.611,109.492 712.621,109.495 712.63,109.499 712.639,109.502 712.648,109.505 712.657,109.508 712.666,109.512 712.676,109.515 712.685,109.518 712.694,109.521 712.703,109.525 712.712,109.528 712.722,109.531 712.731,109.534 712.74,109.537 712.749,109.541 712.758,109.544 712.768,109.547 712.777,109.55 712.786,109.554 712.795,109.557 712.804,109.56 712.813,109.563 712.823,109.567 712.832,109.57 712.841,109.573 712.85,109.576 712.859,109.579 712.869,109.583 712.878,109.586 712.887,109.589 712.896,109.592 712.905,109.596 712.915,109.599 712.924,109.602 712.933,109.605 712.942,109.608 712.951,109.612 712.961,109.615 712.97,109.618 712.979,109.621 712.988,109.625 712.997,109.628 713.006,109.631 713.016,109.634 713.025,109.638 713.034,109.641 713.043,109.644 713.052,109.647 713.062,109.65 713.071,109.654 713.08,109.657 713.089,109.66 713.098,109.663 713.108,109.667 713.117,109.67 713.126,109.673 713.135,109.676 713.144,109.68 713.153,109.683 713.163,109.686 713.172,109.689 713.181,109.692 713.19,109.696 713.199,109.699 713.209,109.702 713.218,109.705 713.227,109.709 713.236,109.712 713.245,109.715 713.255,109.718 713.264,109.722 713.273,109.725 713.282,109.728 713.291,109.731 713.301,109.734 713.31,109.738 713.319,109.741 713.328,109.744 713.337,109.747 713.346,109.751 713.356,109.754 713.365,109.757 713.374,109.76 713.383,109.764 713.392,109.767 713.402,109.77 713.411,109.773 713.42,109.776 713.429,109.78 713.438,109.783 713.448,109.786 713.457,109.789 713.466,109.793 713.475,109.796 713.484,109.799 713.493,109.802 713.503,109.805 713.512,109.809 713.521,109.812 713.53,109.815 713.539,109.818 713.549,109.822 713.558,109.825 713.567,109.828 713.576,109.831 713.585,109.835 713.595,109.838 713.604,109.841 713.613,109.844 713.622,109.847 713.631,109.851 713.641,109.854 713.65,109.857 713.659,109.86 713.668,109.864 713.677,109.867 713.686,109.87 713.696,109.873 713.705,109.877 713.714,109.88 713.723,109.883 713.732,109.886 713.742,109.889 713.751,109.893 713.76,109.896 713.769,109.899 713.778,109.902 713.788,109.906 713.797,109.909 713.806,109.912 713.815,109.915 713.824,109.918 713.834,109.922 713.843,109.925 713.852,109.928 713.861,109.931 713.87,109.935 713.879,109.938 713.889,109.941 713.898,109.944 713.907,109.948 713.916,109.951 713.925,109.954 713.935,109.957 713.944,109.96 713.953,109.964 713.962,109.967 713.971,109.97 713.981,109.973 713.99,109.977 713.999,109.98 714.008,109.983 714.017,109.986 714.026,109.989 714.036,109.993 714.045,109.996 714.054,109.999 714.063,110.002 714.072,110.006 714.082,110.009 714.091,110.012 714.1,110.015 714.109,110.019 714.118,110.022 714.128,110.025 714.137,110.028 714.146,110.031 714.155,110.035 714.164,110.038 714.174,110.041 714.183,110.044 714.192,110.048 714.201,110.051 714.21,110.054 714.219,110.057 714.229,110.06 714.238,110.064 714.247,110.067 714.256,110.07 714.265,110.073 714.275,110.077 714.284,110.08 714.293,110.083 714.302,110.086 714.311,110.09 714.321,110.093 714.33,110.096 714.339,110.099 714.348,110.102 714.357,110.106 714.366,110.109 714.376,110.112 714.385,110.115 714.394,110.119 714.403,110.122 714.412,110.125 714.422,110.128 714.431,110.131 714.44,110.135 714.449,110.138 714.458,110.141 714.468,110.144 714.477,110.148 714.486,110.151 714.495,110.154 714.504,110.157 714.514,110.161 714.523,110.164 714.532,110.167 714.541,110.17 714.55,110.173 714.559,110.177 714.569,110.18 714.578,110.183 714.587,110.186 714.596,110.19 714.605,110.193 714.615,110.196 714.624,110.199 714.633,110.202 714.642,110.206 714.651,110.209 714.661,110.212 714.67,110.215 714.679,110.219 714.688,110.222 714.697,110.225 714.706,110.228 714.716,110.231 714.725,110.235 714.734,110.238 714.743,110.241 714.752,110.244 714.762,110.248 714.771,110.251 714.78,110.254 714.789,110.257 714.798,110.261 714.808,110.264 714.817,110.267 714.826,110.27 714.835,110.273 714.844,110.277 714.854,110.28 714.863,110.283 714.872,110.286 714.881,110.29 714.89,110.293 714.899,110.296 714.909,110.299 714.918,110.302 714.927,110.306 714.936,110.309 714.945,110.312 714.955,110.315 714.964,110.319 714.973,110.322 714.982,110.325 714.991,110.328 715.001,110.331 715.01,110.335 715.019,110.338 715.028,110.341 715.037,110.344 715.046,110.348 715.056,110.351 715.065,110.354 715.074,110.357 715.083,110.36 715.092,110.364 715.102,110.367 715.111,110.37 715.12,110.373 715.129,110.377 715.138,110.38 715.148,110.383 715.157,110.386 715.166,110.39 715.175,110.393 715.184,110.396 715.194,110.399 715.203,110.402 715.212,110.406 715.221,110.409 715.23,110.412 715.239,110.415 715.249,110.419 715.258,110.422 715.267,110.425 715.276,110.428 715.285,110.431 715.295,110.435 715.304,110.438 715.313,110.441 715.322,110.444 715.331,110.448 715.341,110.451 715.35,110.454 715.359,110.457 715.368,110.46 715.377,110.464 715.386,110.467 715.396,110.47 715.405,110.473 715.414,110.477 715.423,110.48 715.432,110.483 715.442,110.486 715.451,110.489 715.46,110.493 715.469,110.496 715.478,110.499 715.488,110.502 715.497,110.506 715.506,110.509 715.515,110.512 715.524,110.515 715.534,110.518 715.543,110.522 715.552,110.525 715.561,110.528 715.57,110.531 715.579,110.535 715.589,110.538 715.598,110.541 715.607,110.544 715.616,110.547 715.625,110.551 715.635,110.554 715.644,110.557 715.653,110.56 715.662,110.564 715.671,110.567 715.681,110.57 715.69,110.573 715.699,110.576 715.708,110.58 715.717,110.583 715.726,110.586 715.736,110.589 715.745,110.593 715.754,110.596 715.763,110.599 715.772,110.602 715.782,110.605 715.791,110.609 715.8,110.612 715.809,110.615 715.818,110.618 715.828,110.622 715.837,110.625 715.846,110.628 715.855,110.631 715.864,110.634 715.874,110.638 715.883,110.641 715.892,110.644 715.901,110.647 715.91,110.651 715.919,110.654 715.929,110.657 715.938,110.66 715.947,110.663 715.956,110.667 715.965,110.67 715.975,110.673 715.984,110.676 715.993,110.68 716.002,110.683 716.011,110.686 716.021,110.689 716.03,110.692 716.039,110.696 716.048,110.699 716.057,110.702 716.067,110.705 716.076,110.709 716.085,110.712 716.094,110.715 716.103,110.718 716.112,110.721 716.122,110.725 716.131,110.728 716.14,110.731 716.149,110.734 716.158,110.738 716.168,110.741 716.177,110.744 716.186,110.747 716.195,110.75 716.204,110.754 716.214,110.757 716.223,110.76 716.232,110.763 716.241,110.767 716.25,110.77 716.259,110.773 716.269,110.776 716.278,110.779 716.287,110.783 716.296,110.786 716.305,110.789 716.315,110.792 716.324,110.796 716.333,110.799 716.342,110.802 716.351,110.805 716.361,110.808 716.37,110.812 716.379,110.815 716.388,110.818 716.397,110.821 716.407,110.825 716.416,110.828 716.425,110.831 716.434,110.834 716.443,110.837 716.452,110.841 716.462,110.844 716.471,110.847 716.48,110.85 716.489,110.854 716.498,110.857 716.508,110.86 716.517,110.863 716.526,110.866 716.535,110.87 716.544,110.873 716.554,110.876 716.563,110.879 716.572,110.883 716.581,110.886 716.59,110.889 716.599,110.892 716.609,110.895 716.618,110.899 716.627,110.902 716.636,110.905 716.645,110.908 716.655,110.912 716.664,110.915 716.673,110.918 716.682,110.921 716.691,110.924 716.701,110.928 716.71,110.931 716.719,110.934 716.728,110.937 716.737,110.941 716.747,110.944 716.756,110.947 716.765,110.95 716.774,110.953 716.783,110.957 716.792,110.96 716.802,110.963 716.811,110.966 716.82,110.97 716.829,110.973 716.838,110.976 716.848,110.979 716.857,110.982 716.866,110.986 716.875,110.989 716.884,110.992 716.894,110.995 716.903,110.998 716.912,111.002 716.921,111.005 716.93,111.008 716.939,111.011 716.949,111.015 716.958,111.018 716.967,111.021 716.976,111.024 716.985,111.027 716.995,111.031 717.004,111.034 717.013,111.037 717.022,111.04 717.031,111.044 717.041,111.047 717.05,111.05 717.059,111.053 717.068,111.056 717.077,111.06 717.087,111.063 717.096,111.066 717.105,111.069 717.114,111.073 717.123,111.076 717.132,111.079 717.142,111.082 717.151,111.085 717.16,111.089 717.169,111.092 717.178,111.095 717.188,111.098 717.197,111.102 717.206,111.105 717.215,111.108 717.224,111.111 717.234,111.114 717.243,111.118 717.252,111.121 717.261,111.124 717.27,111.127 717.279,111.13 717.289,111.134 717.298,111.137 717.307,111.14 717.316,111.143 717.325,111.147 717.335,111.15 717.344,111.153 717.353,111.156 717.362,111.159 717.371,111.163 717.381,111.166 717.39,111.169 717.399,111.172 717.408,111.176 717.417,111.179 717.427,111.182 717.436,111.185 717.445,111.188 717.454,111.192 717.463,111.195 717.472,111.198 717.482,111.201 717.491,111.205 717.5,111.208 717.509,111.211 717.518,111.214 717.528,111.217 717.537,111.221 717.546,111.224 717.555,111.227 717.564,111.23 717.574,111.233 717.583,111.237 717.592,111.24 717.601,111.243 717.61,111.246 717.619,111.25 717.629,111.253 717.638,111.256 717.647,111.259 717.656,111.262 717.665,111.266 717.675,111.269 717.684,111.272 717.693,111.275 717.702,111.279 717.711,111.282 717.721,111.285 717.73,111.288 717.739,111.291 717.748,111.295 717.757,111.298 717.767,111.301 717.776,111.304 717.785,111.307 717.794,111.311 717.803,111.314 717.812,111.317 717.822,111.32 717.831,111.324 717.84,111.327 717.849,111.33 717.858,111.333 717.868,111.336 717.877,111.34 717.886,111.343 717.895,111.346 717.904,111.349 717.914,111.353 717.923,111.356 717.932,111.359 717.941,111.362 717.95,111.365 717.959,111.369 717.969,111.372 717.978,111.375 717.987,111.378 717.996,111.381 718.005,111.385 718.015,111.388 718.024,111.391 718.033,111.394 718.042,111.398 718.051,111.401 718.061,111.404 718.07,111.407 718.079,111.41 718.088,111.414 718.097,111.417 718.107,111.42 718.116,111.423 718.125,111.427 718.134,111.43 718.143,111.433 718.152,111.436 718.162,111.439 718.171,111.443 718.18,111.446 718.189,111.449 718.198,111.452 718.208,111.455 718.217,111.459 718.226,111.462 718.235,111.465 718.244,111.468 718.254,111.472 718.263,111.475 718.272,111.478 718.281,111.481 718.29,111.484 718.299,111.488 718.309,111.491 718.318,111.494 718.327,111.497 718.336,111.5 718.345,111.504 718.355,111.507 718.364,111.51 718.373,111.513 718.382,111.517 718.391,111.52 718.401,111.523 718.41,111.526 718.419,111.529 718.428,111.533 718.437,111.536 718.447,111.539 718.456,111.542 718.465,111.546 718.474,111.549 718.483,111.552 718.492,111.555 718.502,111.558 718.511,111.562 718.52,111.565 718.529,111.568 718.538,111.571 718.548,111.574 718.557,111.578 718.566,111.581 718.575,111.584 718.584,111.587 718.594,111.591 718.603,111.594 718.612,111.597 718.621,111.6 718.63,111.603 718.64,111.607 718.649,111.61 718.658,111.613 718.667,111.616 718.676,111.619 718.685,111.623 718.695,111.626 718.704,111.629 718.713,111.632 718.722,111.636 718.731,111.639 718.741,111.642 718.75,111.645 718.759,111.648 718.768,111.652 718.777,111.655 718.787,111.658 718.796,111.661 718.805,111.664 718.814,111.668 718.823,111.671 718.832,111.674 718.842,111.677 718.851,111.681 718.86,111.684 718.869,111.687 718.878,111.69 718.888,111.693 718.897,111.697 718.906,111.7 718.915,111.703 718.924,111.706 718.934,111.709 718.943,111.713 718.952,111.716 718.961,111.719 718.97,111.722 718.98,111.726 718.989,111.729 718.998,111.732 719.007,111.735 719.016,111.738 719.025,111.742 719.035,111.745 719.044,111.748 719.053,111.751 719.062,111.754 719.071,111.758 719.081,111.761 719.09,111.764 719.099,111.767 719.108,111.771 719.117,111.774 719.127,111.777 719.136,111.78 719.145,111.783 719.154,111.787 719.163,111.79 719.172,111.793 719.182,111.796 719.191,111.799 719.2,111.803 719.209,111.806 719.218,111.809 719.228,111.812 719.237,111.816 719.246,111.819 719.255,111.822 719.264,111.825 719.274,111.828 719.283,111.832 719.292,111.835 719.301,111.838 719.31,111.841 719.32,111.844 719.329,111.848 719.338,111.851 719.347,111.854 719.356,111.857 719.365,111.861 719.375,111.864 719.384,111.867 719.393,111.87 719.402,111.873 719.411,111.877 719.421,111.88 719.43,111.883 719.439,111.886 719.448,111.889 719.457,111.893 719.467,111.896 719.476,111.899 719.485,111.902 719.494,111.906 719.503,111.909 719.512,111.912 719.522,111.915 719.531,111.918 719.54,111.922 719.549,111.925 719.558,111.928 719.568,111.931 719.577,111.934 719.586,111.938 719.595,111.941 719.604,111.944 719.614,111.947 719.623,111.951 719.632,111.954 719.641,111.957 719.65,111.96 719.66,111.963 719.669,111.967 719.678,111.97 719.687,111.973 719.696,111.976 719.705,111.979 719.715,111.983 719.724,111.986 719.733,111.989 719.742,111.992 719.751,111.995 719.761,111.999 719.77,112.002 719.779,112.005 719.788,112.008 719.797,112.012 719.807,112.015 719.816,112.018 719.825,112.021 719.834,112.024 719.843,112.028 719.852,112.031 719.862,112.034 719.871,112.037 719.88,112.04 719.889,112.044 719.898,112.047 719.908,112.05 719.917,112.053 719.926,112.057 719.935,112.06 719.944,112.063 719.954,112.066 719.963,112.069 719.972,112.073 719.981,112.076 719.99,112.079 720,112.082 720.009,112.085 720.018,112.089 720.027,112.092 720.036,112.095 720.045,112.098 720.055,112.101 720.064,112.105 720.073,112.108 720.082,112.111 720.091,112.114 720.101,112.118 720.11,112.121 720.119,112.124 720.128,112.127 720.137,112.13 720.147,112.134 720.156,112.137 720.165,112.14 720.174,112.143 720.183,112.146 720.192,112.15 720.202,112.153 720.211,112.156 720.22,112.159 720.229,112.163 720.238,112.166 720.248,112.169 720.257,112.172 720.266,112.175 720.275,112.179 720.284,112.182 720.294,112.185 720.303,112.188 720.312,112.191 720.321,112.195 720.33,112.198 720.34,112.201 720.349,112.204 720.358,112.207 720.367,112.211 720.376,112.214 720.385,112.217 720.395,112.22 720.404,112.224 720.413,112.227 720.422,112.23 720.431,112.233 720.441,112.236 720.45,112.24 720.459,112.243 720.468,112.246 720.477,112.249 720.487,112.252 720.496,112.256 720.505,112.259 720.514,112.262 720.523,112.265 720.532,112.268 720.542,112.272 720.551,112.275 720.56,112.278 720.569,112.281 720.578,112.285 720.588,112.288 720.597,112.291 720.606,112.294 720.615,112.297 720.624,112.301 720.634,112.304 720.643,112.307 720.652,112.31 720.661,112.313 720.67,112.317 720.68,112.32 720.689,112.323 720.698,112.326 720.707,112.329 720.716,112.333 720.725,112.336 720.735,112.339 720.744,112.342 720.753,112.346 720.762,112.349 720.771,112.352 720.781,112.355 720.79,112.358 720.799,112.362 720.808,112.365 720.817,112.368 720.827,112.371 720.836,112.374 720.845,112.378 720.854,112.381 720.863,112.384 720.872,112.387 720.882,112.39 720.891,112.394 720.9,112.397 720.909,112.4 720.918,112.403 720.928,112.406 720.937,112.41 720.946,112.413 720.955,112.416 720.964,112.419 720.974,112.423 720.983,112.426 720.992,112.429 721.001,112.432 721.01,112.435 721.02,112.439 721.029,112.442 721.038,112.445 721.047,112.448 721.056,112.451 721.065,112.455 721.075,112.458 721.084,112.461 721.093,112.464 721.102,112.467 721.111,112.471 721.121,112.474 721.13,112.477 721.139,112.48 721.148,112.484 721.157,112.487 721.167,112.49 721.176,112.493 721.185,112.496 721.194,112.5 721.203,112.503 721.213,112.506 721.222,112.509 721.231,112.512 721.24,112.516 721.249,112.519 721.258,112.522 721.268,112.525 721.277,112.528 721.286,112.532 721.295,112.535 721.304,112.538 721.314,112.541 721.323,112.544 721.332,112.548 721.341,112.551 721.35,112.554 721.36,112.557 721.369,112.561 721.378,112.564 721.387,112.567 721.396,112.57 721.405,112.573 721.415,112.577 721.424,112.58 721.433,112.583 721.442,112.586 721.451,112.589 721.461,112.593 721.47,112.596 721.479,112.599 721.488,112.602 721.497,112.605 721.507,112.609 721.516,112.612 721.525,112.615 721.534,112.618 721.543,112.621 721.553,112.625 721.562,112.628 721.571,112.631 721.58,112.634 721.589,112.637 721.598,112.641 721.608,112.644 721.617,112.647 721.626,112.65 721.635,112.654 721.644,112.657 721.654,112.66 721.663,112.663 721.672,112.666 721.681,112.67 721.69,112.673 721.7,112.676 721.709,112.679 721.718,112.682 721.727,112.686 721.736,112.689 721.745,112.692 721.755,112.695 721.764,112.698 721.773,112.702 721.782,112.705 721.791,112.708 721.801,112.711 721.81,112.714 721.819,112.718 721.828,112.721 721.837,112.724 721.847,112.727 721.856,112.731 721.865,112.734 721.874,112.737 721.883,112.74 721.893,112.743 721.902,112.747 721.911,112.75 721.92,112.753 721.929,112.756 721.938,112.759 721.948,112.763 721.957,112.766 721.966,112.769 721.975,112.772 721.984,112.775 721.994,112.779 722.003,112.782 722.012,112.785 722.021,112.788 722.03,112.791 722.04,112.795 722.049,112.798 722.058,112.801 722.067,112.804 722.076,112.807 722.085,112.811 722.095,112.814 722.104,112.817 722.113,112.82 722.122,112.823 722.131,112.827 722.141,112.83 722.15,112.833 722.159,112.836 722.168,112.84 722.177,112.843 722.187,112.846 722.196,112.849 722.205,112.852 722.214,112.856 722.223,112.859 722.233,112.862 722.242,112.865 722.251,112.868 722.26,112.872 722.269,112.875 722.278,112.878 722.288,112.881 722.297,112.884 722.306,112.888 722.315,112.891 722.324,112.894 722.334,112.897 722.343,112.9 722.352,112.904 722.361,112.907 722.37,112.91 722.38,112.913 722.389,112.916 722.398,112.92 722.407,112.923 722.416,112.926 722.425,112.929 722.435,112.932 722.444,112.936 722.453,112.939 722.462,112.942 722.471,112.945 722.481,112.949 722.49,112.952 722.499,112.955 722.508,112.958 722.517,112.961 722.527,112.965 722.536,112.968 722.545,112.971 722.554,112.974 722.563,112.977 722.573,112.981 722.582,112.984 722.591,112.987 722.6,112.99 722.609,112.993 722.618,112.997 722.628,113 722.637,113.003 722.646,113.006 722.655,113.009 722.664,113.013 722.674,113.016 722.683,113.019 722.692,113.022 722.701,113.025 722.71,113.029 722.72,113.032 722.729,113.035 722.738,113.038 722.747,113.041 722.756,113.045 722.765,113.048 722.775,113.051 722.784,113.054 722.793,113.057 722.802,113.061 722.811,113.064 722.821,113.067 722.83,113.07 722.839,113.074 722.848,113.077 722.857,113.08 722.867,113.083 722.876,113.086 722.885,113.09 722.894,113.093 722.903,113.096 722.913,113.099 722.922,113.102 722.931,113.106 722.94,113.109 722.949,113.112 722.958,113.115 722.968,113.118 722.977,113.122 722.986,113.125 722.995,113.128 723.004,113.131 723.014,113.134 723.023,113.138 723.032,113.141 723.041,113.144 723.05,113.147 723.06,113.15 723.069,113.154 723.078,113.157 723.087,113.16 723.096,113.163 723.105,113.166 723.115,113.17 723.124,113.173 723.133,113.176 723.142,113.179 723.151,113.182 723.161,113.186 723.17,113.189 723.179,113.192 723.188,113.195 723.197,113.198 723.207,113.202 723.216,113.205 723.225,113.208 723.234,113.211 723.243,113.214 723.253,113.218 723.262,113.221 723.271,113.224 723.28,113.227 723.289,113.23 723.298,113.234 723.308,113.237 723.317,113.24 723.326,113.243 723.335,113.247 723.344,113.25 723.354,113.253 723.363,113.256 723.372,113.259 723.381,113.263 723.39,113.266 723.4,113.269 723.409,113.272 723.418,113.275 723.427,113.279 723.436,113.282 723.446,113.285 723.455,113.288 723.464,113.291 723.473,113.295 723.482,113.298 723.491,113.301 723.501,113.304 723.51,113.307 723.519,113.311 723.528,113.314 723.537,113.317 723.547,113.32 723.556,113.323 723.565,113.327 723.574,113.33 723.583,113.333 723.593,113.336 723.602,113.339 723.611,113.343 723.62,113.346 723.629,113.349 723.638,113.352 723.648,113.355 723.657,113.359 723.666,113.362 723.675,113.365 723.684,113.368 723.694,113.371 723.703,113.375 723.712,113.378 723.721,113.381 723.73,113.384 723.74,113.387 723.749,113.391 723.758,113.394 723.767,113.397 723.776,113.4 723.786,113.403 723.795,113.407 723.804,113.41 723.813,113.413 723.822,113.416 723.831,113.419 723.841,113.423 723.85,113.426 723.859,113.429 723.868,113.432 723.877,113.435 723.887,113.439 723.896,113.442 723.905,113.445 723.914,113.448 723.923,113.451 723.933,113.455 723.942,113.458 723.951,113.461 723.96,113.464 723.969,113.467 723.978,113.471 723.988,113.474 723.997,113.477 724.006,113.48 724.015,113.483 724.024,113.487 724.034,113.49 724.043,113.493 724.052,113.496 724.061,113.499 724.07,113.503 724.08,113.506 724.089,113.509 724.098,113.512 724.107,113.515 724.116,113.519 724.126,113.522 724.135,113.525 724.144,113.528 724.153,113.531 724.162,113.535 724.171,113.538 724.181,113.541 724.19,113.544 724.199,113.547 724.208,113.551 724.217,113.554 724.227,113.557 724.236,113.56 724.245,113.563 724.254,113.567 724.263,113.57 724.273,113.573 724.282,113.576 724.291,113.58 724.3,113.583 724.309,113.586 724.318,113.589 724.328,113.592 724.337,113.596 724.346,113.599 724.355,113.602 724.364,113.605 724.374,113.608 724.383,113.612 724.392,113.615 724.401,113.618 724.41,113.621 724.42,113.624 724.429,113.628 724.438,113.631 724.447,113.634 724.456,113.637 724.466,113.64 724.475,113.644 724.484,113.647 724.493,113.65 724.502,113.653 724.511,113.656 724.521,113.66 724.53,113.663 724.539,113.666 724.548,113.669 724.557,113.672 724.567,113.676 724.576,113.679 724.585,113.682 724.594,113.685 724.603,113.688 724.613,113.692 724.622,113.695 724.631,113.698 724.64,113.701 724.649,113.704 724.658,113.708 724.668,113.711 724.677,113.714 724.686,113.717 724.695,113.72 724.704,113.724 724.714,113.727 724.723,113.73 724.732,113.733 724.741,113.736 724.75,113.739 724.76,113.743 724.769,113.746 724.778,113.749 724.787,113.752 724.796,113.755 724.806,113.759 724.815,113.762 724.824,113.765 724.833,113.768 724.842,113.771 724.851,113.775 724.861,113.778 724.87,113.781 724.879,113.784 724.888,113.787 724.897,113.791 724.907,113.794 724.916,113.797 724.925,113.8 724.934,113.803 724.943,113.807 724.953,113.81 724.962,113.813 724.971,113.816 724.98,113.819 724.989,113.823 724.998,113.826 725.008,113.829 725.017,113.832 725.026,113.835 725.035,113.839 725.044,113.842 725.054,113.845 725.063,113.848 725.072,113.851 725.081,113.855 725.09,113.858 725.1,113.861 725.109,113.864 725.118,113.867 725.127,113.871 725.136,113.874 725.146,113.877 725.155,113.88 725.164,113.883 725.173,113.887 725.182,113.89 725.191,113.893 725.201,113.896 725.21,113.899 725.219,113.903 725.228,113.906 725.237,113.909 725.247,113.912 725.256,113.915 725.265,113.919 725.274,113.922 725.283,113.925 725.293,113.928 725.302,113.931 725.311,113.935 725.32,113.938 725.329,113.941 725.338,113.944 725.348,113.947 725.357,113.951 725.366,113.954 725.375,113.957 725.384,113.96 725.394,113.963 725.403,113.967 725.412,113.97 725.421,113.973 725.43,113.976 725.44,113.979 725.449,113.983 725.458,113.986 725.467,113.989 725.476,113.992 725.486,113.995 725.495,113.999 725.504,114.002 725.513,114.005 725.522,114.008 725.531,114.011 725.541,114.015 725.55,114.018 725.559,114.021 725.568,114.024 725.577,114.027 725.587,114.031 725.596,114.034 725.605,114.037 725.614,114.04 725.623,114.043 725.633,114.047 725.642,114.05 725.651,114.053 725.66,114.056 725.669,114.059 725.678,114.063 725.688,114.066 725.697,114.069 725.706,114.072 725.715,114.075 725.724,114.078 725.734,114.082 725.743,114.085 725.752,114.088 725.761,114.091 725.77,114.094 725.78,114.098 725.789,114.101 725.798,114.104 725.807,114.107 725.816,114.11 725.826,114.114 725.835,114.117 725.844,114.12 725.853,114.123 725.862,114.126 725.871,114.13 725.881,114.133 725.89,114.136 725.899,114.139 725.908,114.142 725.917,114.146 725.927,114.149 725.936,114.152 725.945,114.155 725.954,114.158 725.963,114.162 725.973,114.165 725.982,114.168 725.991,114.171 726,114.174 726.009,114.178 726.019,114.181 726.028,114.184 726.037,114.187 726.046,114.19 726.055,114.194 726.064,114.197 726.074,114.2 726.083,114.203 726.092,114.206 726.101,114.21 726.11,114.213 726.12,114.216 726.129,114.219 726.138,114.222 726.147,114.226 726.156,114.229 726.166,114.232 726.175,114.235 726.184,114.238 726.193,114.242 726.202,114.245 726.211,114.248 726.221,114.251 726.23,114.254 726.239,114.257 726.248,114.261 726.257,114.264 726.267,114.267 726.276,114.27 726.285,114.273 726.294,114.277 726.303,114.28 726.313,114.283 726.322,114.286 726.331,114.289 726.34,114.293 726.349,114.296 726.359,114.299 726.368,114.302 726.377,114.305 726.386,114.309 726.395,114.312 726.404,114.315 726.414,114.318 726.423,114.321 726.432,114.325 726.441,114.328 726.45,114.331 726.46,114.334 726.469,114.337 726.478,114.341 726.487,114.344 726.496,114.347 726.506,114.35 726.515,114.353 726.524,114.357 726.533,114.36 726.542,114.363 726.551,114.366 726.561,114.369 726.57,114.373 726.579,114.376 726.588,114.379 726.597,114.382 726.607,114.385 726.616,114.388 726.625,114.392 726.634,114.395 726.643,114.398 726.653,114.401 726.662,114.404 726.671,114.408 726.68,114.411 726.689,114.414 726.699,114.417 726.708,114.42 726.717,114.424 726.726,114.427 726.735,114.43 726.744,114.433 726.754,114.436 726.763,114.44 726.772,114.443 726.781,114.446 726.79,114.449 726.8,114.452 726.809,114.456 726.818,114.459 726.827,114.462 726.836,114.465 726.846,114.468 726.855,114.472 726.864,114.475 726.873,114.478 726.882,114.481 726.891,114.484 726.901,114.488 726.91,114.491 726.919,114.494 726.928,114.497 726.937,114.5 726.947,114.503 726.956,114.507 726.965,114.51 726.974,114.513 726.983,114.516 726.993,114.519 727.002,114.523 727.011,114.526 727.02,114.529 727.029,114.532 727.039,114.535 727.048,114.539 727.057,114.542 727.066,114.545 727.075,114.548 727.084,114.551 727.094,114.555 727.103,114.558 727.112,114.561 727.121,114.564 727.13,114.567 727.14,114.571 727.149,114.574 727.158,114.577 727.167,114.58 727.176,114.583 727.186,114.586 727.195,114.59 727.204,114.593 727.213,114.596 727.222,114.599 727.231,114.602 727.241,114.606 727.25,114.609 727.259,114.612 727.268,114.615 727.277,114.618 727.287,114.622 727.296,114.625 727.305,114.628 727.314,114.631 727.323,114.634 727.333,114.638 727.342,114.641 727.351,114.644 727.36,114.647 727.369,114.65 727.379,114.654 727.388,114.657 727.397,114.66 727.406,114.663 727.415,114.666 727.424,114.67 727.434,114.673 727.443,114.676 727.452,114.679 727.461,114.682 727.47,114.685 727.48,114.689 727.489,114.692 727.498,114.695 727.507,114.698 727.516,114.701 727.526,114.705 727.535,114.708 727.544,114.711 727.553,114.714 727.562,114.717 727.571,114.721 727.581,114.724 727.59,114.727 727.599,114.73 727.608,114.733 727.617,114.737 727.627,114.74 727.636,114.743 727.645,114.746 727.654,114.749 727.663,114.753 727.673,114.756 727.682,114.759 727.691,114.762 727.7,114.765 727.709,114.768 727.719,114.772 727.728,114.775 727.737,114.778 727.746,114.781 727.755,114.784 727.764,114.788 727.774,114.791 727.783,114.794 727.792,114.797 727.801,114.8 727.81,114.804 727.82,114.807 727.829,114.81 727.838,114.813 727.847,114.816 727.856,114.82 727.866,114.823 727.875,114.826 727.884,114.829 727.893,114.832 727.902,114.835 727.911,114.839 727.921,114.842 727.93,114.845 727.939,114.848 727.948,114.851 727.957,114.855 727.967,114.858 727.976,114.861 727.985,114.864 727.994,114.867 728.003,114.871 728.013,114.874 728.022,114.877 728.031,114.88 728.04,114.883 728.049,114.887 728.059,114.89 728.068,114.893 728.077,114.896 728.086,114.899 728.095,114.902 728.104,114.906 728.114,114.909 728.123,114.912 728.132,114.915 728.141,114.918 728.15,114.922 728.16,114.925 728.169,114.928 728.178,114.931 728.187,114.934 728.196,114.938 728.206,114.941 728.215,114.944 728.224,114.947 728.233,114.95 728.242,114.954 728.251,114.957 728.261,114.96 728.27,114.963 728.279,114.966 728.288,114.969 728.297,114.973 728.307,114.976 728.316,114.979 728.325,114.982 728.334,114.985 728.343,114.989 728.353,114.992 728.362,114.995 728.371,114.998 728.38,115.001 728.389,115.005 728.399,115.008 728.408,115.011 728.417,115.014 728.426,115.017 728.435,115.021 728.444,115.024 728.454,115.027 728.463,115.03 728.472,115.033 728.481,115.036 728.49,115.04 728.5,115.043 728.509,115.046 728.518,115.049 728.527,115.052 728.536,115.056 728.546,115.059 728.555,115.062 728.564,115.065 728.573,115.068 728.582,115.072 728.592,115.075 728.601,115.078 728.61,115.081 728.619,115.084 728.628,115.088 728.637,115.091 728.647,115.094 728.656,115.097 728.665,115.1 728.674,115.103 728.683,115.107 728.693,115.11 728.702,115.113 728.711,115.116 728.72,115.119 728.729,115.123 728.739,115.126 728.748,115.129 728.757,115.132 728.766,115.135 728.775,115.139 728.784,115.142 728.794,115.145 728.803,115.148 728.812,115.151 728.821,115.154 728.83,115.158 728.84,115.161 728.849,115.164 728.858,115.167 728.867,115.17 728.876,115.174 728.886,115.177 728.895,115.18 728.904,115.183 728.913,115.186 728.922,115.19 728.932,115.193 728.941,115.196 728.95,115.199 728.959,115.202 728.968,115.205 728.977,115.209 728.987,115.212 728.996,115.215 729.005,115.218 729.014,115.221 729.023,115.225 729.033,115.228 729.042,115.231 729.051,115.234 729.06,115.237 729.069,115.241 729.079,115.244 729.088,115.247 729.097,115.25 729.106,115.253 729.115,115.257 729.124,115.26 729.134,115.263 729.143,115.266 729.152,115.269 729.161,115.272 729.17,115.276 729.18,115.279 729.189,115.282 729.198,115.285 729.207,115.288 729.216,115.292 729.226,115.295 729.235,115.298 729.244,115.301 729.253,115.304 729.262,115.308 729.272,115.311 729.281,115.314 729.29,115.317 729.299,115.32 729.308,115.323 729.317,115.327 729.327,115.33 729.336,115.333 729.345,115.336 729.354,115.339 729.363,115.343 729.373,115.346 729.382,115.349 729.391,115.352 729.4,115.355 729.409,115.359 729.419,115.362 729.428,115.365 729.437,115.368 729.446,115.371 729.455,115.374 729.464,115.378 729.474,115.381 729.483,115.384 729.492,115.387 729.501,115.39 729.51,115.394 729.52,115.397 729.529,115.4 729.538,115.403 729.547,115.406 729.556,115.41 729.566,115.413 729.575,115.416 729.584,115.419 729.593,115.422 729.602,115.425 729.612,115.429 729.621,115.432 729.63,115.435 729.639,115.438 729.648,115.441 729.657,115.445 729.667,115.448 729.676,115.451 729.685,115.454 729.694,115.457 729.703,115.46 729.713,115.464 729.722,115.467 729.731,115.47 729.74,115.473 729.749,115.476 729.759,115.48 729.768,115.483 729.777,115.486 729.786,115.489 729.795,115.492 729.804,115.496 729.814,115.499 729.823,115.502 729.832,115.505 729.841,115.508 729.85,115.511 729.86,115.515 729.869,115.518 729.878,115.521 729.887,115.524 729.896,115.527 729.906,115.531 729.915,115.534 729.924,115.537 729.933,115.54 729.942,115.543 729.952,115.547 729.961,115.55 729.97,115.553 729.979,115.556 729.988,115.559 729.997,115.562 730.007,115.566 730.016,115.569 730.025,115.572 730.034,115.575 730.043,115.578 730.053,115.582 730.062,115.585 730.071,115.588 730.08,115.591 730.089,115.594 730.099,115.597 730.108,115.601 730.117,115.604 730.126,115.607 730.135,115.61 730.144,115.613 730.154,115.617 730.163,115.62 730.172,115.623 730.181,115.626 730.19,115.629 730.2,115.633 730.209,115.636 730.218,115.639 730.227,115.642 730.236,115.645 730.246,115.648 730.255,115.652 730.264,115.655 730.273,115.658 730.282,115.661 730.292,115.664 730.301,115.668 730.31,115.671 730.319,115.674 730.328,115.677 730.337,115.68 730.347,115.683 730.356,115.687 730.365,115.69 730.374,115.693 730.383,115.696 730.393,115.699 730.402,115.703 730.411,115.706 730.42,115.709 730.429,115.712 730.439,115.715 730.448,115.719 730.457,115.722 730.466,115.725 730.475,115.728 730.484,115.731 730.494,115.734 730.503,115.738 730.512,115.741 730.521,115.744 730.53,115.747 730.54,115.75 730.549,115.754 730.558,115.757 730.567,115.76 730.576,115.763 730.586,115.766 730.595,115.769 730.604,115.773 730.613,115.776 730.622,115.779 730.632,115.782 730.641,115.785 730.65,115.789 730.659,115.792 730.668,115.795 730.677,115.798 730.687,115.801 730.696,115.805 730.705,115.808 730.714,115.811 730.723,115.814 730.733,115.817 730.742,115.82 730.751,115.824 730.76,115.827 730.769,115.83 730.779,115.833 730.788,115.836 730.797,115.84 730.806,115.843 730.815,115.846 730.825,115.849 730.834,115.852 730.843,115.855 730.852,115.859 730.861,115.862 730.87,115.865 730.88,115.868 730.889,115.871 730.898,115.875 730.907,115.878 730.916,115.881 730.926,115.884 730.935,115.887 730.944,115.89 730.953,115.894 730.962,115.897 730.972,115.9 730.981,115.903 730.99,115.906 730.999,115.91 731.008,115.913 731.017,115.916 731.027,115.919 731.036,115.922 731.045,115.925 731.054,115.929 731.063,115.932 731.073,115.935 731.082,115.938 731.091,115.941 731.1,115.945 731.109,115.948 731.119,115.951 731.128,115.954 731.137,115.957 731.146,115.96 731.155,115.964 731.165,115.967 731.174,115.97 731.183,115.973 731.192,115.976 731.201,115.98 731.21,115.983 731.22,115.986 731.229,115.989 731.238,115.992 731.247,115.995 731.256,115.999 731.266,116.002 731.275,116.005 731.284,116.008 731.293,116.011 731.302,116.015 731.312,116.018 731.321,116.021 731.33,116.024 731.339,116.027 731.348,116.031 731.357,116.034 731.367,116.037 731.376,116.04 731.385,116.043 731.394,116.046 731.403,116.05 731.413,116.053 731.422,116.056 731.431,116.059 731.44,116.062 731.449,116.066 731.459,116.069 731.468,116.072 731.477,116.075 731.486,116.078 731.495,116.081 731.505,116.085 731.514,116.088 731.523,116.091 731.532,116.094 731.541,116.097 731.55,116.101 731.56,116.104 731.569,116.107 731.578,116.11 731.587,116.113 731.596,116.116 731.606,116.12 731.615,116.123 731.624,116.126 731.633,116.129 731.642,116.132 731.652,116.136 731.661,116.139 731.67,116.142 731.679,116.145 731.688,116.148 731.697,116.151 731.707,116.155 731.716,116.158 731.725,116.161 731.734,116.164 731.743,116.167 731.753,116.17 731.762,116.174 731.771,116.177 731.78,116.18 731.789,116.183 731.799,116.186 731.808,116.19 731.817,116.193 731.826,116.196 731.835,116.199 731.845,116.202 731.854,116.205 731.863,116.209 731.872,116.212 731.881,116.215 731.89,116.218 731.9,116.221 731.909,116.225 731.918,116.228 731.927,116.231 731.936,116.234 731.946,116.237 731.955,116.24 731.964,116.244 731.973,116.247 731.982,116.25 731.992,116.253 732.001,116.256 732.01,116.26 732.019,116.263 732.028,116.266 732.037,116.269 732.047,116.272 732.056,116.275 732.065,116.279 732.074,116.282 732.083,116.285 732.093,116.288 732.102,116.291 732.111,116.295 732.12,116.298 732.129,116.301 732.139,116.304 732.148,116.307 732.157,116.31 732.166,116.314 732.175,116.317 732.185,116.32 732.194,116.323 732.203,116.326 732.212,116.33 732.221,116.333 732.23,116.336 732.24,116.339 732.249,116.342 732.258,116.345 732.267,116.349 732.276,116.352 732.286,116.355 732.295,116.358 732.304,116.361 732.313,116.365 732.322,116.368 732.332,116.371 732.341,116.374 732.35,116.377 732.359,116.38 732.368,116.384 732.377,116.387 732.387,116.39 732.396,116.393 732.405,116.396 732.414,116.399 732.423,116.403 732.433,116.406 732.442,116.409 732.451,116.412 732.46,116.415 732.469,116.419 732.479,116.422 732.488,116.425 732.497,116.428 732.506,116.431 732.515,116.434 732.525,116.438 732.534,116.441 732.543,116.444 732.552,116.447 732.561,116.45 732.57,116.454 732.58,116.457 732.589,116.46 732.598,116.463 732.607,116.466 732.616,116.469 732.626,116.473 732.635,116.476 732.644,116.479 732.653,116.482 732.662,116.485 732.672,116.489 732.681,116.492 732.69,116.495 732.699,116.498 732.708,116.501 732.717,116.504 732.727,116.508 732.736,116.511 732.745,116.514 732.754,116.517 732.763,116.52 732.773,116.523 732.782,116.527 732.791,116.53 732.8,116.533 732.809,116.536 732.819,116.539 732.828,116.543 732.837,116.546 732.846,116.549 732.855,116.552 732.865,116.555 732.874,116.558 732.883,116.562 732.892,116.565 732.901,116.568 732.91,116.571 732.92,116.574 732.929,116.577 732.938,116.581 732.947,116.584 732.956,116.587 732.966,116.59 732.975,116.593 732.984,116.597 732.993,116.6 733.002,116.603 733.012,116.606 733.021,116.609 733.03,116.612 733.039,116.616 733.048,116.619 733.057,116.622 733.067,116.625 733.076,116.628 733.085,116.632 733.094,116.635 733.103,116.638 733.113,116.641 733.122,116.644 733.131,116.647 733.14,116.651 733.149,116.654 733.159,116.657 733.168,116.66 733.177,116.663 733.186,116.666 733.195,116.67 733.205,116.673 733.214,116.676 733.223,116.679 733.232,116.682 733.241,116.686 733.25,116.689 733.26,116.692 733.269,116.695 733.278,116.698 733.287,116.701 733.296,116.705 733.306,116.708 733.315,116.711 733.324,116.714 733.333,116.717 733.342,116.72 733.352,116.724 733.361,116.727 733.37,116.73 733.379,116.733 733.388,116.736 733.398,116.74 733.407,116.743 733.416,116.746 733.425,116.749 733.434,116.752 733.443,116.755 733.453,116.759 733.462,116.762 733.471,116.765 733.48,116.768 733.489,116.771 733.499,116.774 733.508,116.778 733.517,116.781 733.526,116.784 733.535,116.787 733.545,116.79 733.554,116.794 733.563,116.797 733.572,116.8 733.581,116.803 733.59,116.806 733.6,116.809 733.609,116.813 733.618,116.816 733.627,116.819 733.636,116.822 733.646,116.825 733.655,116.829 733.664,116.832 733.673,116.835 733.682,116.838 733.692,116.841 733.701,116.844 733.71,116.848 733.719,116.851 733.728,116.854 733.738,116.857 733.747,116.86 733.756,116.863 733.765,116.867 733.774,116.87 733.783,116.873 733.793,116.876 733.802,116.879 733.811,116.882 733.82,116.886 733.829,116.889 733.839,116.892 733.848,116.895 733.857,116.898 733.866,116.902 733.875,116.905 733.885,116.908 733.894,116.911 733.903,116.914 733.912,116.917 733.921,116.921 733.93,116.924 733.94,116.927 733.949,116.93 733.958,116.933 733.967,116.936 733.976,116.94 733.986,116.943 733.995,116.946 734.004,116.949 734.013,116.952 734.022,116.956 734.032,116.959 734.041,116.962 734.05,116.965 734.059,116.968 734.068,116.971 734.078,116.975 734.087,116.978 734.096,116.981 734.105,116.984 734.114,116.987 734.123,116.99 734.133,116.994 734.142,116.997 734.151,117 734.16,117.003 734.169,117.006 734.179,117.01 734.188,117.013 734.197,117.016 734.206,117.019 734.215,117.022 734.225,117.025 734.234,117.029 734.243,117.032 734.252,117.035 734.261,117.038 734.27,117.041 734.28,117.044 734.289,117.048 734.298,117.051 734.307,117.054 734.316,117.057 734.326,117.06 734.335,117.063 734.344,117.067 734.353,117.07 734.362,117.073 734.372,117.076 734.381,117.079 734.39,117.083 734.399,117.086 734.408,117.089 734.418,117.092 734.427,117.095 734.436,117.098 734.445,117.102 734.454,117.105 734.463,117.108 734.473,117.111 734.482,117.114 734.491,117.117 734.5,117.121 734.509,117.124 734.519,117.127 734.528,117.13 734.537,117.133 734.546,117.136 734.555,117.14 734.565,117.143 734.574,117.146 734.583,117.149 734.592,117.152 734.601,117.156 734.61,117.159 734.62,117.162 734.629,117.165 734.638,117.168 734.647,117.171 734.656,117.175 734.666,117.178 734.675,117.181 734.684,117.184 734.693,117.187 734.702,117.19 734.712,117.194 734.721,117.197 734.73,117.2 734.739,117.203 734.748,117.206 734.758,117.209 734.767,117.213 734.776,117.216 734.785,117.219 734.794,117.222 734.803,117.225 734.813,117.229 734.822,117.232 734.831,117.235 734.84,117.238 734.849,117.241 734.859,117.244 734.868,117.248 734.877,117.251 734.886,117.254 734.895,117.257 734.905,117.26 734.914,117.263 734.923,117.267 734.932,117.27 734.941,117.273 734.95,117.276 734.96,117.279 734.969,117.282 734.978,117.286 734.987,117.289 734.996,117.292 735.006,117.295 735.015,117.298 735.024,117.302 735.033,117.305 735.042,117.308 735.052,117.311 735.061,117.314 735.07,117.317 735.079,117.321 735.088,117.324 735.098,117.327 735.107,117.33 735.116,117.333 735.125,117.336 735.134,117.34 735.143,117.343 735.153,117.346 735.162,117.349 735.171,117.352 735.18,117.355 735.189,117.359 735.199,117.362 735.208,117.365 735.217,117.368 735.226,117.371 735.235,117.374 735.245,117.378 735.254,117.381 735.263,117.384 735.272,117.387 735.281,117.39 735.29,117.394 735.3,117.397 735.309,117.4 735.318,117.403 735.327,117.406 735.336,117.409 735.346,117.413 735.355,117.416 735.364,117.419 735.373,117.422 735.382,117.425 735.392,117.428 735.401,117.432 735.41,117.435 735.419,117.438 735.428,117.441 735.438,117.444 735.447,117.447 735.456,117.451 735.465,117.454 735.474,117.457 735.483,117.46 735.493,117.463 735.502,117.466 735.511,117.47 735.52,117.473 735.529,117.476 735.539,117.479 735.548,117.482 735.557,117.485 735.566,117.489 735.575,117.492 735.585,117.495 735.594,117.498 735.603,117.501 735.612,117.505 735.621,117.508 735.63,117.511 735.64,117.514 735.649,117.517 735.658,117.52 735.667,117.524 735.676,117.527 735.686,117.53 735.695,117.533 735.704,117.536 735.713,117.539 735.722,117.543 735.732,117.546 735.741,117.549 735.75,117.552 735.759,117.555 735.768,117.558 735.778,117.562 735.787,117.565 735.796,117.568 735.805,117.571 735.814,117.574 735.823,117.577 735.833,117.581 735.842,117.584 735.851,117.587 735.86,117.59 735.869,117.593 735.879,117.596 735.888,117.6 735.897,117.603 735.906,117.606 735.915,117.609 735.925,117.612 735.934,117.615 735.943,117.619 735.952,117.622 735.961,117.625 735.971,117.628 735.98,117.631 735.989,117.635 735.998,117.638 736.007,117.641 736.016,117.644 736.026,117.647 736.035,117.65 736.044,117.654 736.053,117.657 736.062,117.66 736.072,117.663 736.081,117.666 736.09,117.669 736.099,117.673 736.108,117.676 736.118,117.679 736.127,117.682 736.136,117.685 736.145,117.688 736.154,117.692 736.163,117.695 736.173,117.698 736.182,117.701 736.191,117.704 736.2,117.707 736.209,117.711 736.219,117.714 736.228,117.717 736.237,117.72 736.246,117.723 736.255,117.726 736.265,117.73 736.274,117.733 736.283,117.736 736.292,117.739 736.301,117.742 736.311,117.745 736.32,117.749 736.329,117.752 736.338,117.755 736.347,117.758 736.356,117.761 736.366,117.764 736.375,117.768 736.384,117.771 736.393,117.774 736.402,117.777 736.412,117.78 736.421,117.783 736.43,117.787 736.439,117.79 736.448,117.793 736.458,117.796 736.467,117.799 736.476,117.803 736.485,117.806 736.494,117.809 736.503,117.812 736.513,117.815 736.522,117.818 736.531,117.822 736.54,117.825 736.549,117.828 736.559,117.831 736.568,117.834 736.577,117.837 736.586,117.841 736.595,117.844 736.605,117.847 736.614,117.85 736.623,117.853 736.632,117.856 736.641,117.86 736.651,117.863 736.66,117.866 736.669,117.869 736.678,117.872 736.687,117.875 736.696,117.879 736.706,117.882 736.715,117.885 736.724,117.888 736.733,117.891 736.742,117.894 736.752,117.898 736.761,117.901 736.77,117.904 736.779,117.907 736.788,117.91 736.798,117.913 736.807,117.917 736.816,117.92 736.825,117.923 736.834,117.926 736.843,117.929 736.853,117.932 736.862,117.936 736.871,117.939 736.88,117.942 736.889,117.945 736.899,117.948 736.908,117.951 736.917,117.955 736.926,117.958 736.935,117.961 736.945,117.964 736.954,117.967 736.963,117.97 736.972,117.974 736.981,117.977 736.991,117.98 737,117.983 737.009,117.986 737.018,117.989 737.027,117.993 737.036,117.996 737.046,117.999 737.055,118.002 737.064,118.005 737.073,118.008 737.082,118.012 737.092,118.015 737.101,118.018 737.11,118.021 737.119,118.024 737.128,118.027 737.138,118.031 737.147,118.034 737.156,118.037 737.165,118.04 737.174,118.043 737.183,118.046 737.193,118.05 737.202,118.053 737.211,118.056 737.22,118.059 737.229,118.062 737.239,118.065 737.248,118.069 737.257,118.072 737.266,118.075 737.275,118.078 737.285,118.081 737.294,118.084 737.303,118.088 737.312,118.091 737.321,118.094 737.331,118.097 737.34,118.1 737.349,118.103 737.358,118.107 737.367,118.11 737.376,118.113 737.386,118.116 737.395,118.119 737.404,118.122 737.413,118.126 737.422,118.129 737.432,118.132 737.441,118.135 737.45,118.138 737.459,118.141 737.468,118.145 737.478,118.148 737.487,118.151 737.496,118.154 737.505,118.157 737.514,118.16 737.523,118.164 737.533,118.167 737.542,118.17 737.551,118.173 737.56,118.176 737.569,118.179 737.579,118.183 737.588,118.186 737.597,118.189 737.606,118.192 737.615,118.195 737.625,118.198 737.634,118.202 737.643,118.205 737.652,118.208 737.661,118.211 737.671,118.214 737.68,118.217 737.689,118.221 737.698,118.224 737.707,118.227 737.716,118.23 737.726,118.233 737.735,118.236 737.744,118.24 737.753,118.243 737.762,118.246 737.772,118.249 737.781,118.252 737.79,118.255 737.799,118.259 737.808,118.262 737.818,118.265 737.827,118.268 737.836,118.271 737.845,118.274 737.854,118.278 737.863,118.281 737.873,118.284 737.882,118.287 737.891,118.29 737.9,118.293 737.909,118.297 737.919,118.3 737.928,118.303 737.937,118.306 737.946,118.309 737.955,118.312 737.965,118.316 737.974,118.319 737.983,118.322 737.992,118.325 738.001,118.328 738.011,118.331 738.02,118.335 738.029,118.338 738.038,118.341 738.047,118.344 738.056,118.347 738.066,118.35 738.075,118.354 738.084,118.357 738.093,118.36 738.102,118.363 738.112,118.366 738.121,118.369 738.13,118.373 738.139,118.376 738.148,118.379 738.158,118.382 738.167,118.385 738.176,118.388 738.185,118.392 738.194,118.395 738.204,118.398 738.213,118.401 738.222,118.404 738.231,118.407 738.24,118.411 738.249,118.414 738.259,118.417 738.268,118.42 738.277,118.423 738.286,118.426 738.295,118.43 738.305,118.433 738.314,118.436 738.323,118.439 738.332,118.442 738.341,118.445 738.351,118.448 738.36,118.452 738.369,118.455 738.378,118.458 738.387,118.461 738.396,118.464 738.406,118.467 738.415,118.471 738.424,118.474 738.433,118.477 738.442,118.48 738.452,118.483 738.461,118.486 738.47,118.49 738.479,118.493 738.488,118.496 738.498,118.499 738.507,118.502 738.516,118.505 738.525,118.509 738.534,118.512 738.544,118.515 738.553,118.518 738.562,118.521 738.571,118.524 738.58,118.528 738.589,118.531 738.599,118.534 738.608,118.537 738.617,118.54 738.626,118.543 738.635,118.547 738.645,118.55 738.654,118.553 738.663,118.556 738.672,118.559 738.681,118.562 738.691,118.566 738.7,118.569 738.709,118.572 738.718,118.575 738.727,118.578 738.736,118.581 738.746,118.585 738.755,118.588 738.764,118.591 738.773,118.594 738.782,118.597 738.792,118.6 738.801,118.604 738.81,118.607 738.819,118.61 738.828,118.613 738.838,118.616 738.847,118.619 738.856,118.622 738.865,118.626 738.874,118.629 738.884,118.632 738.893,118.635 738.902,118.638 738.911,118.641 738.92,118.645 738.929,118.648 738.939,118.651 738.948,118.654 738.957,118.657 738.966,118.66 738.975,118.664 738.985,118.667 738.994,118.67 739.003,118.673 739.012,118.676 739.021,118.679 739.031,118.683 739.04,118.686 739.049,118.689 739.058,118.692 739.067,118.695 739.076,118.698 739.086,118.702 739.095,118.705 739.104,118.708 739.113,118.711 739.122,118.714 739.132,118.717 739.141,118.721 739.15,118.724 739.159,118.727 739.168,118.73 739.178,118.733 739.187,118.736 739.196,118.739 739.205,118.743 739.214,118.746 739.224,118.749 739.233,118.752 739.242,118.755 739.251,118.758 739.26,118.762 739.269,118.765 739.279,118.768 739.288,118.771 739.297,118.774 739.306,118.777 739.315,118.781 739.325,118.784 739.334,118.787 739.343,118.79 739.352,118.793 739.361,118.796 739.371,118.8 739.38,118.803 739.389,118.806 739.398,118.809 739.407,118.812 739.416,118.815 739.426,118.819 739.435,118.822 739.444,118.825 739.453,118.828 739.462,118.831 739.472,118.834 739.481,118.838 739.49,118.841 739.499,118.844 739.508,118.847 739.518,118.85 739.527,118.853 739.536,118.856 739.545,118.86 739.554,118.863 739.564,118.866 739.573,118.869 739.582,118.872 739.591,118.875 739.6,118.879 739.609,118.882 739.619,118.885 739.628,118.888 739.637,118.891 739.646,118.894 739.655,118.898 739.665,118.901 739.674,118.904 739.683,118.907 739.692,118.91 739.701,118.913 739.711,118.917 739.72,118.92 739.729,118.923 739.738,118.926 739.747,118.929 739.756,118.932 739.766,118.935 739.775,118.939 739.784,118.942 739.793,118.945 739.802,118.948 739.812,118.951 739.821,118.954 739.83,118.958 739.839,118.961 739.848,118.964 739.858,118.967 739.867,118.97 739.876,118.973 739.885,118.977 739.894,118.98 739.904,118.983 739.913,118.986 739.922,118.989 739.931,118.992 739.94,118.996 739.949,118.999 739.959,119.002 739.968,119.005 739.977,119.008 739.986,119.011 739.995,119.015 740.005,119.018 740.014,119.021 740.023,119.024 740.032,119.027 740.041,119.03 740.051,119.033 740.06,119.037 740.069,119.04 740.078,119.043 740.087,119.046 740.096,119.049 740.106,119.052 740.115,119.056 740.124,119.059 740.133,119.062 740.142,119.065 740.152,119.068 740.161,119.071 740.17,119.075 740.179,119.078 740.188,119.081 740.198,119.084 740.207,119.087 740.216,119.09 740.225,119.093 740.234,119.097 740.244,119.1 740.253,119.103 740.262,119.106 740.271,119.109 740.28,119.112 740.289,119.116 740.299,119.119 740.308,119.122 740.317,119.125 740.326,119.128 740.335,119.131 740.345,119.135 740.354,119.138 740.363,119.141 740.372,119.144 740.381,119.147 740.391,119.15 740.4,119.154 740.409,119.157 740.418,119.16 740.427,119.163 740.436,119.166 740.446,119.169 740.455,119.172 740.464,119.176 740.473,119.179 740.482,119.182 740.492,119.185 740.501,119.188 740.51,119.191 740.519,119.195 740.528,119.198 740.538,119.201 740.547,119.204 740.556,119.207 740.565,119.21 740.574,119.214 740.584,119.217 740.593,119.22 740.602,119.223 740.611,119.226 740.62,119.229 740.629,119.232 740.639,119.236 740.648,119.239 740.657,119.242 740.666,119.245 740.675,119.248 740.685,119.251 740.694,119.255 740.703,119.258 740.712,119.261 740.721,119.264 740.731,119.267 740.74,119.27 740.749,119.274 740.758,119.277 740.767,119.28 740.777,119.283 740.786,119.286 740.795,119.289 740.804,119.292 740.813,119.296 740.822,119.299 740.832,119.302 740.841,119.305 740.85,119.308 740.859,119.311 740.868,119.315 740.878,119.318 740.887,119.321 740.896,119.324 740.905,119.327 740.914,119.33 740.924,119.334 740.933,119.337 740.942,119.34 740.951,119.343 740.96,119.346 740.969,119.349 740.979,119.352 740.988,119.356 740.997,119.359 741.006,119.362 741.015,119.365 741.025,119.368 741.034,119.371 741.043,119.375 741.052,119.378 741.061,119.381 741.071,119.384 741.08,119.387 741.089,119.39 741.098,119.394 741.107,119.397 741.117,119.4 741.126,119.403 741.135,119.406 741.144,119.409 741.153,119.412 741.162,119.416 741.172,119.419 741.181,119.422 741.19,119.425 741.199,119.428 741.208,119.431 741.218,119.435 741.227,119.438 741.236,119.441 741.245,119.444 741.254,119.447 741.264,119.45 741.273,119.454 741.282,119.457 741.291,119.46 741.3,119.463 741.309,119.466 741.319,119.469 741.328,119.472 741.337,119.476 741.346,119.479 741.355,119.482 741.365,119.485 741.374,119.488 741.383,119.491 741.392,119.495 741.401,119.498 741.411,119.501 741.42,119.504 741.429,119.507 741.438,119.51 741.447,119.513 741.457,119.517 741.466,119.52 741.475,119.523 741.484,119.526 741.493,119.529 741.502,119.532 741.512,119.536 741.521,119.539 741.53,119.542 741.539,119.545 741.548,119.548 741.558,119.551 741.567,119.555 741.576,119.558 741.585,119.561 741.594,119.564 741.604,119.567 741.613,119.57 741.622,119.573 741.631,119.577 741.64,119.58 741.649,119.583 741.659,119.586 741.668,119.589 741.677,119.592 741.686,119.596 741.695,119.599 741.705,119.602 741.714,119.605 741.723,119.608 741.732,119.611 741.741,119.614 741.751,119.618 741.76,119.621 741.769,119.624 741.778,119.627 741.787,119.63 741.797,119.633 741.806,119.637 741.815,119.64 741.824,119.643 741.833,119.646 741.842,119.649 741.852,119.652 741.861,119.655 741.87,119.659 741.879,119.662 741.888,119.665 741.898,119.668 741.907,119.671 741.916,119.674 741.925,119.678 741.934,119.681 741.944,119.684 741.953,119.687 741.962,119.69 741.971,119.693 741.98,119.697 741.989,119.7 741.999,119.703 742.008,119.706 742.017,119.709 742.026,119.712 742.035,119.715 742.045,119.719 742.054,119.722 742.063,119.725 742.072,119.728 742.081,119.731 742.091,119.734 742.1,119.738 742.109,119.741 742.118,119.744 742.127,119.747 742.137,119.75 742.146,119.753 742.155,119.756 742.164,119.76 742.173,119.763 742.182,119.766 742.192,119.769 742.201,119.772 742.21,119.775 742.219,119.779 742.228,119.782 742.238,119.785 742.247,119.788 742.256,119.791 742.265,119.794 742.274,119.797 742.284,119.801 742.293,119.804 742.302,119.807 742.311,119.81 742.32,119.813 742.329,119.816 742.339,119.82 742.348,119.823 742.357,119.826 742.366,119.829 742.375,119.832 742.385,119.835 742.394,119.838 742.403,119.842 742.412,119.845 742.421,119.848 742.431,119.851 742.44,119.854 742.449,119.857 742.458,119.861 742.467,119.864 742.477,119.867 742.486,119.87 742.495,119.873 742.504,119.876 742.513,119.879 742.522,119.883 742.532,119.886 742.541,119.889 742.55,119.892 742.559,119.895 742.568,119.898 742.578,119.902 742.587,119.905 742.596,119.908 742.605,119.911 742.614,119.914 742.624,119.917 742.633,119.92 742.642,119.924 742.651,119.927 742.66,119.93 742.669,119.933 742.679,119.936 742.688,119.939 742.697,119.943 742.706,119.946 742.715,119.949 742.725,119.952 742.734,119.955 742.743,119.958 742.752,119.961 742.761,119.965 742.771,119.968 742.78,119.971 742.789,119.974 742.798,119.977 742.807,119.98 742.817,119.983 742.826,119.987 742.835,119.99 742.844,119.993 742.853,119.996 742.862,119.999 742.872,120.002 742.881,120.006 742.89,120.009 742.899,120.012 742.908,120.015 742.918,120.018 742.927,120.021 742.936,120.024 742.945,120.028 742.954,120.031 742.964,120.034 742.973,120.037 742.982,120.04 742.991,120.043 743,120.047 743.009,120.05 743.019,120.053 743.028,120.056 743.037,120.059 743.046,120.062 743.055,120.065 743.065,120.069 743.074,120.072 743.083,120.075 743.092,120.078 743.101,120.081 743.111,120.084 743.12,120.088 743.129,120.091 743.138,120.094 743.147,120.097 743.157,120.1 743.166,120.103 743.175,120.106 743.184,120.11 743.193,120.113 743.202,120.116 743.212,120.119 743.221,120.122 743.23,120.125 743.239,120.128 743.248,120.132 743.258,120.135 743.267,120.138 743.276,120.141 743.285,120.144 743.294,120.147 743.304,120.151 743.313,120.154 743.322,120.157 743.331,120.16 743.34,120.163 743.35,120.166 743.359,120.169 743.368,120.173 743.377,120.176 743.386,120.179 743.395,120.182 743.405,120.185 743.414,120.188 743.423,120.192 743.432,120.195 743.441,120.198 743.451,120.201 743.46,120.204 743.469,120.207 743.478,120.21 743.487,120.214 743.497,120.217 743.506,120.22 743.515,120.223 743.524,120.226 743.533,120.229 743.542,120.232 743.552,120.236 743.561,120.239 743.57,120.242 743.579,120.245 743.588,120.248 743.598,120.251 743.607,120.255 743.616,120.258 743.625,120.261 743.634,120.264 743.644,120.267 743.653,120.27 743.662,120.273 743.671,120.277 743.68,120.28 743.69,120.283 743.699,120.286 743.708,120.289 743.717,120.292 743.726,120.296 743.735,120.299 743.745,120.302 743.754,120.305 743.763,120.308 743.772,120.311 743.781,120.314 743.791,120.318 743.8,120.321 743.809,120.324 743.818,120.327 743.827,120.33 743.837,120.333 743.846,120.336 743.855,120.34 743.864,120.343 743.873,120.346 743.882,120.349 743.892,120.352 743.901,120.355 743.91,120.359 743.919,120.362 743.928,120.365 743.938,120.368 743.947,120.371 743.956,120.374 743.965,120.377 743.974,120.381 743.984,120.384 743.993,120.387 744.002,120.39 744.011,120.393 744.02,120.396 744.03,120.399 744.039,120.403 744.048,120.406 744.057,120.409 744.066,120.412 744.075,120.415 744.085,120.418 744.094,120.421 744.103,120.425 744.112,120.428 744.121,120.431 744.131,120.434 744.14,120.437 744.149,120.44 744.158,120.444 744.167,120.447 744.177,120.45 744.186,120.453 744.195,120.456 744.204,120.459 744.213,120.462 744.222,120.466 744.232,120.469 744.241,120.472 744.25,120.475 744.259,120.478 744.268,120.481 744.278,120.484 744.287,120.488 744.296,120.491 744.305,120.494 744.314,120.497 744.324,120.5 744.333,120.503 744.342,120.507 744.351,120.51 744.36,120.513 744.37,120.516 744.379,120.519 744.388,120.522 744.397,120.525 744.406,120.529 744.415,120.532 744.425,120.535 744.434,120.538 744.443,120.541 744.452,120.544 744.461,120.547 744.471,120.551 744.48,120.554 744.489,120.557 744.498,120.56 744.507,120.563 744.517,120.566 744.526,120.569 744.535,120.573 744.544,120.576 744.553,120.579 744.562,120.582 744.572,120.585 744.581,120.588 744.59,120.592 744.599,120.595 744.608,120.598 744.618,120.601 744.627,120.604 744.636,120.607 744.645,120.61 744.654,120.614 744.664,120.617 744.673,120.62 744.682,120.623 744.691,120.626 744.7,120.629 744.71,120.632 744.719,120.636 744.728,120.639 744.737,120.642 744.746,120.645 744.755,120.648 744.765,120.651 744.774,120.654 744.783,120.658 744.792,120.661 744.801,120.664 744.811,120.667 744.82,120.67 744.829,120.673 744.838,120.677 744.847,120.68 744.857,120.683 744.866,120.686 744.875,120.689 744.884,120.692 744.893,120.695 744.902,120.699 744.912,120.702 744.921,120.705 744.93,120.708 744.939,120.711 744.948,120.714 744.958,120.717 744.967,120.721 744.976,120.724 744.985,120.727 744.994,120.73 745.004,120.733 745.013,120.736 745.022,120.739 745.031,120.743 745.04,120.746 745.05,120.749 745.059,120.752 745.068,120.755 745.077,120.758 745.086,120.762 745.095,120.765 745.105,120.768 745.114,120.771 745.123,120.774 745.132,120.777 745.141,120.78 745.151,120.784 745.16,120.787 745.169,120.79 745.178,120.793 745.187,120.796 745.197,120.799 745.206,120.802 745.215,120.806 745.224,120.809 745.233,120.812 745.242,120.815 745.252,120.818 745.261,120.821 745.27,120.824 745.279,120.828 745.288,120.831 745.298,120.834 745.307,120.837 745.316,120.84 745.325,120.843 745.334,120.846 745.344,120.85 745.353,120.853 745.362,120.856 745.371,120.859 745.38,120.862 745.39,120.865 745.399,120.868 745.408,120.872 745.417,120.875 745.426,120.878 745.435,120.881 745.445,120.884 745.454,120.887 745.463,120.891 745.472,120.894 745.481,120.897 745.491,120.9 745.5,120.903 745.509,120.906 745.518,120.909 745.527,120.913 745.537,120.916 745.546,120.919 745.555,120.922 745.564,120.925 745.573,120.928 745.583,120.931 745.592,120.935 745.601,120.938 745.61,120.941 745.619,120.944 745.628,120.947 745.638,120.95 745.647,120.953 745.656,120.957 745.665,120.96 745.674,120.963 745.684,120.966 745.693,120.969 745.702,120.972 745.711,120.975 745.72,120.979 745.73,120.982 745.739,120.985 745.748,120.988 745.757,120.991 745.766,120.994 745.775,120.997 745.785,121.001 745.794,121.004 745.803,121.007 745.812,121.01 745.821,121.013 745.831,121.016 745.84,121.019 745.849,121.023 745.858,121.026 745.867,121.029 745.877,121.032 745.886,121.035 745.895,121.038 745.904,121.041 745.913,121.045 745.923,121.048 745.932,121.051 745.941,121.054 745.95,121.057 745.959,121.06 745.968,121.063 745.978,121.067 745.987,121.07 745.996,121.073 746.005,121.076 746.014,121.079 746.024,121.082 746.033,121.086 746.042,121.089 746.051,121.092 746.06,121.095 746.07,121.098 746.079,121.101 746.088,121.104 746.097,121.108 746.106,121.111 746.115,121.114 746.125,121.117 746.134,121.12 746.143,121.123 746.152,121.126 746.161,121.13 746.171,121.133 746.18,121.136 746.189,121.139 746.198,121.142 746.207,121.145 746.217,121.148 746.226,121.152 746.235,121.155 746.244,121.158 746.253,121.161 746.263,121.164 746.272,121.167 746.281,121.17 746.29,121.174 746.299,121.177 746.308,121.18 746.318,121.183 746.327,121.186 746.336,121.189 746.345,121.192 746.354,121.196 746.364,121.199 746.373,121.202 746.382,121.205 746.391,121.208 746.4,121.211 746.41,121.214 746.419,121.218 746.428,121.221 746.437,121.224 746.446,121.227 746.455,121.23 746.465,121.233 746.474,121.236 746.483,121.24 746.492,121.243 746.501,121.246 746.511,121.249 746.52,121.252 746.529,121.255 746.538,121.258 746.547,121.262 746.557,121.265 746.566,121.268 746.575,121.271 746.584,121.274 746.593,121.277 746.603,121.28 746.612,121.284 746.621,121.287 746.63,121.29 746.639,121.293 746.648,121.296 746.658,121.299 746.667,121.302 746.676,121.306 746.685,121.309 746.694,121.312 746.704,121.315 746.713,121.318 746.722,121.321 746.731,121.324 746.74,121.328 746.75,121.331 746.759,121.334 746.768,121.337 746.777,121.34 746.786,121.343 746.795,121.346 746.805,121.35 746.814,121.353 746.823,121.356 746.832,121.359 746.841,121.362 746.851,121.365 746.86,121.368 746.869,121.372 746.878,121.375 746.887,121.378 746.897,121.381 746.906,121.384 746.915,121.387 746.924,121.39 746.933,121.394 746.943,121.397 746.952,121.4 746.961,121.403 746.97,121.406 746.979,121.409 746.988,121.412 746.998,121.416 747.007,121.419 747.016,121.422 747.025,121.425 747.034,121.428 747.044,121.431 747.053,121.434 747.062,121.438 747.071,121.441 747.08,121.444 747.09,121.447 747.099,121.45 747.108,121.453 747.117,121.456 747.126,121.46 747.135,121.463 747.145,121.466 747.154,121.469 747.163,121.472 747.172,121.475 747.181,121.478 747.191,121.482 747.2,121.485 747.209,121.488 747.218,121.491 747.227,121.494 747.237,121.497 747.246,121.5 747.255,121.504 747.264,121.507 747.273,121.51 747.283,121.513 747.292,121.516 747.301,121.519 747.31,121.522 747.319,121.526 747.328,121.529 747.338,121.532 747.347,121.535 747.356,121.538 747.365,121.541 747.374,121.544 747.384,121.547 747.393,121.551 747.402,121.554 747.411,121.557 747.42,121.56 747.43,121.563 747.439,121.566 747.448,121.569 747.457,121.573 747.466,121.576 747.475,121.579 747.485,121.582 747.494,121.585 747.503,121.588 747.512,121.591 747.521,121.595 747.531,121.598 747.54,121.601 747.549,121.604 747.558,121.607 747.567,121.61 747.577,121.613 747.586,121.617 747.595,121.62 747.604,121.623 747.613,121.626 747.623,121.629 747.632,121.632 747.641,121.635 747.65,121.639 747.659,121.642 747.668,121.645 747.678,121.648 747.687,121.651 747.696,121.654 747.705,121.657 747.714,121.661 747.724,121.664 747.733,121.667 747.742,121.67 747.751,121.673 747.76,121.676 747.77,121.679 747.779,121.683 747.788,121.686 747.797,121.689 747.806,121.692 747.815,121.695 747.825,121.698 747.834,121.701 747.843,121.705 747.852,121.708 747.861,121.711 747.871,121.714 747.88,121.717 747.889,121.72 747.898,121.723 747.907,121.726 747.917,121.73 747.926,121.733 747.935,121.736 747.944,121.739 747.953,121.742 747.963,121.745 747.972,121.748 747.981,121.752 747.99,121.755 747.999,121.758 748.008,121.761 748.018,121.764 748.027,121.767 748.036,121.77 748.045,121.774 748.054,121.777 748.064,121.78 748.073,121.783 748.082,121.786 748.091,121.789 748.1,121.792 748.11,121.796 748.119,121.799 748.128,121.802 748.137,121.805 748.146,121.808 748.156,121.811 748.165,121.814 748.174,121.818 748.183,121.821 748.192,121.824 748.201,121.827 748.211,121.83 748.22,121.833 748.229,121.836 748.238,121.84 748.247,121.843 748.257,121.846 748.266,121.849 748.275,121.852 748.284,121.855 748.293,121.858 748.303,121.861 748.312,121.865 748.321,121.868 748.33,121.871 748.339,121.874 748.348,121.877 748.358,121.88 748.367,121.883 748.376,121.887 748.385,121.89 748.394,121.893 748.404,121.896 748.413,121.899 748.422,121.902 748.431,121.905 748.44,121.909 748.45,121.912 748.459,121.915 748.468,121.918 748.477,121.921 748.486,121.924 748.496,121.927 748.505,121.931 748.514,121.934 748.523,121.937 748.532,121.94 748.541,121.943 748.551,121.946 748.56,121.949 748.569,121.952 748.578,121.956 748.587,121.959 748.597,121.962 748.606,121.965 748.615,121.968 748.624,121.971 748.633,121.974 748.643,121.978 748.652,121.981 748.661,121.984 748.67,121.987 748.679,121.99 748.688,121.993 748.698,121.996 748.707,122 748.716,122.003 748.725,122.006 748.734,122.009 748.744,122.012 748.753,122.015 748.762,122.018 748.771,122.022 748.78,122.025 748.79,122.028 748.799,122.031 748.808,122.034 748.817,122.037 748.826,122.04 748.836,122.043 748.845,122.047 748.854,122.05 748.863,122.053 748.872,122.056 748.881,122.059 748.891,122.062 748.9,122.065 748.909,122.069 748.918,122.072 748.927,122.075 748.937,122.078 748.946,122.081 748.955,122.084 748.964,122.087 748.973,122.091 748.983,122.094 748.992,122.097 749.001,122.1 749.01,122.103 749.019,122.106 749.028,122.109 749.038,122.112 749.047,122.116 749.056,122.119 749.065,122.122 749.074,122.125 749.084,122.128 749.093,122.131 749.102,122.134 749.111,122.138 749.12,122.141 749.13,122.144 749.139,122.147 749.148,122.15 749.157,122.153 749.166,122.156 749.176,122.16 749.185,122.163 749.194,122.166 749.203,122.169 749.212,122.172 749.221,122.175 749.231,122.178 749.24,122.182 749.249,122.185 749.258,122.188 749.267,122.191 749.277,122.194 749.286,122.197 749.295,122.2 749.304,122.203 749.313,122.207 749.323,122.21 749.332,122.213 749.341,122.216 749.35,122.219 749.359,122.222 749.368,122.225 749.378,122.229 749.387,122.232 749.396,122.235 749.405,122.238 749.414,122.241 749.424,122.244 749.433,122.247 749.442,122.25 749.451,122.254 749.46,122.257 749.47,122.26 749.479,122.263 749.488,122.266 749.497,122.269 749.506,122.272 749.516,122.276 749.525,122.279 749.534,122.282 749.543,122.285 749.552,122.288 749.561,122.291 749.571,122.294 749.58,122.298 749.589,122.301 749.598,122.304 749.607,122.307 749.617,122.31 749.626,122.313 749.635,122.316 749.644,122.319 749.653,122.323 749.663,122.326 749.672,122.329 749.681,122.332 749.69,122.335 749.699,122.338 749.708,122.341 749.718,122.345 749.727,122.348 749.736,122.351 749.745,122.354 749.754,122.357 749.764,122.36 749.773,122.363 749.782,122.367 749.791,122.37 749.8,122.373 749.81,122.376 749.819,122.379 749.828,122.382 749.837,122.385 749.846,122.388 749.856,122.392 749.865,122.395 749.874,122.398 749.883,122.401 749.892,122.404 749.901,122.407 749.911,122.41 749.92,122.414 749.929,122.417 749.938,122.42 749.947,122.423 749.957,122.426 749.966,122.429 749.975,122.432 749.984,122.435 749.993,122.439 750.003,122.442 750.012,122.445 750.021,122.448 750.03,122.451 750.039,122.454 750.048,122.457 750.058,122.461 750.067,122.464 750.076,122.467 750.085,122.47 750.094,122.473 750.104,122.476 750.113,122.479 750.122,122.482 750.131,122.486 750.14,122.489 750.15,122.492 750.159,122.495 750.168,122.498 750.177,122.501 750.186,122.504 750.196,122.508 750.205,122.511 750.214,122.514 750.223,122.517 750.232,122.52 750.241,122.523 750.251,122.526 750.26,122.529 750.269,122.533 750.278,122.536 750.287,122.539 750.297,122.542 750.306,122.545 750.315,122.548 750.324,122.551 750.333,122.555 750.343,122.558 750.352,122.561 750.361,122.564 750.37,122.567 750.379,122.57 750.388,122.573 750.398,122.576 750.407,122.58 750.416,122.583 750.425,122.586 750.434,122.589 750.444,122.592 750.453,122.595 750.462,122.598 750.471,122.602 750.48,122.605 750.49,122.608 750.499,122.611 750.508,122.614 750.517,122.617 750.526,122.62 750.536,122.623 750.545,122.627 750.554,122.63 750.563,122.633 750.572,122.636 750.581,122.639 750.591,122.642 750.6,122.645 750.609,122.649 750.618,122.652 750.627,122.655 750.637,122.658 750.646,122.661 750.655,122.664 750.664,122.667 750.673,122.67 750.683,122.674 750.692,122.677 750.701,122.68 750.71,122.683 750.719,122.686 750.729,122.689 750.738,122.692 750.747,122.696 750.756,122.699 750.765,122.702 750.774,122.705 750.784,122.708 750.793,122.711 750.802,122.714 750.811,122.717 750.82,122.721 750.83,122.724 750.839,122.727 750.848,122.73 750.857,122.733 750.866,122.736 750.876,122.739 750.885,122.743 750.894,122.746 750.903,122.749 750.912,122.752 750.921,122.755 750.931,122.758 750.94,122.761 750.949,122.764 750.958,122.768 750.967,122.771 750.977,122.774 750.986,122.777 750.995,122.78 751.004,122.783 751.013,122.786 751.023,122.79 751.032,122.793 751.041,122.796 751.05,122.799 751.059,122.802 751.069,122.805 751.078,122.808 751.087,122.811 751.096,122.815 751.105,122.818 751.114,122.821 751.124,122.824 751.133,122.827 751.142,122.83 751.151,122.833 751.16,122.836 751.17,122.84 751.179,122.843 751.188,122.846 751.197,122.849 751.206,122.852 751.216,122.855 751.225,122.858 751.234,122.862 751.243,122.865 751.252,122.868 751.261,122.871 751.271,122.874 751.28,122.877 751.289,122.88 751.298,122.883 751.307,122.887 751.317,122.89 751.326,122.893 751.335,122.896 751.344,122.899 751.353,122.902 751.363,122.905 751.372,122.908 751.381,122.912 751.39,122.915 751.399,122.918 751.409,122.921 751.418,122.924 751.427,122.927 751.436,122.93 751.445,122.934 751.454,122.937 751.464,122.94 751.473,122.943 751.482,122.946 751.491,122.949 751.5,122.952 751.51,122.955 751.519,122.959 751.528,122.962 751.537,122.965 751.546,122.968 751.556,122.971 751.565,122.974 751.574,122.977 751.583,122.98 751.592,122.984 751.601,122.987 751.611,122.99 751.62,122.993 751.629,122.996 751.638,122.999 751.647,123.002 751.657,123.006 751.666,123.009 751.675,123.012 751.684,123.015 751.693,123.018 751.703,123.021 751.712,123.024 751.721,123.027 751.73,123.031 751.739,123.034 751.749,123.037 751.758,123.04 751.767,123.043 751.776,123.046 751.785,123.049 751.794,123.052 751.804,123.056 751.813,123.059 751.822,123.062 751.831,123.065 751.84,123.068 751.85,123.071 751.859,123.074 751.868,123.078 751.877,123.081 751.886,123.084 751.896,123.087 751.905,123.09 751.914,123.093 751.923,123.096 751.932,123.099 751.941,123.103 751.951,123.106 751.96,123.109 751.969,123.112 751.978,123.115 751.987,123.118 751.997,123.121 752.006,123.124 752.015,123.128 752.024,123.131 752.033,123.134 752.043,123.137 752.052,123.14 752.061,123.143 752.07,123.146 752.079,123.149 752.089,123.153 752.098,123.156 752.107,123.159 752.116,123.162 752.125,123.165 752.134,123.168 752.144,123.171 752.153,123.175 752.162,123.178 752.171,123.181 752.18,123.184 752.19,123.187 752.199,123.19 752.208,123.193 752.217,123.196 752.226,123.2 752.236,123.203 752.245,123.206 752.254,123.209 752.263,123.212 752.272,123.215 752.281,123.218 752.291,123.221 752.3,123.225 752.309,123.228 752.318,123.231 752.327,123.234 752.337,123.237 752.346,123.24 752.355,123.243 752.364,123.246 752.373,123.25 752.383,123.253 752.392,123.256 752.401,123.259 752.41,123.262 752.419,123.265 752.429,123.268 752.438,123.272 752.447,123.275 752.456,123.278 752.465,123.281 752.474,123.284 752.484,123.287 752.493,123.29 752.502,123.293 752.511,123.297 752.52,123.3 752.53,123.303 752.539,123.306 752.548,123.309 752.557,123.312 752.566,123.315 752.576,123.318 752.585,123.322 752.594,123.325 752.603,123.328 752.612,123.331 752.621,123.334 752.631,123.337 752.64,123.34 752.649,123.343 752.658,123.347 752.667,123.35 752.677,123.353 752.686,123.356 752.695,123.359 752.704,123.362 752.713,123.365 752.723,123.368 752.732,123.372 752.741,123.375 752.75,123.378 752.759,123.381 752.769,123.384 752.778,123.387 752.787,123.39 752.796,123.393 752.805,123.397 752.814,123.4 752.824,123.403 752.833,123.406 752.842,123.409 752.851,123.412 752.86,123.415 752.87,123.419 752.879,123.422 752.888,123.425 752.897,123.428 752.906,123.431 752.916,123.434 752.925,123.437 752.934,123.44 752.943,123.444 752.952,123.447 752.962,123.45 752.971,123.453 752.98,123.456 752.989,123.459 752.998,123.462 753.007,123.465 753.017,123.469 753.026,123.472 753.035,123.475 753.044,123.478 753.053,123.481 753.063,123.484 753.072,123.487 753.081,123.49 753.09,123.494 753.099,123.497 753.109,123.5 753.118,123.503 753.127,123.506 753.136,123.509 753.145,123.512 753.154,123.515 753.164,123.519 753.173,123.522 753.182,123.525 753.191,123.528 753.2,123.531 753.21,123.534 753.219,123.537 753.228,123.54 753.237,123.544 753.246,123.547 753.256,123.55 753.265,123.553 753.274,123.556 753.283,123.559 753.292,123.562 753.302,123.565 753.311,123.569 753.32,123.572 753.329,123.575 753.338,123.578 753.347,123.581 753.357,123.584 753.366,123.587 753.375,123.59 753.384,123.594 753.393,123.597 753.403,123.6 753.412,123.603 753.421,123.606 753.43,123.609 753.439,123.612 753.449,123.615 753.458,123.619 753.467,123.622 753.476,123.625 753.485,123.628 753.494,123.631 753.504,123.634 753.513,123.637 753.522,123.64 753.531,123.644 753.54,123.647 753.55,123.65 753.559,123.653 753.568,123.656 753.577,123.659 753.586,123.662 753.596,123.665 753.605,123.669 753.614,123.672 753.623,123.675 753.632,123.678 753.642,123.681 753.651,123.684 753.66,123.687 753.669,123.69 753.678,123.694 753.687,123.697 753.697,123.7 753.706,123.703 753.715,123.706 753.724,123.709 753.733,123.712 753.743,123.715 753.752,123.719 753.761,123.722 753.77,123.725 753.779,123.728 753.789,123.731 753.798,123.734 753.807,123.737 753.816,123.74 753.825,123.744 753.834,123.747 753.844,123.75 753.853,123.753 753.862,123.756 753.871,123.759 753.88,123.762 753.89,123.765 753.899,123.769 753.908,123.772 753.917,123.775 753.926,123.778 753.936,123.781 753.945,123.784 753.954,123.787 753.963,123.79 753.972,123.794 753.982,123.797 753.991,123.8 754,123.803 754.009,123.806 754.018,123.809 754.027,123.812 754.037,123.815 754.046,123.819 754.055,123.822 754.064,123.825 754.073,123.828 754.083,123.831 754.092,123.834 754.101,123.837 754.11,123.84 754.119,123.844 754.129,123.847 754.138,123.85 754.147,123.853 754.156,123.856 754.165,123.859 754.174,123.862 754.184,123.865 754.193,123.869 754.202,123.872 754.211,123.875 754.22,123.878 754.23,123.881 754.239,123.884 754.248,123.887 754.257,123.89 754.266,123.894 754.276,123.897 754.285,123.9 754.294,123.903 754.303,123.906 754.312,123.909 754.322,123.912 754.331,123.915 754.34,123.919 754.349,123.922 754.358,123.925 754.367,123.928 754.377,123.931 754.386,123.934 754.395,123.937 754.404,123.94 754.413,123.944 754.423,123.947 754.432,123.95 754.441,123.953 754.45,123.956 754.459,123.959 754.469,123.962 754.478,123.965 754.487,123.969 754.496,123.972 754.505,123.975 754.514,123.978 754.524,123.981 754.533,123.984 754.542,123.987 754.551,123.99 754.56,123.993 754.57,123.997 754.579,124 754.588,124.003 754.597,124.006 754.606,124.009 754.616,124.012 754.625,124.015 754.634,124.018 754.643,124.022 754.652,124.025 754.662,124.028 754.671,124.031 754.68,124.034 754.689,124.037 754.698,124.04 754.707,124.043 754.717,124.047 754.726,124.05 754.735,124.053 754.744,124.056 754.753,124.059 754.763,124.062 754.772,124.065 754.781,124.068 754.79,124.072 754.799,124.075 754.809,124.078 754.818,124.081 754.827,124.084 754.836,124.087 754.845,124.09 754.854,124.093 754.864,124.097 754.873,124.1 754.882,124.103 754.891,124.106 754.9,124.109 754.91,124.112 754.919,124.115 754.928,124.118 754.937,124.122 754.946,124.125 754.956,124.128 754.965,124.131 754.974,124.134 754.983,124.137 754.992,124.14 755.002,124.143 755.011,124.146 755.02,124.15 755.029,124.153 755.038,124.156 755.047,124.159 755.057,124.162 755.066,124.165 755.075,124.168 755.084,124.171 755.093,124.175 755.103,124.178 755.112,124.181 755.121,124.184 755.13,124.187 755.139,124.19 755.149,124.193 755.158,124.196 755.167,124.2 755.176,124.203 755.185,124.206 755.194,124.209 755.204,124.212 755.213,124.215 755.222,124.218 755.231,124.221 755.24,124.225 755.25,124.228 755.259,124.231 755.268,124.234 755.277,124.237 755.286,124.24 755.296,124.243 755.305,124.246 755.314,124.249 755.323,124.253 755.332,124.256 755.342,124.259 755.351,124.262 755.36,124.265 755.369,124.268 755.378,124.271 755.387,124.274 755.397,124.278 755.406,124.281 755.415,124.284 755.424,124.287 755.433,124.29 755.443,124.293 755.452,124.296 755.461,124.299 755.47,124.303 755.479,124.306 755.489,124.309 755.498,124.312 755.507,124.315 755.516,124.318 755.525,124.321 755.535,124.324 755.544,124.327 755.553,124.331 755.562,124.334 755.571,124.337 755.58,124.34 755.59,124.343 755.599,124.346 755.608,124.349 755.617,124.352 755.626,124.356 755.636,124.359 755.645,124.362 755.654,124.365 755.663,124.368 755.672,124.371 755.682,124.374 755.691,124.377 755.7,124.381 755.709,124.384 755.718,124.387 755.727,124.39 755.737,124.393 755.746,124.396 755.755,124.399 755.764,124.402 755.773,124.405 755.783,124.409 755.792,124.412 755.801,124.415 755.81,124.418 755.819,124.421 755.829,124.424 755.838,124.427 755.847,124.43 755.856,124.434 755.865,124.437 755.875,124.44 755.884,124.443 755.893,124.446 755.902,124.449 755.911,124.452 755.92,124.455 755.93,124.459 755.939,124.462 755.948,124.465 755.957,124.468 755.966,124.471 755.976,124.474 755.985,124.477 755.994,124.48 756.003,124.483 756.012,124.487 756.022,124.49 756.031,124.493 756.04,124.496 756.049,124.499 756.058,124.502 756.067,124.505 756.077,124.508 756.086,124.512 756.095,124.515 756.104,124.518 756.113,124.521 756.123,124.524 756.132,124.527 756.141,124.53 756.15,124.533 756.159,124.536 756.169,124.54 756.178,124.543 756.187,124.546 756.196,124.549 756.205,124.552 756.215,124.555 756.224,124.558 756.233,124.561 756.242,124.565 756.251,124.568 756.26,124.571 756.27,124.574 756.279,124.577 756.288,124.58 756.297,124.583 756.306,124.586 756.316,124.59 756.325,124.593 756.334,124.596 756.343,124.599 756.352,124.602 756.362,124.605 756.371,124.608 756.38,124.611 756.389,124.614 756.398,124.618 756.407,124.621 756.417,124.624 756.426,124.627 756.435,124.63 756.444,124.633 756.453,124.636 756.463,124.639 756.472,124.643 756.481,124.646 756.49,124.649 756.499,124.652 756.509,124.655 756.518,124.658 756.527,124.661 756.536,124.664 756.545,124.667 756.555,124.671 756.564,124.674 756.573,124.677 756.582,124.68 756.591,124.683 756.6,124.686 756.61,124.689 756.619,124.692 756.628,124.696 756.637,124.699 756.646,124.702 756.656,124.705 756.665,124.708 756.674,124.711 756.683,124.714 756.692,124.717 756.702,124.72 756.711,124.724 756.72,124.727 756.729,124.73 756.738,124.733 756.747,124.736 756.757,124.739 756.766,124.742 756.775,124.745 756.784,124.749 756.793,124.752 756.803,124.755 756.812,124.758 756.821,124.761 756.83,124.764 756.839,124.767 756.849,124.77 756.858,124.773 756.867,124.777 756.876,124.78 756.885,124.783 756.895,124.786 756.904,124.789 756.913,124.792 756.922,124.795 756.931,124.798 756.94,124.802 756.95,124.805 756.959,124.808 756.968,124.811 756.977,124.814 756.986,124.817 756.996,124.82 757.005,124.823 757.014,124.826 757.023,124.83 757.032,124.833 757.042,124.836 757.051,124.839 757.06,124.842 757.069,124.845 757.078,124.848 757.087,124.851 757.097,124.854 757.106,124.858 757.115,124.861 757.124,124.864 757.133,124.867 757.143,124.87 757.152,124.873 757.161,124.876 757.17,124.879 757.179,124.883 757.189,124.886 757.198,124.889 757.207,124.892 757.216,124.895 757.225,124.898 757.235,124.901 757.244,124.904 757.253,124.907 757.262,124.911 757.271,124.914 757.28,124.917 757.29,124.92 757.299,124.923 757.308,124.926 757.317,124.929 757.326,124.932 757.336,124.936 757.345,124.939 757.354,124.942 757.363,124.945 757.372,124.948 757.382,124.951 757.391,124.954 757.4,124.957 757.409,124.96 757.418,124.964 757.427,124.967 757.437,124.97 757.446,124.973 757.455,124.976 757.464,124.979 757.473,124.982 757.483,124.985 757.492,124.988 757.501,124.992 757.51,124.995 757.519,124.998 757.529,125.001 757.538,125.004 757.547,125.007 757.556,125.01 757.565,125.013 757.575,125.017 757.584,125.02 757.593,125.023 757.602,125.026 757.611,125.029 757.62,125.032 757.63,125.035 757.639,125.038 757.648,125.041 757.657,125.045 757.666,125.048 757.676,125.051 757.685,125.054 757.694,125.057 757.703,125.06 757.712,125.063 757.722,125.066 757.731,125.069 757.74,125.073 757.749,125.076 757.758,125.079 757.767,125.082 757.777,125.085 757.786,125.088 757.795,125.091 757.804,125.094 757.813,125.097 757.823,125.101 757.832,125.104 757.841,125.107 757.85,125.11 757.859,125.113 757.869,125.116 757.878,125.119 757.887,125.122 757.896,125.126 757.905,125.129 757.915,125.132 757.924,125.135 757.933,125.138 757.942,125.141 757.951,125.144 757.96,125.147 757.97,125.15 757.979,125.154 757.988,125.157 757.997,125.16 758.006,125.163 758.016,125.166 758.025,125.169 758.034,125.172 758.043,125.175 758.052,125.178 758.062,125.182 758.071,125.185 758.08,125.188 758.089,125.191 758.098,125.194 758.108,125.197 758.117,125.2 758.126,125.203 758.135,125.206 758.144,125.21 758.153,125.213 758.163,125.216 758.172,125.219 758.181,125.222 758.19,125.225 758.199,125.228 758.209,125.231 758.218,125.235 758.227,125.238 758.236,125.241 758.245,125.244 758.255,125.247 758.264,125.25 758.273,125.253 758.282,125.256 758.291,125.259 758.3,125.263 758.31,125.266 758.319,125.269 758.328,125.272 758.337,125.275 758.346,125.278 758.356,125.281 758.365,125.284 758.374,125.287 758.383,125.291 758.392,125.294 758.402,125.297 758.411,125.3 758.42,125.303 758.429,125.306 758.438,125.309 758.448,125.312 758.457,125.315 758.466,125.319 758.475,125.322 758.484,125.325 758.493,125.328 758.503,125.331 758.512,125.334 758.521,125.337 758.53,125.34 758.539,125.343 758.549,125.347 758.558,125.35 758.567,125.353 758.576,125.356 758.585,125.359 758.595,125.362 758.604,125.365 758.613,125.368 758.622,125.371 758.631,125.375 758.64,125.378 758.65,125.381 758.659,125.384 758.668,125.387 758.677,125.39 758.686,125.393 758.696,125.396 758.705,125.399 758.714,125.403 758.723,125.406 758.732,125.409 758.742,125.412 758.751,125.415 758.76,125.418 758.769,125.421 758.778,125.424 758.788,125.427 758.797,125.431 758.806,125.434 758.815,125.437 758.824,125.44 758.833,125.443 758.843,125.446 758.852,125.449 758.861,125.452 758.87,125.455 758.879,125.459 758.889,125.462 758.898,125.465 758.907,125.468 758.916,125.471 758.925,125.474 758.935,125.477 758.944,125.48 758.953,125.484 758.962,125.487 758.971,125.49 758.98,125.493 758.99,125.496 758.999,125.499 759.008,125.502 759.017,125.505 759.026,125.508 759.036,125.512 759.045,125.515 759.054,125.518 759.063,125.521 759.072,125.524 759.082,125.527 759.091,125.53 759.1,125.533 759.109,125.536 759.118,125.54 759.128,125.543 759.137,125.546 759.146,125.549 759.155,125.552 759.164,125.555 759.173,125.558 759.183,125.561 759.192,125.564 759.201,125.568 759.21,125.571 759.219,125.574 759.229,125.577 759.238,125.58 759.247,125.583 759.256,125.586 759.265,125.589 759.275,125.592 759.284,125.596 759.293,125.599 759.302,125.602 759.311,125.605 759.32,125.608 759.33,125.611 759.339,125.614 759.348,125.617 759.357,125.62 759.366,125.624 759.376,125.627 759.385,125.63 759.394,125.633 759.403,125.636 759.412,125.639 759.422,125.642 759.431,125.645 759.44,125.648 759.449,125.651 759.458,125.655 759.468,125.658 759.477,125.661 759.486,125.664 759.495,125.667 759.504,125.67 759.513,125.673 759.523,125.676 759.532,125.679 759.541,125.683 759.55,125.686 759.559,125.689 759.569,125.692 759.578,125.695 759.587,125.698 759.596,125.701 759.605,125.704 759.615,125.707 759.624,125.711 759.633,125.714 759.642,125.717 759.651,125.72 759.66,125.723 759.67,125.726 759.679,125.729 759.688,125.732 759.697,125.735 759.706,125.739 759.716,125.742 759.725,125.745 759.734,125.748 759.743,125.751 759.752,125.754 759.762,125.757 759.771,125.76 759.78,125.763 759.789,125.767 759.798,125.77 759.808,125.773 759.817,125.776 759.826,125.779 759.835,125.782 759.844,125.785 759.853,125.788 759.863,125.791 759.872,125.795 759.881,125.798 759.89,125.801 759.899,125.804 759.909,125.807 759.918,125.81 759.927,125.813 759.936,125.816 759.945,125.819 759.955,125.823 759.964,125.826 759.973,125.829 759.982,125.832 759.991,125.835 760,125.838 760.01,125.841 760.019,125.844 760.028,125.847 760.037,125.851 760.046,125.854 760.056,125.857 760.065,125.86 760.074,125.863 760.083,125.866 760.092,125.869 760.102,125.872 760.111,125.875 760.12,125.878 760.129,125.882 760.138,125.885 760.148,125.888 760.157,125.891 760.166,125.894 760.175,125.897 760.184,125.9 760.193,125.903 760.203,125.906 760.212,125.91 760.221,125.913 760.23,125.916 760.239,125.919 760.249,125.922 760.258,125.925 760.267,125.928 760.276,125.931 760.285,125.934 760.295,125.938 760.304,125.941 760.313,125.944 760.322,125.947 760.331,125.95 760.34,125.953 760.35,125.956 760.359,125.959 760.368,125.962 760.377,125.966 760.386,125.969 760.396,125.972 760.405,125.975 760.414,125.978 760.423,125.981 760.432,125.984 760.442,125.987 760.451,125.99 760.46,125.993 760.469,125.997 760.478,126 760.488,126.003 760.497,126.006 760.506,126.009 760.515,126.012 760.524,126.015 760.533,126.018 760.543,126.021 760.552,126.025 760.561,126.028 760.57,126.031 760.579,126.034 760.589,126.037 760.598,126.04 760.607,126.043 760.616,126.046 760.625,126.049 760.635,126.053 760.644,126.056 760.653,126.059 760.662,126.062 760.671,126.065 760.681,126.068 760.69,126.071 760.699,126.074 760.708,126.077 760.717,126.081 760.726,126.084 760.736,126.087 760.745,126.09 760.754,126.093 760.763,126.096 760.772,126.099 760.782,126.102 760.791,126.105 760.8,126.108 760.809,126.112 760.818,126.115 760.828,126.118 760.837,126.121 760.846,126.124 760.855,126.127 760.864,126.13 760.873,126.133 760.883,126.136 760.892,126.14 760.901,126.143 760.91,126.146 760.919,126.149 760.929,126.152 760.938,126.155 760.947,126.158 760.956,126.161 760.965,126.164 760.975,126.167 760.984,126.171 760.993,126.174 761.002,126.177 761.011,126.18 761.021,126.183 761.03,126.186 761.039,126.189 761.048,126.192 761.057,126.195 761.066,126.199 761.076,126.202 761.085,126.205 761.094,126.208 761.103,126.211 761.112,126.214 761.122,126.217 761.131,126.22 761.14,126.223 761.149,126.227 761.158,126.23 761.168,126.233 761.177,126.236 761.186,126.239 761.195,126.242 761.204,126.245 761.213,126.248 761.223,126.251 761.232,126.254 761.241,126.258 761.25,126.261 761.259,126.264 761.269,126.267 761.278,126.27 761.287,126.273 761.296,126.276 761.305,126.279 761.315,126.282 761.324,126.286 761.333,126.289 761.342,126.292 761.351,126.295 761.361,126.298 761.37,126.301 761.379,126.304 761.388,126.307 761.397,126.31 761.406,126.313 761.416,126.317 761.425,126.32 761.434,126.323 761.443,126.326 761.452,126.329 761.462,126.332 761.471,126.335 761.48,126.338 761.489,126.341 761.498,126.345 761.508,126.348 761.517,126.351 761.526,126.354 761.535,126.357 761.544,126.36 761.553,126.363 761.563,126.366 761.572,126.369 761.581,126.372 761.59,126.376 761.599,126.379 761.609,126.382 761.618,126.385 761.627,126.388 761.636,126.391 761.645,126.394 761.655,126.397 761.664,126.4 761.673,126.404 761.682,126.407 761.691,126.41 761.701,126.413 761.71,126.416 761.719,126.419 761.728,126.422 761.737,126.425 761.746,126.428 761.756,126.431 761.765,126.435 761.774,126.438 761.783,126.441 761.792,126.444 761.802,126.447 761.811,126.45 761.82,126.453 761.829,126.456 761.838,126.459 761.848,126.463 761.857,126.466 761.866,126.469 761.875,126.472 761.884,126.475 761.893,126.478 761.903,126.481 761.912,126.484 761.921,126.487 761.93,126.49 761.939,126.494 761.949,126.497 761.958,126.5 761.967,126.503 761.976,126.506 761.985,126.509 761.995,126.512 762.004,126.515 762.013,126.518 762.022,126.521 762.031,126.525 762.041,126.528 762.05,126.531 762.059,126.534 762.068,126.537 762.077,126.54 762.086,126.543 762.096,126.546 762.105,126.549 762.114,126.553 762.123,126.556 762.132,126.559 762.142,126.562 762.151,126.565 762.16,126.568 762.169,126.571 762.178,126.574 762.188,126.577 762.197,126.58 762.206,126.584 762.215,126.587 762.224,126.59 762.233,126.593 762.243,126.596 762.252,126.599 762.261,126.602 762.27,126.605 762.279,126.608 762.289,126.611 762.298,126.615 762.307,126.618 762.316,126.621 762.325,126.624 762.335,126.627 762.344,126.63 762.353,126.633 762.362,126.636 762.371,126.639 762.381,126.643 762.39,126.646 762.399,126.649 762.408,126.652 762.417,126.655 762.426,126.658 762.436,126.661 762.445,126.664 762.454,126.667 762.463,126.67 762.472,126.674 762.482,126.677 762.491,126.68 762.5,126.683 762.509,126.686 762.518,126.689 762.528,126.692 762.537,126.695 762.546,126.698 762.555,126.701 762.564,126.705 762.573,126.708 762.583,126.711 762.592,126.714 762.601,126.717 762.61,126.72 762.619,126.723 762.629,126.726 762.638,126.729 762.647,126.732 762.656,126.736 762.665,126.739 762.675,126.742 762.684,126.745 762.693,126.748 762.702,126.751 762.711,126.754 762.721,126.757 762.73,126.76 762.739,126.764 762.748,126.767 762.757,126.77 762.766,126.773 762.776,126.776 762.785,126.779 762.794,126.782 762.803,126.785 762.812,126.788 762.822,126.791 762.831,126.795 762.84,126.798 762.849,126.801 762.858,126.804 762.868,126.807 762.877,126.81 762.886,126.813 762.895,126.816 762.904,126.819 762.914,126.822 762.923,126.826 762.932,126.829 762.941,126.832 762.95,126.835 762.959,126.838 762.969,126.841 762.978,126.844 762.987,126.847 762.996,126.85 763.005,126.853 763.015,126.857 763.024,126.86 763.033,126.863 763.042,126.866 763.051,126.869 763.061,126.872 763.07,126.875 763.079,126.878 763.088,126.881 763.097,126.884 763.106,126.888 763.116,126.891 763.125,126.894 763.134,126.897 763.143,126.9 763.152,126.903 763.162,126.906 763.171,126.909 763.18,126.912 763.189,126.915 763.198,126.919 763.208,126.922 763.217,126.925 763.226,126.928 763.235,126.931 763.244,126.934 763.254,126.937 763.263,126.94 763.272,126.943 763.281,126.947 763.29,126.95 763.299,126.953 763.309,126.956 763.318,126.959 763.327,126.962 763.336,126.965 763.345,126.968 763.355,126.971 763.364,126.974 763.373,126.978 763.382,126.981 763.391,126.984 763.401,126.987 763.41,126.99 763.419,126.993 763.428,126.996 763.437,126.999 763.446,127.002 763.456,127.005 763.465,127.009 763.474,127.012 763.483,127.015 763.492,127.018 763.502,127.021 763.511,127.024 763.52,127.027 763.529,127.03 763.538,127.033 763.548,127.036 763.557,127.04 763.566,127.043 763.575,127.046 763.584,127.049 763.594,127.052 763.603,127.055 763.612,127.058 763.621,127.061 763.63,127.064 763.639,127.067 763.649,127.071 763.658,127.074 763.667,127.077 763.676,127.08 763.685,127.083 763.695,127.086 763.704,127.089 763.713,127.092 763.722,127.095 763.731,127.098 763.741,127.102 763.75,127.105 763.759,127.108 763.768,127.111 763.777,127.114 763.786,127.117 763.796,127.12 763.805,127.123 763.814,127.126 763.823,127.129 763.832,127.132 763.842,127.136 763.851,127.139 763.86,127.142 763.869,127.145 763.878,127.148 763.888,127.151 763.897,127.154 763.906,127.157 763.915,127.16 763.924,127.163 763.934,127.167 763.943,127.17 763.952,127.173 763.961,127.176 763.97,127.179 763.979,127.182 763.989,127.185 763.998,127.188 764.007,127.191 764.016,127.194 764.025,127.198 764.035,127.201 764.044,127.204 764.053,127.207 764.062,127.21 764.071,127.213 764.081,127.216 764.09,127.219 764.099,127.222 764.108,127.225 764.117,127.229 764.126,127.232 764.136,127.235 764.145,127.238 764.154,127.241 764.163,127.244 764.172,127.247 764.182,127.25 764.191,127.253 764.2,127.256 764.209,127.26 764.218,127.263 764.228,127.266 764.237,127.269 764.246,127.272 764.255,127.275 764.264,127.278 764.274,127.281 764.283,127.284 764.292,127.287 764.301,127.291 764.31,127.294 764.319,127.297 764.329,127.3 764.338,127.303 764.347,127.306 764.356,127.309 764.365,127.312 764.375,127.315 764.384,127.318 764.393,127.322 764.402,127.325 764.411,127.328 764.421,127.331 764.43,127.334 764.439,127.337 764.448,127.34 764.457,127.343 764.466,127.346 764.476,127.349 764.485,127.352 764.494,127.356 764.503,127.359 764.512,127.362 764.522,127.365 764.531,127.368 764.54,127.371 764.549,127.374 764.558,127.377 764.568,127.38 764.577,127.383 764.586,127.387 764.595,127.39 764.604,127.393 764.614,127.396 764.623,127.399 764.632,127.402 764.641,127.405 764.65,127.408 764.659,127.411 764.669,127.414 764.678,127.418 764.687,127.421 764.696,127.424 764.705,127.427 764.715,127.43 764.724,127.433 764.733,127.436 764.742,127.439 764.751,127.442 764.761,127.445 764.77,127.449 764.779,127.452 764.788,127.455 764.797,127.458 764.806,127.461 764.816,127.464 764.825,127.467 764.834,127.47 764.843,127.473 764.852,127.476 764.862,127.479 764.871,127.483 764.88,127.486 764.889,127.489 764.898,127.492 764.908,127.495 764.917,127.498 764.926,127.501 764.935,127.504 764.944,127.507 764.954,127.51 764.963,127.514 764.972,127.517 764.981,127.52 764.99,127.523 764.999,127.526 765.009,127.529 765.018,127.532 765.027,127.535 765.036,127.538 765.045,127.541 765.055,127.545 765.064,127.548 765.073,127.551 765.082,127.554 765.091,127.557 765.101,127.56 765.11,127.563 765.119,127.566 765.128,127.569 765.137,127.572 765.146,127.575 765.156,127.579 765.165,127.582 765.174,127.585 765.183,127.588 765.192,127.591 765.202,127.594 765.211,127.597 765.22,127.6 765.229,127.603 765.238,127.606 765.248,127.61 765.257,127.613 765.266,127.616 765.275,127.619 765.284,127.622 765.294,127.625 765.303,127.628 765.312,127.631 765.321,127.634 765.33,127.637 765.339,127.64 765.349,127.644 765.358,127.647 765.367,127.65 765.376,127.653 765.385,127.656 765.395,127.659 765.404,127.662 765.413,127.665 765.422,127.668 765.431,127.671 765.441,127.675 765.45,127.678 765.459,127.681 765.468,127.684 765.477,127.687 765.487,127.69 765.496,127.693 765.505,127.696 765.514,127.699 765.523,127.702 765.532,127.705 765.542,127.709 765.551,127.712 765.56,127.715 765.569,127.718 765.578,127.721 765.588,127.724 765.597,127.727 765.606,127.73 765.615,127.733 765.624,127.736 765.634,127.74 765.643,127.743 765.652,127.746 765.661,127.749 765.67,127.752 765.679,127.755 765.689,127.758 765.698,127.761 765.707,127.764 765.716,127.767 765.725,127.77 765.735,127.774 765.744,127.777 765.753,127.78 765.762,127.783 765.771,127.786 765.781,127.789 765.79,127.792 765.799,127.795 765.808,127.798 765.817,127.801 765.827,127.805 765.836,127.808 765.845,127.811 765.854,127.814 765.863,127.817 765.872,127.82 765.882,127.823 765.891,127.826 765.9,127.829 765.909,127.832 765.918,127.835 765.928,127.839 765.937,127.842 765.946,127.845 765.955,127.848 765.964,127.851 765.974,127.854 765.983,127.857 765.992,127.86 766.001,127.863 766.01,127.866 766.019,127.869 766.029,127.873 766.038,127.876 766.047,127.879 766.056,127.882 766.065,127.885 766.075,127.888 766.084,127.891 766.093,127.894 766.102,127.897 766.111,127.9 766.121,127.904 766.13,127.907 766.139,127.91 766.148,127.913 766.157,127.916 766.167,127.919 766.176,127.922 766.185,127.925 766.194,127.928 766.203,127.931 766.212,127.934 766.222,127.938 766.231,127.941 766.24,127.944 766.249,127.947 766.258,127.95 766.268,127.953 766.277,127.956 766.286,127.959 766.295,127.962 766.304,127.965 766.314,127.968 766.323,127.972 766.332,127.975 766.341,127.978 766.35,127.981 766.359,127.984 766.369,127.987 766.378,127.99 766.387,127.993 766.396,127.996 766.405,127.999 766.415,128.002 766.424,128.006 766.433,128.009 766.442,128.012 766.451,128.015 766.461,128.018 766.47,128.021 766.479,128.024 766.488,128.027 766.497,128.03 766.507,128.033 766.516,128.037 766.525,128.04 766.534,128.043 766.543,128.046 766.552,128.049 766.562,128.052 766.571,128.055 766.58,128.058 766.589,128.061 766.598,128.064 766.608,128.067 766.617,128.071 766.626,128.074 766.635,128.077 766.644,128.08 766.654,128.083 766.663,128.086 766.672,128.089 766.681,128.092 766.69,128.095 766.699,128.098 766.709,128.101 766.718,128.105 766.727,128.108 766.736,128.111 766.745,128.114 766.755,128.117 766.764,128.12 766.773,128.123 766.782,128.126 766.791,128.129 766.801,128.132 766.81,128.135 766.819,128.139 766.828,128.142 766.837,128.145 766.847,128.148 766.856,128.151 766.865,128.154 766.874,128.157 766.883,128.16 766.892,128.163 766.902,128.166 766.911,128.169 766.92,128.173 766.929,128.176 766.938,128.179 766.948,128.182 766.957,128.185 766.966,128.188 766.975,128.191 766.984,128.194 766.994,128.197 767.003,128.2 767.012,128.203 767.021,128.207 767.03,128.21 767.039,128.213 767.049,128.216 767.058,128.219 767.067,128.222 767.076,128.225 767.085,128.228 767.095,128.231 767.104,128.234 767.113,128.237 767.122,128.241 767.131,128.244 767.141,128.247 767.15,128.25 767.159,128.253 767.168,128.256 767.177,128.259 767.187,128.262 767.196,128.265 767.205,128.268 767.214,128.271 767.223,128.275 767.232,128.278 767.242,128.281 767.251,128.284 767.26,128.287 767.269,128.29 767.278,128.293 767.288,128.296 767.297,128.299 767.306,128.302 767.315,128.305 767.324,128.309 767.334,128.312 767.343,128.315 767.352,128.318 767.361,128.321 767.37,128.324 767.379,128.327 767.389,128.33 767.398,128.333 767.407,128.336 767.416,128.339 767.425,128.343 767.435,128.346 767.444,128.349 767.453,128.352 767.462,128.355 767.471,128.358 767.481,128.361 767.49,128.364 767.499,128.367 767.508,128.37 767.517,128.373 767.527,128.377 767.536,128.38 767.545,128.383 767.554,128.386 767.563,128.389 767.572,128.392 767.582,128.395 767.591,128.398 767.6,128.401 767.609,128.404 767.618,128.407 767.628,128.411 767.637,128.414 767.646,128.417 767.655,128.42 767.664,128.423 767.674,128.426 767.683,128.429 767.692,128.432 767.701,128.435 767.71,128.438 767.719,128.441 767.729,128.445 767.738,128.448 767.747,128.451 767.756,128.454 767.765,128.457 767.775,128.46 767.784,128.463 767.793,128.466 767.802,128.469 767.811,128.472 767.821,128.475 767.83,128.479 767.839,128.482 767.848,128.485 767.857,128.488 767.867,128.491 767.876,128.494 767.885,128.497 767.894,128.5 767.903,128.503 767.912,128.506 767.922,128.509 767.931,128.512 767.94,128.516 767.949,128.519 767.958,128.522 767.968,128.525 767.977,128.528 767.986,128.531 767.995,128.534 768.004,128.537 768.014,128.54 768.023,128.543 768.032,128.546 768.041,128.55 768.05,128.553 768.06,128.556 768.069,128.559 768.078,128.562 768.087,128.565 768.096,128.568 768.105,128.571 768.115,128.574 768.124,128.577 768.133,128.58 768.142,128.584 768.151,128.587 768.161,128.59 768.17,128.593 768.179,128.596 768.188,128.599 768.197,128.602 768.207,128.605 768.216,128.608 768.225,128.611 768.234,128.614 768.243,128.617 768.252,128.621 768.262,128.624 768.271,128.627 768.28,128.63 768.289,128.633 768.298,128.636 768.308,128.639 768.317,128.642 768.326,128.645 768.335,128.648 768.344,128.651 768.354,128.655 768.363,128.658 768.372,128.661 768.381,128.664 768.39,128.667 768.4,128.67 768.409,128.673 768.418,128.676 768.427,128.679 768.436,128.682 768.445,128.685 768.455,128.689 768.464,128.692 768.473,128.695 768.482,128.698 768.491,128.701 768.501,128.704 768.51,128.707 768.519,128.71 768.528,128.713 768.537,128.716 768.547,128.719 768.556,128.722 768.565,128.726 768.574,128.729 768.583,128.732 768.592,128.735 768.602,128.738 768.611,128.741 768.62,128.744 768.629,128.747 768.638,128.75 768.648,128.753 768.657,128.756 768.666,128.76 768.675,128.763 768.684,128.766 768.694,128.769 768.703,128.772 768.712,128.775 768.721,128.778 768.73,128.781 768.74,128.784 768.749,128.787 768.758,128.79 768.767,128.793 768.776,128.797 768.785,128.8 768.795,128.803 768.804,128.806 768.813,128.809 768.822,128.812 768.831,128.815 768.841,128.818 768.85,128.821 768.859,128.824 768.868,128.827 768.877,128.831 768.887,128.834 768.896,128.837 768.905,128.84 768.914,128.843 768.923,128.846 768.932,128.849 768.942,128.852 768.951,128.855 768.96,128.858 768.969,128.861 768.978,128.864 768.988,128.868 768.997,128.871 769.006,128.874 769.015,128.877 769.024,128.88 769.034,128.883 769.043,128.886 769.052,128.889 769.061,128.892 769.07,128.895 769.08,128.898 769.089,128.902 769.098,128.905 769.107,128.908 769.116,128.911 769.125,128.914 769.135,128.917 769.144,128.92 769.153,128.923 769.162,128.926 769.171,128.929 769.181,128.932 769.19,128.935 769.199,128.939 769.208,128.942 769.217,128.945 769.227,128.948 769.236,128.951 769.245,128.954 769.254,128.957 769.263,128.96 769.272,128.963 769.282,128.966 769.291,128.969 769.3,128.972 769.309,128.976 769.318,128.979 769.328,128.982 769.337,128.985 769.346,128.988 769.355,128.991 769.364,128.994 769.374,128.997 769.383,129 769.392,129.003 769.401,129.006 769.41,129.01 769.42,129.013 769.429,129.016 769.438,129.019 769.447,129.022 769.456,129.025 769.465,129.028 769.475,129.031 769.484,129.034 769.493,129.037 769.502,129.04 769.511,129.043 769.521,129.047 769.53,129.05 769.539,129.053 769.548,129.056 769.557,129.059 769.567,129.062 769.576,129.065 769.585,129.068 769.594,129.071 769.603,129.074 769.612,129.077 769.622,129.08 769.631,129.084 769.64,129.087 769.649,129.09 769.658,129.093 769.668,129.096 769.677,129.099 769.686,129.102 769.695,129.105 769.704,129.108 769.714,129.111 769.723,129.114 769.732,129.117 769.741,129.121 769.75,129.124 769.76,129.127 769.769,129.13 769.778,129.133 769.787,129.136 769.796,129.139 769.805,129.142 769.815,129.145 769.824,129.148 769.833,129.151 769.842,129.154 769.851,129.158 769.861,129.161 769.87,129.164 769.879,129.167 769.888,129.17 769.897,129.173 769.907,129.176 769.916,129.179 769.925,129.182 769.934,129.185 769.943,129.188 769.952,129.192 769.962,129.195 769.971,129.198 769.98,129.201 769.989,129.204 769.998,129.207 770.008,129.21 770.017,129.213 770.026,129.216 770.035,129.219 770.044,129.222 770.054,129.225 770.063,129.229 770.072,129.232 770.081,129.235 770.09,129.238 770.1,129.241 770.109,129.244 770.118,129.247 770.127,129.25 770.136,129.253 770.145,129.256 770.155,129.259 770.164,129.262 770.173,129.266 770.182,129.269 770.191,129.272 770.201,129.275 770.21,129.278 770.219,129.281 770.228,129.284 770.237,129.287 770.247,129.29 770.256,129.293 770.265,129.296 770.274,129.299 770.283,129.303 770.293,129.306 770.302,129.309 770.311,129.312 770.32,129.315 770.329,129.318 770.338,129.321 770.348,129.324 770.357,129.327 770.366,129.33 770.375,129.333 770.384,129.336 770.394,129.34 770.403,129.343 770.412,129.346 770.421,129.349 770.43,129.352 770.44,129.355 770.449,129.358 770.458,129.361 770.467,129.364 770.476,129.367 770.485,129.37 770.495,129.373 770.504,129.376 770.513,129.38 770.522,129.383 770.531,129.386 770.541,129.389 770.55,129.392 770.559,129.395 770.568,129.398 770.577,129.401 770.587,129.404 770.596,129.407 770.605,129.41 770.614,129.413 770.623,129.417 770.633,129.42 770.642,129.423 770.651,129.426 770.66,129.429 770.669,129.432 770.678,129.435 770.688,129.438 770.697,129.441 770.706,129.444 770.715,129.447 770.724,129.45 770.734,129.454 770.743,129.457 770.752,129.46 770.761,129.463 770.77,129.466 770.78,129.469 770.789,129.472 770.798,129.475 770.807,129.478 770.816,129.481 770.825,129.484 770.835,129.487 770.844,129.491 770.853,129.494 770.862,129.497 770.871,129.5 770.881,129.503 770.89,129.506 770.899,129.509 770.908,129.512 770.917,129.515 770.927,129.518 770.936,129.521 770.945,129.524 770.954,129.528 770.963,129.531 770.973,129.534 770.982,129.537 770.991,129.54 771,129.543 771.009,129.546 771.018,129.549 771.028,129.552 771.037,129.555 771.046,129.558 771.055,129.561 771.064,129.564 771.074,129.568 771.083,129.571 771.092,129.574 771.101,129.577 771.11,129.58 771.12,129.583 771.129,129.586 771.138,129.589 771.147,129.592 771.156,129.595 771.165,129.598 771.175,129.601 771.184,129.605 771.193,129.608 771.202,129.611 771.211,129.614 771.221,129.617 771.23,129.62 771.239,129.623 771.248,129.626 771.257,129.629 771.267,129.632 771.276,129.635 771.285,129.638 771.294,129.642 771.303,129.645 771.313,129.648 771.322,129.651 771.331,129.654 771.34,129.657 771.349,129.66 771.358,129.663 771.368,129.666 771.377,129.669 771.386,129.672 771.395,129.675 771.404,129.678 771.414,129.682 771.423,129.685 771.432,129.688 771.441,129.691 771.45,129.694 771.46,129.697 771.469,129.7 771.478,129.703 771.487,129.706 771.496,129.709 771.505,129.712 771.515,129.715 771.524,129.719 771.533,129.722 771.542,129.725 771.551,129.728 771.561,129.731 771.57,129.734 771.579,129.737 771.588,129.74 771.597,129.743 771.607,129.746 771.616,129.749 771.625,129.752 771.634,129.755 771.643,129.759 771.653,129.762 771.662,129.765 771.671,129.768 771.68,129.771 771.689,129.774 771.698,129.777 771.708,129.78 771.717,129.783 771.726,129.786 771.735,129.789 771.744,129.792 771.754,129.796 771.763,129.799 771.772,129.802 771.781,129.805 771.79,129.808 771.8,129.811 771.809,129.814 771.818,129.817 771.827,129.82 771.836,129.823 771.845,129.826 771.855,129.829 771.864,129.832 771.873,129.836 771.882,129.839 771.891,129.842 771.901,129.845 771.91,129.848 771.919,129.851 771.928,129.854 771.937,129.857 771.947,129.86 771.956,129.863 771.965,129.866 771.974,129.869 771.983,129.872 771.993,129.876 772.002,129.879 772.011,129.882 772.02,129.885 772.029,129.888 772.038,129.891 772.048,129.894 772.057,129.897 772.066,129.9 772.075,129.903 772.084,129.906 772.094,129.909 772.103,129.913 772.112,129.916 772.121,129.919 772.13,129.922 772.14,129.925 772.149,129.928 772.158,129.931 772.167,129.934 772.176,129.937 772.185,129.94 772.195,129.943 772.204,129.946 772.213,129.949 772.222,129.953 772.231,129.956 772.241,129.959 772.25,129.962 772.259,129.965 772.268,129.968 772.277,129.971 772.287,129.974 772.296,129.977 772.305,129.98 772.314,129.983 772.323,129.986 772.333,129.989 772.342,129.993 772.351,129.996 772.36,129.999 772.369,130.002 772.378,130.005 772.388,130.008 772.397,130.011 772.406,130.014 772.415,130.017 772.424,130.02 772.434,130.023 772.443,130.026 772.452,130.029 772.461,130.033 772.47,130.036 772.48,130.039 772.489,130.042 772.498,130.045 772.507,130.048 772.516,130.051 772.525,130.054 772.535,130.057 772.544,130.06 772.553,130.063 772.562,130.066 772.571,130.069 772.581,130.073 772.59,130.076 772.599,130.079 772.608,130.082 772.617,130.085 772.627,130.088 772.636,130.091 772.645,130.094 772.654,130.097 772.663,130.1 772.673,130.103 772.682,130.106 772.691,130.109 772.7,130.113 772.709,130.116 772.718,130.119 772.728,130.122 772.737,130.125 772.746,130.128 772.755,130.131 772.764,130.134 772.774,130.137 772.783,130.14 772.792,130.143 772.801,130.146 772.81,130.149 772.82,130.153 772.829,130.156 772.838,130.159 772.847,130.162 772.856,130.165 772.866,130.168 772.875,130.171 772.884,130.174 772.893,130.177 772.902,130.18 772.911,130.183 772.921,130.186 772.93,130.189 772.939,130.193 772.948,130.196 772.957,130.199 772.967,130.202 772.976,130.205 772.985,130.208 772.994,130.211 773.003,130.214 773.013,130.217 773.022,130.22 773.031,130.223 773.04,130.226 773.049,130.229 773.058,130.233 773.068,130.236 773.077,130.239 773.086,130.242 773.095,130.245 773.104,130.248 773.114,130.251 773.123,130.254 773.132,130.257 773.141,130.26 773.15,130.263 773.16,130.266 773.169,130.269 773.178,130.273 773.187,130.276 773.196,130.279 773.206,130.282 773.215,130.285 773.224,130.288 773.233,130.291 773.242,130.294 773.251,130.297 773.261,130.3 773.27,130.303 773.279,130.306 773.288,130.309 773.297,130.313 773.307,130.316 773.316,130.319 773.325,130.322 773.334,130.325 773.343,130.328 773.353,130.331 773.362,130.334 773.371,130.337 773.38,130.34 773.389,130.343 773.398,130.346 773.408,130.349 773.417,130.353 773.426,130.356 773.435,130.359 773.444,130.362 773.454,130.365 773.463,130.368 773.472,130.371 773.481,130.374 773.49,130.377 773.5,130.38 773.509,130.383 773.518,130.386 773.527,130.389 773.536,130.392 773.546,130.396 773.555,130.399 773.564,130.402 773.573,130.405 773.582,130.408 773.591,130.411 773.601,130.414 773.61,130.417 773.619,130.42 773.628,130.423 773.637,130.426 773.647,130.429 773.656,130.432 773.665,130.436 773.674,130.439 773.683,130.442 773.693,130.445 773.702,130.448 773.711,130.451 773.72,130.454 773.729,130.457 773.738,130.46 773.748,130.463 773.757,130.466 773.766,130.469 773.775,130.472 773.784,130.476 773.794,130.479 773.803,130.482 773.812,130.485 773.821,130.488 773.83,130.491 773.84,130.494 773.849,130.497 773.858,130.5 773.867,130.503 773.876,130.506 773.886,130.509 773.895,130.512 773.904,130.515 773.913,130.519 773.922,130.522 773.931,130.525 773.941,130.528 773.95,130.531 773.959,130.534 773.968,130.537 773.977,130.54 773.987,130.543 773.996,130.546 774.005,130.549 774.014,130.552 774.023,130.555 774.033,130.559 774.042,130.562 774.051,130.565 774.06,130.568 774.069,130.571 774.078,130.574 774.088,130.577 774.097,130.58 774.106,130.583 774.115,130.586 774.124,130.589 774.134,130.592 774.143,130.595 774.152,130.598 774.161,130.602 774.17,130.605 774.18,130.608 774.189,130.611 774.198,130.614 774.207,130.617 774.216,130.62 774.226,130.623 774.235,130.626 774.244,130.629 774.253,130.632 774.262,130.635 774.271,130.638 774.281,130.642 774.29,130.645 774.299,130.648 774.308,130.651 774.317,130.654 774.327,130.657 774.336,130.66 774.345,130.663 774.354,130.666 774.363,130.669 774.373,130.672 774.382,130.675 774.391,130.678 774.4,130.681 774.409,130.685 774.418,130.688 774.428,130.691 774.437,130.694 774.446,130.697 774.455,130.7 774.464,130.703 774.474,130.706 774.483,130.709 774.492,130.712 774.501,130.715 774.51,130.718 774.52,130.721 774.529,130.724 774.538,130.728 774.547,130.731 774.556,130.734 774.566,130.737 774.575,130.74 774.584,130.743 774.593,130.746 774.602,130.749 774.611,130.752 774.621,130.755 774.63,130.758 774.639,130.761 774.648,130.764 774.657,130.768 774.667,130.771 774.676,130.774 774.685,130.777 774.694,130.78 774.703,130.783 774.713,130.786 774.722,130.789 774.731,130.792 774.74,130.795 774.749,130.798 774.758,130.801 774.768,130.804 774.777,130.807 774.786,130.811 774.795,130.814 774.804,130.817 774.814,130.82 774.823,130.823 774.832,130.826 774.841,130.829 774.85,130.832 774.86,130.835 774.869,130.838 774.878,130.841 774.887,130.844 774.896,130.847 774.906,130.85 774.915,130.854 774.924,130.857 774.933,130.86 774.942,130.863 774.951,130.866 774.961,130.869 774.97,130.872 774.979,130.875 774.988,130.878 774.997,130.881 775.007,130.884 775.016,130.887 775.025,130.89 775.034,130.893 775.043,130.897 775.053,130.9 775.062,130.903 775.071,130.906 775.08,130.909 775.089,130.912 775.098,130.915 775.108,130.918 775.117,130.921 775.126,130.924 775.135,130.927 775.144,130.93 775.154,130.933 775.163,130.936 775.172,130.94 775.181,130.943 775.19,130.946 775.2,130.949 775.209,130.952 775.218,130.955 775.227,130.958 775.236,130.961 775.246,130.964 775.255,130.967 775.264,130.97 775.273,130.973 775.282,130.976 775.291,130.979 775.301,130.983 775.31,130.986 775.319,130.989 775.328,130.992 775.337,130.995 775.347,130.998 775.356,131.001 775.365,131.004 775.374,131.007 775.383,131.01 775.393,131.013 775.402,131.016 775.411,131.019 775.42,131.022 775.429,131.026 775.439,131.029 775.448,131.032 775.457,131.035 775.466,131.038 775.475,131.041 775.484,131.044 775.494,131.047 775.503,131.05 775.512,131.053 775.521,131.056 775.53,131.059 775.54,131.062 775.549,131.065 775.558,131.069 775.567,131.072 775.576,131.075 775.586,131.078 775.595,131.081 775.604,131.084 775.613,131.087 775.622,131.09 775.631,131.093 775.641,131.096 775.65,131.099 775.659,131.102 775.668,131.105 775.677,131.108 775.687,131.112 775.696,131.115 775.705,131.118 775.714,131.121 775.723,131.124 775.733,131.127 775.742,131.13 775.751,131.133 775.76,131.136 775.769,131.139 775.779,131.142 775.788,131.145 775.797,131.148 775.806,131.151 775.815,131.155 775.824,131.158 775.834,131.161 775.843,131.164 775.852,131.167 775.861,131.17 775.87,131.173 775.88,131.176 775.889,131.179 775.898,131.182 775.907,131.185 775.916,131.188 775.926,131.191 775.935,131.194 775.944,131.198 775.953,131.201 775.962,131.204 775.971,131.207 775.981,131.21 775.99,131.213 775.999,131.216 776.008,131.219 776.017,131.222 776.027,131.225 776.036,131.228 776.045,131.231 776.054,131.234 776.063,131.237 776.073,131.24 776.082,131.244 776.091,131.247 776.1,131.25 776.109,131.253 776.119,131.256 776.128,131.259 776.137,131.262 776.146,131.265 776.155,131.268 776.164,131.271 776.174,131.274 776.183,131.277 776.192,131.28 776.201,131.283 776.21,131.287 776.22,131.29 776.229,131.293 776.238,131.296 776.247,131.299 776.256,131.302 776.266,131.305 776.275,131.308 776.284,131.311 776.293,131.314 776.302,131.317 776.311,131.32 776.321,131.323 776.33,131.326 776.339,131.33 776.348,131.333 776.357,131.336 776.367,131.339 776.376,131.342 776.385,131.345 776.394,131.348 776.403,131.351 776.413,131.354 776.422,131.357 776.431,131.36 776.44,131.363 776.449,131.366 776.459,131.369 776.468,131.372 776.477,131.376 776.486,131.379 776.495,131.382 776.504,131.385 776.514,131.388 776.523,131.391 776.532,131.394 776.541,131.397 776.55,131.4 776.56,131.403 776.569,131.406 776.578,131.409 776.587,131.412 776.596,131.415 776.606,131.419 776.615,131.422 776.624,131.425 776.633,131.428 776.642,131.431 776.651,131.434 776.661,131.437 776.67,131.44 776.679,131.443 776.688,131.446 776.697,131.449 776.707,131.452 776.716,131.455 776.725,131.458 776.734,131.461 776.743,131.465 776.753,131.468 776.762,131.471 776.771,131.474 776.78,131.477 776.789,131.48 776.799,131.483 776.808,131.486 776.817,131.489 776.826,131.492 776.835,131.495 776.844,131.498 776.854,131.501 776.863,131.504 776.872,131.507 776.881,131.511 776.89,131.514 776.9,131.517 776.909,131.52 776.918,131.523 776.927,131.526 776.936,131.529 776.946,131.532 776.955,131.535 776.964,131.538 776.973,131.541 776.982,131.544 776.991,131.547 777.001,131.55 777.01,131.554 777.019,131.557 777.028,131.56 777.037,131.563 777.047,131.566 777.056,131.569 777.065,131.572 777.074,131.575 777.083,131.578 777.093,131.581 777.102,131.584 777.111,131.587 777.12,131.59 777.129,131.593 777.139,131.596 777.148,131.6 777.157,131.603 777.166,131.606 777.175,131.609 777.184,131.612 777.194,131.615 777.203,131.618 777.212,131.621 777.221,131.624 777.23,131.627 777.24,131.63 777.249,131.633 777.258,131.636 777.267,131.639 777.276,131.642 777.286,131.646 777.295,131.649 777.304,131.652 777.313,131.655 777.322,131.658 777.331,131.661 777.341,131.664 777.35,131.667 777.359,131.67 777.368,131.673 777.377,131.676 777.387,131.679 777.396,131.682 777.405,131.685 777.414,131.688 777.423,131.692 777.433,131.695 777.442,131.698 777.451,131.701 777.46,131.704 777.469,131.707 777.479,131.71 777.488,131.713 777.497,131.716 777.506,131.719 777.515,131.722 777.524,131.725 777.534,131.728 777.543,131.731 777.552,131.734 777.561,131.738 777.57,131.741 777.58,131.744 777.589,131.747 777.598,131.75 777.607,131.753 777.616,131.756 777.626,131.759 777.635,131.762 777.644,131.765 777.653,131.768 777.662,131.771 777.672,131.774 777.681,131.777 777.69,131.78 777.699,131.784 777.708,131.787 777.717,131.79 777.727,131.793 777.736,131.796 777.745,131.799 777.754,131.802 777.763,131.805 777.773,131.808 777.782,131.811 777.791,131.814 777.8,131.817 777.809,131.82 777.819,131.823 777.828,131.826 777.837,131.83 777.846,131.833 777.855,131.836 777.864,131.839 777.874,131.842 777.883,131.845 777.892,131.848 777.901,131.851 777.91,131.854 777.92,131.857 777.929,131.86 777.938,131.863 777.947,131.866 777.956,131.869 777.966,131.872 777.975,131.876 777.984,131.879 777.993,131.882 778.002,131.885 778.012,131.888 778.021,131.891 778.03,131.894 778.039,131.897 778.048,131.9 778.057,131.903 778.067,131.906 778.076,131.909 778.085,131.912 778.094,131.915 778.103,131.918 778.113,131.922 778.122,131.925 778.131,131.928 778.14,131.931 778.149,131.934 778.159,131.937 778.168,131.94 778.177,131.943 778.186,131.946 778.195,131.949 778.204,131.952 778.214,131.955 778.223,131.958 778.232,131.961 778.241,131.964 778.25,131.968 778.26,131.971 778.269,131.974 778.278,131.977 778.287,131.98 778.296,131.983 778.306,131.986 778.315,131.989 778.324,131.992 778.333,131.995 778.342,131.998 778.352,132.001 778.361,132.004 778.37,132.007 778.379,132.01 778.388,132.013 778.397,132.017 778.407,132.02 778.416,132.023 778.425,132.026 778.434,132.029 778.443,132.032 778.453,132.035 778.462,132.038 778.471,132.041 778.48,132.044 778.489,132.047 778.499,132.05 778.508,132.053 778.517,132.056 778.526,132.059 778.535,132.063 778.544,132.066 778.554,132.069 778.563,132.072 778.572,132.075 778.581,132.078 778.59,132.081 778.6,132.084 778.609,132.087 778.618,132.09 778.627,132.093 778.636,132.096 778.646,132.099 778.655,132.102 778.664,132.105 778.673,132.108 778.682,132.112 778.692,132.115 778.701,132.118 778.71,132.121 778.719,132.124 778.728,132.127 778.737,132.13 778.747,132.133 778.756,132.136 778.765,132.139 778.774,132.142 778.783,132.145 778.793,132.148 778.802,132.151 778.811,132.154 778.82,132.158 778.829,132.161 778.839,132.164 778.848,132.167 778.857,132.17 778.866,132.173 778.875,132.176 778.884,132.179 778.894,132.182 778.903,132.185 778.912,132.188 778.921,132.191 778.93,132.194 778.94,132.197 778.949,132.2 778.958,132.203 778.967,132.207 778.976,132.21 778.986,132.213 778.995,132.216 779.004,132.219 779.013,132.222 779.022,132.225 779.032,132.228 779.041,132.231 779.05,132.234 779.059,132.237 779.068,132.24 779.077,132.243 779.087,132.246 779.096,132.249 779.105,132.253 779.114,132.256 779.123,132.259 779.133,132.262 779.142,132.265 779.151,132.268 779.16,132.271 779.169,132.274 779.179,132.277 779.188,132.28 779.197,132.283 779.206,132.286 779.215,132.289 779.224,132.292 779.234,132.295 779.243,132.298 779.252,132.302 779.261,132.305 779.27,132.308 779.28,132.311 779.289,132.314 779.298,132.317 779.307,132.32 779.316,132.323 779.326,132.326 779.335,132.329 779.344,132.332 779.353,132.335 779.362,132.338 779.372,132.341 779.381,132.344 779.39,132.347 779.399,132.351 779.408,132.354 779.417,132.357 779.427,132.36 779.436,132.363 779.445,132.366 779.454,132.369 779.463,132.372 779.473,132.375 779.482,132.378 779.491,132.381 779.5,132.384 779.509,132.387 779.519,132.39 779.528,132.393 779.537,132.397 779.546,132.4 779.555,132.403 779.564,132.406 779.574,132.409 779.583,132.412 779.592,132.415 779.601,132.418 779.61,132.421 779.62,132.424 779.629,132.427 779.638,132.43 779.647,132.433 779.656,132.436 779.666,132.439 779.675,132.442 779.684,132.446 779.693,132.449 779.702,132.452 779.712,132.455 779.721,132.458 779.73,132.461 779.739,132.464 779.748,132.467 779.757,132.47 779.767,132.473 779.776,132.476 779.785,132.479 779.794,132.482 779.803,132.485 779.813,132.488 779.822,132.491 779.831,132.495 779.84,132.498 779.849,132.501 779.859,132.504 779.868,132.507 779.877,132.51 779.886,132.513 779.895,132.516 779.904,132.519 779.914,132.522 779.923,132.525 779.932,132.528 779.941,132.531 779.95,132.534 779.96,132.537 779.969,132.54 779.978,132.544 779.987,132.547 779.996,132.55 780.006,132.553 780.015,132.556 780.024,132.559 780.033,132.562 780.042,132.565 780.052,132.568 780.061,132.571 780.07,132.574 780.079,132.577 780.088,132.58 780.097,132.583 780.107,132.586 780.116,132.589 780.125,132.593 780.134,132.596 780.143,132.599 780.153,132.602 780.162,132.605 780.171,132.608 780.18,132.611 780.189,132.614 780.199,132.617 780.208,132.62 780.217,132.623 780.226,132.626 780.235,132.629 780.245,132.632 780.254,132.635 780.263,132.638 780.272,132.642 780.281,132.645 780.29,132.648 780.3,132.651 780.309,132.654 780.318,132.657 780.327,132.66 780.336,132.663 780.346,132.666 780.355,132.669 780.364,132.672 780.373,132.675 780.382,132.678 780.392,132.681 780.401,132.684 780.41,132.687 780.419,132.69 780.428,132.694 780.437,132.697 780.447,132.7 780.456,132.703 780.465,132.706 780.474,132.709 780.483,132.712 780.493,132.715 780.502,132.718 780.511,132.721 780.52,132.724 780.529,132.727 780.539,132.73 780.548,132.733 780.557,132.736 780.566,132.739 780.575,132.743 780.585,132.746 780.594,132.749 780.603,132.752 780.612,132.755 780.621,132.758 780.63,132.761 780.64,132.764 780.649,132.767 780.658,132.77 780.667,132.773 780.676,132.776 780.686,132.779 780.695,132.782 780.704,132.785 780.713,132.788 780.722,132.792 780.732,132.795 780.741,132.798 780.75,132.801 780.759,132.804 780.768,132.807 780.777,132.81 780.787,132.813 780.796,132.816 780.805,132.819 780.814,132.822 780.823,132.825 780.833,132.828 780.842,132.831 780.851,132.834 780.86,132.837 780.869,132.84 780.879,132.844 780.888,132.847 780.897,132.85 780.906,132.853 780.915,132.856 780.925,132.859 780.934,132.862 780.943,132.865 780.952,132.868 780.961,132.871 780.97,132.874 780.98,132.877 780.989,132.88 780.998,132.883 781.007,132.886 781.016,132.889 781.026,132.893 781.035,132.896 781.044,132.899 781.053,132.902 781.062,132.905 781.072,132.908 781.081,132.911 781.09,132.914 781.099,132.917 781.108,132.92 781.117,132.923 781.127,132.926 781.136,132.929 781.145,132.932 781.154,132.935 781.163,132.938 781.173,132.941 781.182,132.945 781.191,132.948 781.2,132.951 781.209,132.954 781.219,132.957 781.228,132.96 781.237,132.963 781.246,132.966 781.255,132.969 781.265,132.972 781.274,132.975 781.283,132.978 781.292,132.981 781.301,132.984 781.31,132.987 781.32,132.99 781.329,132.994 781.338,132.997 781.347,133 781.356,133.003 781.366,133.006 781.375,133.009 781.384,133.012 781.393,133.015 781.402,133.018 781.412,133.021 781.421,133.024 781.43,133.027 781.439,133.03 781.448,133.033 781.457,133.036 781.467,133.039 781.476,133.042 781.485,133.046 781.494,133.049 781.503,133.052 781.513,133.055 781.522,133.058 781.531,133.061 781.54,133.064 781.549,133.067 781.559,133.07 781.568,133.073 781.577,133.076 781.586,133.079 781.595,133.082 781.605,133.085 781.614,133.088 781.623,133.091 781.632,133.094 781.641,133.098 781.65,133.101 781.66,133.104 781.669,133.107 781.678,133.11 781.687,133.113 781.696,133.116 781.706,133.119 781.715,133.122 781.724,133.125 781.733,133.128 781.742,133.131 781.752,133.134 781.761,133.137 781.77,133.14 781.779,133.143 781.788,133.146 781.797,133.15 781.807,133.153 781.816,133.156 781.825,133.159 781.834,133.162 781.843,133.165 781.853,133.168 781.862,133.171 781.871,133.174 781.88,133.177 781.889,133.18 781.899,133.183 781.908,133.186 781.917,133.189 781.926,133.192 781.935,133.195 781.945,133.198 781.954,133.202 781.963,133.205 781.972,133.208 781.981,133.211 781.99,133.214 782,133.217 782.009,133.22 782.018,133.223 782.027,133.226 782.036,133.229 782.046,133.232 782.055,133.235 782.064,133.238 782.073,133.241 782.082,133.244 782.092,133.247 782.101,133.25 782.11,133.254 782.119,133.257 782.128,133.26 782.137,133.263 782.147,133.266 782.156,133.269 782.165,133.272 782.174,133.275 782.183,133.278 782.193,133.281 782.202,133.284 782.211,133.287 782.22,133.29 782.229,133.293 782.239,133.296 782.248,133.299 782.257,133.302 782.266,133.306 782.275,133.309 782.285,133.312 782.294,133.315 782.303,133.318 782.312,133.321 782.321,133.324 782.33,133.327 782.34,133.33 782.349,133.333 782.358,133.336 782.367,133.339 782.376,133.342 782.386,133.345 782.395,133.348 782.404,133.351 782.413,133.354 782.422,133.358 782.432,133.361 782.441,133.364 782.45,133.367 782.459,133.37 782.468,133.373 782.477,133.376 782.487,133.379 782.496,133.382 782.505,133.385 782.514,133.388 782.523,133.391 782.533,133.394 782.542,133.397 782.551,133.4 782.56,133.403 782.569,133.406 782.579,133.41 782.588,133.413 782.597,133.416 782.606,133.419 782.615,133.422 782.625,133.425 782.634,133.428 782.643,133.431 782.652,133.434 782.661,133.437 782.67,133.44 782.68,133.443 782.689,133.446 782.698,133.449 782.707,133.452 782.716,133.455 782.726,133.458 782.735,133.462 782.744,133.465 782.753,133.468 782.762,133.471 782.772,133.474 782.781,133.477 782.79,133.48 782.799,133.483 782.808,133.486 782.818,133.489 782.827,133.492 782.836,133.495 782.845,133.498 782.854,133.501 782.863,133.504 782.873,133.507 782.882,133.51 782.891,133.513 782.9,133.517 782.909,133.52 782.919,133.523 782.928,133.526 782.937,133.529 782.946,133.532 782.955,133.535 782.965,133.538 782.974,133.541 782.983,133.544 782.992,133.547 783.001,133.55 783.01,133.553 783.02,133.556 783.029,133.559 783.038,133.562 783.047,133.565 783.056,133.569 783.066,133.572 783.075,133.575 783.084,133.578 783.093,133.581 783.102,133.584 783.112,133.587 783.121,133.59 783.13,133.593 783.139,133.596 783.148,133.599 783.158,133.602 783.167,133.605 783.176,133.608 783.185,133.611 783.194,133.614 783.203,133.617 783.213,133.62 783.222,133.624 783.231,133.627 783.24,133.63 783.249,133.633 783.259,133.636 783.268,133.639 783.277,133.642 783.286,133.645 783.295,133.648 783.305,133.651 783.314,133.654 783.323,133.657 783.332,133.66 783.341,133.663 783.35,133.666 783.36,133.669 783.369,133.672 783.378,133.676 783.387,133.679 783.396,133.682 783.406,133.685 783.415,133.688 783.424,133.691 783.433,133.694 783.442,133.697 783.452,133.7 783.461,133.703 783.47,133.706 783.479,133.709 783.488,133.712 783.498,133.715 783.507,133.718 783.516,133.721 783.525,133.724 783.534,133.727 783.543,133.731 783.553,133.734 783.562,133.737 783.571,133.74 783.58,133.743 783.589,133.746 783.599,133.749 783.608,133.752 783.617,133.755 783.626,133.758 783.635,133.761 783.645,133.764 783.654,133.767 783.663,133.77 783.672,133.773 783.681,133.776 783.69,133.779 783.7,133.782 783.709,133.786 783.718,133.789 783.727,133.792 783.736,133.795 783.746,133.798 783.755,133.801 783.764,133.804 783.773,133.807 783.782,133.81 783.792,133.813 783.801,133.816 783.81,133.819 783.819,133.822 783.828,133.825 783.838,133.828 783.847,133.831 783.856,133.834 783.865,133.837 783.874,133.841 783.883,133.844 783.893,133.847 783.902,133.85 783.911,133.853 783.92,133.856 783.929,133.859 783.939,133.862 783.948,133.865 783.957,133.868 783.966,133.871 783.975,133.874 783.985,133.877 783.994,133.88 784.003,133.883 784.012,133.886 784.021,133.889 784.03,133.892 784.04,133.896 784.049,133.899 784.058,133.902 784.067,133.905 784.076,133.908 784.086,133.911 784.095,133.914 784.104,133.917 784.113,133.92 784.122,133.923 784.132,133.926 784.141,133.929 784.15,133.932 784.159,133.935 784.168,133.938 784.178,133.941 784.187,133.944 784.196,133.947 784.205,133.951 784.214,133.954 784.223,133.957 784.233,133.96 784.242,133.963 784.251,133.966 784.26,133.969 784.269,133.972 784.279,133.975 784.288,133.978 784.297,133.981 784.306,133.984 784.315,133.987 784.325,133.99 784.334,133.993 784.343,133.996 784.352,133.999 784.361,134.002 784.37,134.006 784.38,134.009 784.389,134.012 784.398,134.015 784.407,134.018 784.416,134.021 784.426,134.024 784.435,134.027 784.444,134.03 784.453,134.033 784.462,134.036 784.472,134.039 784.481,134.042 784.49,134.045 784.499,134.048 784.508,134.051 784.518,134.054 784.527,134.057 784.536,134.061 784.545,134.064 784.554,134.067 784.563,134.07 784.573,134.073 784.582,134.076 784.591,134.079 784.6,134.082 784.609,134.085 784.619,134.088 784.628,134.091 784.637,134.094 784.646,134.097 784.655,134.1 784.665,134.103 784.674,134.106 784.683,134.109 784.692,134.112 784.701,134.116 784.71,134.119 784.72,134.122 784.729,134.125 784.738,134.128 784.747,134.131 784.756,134.134 784.766,134.137 784.775,134.14 784.784,134.143 784.793,134.146 784.802,134.149 784.812,134.152 784.821,134.155 784.83,134.158 784.839,134.161 784.848,134.164 784.858,134.167 784.867,134.17 784.876,134.174 784.885,134.177 784.894,134.18 784.903,134.183 784.913,134.186 784.922,134.189 784.931,134.192 784.94,134.195 784.949,134.198 784.959,134.201 784.968,134.204 784.977,134.207 784.986,134.21 784.995,134.213 785.005,134.216 785.014,134.219 785.023,134.222 785.032,134.225 785.041,134.229 785.051,134.232 785.06,134.235 785.069,134.238 785.078,134.241 785.087,134.244 785.096,134.247 785.106,134.25 785.115,134.253 785.124,134.256 785.133,134.259 785.142,134.262 785.152,134.265 785.161,134.268 785.17,134.271 785.179,134.274 785.188,134.277 785.198,134.28 785.207,134.283 785.216,134.287 785.225,134.29 785.234,134.293 785.243,134.296 785.253,134.299 785.262,134.302 785.271,134.305 785.28,134.308 785.289,134.311 785.299,134.314 785.308,134.317 785.317,134.32 785.326,134.323 785.335,134.326 785.345,134.329 785.354,134.332 785.363,134.335 785.372,134.338 785.381,134.342 785.391,134.345 785.4,134.348 785.409,134.351 785.418,134.354 785.427,134.357 785.436,134.36 785.446,134.363 785.455,134.366 785.464,134.369 785.473,134.372 785.482,134.375 785.492,134.378 785.501,134.381 785.51,134.384 785.519,134.387 785.528,134.39 785.538,134.393 785.547,134.396 785.556,134.4 785.565,134.403 785.574,134.406 785.583,134.409 785.593,134.412 785.602,134.415 785.611,134.418 785.62,134.421 785.629,134.424 785.639,134.427 785.648,134.43 785.657,134.433 785.666,134.436 785.675,134.439 785.685,134.442 785.694,134.445 785.703,134.448 785.712,134.451 785.721,134.454 785.731,134.458 785.74,134.461 785.749,134.464 785.758,134.467 785.767,134.47 785.776,134.473 785.786,134.476 785.795,134.479 785.804,134.482 785.813,134.485 785.822,134.488 785.832,134.491 785.841,134.494 785.85,134.497 785.859,134.5 785.868,134.503 785.878,134.506 785.887,134.509 785.896,134.512 785.905,134.516 785.914,134.519 785.923,134.522 785.933,134.525 785.942,134.528 785.951,134.531 785.96,134.534 785.969,134.537 785.979,134.54 785.988,134.543 785.997,134.546 786.006,134.549 786.015,134.552 786.025,134.555 786.034,134.558 786.043,134.561 786.052,134.564 786.061,134.567 786.071,134.57 786.08,134.574 786.089,134.577 786.098,134.58 786.107,134.583 786.116,134.586 786.126,134.589 786.135,134.592 786.144,134.595 786.153,134.598 786.162,134.601 786.172,134.604 786.181,134.607 786.19,134.61 786.199,134.613 786.208,134.616 786.218,134.619 786.227,134.622 786.236,134.625 786.245,134.628 786.254,134.632 786.263,134.635 786.273,134.638 786.282,134.641 786.291,134.644 786.3,134.647 786.309,134.65 786.319,134.653 786.328,134.656 786.337,134.659 786.346,134.662 786.355,134.665 786.365,134.668 786.374,134.671 786.383,134.674 786.392,134.677 786.401,134.68 786.411,134.683 786.42,134.686 786.429,134.69 786.438,134.693 786.447,134.696 786.456,134.699 786.466,134.702 786.475,134.705 786.484,134.708 786.493,134.711 786.502,134.714 786.512,134.717 786.521,134.72 786.53,134.723 786.539,134.726 786.548,134.729 786.558,134.732 786.567,134.735 786.576,134.738 786.585,134.741 786.594,134.744 786.603,134.748 786.613,134.751 786.622,134.754 786.631,134.757 786.64,134.76 786.649,134.763 786.659,134.766 786.668,134.769 786.677,134.772 786.686,134.775 786.695,134.778 786.705,134.781 786.714,134.784 786.723,134.787 786.732,134.79 786.741,134.793 786.751,134.796 786.76,134.799 786.769,134.802 786.778,134.806 786.787,134.809 786.796,134.812 786.806,134.815 786.815,134.818 786.824,134.821 786.833,134.824 786.842,134.827 786.852,134.83 786.861,134.833 786.87,134.836 786.879,134.839 786.888,134.842 786.898,134.845 786.907,134.848 786.916,134.851 786.925,134.854 786.934,134.857 786.943,134.86 786.953,134.863 786.962,134.867 786.971,134.87 786.98,134.873 786.989,134.876 786.999,134.879 787.008,134.882 787.017,134.885 787.026,134.888 787.035,134.891 787.045,134.894 787.054,134.897 787.063,134.9 787.072,134.903 787.081,134.906 787.091,134.909 787.1,134.912 787.109,134.915 787.118,134.918 787.127,134.921 787.136,134.925 787.146,134.928 787.155,134.931 787.164,134.934 787.173,134.937 787.182,134.94 787.192,134.943 787.201,134.946 787.21,134.949 787.219,134.952 787.228,134.955 787.238,134.958 787.247,134.961 787.256,134.964 787.265,134.967 787.274,134.97 787.283,134.973 787.293,134.976 787.302,134.979 787.311,134.982 787.32,134.986 787.329,134.989 787.339,134.992 787.348,134.995 787.357,134.998 787.366,135.001 787.375,135.004 787.385,135.007 787.394,135.01 787.403,135.013 787.412,135.016 787.421,135.019 787.431,135.022 787.44,135.025 787.449,135.028 787.458,135.031 787.467,135.034 787.476,135.037 787.486,135.04 787.495,135.043 787.504,135.047 787.513,135.05 787.522,135.053 787.532,135.056 787.541,135.059 787.55,135.062 787.559,135.065 787.568,135.068 787.578,135.071 787.587,135.074 787.596,135.077 787.605,135.08 787.614,135.083 787.624,135.086 787.633,135.089 787.642,135.092 787.651,135.095 787.66,135.098 787.669,135.101 787.679,135.104 787.688,135.108 787.697,135.111 787.706,135.114 787.715,135.117 787.725,135.12 787.734,135.123 787.743,135.126 787.752,135.129 787.761,135.132 787.771,135.135 787.78,135.138 787.789,135.141 787.798,135.144 787.807,135.147 787.816,135.15 787.826,135.153 787.835,135.156 787.844,135.159 787.853,135.162 787.862,135.165 787.872,135.169 787.881,135.172 787.89,135.175 787.899,135.178 787.908,135.181 787.918,135.184 787.927,135.187 787.936,135.19 787.945,135.193 787.954,135.196 787.964,135.199 787.973,135.202 787.982,135.205 787.991,135.208 788,135.211 788.009,135.214 788.019,135.217 788.028,135.22 788.037,135.223 788.046,135.226 788.055,135.23 788.065,135.233 788.074,135.236 788.083,135.239 788.092,135.242 788.101,135.245 788.111,135.248 788.12,135.251 788.129,135.254 788.138,135.257 788.147,135.26 788.156,135.263 788.166,135.266 788.175,135.269 788.184,135.272 788.193,135.275 788.202,135.278 788.212,135.281 788.221,135.284 788.23,135.287 788.239,135.291 788.248,135.294 788.258,135.297 788.267,135.3 788.276,135.303 788.285,135.306 788.294,135.309 788.304,135.312 788.313,135.315 788.322,135.318 788.331,135.321 788.34,135.324 788.349,135.327 788.359,135.33 788.368,135.333 788.377,135.336 788.386,135.339 788.395,135.342 788.405,135.345 788.414,135.348 788.423,135.352 788.432,135.355 788.441,135.358 788.451,135.361 788.46,135.364 788.469,135.367 788.478,135.37 788.487,135.373 788.496,135.376 788.506,135.379 788.515,135.382 788.524,135.385 788.533,135.388 788.542,135.391 788.552,135.394 788.561,135.397 788.57,135.4 788.579,135.403 788.588,135.406 788.598,135.409 788.607,135.413 788.616,135.416 788.625,135.419 788.634,135.422 788.644,135.425 788.653,135.428 788.662,135.431 788.671,135.434 788.68,135.437 788.689,135.44 788.699,135.443 788.708,135.446 788.717,135.449 788.726,135.452 788.735,135.455 788.745,135.458 788.754,135.461 788.763,135.464 788.772,135.467 788.781,135.47 788.791,135.473 788.8,135.477 788.809,135.48 788.818,135.483 788.827,135.486 788.836,135.489 788.846,135.492 788.855,135.495 788.864,135.498 788.873,135.501 788.882,135.504 788.892,135.507 788.901,135.51 788.91,135.513 788.919,135.516 788.928,135.519 788.938,135.522 788.947,135.525 788.956,135.528 788.965,135.531 788.974,135.534 788.984,135.538 788.993,135.541 789.002,135.544 789.011,135.547 789.02,135.55 789.029,135.553 789.039,135.556 789.048,135.559 789.057,135.562 789.066,135.565 789.075,135.568 789.085,135.571 789.094,135.574 789.103,135.577 789.112,135.58 789.121,135.583 789.131,135.586 789.14,135.589 789.149,135.592 789.158,135.595 789.167,135.598 789.176,135.602 789.186,135.605 789.195,135.608 789.204,135.611 789.213,135.614 789.222,135.617 789.232,135.62 789.241,135.623 789.25,135.626 789.259,135.629 789.268,135.632 789.278,135.635 789.287,135.638 789.296,135.641 789.305,135.644 789.314,135.647 789.324,135.65 789.333,135.653 789.342,135.656 789.351,135.659 789.36,135.662 789.369,135.666 789.379,135.669 789.388,135.672 789.397,135.675 789.406,135.678 789.415,135.681 789.425,135.684 789.434,135.687 789.443,135.69 789.452,135.693 789.461,135.696 789.471,135.699 789.48,135.702 789.489,135.705 789.498,135.708 789.507,135.711 789.516,135.714 789.526,135.717 789.535,135.72 789.544,135.723 789.553,135.726 789.562,135.73 789.572,135.733 789.581,135.736 789.59,135.739 789.599,135.742 789.608,135.745 789.618,135.748 789.627,135.751 789.636,135.754 789.645,135.757 789.654,135.76 789.664,135.763 789.673,135.766 789.682,135.769 789.691,135.772 789.7,135.775 789.709,135.778 789.719,135.781 789.728,135.784 789.737,135.787 789.746,135.79 789.755,135.794 789.765,135.797 789.774,135.8 789.783,135.803 789.792,135.806 789.801,135.809 789.811,135.812 789.82,135.815 789.829,135.818 789.838,135.821 789.847,135.824 789.856,135.827 789.866,135.83 789.875,135.833 789.884,135.836 789.893,135.839 789.902,135.842 789.912,135.845 789.921,135.848 789.93,135.851 789.939,135.854 789.948,135.858 789.958,135.861 789.967,135.864 789.976,135.867 789.985,135.87 789.994,135.873 790.004,135.876 790.013,135.879 790.022,135.882 790.031,135.885 790.04,135.888 790.049,135.891 790.059,135.894 790.068,135.897 790.077,135.9 790.086,135.903 790.095,135.906 790.105,135.909 790.114,135.912 790.123,135.915 790.132,135.918 790.141,135.922 790.151,135.925 790.16,135.928 790.169,135.931 790.178,135.934 790.187,135.937 790.197,135.94 790.206,135.943 790.215,135.946 790.224,135.949 790.233,135.952 790.242,135.955 790.252,135.958 790.261,135.961 790.27,135.964 790.279,135.967 790.288,135.97 790.298,135.973 790.307,135.976 790.316,135.979 790.325,135.982 790.334,135.985 790.344,135.989 790.353,135.992 790.362,135.995 790.371,135.998 790.38,136.001 790.389,136.004 790.399,136.007 790.408,136.01 790.417,136.013 790.426,136.016 790.435,136.019 790.445,136.022 790.454,136.025 790.463,136.028 790.472,136.031 790.481,136.034 790.491,136.037 790.5,136.04 790.509,136.043 790.518,136.046 790.527,136.049 790.537,136.053 790.546,136.056 790.555,136.059 790.564,136.062 790.573,136.065 790.582,136.068 790.592,136.071 790.601,136.074 790.61,136.077 790.619,136.08 790.628,136.083 790.638,136.086 790.647,136.089 790.656,136.092 790.665,136.095 790.674,136.098 790.684,136.101 790.693,136.104 790.702,136.107 790.711,136.11 790.72,136.113 790.729,136.116 790.739,136.12 790.748,136.123 790.757,136.126 790.766,136.129 790.775,136.132 790.785,136.135 790.794,136.138 790.803,136.141 790.812,136.144 790.821,136.147 790.831,136.15 790.84,136.153 790.849,136.156 790.858,136.159 790.867,136.162 790.877,136.165 790.886,136.168 790.895,136.171 790.904,136.174 790.913,136.177 790.922,136.18 790.932,136.184 790.941,136.187 790.95,136.19 790.959,136.193 790.968,136.196 790.978,136.199 790.987,136.202 790.996,136.205 791.005,136.208 791.014,136.211 791.024,136.214 791.033,136.217 791.042,136.22 791.051,136.223 791.06,136.226 791.069,136.229 791.079,136.232 791.088,136.235 791.097,136.238 791.106,136.241 791.115,136.244 791.125,136.247 791.134,136.251 791.143,136.254 791.152,136.257 791.161,136.26 791.171,136.263 791.18,136.266 791.189,136.269 791.198,136.272 791.207,136.275 791.217,136.278 791.226,136.281 791.235,136.284 791.244,136.287 791.253,136.29 791.262,136.293 791.272,136.296 791.281,136.299 791.29,136.302 791.299,136.305 791.308,136.308 791.318,136.311 791.327,136.314 791.336,136.318 791.345,136.321 791.354,136.324 791.364,136.327 791.373,136.33 791.382,136.333 791.391,136.336 791.4,136.339 791.409,136.342 791.419,136.345 791.428,136.348 791.437,136.351 791.446,136.354 791.455,136.357 791.465,136.36 791.474,136.363 791.483,136.366 791.492,136.369 791.501,136.372 791.511,136.375 791.52,136.378 791.529,136.381 791.538,136.385 791.547,136.388 791.557,136.391 791.566,136.394 791.575,136.397 791.584,136.4 791.593,136.403 791.602,136.406 791.612,136.409 791.621,136.412 791.63,136.415 791.639,136.418 791.648,136.421 791.658,136.424 791.667,136.427 791.676,136.43 791.685,136.433 791.694,136.436 791.704,136.439 791.713,136.442 791.722,136.445 791.731,136.448 791.74,136.452 791.749,136.455 791.759,136.458 791.768,136.461 791.777,136.464 791.786,136.467 791.795,136.47 791.805,136.473 791.814,136.476 791.823,136.479 791.832,136.482 791.841,136.485 791.851,136.488 791.86,136.491 791.869,136.494 791.878,136.497 791.887,136.5 791.897,136.503 791.906,136.506 791.915,136.509 791.924,136.512 791.933,136.515 791.942,136.518 791.952,136.522 791.961,136.525 791.97,136.528 791.979,136.531 791.988,136.534 791.998,136.537 792.007,136.54 792.016,136.543 792.025,136.546 792.034,136.549 792.044,136.552 792.053,136.555 792.062,136.558 792.071,136.561 792.08,136.564 792.089,136.567 792.099,136.57 792.108,136.573 792.117,136.576 792.126,136.579 792.135,136.582 792.145,136.585 792.154,136.589 792.163,136.592 792.172,136.595 792.181,136.598 792.191,136.601 792.2,136.604 792.209,136.607 792.218,136.61 792.227,136.613 792.237,136.616 792.246,136.619 792.255,136.622 792.264,136.625 792.273,136.628 792.282,136.631 792.292,136.634 792.301,136.637 792.31,136.64 792.319,136.643 792.328,136.646 792.338,136.649 792.347,136.652 792.356,136.655 792.365,136.659 792.374,136.662 792.384,136.665 792.393,136.668 792.402,136.671 792.411,136.674 792.42,136.677 792.43,136.68 792.439,136.683 792.448,136.686 792.457,136.689 792.466,136.692 792.475,136.695 792.485,136.698 792.494,136.701 792.503,136.704 792.512,136.707 792.521,136.71 792.531,136.713 792.54,136.716 792.549,136.719 792.558,136.722 792.567,136.725 792.577,136.729 792.586,136.732 792.595,136.735 792.604,136.738 792.613,136.741 792.622,136.744 792.632,136.747 792.641,136.75 792.65,136.753 792.659,136.756 792.668,136.759 792.678,136.762 792.687,136.765 792.696,136.768 792.705,136.771 792.714,136.774 792.724,136.777 792.733,136.78 792.742,136.783 792.751,136.786 792.76,136.789 792.77,136.792 792.779,136.795 792.788,136.799 792.797,136.802 792.806,136.805 792.815,136.808 792.825,136.811 792.834,136.814 792.843,136.817 792.852,136.82 792.861,136.823 792.871,136.826 792.88,136.829 792.889,136.832 792.898,136.835 792.907,136.838 792.917,136.841 792.926,136.844 792.935,136.847 792.944,136.85 792.953,136.853 792.962,136.856 792.972,136.859 792.981,136.862 792.99,136.865 792.999,136.869 793.008,136.872 793.018,136.875 793.027,136.878 793.036,136.881 793.045,136.884 793.054,136.887 793.064,136.89 793.073,136.893 793.082,136.896 793.091,136.899 793.1,136.902 793.11,136.905 793.119,136.908 793.128,136.911 793.137,136.914 793.146,136.917 793.155,136.92 793.165,136.923 793.174,136.926 793.183,136.929 793.192,136.932 793.201,136.935 793.211,136.939 793.22,136.942 793.229,136.945 793.238,136.948 793.247,136.951 793.257,136.954 793.266,136.957 793.275,136.96 793.284,136.963 793.293,136.966 793.302,136.969 793.312,136.972 793.321,136.975 793.33,136.978 793.339,136.981 793.348,136.984 793.358,136.987 793.367,136.99 793.376,136.993 793.385,136.996 793.394,136.999 793.404,137.002 793.413,137.005 793.422,137.009 793.431,137.012 793.44,137.015 793.45,137.018 793.459,137.021 793.468,137.024 793.477,137.027 793.486,137.03 793.495,137.033 793.505,137.036 793.514,137.039 793.523,137.042 793.532,137.045 793.541,137.048 793.551,137.051 793.56,137.054 793.569,137.057 793.578,137.06 793.587,137.063 793.597,137.066 793.606,137.069 793.615,137.072 793.624,137.075 793.633,137.078 793.642,137.082 793.652,137.085 793.661,137.088 793.67,137.091 793.679,137.094 793.688,137.097 793.698,137.1 793.707,137.103 793.716,137.106 793.725,137.109 793.734,137.112 793.744,137.115 793.753,137.118 793.762,137.121 793.771,137.124 793.78,137.127 793.79,137.13 793.799,137.133 793.808,137.136 793.817,137.139 793.826,137.142 793.835,137.145 793.845,137.148 793.854,137.152 793.863,137.155 793.872,137.158 793.881,137.161 793.891,137.164 793.9,137.167 793.909,137.17 793.918,137.173 793.927,137.176 793.937,137.179 793.946,137.182 793.955,137.185 793.964,137.188 793.973,137.191 793.982,137.194 793.992,137.197 794.001,137.2 794.01,137.203 794.019,137.206 794.028,137.209 794.038,137.212 794.047,137.215 794.056,137.218 794.065,137.221 794.074,137.225 794.084,137.228 794.093,137.231 794.102,137.234 794.111,137.237 794.12,137.24 794.13,137.243 794.139,137.246 794.148,137.249 794.157,137.252 794.166,137.255 794.175,137.258 794.185,137.261 794.194,137.264 794.203,137.267 794.212,137.27 794.221,137.273 794.231,137.276 794.24,137.279 794.249,137.282 794.258,137.285 794.267,137.288 794.277,137.291 794.286,137.294 794.295,137.298 794.304,137.301 794.313,137.304 794.322,137.307 794.332,137.31 794.341,137.313 794.35,137.316 794.359,137.319 794.368,137.322 794.378,137.325 794.387,137.328 794.396,137.331 794.405,137.334 794.414,137.337 794.424,137.34 794.433,137.343 794.442,137.346 794.451,137.349 794.46,137.352 794.47,137.355 794.479,137.358 794.488,137.361 794.497,137.364 794.506,137.367 794.515,137.371 794.525,137.374 794.534,137.377 794.543,137.38 794.552,137.383 794.561,137.386 794.571,137.389 794.58,137.392 794.589,137.395 794.598,137.398 794.607,137.401 794.617,137.404 794.626,137.407 794.635,137.41 794.644,137.413 794.653,137.416 794.662,137.419 794.672,137.422 794.681,137.425 794.69,137.428 794.699,137.431 794.708,137.434 794.718,137.437 794.727,137.44 794.736,137.444 794.745,137.447 794.754,137.45 794.764,137.453 794.773,137.456 794.782,137.459 794.791,137.462 794.8,137.465 794.81,137.468 794.819,137.471 794.828,137.474 794.837,137.477 794.846,137.48 794.855,137.483 794.865,137.486 794.874,137.489 794.883,137.492 794.892,137.495 794.901,137.498 794.911,137.501 794.92,137.504 794.929,137.507 794.938,137.51 794.947,137.513 794.957,137.517 794.966,137.52 794.975,137.523 794.984,137.526 794.993,137.529 795.003,137.532 795.012,137.535 795.021,137.538 795.03,137.541 795.039,137.544 795.048,137.547 795.058,137.55 795.067,137.553 795.076,137.556 795.085,137.559 795.094,137.562 795.104,137.565 795.113,137.568 795.122,137.571 795.131,137.574 795.14,137.577 795.15,137.58 795.159,137.583 795.168,137.586 795.177,137.589 795.186,137.593 795.195,137.596 795.205,137.599 795.214,137.602 795.223,137.605 795.232,137.608 795.241,137.611 795.251,137.614 795.26,137.617 795.269,137.62 795.278,137.623 795.287,137.626 795.297,137.629 795.306,137.632 795.315,137.635 795.324,137.638 795.333,137.641 795.343,137.644 795.352,137.647 795.361,137.65 795.37,137.653 795.379,137.656 795.388,137.659 795.398,137.662 795.407,137.665 795.416,137.669 795.425,137.672 795.434,137.675 795.444,137.678 795.453,137.681 795.462,137.684 795.471,137.687 795.48,137.69 795.49,137.693 795.499,137.696 795.508,137.699 795.517,137.702 795.526,137.705 795.535,137.708 795.545,137.711 795.554,137.714 795.563,137.717 795.572,137.72 795.581,137.723 795.591,137.726 795.6,137.729 795.609,137.732 795.618,137.735 795.627,137.738 795.637,137.741 795.646,137.745 795.655,137.748 795.664,137.751 795.673,137.754 795.683,137.757 795.692,137.76 795.701,137.763 795.71,137.766 795.719,137.769 795.728,137.772 795.738,137.775 795.747,137.778 795.756,137.781 795.765,137.784 795.774,137.787 795.784,137.79 795.793,137.793 795.802,137.796 795.811,137.799 795.82,137.802 795.83,137.805 795.839,137.808 795.848,137.811 795.857,137.814 795.866,137.817 795.875,137.821 795.885,137.824 795.894,137.827 795.903,137.83 795.912,137.833 795.921,137.836 795.931,137.839 795.94,137.842 795.949,137.845 795.958,137.848 795.967,137.851 795.977,137.854 795.986,137.857 795.995,137.86 796.004,137.863 796.013,137.866 796.023,137.869 796.032,137.872 796.041,137.875 796.05,137.878 796.059,137.881 796.068,137.884 796.078,137.887 796.087,137.89 796.096,137.893 796.105,137.897 796.114,137.9 796.124,137.903 796.133,137.906 796.142,137.909 796.151,137.912 796.16,137.915 796.17,137.918 796.179,137.921 796.188,137.924 796.197,137.927 796.206,137.93 796.215,137.933 796.225,137.936 796.234,137.939 796.243,137.942 796.252,137.945 796.261,137.948 796.271,137.951 796.28,137.954 796.289,137.957 796.298,137.96 796.307,137.963 796.317,137.966 796.326,137.969 796.335,137.973 796.344,137.976 796.353,137.979 796.363,137.982 796.372,137.985 796.381,137.988 796.39,137.991 796.399,137.994 796.408,137.997 796.418,138 796.427,138.003 796.436,138.006 796.445,138.009 796.454,138.012 796.464,138.015 796.473,138.018 796.482,138.021 796.491,138.024 796.5,138.027 796.51,138.03 796.519,138.033 796.528,138.036 796.537,138.039 796.546,138.042 796.555,138.045 796.565,138.048 796.574,138.052 796.583,138.055 796.592,138.058 796.601,138.061 796.611,138.064 796.62,138.067 796.629,138.07 796.638,138.073 796.647,138.076 796.657,138.079 796.666,138.082 796.675,138.085 796.684,138.088 796.693,138.091 796.703,138.094 796.712,138.097 796.721,138.1 796.73,138.103 796.739,138.106 796.748,138.109 796.758,138.112 796.767,138.115 796.776,138.118 796.785,138.121 796.794,138.124 796.804,138.128 796.813,138.131 796.822,138.134 796.831,138.137 796.84,138.14 796.85,138.143 796.859,138.146 796.868,138.149 796.877,138.152 796.886,138.155 796.895,138.158 796.905,138.161 796.914,138.164 796.923,138.167 796.932,138.17 796.941,138.173 796.951,138.176 796.96,138.179 796.969,138.182 796.978,138.185 796.987,138.188 796.997,138.191 797.006,138.194 797.015,138.197 797.024,138.2 797.033,138.203 797.043,138.207 797.052,138.21 797.061,138.213 797.07,138.216 797.079,138.219 797.088,138.222 797.098,138.225 797.107,138.228 797.116,138.231 797.125,138.234 797.134,138.237 797.144,138.24 797.153,138.243 797.162,138.246 797.171,138.249 797.18,138.252 797.19,138.255 797.199,138.258 797.208,138.261 797.217,138.264 797.226,138.267 797.235,138.27 797.245,138.273 797.254,138.276 797.263,138.279 797.272,138.282 797.281,138.286 797.291,138.289 797.3,138.292 797.309,138.295 797.318,138.298 797.327,138.301 797.337,138.304 797.346,138.307 797.355,138.31 797.364,138.313 797.373,138.316 797.383,138.319 797.392,138.322 797.401,138.325 797.41,138.328 797.419,138.331 797.428,138.334 797.438,138.337 797.447,138.34 797.456,138.343 797.465,138.346 797.474,138.349 797.484,138.352 797.493,138.355 797.502,138.358 797.511,138.361 797.52,138.364 797.53,138.368 797.539,138.371 797.548,138.374 797.557,138.377 797.566,138.38 797.576,138.383 797.585,138.386 797.594,138.389 797.603,138.392 797.612,138.395 797.621,138.398 797.631,138.401 797.64,138.404 797.649,138.407 797.658,138.41 797.667,138.413 797.677,138.416 797.686,138.419 797.695,138.422 797.704,138.425 797.713,138.428 797.723,138.431 797.732,138.434 797.741,138.437 797.75,138.44 797.759,138.443 797.768,138.447 797.778,138.45 797.787,138.453 797.796,138.456 797.805,138.459 797.814,138.462 797.824,138.465 797.833,138.468 797.842,138.471 797.851,138.474 797.86,138.477 797.87,138.48 797.879,138.483 797.888,138.486 797.897,138.489 797.906,138.492 797.916,138.495 797.925,138.498 797.934,138.501 797.943,138.504 797.952,138.507 797.961,138.51 797.971,138.513 797.98,138.516 797.989,138.519 797.998,138.522 798.007,138.525 798.017,138.529 798.026,138.532 798.035,138.535 798.044,138.538 798.053,138.541 798.063,138.544 798.072,138.547 798.081,138.55 798.09,138.553 798.099,138.556 798.108,138.559 798.118,138.562 798.127,138.565 798.136,138.568 798.145,138.571 798.154,138.574 798.164,138.577 798.173,138.58 798.182,138.583 798.191,138.586 798.2,138.589 798.21,138.592 798.219,138.595 798.228,138.598 798.237,138.601 798.246,138.604 798.256,138.607 798.265,138.611 798.274,138.614 798.283,138.617 798.292,138.62 798.301,138.623 798.311,138.626 798.32,138.629 798.329,138.632 798.338,138.635 798.347,138.638 798.357,138.641 798.366,138.644 798.375,138.647 798.384,138.65 798.393,138.653 798.403,138.656 798.412,138.659 798.421,138.662 798.43,138.665 798.439,138.668 798.448,138.671 798.458,138.674 798.467,138.677 798.476,138.68 798.485,138.683 798.494,138.686 798.504,138.689 798.513,138.693 798.522,138.696 798.531,138.699 798.54,138.702 798.55,138.705 798.559,138.708 798.568,138.711 798.577,138.714 798.586,138.717 798.596,138.72 798.605,138.723 798.614,138.726 798.623,138.729 798.632,138.732 798.641,138.735 798.651,138.738 798.66,138.741 798.669,138.744 798.678,138.747 798.687,138.75 798.697,138.753 798.706,138.756 798.715,138.759 798.724,138.762 798.733,138.765 798.743,138.768 798.752,138.771 798.761,138.775 798.77,138.778 798.779,138.781 798.788,138.784 798.798,138.787 798.807,138.79 798.816,138.793 798.825,138.796 798.834,138.799 798.844,138.802 798.853,138.805 798.862,138.808 798.871,138.811 798.88,138.814 798.89,138.817 798.899,138.82 798.908,138.823 798.917,138.826 798.926,138.829 798.936,138.832 798.945,138.835 798.954,138.838 798.963,138.841 798.972,138.844 798.981,138.847 798.991,138.85 799,138.853 799.009,138.856 799.018,138.86 799.027,138.863 799.037,138.866 799.046,138.869 799.055,138.872 799.064,138.875 799.073,138.878 799.083,138.881 799.092,138.884 799.101,138.887 799.11,138.89 799.119,138.893 799.128,138.896 799.138,138.899 799.147,138.902 799.156,138.905 799.165,138.908 799.174,138.911 799.184,138.914 799.193,138.917 799.202,138.92 799.211,138.923 799.22,138.926 799.23,138.929 799.239,138.932 799.248,138.935 799.257,138.938 799.266,138.942 799.276,138.945 799.285,138.948 799.294,138.951 799.303,138.954 799.312,138.957 799.321,138.96 799.331,138.963 799.34,138.966 799.349,138.969 799.358,138.972 799.367,138.975 799.377,138.978 799.386,138.981 799.395,138.984 799.404,138.987 799.413,138.99 799.423,138.993 799.432,138.996 799.441,138.999 799.45,139.002 799.459,139.005 799.468,139.008 799.478,139.011 799.487,139.014 799.496,139.017 799.505,139.02 799.514,139.023 799.524,139.027 799.533,139.03 799.542,139.033 799.551,139.036 799.56,139.039 799.57,139.042 799.579,139.045 799.588,139.048 799.597,139.051 799.606,139.054 799.616,139.057 799.625,139.06 799.634,139.063 799.643,139.066 799.652,139.069 799.661,139.072 799.671,139.075 799.68,139.078 799.689,139.081 799.698,139.084 799.707,139.087 799.717,139.09 799.726,139.093 799.735,139.096 799.744,139.099 799.753,139.102 799.763,139.105 799.772,139.108 799.781,139.111 799.79,139.115 799.799,139.118 799.809,139.121 799.818,139.124 799.827,139.127 799.836,139.13 799.845,139.133 799.854,139.136 799.864,139.139 799.873,139.142 799.882,139.145 799.891,139.148 799.9,139.151 799.91,139.154 799.919,139.157 799.928,139.16 799.937,139.163 799.946,139.166 799.956,139.169 799.965,139.172 799.974,139.175 799.983,139.178 799.992,139.181 800.001,139.184 800.011,139.187 800.02,139.19 800.029,139.193 800.038,139.196 800.047,139.2 800.057,139.203 800.066,139.206 800.075,139.209 800.084,139.212 800.093,139.215 800.103,139.218 800.112,139.221 800.121,139.224 800.13,139.227 800.139,139.23 800.149,139.233 800.158,139.236 800.167,139.239 800.176,139.242 800.185,139.245 800.194,139.248 800.204,139.251 800.213,139.254 800.222,139.257 800.231,139.26 800.24,139.263 800.25,139.266 800.259,139.269 800.268,139.272 800.277,139.275 800.286,139.278 800.296,139.281 800.305,139.284 800.314,139.288 800.323,139.291 800.332,139.294 800.341,139.297 800.351,139.3 800.36,139.303 800.369,139.306 800.378,139.309 800.387,139.312 800.397,139.315 800.406,139.318 800.415,139.321 800.424,139.324 800.433,139.327 800.443,139.33 800.452,139.333 800.461,139.336 800.47,139.339 800.479,139.342 800.489,139.345 800.498,139.348 800.507,139.351 800.516,139.354 800.525,139.357 800.534,139.36 800.544,139.363 800.553,139.366 800.562,139.369 800.571,139.372 800.58,139.376 800.59,139.379 800.599,139.382 800.608,139.385 800.617,139.388 800.626,139.391 800.636,139.394 800.645,139.397 800.654,139.4 800.663,139.403 800.672,139.406 800.681,139.409 800.691,139.412 800.7,139.415 800.709,139.418 800.718,139.421 800.727,139.424 800.737,139.427 800.746,139.43 800.755,139.433 800.764,139.436 800.773,139.439 800.783,139.442 800.792,139.445 800.801,139.448 800.81,139.451 800.819,139.454 800.829,139.457 800.838,139.46 800.847,139.464 800.856,139.467 800.865,139.47 800.874,139.473 800.884,139.476 800.893,139.479 800.902,139.482 800.911,139.485 800.92,139.488 800.93,139.491 800.939,139.494 800.948,139.497 800.957,139.5 800.966,139.503 800.976,139.506 800.985,139.509 800.994,139.512 801.003,139.515 801.012,139.518 801.021,139.521 801.031,139.524 801.04,139.527 801.049,139.53 801.058,139.533 801.067,139.536 801.077,139.539 801.086,139.542 801.095,139.545 801.104,139.548 801.113,139.552 801.123,139.555 801.132,139.558 801.141,139.561 801.15,139.564 801.159,139.567 801.169,139.57 801.178,139.573 801.187,139.576 801.196,139.579 801.205,139.582 801.214,139.585 801.224,139.588 801.233,139.591 801.242,139.594 801.251,139.597 801.26,139.6 801.27,139.603 801.279,139.606 801.288,139.609 801.297,139.612 801.306,139.615 801.316,139.618 801.325,139.621 801.334,139.624 801.343,139.627 801.352,139.63 801.361,139.633 801.371,139.636 801.38,139.639 801.389,139.643 801.398,139.646 801.407,139.649 801.417,139.652 801.426,139.655 801.435,139.658 801.444,139.661 801.453,139.664 801.463,139.667 801.472,139.67 801.481,139.673 801.49,139.676 801.499,139.679 801.509,139.682 801.518,139.685 801.527,139.688 801.536,139.691 801.545,139.694 801.554,139.697 801.564,139.7 801.573,139.703 801.582,139.706 801.591,139.709 801.6,139.712 801.61,139.715 801.619,139.718 801.628,139.721 801.637,139.724 801.646,139.727 801.656,139.73 801.665,139.734 801.674,139.737 801.683,139.74 801.692,139.743 801.701,139.746 801.711,139.749 801.72,139.752 801.729,139.755 801.738,139.758 801.747,139.761 801.757,139.764 801.766,139.767 801.775,139.77 801.784,139.773 801.793,139.776 801.803,139.779 801.812,139.782 801.821,139.785 801.83,139.788 801.839,139.791 801.849,139.794 801.858,139.797 801.867,139.8 801.876,139.803 801.885,139.806 801.894,139.809 801.904,139.812 801.913,139.815 801.922,139.818 801.931,139.821 801.94,139.825 801.95,139.828 801.959,139.831 801.968,139.834 801.977,139.837 801.986,139.84 801.996,139.843 802.005,139.846 802.014,139.849 802.023,139.852 802.032,139.855 802.041,139.858 802.051,139.861 802.06,139.864 802.069,139.867 802.078,139.87 802.087,139.873 802.097,139.876 802.106,139.879 802.115,139.882 802.124,139.885 802.133,139.888 802.143,139.891 802.152,139.894 802.161,139.897 802.17,139.9 802.179,139.903 802.189,139.906 802.198,139.909 802.207,139.912 802.216,139.916 802.225,139.919 802.234,139.922 802.244,139.925 802.253,139.928 802.262,139.931 802.271,139.934 802.28,139.937 802.29,139.94 802.299,139.943 802.308,139.946 802.317,139.949 802.326,139.952 802.336,139.955 802.345,139.958 802.354,139.961 802.363,139.964 802.372,139.967 802.382,139.97 802.391,139.973 802.4,139.976 802.409,139.979 802.418,139.982 802.427,139.985 802.437,139.988 802.446,139.991 802.455,139.994 802.464,139.997 802.473,140 802.483,140.003 802.492,140.006 802.501,140.01 802.51,140.013 802.519,140.016 802.529,140.019 802.538,140.022 802.547,140.025 802.556,140.028 802.565,140.031 802.574,140.034 802.584,140.037 802.593,140.04 802.602,140.043 802.611,140.046 802.62,140.049 802.63,140.052 802.639,140.055 802.648,140.058 802.657,140.061 802.666,140.064 802.676,140.067 802.685,140.07 802.694,140.073 802.703,140.076 802.712,140.079 802.722,140.082 802.731,140.085 802.74,140.088 802.749,140.091 802.758,140.094 802.767,140.097 802.777,140.1 802.786,140.104 802.795,140.107 802.804,140.11 802.813,140.113 802.823,140.116 802.832,140.119 802.841,140.122 802.85,140.125 802.859,140.128 802.869,140.131 802.878,140.134 802.887,140.137 802.896,140.14 802.905,140.143 802.914,140.146 802.924,140.149 802.933,140.152 802.942,140.155 802.951,140.158 802.96,140.161 802.97,140.164 802.979,140.167 802.988,140.17 802.997,140.173 803.006,140.176 803.016,140.179 803.025,140.182 803.034,140.185 803.043,140.188 803.052,140.191 803.062,140.194 803.071,140.197 803.08,140.201 803.089,140.204 803.098,140.207 803.107,140.21 803.117,140.213 803.126,140.216 803.135,140.219 803.144,140.222 803.153,140.225 803.163,140.228 803.172,140.231 803.181,140.234 803.19,140.237 803.199,140.24 803.209,140.243 803.218,140.246 803.227,140.249 803.236,140.252 803.245,140.255 803.254,140.258 803.264,140.261 803.273,140.264 803.282,140.267 803.291,140.27 803.3,140.273 803.31,140.276 803.319,140.279 803.328,140.282 803.337,140.285 803.346,140.288 803.356,140.291 803.365,140.295 803.374,140.298 803.383,140.301 803.392,140.304 803.402,140.307 803.411,140.31 803.42,140.313 803.429,140.316 803.438,140.319 803.447,140.322 803.457,140.325 803.466,140.328 803.475,140.331 803.484,140.334 803.493,140.337 803.503,140.34 803.512,140.343 803.521,140.346 803.53,140.349 803.539,140.352 803.549,140.355 803.558,140.358 803.567,140.361 803.576,140.364 803.585,140.367 803.594,140.37 803.604,140.373 803.613,140.376 803.622,140.379 803.631,140.382 803.64,140.385 803.65,140.388 803.659,140.392 803.668,140.395 803.677,140.398 803.686,140.401 803.696,140.404 803.705,140.407 803.714,140.41 803.723,140.413 803.732,140.416 803.742,140.419 803.751,140.422 803.76,140.425 803.769,140.428 803.778,140.431 803.787,140.434 803.797,140.437 803.806,140.44 803.815,140.443 803.824,140.446 803.833,140.449 803.843,140.452 803.852,140.455 803.861,140.458 803.87,140.461 803.879,140.464 803.889,140.467 803.898,140.47 803.907,140.473 803.916,140.476 803.925,140.479 803.934,140.482 803.944,140.485 803.953,140.488 803.962,140.492 803.971,140.495 803.98,140.498 803.99,140.501 803.999,140.504 804.008,140.507 804.017,140.51 804.026,140.513 804.036,140.516 804.045,140.519 804.054,140.522 804.063,140.525 804.072,140.528 804.082,140.531 804.091,140.534 804.1,140.537 804.109,140.54 804.118,140.543 804.127,140.546 804.137,140.549 804.146,140.552 804.155,140.555 804.164,140.558 804.173,140.561 804.183,140.564 804.192,140.567 804.201,140.57 804.21,140.573 804.219,140.576 804.229,140.579 804.238,140.582 804.247,140.585 804.256,140.589 804.265,140.592 804.274,140.595 804.284,140.598 804.293,140.601 804.302,140.604 804.311,140.607 804.32,140.61 804.33,140.613 804.339,140.616 804.348,140.619 804.357,140.622 804.366,140.625 804.376,140.628 804.385,140.631 804.394,140.634 804.403,140.637 804.412,140.64 804.422,140.643 804.431,140.646 804.44,140.649 804.449,140.652 804.458,140.655 804.467,140.658 804.477,140.661 804.486,140.664 804.495,140.667 804.504,140.67 804.513,140.673 804.523,140.676 804.532,140.679 804.541,140.682 804.55,140.685 804.559,140.689 804.569,140.692 804.578,140.695 804.587,140.698 804.596,140.701 804.605,140.704 804.614,140.707 804.624,140.71 804.633,140.713 804.642,140.716 804.651,140.719 804.66,140.722 804.67,140.725 804.679,140.728 804.688,140.731 804.697,140.734 804.706,140.737 804.716,140.74 804.725,140.743 804.734,140.746 804.743,140.749 804.752,140.752 804.762,140.755 804.771,140.758 804.78,140.761 804.789,140.764 804.798,140.767 804.807,140.77 804.817,140.773 804.826,140.776 804.835,140.779 804.844,140.782 804.853,140.785 804.863,140.788 804.872,140.792 804.881,140.795 804.89,140.798 804.899,140.801 804.909,140.804 804.918,140.807 804.927,140.81 804.936,140.813 804.945,140.816 804.955,140.819 804.964,140.822 804.973,140.825 804.982,140.828 804.991,140.831 805,140.834 805.01,140.837 805.019,140.84 805.028,140.843 805.037,140.846 805.046,140.849 805.056,140.852 805.065,140.855 805.074,140.858 805.083,140.861 805.092,140.864 805.102,140.867 805.111,140.87 805.12,140.873 805.129,140.876 805.138,140.879 805.147,140.882 805.157,140.885 805.166,140.888 805.175,140.891 805.184,140.895 805.193,140.898 805.203,140.901 805.212,140.904 805.221,140.907 805.23,140.91 805.239,140.913 805.249,140.916 805.258,140.919 805.267,140.922 805.276,140.925 805.285,140.928 805.295,140.931 805.304,140.934 805.313,140.937 805.322,140.94 805.331,140.943 805.34,140.946 805.35,140.949 805.359,140.952 805.368,140.955 805.377,140.958 805.386,140.961 805.396,140.964 805.405,140.967 805.414,140.97 805.423,140.973 805.432,140.976 805.442,140.979 805.451,140.982 805.46,140.985 805.469,140.988 805.478,140.991 805.487,140.994 805.497,140.998 805.506,141.001 805.515,141.004 805.524,141.007 805.533,141.01 805.543,141.013 805.552,141.016 805.561,141.019 805.57,141.022 805.579,141.025 805.589,141.028 805.598,141.031 805.607,141.034 805.616,141.037 805.625,141.04 805.635,141.043 805.644,141.046 805.653,141.049 805.662,141.052 805.671,141.055 805.68,141.058 805.69,141.061 805.699,141.064 805.708,141.067 805.717,141.07 805.726,141.073 805.736,141.076 805.745,141.079 805.754,141.082 805.763,141.085 805.772,141.088 805.782,141.091 805.791,141.094 805.8,141.097 805.809,141.101 805.818,141.104 805.827,141.107 805.837,141.11 805.846,141.113 805.855,141.116 805.864,141.119 805.873,141.122 805.883,141.125 805.892,141.128 805.901,141.131 805.91,141.134 805.919,141.137 805.929,141.14 805.938,141.143 805.947,141.146 805.956,141.149 805.965,141.152 805.975,141.155 805.984,141.158 805.993,141.161 806.002,141.164 806.011,141.167 806.02,141.17 806.03,141.173 806.039,141.176 806.048,141.179 806.057,141.182 806.066,141.185 806.076,141.188 806.085,141.191 806.094,141.194 806.103,141.197 806.112,141.2 806.122,141.203 806.131,141.207 806.14,141.21 806.149,141.213 806.158,141.216 806.167,141.219 806.177,141.222 806.186,141.225 806.195,141.228 806.204,141.231 806.213,141.234 806.223,141.237 806.232,141.24 806.241,141.243 806.25,141.246 806.259,141.249 806.269,141.252 806.278,141.255 806.287,141.258 806.296,141.261 806.305,141.264 806.315,141.267 806.324,141.27 806.333,141.273 806.342,141.276 806.351,141.279 806.36,141.282 806.37,141.285 806.379,141.288 806.388,141.291 806.397,141.294 806.406,141.297 806.416,141.3 806.425,141.303 806.434,141.306 806.443,141.309 806.452,141.312 806.462,141.316 806.471,141.319 806.48,141.322 806.489,141.325 806.498,141.328 806.507,141.331 806.517,141.334 806.526,141.337 806.535,141.34 806.544,141.343 806.553,141.346 806.563,141.349 806.572,141.352 806.581,141.355 806.59,141.358 806.599,141.361 806.609,141.364 806.618,141.367 806.627,141.37 806.636,141.373 806.645,141.376 806.655,141.379 806.664,141.382 806.673,141.385 806.682,141.388 806.691,141.391 806.7,141.394 806.71,141.397 806.719,141.4 806.728,141.403 806.737,141.406 806.746,141.409 806.756,141.412 806.765,141.415 806.774,141.418 806.783,141.422 806.792,141.425 806.802,141.428 806.811,141.431 806.82,141.434 806.829,141.437 806.838,141.44 806.847,141.443 806.857,141.446 806.866,141.449 806.875,141.452 806.884,141.455 806.893,141.458 806.903,141.461 806.912,141.464 806.921,141.467 806.93,141.47 806.939,141.473 806.949,141.476 806.958,141.479 806.967,141.482 806.976,141.485 806.985,141.488 806.995,141.491 807.004,141.494 807.013,141.497 807.022,141.5 807.031,141.503 807.04,141.506 807.05,141.509 807.059,141.512 807.068,141.515 807.077,141.518 807.086,141.521 807.096,141.524 807.105,141.527 807.114,141.53 807.123,141.534 807.132,141.537 807.142,141.54 807.151,141.543 807.16,141.546 807.169,141.549 807.178,141.552 807.188,141.555 807.197,141.558 807.206,141.561 807.215,141.564 807.224,141.567 807.233,141.57 807.243,141.573 807.252,141.576 807.261,141.579 807.27,141.582 807.279,141.585 807.289,141.588 807.298,141.591 807.307,141.594 807.316,141.597 807.325,141.6 807.335,141.603 807.344,141.606 807.353,141.609 807.362,141.612 807.371,141.615 807.38,141.618 807.39,141.621 807.399,141.624 807.408,141.627 807.417,141.63 807.426,141.633 807.436,141.636 807.445,141.639 807.454,141.643 807.463,141.646 807.472,141.649 807.482,141.652 807.491,141.655 807.5,141.658 807.509,141.661 807.518,141.664 807.528,141.667 807.537,141.67 807.546,141.673 807.555,141.676 807.564,141.679 807.573,141.682 807.583,141.685 807.592,141.688 807.601,141.691 807.61,141.694 807.619,141.697 807.629,141.7 807.638,141.703 807.647,141.706 807.656,141.709 807.665,141.712 807.675,141.715 807.684,141.718 807.693,141.721 807.702,141.724 807.711,141.727 807.72,141.73 807.73,141.733 807.739,141.736 807.748,141.739 807.757,141.742 807.766,141.745 807.776,141.748 807.785,141.751 807.794,141.754 807.803,141.758 807.812,141.761 807.822,141.764 807.831,141.767 807.84,141.77 807.849,141.773 807.858,141.776 807.868,141.779 807.877,141.782 807.886,141.785 807.895,141.788 807.904,141.791 807.913,141.794 807.923,141.797 807.932,141.8 807.941,141.803 807.95,141.806 807.959,141.809 807.969,141.812 807.978,141.815 807.987,141.818 807.996,141.821 808.005,141.824 808.015,141.827 808.024,141.83 808.033,141.833 808.042,141.836 808.051,141.839 808.06,141.842 808.07,141.845 808.079,141.848 808.088,141.851 808.097,141.854 808.106,141.857 808.116,141.86 808.125,141.863 808.134,141.866 808.143,141.87 808.152,141.873 808.162,141.876 808.171,141.879 808.18,141.882 808.189,141.885 808.198,141.888 808.208,141.891 808.217,141.894 808.226,141.897 808.235,141.9 808.244,141.903 808.253,141.906 808.263,141.909 808.272,141.912 808.281,141.915 808.29,141.918 808.299,141.921 808.309,141.924 808.318,141.927 808.327,141.93 808.336,141.933 808.345,141.936 808.355,141.939 808.364,141.942 808.373,141.945 808.382,141.948 808.391,141.951 808.4,141.954 808.41,141.957 808.419,141.96 808.428,141.963 808.437,141.966 808.446,141.969 808.456,141.972 808.465,141.975 808.474,141.978 808.483,141.981 808.492,141.984 808.502,141.988 808.511,141.991 808.52,141.994 808.529,141.997 808.538,142 808.548,142.003 808.557,142.006 808.566,142.009 808.575,142.012 808.584,142.015 808.593,142.018 808.603,142.021 808.612,142.024 808.621,142.027 808.63,142.03 808.639,142.033 808.649,142.036 808.658,142.039 808.667,142.042 808.676,142.045 808.685,142.048 808.695,142.051 808.704,142.054 808.713,142.057 808.722,142.06 808.731,142.063 808.74,142.066 808.75,142.069 808.759,142.072 808.768,142.075 808.777,142.078 808.786,142.081 808.796,142.084 808.805,142.087 808.814,142.09 808.823,142.093 808.832,142.096 808.842,142.099 808.851,142.102 808.86,142.106 808.869,142.109 808.878,142.112 808.888,142.115 808.897,142.118 808.906,142.121 808.915,142.124 808.924,142.127 808.933,142.13 808.943,142.133 808.952,142.136 808.961,142.139 808.97,142.142 808.979,142.145 808.989,142.148 808.998,142.151 809.007,142.154 809.016,142.157 809.025,142.16 809.035,142.163 809.044,142.166 809.053,142.169 809.062,142.172 809.071,142.175 809.08,142.178 809.09,142.181 809.099,142.184 809.108,142.187 809.117,142.19 809.126,142.193 809.136,142.196 809.145,142.199 809.154,142.202 809.163,142.205 809.172,142.208 809.182,142.211 809.191,142.214 809.2,142.217 809.209,142.22 809.218,142.224 809.228,142.227 809.237,142.23 809.246,142.233 809.255,142.236 809.264,142.239 809.273,142.242 809.283,142.245 809.292,142.248 809.301,142.251 809.31,142.254 809.319,142.257 809.329,142.26 809.338,142.263 809.347,142.266 809.356,142.269 809.365,142.272 809.375,142.275 809.384,142.278 809.393,142.281 809.402,142.284 809.411,142.287 809.42,142.29 809.43,142.293 809.439,142.296 809.448,142.299 809.457,142.302 809.466,142.305 809.476,142.308 809.485,142.311 809.494,142.314 809.503,142.317 809.512,142.32 809.522,142.323 809.531,142.326 809.54,142.329 809.549,142.332 809.558,142.335 809.568,142.338 809.577,142.341 809.586,142.345 809.595,142.348 809.604,142.351 809.613,142.354 809.623,142.357 809.632,142.36 809.641,142.363 809.65,142.366 809.659,142.369 809.669,142.372 809.678,142.375 809.687,142.378 809.696,142.381 809.705,142.384 809.715,142.387 809.724,142.39 809.733,142.393 809.742,142.396 809.751,142.399 809.761,142.402 809.77,142.405 809.779,142.408 809.788,142.411 809.797,142.414 809.806,142.417 809.816,142.42 809.825,142.423 809.834,142.426 809.843,142.429 809.852,142.432 809.862,142.435 809.871,142.438 809.88,142.441 809.889,142.444 809.898,142.447 809.908,142.45 809.917,142.453 809.926,142.456 809.935,142.459 809.944,142.462 809.953,142.465 809.963,142.469 809.972,142.472 809.981,142.475 809.99,142.478 809.999,142.481 810.009,142.484 810.018,142.487 810.027,142.49 810.036,142.493 810.045,142.496 810.055,142.499 810.064,142.502 810.073,142.505 810.082,142.508 810.091,142.511 810.101,142.514 810.11,142.517 810.119,142.52 810.128,142.523 810.137,142.526 810.146,142.529 810.156,142.532 810.165,142.535 810.174,142.538 810.183,142.541 810.192,142.544 810.202,142.547 810.211,142.55 810.22,142.553 810.229,142.556 810.238,142.559 810.248,142.562 810.257,142.565 810.266,142.568 810.275,142.571 810.284,142.574 810.293,142.577 810.303,142.58 810.312,142.583 810.321,142.586 810.33,142.589 810.339,142.593 810.349,142.596 810.358,142.599 810.367,142.602 810.376,142.605 810.385,142.608 810.395,142.611 810.404,142.614 810.413,142.617 810.422,142.62 810.431,142.623 810.441,142.626 810.45,142.629 810.459,142.632 810.468,142.635 810.477,142.638 810.486,142.641 810.496,142.644 810.505,142.647 810.514,142.65 810.523,142.653 810.532,142.656 810.542,142.659 810.551,142.662 810.56,142.665 810.569,142.668 810.578,142.671 810.588,142.674 810.597,142.677 810.606,142.68 810.615,142.683 810.624,142.686 810.633,142.689 810.643,142.692 810.652,142.695 810.661,142.698 810.67,142.701 810.679,142.704 810.689,142.707 810.698,142.71 810.707,142.713 810.716,142.716 810.725,142.72 810.735,142.723 810.744,142.726 810.753,142.729 810.762,142.732 810.771,142.735 810.781,142.738 810.79,142.741 810.799,142.744 810.808,142.747 810.817,142.75 810.826,142.753 810.836,142.756 810.845,142.759 810.854,142.762 810.863,142.765 810.872,142.768 810.882,142.771 810.891,142.774 810.9,142.777 810.909,142.78 810.918,142.783 810.928,142.786 810.937,142.789 810.946,142.792 810.955,142.795 810.964,142.798 810.973,142.801 810.983,142.804 810.992,142.807 811.001,142.81 811.01,142.813 811.019,142.816 811.029,142.819 811.038,142.822 811.047,142.825 811.056,142.828 811.065,142.831 811.075,142.834 811.084,142.837 811.093,142.84 811.102,142.843 811.111,142.846 811.121,142.85 811.13,142.853 811.139,142.856 811.148,142.859 811.157,142.862 811.166,142.865 811.176,142.868 811.185,142.871 811.194,142.874 811.203,142.877 811.212,142.88 811.222,142.883 811.231,142.886 811.24,142.889 811.249,142.892 811.258,142.895 811.268,142.898 811.277,142.901 811.286,142.904 811.295,142.907 811.304,142.91 811.313,142.913 811.323,142.916 811.332,142.919 811.341,142.922 811.35,142.925 811.359,142.928 811.369,142.931 811.378,142.934 811.387,142.937 811.396,142.94 811.405,142.943 811.415,142.946 811.424,142.949 811.433,142.952 811.442,142.955 811.451,142.958 811.461,142.961 811.47,142.964 811.479,142.967 811.488,142.97 811.497,142.973 811.506,142.976 811.516,142.98 811.525,142.983 811.534,142.986 811.543,142.989 811.552,142.992 811.562,142.995 811.571,142.998 811.58,143.001 811.589,143.004 811.598,143.007 811.608,143.01 811.617,143.013 811.626,143.016 811.635,143.019 811.644,143.022 811.653,143.025 811.663,143.028 811.672,143.031 811.681,143.034 811.69,143.037 811.699,143.04 811.709,143.043 811.718,143.046 811.727,143.049 811.736,143.052 811.745,143.055 811.755,143.058 811.764,143.061 811.773,143.064 811.782,143.067 811.791,143.07 811.801,143.073 811.81,143.076 811.819,143.079 811.828,143.082 811.837,143.085 811.846,143.088 811.856,143.091 811.865,143.094 811.874,143.097 811.883,143.1 811.892,143.103 811.902,143.106 811.911,143.109 811.92,143.112 811.929,143.116 811.938,143.119 811.948,143.122 811.957,143.125 811.966,143.128 811.975,143.131 811.984,143.134 811.993,143.137 812.003,143.14 812.012,143.143 812.021,143.146 812.03,143.149 812.039,143.152 812.049,143.155 812.058,143.158 812.067,143.161 812.076,143.164 812.085,143.167 812.095,143.17 812.104,143.173 812.113,143.176 812.122,143.179 812.131,143.182 812.141,143.185 812.15,143.188 812.159,143.191 812.168,143.194 812.177,143.197 812.186,143.2 812.196,143.203 812.205,143.206 812.214,143.209 812.223,143.212 812.232,143.215 812.242,143.218 812.251,143.221 812.26,143.224 812.269,143.227 812.278,143.23 812.288,143.233 812.297,143.236 812.306,143.239 812.315,143.242 812.324,143.245 812.334,143.248 812.343,143.252 812.352,143.255 812.361,143.258 812.37,143.261 812.379,143.264 812.389,143.267 812.398,143.27 812.407,143.273 812.416,143.276 812.425,143.279 812.435,143.282 812.444,143.285 812.453,143.288 812.462,143.291 812.471,143.294 812.481,143.297 812.49,143.3 812.499,143.303 812.508,143.306 812.517,143.309 812.526,143.312 812.536,143.315 812.545,143.318 812.554,143.321 812.563,143.324 812.572,143.327 812.582,143.33 812.591,143.333 812.6,143.336 812.609,143.339 812.618,143.342 812.628,143.345 812.637,143.348 812.646,143.351 812.655,143.354 812.664,143.357 812.674,143.36 812.683,143.363 812.692,143.366 812.701,143.369 812.71,143.372 812.719,143.375 812.729,143.378 812.738,143.381 812.747,143.384 812.756,143.387 812.765,143.391 812.775,143.394 812.784,143.397 812.793,143.4 812.802,143.403 812.811,143.406 812.821,143.409 812.83,143.412 812.839,143.415 812.848,143.418 812.857,143.421 812.866,143.424 812.876,143.427 812.885,143.43 812.894,143.433 812.903,143.436 812.912,143.439 812.922,143.442 812.931,143.445 812.94,143.448 812.949,143.451 812.958,143.454 812.968,143.457 812.977,143.46 812.986,143.463 812.995,143.466 813.004,143.469 813.014,143.472 813.023,143.475 813.032,143.478 813.041,143.481 813.05,143.484 813.059,143.487 813.069,143.49 813.078,143.493 813.087,143.496 813.096,143.499 813.105,143.502 813.115,143.505 813.124,143.508 813.133,143.511 813.142,143.514 813.151,143.517 813.161,143.52 813.17,143.523 813.179,143.526 813.188,143.529 813.197,143.533 813.206,143.536 813.216,143.539 813.225,143.542 813.234,143.545 813.243,143.548 813.252,143.551 813.262,143.554 813.271,143.557 813.28,143.56 813.289,143.563 813.298,143.566 813.308,143.569 813.317,143.572 813.326,143.575 813.335,143.578 813.344,143.581 813.354,143.584 813.363,143.587 813.372,143.59 813.381,143.593 813.39,143.596 813.399,143.599 813.409,143.602 813.418,143.605 813.427,143.608 813.436,143.611 813.445,143.614 813.455,143.617 813.464,143.62 813.473,143.623 813.482,143.626 813.491,143.629 813.501,143.632 813.51,143.635 813.519,143.638 813.528,143.641 813.537,143.644 813.546,143.647 813.556,143.65 813.565,143.653 813.574,143.656 813.583,143.659 813.592,143.662 813.602,143.665 813.611,143.668 813.62,143.671 813.629,143.674 813.638,143.678 813.648,143.681 813.657,143.684 813.666,143.687 813.675,143.69 813.684,143.693 813.694,143.696 813.703,143.699 813.712,143.702 813.721,143.705 813.73,143.708 813.739,143.711 813.749,143.714 813.758,143.717 813.767,143.72 813.776,143.723 813.785,143.726 813.795,143.729 813.804,143.732 813.813,143.735 813.822,143.738 813.831,143.741 813.841,143.744 813.85,143.747 813.859,143.75 813.868,143.753 813.877,143.756 813.886,143.759 813.896,143.762 813.905,143.765 813.914,143.768 813.923,143.771 813.932,143.774 813.942,143.777 813.951,143.78 813.96,143.783 813.969,143.786 813.978,143.789 813.988,143.792 813.997,143.795 814.006,143.798 814.015,143.801 814.024,143.804 814.034,143.807 814.043,143.81 814.052,143.813 814.061,143.816 814.07,143.819 814.079,143.822 814.089,143.826 814.098,143.829 814.107,143.832 814.116,143.835 814.125,143.838 814.135,143.841 814.144,143.844 814.153,143.847 814.162,143.85 814.171,143.853 814.181,143.856 814.19,143.859 814.199,143.862 814.208,143.865 814.217,143.868 814.226,143.871 814.236,143.874 814.245,143.877 814.254,143.88 814.263,143.883 814.272,143.886 814.282,143.889 814.291,143.892 814.3,143.895 814.309,143.898 814.318,143.901 814.328,143.904 814.337,143.907 814.346,143.91 814.355,143.913 814.364,143.916 814.374,143.919 814.383,143.922 814.392,143.925 814.401,143.928 814.41,143.931 814.419,143.934 814.429,143.937 814.438,143.94 814.447,143.943 814.456,143.946 814.465,143.949 814.475,143.952 814.484,143.955 814.493,143.958 814.502,143.961 814.511,143.964 814.521,143.967 814.53,143.97 814.539,143.973 814.548,143.976 814.557,143.98 814.566,143.983 814.576,143.986 814.585,143.989 814.594,143.992 814.603,143.995 814.612,143.998 814.622,144.001 814.631,144.004 814.64,144.007 814.649,144.01 814.658,144.013 814.668,144.016 814.677,144.019 814.686,144.022 814.695,144.025 814.704,144.028 814.714,144.031 814.723,144.034 814.732,144.037 814.741,144.04 814.75,144.043 814.759,144.046 814.769,144.049 814.778,144.052 814.787,144.055 814.796,144.058 814.805,144.061 814.815,144.064 814.824,144.067 814.833,144.07 814.842,144.073 814.851,144.076 814.861,144.079 814.87,144.082 814.879,144.085 814.888,144.088 814.897,144.091 814.907,144.094 814.916,144.097 814.925,144.1 814.934,144.103 814.943,144.106 814.952,144.109 814.962,144.112 814.971,144.115 814.98,144.118 814.989,144.121 814.998,144.124 815.008,144.127 815.017,144.13 815.026,144.133 815.035,144.137 815.044,144.14 815.054,144.143 815.063,144.146 815.072,144.149 815.081,144.152 815.09,144.155 815.099,144.158 815.109,144.161 815.118,144.164 815.127,144.167 815.136,144.17 815.145,144.173 815.155,144.176 815.164,144.179 815.173,144.182 815.182,144.185 815.191,144.188 815.201,144.191 815.21,144.194 815.219,144.197 815.228,144.2 815.237,144.203 815.247,144.206 815.256,144.209 815.265,144.212 815.274,144.215 815.283,144.218 815.292,144.221 815.302,144.224 815.311,144.227 815.32,144.23 815.329,144.233 815.338,144.236 815.348,144.239 815.357,144.242 815.366,144.245 815.375,144.248 815.384,144.251 815.394,144.254 815.403,144.257 815.412,144.26 815.421,144.263 815.43,144.266 815.439,144.269 815.449,144.272 815.458,144.275 815.467,144.278 815.476,144.281 815.485,144.284 815.495,144.287 815.504,144.29 815.513,144.293 815.522,144.297 815.531,144.3 815.541,144.303 815.55,144.306 815.559,144.309 815.568,144.312 815.577,144.315 815.587,144.318 815.596,144.321 815.605,144.324 815.614,144.327 815.623,144.33 815.632,144.333 815.642,144.336 815.651,144.339 815.66,144.342 815.669,144.345 815.678,144.348 815.688,144.351 815.697,144.354 815.706,144.357 815.715,144.36 815.724,144.363 815.734,144.366 815.743,144.369 815.752,144.372 815.761,144.375 815.77,144.378 815.779,144.381 815.789,144.384 815.798,144.387 815.807,144.39 815.816,144.393 815.825,144.396 815.835,144.399 815.844,144.402 815.853,144.405 815.862,144.408 815.871,144.411 815.881,144.414 815.89,144.417 815.899,144.42 815.908,144.423 815.917,144.426 815.927,144.429 815.936,144.432 815.945,144.435 815.954,144.438 815.963,144.441 815.972,144.444 815.982,144.447 815.991,144.45 816,144.453 816.009,144.456 816.018,144.46 816.028,144.463 816.037,144.466 816.046,144.469 816.055,144.472 816.064,144.475 816.074,144.478 816.083,144.481 816.092,144.484 816.101,144.487 816.11,144.49 816.119,144.493 816.129,144.496 816.138,144.499 816.147,144.502 816.156,144.505 816.165,144.508 816.175,144.511 816.184,144.514 816.193,144.517 816.202,144.52 816.211,144.523 816.221,144.526 816.23,144.529 816.239,144.532 816.248,144.535 816.257,144.538 816.267,144.541 816.276,144.544 816.285,144.547 816.294,144.55 816.303,144.553 816.312,144.556 816.322,144.559 816.331,144.562 816.34,144.565 816.349,144.568 816.358,144.571 816.368,144.574 816.377,144.577 816.386,144.58 816.395,144.583 816.404,144.586 816.414,144.589 816.423,144.592 816.432,144.595 816.441,144.598 816.45,144.601 816.459,144.604 816.469,144.607 816.478,144.61 816.487,144.613 816.496,144.616 816.505,144.619 816.515,144.622 816.524,144.625 816.533,144.628 816.542,144.632 816.551,144.635 816.561,144.638 816.57,144.641 816.579,144.644 816.588,144.647 816.597,144.65 816.607,144.653 816.616,144.656 816.625,144.659 816.634,144.662 816.643,144.665 816.652,144.668 816.662,144.671 816.671,144.674 816.68,144.677 816.689,144.68 816.698,144.683 816.708,144.686 816.717,144.689 816.726,144.692 816.735,144.695 816.744,144.698 816.754,144.701 816.763,144.704 816.772,144.707 816.781,144.71 816.79,144.713 816.799,144.716 816.809,144.719 816.818,144.722 816.827,144.725 816.836,144.728 816.845,144.731 816.855,144.734 816.864,144.737 816.873,144.74 816.882,144.743 816.891,144.746 816.901,144.749 816.91,144.752 816.919,144.755 816.928,144.758 816.937,144.761 816.947,144.764 816.956,144.767 816.965,144.77 816.974,144.773 816.983,144.776 816.992,144.779 817.002,144.782 817.011,144.785 817.02,144.788 817.029,144.791 817.038,144.794 817.048,144.797 817.057,144.8 817.066,144.803 817.075,144.807 817.084,144.81 817.094,144.813 817.103,144.816 817.112,144.819 817.121,144.822 817.13,144.825 817.14,144.828 817.149,144.831 817.158,144.834 817.167,144.837 817.176,144.84 817.185,144.843 817.195,144.846 817.204,144.849 817.213,144.852 817.222,144.855 817.231,144.858 817.241,144.861 817.25,144.864 817.259,144.867 817.268,144.87 817.277,144.873 817.287,144.876 817.296,144.879 817.305,144.882 817.314,144.885 817.323,144.888 817.332,144.891 817.342,144.894 817.351,144.897 817.36,144.9 817.369,144.903 817.378,144.906 817.388,144.909 817.397,144.912 817.406,144.915 817.415,144.918 817.424,144.921 817.434,144.924 817.443,144.927 817.452,144.93 817.461,144.933 817.47,144.936 817.48,144.939 817.489,144.942 817.498,144.945 817.507,144.948 817.516,144.951 817.525,144.954 817.535,144.957 817.544,144.96 817.553,144.963 817.562,144.966 817.571,144.969 817.581,144.972 817.59,144.975 817.599,144.978 817.608,144.981 817.617,144.984 817.627,144.988 817.636,144.991 817.645,144.994 817.654,144.997 817.663,145 817.672,145.003 817.682,145.006 817.691,145.009 817.7,145.012 817.709,145.015 817.718,145.018 817.728,145.021 817.737,145.024 817.746,145.027 817.755,145.03 817.764,145.033 817.774,145.036 817.783,145.039 817.792,145.042 817.801,145.045 817.81,145.048 817.82,145.051 817.829,145.054 817.838,145.057 817.847,145.06 817.856,145.063 817.865,145.066 817.875,145.069 817.884,145.072 817.893,145.075 817.902,145.078 817.911,145.081 817.921,145.084 817.93,145.087 817.939,145.09 817.948,145.093 817.957,145.096 817.967,145.099 817.976,145.102 817.985,145.105 817.994,145.108 818.003,145.111 818.012,145.114 818.022,145.117 818.031,145.12 818.04,145.123 818.049,145.126 818.058,145.129 818.068,145.132 818.077,145.135 818.086,145.138 818.095,145.141 818.104,145.144 818.114,145.147 818.123,145.15 818.132,145.153 818.141,145.156 818.15,145.159 818.16,145.162 818.169,145.165 818.178,145.168 818.187,145.171 818.196,145.175 818.205,145.178 818.215,145.181 818.224,145.184 818.233,145.187 818.242,145.19 818.251,145.193 818.261,145.196 818.27,145.199 818.279,145.202 818.288,145.205 818.297,145.208 818.307,145.211 818.316,145.214 818.325,145.217 818.334,145.22 818.343,145.223 818.352,145.226 818.362,145.229 818.371,145.232 818.38,145.235 818.389,145.238 818.398,145.241 818.408,145.244 818.417,145.247 818.426,145.25 818.435,145.253 818.444,145.256 818.454,145.259 818.463,145.262 818.472,145.265 818.481,145.268 818.49,145.271 818.5,145.274 818.509,145.277 818.518,145.28 818.527,145.283 818.536,145.286 818.545,145.289 818.555,145.292 818.564,145.295 818.573,145.298 818.582,145.301 818.591,145.304 818.601,145.307 818.61,145.31 818.619,145.313 818.628,145.316 818.637,145.319 818.647,145.322 818.656,145.325 818.665,145.328 818.674,145.331 818.683,145.334 818.692,145.337 818.702,145.34 818.711,145.343 818.72,145.346 818.729,145.349 818.738,145.352 818.748,145.355 818.757,145.358 818.766,145.361 818.775,145.364 818.784,145.367 818.794,145.371 818.803,145.374 818.812,145.377 818.821,145.38 818.83,145.383 818.84,145.386 818.849,145.389 818.858,145.392 818.867,145.395 818.876,145.398 818.885,145.401 818.895,145.404 818.904,145.407 818.913,145.41 818.922,145.413 818.931,145.416 818.941,145.419 818.95,145.422 818.959,145.425 818.968,145.428 818.977,145.431 818.987,145.434 818.996,145.437 819.005,145.44 819.014,145.443 819.023,145.446 819.032,145.449 819.042,145.452 819.051,145.455 819.06,145.458 819.069,145.461 819.078,145.464 819.088,145.467 819.097,145.47 819.106,145.473 819.115,145.476 819.124,145.479 819.134,145.482 819.143,145.485 819.152,145.488 819.161,145.491 819.17,145.494 819.18,145.497 819.189,145.5 819.198,145.503 819.207,145.506 819.216,145.509 819.225,145.512 819.235,145.515 819.244,145.518 819.253,145.521 819.262,145.524 819.271,145.527 819.281,145.53 819.29,145.533 819.299,145.536 819.308,145.539 819.317,145.542 819.327,145.545 819.336,145.548 819.345,145.551 819.354,145.554 819.363,145.557 819.372,145.56 819.382,145.563 819.391,145.566 819.4,145.569 819.409,145.572 819.418,145.576 819.428,145.579 819.437,145.582 819.446,145.585 819.455,145.588 819.464,145.591 819.474,145.594 819.483,145.597 819.492,145.6 819.501,145.603 819.51,145.606 819.52,145.609 819.529,145.612 819.538,145.615 819.547,145.618 819.556,145.621 819.565,145.624 819.575,145.627 819.584,145.63 819.593,145.633 819.602,145.636 819.611,145.639 819.621,145.642 819.63,145.645 819.639,145.648 819.648,145.651 819.657,145.654 819.667,145.657 819.676,145.66 819.685,145.663 819.694,145.666 819.703,145.669 819.713,145.672 819.722,145.675 819.731,145.678 819.74,145.681 819.749,145.684 819.758,145.687 819.768,145.69 819.777,145.693 819.786,145.696 819.795,145.699 819.804,145.702 819.814,145.705 819.823,145.708 819.832,145.711 819.841,145.714 819.85,145.717 819.86,145.72 819.869,145.723 819.878,145.726 819.887,145.729 819.896,145.732 819.905,145.735 819.915,145.738 819.924,145.741 819.933,145.744 819.942,145.747 819.951,145.75 819.961,145.753 819.97,145.756 819.979,145.759 819.988,145.762 819.997,145.765 820.007,145.768 820.016,145.771 820.025,145.774 820.034,145.777 820.043,145.78 820.053,145.783 820.062,145.786 820.071,145.79 820.08,145.793 820.089,145.796 820.098,145.799 820.108,145.802 820.117,145.805 820.126,145.808 820.135,145.811 820.144,145.814 820.154,145.817 820.163,145.82 820.172,145.823 820.181,145.826 820.19,145.829 820.2,145.832 820.209,145.835 820.218,145.838 820.227,145.841 820.236,145.844 820.245,145.847 820.255,145.85 820.264,145.853 820.273,145.856 820.282,145.859 820.291,145.862 820.301,145.865 820.31,145.868 820.319,145.871 820.328,145.874 820.337,145.877 820.347,145.88 820.356,145.883 820.365,145.886 820.374,145.889 820.383,145.892 820.393,145.895 820.402,145.898 820.411,145.901 820.42,145.904 820.429,145.907 820.438,145.91 820.448,145.913 820.457,145.916 820.466,145.919 820.475,145.922 820.484,145.925 820.494,145.928 820.503,145.931 820.512,145.934 820.521,145.937 820.53,145.94 820.54,145.943 820.549,145.946 820.558,145.949 820.567,145.952 820.576,145.955 820.585,145.958 820.595,145.961 820.604,145.964 820.613,145.967 820.622,145.97 820.631,145.973 820.641,145.976 820.65,145.979 820.659,145.982 820.668,145.985 820.677,145.988 820.687,145.991 820.696,145.994 820.705,145.997 820.714,146 820.723,146.003 820.733,146.006 820.742,146.009 820.751,146.013 820.76,146.016 820.769,146.019 820.778,146.022 820.788,146.025 820.797,146.028 820.806,146.031 820.815,146.034 820.824,146.037 820.834,146.04 820.843,146.043 820.852,146.046 820.861,146.049 820.87,146.052 820.88,146.055 820.889,146.058 820.898,146.061 820.907,146.064 820.916,146.067 820.925,146.07 820.935,146.073 820.944,146.076 820.953,146.079 820.962,146.082 820.971,146.085 820.981,146.088 820.99,146.091 820.999,146.094 821.008,146.097 821.017,146.1 821.027,146.103 821.036,146.106 821.045,146.109 821.054,146.112 821.063,146.115 821.073,146.118 821.082,146.121 821.091,146.124 821.1,146.127 821.109,146.13 821.118,146.133 821.128,146.136 821.137,146.139 821.146,146.142 821.155,146.145 821.164,146.148 821.174,146.151 821.183,146.154 821.192,146.157 821.201,146.16 821.21,146.163 821.22,146.166 821.229,146.169 821.238,146.172 821.247,146.175 821.256,146.178 821.265,146.181 821.275,146.184 821.284,146.187 821.293,146.19 821.302,146.193 821.311,146.196 821.321,146.199 821.33,146.202 821.339,146.205 821.348,146.208 821.357,146.211 821.367,146.214 821.376,146.217 821.385,146.22 821.394,146.223 821.403,146.226 821.413,146.229 821.422,146.232 821.431,146.235 821.44,146.238 821.449,146.241 821.458,146.244 821.468,146.247 821.477,146.251 821.486,146.254 821.495,146.257 821.504,146.26 821.514,146.263 821.523,146.266 821.532,146.269 821.541,146.272 821.55,146.275 821.56,146.278 821.569,146.281 821.578,146.284 821.587,146.287 821.596,146.29 821.605,146.293 821.615,146.296 821.624,146.299 821.633,146.302 821.642,146.305 821.651,146.308 821.661,146.311 821.67,146.314 821.679,146.317 821.688,146.32 821.697,146.323 821.707,146.326 821.716,146.329 821.725,146.332 821.734,146.335 821.743,146.338 821.753,146.341 821.762,146.344 821.771,146.347 821.78,146.35 821.789,146.353 821.798,146.356 821.808,146.359 821.817,146.362 821.826,146.365 821.835,146.368 821.844,146.371 821.854,146.374 821.863,146.377 821.872,146.38 821.881,146.383 821.89,146.386 821.9,146.389 821.909,146.392 821.918,146.395 821.927,146.398 821.936,146.401 821.945,146.404 821.955,146.407 821.964,146.41 821.973,146.413 821.982,146.416 821.991,146.419 822.001,146.422 822.01,146.425 822.019,146.428 822.028,146.431 822.037,146.434 822.047,146.437 822.056,146.44 822.065,146.443 822.074,146.446 822.083,146.449 822.093,146.452 822.102,146.455 822.111,146.458 822.12,146.461 822.129,146.464 822.138,146.467 822.148,146.47 822.157,146.473 822.166,146.476 822.175,146.479 822.184,146.482 822.194,146.485 822.203,146.488 822.212,146.491 822.221,146.494 822.23,146.497 822.24,146.5 822.249,146.503 822.258,146.507 822.267,146.51 822.276,146.513 822.286,146.516 822.295,146.519 822.304,146.522 822.313,146.525 822.322,146.528 822.331,146.531 822.341,146.534 822.35,146.537 822.359,146.54 822.368,146.543 822.377,146.546 822.387,146.549 822.396,146.552 822.405,146.555 822.414,146.558 822.423,146.561 822.433,146.564 822.442,146.567 822.451,146.57 822.46,146.573 822.469,146.576 822.478,146.579 822.488,146.582 822.497,146.585 822.506,146.588 822.515,146.591 822.524,146.594 822.534,146.597 822.543,146.6 822.552,146.603 822.561,146.606 822.57,146.609 822.58,146.612 822.589,146.615 822.598,146.618 822.607,146.621 822.616,146.624 822.626,146.627 822.635,146.63 822.644,146.633 822.653,146.636 822.662,146.639 822.671,146.642 822.681,146.645 822.69,146.648 822.699,146.651 822.708,146.654 822.717,146.657 822.727,146.66 822.736,146.663 822.745,146.666 822.754,146.669 822.763,146.672 822.773,146.675 822.782,146.678 822.791,146.681 822.8,146.684 822.809,146.687 822.818,146.69 822.828,146.693 822.837,146.696 822.846,146.699 822.855,146.702 822.864,146.705 822.874,146.708 822.883,146.711 822.892,146.714 822.901,146.717 822.91,146.72 822.92,146.723 822.929,146.726 822.938,146.729 822.947,146.732 822.956,146.735 822.966,146.738 822.975,146.741 822.984,146.744 822.993,146.747 823.002,146.75 823.011,146.753 823.021,146.756 823.03,146.759 823.039,146.762 823.048,146.765 823.057,146.768 823.067,146.771 823.076,146.774 823.085,146.777 823.094,146.781 823.103,146.784 823.113,146.787 823.122,146.79 823.131,146.793 823.14,146.796 823.149,146.799 823.158,146.802 823.168,146.805 823.177,146.808 823.186,146.811 823.195,146.814 823.204,146.817 823.214,146.82 823.223,146.823 823.232,146.826 823.241,146.829 823.25,146.832 823.26,146.835 823.269,146.838 823.278,146.841 823.287,146.844 823.296,146.847 823.306,146.85 823.315,146.853 823.324,146.856 823.333,146.859 823.342,146.862 823.351,146.865 823.361,146.868 823.37,146.871 823.379,146.874 823.388,146.877 823.397,146.88 823.407,146.883 823.416,146.886 823.425,146.889 823.434,146.892 823.443,146.895 823.453,146.898 823.462,146.901 823.471,146.904 823.48,146.907 823.489,146.91 823.498,146.913 823.508,146.916 823.517,146.919 823.526,146.922 823.535,146.925 823.544,146.928 823.554,146.931 823.563,146.934 823.572,146.937 823.581,146.94 823.59,146.943 823.6,146.946 823.609,146.949 823.618,146.952 823.627,146.955 823.636,146.958 823.646,146.961 823.655,146.964 823.664,146.967 823.673,146.97 823.682,146.973 823.691,146.976 823.701,146.979 823.71,146.982 823.719,146.985 823.728,146.988 823.737,146.991 823.747,146.994 823.756,146.997 823.765,147 823.774,147.003 823.783,147.006 823.793,147.009 823.802,147.012 823.811,147.015 823.82,147.018 823.829,147.021 823.838,147.024 823.848,147.027 823.857,147.03 823.866,147.033 823.875,147.036 823.884,147.039 823.894,147.042 823.903,147.045 823.912,147.048 823.921,147.051 823.93,147.054 823.94,147.057 823.949,147.06 823.958,147.063 823.967,147.066 823.976,147.069 823.986,147.072 823.995,147.075 824.004,147.078 824.013,147.082 824.022,147.085 824.031,147.088 824.041,147.091 824.05,147.094 824.059,147.097 824.068,147.1 824.077,147.103 824.087,147.106 824.096,147.109 824.105,147.112 824.114,147.115 824.123,147.118 824.133,147.121 824.142,147.124 824.151,147.127 824.16,147.13 824.169,147.133 824.178,147.136 824.188,147.139 824.197,147.142 824.206,147.145 824.215,147.148 824.224,147.151 824.234,147.154 824.243,147.157 824.252,147.16 824.261,147.163 824.27,147.166 824.28,147.169 824.289,147.172 824.298,147.175 824.307,147.178 824.316,147.181 824.326,147.184 824.335,147.187 824.344,147.19 824.353,147.193 824.362,147.196 824.371,147.199 824.381,147.202 824.39,147.205 824.399,147.208 824.408,147.211 824.417,147.214 824.427,147.217 824.436,147.22 824.445,147.223 824.454,147.226 824.463,147.229 824.473,147.232 824.482,147.235 824.491,147.238 824.5,147.241 824.509,147.244 824.519,147.247 824.528,147.25 824.537,147.253 824.546,147.256 824.555,147.259 824.564,147.262 824.574,147.265 824.583,147.268 824.592,147.271 824.601,147.274 824.61,147.277 824.62,147.28 824.629,147.283 824.638,147.286 824.647,147.289 824.656,147.292 824.666,147.295 824.675,147.298 824.684,147.301 824.693,147.304 824.702,147.307 824.711,147.31 824.721,147.313 824.73,147.316 824.739,147.319 824.748,147.322 824.757,147.325 824.767,147.328 824.776,147.331 824.785,147.334 824.794,147.337 824.803,147.34 824.813,147.343 824.822,147.346 824.831,147.349 824.84,147.352 824.849,147.355 824.859,147.358 824.868,147.361 824.877,147.364 824.886,147.367 824.895,147.37 824.904,147.373 824.914,147.376 824.923,147.379 824.932,147.382 824.941,147.385 824.95,147.388 824.96,147.391 824.969,147.394 824.978,147.397 824.987,147.4 824.996,147.403 825.006,147.406 825.015,147.409 825.024,147.412 825.033,147.415 825.042,147.419 825.051,147.422 825.061,147.425 825.07,147.428 825.079,147.431 825.088,147.434 825.097,147.437 825.107,147.44 825.116,147.443 825.125,147.446 825.134,147.449 825.143,147.452 825.153,147.455 825.162,147.458 825.171,147.461 825.18,147.464 825.189,147.467 825.199,147.47 825.208,147.473 825.217,147.476 825.226,147.479 825.235,147.482 825.244,147.485 825.254,147.488 825.263,147.491 825.272,147.494 825.281,147.497 825.29,147.5 825.3,147.503 825.309,147.506 825.318,147.509 825.327,147.512 825.336,147.515 825.346,147.518 825.355,147.521 825.364,147.524 825.373,147.527 825.382,147.53 825.391,147.533 825.401,147.536 825.41,147.539 825.419,147.542 825.428,147.545 825.437,147.548 825.447,147.551 825.456,147.554 825.465,147.557 825.474,147.56 825.483,147.563 825.493,147.566 825.502,147.569 825.511,147.572 825.52,147.575 825.529,147.578 825.539,147.581 825.548,147.584 825.557,147.587 825.566,147.59 825.575,147.593 825.584,147.596 825.594,147.599 825.603,147.602 825.612,147.605 825.621,147.608 825.63,147.611 825.64,147.614 825.649,147.617 825.658,147.62 825.667,147.623 825.676,147.626 825.686,147.629 825.695,147.632 825.704,147.635 825.713,147.638 825.722,147.641 825.731,147.644 825.741,147.647 825.75,147.65 825.759,147.653 825.768,147.656 825.777,147.659 825.787,147.662 825.796,147.665 825.805,147.668 825.814,147.671 825.823,147.674 825.833,147.677 825.842,147.68 825.851,147.683 825.86,147.686 825.869,147.689 825.879,147.692 825.888,147.695 825.897,147.698 825.906,147.701 825.915,147.704 825.924,147.707 825.934,147.71 825.943,147.713 825.952,147.716 825.961,147.719 825.97,147.722 825.98,147.725 825.989,147.728 825.998,147.731 826.007,147.734 826.016,147.737 826.026,147.74 826.035,147.743 826.044,147.746 826.053,147.749 826.062,147.752 826.071,147.755 826.081,147.758 826.09,147.761 826.099,147.764 826.108,147.767 826.117,147.77 826.127,147.773 826.136,147.776 826.145,147.779 826.154,147.782 826.163,147.785 826.173,147.788 826.182,147.791 826.191,147.794 826.2,147.797 826.209,147.8 826.219,147.803 826.228,147.807 826.237,147.81 826.246,147.813 826.255,147.816 826.264,147.819 826.274,147.822 826.283,147.825 826.292,147.828 826.301,147.831 826.31,147.834 826.32,147.837 826.329,147.84 826.338,147.843 826.347,147.846 826.356,147.849 826.366,147.852 826.375,147.855 826.384,147.858 826.393,147.861 826.402,147.864 826.411,147.867 826.421,147.87 826.43,147.873 826.439,147.876 826.448,147.879 826.457,147.882 826.467,147.885 826.476,147.888 826.485,147.891 826.494,147.894 826.503,147.897 826.513,147.9 826.522,147.903 826.531,147.906 826.54,147.909 826.549,147.912 826.559,147.915 826.568,147.918 826.577,147.921 826.586,147.924 826.595,147.927 826.604,147.93 826.614,147.933 826.623,147.936 826.632,147.939 826.641,147.942 826.65,147.945 826.66,147.948 826.669,147.951 826.678,147.954 826.687,147.957 826.696,147.96 826.706,147.963 826.715,147.966 826.724,147.969 826.733,147.972 826.742,147.975 826.751,147.978 826.761,147.981 826.77,147.984 826.779,147.987 826.788,147.99 826.797,147.993 826.807,147.996 826.816,147.999 826.825,148.002 826.834,148.005 826.843,148.008 826.853,148.011 826.862,148.014 826.871,148.017 826.88,148.02 826.889,148.023 826.899,148.026 826.908,148.029 826.917,148.032 826.926,148.035 826.935,148.038 826.944,148.041 826.954,148.044 826.963,148.047 826.972,148.05 826.981,148.053 826.99,148.056 827,148.059 827.009,148.062 827.018,148.065 827.027,148.068 827.036,148.071 827.046,148.074 827.055,148.077 827.064,148.08 827.073,148.083 827.082,148.086 827.092,148.089 827.101,148.092 827.11,148.095 827.119,148.098 827.128,148.101 827.137,148.104 827.147,148.107 827.156,148.11 827.165,148.113 827.174,148.116 827.183,148.119 827.193,148.122 827.202,148.125 827.211,148.128 827.22,148.131 827.229,148.134 827.239,148.137 827.248,148.14 827.257,148.143 827.266,148.146 827.275,148.149 827.284,148.152 827.294,148.155 827.303,148.158 827.312,148.161 827.321,148.164 827.33,148.167 827.34,148.17 827.349,148.173 827.358,148.176 827.367,148.179 827.376,148.182 827.386,148.185 827.395,148.188 827.404,148.191 827.413,148.194 827.422,148.197 827.432,148.2 827.441,148.203 827.45,148.206 827.459,148.209 827.468,148.212 827.477,148.215 827.487,148.218 827.496,148.221 827.505,148.224 827.514,148.227 827.523,148.23 827.533,148.233 827.542,148.236 827.551,148.239 827.56,148.242 827.569,148.245 827.579,148.248 827.588,148.251 827.597,148.254 827.606,148.257 827.615,148.26 827.624,148.263 827.634,148.266 827.643,148.269 827.652,148.272 827.661,148.275 827.67,148.278 827.68,148.282 827.689,148.285 827.698,148.288 827.707,148.291 827.716,148.294 827.726,148.297 827.735,148.3 827.744,148.303 827.753,148.306 827.762,148.309 827.772,148.312 827.781,148.315 827.79,148.318 827.799,148.321 827.808,148.324 827.817,148.327 827.827,148.33 827.836,148.333 827.845,148.336 827.854,148.339 827.863,148.342 827.873,148.345 827.882,148.348 827.891,148.351 827.9,148.354 827.909,148.357 827.919,148.36 827.928,148.363 827.937,148.366 827.946,148.369 827.955,148.372 827.964,148.375 827.974,148.378 827.983,148.381 827.992,148.384 828.001,148.387 828.01,148.39 828.02,148.393 828.029,148.396 828.038,148.399 828.047,148.402 828.056,148.405 828.066,148.408 828.075,148.411 828.084,148.414 828.093,148.417 828.102,148.42 828.112,148.423 828.121,148.426 828.13,148.429 828.139,148.432 828.148,148.435 828.157,148.438 828.167,148.441 828.176,148.444 828.185,148.447 828.194,148.45 828.203,148.453 828.213,148.456 828.222,148.459 828.231,148.462 828.24,148.465 828.249,148.468 828.259,148.471 828.268,148.474 828.277,148.477 828.286,148.48 828.295,148.483 828.304,148.486 828.314,148.489 828.323,148.492 828.332,148.495 828.341,148.498 828.35,148.501 828.36,148.504 828.369,148.507 828.378,148.51 828.387,148.513 828.396,148.516 828.406,148.519 828.415,148.522 828.424,148.525 828.433,148.528 828.442,148.531 828.452,148.534 828.461,148.537 828.47,148.54 828.479,148.543 828.488,148.546 828.497,148.549 828.507,148.552 828.516,148.555 828.525,148.558 828.534,148.561 828.543,148.564 828.553,148.567 828.562,148.57 828.571,148.573 828.58,148.576 828.589,148.579 828.599,148.582 828.608,148.585 828.617,148.588 828.626,148.591 828.635,148.594 828.644,148.597 828.654,148.6 828.663,148.603 828.672,148.606 828.681,148.609 828.69,148.612 828.7,148.615 828.709,148.618 828.718,148.621 828.727,148.624 828.736,148.627 828.746,148.63 828.755,148.633 828.764,148.636 828.773,148.639 828.782,148.642 828.792,148.645 828.801,148.648 828.81,148.651 828.819,148.654 828.828,148.657 828.837,148.66 828.847,148.663 828.856,148.666 828.865,148.669 828.874,148.672 828.883,148.675 828.893,148.678 828.902,148.681 828.911,148.684 828.92,148.687 828.929,148.69 828.939,148.693 828.948,148.696 828.957,148.699 828.966,148.702 828.975,148.705 828.984,148.708 828.994,148.711 829.003,148.714 829.012,148.717 829.021,148.72 829.03,148.723 829.04,148.726 829.049,148.729 829.058,148.732 829.067,148.735 829.076,148.738 829.086,148.741 829.095,148.744 829.104,148.747 829.113,148.75 829.122,148.753 829.132,148.756 829.141,148.759 829.15,148.762 829.159,148.765 829.168,148.768 829.177,148.771 829.187,148.774 829.196,148.777 829.205,148.78 829.214,148.783 829.223,148.786 829.233,148.789 829.242,148.792 829.251,148.795 829.26,148.798 829.269,148.801 829.279,148.804 829.288,148.807 829.297,148.81 829.306,148.813 829.315,148.816 829.324,148.819 829.334,148.822 829.343,148.825 829.352,148.828 829.361,148.831 829.37,148.834 829.38,148.837 829.389,148.84 829.398,148.843 829.407,148.846 829.416,148.849 829.426,148.852 829.435,148.855 829.444,148.858 829.453,148.861 829.462,148.864 829.472,148.867 829.481,148.87 829.49,148.873 829.499,148.876 829.508,148.879 829.517,148.882 829.527,148.885 829.536,148.888 829.545,148.891 829.554,148.894 829.563,148.897 829.573,148.9 829.582,148.903 829.591,148.906 829.6,148.909 829.609,148.912 829.619,148.915 829.628,148.918 829.637,148.921 829.646,148.924 829.655,148.927 829.665,148.93 829.674,148.933 829.683,148.936 829.692,148.939 829.701,148.942 829.71,148.945 829.72,148.948 829.729,148.951 829.738,148.954 829.747,148.957 829.756,148.96 829.766,148.963 829.775,148.966 829.784,148.969 829.793,148.972 829.802,148.975 829.812,148.978 829.821,148.981 829.83,148.985 829.839,148.988 829.848,148.991 829.857,148.994 829.867,148.997 829.876,149 829.885,149.003 829.894,149.006 829.903,149.009 829.913,149.012 829.922,149.015 829.931,149.018 829.94,149.021 829.949,149.024 829.959,149.027 829.968,149.03 829.977,149.033 829.986,149.036 829.995,149.039 830.005,149.042 830.014,149.045 830.023,149.048 830.032,149.051 830.041,149.054 830.05,149.057 830.06,149.06 830.069,149.063 830.078,149.066 830.087,149.069 830.096,149.072 830.106,149.075 830.115,149.078 830.124,149.081 830.133,149.084 830.142,149.087 830.152,149.09 830.161,149.093 830.17,149.096 830.179,149.099 830.188,149.102 830.197,149.105 830.207,149.108 830.216,149.111 830.225,149.114 830.234,149.117 830.243,149.12 830.253,149.123 830.262,149.126 830.271,149.129 830.28,149.132 830.289,149.135 830.299,149.138 830.308,149.141 830.317,149.144 830.326,149.147 830.335,149.15 830.345,149.153 830.354,149.156 830.363,149.159 830.372,149.162 830.381,149.165 830.39,149.168 830.4,149.171 830.409,149.174 830.418,149.177 830.427,149.18 830.436,149.183 830.446,149.186 830.455,149.189 830.464,149.192 830.473,149.195 830.482,149.198 830.492,149.201 830.501,149.204 830.51,149.207 830.519,149.21 830.528,149.213 830.537,149.216 830.547,149.219 830.556,149.222 830.565,149.225 830.574,149.228 830.583,149.231 830.593,149.234 830.602,149.237 830.611,149.24 830.62,149.243 830.629,149.246 830.639,149.249 830.648,149.252 830.657,149.255 830.666,149.258 830.675,149.261 830.685,149.264 830.694,149.267 830.703,149.27 830.712,149.273 830.721,149.276 830.73,149.279 830.74,149.282 830.749,149.285 830.758,149.288 830.767,149.291 830.776,149.294 830.786,149.297 830.795,149.3 830.804,149.303 830.813,149.306 830.822,149.309 830.832,149.312 830.841,149.315 830.85,149.318 830.859,149.321 830.868,149.324 830.877,149.327 830.887,149.33 830.896,149.333 830.905,149.336 830.914,149.339 830.923,149.342 830.933,149.345 830.942,149.348 830.951,149.351 830.96,149.354 830.969,149.357 830.979,149.36 830.988,149.363 830.997,149.366 831.006,149.369 831.015,149.372 831.025,149.375 831.034,149.378 831.043,149.381 831.052,149.384 831.061,149.387 831.07,149.39 831.08,149.393 831.089,149.396 831.098,149.399 831.107,149.402 831.116,149.405 831.126,149.408 831.135,149.411 831.144,149.414 831.153,149.417 831.162,149.42 831.172,149.423 831.181,149.426 831.19,149.429 831.199,149.432 831.208,149.435 831.217,149.438 831.227,149.441 831.236,149.444 831.245,149.447 831.254,149.45 831.263,149.453 831.273,149.456 831.282,149.459 831.291,149.462 831.3,149.465 831.309,149.468 831.319,149.471 831.328,149.474 831.337,149.477 831.346,149.48 831.355,149.483 831.365,149.486 831.374,149.489 831.383,149.492 831.392,149.495 831.401,149.498 831.41,149.501 831.42,149.504 831.429,149.507 831.438,149.51 831.447,149.513 831.456,149.516 831.466,149.519 831.475,149.522 831.484,149.525 831.493,149.528 831.502,149.531 831.512,149.534 831.521,149.537 831.53,149.54 831.539,149.543 831.548,149.546 831.557,149.549 831.567,149.552 831.576,149.555 831.585,149.558 831.594,149.561 831.603,149.564 831.613,149.567 831.622,149.57 831.631,149.573 831.64,149.576 831.649,149.579 831.659,149.582 831.668,149.585 831.677,149.588 831.686,149.591 831.695,149.594 831.705,149.597 831.714,149.6 831.723,149.603 831.732,149.606 831.741,149.609 831.75,149.612 831.76,149.615 831.769,149.618 831.778,149.621 831.787,149.624 831.796,149.627 831.806,149.63 831.815,149.633 831.824,149.636 831.833,149.639 831.842,149.642 831.852,149.645 831.861,149.648 831.87,149.651 831.879,149.654 831.888,149.657 831.898,149.66 831.907,149.663 831.916,149.666 831.925,149.669 831.934,149.672 831.943,149.675 831.953,149.678 831.962,149.681 831.971,149.684 831.98,149.687 831.989,149.69 831.999,149.693 832.008,149.696 832.017,149.699 832.026,149.702 832.035,149.705 832.045,149.708 832.054,149.711 832.063,149.714 832.072,149.717 832.081,149.72 832.09,149.723 832.1,149.726 832.109,149.729 832.118,149.732 832.127,149.735 832.136,149.738 832.146,149.741 832.155,149.744 832.164,149.747 832.173,149.75 832.182,149.753 832.192,149.756 832.201,149.759 832.21,149.762 832.219,149.765 832.228,149.768 832.238,149.771 832.247,149.774 832.256,149.777 832.265,149.78 832.274,149.783 832.283,149.786 832.293,149.789 832.302,149.792 832.311,149.795 832.32,149.798 832.329,149.801 832.339,149.804 832.348,149.807 832.357,149.81 832.366,149.813 832.375,149.816 832.385,149.819 832.394,149.822 832.403,149.825 832.412,149.828 832.421,149.831 832.43,149.834 832.44,149.837 832.449,149.84 832.458,149.843 832.467,149.846 832.476,149.849 832.486,149.852 832.495,149.855 832.504,149.858 832.513,149.861 832.522,149.864 832.532,149.867 832.541,149.87 832.55,149.873 832.559,149.876 832.568,149.879 832.578,149.882 832.587,149.885 832.596,149.888 832.605,149.891 832.614,149.894 832.623,149.897 832.633,149.9 832.642,149.903 832.651,149.906 832.66,149.909 832.669,149.912 832.679,149.915 832.688,149.918 832.697,149.921 832.706,149.924 832.715,149.927 832.725,149.93 832.734,149.933 832.743,149.936 832.752,149.939 832.761,149.942 832.77,149.945 832.78,149.948 832.789,149.951 832.798,149.954 832.807,149.957 832.816,149.96 832.826,149.963 832.835,149.966 832.844,149.969 832.853,149.972 832.862,149.975 832.872,149.978 832.881,149.981 832.89,149.984 832.899,149.987 832.908,149.99 832.918,149.993 832.927,149.996 832.936,149.999 832.945,150.002 832.954,150.005 832.963,150.008 832.973,150.011 832.982,150.014 832.991,150.017 833,150.02 833.009,150.023 833.019,150.026 833.028,150.029 833.037,150.032 833.046,150.035 833.055,150.038 833.065,150.041 833.074,150.044 833.083,150.047 833.092,150.05 833.101,150.053 833.11,150.056 833.12,150.059 833.129,150.062 833.138,150.065 833.147,150.068 833.156,150.071 833.166,150.074 833.175,150.077 833.184,150.08 833.193,150.083 833.202,150.086 833.212,150.089 833.221,150.092 833.23,150.095 833.239,150.098 833.248,150.101 833.258,150.104 833.267,150.107 833.276,150.11 833.285,150.113 833.294,150.116 833.303,150.119 833.313,150.122 833.322,150.125 833.331,150.128 833.34,150.131 833.349,150.134 833.359,150.137 833.368,150.14 833.377,150.143 833.386,150.146 833.395,150.149 833.405,150.152 833.414,150.155 833.423,150.158 833.432,150.161 833.441,150.164 833.45,150.167 833.46,150.17 833.469,150.173 833.478,150.176 833.487,150.179 833.496,150.182 833.506,150.185 833.515,150.188 833.524,150.191 833.533,150.194 833.542,150.197 833.552,150.2 833.561,150.203 833.57,150.206 833.579,150.209 833.588,150.212 833.598,150.215 833.607,150.218 833.616,150.221 833.625,150.224 833.634,150.227 833.643,150.23 833.653,150.233 833.662,150.236 833.671,150.239 833.68,150.242 833.689,150.245 833.699,150.248 833.708,150.251 833.717,150.254 833.726,150.257 833.735,150.26 833.745,150.263 833.754,150.266 833.763,150.269 833.772,150.272 833.781,150.275 833.79,150.278 833.8,150.281 833.809,150.284 833.818,150.287 833.827,150.29 833.836,150.293 833.846,150.296 833.855,150.299 833.864,150.302 833.873,150.305 833.882,150.308 833.892,150.311 833.901,150.314 833.91,150.317 833.919,150.32 833.928,150.323 833.938,150.326 833.947,150.329 833.956,150.332 833.965,150.335 833.974,150.338 833.983,150.341 833.993,150.344 834.002,150.347 834.011,150.35 834.02,150.353 834.029,150.356 834.039,150.359 834.048,150.362 834.057,150.365 834.066,150.368 834.075,150.371 834.085,150.374 834.094,150.377 834.103,150.38 834.112,150.383 834.121,150.386 834.13,150.389 834.14,150.392 834.149,150.395 834.158,150.398 834.167,150.401 834.176,150.404 834.186,150.407 834.195,150.41 834.204,150.413 834.213,150.416 834.222,150.419 834.232,150.422 834.241,150.425 834.25,150.428 834.259,150.431 834.268,150.434 834.278,150.437 834.287,150.44 834.296,150.443 834.305,150.446 834.314,150.449 834.323,150.452 834.333,150.455 834.342,150.458 834.351,150.461 834.36,150.464 834.369,150.467 834.379,150.47 834.388,150.473 834.397,150.476 834.406,150.479 834.415,150.482 834.425,150.485 834.434,150.488 834.443,150.491 834.452,150.494 834.461,150.497 834.471,150.5 834.48,150.503 834.489,150.506 834.498,150.509 834.507,150.512 834.516,150.515 834.526,150.518 834.535,150.521 834.544,150.524 834.553,150.527 834.562,150.53 834.572,150.533 834.581,150.536 834.59,150.539 834.599,150.542 834.608,150.545 834.618,150.548 834.627,150.551 834.636,150.554 834.645,150.557 834.654,150.56 834.663,150.563 834.673,150.566 834.682,150.569 834.691,150.572 834.7,150.575 834.709,150.578 834.719,150.581 834.728,150.584 834.737,150.587 834.746,150.59 834.755,150.593 834.765,150.596 834.774,150.599 834.783,150.602 834.792,150.605 834.801,150.608 834.811,150.611 834.82,150.614 834.829,150.617 834.838,150.62 834.847,150.623 834.856,150.626 834.866,150.629 834.875,150.632 834.884,150.635 834.893,150.638 834.902,150.641 834.912,150.644 834.921,150.647 834.93,150.65 834.939,150.653 834.948,150.656 834.958,150.659 834.967,150.662 834.976,150.665 834.985,150.668 834.994,150.671 835.003,150.674 835.013,150.677 835.022,150.68 835.031,150.683 835.04,150.686 835.049,150.689 835.059,150.692 835.068,150.695 835.077,150.698 835.086,150.701 835.095,150.704 835.105,150.707 835.114,150.71 835.123,150.713 835.132,150.716 835.141,150.719 835.151,150.722 835.16,150.725 835.169,150.728 835.178,150.731 835.187,150.734 835.196,150.737 835.206,150.74 835.215,150.743 835.224,150.746 835.233,150.749 835.242,150.751 835.252,150.754 835.261,150.757 835.27,150.76 835.279,150.763 835.288,150.766 835.298,150.769 835.307,150.772 835.316,150.775 835.325,150.778 835.334,150.781 835.343,150.784 835.353,150.787 835.362,150.79 835.371,150.793 835.38,150.796 835.389,150.799 835.399,150.802 835.408,150.805 835.417,150.808 835.426,150.811 835.435,150.814 835.445,150.817 835.454,150.82 835.463,150.823 835.472,150.826 835.481,150.829 835.491,150.832 835.5,150.835 835.509,150.838 835.518,150.841 835.527,150.844 835.536,150.847 835.546,150.85 835.555,150.853 835.564,150.856 835.573,150.859 835.582,150.862 835.592,150.865 835.601,150.868 835.61,150.871 835.619,150.874 835.628,150.877 835.638,150.88 835.647,150.883 835.656,150.886 835.665,150.889 835.674,150.892 835.683,150.895 835.693,150.898 835.702,150.901 835.711,150.904 835.72,150.907 835.729,150.91 835.739,150.913 835.748,150.916 835.757,150.919 835.766,150.922 835.775,150.925 835.785,150.928 835.794,150.931 835.803,150.934 835.812,150.937 835.821,150.94 835.831,150.943 835.84,150.946 835.849,150.949 835.858,150.952 835.867,150.955 835.876,150.958 835.886,150.961 835.895,150.964 835.904,150.967 835.913,150.97 835.922,150.973 835.932,150.976 835.941,150.979 835.95,150.982 835.959,150.985 835.968,150.988 835.978,150.991 835.987,150.994 835.996,150.997 836.005,151 836.014,151.003 836.023,151.006 836.033,151.009 836.042,151.012 836.051,151.015 836.06,151.018 836.069,151.021 836.079,151.024 836.088,151.027 836.097,151.03 836.106,151.033 836.115,151.036 836.125,151.039 836.134,151.042 836.143,151.045 836.152,151.048 836.161,151.051 836.171,151.054 836.18,151.057 836.189,151.06 836.198,151.063 836.207,151.066 836.216,151.069 836.226,151.072 836.235,151.075 836.244,151.078 836.253,151.081 836.262,151.084 836.272,151.087 836.281,151.09 836.29,151.093 836.299,151.096 836.308,151.099 836.318,151.102 836.327,151.105 836.336,151.108 836.345,151.111 836.354,151.114 836.363,151.117 836.373,151.12 836.382,151.123 836.391,151.126 836.4,151.129 836.409,151.132 836.419,151.135 836.428,151.138 836.437,151.141 836.446,151.144 836.455,151.147 836.465,151.15 836.474,151.153 836.483,151.156 836.492,151.159 836.501,151.162 836.511,151.165 836.52,151.168 836.529,151.171 836.538,151.174 836.547,151.177 836.556,151.18 836.566,151.183 836.575,151.186 836.584,151.189 836.593,151.192 836.602,151.195 836.612,151.198 836.621,151.201 836.63,151.204 836.639,151.207 836.648,151.21 836.658,151.213 836.667,151.216 836.676,151.219 836.685,151.222 836.694,151.225 836.703,151.228 836.713,151.231 836.722,151.234 836.731,151.237 836.74,151.24 836.749,151.243 836.759,151.246 836.768,151.249 836.777,151.252 836.786,151.255 836.795,151.258 836.805,151.261 836.814,151.264 836.823,151.267 836.832,151.27 836.841,151.273 836.851,151.276 836.86,151.279 836.869,151.282 836.878,151.285 836.887,151.288 836.896,151.291 836.906,151.294 836.915,151.297 836.924,151.3 836.933,151.303 836.942,151.306 836.952,151.309 836.961,151.312 836.97,151.315 836.979,151.318 836.988,151.321 836.998,151.324 837.007,151.327 837.016,151.33 837.025,151.333 837.034,151.336 837.044,151.339 837.053,151.342 837.062,151.345 837.071,151.348 837.08,151.351 837.089,151.354 837.099,151.357 837.108,151.36 837.117,151.363 837.126,151.366 837.135,151.369 837.145,151.372 837.154,151.375 837.163,151.378 837.172,151.381 837.181,151.384 837.191,151.387 837.2,151.39 837.209,151.393 837.218,151.396 837.227,151.399 837.236,151.402 837.246,151.405 837.255,151.408 837.264,151.411 837.273,151.414 837.282,151.417 837.292,151.42 837.301,151.423 837.31,151.426 837.319,151.429 837.328,151.432 837.338,151.435 837.347,151.437 837.356,151.44 837.365,151.443 837.374,151.446 837.384,151.449 837.393,151.452 837.402,151.455 837.411,151.458 837.42,151.461 837.429,151.464 837.439,151.467 837.448,151.47 837.457,151.473 837.466,151.476 837.475,151.479 837.485,151.482 837.494,151.485 837.503,151.488 837.512,151.491 837.521,151.494 837.531,151.497 837.54,151.5 837.549,151.503 837.558,151.506 837.567,151.509 837.576,151.512 837.586,151.515 837.595,151.518 837.604,151.521 837.613,151.524 837.622,151.527 837.632,151.53 837.641,151.533 837.65,151.536 837.659,151.539 837.668,151.542 837.678,151.545 837.687,151.548 837.696,151.551 837.705,151.554 837.714,151.557 837.724,151.56 837.733,151.563 837.742,151.566 837.751,151.569 837.76,151.572 837.769,151.575 837.779,151.578 837.788,151.581 837.797,151.584 837.806,151.587 837.815,151.59 837.825,151.593 837.834,151.596 837.843,151.599 837.852,151.602 837.861,151.605 837.871,151.608 837.88,151.611 837.889,151.614 837.898,151.617 837.907,151.62 837.916,151.623 837.926,151.626 837.935,151.629 837.944,151.632 837.953,151.635 837.962,151.638 837.972,151.641 837.981,151.644 837.99,151.647 837.999,151.65 838.008,151.653 838.018,151.656 838.027,151.659 838.036,151.662 838.045,151.665 838.054,151.668 838.064,151.671 838.073,151.674 838.082,151.677 838.091,151.68 838.1,151.683 838.109,151.686 838.119,151.689 838.128,151.692 838.137,151.695 838.146,151.698 838.155,151.701 838.165,151.704 838.174,151.707 838.183,151.71 838.192,151.713 838.201,151.716 838.211,151.719 838.22,151.722 838.229,151.725 838.238,151.728 838.247,151.731 838.256,151.734 838.266,151.737 838.275,151.74 838.284,151.743 838.293,151.746 838.302,151.749 838.312,151.752 838.321,151.755 838.33,151.758 838.339,151.761 838.348,151.764 838.358,151.767 838.367,151.77 838.376,151.773 838.385,151.776 838.394,151.779 838.404,151.782 838.413,151.785 838.422,151.788 838.431,151.791 838.44,151.794 838.449,151.797 838.459,151.8 838.468,151.803 838.477,151.806 838.486,151.809 838.495,151.812 838.505,151.815 838.514,151.818 838.523,151.821 838.532,151.824 838.541,151.827 838.551,151.83 838.56,151.833 838.569,151.836 838.578,151.839 838.587,151.842 838.596,151.845 838.606,151.848 838.615,151.851 838.624,151.854 838.633,151.857 838.642,151.86 838.652,151.863 838.661,151.866 838.67,151.869 838.679,151.872 838.688,151.875 838.698,151.878 838.707,151.881 838.716,151.884 838.725,151.887 838.734,151.89 838.744,151.893 838.753,151.896 838.762,151.899 838.771,151.901 838.78,151.904 838.789,151.907 838.799,151.91 838.808,151.913 838.817,151.916 838.826,151.919 838.835,151.922 838.845,151.925 838.854,151.928 838.863,151.931 838.872,151.934 838.881,151.937 838.891,151.94 838.9,151.943 838.909,151.946 838.918,151.949 838.927,151.952 838.936,151.955 838.946,151.958 838.955,151.961 838.964,151.964 838.973,151.967 838.982,151.97 838.992,151.973 839.001,151.976 839.01,151.979 839.019,151.982 839.028,151.985 839.038,151.988 839.047,151.991 839.056,151.994 839.065,151.997 839.074,152 839.084,152.003 839.093,152.006 839.102,152.009 839.111,152.012 839.12,152.015 839.129,152.018 839.139,152.021 839.148,152.024 839.157,152.027 839.166,152.03 839.175,152.033 839.185,152.036 839.194,152.039 839.203,152.042 839.212,152.045 839.221,152.048 839.231,152.051 839.24,152.054 839.249,152.057 839.258,152.06 839.267,152.063 839.277,152.066 839.286,152.069 839.295,152.072 839.304,152.075 839.313,152.078 839.322,152.081 839.332,152.084 839.341,152.087 839.35,152.09 839.359,152.093 839.368,152.096 839.378,152.099 839.387,152.102 839.396,152.105 839.405,152.108 839.414,152.111 839.424,152.114 839.433,152.117 839.442,152.12 839.451,152.123 839.46,152.126 839.469,152.129 839.479,152.132 839.488,152.135 839.497,152.138 839.506,152.141 839.515,152.144 839.525,152.147 839.534,152.15 839.543,152.153 839.552,152.156 839.561,152.159 839.571,152.162 839.58,152.165 839.589,152.168 839.598,152.171 839.607,152.174 839.617,152.177 839.626,152.18 839.635,152.183 839.644,152.186 839.653,152.189 839.662,152.192 839.672,152.195 839.681,152.198 839.69,152.201 839.699,152.204 839.708,152.207 839.718,152.21 839.727,152.213 839.736,152.216 839.745,152.219 839.754,152.222 839.764,152.225 839.773,152.228 839.782,152.231 839.791,152.234 839.8,152.237 839.809,152.24 839.819,152.243 839.828,152.246 839.837,152.249 839.846,152.252 839.855,152.255 839.865,152.258 839.874,152.261 839.883,152.264 839.892,152.267 839.901,152.27 839.911,152.273 839.92,152.275 839.929,152.278 839.938,152.281 839.947,152.284 839.957,152.287 839.966,152.29 839.975,152.293 839.984,152.296 839.993,152.299 840.002,152.302 840.012,152.305 840.021,152.308 840.03,152.311 840.039,152.314 840.048,152.317 840.058,152.32 840.067,152.323 840.076,152.326 840.085,152.329 840.094,152.332 840.104,152.335 840.113,152.338 840.122,152.341 840.131,152.344 840.14,152.347 840.149,152.35 840.159,152.353 840.168,152.356 840.177,152.359 840.186,152.362 840.195,152.365 840.205,152.368 840.214,152.371 840.223,152.374 840.232,152.377 840.241,152.38 840.251,152.383 840.26,152.386 840.269,152.389 840.278,152.392 840.287,152.395 840.297,152.398 840.306,152.401 840.315,152.404 840.324,152.407 840.333,152.41 840.342,152.413 840.352,152.416 840.361,152.419 840.37,152.422 840.379,152.425 840.388,152.428 840.398,152.431 840.407,152.434 840.416,152.437 840.425,152.44 840.434,152.443 840.444,152.446 840.453,152.449 840.462,152.452 840.471,152.455 840.48,152.458 840.489,152.461 840.499,152.464 840.508,152.467 840.517,152.47 840.526,152.473 840.535,152.476 840.545,152.479 840.554,152.482 840.563,152.485 840.572,152.488 840.581,152.491 840.591,152.494 840.6,152.497 840.609,152.5 840.618,152.503 840.627,152.506 840.637,152.509 840.646,152.512 840.655,152.515 840.664,152.518 840.673,152.521 840.682,152.524 840.692,152.527 840.701,152.53 840.71,152.533 840.719,152.536 840.728,152.539 840.738,152.542 840.747,152.545 840.756,152.548 840.765,152.551 840.774,152.554 840.784,152.557 840.793,152.56 840.802,152.563 840.811,152.566 840.82,152.569 840.829,152.572 840.839,152.575 840.848,152.578 840.857,152.581 840.866,152.584 840.875,152.587 840.885,152.59 840.894,152.593 840.903,152.595 840.912,152.598 840.921,152.601 840.931,152.604 840.94,152.607 840.949,152.61 840.958,152.613 840.967,152.616 840.977,152.619 840.986,152.622 840.995,152.625 841.004,152.628 841.013,152.631 841.022,152.634 841.032,152.637 841.041,152.64 841.05,152.643 841.059,152.646 841.068,152.649 841.078,152.652 841.087,152.655 841.096,152.658 841.105,152.661 841.114,152.664 841.124,152.667 841.133,152.67 841.142,152.673 841.151,152.676 841.16,152.679 841.169,152.682 841.179,152.685 841.188,152.688 841.197,152.691 841.206,152.694 841.215,152.697 841.225,152.7 841.234,152.703 841.243,152.706 841.252,152.709 841.261,152.712 841.271,152.715 841.28,152.718 841.289,152.721 841.298,152.724 841.307,152.727 841.317,152.73 841.326,152.733 841.335,152.736 841.344,152.739 841.353,152.742 841.362,152.745 841.372,152.748 841.381,152.751 841.39,152.754 841.399,152.757 841.408,152.76 841.418,152.763 841.427,152.766 841.436,152.769 841.445,152.772 841.454,152.775 841.464,152.778 841.473,152.781 841.482,152.784 841.491,152.787 841.5,152.79 841.509,152.793 841.519,152.796 841.528,152.799 841.537,152.802 841.546,152.805 841.555,152.808 841.565,152.811 841.574,152.814 841.583,152.817 841.592,152.82 841.601,152.823 841.611,152.826 841.62,152.829 841.629,152.832 841.638,152.835 841.647,152.838 841.657,152.841 841.666,152.844 841.675,152.847 841.684,152.85 841.693,152.853 841.702,152.856 841.712,152.859 841.721,152.862 841.73,152.865 841.739,152.868 841.748,152.871 841.758,152.874 841.767,152.877 841.776,152.88 841.785,152.882 841.794,152.885 841.804,152.888 841.813,152.891 841.822,152.894 841.831,152.897 841.84,152.9 841.85,152.903 841.859,152.906 841.868,152.909 841.877,152.912 841.886,152.915 841.895,152.918 841.905,152.921 841.914,152.924 841.923,152.927 841.932,152.93 841.941,152.933 841.951,152.936 841.96,152.939 841.969,152.942 841.978,152.945 841.987,152.948 841.997,152.951 842.006,152.954 842.015,152.957 842.024,152.96 842.033,152.963 842.042,152.966 842.052,152.969 842.061,152.972 842.07,152.975 842.079,152.978 842.088,152.981 842.098,152.984 842.107,152.987 842.116,152.99 842.125,152.993 842.134,152.996 842.144,152.999 842.153,153.002 842.162,153.005 842.171,153.008 842.18,153.011 842.19,153.014 842.199,153.017 842.208,153.02 842.217,153.023 842.226,153.026 842.235,153.029 842.245,153.032 842.254,153.035 842.263,153.038 842.272,153.041 842.281,153.044 842.291,153.047 842.3,153.05 842.309,153.053 842.318,153.056 842.327,153.059 842.337,153.062 842.346,153.065 842.355,153.068 842.364,153.071 842.373,153.074 842.382,153.077 842.392,153.08 842.401,153.083 842.41,153.086 842.419,153.089 842.428,153.092 842.438,153.095 842.447,153.098 842.456,153.101 842.465,153.104 842.474,153.107 842.484,153.11 842.493,153.113 842.502,153.116 842.511,153.119 842.52,153.122 842.53,153.125 842.539,153.128 842.548,153.131 842.557,153.134 842.566,153.137 842.575,153.14 842.585,153.142 842.594,153.145 842.603,153.148 842.612,153.151 842.621,153.154 842.631,153.157 842.64,153.16 842.649,153.163 842.658,153.166 842.667,153.169 842.677,153.172 842.686,153.175 842.695,153.178 842.704,153.181 842.713,153.184 842.722,153.187 842.732,153.19 842.741,153.193 842.75,153.196 842.759,153.199 842.768,153.202 842.778,153.205 842.787,153.208 842.796,153.211 842.805,153.214 842.814,153.217 842.824,153.22 842.833,153.223 842.842,153.226 842.851,153.229 842.86,153.232 842.87,153.235 842.879,153.238 842.888,153.241 842.897,153.244 842.906,153.247 842.915,153.25 842.925,153.253 842.934,153.256 842.943,153.259 842.952,153.262 842.961,153.265 842.971,153.268 842.98,153.271 842.989,153.274 842.998,153.277 843.007,153.28 843.017,153.283 843.026,153.286 843.035,153.289 843.044,153.292 843.053,153.295 843.062,153.298 843.072,153.301 843.081,153.304 843.09,153.307 843.099,153.31 843.108,153.313 843.118,153.316 843.127,153.319 843.136,153.322 843.145,153.325 843.154,153.328 843.164,153.331 843.173,153.334 843.182,153.337 843.191,153.34 843.2,153.343 843.21,153.346 843.219,153.349 843.228,153.352 843.237,153.355 843.246,153.358 843.255,153.361 843.265,153.364 843.274,153.367 843.283,153.37 843.292,153.373 843.301,153.376 843.311,153.379 843.32,153.381 843.329,153.384 843.338,153.387 843.347,153.39 843.357,153.393 843.366,153.396 843.375,153.399 843.384,153.402 843.393,153.405 843.402,153.408 843.412,153.411 843.421,153.414 843.43,153.417 843.439,153.42 843.448,153.423 843.458,153.426 843.467,153.429 843.476,153.432 843.485,153.435 843.494,153.438 843.504,153.441 843.513,153.444 843.522,153.447 843.531,153.45 843.54,153.453 843.55,153.456 843.559,153.459 843.568,153.462 843.577,153.465 843.586,153.468 843.595,153.471 843.605,153.474 843.614,153.477 843.623,153.48 843.632,153.483 843.641,153.486 843.651,153.489 843.66,153.492 843.669,153.495 843.678,153.498 843.687,153.501 843.697,153.504 843.706,153.507 843.715,153.51 843.724,153.513 843.733,153.516 843.742,153.519 843.752,153.522 843.761,153.525 843.77,153.528 843.779,153.531 843.788,153.534 843.798,153.537 843.807,153.54 843.816,153.543 843.825,153.546 843.834,153.549 843.844,153.552 843.853,153.555 843.862,153.558 843.871,153.561 843.88,153.564 843.89,153.567 843.899,153.57 843.908,153.573 843.917,153.576 843.926,153.579 843.935,153.582 843.945,153.585 843.954,153.588 843.963,153.591 843.972,153.594 843.981,153.597 843.991,153.6 844,153.603 844.009,153.605 844.018,153.608 844.027,153.611 844.037,153.614 844.046,153.617 844.055,153.62 844.064,153.623 844.073,153.626 844.082,153.629 844.092,153.632 844.101,153.635 844.11,153.638 844.119,153.641 844.128,153.644 844.138,153.647 844.147,153.65 844.156,153.653 844.165,153.656 844.174,153.659 844.184,153.662 844.193,153.665 844.202,153.668 844.211,153.671 844.22,153.674 844.23,153.677 844.239,153.68 844.248,153.683 844.257,153.686 844.266,153.689 844.275,153.692 844.285,153.695 844.294,153.698 844.303,153.701 844.312,153.704 844.321,153.707 844.331,153.71 844.34,153.713 844.349,153.716 844.358,153.719 844.367,153.722 844.377,153.725 844.386,153.728 844.395,153.731 844.404,153.734 844.413,153.737 844.423,153.74 844.432,153.743 844.441,153.746 844.45,153.749 844.459,153.752 844.468,153.755 844.478,153.758 844.487,153.761 844.496,153.764 844.505,153.767 844.514,153.77 844.524,153.773 844.533,153.776 844.542,153.779 844.551,153.782 844.56,153.785 844.57,153.788 844.579,153.791 844.588,153.794 844.597,153.797 844.606,153.8 844.615,153.803 844.625,153.806 844.634,153.809 844.643,153.812 844.652,153.815 844.661,153.817 844.671,153.82 844.68,153.823 844.689,153.826 844.698,153.829 844.707,153.832 844.717,153.835 844.726,153.838 844.735,153.841 844.744,153.844 844.753,153.847 844.763,153.85 844.772,153.853 844.781,153.856 844.79,153.859 844.799,153.862 844.808,153.865 844.818,153.868 844.827,153.871 844.836,153.874 844.845,153.877 844.854,153.88 844.864,153.883 844.873,153.886 844.882,153.889 844.891,153.892 844.9,153.895 844.91,153.898 844.919,153.901 844.928,153.904 844.937,153.907 844.946,153.91 844.955,153.913 844.965,153.916 844.974,153.919 844.983,153.922 844.992,153.925 845.001,153.928 845.011,153.931 845.02,153.934 845.029,153.937 845.038,153.94 845.047,153.943 845.057,153.946 845.066,153.949 845.075,153.952 845.084,153.955 845.093,153.958 845.103,153.961 845.112,153.964 845.121,153.967 845.13,153.97 845.139,153.973 845.148,153.976 845.158,153.979 845.167,153.982 845.176,153.985 845.185,153.988 845.194,153.991 845.204,153.994 845.213,153.997 845.222,154 845.231,154.003 845.24,154.006 845.25,154.009 845.259,154.012 845.268,154.015 845.277,154.017 845.286,154.02 845.295,154.023 845.305,154.026 845.314,154.029 845.323,154.032 845.332,154.035 845.341,154.038 845.351,154.041 845.36,154.044 845.369,154.047 845.378,154.05 845.387,154.053 845.397,154.056 845.406,154.059 845.415,154.062 845.424,154.065 845.433,154.068 845.443,154.071 845.452,154.074 845.461,154.077 845.47,154.08 845.479,154.083 845.488,154.086 845.498,154.089 845.507,154.092 845.516,154.095 845.525,154.098 845.534,154.101 845.544,154.104 845.553,154.107 845.562,154.11 845.571,154.113 845.58,154.116 845.59,154.119 845.599,154.122 845.608,154.125 845.617,154.128 845.626,154.131 845.635,154.134 845.645,154.137 845.654,154.14 845.663,154.143 845.672,154.146 845.681,154.149 845.691,154.152 845.7,154.155 845.709,154.158 845.718,154.161 845.727,154.164 845.737,154.167 845.746,154.17 845.755,154.173 845.764,154.176 845.773,154.179 845.783,154.182 845.792,154.185 845.801,154.188 845.81,154.191 845.819,154.194 845.828,154.197 845.838,154.2 845.847,154.203 845.856,154.206 845.865,154.208 845.874,154.211 845.884,154.214 845.893,154.217 845.902,154.22 845.911,154.223 845.92,154.226 845.93,154.229 845.939,154.232 845.948,154.235 845.957,154.238 845.966,154.241 845.975,154.244 845.985,154.247 845.994,154.25 846.003,154.253 846.012,154.256 846.021,154.259 846.031,154.262 846.04,154.265 846.049,154.268 846.058,154.271 846.067,154.274 846.077,154.277 846.086,154.28 846.095,154.283 846.104,154.286 846.113,154.289 846.123,154.292 846.132,154.295 846.141,154.298 846.15,154.301 846.159,154.304 846.168,154.307 846.178,154.31 846.187,154.313 846.196,154.316 846.205,154.319 846.214,154.322 846.224,154.325 846.233,154.328 846.242,154.331 846.251,154.334 846.26,154.337 846.27,154.34 846.279,154.343 846.288,154.346 846.297,154.349 846.306,154.352 846.315,154.355 846.325,154.358 846.334,154.361 846.343,154.364 846.352,154.367 846.361,154.37 846.371,154.373 846.38,154.376 846.389,154.379 846.398,154.382 846.407,154.385 846.417,154.387 846.426,154.39 846.435,154.393 846.444,154.396 846.453,154.399 846.463,154.402 846.472,154.405 846.481,154.408 846.49,154.411 846.499,154.414 846.508,154.417 846.518,154.42 846.527,154.423 846.536,154.426 846.545,154.429 846.554,154.432 846.564,154.435 846.573,154.438 846.582,154.441 846.591,154.444 846.6,154.447 846.61,154.45 846.619,154.453 846.628,154.456 846.637,154.459 846.646,154.462 846.656,154.465 846.665,154.468 846.674,154.471 846.683,154.474 846.692,154.477 846.701,154.48 846.711,154.483 846.72,154.486 846.729,154.489 846.738,154.492 846.747,154.495 846.757,154.498 846.766,154.501 846.775,154.504 846.784,154.507 846.793,154.51 846.803,154.513 846.812,154.516 846.821,154.519 846.83,154.522 846.839,154.525 846.848,154.528 846.858,154.531 846.867,154.534 846.876,154.537 846.885,154.54 846.894,154.543 846.904,154.546 846.913,154.549 846.922,154.552 846.931,154.555 846.94,154.558 846.95,154.561 846.959,154.563 846.968,154.566 846.977,154.569 846.986,154.572 846.996,154.575 847.005,154.578 847.014,154.581 847.023,154.584 847.032,154.587 847.041,154.59 847.051,154.593 847.06,154.596 847.069,154.599 847.078,154.602 847.087,154.605 847.097,154.608 847.106,154.611 847.115,154.614 847.124,154.617 847.133,154.62 847.143,154.623 847.152,154.626 847.161,154.629 847.17,154.632 847.179,154.635 847.188,154.638 847.198,154.641 847.207,154.644 847.216,154.647 847.225,154.65 847.234,154.653 847.244,154.656 847.253,154.659 847.262,154.662 847.271,154.665 847.28,154.668 847.29,154.671 847.299,154.674 847.308,154.677 847.317,154.68 847.326,154.683 847.336,154.686 847.345,154.689 847.354,154.692 847.363,154.695 847.372,154.698 847.381,154.701 847.391,154.704 847.4,154.707 847.409,154.71 847.418,154.713 847.427,154.716 847.437,154.719 847.446,154.722 847.455,154.725 847.464,154.728 847.473,154.73 847.483,154.733 847.492,154.736 847.501,154.739 847.51,154.742 847.519,154.745 847.528,154.748 847.538,154.751 847.547,154.754 847.556,154.757 847.565,154.76 847.574,154.763 847.584,154.766 847.593,154.769 847.602,154.772 847.611,154.775 847.62,154.778 847.63,154.781 847.639,154.784 847.648,154.787 847.657,154.79 847.666,154.793 847.676,154.796 847.685,154.799 847.694,154.802 847.703,154.805 847.712,154.808 847.721,154.811 847.731,154.814 847.74,154.817 847.749,154.82 847.758,154.823 847.767,154.826 847.777,154.829 847.786,154.832 847.795,154.835 847.804,154.838 847.813,154.841 847.823,154.844 847.832,154.847 847.841,154.85 847.85,154.853 847.859,154.856 847.868,154.859 847.878,154.862 847.887,154.865 847.896,154.868 847.905,154.871 847.914,154.874 847.924,154.877 847.933,154.88 847.942,154.883 847.951,154.886 847.96,154.889 847.97,154.891 847.979,154.894 847.988,154.897 847.997,154.9 848.006,154.903 848.016,154.906 848.025,154.909 848.034,154.912 848.043,154.915 848.052,154.918 848.061,154.921 848.071,154.924 848.08,154.927 848.089,154.93 848.098,154.933 848.107,154.936 848.117,154.939 848.126,154.942 848.135,154.945 848.144,154.948 848.153,154.951 848.163,154.954 848.172,154.957 848.181,154.96 848.19,154.963 848.199,154.966 848.208,154.969 848.218,154.972 848.227,154.975 848.236,154.978 848.245,154.981 848.254,154.984 848.264,154.987 848.273,154.99 848.282,154.993 848.291,154.996 848.3,154.999 848.31,155.002 848.319,155.005 848.328,155.008 848.337,155.011 848.346,155.014 848.356,155.017 848.365,155.02 848.374,155.023 848.383,155.026 848.392,155.029 848.401,155.032 848.411,155.035 848.42,155.038 848.429,155.041 848.438,155.044 848.447,155.047 848.457,155.049 848.466,155.052 848.475,155.055 848.484,155.058 848.493,155.061 848.503,155.064 848.512,155.067 848.521,155.07 848.53,155.073 848.539,155.076 848.548,155.079 848.558,155.082 848.567,155.085 848.576,155.088 848.585,155.091 848.594,155.094 848.604,155.097 848.613,155.1 848.622,155.103 848.631,155.106 848.64,155.109 848.65,155.112 848.659,155.115 848.668,155.118 848.677,155.121 848.686,155.124 848.696,155.127 848.705,155.13 848.714,155.133 848.723,155.136 848.732,155.139 848.741,155.142 848.751,155.145 848.76,155.148 848.769,155.151 848.778,155.154 848.787,155.157 848.797,155.16 848.806,155.163 848.815,155.166 848.824,155.169 848.833,155.172 848.843,155.175 848.852,155.178 848.861,155.181 848.87,155.184 848.879,155.187 848.888,155.19 848.898,155.193 848.907,155.196 848.916,155.198 848.925,155.201 848.934,155.204 848.944,155.207 848.953,155.21 848.962,155.213 848.971,155.216 848.98,155.219 848.99,155.222 848.999,155.225 849.008,155.228 849.017,155.231 849.026,155.234 849.036,155.237 849.045,155.24 849.054,155.243 849.063,155.246 849.072,155.249 849.081,155.252 849.091,155.255 849.1,155.258 849.109,155.261 849.118,155.264 849.127,155.267 849.137,155.27 849.146,155.273 849.155,155.276 849.164,155.279 849.173,155.282 849.183,155.285 849.192,155.288 849.201,155.291 849.21,155.294 849.219,155.297 849.229,155.3 849.238,155.303 849.247,155.306 849.256,155.309 849.265,155.312 849.274,155.315 849.284,155.318 849.293,155.321 849.302,155.324 849.311,155.327 849.32,155.33 849.33,155.333 849.339,155.336 849.348,155.339 849.357,155.342 849.366,155.345 849.376,155.347 849.385,155.35 849.394,155.353 849.403,155.356 849.412,155.359 849.421,155.362 849.431,155.365 849.44,155.368 849.449,155.371 849.458,155.374 849.467,155.377 849.477,155.38 849.486,155.383 849.495,155.386 849.504,155.389 849.513,155.392 849.523,155.395 849.532,155.398 849.541,155.401 849.55,155.404 849.559,155.407 849.569,155.41 849.578,155.413 849.587,155.416 849.596,155.419 849.605,155.422 849.614,155.425 849.624,155.428 849.633,155.431 849.642,155.434 849.651,155.437 849.66,155.44 849.67,155.443 849.679,155.446 849.688,155.449 849.697,155.452 849.706,155.455 849.716,155.458 849.725,155.461 849.734,155.464 849.743,155.467 849.752,155.47 849.761,155.473 849.771,155.476 849.78,155.479 849.789,155.482 849.798,155.485 849.807,155.487 849.817,155.49 849.826,155.493 849.835,155.496 849.844,155.499 849.853,155.502 849.863,155.505 849.872,155.508 849.881,155.511 849.89,155.514 849.899,155.517 849.909,155.52 849.918,155.523 849.927,155.526 849.936,155.529 849.945,155.532 849.954,155.535 849.964,155.538 849.973,155.541 849.982,155.544 849.991,155.547 850,155.55 850.01,155.553 850.019,155.556 850.028,155.559 850.037,155.562 850.046,155.565 850.056,155.568 850.065,155.571 850.074,155.574 850.083,155.577 850.092,155.58 850.101,155.583 850.111,155.586 850.12,155.589 850.129,155.592 850.138,155.595 850.147,155.598 850.157,155.601 850.166,155.604 850.175,155.607 850.184,155.61 850.193,155.613 850.203,155.616 850.212,155.619 850.221,155.622 850.23,155.625 850.239,155.627 850.249,155.63 850.258,155.633 850.267,155.636 850.276,155.639 850.285,155.642 850.294,155.645 850.304,155.648 850.313,155.651 850.322,155.654 850.331,155.657 850.34,155.66 850.35,155.663 850.359,155.666 850.368,155.669 850.377,155.672 850.386,155.675 850.396,155.678 850.405,155.681 850.414,155.684 850.423,155.687 850.432,155.69 850.441,155.693 850.451,155.696 850.46,155.699 850.469,155.702 850.478,155.705 850.487,155.708 850.497,155.711 850.506,155.714 850.515,155.717 850.524,155.72 850.533,155.723 850.543,155.726 850.552,155.729 850.561,155.732 850.57,155.735 850.579,155.738 850.589,155.741 850.598,155.744 850.607,155.747 850.616,155.75 850.625,155.753 850.634,155.756 850.644,155.759 850.653,155.761 850.662,155.764 850.671,155.767 850.68,155.77 850.69,155.773 850.699,155.776 850.708,155.779 850.717,155.782 850.726,155.785 850.736,155.788 850.745,155.791 850.754,155.794 850.763,155.797 850.772,155.8 850.781,155.803 850.791,155.806 850.8,155.809 850.809,155.812 850.818,155.815 850.827,155.818 850.837,155.821 850.846,155.824 850.855,155.827 850.864,155.83 850.873,155.833 850.883,155.836 850.892,155.839 850.901,155.842 850.91,155.845 850.919,155.848 850.929,155.851 850.938,155.854 850.947,155.857 850.956,155.86 850.965,155.863 850.974,155.866 850.984,155.869 850.993,155.872 851.002,155.875 851.011,155.878 851.02,155.881 851.03,155.884 851.039,155.887 851.048,155.89 851.057,155.893 851.066,155.895 851.076,155.898 851.085,155.901 851.094,155.904 851.103,155.907 851.112,155.91 851.121,155.913 851.131,155.916 851.14,155.919 851.149,155.922 851.158,155.925 851.167,155.928 851.177,155.931 851.186,155.934 851.195,155.937 851.204,155.94 851.213,155.943 851.223,155.946 851.232,155.949 851.241,155.952 851.25,155.955 851.259,155.958 851.269,155.961 851.278,155.964 851.287,155.967 851.296,155.97 851.305,155.973 851.314,155.976 851.324,155.979 851.333,155.982 851.342,155.985 851.351,155.988 851.36,155.991 851.37,155.994 851.379,155.997 851.388,156 851.397,156.003 851.406,156.006 851.416,156.009 851.425,156.012 851.434,156.015 851.443,156.018 851.452,156.021 851.461,156.023 851.471,156.026 851.48,156.029 851.489,156.032 851.498,156.035 851.507,156.038 851.517,156.041 851.526,156.044 851.535,156.047 851.544,156.05 851.553,156.053 851.563,156.056 851.572,156.059 851.581,156.062 851.59,156.065 851.599,156.068 851.609,156.071 851.618,156.074 851.627,156.077 851.636,156.08 851.645,156.083 851.654,156.086 851.664,156.089 851.673,156.092 851.682,156.095 851.691,156.098 851.7,156.101 851.71,156.104 851.719,156.107 851.728,156.11 851.737,156.113 851.746,156.116 851.756,156.119 851.765,156.122 851.774,156.125 851.783,156.128 851.792,156.131 851.802,156.134 851.811,156.137 851.82,156.14 851.829,156.143 851.838,156.146 851.847,156.148 851.857,156.151 851.866,156.154 851.875,156.157 851.884,156.16 851.893,156.163 851.903,156.166 851.912,156.169 851.921,156.172 851.93,156.175 851.939,156.178 851.949,156.181 851.958,156.184 851.967,156.187 851.976,156.19 851.985,156.193 851.994,156.196 852.004,156.199 852.013,156.202 852.022,156.205 852.031,156.208 852.04,156.211 852.05,156.214 852.059,156.217 852.068,156.22 852.077,156.223 852.086,156.226 852.096,156.229 852.105,156.232 852.114,156.235 852.123,156.238 852.132,156.241 852.142,156.244 852.151,156.247 852.16,156.25 852.169,156.253 852.178,156.256 852.187,156.259 852.197,156.262 852.206,156.265 852.215,156.268 852.224,156.271 852.233,156.273 852.243,156.276 852.252,156.279 852.261,156.282 852.27,156.285 852.279,156.288 852.289,156.291 852.298,156.294 852.307,156.297 852.316,156.3 852.325,156.303 852.334,156.306 852.344,156.309 852.353,156.312 852.362,156.315 852.371,156.318 852.38,156.321 852.39,156.324 852.399,156.327 852.408,156.33 852.417,156.333 852.426,156.336 852.436,156.339 852.445,156.342 852.454,156.345 852.463,156.348 852.472,156.351 852.482,156.354 852.491,156.357 852.5,156.36 852.509,156.363 852.518,156.366 852.527,156.369 852.537,156.372 852.546,156.375 852.555,156.378 852.564,156.381 852.573,156.384 852.583,156.387 852.592,156.39 852.601,156.393 852.61,156.395 852.619,156.398 852.629,156.401 852.638,156.404 852.647,156.407 852.656,156.41 852.665,156.413 852.674,156.416 852.684,156.419 852.693,156.422 852.702,156.425 852.711,156.428 852.72,156.431 852.73,156.434 852.739,156.437 852.748,156.44 852.757,156.443 852.766,156.446 852.776,156.449 852.785,156.452 852.794,156.455 852.803,156.458 852.812,156.461 852.822,156.464 852.831,156.467 852.84,156.47 852.849,156.473 852.858,156.476 852.867,156.479 852.877,156.482 852.886,156.485 852.895,156.488 852.904,156.491 852.913,156.494 852.923,156.497 852.932,156.5 852.941,156.503 852.95,156.506 852.959,156.509 852.969,156.511 852.978,156.514 852.987,156.517 852.996,156.52 853.005,156.523 853.014,156.526 853.024,156.529 853.033,156.532 853.042,156.535 853.051,156.538 853.06,156.541 853.07,156.544 853.079,156.547 853.088,156.55 853.097,156.553 853.106,156.556 853.116,156.559 853.125,156.562 853.134,156.565 853.143,156.568 853.152,156.571 853.162,156.574 853.171,156.577 853.18,156.58 853.189,156.583 853.198,156.586 853.207,156.589 853.217,156.592 853.226,156.595 853.235,156.598 853.244,156.601 853.253,156.604 853.263,156.607 853.272,156.61 853.281,156.613 853.29,156.616 853.299,156.619 853.309,156.622 853.318,156.625 853.327,156.627 853.336,156.63 853.345,156.633 853.354,156.636 853.364,156.639 853.373,156.642 853.382,156.645 853.391,156.648 853.4,156.651 853.41,156.654 853.419,156.657 853.428,156.66 853.437,156.663 853.446,156.666 853.456,156.669 853.465,156.672 853.474,156.675 853.483,156.678 853.492,156.681 853.502,156.684 853.511,156.687 853.52,156.69 853.529,156.693 853.538,156.696 853.547,156.699 853.557,156.702 853.566,156.705 853.575,156.708 853.584,156.711 853.593,156.714 853.603,156.717 853.612,156.72 853.621,156.723 853.63,156.726 853.639,156.729 853.649,156.732 853.658,156.735 853.667,156.738 853.676,156.741 853.685,156.743 853.694,156.746 853.704,156.749 853.713,156.752 853.722,156.755 853.731,156.758 853.74,156.761 853.75,156.764 853.759,156.767 853.768,156.77 853.777,156.773 853.786,156.776 853.796,156.779 853.805,156.782 853.814,156.785 853.823,156.788 853.832,156.791 853.842,156.794 853.851,156.797 853.86,156.8 853.869,156.803 853.878,156.806 853.887,156.809 853.897,156.812 853.906,156.815 853.915,156.818 853.924,156.821 853.933,156.824 853.943,156.827 853.952,156.83 853.961,156.833 853.97,156.836 853.979,156.839 853.989,156.842 853.998,156.845 854.007,156.848 854.016,156.851 854.025,156.853 854.035,156.856 854.044,156.859 854.053,156.862 854.062,156.865 854.071,156.868 854.08,156.871 854.09,156.874 854.099,156.877 854.108,156.88 854.117,156.883 854.126,156.886 854.136,156.889 854.145,156.892 854.154,156.895 854.163,156.898 854.172,156.901 854.182,156.904 854.191,156.907 854.2,156.91 854.209,156.913 854.218,156.916 854.227,156.919 854.237,156.922 854.246,156.925 854.255,156.928 854.264,156.931 854.273,156.934 854.283,156.937 854.292,156.94 854.301,156.943 854.31,156.946 854.319,156.949 854.329,156.952 854.338,156.955 854.347,156.958 854.356,156.961 854.365,156.963 854.375,156.966 854.384,156.969 854.393,156.972 854.402,156.975 854.411,156.978 854.42,156.981 854.43,156.984 854.439,156.987 854.448,156.99 854.457,156.993 854.466,156.996 854.476,156.999 854.485,157.002 854.494,157.005 854.503,157.008 854.512,157.011 854.522,157.014 854.531,157.017 854.54,157.02 854.549,157.023 854.558,157.026 854.567,157.029 854.577,157.032 854.586,157.035 854.595,157.038 854.604,157.041 854.613,157.044 854.623,157.047 854.632,157.05 854.641,157.053 854.65,157.056 854.659,157.059 854.669,157.062 854.678,157.065 854.687,157.068 854.696,157.071 854.705,157.073 854.715,157.076 854.724,157.079 854.733,157.082 854.742,157.085 854.751,157.088 854.76,157.091 854.77,157.094 854.779,157.097 854.788,157.1 854.797,157.103 854.806,157.106 854.816,157.109 854.825,157.112 854.834,157.115 854.843,157.118 854.852,157.121 854.862,157.124 854.871,157.127 854.88,157.13 854.889,157.133 854.898,157.136 854.907,157.139 854.917,157.142 854.926,157.145 854.935,157.148 854.944,157.151 854.953,157.154 854.963,157.157 854.972,157.16 854.981,157.163 854.99,157.166 854.999,157.169 855.009,157.172 855.018,157.175 855.027,157.178 855.036,157.18 855.045,157.183 855.055,157.186 855.064,157.189 855.073,157.192 855.082,157.195 855.091,157.198 855.1,157.201 855.11,157.204 855.119,157.207 855.128,157.21 855.137,157.213 855.146,157.216 855.156,157.219 855.165,157.222 855.174,157.225 855.183,157.228 855.192,157.231 855.202,157.234 855.211,157.237 855.22,157.24 855.229,157.243 855.238,157.246 855.247,157.249 855.257,157.252 855.266,157.255 855.275,157.258 855.284,157.261 855.293,157.264 855.303,157.267 855.312,157.27 855.321,157.273 855.33,157.276 855.339,157.279 855.349,157.282 855.358,157.284 855.367,157.287 855.376,157.29 855.385,157.293 855.395,157.296 855.404,157.299 855.413,157.302 855.422,157.305 855.431,157.308 855.44,157.311 855.45,157.314 855.459,157.317 855.468,157.32 855.477,157.323 855.486,157.326 855.496,157.329 855.505,157.332 855.514,157.335 855.523,157.338 855.532,157.341 855.542,157.344 855.551,157.347 855.56,157.35 855.569,157.353 855.578,157.356 855.587,157.359 855.597,157.362 855.606,157.365 855.615,157.368 855.624,157.371 855.633,157.374 855.643,157.377 855.652,157.38 855.661,157.383 855.67,157.386 855.679,157.388 855.689,157.391 855.698,157.394 855.707,157.397 855.716,157.4 855.725,157.403 855.735,157.406 855.744,157.409 855.753,157.412 855.762,157.415 855.771,157.418 855.78,157.421 855.79,157.424 855.799,157.427 855.808,157.43 855.817,157.433 855.826,157.436 855.836,157.439 855.845,157.442 855.854,157.445 855.863,157.448 855.872,157.451 855.882,157.454 855.891,157.457 855.9,157.46 855.909,157.463 855.918,157.466 855.927,157.469 855.937,157.472 855.946,157.475 855.955,157.478 855.964,157.481 855.973,157.484 855.983,157.487 855.992,157.489 856.001,157.492 856.01,157.495 856.019,157.498 856.029,157.501 856.038,157.504 856.047,157.507 856.056,157.51 856.065,157.513 856.075,157.516 856.084,157.519 856.093,157.522 856.102,157.525 856.111,157.528 856.12,157.531 856.13,157.534 856.139,157.537 856.148,157.54 856.157,157.543 856.166,157.546 856.176,157.549 856.185,157.552 856.194,157.555 856.203,157.558 856.212,157.561 856.222,157.564 856.231,157.567 856.24,157.57 856.249,157.573 856.258,157.576 856.267,157.579 856.277,157.582 856.286,157.585 856.295,157.588 856.304,157.59 856.313,157.593 856.323,157.596 856.332,157.599 856.341,157.602 856.35,157.605 856.359,157.608 856.369,157.611 856.378,157.614 856.387,157.617 856.396,157.62 856.405,157.623 856.415,157.626 856.424,157.629 856.433,157.632 856.442,157.635 856.451,157.638 856.46,157.641 856.47,157.644 856.479,157.647 856.488,157.65 856.497,157.653 856.506,157.656 856.516,157.659 856.525,157.662 856.534,157.665 856.543,157.668 856.552,157.671 856.562,157.674 856.571,157.677 856.58,157.68 856.589,157.683 856.598,157.686 856.608,157.688 856.617,157.691 856.626,157.694 856.635,157.697 856.644,157.7 856.653,157.703 856.663,157.706 856.672,157.709 856.681,157.712 856.69,157.715 856.699,157.718 856.709,157.721 856.718,157.724 856.727,157.727 856.736,157.73 856.745,157.733 856.755,157.736 856.764,157.739 856.773,157.742 856.782,157.745 856.791,157.748 856.8,157.751 856.81,157.754 856.819,157.757 856.828,157.76 856.837,157.763 856.846,157.766 856.856,157.769 856.865,157.772 856.874,157.775 856.883,157.778 856.892,157.781 856.902,157.784 856.911,157.786 856.92,157.789 856.929,157.792 856.938,157.795 856.948,157.798 856.957,157.801 856.966,157.804 856.975,157.807 856.984,157.81 856.993,157.813 857.003,157.816 857.012,157.819 857.021,157.822 857.03,157.825 857.039,157.828 857.049,157.831 857.058,157.834 857.067,157.837 857.076,157.84 857.085,157.843 857.095,157.846 857.104,157.849 857.113,157.852 857.122,157.855 857.131,157.858 857.14,157.861 857.15,157.864 857.159,157.867 857.168,157.87 857.177,157.873 857.186,157.876 857.196,157.879 857.205,157.881 857.214,157.884 857.223,157.887 857.232,157.89 857.242,157.893 857.251,157.896 857.26,157.899 857.269,157.902 857.278,157.905 857.288,157.908 857.297,157.911 857.306,157.914 857.315,157.917 857.324,157.92 857.333,157.923 857.343,157.926 857.352,157.929 857.361,157.932 857.37,157.935 857.379,157.938 857.389,157.941 857.398,157.944 857.407,157.947 857.416,157.95 857.425,157.953 857.435,157.956 857.444,157.959 857.453,157.962 857.462,157.965 857.471,157.968 857.48,157.971 857.49,157.974 857.499,157.976 857.508,157.979 857.517,157.982 857.526,157.985 857.536,157.988 857.545,157.991 857.554,157.994 857.563,157.997 857.572,158 857.582,158.003 857.591,158.006 857.6,158.009 857.609,158.012 857.618,158.015 857.628,158.018 857.637,158.021 857.646,158.024 857.655,158.027 857.664,158.03 857.673,158.033 857.683,158.036 857.692,158.039 857.701,158.042 857.71,158.045 857.719,158.048 857.729,158.051 857.738,158.054 857.747,158.057 857.756,158.06 857.765,158.063 857.775,158.066 857.784,158.068 857.793,158.071 857.802,158.074 857.811,158.077 857.82,158.08 857.83,158.083 857.839,158.086 857.848,158.089 857.857,158.092 857.866,158.095 857.876,158.098 857.885,158.101 857.894,158.104 857.903,158.107 857.912,158.11 857.922,158.113 857.931,158.116 857.94,158.119 857.949,158.122 857.958,158.125 857.968,158.128 857.977,158.131 857.986,158.134 857.995,158.137 858.004,158.14 858.013,158.143 858.023,158.146 858.032,158.149 858.041,158.152 858.05,158.155 858.059,158.158 858.069,158.161 858.078,158.163 858.087,158.166 858.096,158.169 858.105,158.172 858.115,158.175 858.124,158.178 858.133,158.181 858.142,158.184 858.151,158.187 858.16,158.19 858.17,158.193 858.179,158.196 858.188,158.199 858.197,158.202 858.206,158.205 858.216,158.208 858.225,158.211 858.234,158.214 858.243,158.217 858.252,158.22 858.262,158.223 858.271,158.226 858.28,158.229 858.289,158.232 858.298,158.235 858.308,158.238 858.317,158.241 858.326,158.244 858.335,158.247 858.344,158.25 858.353,158.252 858.363,158.255 858.372,158.258 858.381,158.261 858.39,158.264 858.399,158.267 858.409,158.27 858.418,158.273 858.427,158.276 858.436,158.279 858.445,158.282 858.455,158.285 858.464,158.288 858.473,158.291 858.482,158.294 858.491,158.297 858.5,158.3 858.51,158.303 858.519,158.306 858.528,158.309 858.537,158.312 858.546,158.315 858.556,158.318 858.565,158.321 858.574,158.324 858.583,158.327 858.592,158.33 858.602,158.333 858.611,158.336 858.62,158.339 858.629,158.342 858.638,158.344 858.648,158.347 858.657,158.35 858.666,158.353 858.675,158.356 858.684,158.359 858.693,158.362 858.703,158.365 858.712,158.368 858.721,158.371 858.73,158.374 858.739,158.377 858.749,158.38 858.758,158.383 858.767,158.386 858.776,158.389 858.785,158.392 858.795,158.395 858.804,158.398 858.813,158.401 858.822,158.404 858.831,158.407 858.84,158.41 858.85,158.413 858.859,158.416 858.868,158.419 858.877,158.422 858.886,158.425 858.896,158.428 858.905,158.431 858.914,158.433 858.923,158.436 858.932,158.439 858.942,158.442 858.951,158.445 858.96,158.448 858.969,158.451 858.978,158.454 858.988,158.457 858.997,158.46 859.006,158.463 859.015,158.466 859.024,158.469 859.033,158.472 859.043,158.475 859.052,158.478 859.061,158.481 859.07,158.484 859.079,158.487 859.089,158.49 859.098,158.493 859.107,158.496 859.116,158.499 859.125,158.502 859.135,158.505 859.144,158.508 859.153,158.511 859.162,158.514 859.171,158.517 859.181,158.519 859.19,158.522 859.199,158.525 859.208,158.528 859.217,158.531 859.226,158.534 859.236,158.537 859.245,158.54 859.254,158.543 859.263,158.546 859.272,158.549 859.282,158.552 859.291,158.555 859.3,158.558 859.309,158.561 859.318,158.564 859.328,158.567 859.337,158.57 859.346,158.573 859.355,158.576 859.364,158.579 859.373,158.582 859.383,158.585 859.392,158.588 859.401,158.591 859.41,158.594 859.419,158.597 859.429,158.6 859.438,158.603 859.447,158.606 859.456,158.608 859.465,158.611 859.475,158.614 859.484,158.617 859.493,158.62 859.502,158.623 859.511,158.626 859.521,158.629 859.53,158.632 859.539,158.635 859.548,158.638 859.557,158.641 859.566,158.644 859.576,158.647 859.585,158.65 859.594,158.653 859.603,158.656 859.612,158.659 859.622,158.662 859.631,158.665 859.64,158.668 859.649,158.671 859.658,158.674 859.668,158.677 859.677,158.68 859.686,158.683 859.695,158.686 859.704,158.689 859.713,158.692 859.723,158.694 859.732,158.697 859.741,158.7 859.75,158.703 859.759,158.706 859.769,158.709 859.778,158.712 859.787,158.715 859.796,158.718 859.805,158.721 859.815,158.724 859.824,158.727 859.833,158.73 859.842,158.733 859.851,158.736 859.861,158.739 859.87,158.742 859.879,158.745 859.888,158.748 859.897,158.751 859.906,158.754 859.916,158.757 859.925,158.76 859.934,158.763 859.943,158.766 859.952,158.769 859.962,158.772 859.971,158.775 859.98,158.778 859.989,158.78 859.998,158.783 860.008,158.786 860.017,158.789 860.026,158.792 860.035,158.795 860.044,158.798 860.053,158.801 860.063,158.804 860.072,158.807 860.081,158.81 860.09,158.813 860.099,158.816 860.109,158.819 860.118,158.822 860.127,158.825 860.136,158.828 860.145,158.831 860.155,158.834 860.164,158.837 860.173,158.84 860.182,158.843 860.191,158.846 860.201,158.849 860.21,158.852 860.219,158.855 860.228,158.858 860.237,158.861 860.246,158.863 860.256,158.866 860.265,158.869 860.274,158.872 860.283,158.875 860.292,158.878 860.302,158.881 860.311,158.884 860.32,158.887 860.329,158.89 860.338,158.893 860.348,158.896 860.357,158.899 860.366,158.902 860.375,158.905 860.384,158.908 860.393,158.911 860.403,158.914 860.412,158.917 860.421,158.92 860.43,158.923 860.439,158.926 860.449,158.929 860.458,158.932 860.467,158.935 860.476,158.938 860.485,158.941 860.495,158.944 860.504,158.946 860.513,158.949 860.522,158.952 860.531,158.955 860.541,158.958 860.55,158.961 860.559,158.964 860.568,158.967 860.577,158.97 860.586,158.973 860.596,158.976 860.605,158.979 860.614,158.982 860.623,158.985 860.632,158.988 860.642,158.991 860.651,158.994 860.66,158.997 860.669,159 860.678,159.003 860.688,159.006 860.697,159.009 860.706,159.012 860.715,159.015 860.724,159.018 860.733,159.021 860.743,159.024 860.752,159.027 860.761,159.029 860.77,159.032 860.779,159.035 860.789,159.038 860.798,159.041 860.807,159.044 860.816,159.047 860.825,159.05 860.835,159.053 860.844,159.056 860.853,159.059 860.862,159.062 860.871,159.065 860.881,159.068 860.89,159.071 860.899,159.074 860.908,159.077 860.917,159.08 860.926,159.083 860.936,159.086 860.945,159.089 860.954,159.092 860.963,159.095 860.972,159.098 860.982,159.101 860.991,159.104 861,159.107 861.009,159.11 861.018,159.112 861.028,159.115 861.037,159.118 861.046,159.121 861.055,159.124 861.064,159.127 861.073,159.13 861.083,159.133 861.092,159.136 861.101,159.139 861.11,159.142 861.119,159.145 861.129,159.148 861.138,159.151 861.147,159.154 861.156,159.157 861.165,159.16 861.175,159.163 861.184,159.166 861.193,159.169 861.202,159.172 861.211,159.175 861.221,159.178 861.23,159.181 861.239,159.184 861.248,159.187 861.257,159.19 861.266,159.192 861.276,159.195 861.285,159.198 861.294,159.201 861.303,159.204 861.312,159.207 861.322,159.21 861.331,159.213 861.34,159.216 861.349,159.219 861.358,159.222 861.368,159.225 861.377,159.228 861.386,159.231 861.395,159.234 861.404,159.237 861.414,159.24 861.423,159.243 861.432,159.246 861.441,159.249 861.45,159.252 861.459,159.255 861.469,159.258 861.478,159.261 861.487,159.264 861.496,159.267 861.505,159.27 861.515,159.272 861.524,159.275 861.533,159.278 861.542,159.281 861.551,159.284 861.561,159.287 861.57,159.29 861.579,159.293 861.588,159.296 861.597,159.299 861.606,159.302 861.616,159.305 861.625,159.308 861.634,159.311 861.643,159.314 861.652,159.317 861.662,159.32 861.671,159.323 861.68,159.326 861.689,159.329 861.698,159.332 861.708,159.335 861.717,159.338 861.726,159.341 861.735,159.344 861.744,159.347 861.754,159.35 861.763,159.352 861.772,159.355 861.781,159.358 861.79,159.361 861.799,159.364 861.809,159.367 861.818,159.37 861.827,159.373 861.836,159.376 861.845,159.379 861.855,159.382 861.864,159.385 861.873,159.388 861.882,159.391 861.891,159.394 861.901,159.397 861.91,159.4 861.919,159.403 861.928,159.406 861.937,159.409 861.946,159.412 861.956,159.415 861.965,159.418 861.974,159.421 861.983,159.424 861.992,159.427 862.002,159.429 862.011,159.432 862.02,159.435 862.029,159.438 862.038,159.441 862.048,159.444 862.057,159.447 862.066,159.45 862.075,159.453 862.084,159.456 862.094,159.459 862.103,159.462 862.112,159.465 862.121,159.468 862.13,159.471 862.139,159.474 862.149,159.477 862.158,159.48 862.167,159.483 862.176,159.486 862.185,159.489 862.195,159.492 862.204,159.495 862.213,159.498 862.222,159.501 862.231,159.504 862.241,159.507 862.25,159.509 862.259,159.512 862.268,159.515 862.277,159.518 862.286,159.521 862.296,159.524 862.305,159.527 862.314,159.53 862.323,159.533 862.332,159.536 862.342,159.539 862.351,159.542 862.36,159.545 862.369,159.548 862.378,159.551 862.388,159.554 862.397,159.557 862.406,159.56 862.415,159.563 862.424,159.566 862.434,159.569 862.443,159.572 862.452,159.575 862.461,159.578 862.47,159.581 862.479,159.584 862.489,159.586 862.498,159.589 862.507,159.592 862.516,159.595 862.525,159.598 862.535,159.601 862.544,159.604 862.553,159.607 862.562,159.61 862.571,159.613 862.581,159.616 862.59,159.619 862.599,159.622 862.608,159.625 862.617,159.628 862.626,159.631 862.636,159.634 862.645,159.637 862.654,159.64 862.663,159.643 862.672,159.646 862.682,159.649 862.691,159.652 862.7,159.655 862.709,159.658 862.718,159.66 862.728,159.663 862.737,159.666 862.746,159.669 862.755,159.672 862.764,159.675 862.774,159.678 862.783,159.681 862.792,159.684 862.801,159.687 862.81,159.69 862.819,159.693 862.829,159.696 862.838,159.699 862.847,159.702 862.856,159.705 862.865,159.708 862.875,159.711 862.884,159.714 862.893,159.717 862.902,159.72 862.911,159.723 862.921,159.726 862.93,159.729 862.939,159.732 862.948,159.735 862.957,159.737 862.966,159.74 862.976,159.743 862.985,159.746 862.994,159.749 863.003,159.752 863.012,159.755 863.022,159.758 863.031,159.761 863.04,159.764 863.049,159.767 863.058,159.77 863.068,159.773 863.077,159.776 863.086,159.779 863.095,159.782 863.104,159.785 863.114,159.788 863.123,159.791 863.132,159.794 863.141,159.797 863.15,159.8 863.159,159.803 863.169,159.806 863.178,159.809 863.187,159.811 863.196,159.814 863.205,159.817 863.215,159.82 863.224,159.823 863.233,159.826 863.242,159.829 863.251,159.832 863.261,159.835 863.27,159.838 863.279,159.841 863.288,159.844 863.297,159.847 863.306,159.85 863.316,159.853 863.325,159.856 863.334,159.859 863.343,159.862 863.352,159.865 863.362,159.868 863.371,159.871 863.38,159.874 863.389,159.877 863.398,159.88 863.408,159.883 863.417,159.886 863.426,159.888 863.435,159.891 863.444,159.894 863.454,159.897 863.463,159.9 863.472,159.903 863.481,159.906 863.49,159.909 863.499,159.912 863.509,159.915 863.518,159.918 863.527,159.921 863.536,159.924 863.545,159.927 863.555,159.93 863.564,159.933 863.573,159.936 863.582,159.939 863.591,159.942 863.601,159.945 863.61,159.948 863.619,159.951 863.628,159.954 863.637,159.957 863.646,159.96 863.656,159.962 863.665,159.965 863.674,159.968 863.683,159.971 863.692,159.974 863.702,159.977 863.711,159.98 863.72,159.983 863.729,159.986 863.738,159.989 863.748,159.992 863.757,159.995 863.766,159.998 863.775,160.001 863.784,160.004 863.794,160.007 863.803,160.01 863.812,160.013 863.821,160.016 863.83,160.019 863.839,160.022 863.849,160.025 863.858,160.028 863.867,160.031 863.876,160.033 863.885,160.036 863.895,160.039 863.904,160.042 863.913,160.045 863.922,160.048 863.931,160.051 863.941,160.054 863.95,160.057 863.959,160.06 863.968,160.063 863.977,160.066 863.987,160.069 863.996,160.072 864.005,160.075 864.014,160.078 864.023,160.081 864.032,160.084 864.042,160.087 864.051,160.09 864.06,160.093 864.069,160.096 864.078,160.099 864.088,160.102 864.097,160.105 864.106,160.107 864.115,160.11 864.124,160.113 864.134,160.116 864.143,160.119 864.152,160.122 864.161,160.125 864.17,160.128 864.179,160.131 864.189,160.134 864.198,160.137 864.207,160.14 864.216,160.143 864.225,160.146 864.235,160.149 864.244,160.152 864.253,160.155 864.262,160.158 864.271,160.161 864.281,160.164 864.29,160.167 864.299,160.17 864.308,160.173 864.317,160.176 864.327,160.178 864.336,160.181 864.345,160.184 864.354,160.187 864.363,160.19 864.372,160.193 864.382,160.196 864.391,160.199 864.4,160.202 864.409,160.205 864.418,160.208 864.428,160.211 864.437,160.214 864.446,160.217 864.455,160.22 864.464,160.223 864.474,160.226 864.483,160.229 864.492,160.232 864.501,160.235 864.51,160.238 864.519,160.241 864.529,160.244 864.538,160.247 864.547,160.25 864.556,160.252 864.565,160.255 864.575,160.258 864.584,160.261 864.593,160.264 864.602,160.267 864.611,160.27 864.621,160.273 864.63,160.276 864.639,160.279 864.648,160.282 864.657,160.285 864.667,160.288 864.676,160.291 864.685,160.294 864.694,160.297 864.703,160.3 864.712,160.303 864.722,160.306 864.731,160.309 864.74,160.312 864.749,160.315 864.758,160.318 864.768,160.321 864.777,160.323 864.786,160.326 864.795,160.329 864.804,160.332 864.814,160.335 864.823,160.338 864.832,160.341 864.841,160.344 864.85,160.347 864.859,160.35 864.869,160.353 864.878,160.356 864.887,160.359 864.896,160.362 864.905,160.365 864.915,160.368 864.924,160.371 864.933,160.374 864.942,160.377 864.951,160.38 864.961,160.383 864.97,160.386 864.979,160.389 864.988,160.391 864.997,160.394 865.007,160.397 865.016,160.4 865.025,160.403 865.034,160.406 865.043,160.409 865.052,160.412 865.062,160.415 865.071,160.418 865.08,160.421 865.089,160.424 865.098,160.427 865.108,160.43 865.117,160.433 865.126,160.436 865.135,160.439 865.144,160.442 865.154,160.445 865.163,160.448 865.172,160.451 865.181,160.454 865.19,160.457 865.199,160.46 865.209,160.462 865.218,160.465 865.227,160.468 865.236,160.471 865.245,160.474 865.255,160.477 865.264,160.48 865.273,160.483 865.282,160.486 865.291,160.489 865.301,160.492 865.31,160.495 865.319,160.498 865.328,160.501 865.337,160.504 865.347,160.507 865.356,160.51 865.365,160.513 865.374,160.516 865.383,160.519 865.392,160.522 865.402,160.525 865.411,160.528 865.42,160.53 865.429,160.533 865.438,160.536 865.448,160.539 865.457,160.542 865.466,160.545 865.475,160.548 865.484,160.551 865.494,160.554 865.503,160.557 865.512,160.56 865.521,160.563 865.53,160.566 865.539,160.569 865.549,160.572 865.558,160.575 865.567,160.578 865.576,160.581 865.585,160.584 865.595,160.587 865.604,160.59 865.613,160.593 865.622,160.596 865.631,160.599 865.641,160.601 865.65,160.604 865.659,160.607 865.668,160.61 865.677,160.613 865.687,160.616 865.696,160.619 865.705,160.622 865.714,160.625 865.723,160.628 865.732,160.631 865.742,160.634 865.751,160.637 865.76,160.64 865.769,160.643 865.778,160.646 865.788,160.649 865.797,160.652 865.806,160.655 865.815,160.658 865.824,160.661 865.834,160.664 865.843,160.667 865.852,160.669 865.861,160.672 865.87,160.675 865.879,160.678 865.889,160.681 865.898,160.684 865.907,160.687 865.916,160.69 865.925,160.693 865.935,160.696 865.944,160.699 865.953,160.702 865.962,160.705 865.971,160.708 865.981,160.711 865.99,160.714 865.999,160.717 866.008,160.72 866.017,160.723 866.027,160.726 866.036,160.729 866.045,160.732 866.054,160.735 866.063,160.737 866.072,160.74 866.082,160.743 866.091,160.746 866.1,160.749 866.109,160.752 866.118,160.755 866.128,160.758 866.137,160.761 866.146,160.764 866.155,160.767 866.164,160.77 866.174,160.773 866.183,160.776 866.192,160.779 866.201,160.782 866.21,160.785 866.219,160.788 866.229,160.791 866.238,160.794 866.247,160.797 866.256,160.8 866.265,160.803 866.275,160.805 866.284,160.808 866.293,160.811 866.302,160.814 866.311,160.817 866.321,160.82 866.33,160.823 866.339,160.826 866.348,160.829 866.357,160.832 866.367,160.835 866.376,160.838 866.385,160.841 866.394,160.844 866.403,160.847 866.412,160.85 866.422,160.853 866.431,160.856 866.44,160.859 866.449,160.862 866.458,160.865 866.468,160.868 866.477,160.87 866.486,160.873 866.495,160.876 866.504,160.879 866.514,160.882 866.523,160.885 866.532,160.888 866.541,160.891 866.55,160.894 866.56,160.897 866.569,160.9 866.578,160.903 866.587,160.906 866.596,160.909 866.605,160.912 866.615,160.915 866.624,160.918 866.633,160.921 866.642,160.924 866.651,160.927 866.661,160.93 866.67,160.933 866.679,160.936 866.688,160.938 866.697,160.941 866.707,160.944 866.716,160.947 866.725,160.95 866.734,160.953 866.743,160.956 866.752,160.959 866.762,160.962 866.771,160.965 866.78,160.968 866.789,160.971 866.798,160.974 866.808,160.977 866.817,160.98 866.826,160.983 866.835,160.986 866.844,160.989 866.854,160.992 866.863,160.995 866.872,160.998 866.881,161.001 866.89,161.003 866.9,161.006 866.909,161.009 866.918,161.012 866.927,161.015 866.936,161.018 866.945,161.021 866.955,161.024 866.964,161.027 866.973,161.03 866.982,161.033 866.991,161.036 867.001,161.039 867.01,161.042 867.019,161.045 867.028,161.048 867.037,161.051 867.047,161.054 867.056,161.057 867.065,161.06 867.074,161.063 867.083,161.066 867.092,161.068 867.102,161.071 867.111,161.074 867.12,161.077 867.129,161.08 867.138,161.083 867.148,161.086 867.157,161.089 867.166,161.092 867.175,161.095 867.184,161.098 867.194,161.101 867.203,161.104 867.212,161.107 867.221,161.11 867.23,161.113 867.24,161.116 867.249,161.119 867.258,161.122 867.267,161.125 867.276,161.128 867.285,161.131 867.295,161.133 867.304,161.136 867.313,161.139 867.322,161.142 867.331,161.145 867.341,161.148 867.35,161.151 867.359,161.154 867.368,161.157 867.377,161.16 867.387,161.163 867.396,161.166 867.405,161.169 867.414,161.172 867.423,161.175 867.432,161.178 867.442,161.181 867.451,161.184 867.46,161.187 867.469,161.19 867.478,161.193 867.488,161.196 867.497,161.198 867.506,161.201 867.515,161.204 867.524,161.207 867.534,161.21 867.543,161.213 867.552,161.216 867.561,161.219 867.57,161.222 867.58,161.225 867.589,161.228 867.598,161.231 867.607,161.234 867.616,161.237 867.625,161.24 867.635,161.243 867.644,161.246 867.653,161.249 867.662,161.252 867.671,161.255 867.681,161.258 867.69,161.261 867.699,161.263 867.708,161.266 867.717,161.269 867.727,161.272 867.736,161.275 867.745,161.278 867.754,161.281 867.763,161.284 867.772,161.287 867.782,161.29 867.791,161.293 867.8,161.296 867.809,161.299 867.818,161.302 867.828,161.305 867.837,161.308 867.846,161.311 867.855,161.314 867.864,161.317 867.874,161.32 867.883,161.323 867.892,161.326 867.901,161.328 867.91,161.331 867.92,161.334 867.929,161.337 867.938,161.34 867.947,161.343 867.956,161.346 867.965,161.349 867.975,161.352 867.984,161.355 867.993,161.358 868.002,161.361 868.011,161.364 868.021,161.367 868.03,161.37 868.039,161.373 868.048,161.376 868.057,161.379 868.067,161.382 868.076,161.385 868.085,161.388 868.094,161.39 868.103,161.393 868.112,161.396 868.122,161.399 868.131,161.402 868.14,161.405 868.149,161.408 868.158,161.411 868.168,161.414 868.177,161.417 868.186,161.42 868.195,161.423 868.204,161.426 868.214,161.429 868.223,161.432 868.232,161.435 868.241,161.438 868.25,161.441 868.26,161.444 868.269,161.447 868.278,161.45 868.287,161.452 868.296,161.455 868.305,161.458 868.315,161.461 868.324,161.464 868.333,161.467 868.342,161.47 868.351,161.473 868.361,161.476 868.37,161.479 868.379,161.482 868.388,161.485 868.397,161.488 868.407,161.491 868.416,161.494 868.425,161.497 868.434,161.5 868.443,161.503 868.452,161.506 868.462,161.509 868.471,161.512 868.48,161.515 868.489,161.517 868.498,161.52 868.508,161.523 868.517,161.526 868.526,161.529 868.535,161.532 868.544,161.535 868.554,161.538 868.563,161.541 868.572,161.544 868.581,161.547 868.59,161.55 868.6,161.553 868.609,161.556 868.618,161.559 868.627,161.562 868.636,161.565 868.645,161.568 868.655,161.571 868.664,161.574 868.673,161.577 868.682,161.579 868.691,161.582 868.701,161.585 868.71,161.588 868.719,161.591 868.728,161.594 868.737,161.597 868.747,161.6 868.756,161.603 868.765,161.606 868.774,161.609 868.783,161.612 868.793,161.615 868.802,161.618 868.811,161.621 868.82,161.624 868.829,161.627 868.838,161.63 868.848,161.633 868.857,161.636 868.866,161.639 868.875,161.641 868.884,161.644 868.894,161.647 868.903,161.65 868.912,161.653 868.921,161.656 868.93,161.659 868.94,161.662 868.949,161.665 868.958,161.668 868.967,161.671 868.976,161.674 868.985,161.677 868.995,161.68 869.004,161.683 869.013,161.686 869.022,161.689 869.031,161.692 869.041,161.695 869.05,161.698 869.059,161.7 869.068,161.703 869.077,161.706 869.087,161.709 869.096,161.712 869.105,161.715 869.114,161.718 869.123,161.721 869.133,161.724 869.142,161.727 869.151,161.73 869.16,161.733 869.169,161.736 869.178,161.739 869.188,161.742 869.197,161.745 869.206,161.748 869.215,161.751 869.224,161.754 869.234,161.757 869.243,161.76 869.252,161.762 869.261,161.765 869.27,161.768 869.28,161.771 869.289,161.774 869.298,161.777 869.307,161.78 869.316,161.783 869.325,161.786 869.335,161.789 869.344,161.792 869.353,161.795 869.362,161.798 869.371,161.801 869.381,161.804 869.39,161.807 869.399,161.81 869.408,161.813 869.417,161.816 869.427,161.819 869.436,161.822 869.445,161.824 869.454,161.827 869.463,161.83 869.473,161.833 869.482,161.836 869.491,161.839 869.5,161.842 869.509,161.845 869.518,161.848 869.528,161.851 869.537,161.854 869.546,161.857 869.555,161.86 869.564,161.863 869.574,161.866 869.583,161.869 869.592,161.872 869.601,161.875 869.61,161.878 869.62,161.881 869.629,161.883 869.638,161.886 869.647,161.889 869.656,161.892 869.665,161.895 869.675,161.898 869.684,161.901 869.693,161.904 869.702,161.907 869.711,161.91 869.721,161.913 869.73,161.916 869.739,161.919 869.748,161.922 869.757,161.925 869.767,161.928 869.776,161.931 869.785,161.934 869.794,161.937 869.803,161.94 869.813,161.943 869.822,161.945 869.831,161.948 869.84,161.951 869.849,161.954 869.858,161.957 869.868,161.96 869.877,161.963 869.886,161.966 869.895,161.969 869.904,161.972 869.914,161.975 869.923,161.978 869.932,161.981 869.941,161.984 869.95,161.987 869.96,161.99 869.969,161.993 869.978,161.996 869.987,161.999 869.996,162.002 870.005,162.004 870.015,162.007 870.024,162.01 870.033,162.013 870.042,162.016 870.051,162.019 870.061,162.022 870.07,162.025 870.079,162.028 870.088,162.031 870.097,162.034 870.107,162.037 870.116,162.04 870.125,162.043 870.134,162.046 870.143,162.049 870.153,162.052 870.162,162.055 870.171,162.058 870.18,162.061 870.189,162.063 870.198,162.066 870.208,162.069 870.217,162.072 870.226,162.075 870.235,162.078 870.244,162.081 870.254,162.084 870.263,162.087 870.272,162.09 870.281,162.093 870.29,162.096 870.3,162.099 870.309,162.102 870.318,162.105 870.327,162.108 870.336,162.111 870.345,162.114 870.355,162.117 870.364,162.12 870.373,162.122 870.382,162.125 870.391,162.128 870.401,162.131 870.41,162.134 870.419,162.137 870.428,162.14 870.437,162.143 870.447,162.146 870.456,162.149 870.465,162.152 870.474,162.155 870.483,162.158 870.493,162.161 870.502,162.164 870.511,162.167 870.52,162.17 870.529,162.173 870.538,162.176 870.548,162.179 870.557,162.181 870.566,162.184 870.575,162.187 870.584,162.19 870.594,162.193 870.603,162.196 870.612,162.199 870.621,162.202 870.63,162.205 870.64,162.208 870.649,162.211 870.658,162.214 870.667,162.217 870.676,162.22 870.685,162.223 870.695,162.226 870.704,162.229 870.713,162.232 870.722,162.235 870.731,162.238 870.741,162.24 870.75,162.243 870.759,162.246 870.768,162.249 870.777,162.252 870.787,162.255 870.796,162.258 870.805,162.261 870.814,162.264 870.823,162.267 870.833,162.27 870.842,162.273 870.851,162.276 870.86,162.279 870.869,162.282 870.878,162.285 870.888,162.288 870.897,162.291 870.906,162.294 870.915,162.296 870.924,162.299 870.934,162.302 870.943,162.305 870.952,162.308 870.961,162.311 870.97,162.314 870.98,162.317 870.989,162.32 870.998,162.323 871.007,162.326 871.016,162.329 871.025,162.332 871.035,162.335 871.044,162.338 871.053,162.341 871.062,162.344 871.071,162.347 871.081,162.35 871.09,162.353 871.099,162.355 871.108,162.358 871.117,162.361 871.127,162.364 871.136,162.367 871.145,162.37 871.154,162.373 871.163,162.376 871.173,162.379 871.182,162.382 871.191,162.385 871.2,162.388 871.209,162.391 871.218,162.394 871.228,162.397 871.237,162.4 871.246,162.403 871.255,162.406 871.264,162.409 871.274,162.411 871.283,162.414 871.292,162.417 871.301,162.42 871.31,162.423 871.32,162.426 871.329,162.429 871.338,162.432 871.347,162.435 871.356,162.438 871.366,162.441 871.375,162.444 871.384,162.447 871.393,162.45 871.402,162.453 871.411,162.456 871.421,162.459 871.43,162.462 871.439,162.465 871.448,162.468 871.457,162.47 871.467,162.473 871.476,162.476 871.485,162.479 871.494,162.482 871.503,162.485 871.513,162.488 871.522,162.491 871.531,162.494 871.54,162.497 871.549,162.5 871.558,162.503 871.568,162.506 871.577,162.509 871.586,162.512 871.595,162.515 871.604,162.518 871.614,162.521 871.623,162.524 871.632,162.526 871.641,162.529 871.65,162.532 871.66,162.535 871.669,162.538 871.678,162.541 871.687,162.544 871.696,162.547 871.706,162.55 871.715,162.553 871.724,162.556 871.733,162.559 871.742,162.562 871.751,162.565 871.761,162.568 871.77,162.571 871.779,162.574 871.788,162.577 871.797,162.58 871.807,162.582 871.816,162.585 871.825,162.588 871.834,162.591 871.843,162.594 871.853,162.597 871.862,162.6 871.871,162.603 871.88,162.606 871.889,162.609 871.898,162.612 871.908,162.615 871.917,162.618 871.926,162.621 871.935,162.624 871.944,162.627 871.954,162.63 871.963,162.633 871.972,162.636 871.981,162.638 871.99,162.641 872,162.644 872.009,162.647 872.018,162.65 872.027,162.653 872.036,162.656 872.046,162.659 872.055,162.662 872.064,162.665 872.073,162.668 872.082,162.671 872.091,162.674 872.101,162.677 872.11,162.68 872.119,162.683 872.128,162.686 872.137,162.689 872.147,162.692 872.156,162.694 872.165,162.697 872.174,162.7 872.183,162.703 872.193,162.706 872.202,162.709 872.211,162.712 872.22,162.715 872.229,162.718 872.238,162.721 872.248,162.724 872.257,162.727 872.266,162.73 872.275,162.733 872.284,162.736 872.294,162.739 872.303,162.742 872.312,162.745 872.321,162.748 872.33,162.75 872.34,162.753 872.349,162.756 872.358,162.759 872.367,162.762 872.376,162.765 872.386,162.768 872.395,162.771 872.404,162.774 872.413,162.777 872.422,162.78 872.431,162.783 872.441,162.786 872.45,162.789 872.459,162.792 872.468,162.795 872.477,162.798 872.487,162.801 872.496,162.804 872.505,162.806 872.514,162.809 872.523,162.812 872.533,162.815 872.542,162.818 872.551,162.821 872.56,162.824 872.569,162.827 872.578,162.83 872.588,162.833 872.597,162.836 872.606,162.839 872.615,162.842 872.624,162.845 872.634,162.848 872.643,162.851 872.652,162.854 872.661,162.857 872.67,162.86 872.68,162.862 872.689,162.865 872.698,162.868 872.707,162.871 872.716,162.874 872.726,162.877 872.735,162.88 872.744,162.883 872.753,162.886 872.762,162.889 872.771,162.892 872.781,162.895 872.79,162.898 872.799,162.901 872.808,162.904 872.817,162.907 872.827,162.91 872.836,162.913 872.845,162.915 872.854,162.918 872.863,162.921 872.873,162.924 872.882,162.927 872.891,162.93 872.9,162.933 872.909,162.936 872.918,162.939 872.928,162.942 872.937,162.945 872.946,162.948 872.955,162.951 872.964,162.954 872.974,162.957 872.983,162.96 872.992,162.963 873.001,162.966 873.01,162.969 873.02,162.971 873.029,162.974 873.038,162.977 873.047,162.98 873.056,162.983 873.066,162.986 873.075,162.989 873.084,162.992 873.093,162.995 873.102,162.998 873.111,163.001 873.121,163.004 873.13,163.007 873.139,163.01 873.148,163.013 873.157,163.016 873.167,163.019 873.176,163.022 873.185,163.024 873.194,163.027 873.203,163.03 873.213,163.033 873.222,163.036 873.231,163.039 873.24,163.042 873.249,163.045 873.258,163.048 873.268,163.051 873.277,163.054 873.286,163.057 873.295,163.06 873.304,163.063 873.314,163.066 873.323,163.069 873.332,163.072 873.341,163.075 873.35,163.078 873.36,163.08 873.369,163.083 873.378,163.086 873.387,163.089 873.396,163.092 873.406,163.095 873.415,163.098 873.424,163.101 873.433,163.104 873.442,163.107 873.451,163.11 873.461,163.113 873.47,163.116 873.479,163.119 873.488,163.122 873.497,163.125 873.507,163.128 873.516,163.131 873.525,163.133 873.534,163.136 873.543,163.139 873.553,163.142 873.562,163.145 873.571,163.148 873.58,163.151 873.589,163.154 873.598,163.157 873.608,163.16 873.617,163.163 873.626,163.166 873.635,163.169 873.644,163.172 873.654,163.175 873.663,163.178 873.672,163.181 873.681,163.184 873.69,163.186 873.7,163.189 873.709,163.192 873.718,163.195 873.727,163.198 873.736,163.201 873.746,163.204 873.755,163.207 873.764,163.21 873.773,163.213 873.782,163.216 873.791,163.219 873.801,163.222 873.81,163.225 873.819,163.228 873.828,163.231 873.837,163.234 873.847,163.237 873.856,163.239 873.865,163.242 873.874,163.245 873.883,163.248 873.893,163.251 873.902,163.254 873.911,163.257 873.92,163.26 873.929,163.263 873.939,163.266 873.948,163.269 873.957,163.272 873.966,163.275 873.975,163.278 873.984,163.281 873.994,163.284 874.003,163.287 874.012,163.29 874.021,163.292 874.03,163.295 874.04,163.298 874.049,163.301 874.058,163.304 874.067,163.307 874.076,163.31 874.086,163.313 874.095,163.316 874.104,163.319 874.113,163.322 874.122,163.325 874.131,163.328 874.141,163.331 874.15,163.334 874.159,163.337 874.168,163.34 874.177,163.343 874.187,163.345 874.196,163.348 874.205,163.351 874.214,163.354 874.223,163.357 874.233,163.36 874.242,163.363 874.251,163.366 874.26,163.369 874.269,163.372 874.279,163.375 874.288,163.378 874.297,163.381 874.306,163.384 874.315,163.387 874.324,163.39 874.334,163.393 874.343,163.396 874.352,163.398 874.361,163.401 874.37,163.404 874.38,163.407 874.389,163.41 874.398,163.413 874.407,163.416 874.416,163.419 874.426,163.422 874.435,163.425 874.444,163.428 874.453,163.431 874.462,163.434 874.471,163.437 874.481,163.44 874.49,163.443 874.499,163.446 874.508,163.449 874.517,163.451 874.527,163.454 874.536,163.457 874.545,163.46 874.554,163.463 874.563,163.466 874.573,163.469 874.582,163.472 874.591,163.475 874.6,163.478 874.609,163.481 874.619,163.484 874.628,163.487 874.637,163.49 874.646,163.493 874.655,163.496 874.664,163.499 874.674,163.501 874.683,163.504 874.692,163.507 874.701,163.51 874.71,163.513 874.72,163.516 874.729,163.519 874.738,163.522 874.747,163.525 874.756,163.528 874.766,163.531 874.775,163.534 874.784,163.537 874.793,163.54 874.802,163.543 874.811,163.546 874.821,163.549 874.83,163.552 874.839,163.554 874.848,163.557 874.857,163.56 874.867,163.563 874.876,163.566 874.885,163.569 874.894,163.572 874.903,163.575 874.913,163.578 874.922,163.581 874.931,163.584 874.94,163.587 874.949,163.59 874.959,163.593 874.968,163.596 874.977,163.599 874.986,163.602 874.995,163.604 875.004,163.607 875.014,163.61 875.023,163.613 875.032,163.616 875.041,163.619 875.05,163.622 875.06,163.625 875.069,163.628 875.078,163.631 875.087,163.634 875.096,163.637 875.106,163.64 875.115,163.643 875.124,163.646 875.133,163.649 875.142,163.652 875.151,163.655 875.161,163.657 875.17,163.66 875.179,163.663 875.188,163.666 875.197,163.669 875.207,163.672 875.216,163.675 875.225,163.678 875.234,163.681 875.243,163.684 875.253,163.687 875.262,163.69 875.271,163.693 875.28,163.696 875.289,163.699 875.299,163.702 875.308,163.705 875.317,163.707 875.326,163.71 875.335,163.713 875.344,163.716 875.354,163.719 875.363,163.722 875.372,163.725 875.381,163.728 875.39,163.731 875.4,163.734 875.409,163.737 875.418,163.74 875.427,163.743 875.436,163.746 875.446,163.749 875.455,163.752 875.464,163.755 875.473,163.758 875.482,163.76 875.491,163.763 875.501,163.766 875.51,163.769 875.519,163.772 875.528,163.775 875.537,163.778 875.547,163.781 875.556,163.784 875.565,163.787 875.574,163.79 875.583,163.793 875.593,163.796 875.602,163.799 875.611,163.802 875.62,163.805 875.629,163.808 875.639,163.81 875.648,163.813 875.657,163.816 875.666,163.819 875.675,163.822 875.684,163.825 875.694,163.828 875.703,163.831 875.712,163.834 875.721,163.837 875.73,163.84 875.74,163.843 875.749,163.846 875.758,163.849 875.767,163.852 875.776,163.855 875.786,163.858 875.795,163.86 875.804,163.863 875.813,163.866 875.822,163.869 875.831,163.872 875.841,163.875 875.85,163.878 875.859,163.881 875.868,163.884 875.877,163.887 875.887,163.89 875.896,163.893 875.905,163.896 875.914,163.899 875.923,163.902 875.933,163.905 875.942,163.908 875.951,163.91 875.96,163.913 875.969,163.916 875.979,163.919 875.988,163.922 875.997,163.925 876.006,163.928 876.015,163.931 876.024,163.934 876.034,163.937 876.043,163.94 876.052,163.943 876.061,163.946 876.07,163.949 876.08,163.952 876.089,163.955 876.098,163.958 876.107,163.96 876.116,163.963 876.126,163.966 876.135,163.969 876.144,163.972 876.153,163.975 876.162,163.978 876.171,163.981 876.181,163.984 876.19,163.987 876.199,163.99 876.208,163.993 876.217,163.996 876.227,163.999 876.236,164.002 876.245,164.005 876.254,164.008 876.263,164.01 876.273,164.013 876.282,164.016 876.291,164.019 876.3,164.022 876.309,164.025 876.319,164.028 876.328,164.031 876.337,164.034 876.346,164.037 876.355,164.04 876.364,164.043 876.374,164.046 876.383,164.049 876.392,164.052 876.401,164.055 876.41,164.058 876.42,164.06 876.429,164.063 876.438,164.066 876.447,164.069 876.456,164.072 876.466,164.075 876.475,164.078 876.484,164.081 876.493,164.084 876.502,164.087 876.512,164.09 876.521,164.093 876.53,164.096 876.539,164.099 876.548,164.102 876.557,164.105 876.567,164.108 876.576,164.11 876.585,164.113 876.594,164.116 876.603,164.119 876.613,164.122 876.622,164.125 876.631,164.128 876.64,164.131 876.649,164.134 876.659,164.137 876.668,164.14 876.677,164.143 876.686,164.146 876.695,164.149 876.704,164.152 876.714,164.155 876.723,164.158 876.732,164.16 876.741,164.163 876.75,164.166 876.76,164.169 876.769,164.172 876.778,164.175 876.787,164.178 876.796,164.181 876.806,164.184 876.815,164.187 876.824,164.19 876.833,164.193 876.842,164.196 876.852,164.199 876.861,164.202 876.87,164.205 876.879,164.207 876.888,164.21 876.897,164.213 876.907,164.216 876.916,164.219 876.925,164.222 876.934,164.225 876.943,164.228 876.953,164.231 876.962,164.234 876.971,164.237 876.98,164.24 876.989,164.243 876.999,164.246 877.008,164.249 877.017,164.252 877.026,164.255 877.035,164.257 877.044,164.26 877.054,164.263 877.063,164.266 877.072,164.269 877.081,164.272 877.09,164.275 877.1,164.278 877.109,164.281 877.118,164.284 877.127,164.287 877.136,164.29 877.146,164.293 877.155,164.296 877.164,164.299 877.173,164.302 877.182,164.304 877.192,164.307 877.201,164.31 877.21,164.313 877.219,164.316 877.228,164.319 877.237,164.322 877.247,164.325 877.256,164.328 877.265,164.331 877.274,164.334 877.283,164.337 877.293,164.34 877.302,164.343 877.311,164.346 877.32,164.349 877.329,164.352 877.339,164.354 877.348,164.357 877.357,164.36 877.366,164.363 877.375,164.366 877.384,164.369 877.394,164.372 877.403,164.375 877.412,164.378 877.421,164.381 877.43,164.384 877.44,164.387 877.449,164.39 877.458,164.393 877.467,164.396 877.476,164.399 877.486,164.401 877.495,164.404 877.504,164.407 877.513,164.41 877.522,164.413 877.532,164.416 877.541,164.419 877.55,164.422 877.559,164.425 877.568,164.428 877.577,164.431 877.587,164.434 877.596,164.437 877.605,164.44 877.614,164.443 877.623,164.446 877.633,164.449 877.642,164.451 877.651,164.454 877.66,164.457 877.669,164.46 877.679,164.463 877.688,164.466 877.697,164.469 877.706,164.472 877.715,164.475 877.724,164.478 877.734,164.481 877.743,164.484 877.752,164.487 877.761,164.49 877.77,164.493 877.78,164.496 877.789,164.498 877.798,164.501 877.807,164.504 877.816,164.507 877.826,164.51 877.835,164.513 877.844,164.516 877.853,164.519 877.862,164.522 877.872,164.525 877.881,164.528 877.89,164.531 877.899,164.534 877.908,164.537 877.917,164.54 877.927,164.543 877.936,164.545 877.945,164.548 877.954,164.551 877.963,164.554 877.973,164.557 877.982,164.56 877.991,164.563 878,164.566 878.009,164.569 878.019,164.572 878.028,164.575 878.037,164.578 878.046,164.581 878.055,164.584 878.064,164.587 878.074,164.59 878.083,164.592 878.092,164.595 878.101,164.598 878.11,164.601 878.12,164.604 878.129,164.607 878.138,164.61 878.147,164.613 878.156,164.616 878.166,164.619 878.175,164.622 878.184,164.625 878.193,164.628 878.202,164.631 878.212,164.634 878.221,164.637 878.23,164.639 878.239,164.642 878.248,164.645 878.257,164.648 878.267,164.651 878.276,164.654 878.285,164.657 878.294,164.66 878.303,164.663 878.313,164.666 878.322,164.669 878.331,164.672 878.34,164.675 878.349,164.678 878.359,164.681 878.368,164.684 878.377,164.687 878.386,164.689 878.395,164.692 878.404,164.695 878.414,164.698 878.423,164.701 878.432,164.704 878.441,164.707 878.45,164.71 878.46,164.713 878.469,164.716 878.478,164.719 878.487,164.722 878.496,164.725 878.506,164.728 878.515,164.731 878.524,164.734 878.533,164.736 878.542,164.739 878.552,164.742 878.561,164.745 878.57,164.748 878.579,164.751 878.588,164.754 878.597,164.757 878.607,164.76 878.616,164.763 878.625,164.766 878.634,164.769 878.643,164.772 878.653,164.775 878.662,164.778 878.671,164.78 878.68,164.783 878.689,164.786 878.699,164.789 878.708,164.792 878.717,164.795 878.726,164.798 878.735,164.801 878.745,164.804 878.754,164.807 878.763,164.81 878.772,164.813 878.781,164.816 878.79,164.819 878.8,164.822 878.809,164.825 878.818,164.827 878.827,164.83 878.836,164.833 878.846,164.836 878.855,164.839 878.864,164.842 878.873,164.845 878.882,164.848 878.892,164.851 878.901,164.854 878.91,164.857 878.919,164.86 878.928,164.863 878.937,164.866 878.947,164.869 878.956,164.872 878.965,164.874 878.974,164.877 878.983,164.88 878.993,164.883 879.002,164.886 879.011,164.889 879.02,164.892 879.029,164.895 879.039,164.898 879.048,164.901 879.057,164.904 879.066,164.907 879.075,164.91 879.085,164.913 879.094,164.916 879.103,164.919 879.112,164.921 879.121,164.924 879.13,164.927 879.14,164.93 879.149,164.933 879.158,164.936 879.167,164.939 879.176,164.942 879.186,164.945 879.195,164.948 879.204,164.951 879.213,164.954 879.222,164.957 879.232,164.96 879.241,164.963 879.25,164.966 879.259,164.968 879.268,164.971 879.277,164.974 879.287,164.977 879.296,164.98 879.305,164.983 879.314,164.986 879.323,164.989 879.333,164.992 879.342,164.995 879.351,164.998 879.36,165.001 879.369,165.004 879.379,165.007 879.388,165.01 879.397,165.012 879.406,165.015 879.415,165.018 879.425,165.021 879.434,165.024 879.443,165.027 879.452,165.03 879.461,165.033 879.47,165.036 879.48,165.039 879.489,165.042 879.498,165.045 879.507,165.048 879.516,165.051 879.526,165.054 879.535,165.057 879.544,165.059 879.553,165.062 879.562,165.065 879.572,165.068 879.581,165.071 879.59,165.074 879.599,165.077 879.608,165.08 879.617,165.083 879.627,165.086 879.636,165.089 879.645,165.092 879.654,165.095 879.663,165.098 879.673,165.101 879.682,165.103 879.691,165.106 879.7,165.109 879.709,165.112 879.719,165.115 879.728,165.118 879.737,165.121 879.746,165.124 879.755,165.127 879.765,165.13 879.774,165.133 879.783,165.136 879.792,165.139 879.801,165.142 879.81,165.145 879.82,165.148 879.829,165.15 879.838,165.153 879.847,165.156 879.856,165.159 879.866,165.162 879.875,165.165 879.884,165.168 879.893,165.171 879.902,165.174 879.912,165.177 879.921,165.18 879.93,165.183 879.939,165.186 879.948,165.189 879.957,165.192 879.967,165.194 879.976,165.197 879.985,165.2 879.994,165.203 880.003,165.206 880.013,165.209 880.022,165.212 880.031,165.215 880.04,165.218 880.049,165.221 880.059,165.224 880.068,165.227 880.077,165.23 880.086,165.233 880.095,165.236 880.105,165.239 880.114,165.241 880.123,165.244 880.132,165.247 880.141,165.25 880.15,165.253 880.16,165.256 880.169,165.259 880.178,165.262 880.187,165.265 880.196,165.268 880.206,165.271 880.215,165.274 880.224,165.277 880.233,165.28 880.242,165.283 880.252,165.285 880.261,165.288 880.27,165.291 880.279,165.294 880.288,165.297 880.297,165.3 880.307,165.303 880.316,165.306 880.325,165.309 880.334,165.312 880.343,165.315 880.353,165.318 880.362,165.321 880.371,165.324 880.38,165.327 880.389,165.329 880.399,165.332 880.408,165.335 880.417,165.338 880.426,165.341 880.435,165.344 880.445,165.347 880.454,165.35 880.463,165.353 880.472,165.356 880.481,165.359 880.49,165.362 880.5,165.365 880.509,165.368 880.518,165.371 880.527,165.373 880.536,165.376 880.546,165.379 880.555,165.382 880.564,165.385 880.573,165.388 880.582,165.391 880.592,165.394 880.601,165.397 880.61,165.4 880.619,165.403 880.628,165.406 880.637,165.409 880.647,165.412 880.656,165.415 880.665,165.418 880.674,165.42 880.683,165.423 880.693,165.426 880.702,165.429 880.711,165.432 880.72,165.435 880.729,165.438 880.739,165.441 880.748,165.444 880.757,165.447 880.766,165.45 880.775,165.453 880.785,165.456 880.794,165.459 880.803,165.462 880.812,165.464 880.821,165.467 880.83,165.47 880.84,165.473 880.849,165.476 880.858,165.479 880.867,165.482 880.876,165.485 880.886,165.488 880.895,165.491 880.904,165.494 880.913,165.497 880.922,165.5 880.932,165.503 880.941,165.506 880.95,165.508 880.959,165.511 880.968,165.514 880.977,165.517 880.987,165.52 880.996,165.523 881.005,165.526 881.014,165.529 881.023,165.532 881.033,165.535 881.042,165.538 881.051,165.541 881.06,165.544 881.069,165.547 881.079,165.55 881.088,165.552 881.097,165.555 881.106,165.558 881.115,165.561 881.125,165.564 881.134,165.567 881.143,165.57 881.152,165.573 881.161,165.576 881.17,165.579 881.18,165.582 881.189,165.585 881.198,165.588 881.207,165.591 881.216,165.594 881.226,165.596 881.235,165.599 881.244,165.602 881.253,165.605 881.262,165.608 881.272,165.611 881.281,165.614 881.29,165.617 881.299,165.62 881.308,165.623 881.318,165.626 881.327,165.629 881.336,165.632 881.345,165.635 881.354,165.638 881.363,165.64 881.373,165.643 881.382,165.646 881.391,165.649 881.4,165.652 881.409,165.655 881.419,165.658 881.428,165.661 881.437,165.664 881.446,165.667 881.455,165.67 881.465,165.673 881.474,165.676 881.483,165.679 881.492,165.682 881.501,165.684 881.51,165.687 881.52,165.69 881.529,165.693 881.538,165.696 881.547,165.699 881.556,165.702 881.566,165.705 881.575,165.708 881.584,165.711 881.593,165.714 881.602,165.717 881.612,165.72 881.621,165.723 881.63,165.725 881.639,165.728 881.648,165.731 881.658,165.734 881.667,165.737 881.676,165.74 881.685,165.743 881.694,165.746 881.703,165.749 881.713,165.752 881.722,165.755 881.731,165.758 881.74,165.761 881.749,165.764 881.759,165.767 881.768,165.769 881.777,165.772 881.786,165.775 881.795,165.778 881.805,165.781 881.814,165.784 881.823,165.787 881.832,165.79 881.841,165.793 881.85,165.796 881.86,165.799 881.869,165.802 881.878,165.805 881.887,165.808 881.896,165.811 881.906,165.813 881.915,165.816 881.924,165.819 881.933,165.822 881.942,165.825 881.952,165.828 881.961,165.831 881.97,165.834 881.979,165.837 881.988,165.84 881.998,165.843 882.007,165.846 882.016,165.849 882.025,165.852 882.034,165.855 882.043,165.857 882.053,165.86 882.062,165.863 882.071,165.866 882.08,165.869 882.089,165.872 882.099,165.875 882.108,165.878 882.117,165.881 882.126,165.884 882.135,165.887 882.145,165.89 882.154,165.893 882.163,165.896 882.172,165.898 882.181,165.901 882.19,165.904 882.2,165.907 882.209,165.91 882.218,165.913 882.227,165.916 882.236,165.919 882.246,165.922 882.255,165.925 882.264,165.928 882.273,165.931 882.282,165.934 882.292,165.937 882.301,165.94 882.31,165.942 882.319,165.945 882.328,165.948 882.338,165.951 882.347,165.954 882.356,165.957 882.365,165.96 882.374,165.963 882.383,165.966 882.393,165.969 882.402,165.972 882.411,165.975 882.42,165.978 882.429,165.981 882.439,165.983 882.448,165.986 882.457,165.989 882.466,165.992 882.475,165.995 882.485,165.998 882.494,166.001 882.503,166.004 882.512,166.007 882.521,166.01 882.53,166.013 882.54,166.016 882.549,166.019 882.558,166.022 882.567,166.025 882.576,166.027 882.586,166.03 882.595,166.033 882.604,166.036 882.613,166.039 882.622,166.042 882.632,166.045 882.641,166.048 882.65,166.051 882.659,166.054 882.668,166.057 882.678,166.06 882.687,166.063 882.696,166.066 882.705,166.068 882.714,166.071 882.723,166.074 882.733,166.077 882.742,166.08 882.751,166.083 882.76,166.086 882.769,166.089 882.779,166.092 882.788,166.095 882.797,166.098 882.806,166.101 882.815,166.104 882.825,166.107 882.834,166.11 882.843,166.112 882.852,166.115 882.861,166.118 882.87,166.121 882.88,166.124 882.889,166.127 882.898,166.13 882.907,166.133 882.916,166.136 882.926,166.139 882.935,166.142 882.944,166.145 882.953,166.148 882.962,166.151 882.972,166.153 882.981,166.156 882.99,166.159 882.999,166.162 883.008,166.165 883.018,166.168 883.027,166.171 883.036,166.174 883.045,166.177 883.054,166.18 883.063,166.183 883.073,166.186 883.082,166.189 883.091,166.192 883.1,166.194 883.109,166.197 883.119,166.2 883.128,166.203 883.137,166.206 883.146,166.209 883.155,166.212 883.165,166.215 883.174,166.218 883.183,166.221 883.192,166.224 883.201,166.227 883.21,166.23 883.22,166.233 883.229,166.236 883.238,166.238 883.247,166.241 883.256,166.244 883.266,166.247 883.275,166.25 883.284,166.253 883.293,166.256 883.302,166.259 883.312,166.262 883.321,166.265 883.33,166.268 883.339,166.271 883.348,166.274 883.358,166.277 883.367,166.279 883.376,166.282 883.385,166.285 883.394,166.288 883.403,166.291 883.413,166.294 883.422,166.297 883.431,166.3 883.44,166.303 883.449,166.306 883.459,166.309 883.468,166.312 883.477,166.315 883.486,166.318 883.495,166.32 883.505,166.323 883.514,166.326 883.523,166.329 883.532,166.332 883.541,166.335 883.55,166.338 883.56,166.341 883.569,166.344 883.578,166.347 883.587,166.35 883.596,166.353 883.606,166.356 883.615,166.359 883.624,166.361 883.633,166.364 883.642,166.367 883.652,166.37 883.661,166.373 883.67,166.376 883.679,166.379 883.688,166.382 883.698,166.385 883.707,166.388 883.716,166.391 883.725,166.394 883.734,166.397 883.743,166.4 883.753,166.402 883.762,166.405 883.771,166.408 883.78,166.411 883.789,166.414 883.799,166.417 883.808,166.42 883.817,166.423 883.826,166.426 883.835,166.429 883.845,166.432 883.854,166.435 883.863,166.438 883.872,166.441 883.881,166.443 883.891,166.446 883.9,166.449 883.909,166.452 883.918,166.455 883.927,166.458 883.936,166.461 883.946,166.464 883.955,166.467 883.964,166.47 883.973,166.473 883.982,166.476 883.992,166.479 884.001,166.482 884.01,166.485 884.019,166.487 884.028,166.49 884.038,166.493 884.047,166.496 884.056,166.499 884.065,166.502 884.074,166.505 884.083,166.508 884.093,166.511 884.102,166.514 884.111,166.517 884.12,166.52 884.129,166.523 884.139,166.525 884.148,166.528 884.157,166.531 884.166,166.534 884.175,166.537 884.185,166.54 884.194,166.543 884.203,166.546 884.212,166.549 884.221,166.552 884.231,166.555 884.24,166.558 884.249,166.561 884.258,166.564 884.267,166.566 884.276,166.569 884.286,166.572 884.295,166.575 884.304,166.578 884.313,166.581 884.322,166.584 884.332,166.587 884.341,166.59 884.35,166.593 884.359,166.596 884.368,166.599 884.378,166.602 884.387,166.605 884.396,166.607 884.405,166.61 884.414,166.613 884.423,166.616 884.433,166.619 884.442,166.622 884.451,166.625 884.46,166.628 884.469,166.631 884.479,166.634 884.488,166.637 884.497,166.64 884.506,166.643 884.515,166.646 884.525,166.648 884.534,166.651 884.543,166.654 884.552,166.657 884.561,166.66 884.571,166.663 884.58,166.666 884.589,166.669 884.598,166.672 884.607,166.675 884.616,166.678 884.626,166.681 884.635,166.684 884.644,166.687 884.653,166.689 884.662,166.692 884.672,166.695 884.681,166.698 884.69,166.701 884.699,166.704 884.708,166.707 884.718,166.71 884.727,166.713 884.736,166.716 884.745,166.719 884.754,166.722 884.763,166.725 884.773,166.728 884.782,166.73 884.791,166.733 884.8,166.736 884.809,166.739 884.819,166.742 884.828,166.745 884.837,166.748 884.846,166.751 884.855,166.754 884.865,166.757 884.874,166.76 884.883,166.763 884.892,166.766 884.901,166.769 884.911,166.771 884.92,166.774 884.929,166.777 884.938,166.78 884.947,166.783 884.956,166.786 884.966,166.789 884.975,166.792 884.984,166.795 884.993,166.798 885.002,166.801 885.012,166.804 885.021,166.807 885.03,166.809 885.039,166.812 885.048,166.815 885.058,166.818 885.067,166.821 885.076,166.824 885.085,166.827 885.094,166.83 885.103,166.833 885.113,166.836 885.122,166.839 885.131,166.842 885.14,166.845 885.149,166.848 885.159,166.85 885.168,166.853 885.177,166.856 885.186,166.859 885.195,166.862 885.205,166.865 885.214,166.868 885.223,166.871 885.232,166.874 885.241,166.877 885.251,166.88 885.26,166.883 885.269,166.886 885.278,166.889 885.287,166.891 885.296,166.894 885.306,166.897 885.315,166.9 885.324,166.903 885.333,166.906 885.342,166.909 885.352,166.912 885.361,166.915 885.37,166.918 885.379,166.921 885.388,166.924 885.398,166.927 885.407,166.929 885.416,166.932 885.425,166.935 885.434,166.938 885.443,166.941 885.453,166.944 885.462,166.947 885.471,166.95 885.48,166.953 885.489,166.956 885.499,166.959 885.508,166.962 885.517,166.965 885.526,166.968 885.535,166.97 885.545,166.973 885.554,166.976 885.563,166.979 885.572,166.982 885.581,166.985 885.591,166.988 885.6,166.991 885.609,166.994 885.618,166.997 885.627,167 885.636,167.003 885.646,167.006 885.655,167.008 885.664,167.011 885.673,167.014 885.682,167.017 885.692,167.02 885.701,167.023 885.71,167.026 885.719,167.029 885.728,167.032 885.738,167.035 885.747,167.038 885.756,167.041 885.765,167.044 885.774,167.047 885.783,167.049 885.793,167.052 885.802,167.055 885.811,167.058 885.82,167.061 885.829,167.064 885.839,167.067 885.848,167.07 885.857,167.073 885.866,167.076 885.875,167.079 885.885,167.082 885.894,167.085 885.903,167.087 885.912,167.09 885.921,167.093 885.931,167.096 885.94,167.099 885.949,167.102 885.958,167.105 885.967,167.108 885.976,167.111 885.986,167.114 885.995,167.117 886.004,167.12 886.013,167.123 886.022,167.126 886.032,167.128 886.041,167.131 886.05,167.134 886.059,167.137 886.068,167.14 886.078,167.143 886.087,167.146 886.096,167.149 886.105,167.152 886.114,167.155 886.124,167.158 886.133,167.161 886.142,167.164 886.151,167.166 886.16,167.169 886.169,167.172 886.179,167.175 886.188,167.178 886.197,167.181 886.206,167.184 886.215,167.187 886.225,167.19 886.234,167.193 886.243,167.196 886.252,167.199 886.261,167.202 886.271,167.204 886.28,167.207 886.289,167.21 886.298,167.213 886.307,167.216 886.316,167.219 886.326,167.222 886.335,167.225 886.344,167.228 886.353,167.231 886.362,167.234 886.372,167.237 886.381,167.24 886.39,167.243 886.399,167.245 886.408,167.248 886.418,167.251 886.427,167.254 886.436,167.257 886.445,167.26 886.454,167.263 886.464,167.266 886.473,167.269 886.482,167.272 886.491,167.275 886.5,167.278 886.509,167.281 886.519,167.283 886.528,167.286 886.537,167.289 886.546,167.292 886.555,167.295 886.565,167.298 886.574,167.301 886.583,167.304 886.592,167.307 886.601,167.31 886.611,167.313 886.62,167.316 886.629,167.319 886.638,167.321 886.647,167.324 886.656,167.327 886.666,167.33 886.675,167.333 886.684,167.336 886.693,167.339 886.702,167.342 886.712,167.345 886.721,167.348 886.73,167.351 886.739,167.354 886.748,167.357 886.758,167.359 886.767,167.362 886.776,167.365 886.785,167.368 886.794,167.371 886.804,167.374 886.813,167.377 886.822,167.38 886.831,167.383 886.84,167.386 886.849,167.389 886.859,167.392 886.868,167.395 886.877,167.398 886.886,167.4 886.895,167.403 886.905,167.406 886.914,167.409 886.923,167.412 886.932,167.415 886.941,167.418 886.951,167.421 886.96,167.424 886.969,167.427 886.978,167.43 886.987,167.433 886.996,167.436 887.006,167.438 887.015,167.441 887.024,167.444 887.033,167.447 887.042,167.45 887.052,167.453 887.061,167.456 887.07,167.459 887.079,167.462 887.088,167.465 887.098,167.468 887.107,167.471 887.116,167.474 887.125,167.476 887.134,167.479 887.144,167.482 887.153,167.485 887.162,167.488 887.171,167.491 887.18,167.494 887.189,167.497 887.199,167.5 887.208,167.503 887.217,167.506 887.226,167.509 887.235,167.512 887.245,167.514 887.254,167.517 887.263,167.52 887.272,167.523 887.281,167.526 887.291,167.529 887.3,167.532 887.309,167.535 887.318,167.538 887.327,167.541 887.336,167.544 887.346,167.547 887.355,167.55 887.364,167.552 887.373,167.555 887.382,167.558 887.392,167.561 887.401,167.564 887.41,167.567 887.419,167.57 887.428,167.573 887.438,167.576 887.447,167.579 887.456,167.582 887.465,167.585 887.474,167.588 887.484,167.59 887.493,167.593 887.502,167.596 887.511,167.599 887.52,167.602 887.529,167.605 887.539,167.608 887.548,167.611 887.557,167.614 887.566,167.617 887.575,167.62 887.585,167.623 887.594,167.626 887.603,167.628 887.612,167.631 887.621,167.634 887.631,167.637 887.64,167.64 887.649,167.643 887.658,167.646 887.667,167.649 887.676,167.652 887.686,167.655 887.695,167.658 887.704,167.661 887.713,167.664 887.722,167.666 887.732,167.669 887.741,167.672 887.75,167.675 887.759,167.678 887.768,167.681 887.778,167.684 887.787,167.687 887.796,167.69 887.805,167.693 887.814,167.696 887.824,167.699 887.833,167.702 887.842,167.704 887.851,167.707 887.86,167.71 887.869,167.713 887.879,167.716 887.888,167.719 887.897,167.722 887.906,167.725 887.915,167.728 887.925,167.731 887.934,167.734 887.943,167.737 887.952,167.739 887.961,167.742 887.971,167.745 887.98,167.748 887.989,167.751 887.998,167.754 888.007,167.757 888.016,167.76 888.026,167.763 888.035,167.766 888.044,167.769 888.053,167.772 888.062,167.775 888.072,167.777 888.081,167.78 888.09,167.783 888.099,167.786 888.108,167.789 888.118,167.792 888.127,167.795 888.136,167.798 888.145,167.801 888.154,167.804 888.164,167.807 888.173,167.81 888.182,167.813 888.191,167.815 888.2,167.818 888.209,167.821 888.219,167.824 888.228,167.827 888.237,167.83 888.246,167.833 888.255,167.836 888.265,167.839 888.274,167.842 888.283,167.845 888.292,167.848 888.301,167.851 888.311,167.853 888.32,167.856 888.329,167.859 888.338,167.862 888.347,167.865 888.356,167.868 888.366,167.871 888.375,167.874 888.384,167.877 888.393,167.88 888.402,167.883 888.412,167.886 888.421,167.889 888.43,167.891 888.439,167.894 888.448,167.897 888.458,167.9 888.467,167.903 888.476,167.906 888.485,167.909 888.494,167.912 888.504,167.915 888.513,167.918 888.522,167.921 888.531,167.924 888.54,167.926 888.549,167.929 888.559,167.932 888.568,167.935 888.577,167.938 888.586,167.941 888.595,167.944 888.605,167.947 888.614,167.95 888.623,167.953 888.632,167.956 888.641,167.959 888.651,167.962 888.66,167.964 888.669,167.967 888.678,167.97 888.687,167.973 888.697,167.976 888.706,167.979 888.715,167.982 888.724,167.985 888.733,167.988 888.742,167.991 888.752,167.994 888.761,167.997 888.77,168 888.779,168.002 888.788,168.005 888.798,168.008 888.807,168.011 888.816,168.014 888.825,168.017 888.834,168.02 888.844,168.023 888.853,168.026 888.862,168.029 888.871,168.032 888.88,168.035 888.889,168.037 888.899,168.04 888.908,168.043 888.917,168.046 888.926,168.049 888.935,168.052 888.945,168.055 888.954,168.058 888.963,168.061 888.972,168.064 888.981,168.067 888.991,168.07 889,168.073 889.009,168.075 889.018,168.078 889.027,168.081 889.037,168.084 889.046,168.087 889.055,168.09 889.064,168.093 889.073,168.096 889.082,168.099 889.092,168.102 889.101,168.105 889.11,168.108 889.119,168.11 889.128,168.113 889.138,168.116 889.147,168.119 889.156,168.122 889.165,168.125 889.174,168.128 889.184,168.131 889.193,168.134 889.202,168.137 889.211,168.14 889.22,168.143 889.229,168.146 889.239,168.148 889.248,168.151 889.257,168.154 889.266,168.157 889.275,168.16 889.285,168.163 889.294,168.166 889.303,168.169 889.312,168.172 889.321,168.175 889.331,168.178 889.34,168.181 889.349,168.183 889.358,168.186 889.367,168.189 889.377,168.192 889.386,168.195 889.395,168.198 889.404,168.201 889.413,168.204 889.422,168.207 889.432,168.21 889.441,168.213 889.45,168.216 889.459,168.219 889.468,168.221 889.478,168.224 889.487,168.227 889.496,168.23 889.505,168.233 889.514,168.236 889.524,168.239 889.533,168.242 889.542,168.245 889.551,168.248 889.56,168.251 889.569,168.254 889.579,168.256 889.588,168.259 889.597,168.262 889.606,168.265 889.615,168.268 889.625,168.271 889.634,168.274 889.643,168.277 889.652,168.28 889.661,168.283 889.671,168.286 889.68,168.289 889.689,168.292 889.698,168.294 889.707,168.297 889.717,168.3 889.726,168.303 889.735,168.306 889.744,168.309 889.753,168.312 889.762,168.315 889.772,168.318 889.781,168.321 889.79,168.324 889.799,168.327 889.808,168.329 889.818,168.332 889.827,168.335 889.836,168.338 889.845,168.341 889.854,168.344 889.864,168.347 889.873,168.35 889.882,168.353 889.891,168.356 889.9,168.359 889.909,168.362 889.919,168.364 889.928,168.367 889.937,168.37 889.946,168.373 889.955,168.376 889.965,168.379 889.974,168.382 889.983,168.385 889.992,168.388 890.001,168.391 890.011,168.394 890.02,168.397 890.029,168.4 890.038,168.402 890.047,168.405 890.057,168.408 890.066,168.411 890.075,168.414 890.084,168.417 890.093,168.42 890.102,168.423 890.112,168.426 890.121,168.429 890.13,168.432 890.139,168.435 890.148,168.437 890.158,168.44 890.167,168.443 890.176,168.446 890.185,168.449 890.194,168.452 890.204,168.455 890.213,168.458 890.222,168.461 890.231,168.464 890.24,168.467 890.249,168.47 890.259,168.472 890.268,168.475 890.277,168.478 890.286,168.481 890.295,168.484 890.305,168.487 890.314,168.49 890.323,168.493 890.332,168.496 890.341,168.499 890.351,168.502 890.36,168.505 890.369,168.508 890.378,168.51 890.387,168.513 890.397,168.516 890.406,168.519 890.415,168.522 890.424,168.525 890.433,168.528 890.442,168.531 890.452,168.534 890.461,168.537 890.47,168.54 890.479,168.543 890.488,168.545 890.498,168.548 890.507,168.551 890.516,168.554 890.525,168.557 890.534,168.56 890.544,168.563 890.553,168.566 890.562,168.569 890.571,168.572 890.58,168.575 890.589,168.578 890.599,168.58 890.608,168.583 890.617,168.586 890.626,168.589 890.635,168.592 890.645,168.595 890.654,168.598 890.663,168.601 890.672,168.604 890.681,168.607 890.691,168.61 890.7,168.613 890.709,168.615 890.718,168.618 890.727,168.621 890.737,168.624 890.746,168.627 890.755,168.63 890.764,168.633 890.773,168.636 890.782,168.639 890.792,168.642 890.801,168.645 890.81,168.648 890.819,168.65 890.828,168.653 890.838,168.656 890.847,168.659 890.856,168.662 890.865,168.665 890.874,168.668 890.884,168.671 890.893,168.674 890.902,168.677 890.911,168.68 890.92,168.683 890.929,168.685 890.939,168.688 890.948,168.691 890.957,168.694 890.966,168.697 890.975,168.7 890.985,168.703 890.994,168.706 891.003,168.709 891.012,168.712 891.021,168.715 891.031,168.718 891.04,168.72 891.049,168.723 891.058,168.726 891.067,168.729 891.077,168.732 891.086,168.735 891.095,168.738 891.104,168.741 891.113,168.744 891.122,168.747 891.132,168.75 891.141,168.753 891.15,168.755 891.159,168.758 891.168,168.761 891.178,168.764 891.187,168.767 891.196,168.77 891.205,168.773 891.214,168.776 891.224,168.779 891.233,168.782 891.242,168.785 891.251,168.788 891.26,168.791 891.27,168.793 891.279,168.796 891.288,168.799 891.297,168.802 891.306,168.805 891.315,168.808 891.325,168.811 891.334,168.814 891.343,168.817 891.352,168.82 891.361,168.823 891.371,168.826 891.38,168.828 891.389,168.831 891.398,168.834 891.407,168.837 891.417,168.84 891.426,168.843 891.435,168.846 891.444,168.849 891.453,168.852 891.462,168.855 891.472,168.858 891.481,168.86 891.49,168.863 891.499,168.866 891.508,168.869 891.518,168.872 891.527,168.875 891.536,168.878 891.545,168.881 891.554,168.884 891.564,168.887 891.573,168.89 891.582,168.893 891.591,168.895 891.6,168.898 891.61,168.901 891.619,168.904 891.628,168.907 891.637,168.91 891.646,168.913 891.655,168.916 891.665,168.919 891.674,168.922 891.683,168.925 891.692,168.928 891.701,168.93 891.711,168.933 891.72,168.936 891.729,168.939 891.738,168.942 891.747,168.945 891.757,168.948 891.766,168.951 891.775,168.954 891.784,168.957 891.793,168.96 891.802,168.963 891.812,168.965 891.821,168.968 891.83,168.971 891.839,168.974 891.848,168.977 891.858,168.98 891.867,168.983 891.876,168.986 891.885,168.989 891.894,168.992 891.904,168.995 891.913,168.998 891.922,169 891.931,169.003 891.94,169.006 891.95,169.009 891.959,169.012 891.968,169.015 891.977,169.018 891.986,169.021 891.995,169.024 892.005,169.027 892.014,169.03 892.023,169.033 892.032,169.035 892.041,169.038 892.051,169.041 892.06,169.044 892.069,169.047 892.078,169.05 892.087,169.053 892.097,169.056 892.106,169.059 892.115,169.062 892.124,169.065 892.133,169.068 892.142,169.07 892.152,169.073 892.161,169.076 892.17,169.079 892.179,169.082 892.188,169.085 892.198,169.088 892.207,169.091 892.216,169.094 892.225,169.097 892.234,169.1 892.244,169.103 892.253,169.105 892.262,169.108 892.271,169.111 892.28,169.114 892.29,169.117 892.299,169.12 892.308,169.123 892.317,169.126 892.326,169.129 892.335,169.132 892.345,169.135 892.354,169.137 892.363,169.14 892.372,169.143 892.381,169.146 892.391,169.149 892.4,169.152 892.409,169.155 892.418,169.158 892.427,169.161 892.437,169.164 892.446,169.167 892.455,169.17 892.464,169.172 892.473,169.175 892.482,169.178 892.492,169.181 892.501,169.184 892.51,169.187 892.519,169.19 892.528,169.193 892.538,169.196 892.547,169.199 892.556,169.202 892.565,169.205 892.574,169.207 892.584,169.21 892.593,169.213 892.602,169.216 892.611,169.219 892.62,169.222 892.63,169.225 892.639,169.228 892.648,169.231 892.657,169.234 892.666,169.237 892.675,169.239 892.685,169.242 892.694,169.245 892.703,169.248 892.712,169.251 892.721,169.254 892.731,169.257 892.74,169.26 892.749,169.263 892.758,169.266 892.767,169.269 892.777,169.272 892.786,169.274 892.795,169.277 892.804,169.28 892.813,169.283 892.822,169.286 892.832,169.289 892.841,169.292 892.85,169.295 892.859,169.298 892.868,169.301 892.878,169.304 892.887,169.307 892.896,169.309 892.905,169.312 892.914,169.315 892.924,169.318 892.933,169.321 892.942,169.324 892.951,169.327 892.96,169.33 892.97,169.333 892.979,169.336 892.988,169.339 892.997,169.341 893.006,169.344 893.015,169.347 893.025,169.35 893.034,169.353 893.043,169.356 893.052,169.359 893.061,169.362 893.071,169.365 893.08,169.368 893.089,169.371 893.098,169.374 893.107,169.376 893.117,169.379 893.126,169.382 893.135,169.385 893.144,169.388 893.153,169.391 893.162,169.394 893.172,169.397 893.181,169.4 893.19,169.403 893.199,169.406 893.208,169.408 893.218,169.411 893.227,169.414 893.236,169.417 893.245,169.42 893.254,169.423 893.264,169.426 893.273,169.429 893.282,169.432 893.291,169.435 893.3,169.438 893.31,169.441 893.319,169.443 893.328,169.446 893.337,169.449 893.346,169.452 893.355,169.455 893.365,169.458 893.374,169.461 893.383,169.464 893.392,169.467 893.401,169.47 893.411,169.473 893.42,169.476 893.429,169.478 893.438,169.481 893.447,169.484 893.457,169.487 893.466,169.49 893.475,169.493 893.484,169.496 893.493,169.499 893.503,169.502 893.512,169.505 893.521,169.508 893.53,169.51 893.539,169.513 893.548,169.516 893.558,169.519 893.567,169.522 893.576,169.525 893.585,169.528 893.594,169.531 893.604,169.534 893.613,169.537 893.622,169.54 893.631,169.542 893.64,169.545 893.65,169.548 893.659,169.551 893.668,169.554 893.677,169.557 893.686,169.56 893.695,169.563 893.705,169.566 893.714,169.569 893.723,169.572 893.732,169.575 893.741,169.577 893.751,169.58 893.76,169.583 893.769,169.586 893.778,169.589 893.787,169.592 893.797,169.595 893.806,169.598 893.815,169.601 893.824,169.604 893.833,169.607 893.843,169.609 893.852,169.612 893.861,169.615 893.87,169.618 893.879,169.621 893.888,169.624 893.898,169.627 893.907,169.63 893.916,169.633 893.925,169.636 893.934,169.639 893.944,169.642 893.953,169.644 893.962,169.647 893.971,169.65 893.98,169.653 893.99,169.656 893.999,169.659 894.008,169.662 894.017,169.665 894.026,169.668 894.035,169.671 894.045,169.674 894.054,169.676 894.063,169.679 894.072,169.682 894.081,169.685 894.091,169.688 894.1,169.691 894.109,169.694 894.118,169.697 894.127,169.7 894.137,169.703 894.146,169.706 894.155,169.709 894.164,169.711 894.173,169.714 894.183,169.717 894.192,169.72 894.201,169.723 894.21,169.726 894.219,169.729 894.228,169.732 894.238,169.735 894.247,169.738 894.256,169.741 894.265,169.743 894.274,169.746 894.284,169.749 894.293,169.752 894.302,169.755 894.311,169.758 894.32,169.761 894.33,169.764 894.339,169.767 894.348,169.77 894.357,169.773 894.366,169.775 894.375,169.778 894.385,169.781 894.394,169.784 894.403,169.787 894.412,169.79 894.421,169.793 894.431,169.796 894.44,169.799 894.449,169.802 894.458,169.805 894.467,169.807 894.477,169.81 894.486,169.813 894.495,169.816 894.504,169.819 894.513,169.822 894.523,169.825 894.532,169.828 894.541,169.831 894.55,169.834 894.559,169.837 894.568,169.84 894.578,169.842 894.587,169.845 894.596,169.848 894.605,169.851 894.614,169.854 894.624,169.857 894.633,169.86 894.642,169.863 894.651,169.866 894.66,169.869 894.67,169.872 894.679,169.874 894.688,169.877 894.697,169.88 894.706,169.883 894.715,169.886 894.725,169.889 894.734,169.892 894.743,169.895 894.752,169.898 894.761,169.901 894.771,169.904 894.78,169.906 894.789,169.909 894.798,169.912 894.807,169.915 894.817,169.918 894.826,169.921 894.835,169.924 894.844,169.927 894.853,169.93 894.863,169.933 894.872,169.936 894.881,169.938 894.89,169.941 894.899,169.944 894.908,169.947 894.918,169.95 894.927,169.953 894.936,169.956 894.945,169.959 894.954,169.962 894.964,169.965 894.973,169.968 894.982,169.971 894.991,169.973 895,169.976 895.01,169.979 895.019,169.982 895.028,169.985 895.037,169.988 895.046,169.991 895.055,169.994 895.065,169.997 895.074,170 895.083,170.003 895.092,170.005 895.101,170.008 895.111,170.011 895.12,170.014 895.129,170.017 895.138,170.02 895.147,170.023 895.157,170.026 895.166,170.029 895.175,170.032 895.184,170.035 895.193,170.037 895.203,170.04 895.212,170.043 895.221,170.046 895.23,170.049 895.239,170.052 895.248,170.055 895.258,170.058 895.267,170.061 895.276,170.064 895.285,170.067 895.294,170.069 895.304,170.072 895.313,170.075 895.322,170.078 895.331,170.081 895.34,170.084 895.35,170.087 895.359,170.09 895.368,170.093 895.377,170.096 895.386,170.099 895.395,170.101 895.405,170.104 895.414,170.107 895.423,170.11 895.432,170.113 895.441,170.116 895.451,170.119 895.46,170.122 895.469,170.125 895.478,170.128 895.487,170.131 895.497,170.133 895.506,170.136 895.515,170.139 895.524,170.142 895.533,170.145 895.543,170.148 895.552,170.151 895.561,170.154 895.57,170.157 895.579,170.16 895.588,170.163 895.598,170.165 895.607,170.168 895.616,170.171 895.625,170.174 895.634,170.177 895.644,170.18 895.653,170.183 895.662,170.186 895.671,170.189 895.68,170.192 895.69,170.195 895.699,170.197 895.708,170.2 895.717,170.203 895.726,170.206 895.735,170.209 895.745,170.212 895.754,170.215 895.763,170.218 895.772,170.221 895.781,170.224 895.791,170.227 895.8,170.229 895.809,170.232 895.818,170.235 895.827,170.238 895.837,170.241 895.846,170.244 895.855,170.247 895.864,170.25 895.873,170.253 895.883,170.256 895.892,170.259 895.901,170.261 895.91,170.264 895.919,170.267 895.928,170.27 895.938,170.273 895.947,170.276 895.956,170.279 895.965,170.282 895.974,170.285 895.984,170.288 895.993,170.291 896.002,170.293 896.011,170.296 896.02,170.299 896.03,170.302 896.039,170.305 896.048,170.308 896.057,170.311 896.066,170.314 896.076,170.317 896.085,170.32 896.094,170.323 896.103,170.325 896.112,170.328 896.121,170.331 896.131,170.334 896.14,170.337 896.149,170.34 896.158,170.343 896.167,170.346 896.177,170.349 896.186,170.352 896.195,170.355 896.204,170.357 896.213,170.36 896.223,170.363 896.232,170.366 896.241,170.369 896.25,170.372 896.259,170.375 896.268,170.378 896.278,170.381 896.287,170.384 896.296,170.387 896.305,170.389 896.314,170.392 896.324,170.395 896.333,170.398 896.342,170.401 896.351,170.404 896.36,170.407 896.37,170.41 896.379,170.413 896.388,170.416 896.397,170.419 896.406,170.421 896.416,170.424 896.425,170.427 896.434,170.43 896.443,170.433 896.452,170.436 896.461,170.439 896.471,170.442 896.48,170.445 896.489,170.448 896.498,170.451 896.507,170.453 896.517,170.456 896.526,170.459 896.535,170.462 896.544,170.465 896.553,170.468 896.563,170.471 896.572,170.474 896.581,170.477 896.59,170.48 896.599,170.483 896.608,170.485 896.618,170.488 896.627,170.491 896.636,170.494 896.645,170.497 896.654,170.5 896.664,170.503 896.673,170.506 896.682,170.509 896.691,170.512 896.7,170.514 896.71,170.517 896.719,170.52 896.728,170.523 896.737,170.526 896.746,170.529 896.756,170.532 896.765,170.535 896.774,170.538 896.783,170.541 896.792,170.544 896.801,170.546 896.811,170.549 896.82,170.552 896.829,170.555 896.838,170.558 896.847,170.561 896.857,170.564 896.866,170.567 896.875,170.57 896.884,170.573 896.893,170.576 896.903,170.578 896.912,170.581 896.921,170.584 896.93,170.587 896.939,170.59 896.948,170.593 896.958,170.596 896.967,170.599 896.976,170.602 896.985,170.605 896.994,170.608 897.004,170.61 897.013,170.613 897.022,170.616 897.031,170.619 897.04,170.622 897.05,170.625 897.059,170.628 897.068,170.631 897.077,170.634 897.086,170.637 897.096,170.639 897.105,170.642 897.114,170.645 897.123,170.648 897.132,170.651 897.141,170.654 897.151,170.657 897.16,170.66 897.169,170.663 897.178,170.666 897.187,170.669 897.197,170.671 897.206,170.674 897.215,170.677 897.224,170.68 897.233,170.683 897.243,170.686 897.252,170.689 897.261,170.692 897.27,170.695 897.279,170.698 897.288,170.701 897.298,170.703 897.307,170.706 897.316,170.709 897.325,170.712 897.334,170.715 897.344,170.718 897.353,170.721 897.362,170.724 897.371,170.727 897.38,170.73 897.39,170.733 897.399,170.735 897.408,170.738 897.417,170.741 897.426,170.744 897.436,170.747 897.445,170.75 897.454,170.753 897.463,170.756 897.472,170.759 897.481,170.762 897.491,170.764 897.5,170.767 897.509,170.77 897.518,170.773 897.527,170.776 897.537,170.779 897.546,170.782 897.555,170.785 897.564,170.788 897.573,170.791 897.583,170.794 897.592,170.796 897.601,170.799 897.61,170.802 897.619,170.805 897.628,170.808 897.638,170.811 897.647,170.814 897.656,170.817 897.665,170.82 897.674,170.823 897.684,170.826 897.693,170.828 897.702,170.831 897.711,170.834 897.72,170.837 897.73,170.84 897.739,170.843 897.748,170.846 897.757,170.849 897.766,170.852 897.776,170.855 897.785,170.857 897.794,170.86 897.803,170.863 897.812,170.866 897.821,170.869 897.831,170.872 897.84,170.875 897.849,170.878 897.858,170.881 897.867,170.884 897.877,170.887 897.886,170.889 897.895,170.892 897.904,170.895 897.913,170.898 897.923,170.901 897.932,170.904 897.941,170.907 897.95,170.91 897.959,170.913 897.968,170.916 897.978,170.918 897.987,170.921 897.996,170.924 898.005,170.927 898.014,170.93 898.024,170.933 898.033,170.936 898.042,170.939 898.051,170.942 898.06,170.945 898.07,170.948 898.079,170.95 898.088,170.953 898.097,170.956 898.106,170.959 898.116,170.962 898.125,170.965 898.134,170.968 898.143,170.971 898.152,170.974 898.161,170.977 898.171,170.979 898.18,170.982 898.189,170.985 898.198,170.988 898.207,170.991 898.217,170.994 898.226,170.997 898.235,171 898.244,171.003 898.253,171.006 898.263,171.009 898.272,171.011 898.281,171.014 898.29,171.017 898.299,171.02 898.308,171.023 898.318,171.026 898.327,171.029 898.336,171.032 898.345,171.035 898.354,171.038 898.364,171.04 898.373,171.043 898.382,171.046 898.391,171.049 898.4,171.052 898.41,171.055 898.419,171.058 898.428,171.061 898.437,171.064 898.446,171.067 898.456,171.07 898.465,171.072 898.474,171.075 898.483,171.078 898.492,171.081 898.501,171.084 898.511,171.087 898.52,171.09 898.529,171.093 898.538,171.096 898.547,171.099 898.557,171.101 898.566,171.104 898.575,171.107 898.584,171.11 898.593,171.113 898.603,171.116 898.612,171.119 898.621,171.122 898.63,171.125 898.639,171.128 898.649,171.131 898.658,171.133 898.667,171.136 898.676,171.139 898.685,171.142 898.694,171.145 898.704,171.148 898.713,171.151 898.722,171.154 898.731,171.157 898.74,171.16 898.75,171.162 898.759,171.165 898.768,171.168 898.777,171.171 898.786,171.174 898.796,171.177 898.805,171.18 898.814,171.183 898.823,171.186 898.832,171.189 898.841,171.192 898.851,171.194 898.86,171.197 898.869,171.2 898.878,171.203 898.887,171.206 898.897,171.209 898.906,171.212 898.915,171.215 898.924,171.218 898.933,171.221 898.943,171.223 898.952,171.226 898.961,171.229 898.97,171.232 898.979,171.235 898.989,171.238 898.998,171.241 899.007,171.244 899.016,171.247 899.025,171.25 899.034,171.252 899.044,171.255 899.053,171.258 899.062,171.261 899.071,171.264 899.08,171.267 899.09,171.27 899.099,171.273 899.108,171.276 899.117,171.279 899.126,171.282 899.136,171.284 899.145,171.287 899.154,171.29 899.163,171.293 899.172,171.296 899.181,171.299 899.191,171.302 899.2,171.305 899.209,171.308 899.218,171.311 899.227,171.313 899.237,171.316 899.246,171.319 899.255,171.322 899.264,171.325 899.273,171.328 899.283,171.331 899.292,171.334 899.301,171.337 899.31,171.34 899.319,171.342 899.329,171.345 899.338,171.348 899.347,171.351 899.356,171.354 899.365,171.357 899.374,171.36 899.384,171.363 899.393,171.366 899.402,171.369 899.411,171.372 899.42,171.374 899.43,171.377 899.439,171.38 899.448,171.383 899.457,171.386 899.466,171.389 899.476,171.392 899.485,171.395 899.494,171.398 899.503,171.401 899.512,171.403 899.521,171.406 899.531,171.409 899.54,171.412 899.549,171.415 899.558,171.418 899.567,171.421 899.577,171.424 899.586,171.427 899.595,171.43 899.604,171.432 899.613,171.435 899.623,171.438 899.632,171.441 899.641,171.444 899.65,171.447 899.659,171.45 899.669,171.453 899.678,171.456 899.687,171.459 899.696,171.462 899.705,171.464 899.714,171.467 899.724,171.47 899.733,171.473 899.742,171.476 899.751,171.479 899.76,171.482 899.77,171.485 899.779,171.488 899.788,171.491 899.797,171.493 899.806,171.496 899.816,171.499 899.825,171.502 899.834,171.505 899.843,171.508 899.852,171.511 899.861,171.514 899.871,171.517 899.88,171.52 899.889,171.522 899.898,171.525 899.907,171.528 899.917,171.531 899.926,171.534 899.935,171.537 899.944,171.54 899.953,171.543 899.963,171.546 899.972,171.549 899.981,171.551 899.99,171.554 899.999,171.557 900.009,171.56 900.018,171.563 900.027,171.566 900.036,171.569 900.045,171.572 900.054,171.575 900.064,171.578 900.073,171.58 900.082,171.583 900.091,171.586 900.1,171.589 900.11,171.592 900.119,171.595 900.128,171.598 900.137,171.601 900.146,171.604 900.156,171.607 900.165,171.61 900.174,171.612 900.183,171.615 900.192,171.618 900.201,171.621 900.211,171.624 900.22,171.627 900.229,171.63 900.238,171.633 900.247,171.636 900.257,171.639 900.266,171.641 900.275,171.644 900.284,171.647 900.293,171.65 900.303,171.653 900.312,171.656 900.321,171.659 900.33,171.662 900.339,171.665 900.349,171.668 900.358,171.67 900.367,171.673 900.376,171.676 900.385,171.679 900.394,171.682 900.404,171.685 900.413,171.688 900.422,171.691 900.431,171.694 900.44,171.697 900.45,171.699 900.459,171.702 900.468,171.705 900.477,171.708 900.486,171.711 900.496,171.714 900.505,171.717 900.514,171.72 900.523,171.723 900.532,171.726 900.541,171.728 900.551,171.731 900.56,171.734 900.569,171.737 900.578,171.74 900.587,171.743 900.597,171.746 900.606,171.749 900.615,171.752 900.624,171.755 900.633,171.757 900.643,171.76 900.652,171.763 900.661,171.766 900.67,171.769 900.679,171.772 900.689,171.775 900.698,171.778 900.707,171.781 900.716,171.784 900.725,171.786 900.734,171.789 900.744,171.792 900.753,171.795 900.762,171.798 900.771,171.801 900.78,171.804 900.79,171.807 900.799,171.81 900.808,171.813 900.817,171.815 900.826,171.818 900.836,171.821 900.845,171.824 900.854,171.827 900.863,171.83 900.872,171.833 900.882,171.836 900.891,171.839 900.9,171.842 900.909,171.844 900.918,171.847 900.927,171.85 900.937,171.853 900.946,171.856 900.955,171.859 900.964,171.862 900.973,171.865 900.983,171.868 900.992,171.871 901.001,171.873 901.01,171.876 901.019,171.879 901.029,171.882 901.038,171.885 901.047,171.888 901.056,171.891 901.065,171.894 901.074,171.897 901.084,171.9 901.093,171.902 901.102,171.905 901.111,171.908 901.12,171.911 901.13,171.914 901.139,171.917 901.148,171.92 901.157,171.923 901.166,171.926 901.176,171.929 901.185,171.931 901.194,171.934 901.203,171.937 901.212,171.94 901.222,171.943 901.231,171.946 901.24,171.949 901.249,171.952 901.258,171.955 901.267,171.958 901.277,171.96 901.286,171.963 901.295,171.966 901.304,171.969 901.313,171.972 901.323,171.975 901.332,171.978 901.341,171.981 901.35,171.984 901.359,171.987 901.369,171.989 901.378,171.992 901.387,171.995 901.396,171.998 901.405,172.001 901.414,172.004 901.424,172.007 901.433,172.01 901.442,172.013 901.451,172.016 901.46,172.018 901.47,172.021 901.479,172.024 901.488,172.027 901.497,172.03 901.506,172.033 901.516,172.036 901.525,172.039 901.534,172.042 901.543,172.045 901.552,172.047 901.562,172.05 901.571,172.053 901.58,172.056 901.589,172.059 901.598,172.062 901.607,172.065 901.617,172.068 901.626,172.071 901.635,172.074 901.644,172.076 901.653,172.079 901.663,172.082 901.672,172.085 901.681,172.088 901.69,172.091 901.699,172.094 901.709,172.097 901.718,172.1 901.727,172.103 901.736,172.105 901.745,172.108 901.754,172.111 901.764,172.114 901.773,172.117 901.782,172.12 901.791,172.123 901.8,172.126 901.81,172.129 901.819,172.132 901.828,172.134 901.837,172.137 901.846,172.14 901.856,172.143 901.865,172.146 901.874,172.149 901.883,172.152 901.892,172.155 901.902,172.158 901.911,172.161 901.92,172.163 901.929,172.166 901.938,172.169 901.947,172.172 901.957,172.175 901.966,172.178 901.975,172.181 901.984,172.184 901.993,172.187 902.003,172.19 902.012,172.192 902.021,172.195 902.03,172.198 902.039,172.201 902.049,172.204 902.058,172.207 902.067,172.21 902.076,172.213 902.085,172.216 902.094,172.218 902.104,172.221 902.113,172.224 902.122,172.227 902.131,172.23 902.14,172.233 902.15,172.236 902.159,172.239 902.168,172.242 902.177,172.245 902.186,172.247 902.196,172.25 902.205,172.253 902.214,172.256 902.223,172.259 902.232,172.262 902.242,172.265 902.251,172.268 902.26,172.271 902.269,172.274 902.278,172.276 902.287,172.279 902.297,172.282 902.306,172.285 902.315,172.288 902.324,172.291 902.333,172.294 902.343,172.297 902.352,172.3 902.361,172.303 902.37,172.305 902.379,172.308 902.389,172.311 902.398,172.314 902.407,172.317 902.416,172.32 902.425,172.323 902.434,172.326 902.444,172.329 902.453,172.332 902.462,172.334 902.471,172.337 902.48,172.34 902.49,172.343 902.499,172.346 902.508,172.349 902.517,172.352 902.526,172.355 902.536,172.358 902.545,172.36 902.554,172.363 902.563,172.366 902.572,172.369 902.582,172.372 902.591,172.375 902.6,172.378 902.609,172.381 902.618,172.384 902.627,172.387 902.637,172.389 902.646,172.392 902.655,172.395 902.664,172.398 902.673,172.401 902.683,172.404 902.692,172.407 902.701,172.41 902.71,172.413 902.719,172.416 902.729,172.418 902.738,172.421 902.747,172.424 902.756,172.427 902.765,172.43 902.774,172.433 902.784,172.436 902.793,172.439 902.802,172.442 902.811,172.445 902.82,172.447 902.83,172.45 902.839,172.453 902.848,172.456 902.857,172.459 902.866,172.462 902.876,172.465 902.885,172.468 902.894,172.471 902.903,172.473 902.912,172.476 902.922,172.479 902.931,172.482 902.94,172.485 902.949,172.488 902.958,172.491 902.967,172.494 902.977,172.497 902.986,172.5 902.995,172.502 903.004,172.505 903.013,172.508 903.023,172.511 903.032,172.514 903.041,172.517 903.05,172.52 903.059,172.523 903.069,172.526 903.078,172.529 903.087,172.531 903.096,172.534 903.105,172.537 903.114,172.54 903.124,172.543 903.133,172.546 903.142,172.549 903.151,172.552 903.16,172.555 903.17,172.557 903.179,172.56 903.188,172.563 903.197,172.566 903.206,172.569 903.216,172.572 903.225,172.575 903.234,172.578 903.243,172.581 903.252,172.584 903.262,172.586 903.271,172.589 903.28,172.592 903.289,172.595 903.298,172.598 903.307,172.601 903.317,172.604 903.326,172.607 903.335,172.61 903.344,172.613 903.353,172.615 903.363,172.618 903.372,172.621 903.381,172.624 903.39,172.627 903.399,172.63 903.409,172.633 903.418,172.636 903.427,172.639 903.436,172.641 903.445,172.644 903.455,172.647 903.464,172.65 903.473,172.653 903.482,172.656 903.491,172.659 903.5,172.662 903.51,172.665 903.519,172.668 903.528,172.67 903.537,172.673 903.546,172.676 903.556,172.679 903.565,172.682 903.574,172.685 903.583,172.688 903.592,172.691 903.602,172.694 903.611,172.696 903.62,172.699 903.629,172.702 903.638,172.705 903.647,172.708 903.657,172.711 903.666,172.714 903.675,172.717 903.684,172.72 903.693,172.723 903.703,172.725 903.712,172.728 903.721,172.731 903.73,172.734 903.739,172.737 903.749,172.74 903.758,172.743 903.767,172.746 903.776,172.749 903.785,172.752 903.795,172.754 903.804,172.757 903.813,172.76 903.822,172.763 903.831,172.766 903.84,172.769 903.85,172.772 903.859,172.775 903.868,172.778 903.877,172.78 903.886,172.783 903.896,172.786 903.905,172.789 903.914,172.792 903.923,172.795 903.932,172.798 903.942,172.801 903.951,172.804 903.96,172.807 903.969,172.809 903.978,172.812 903.987,172.815 903.997,172.818 904.006,172.821 904.015,172.824 904.024,172.827 904.033,172.83 904.043,172.833 904.052,172.835 904.061,172.838 904.07,172.841 904.079,172.844 904.089,172.847 904.098,172.85 904.107,172.853 904.116,172.856 904.125,172.859 904.135,172.862 904.144,172.864 904.153,172.867 904.162,172.87 904.171,172.873 904.18,172.876 904.19,172.879 904.199,172.882 904.208,172.885 904.217,172.888 904.226,172.89 904.236,172.893 904.245,172.896 904.254,172.899 904.263,172.902 904.272,172.905 904.282,172.908 904.291,172.911 904.3,172.914 904.309,172.917 904.318,172.919 904.327,172.922 904.337,172.925 904.346,172.928 904.355,172.931 904.364,172.934 904.373,172.937 904.383,172.94 904.392,172.943 904.401,172.945 904.41,172.948 904.419,172.951 904.429,172.954 904.438,172.957 904.447,172.96 904.456,172.963 904.465,172.966 904.475,172.969 904.484,172.972 904.493,172.974 904.502,172.977 904.511,172.98 904.52,172.983 904.53,172.986 904.539,172.989 904.548,172.992 904.557,172.995 904.566,172.998 904.576,173 904.585,173.003 904.594,173.006 904.603,173.009 904.612,173.012 904.622,173.015 904.631,173.018 904.64,173.021 904.649,173.024 904.658,173.026 904.667,173.029 904.677,173.032 904.686,173.035 904.695,173.038 904.704,173.041 904.713,173.044 904.723,173.047 904.732,173.05 904.741,173.053 904.75,173.055 904.759,173.058 904.769,173.061 904.778,173.064 904.787,173.067 904.796,173.07 904.805,173.073 904.815,173.076 904.824,173.079 904.833,173.081 904.842,173.084 904.851,173.087 904.86,173.09 904.87,173.093 904.879,173.096 904.888,173.099 904.897,173.102 904.906,173.105 904.916,173.108 904.925,173.11 904.934,173.113 904.943,173.116 904.952,173.119 904.962,173.122 904.971,173.125 904.98,173.128 904.989,173.131 904.998,173.134 905.007,173.136 905.017,173.139 905.026,173.142 905.035,173.145 905.044,173.148 905.053,173.151 905.063,173.154 905.072,173.157 905.081,173.16 905.09,173.162 905.099,173.165 905.109,173.168 905.118,173.171 905.127,173.174 905.136,173.177 905.145,173.18 905.155,173.183 905.164,173.186 905.173,173.189 905.182,173.191 905.191,173.194 905.2,173.197 905.21,173.2 905.219,173.203 905.228,173.206 905.237,173.209 905.246,173.212 905.256,173.215 905.265,173.217 905.274,173.22 905.283,173.223 905.292,173.226 905.302,173.229 905.311,173.232 905.32,173.235 905.329,173.238 905.338,173.241 905.347,173.243 905.357,173.246 905.366,173.249 905.375,173.252 905.384,173.255 905.393,173.258 905.403,173.261 905.412,173.264 905.421,173.267 905.43,173.27 905.439,173.272 905.449,173.275 905.458,173.278 905.467,173.281 905.476,173.284 905.485,173.287 905.495,173.29 905.504,173.293 905.513,173.296 905.522,173.298 905.531,173.301 905.54,173.304 905.55,173.307 905.559,173.31 905.568,173.313 905.577,173.316 905.586,173.319 905.596,173.322 905.605,173.324 905.614,173.327 905.623,173.33 905.632,173.333 905.642,173.336 905.651,173.339 905.66,173.342 905.669,173.345 905.678,173.348 905.687,173.35 905.697,173.353 905.706,173.356 905.715,173.359 905.724,173.362 905.733,173.365 905.743,173.368 905.752,173.371 905.761,173.374 905.77,173.377 905.779,173.379 905.789,173.382 905.798,173.385 905.807,173.388 905.816,173.391 905.825,173.394 905.835,173.397 905.844,173.4 905.853,173.403 905.862,173.405 905.871,173.408 905.88,173.411 905.89,173.414 905.899,173.417 905.908,173.42 905.917,173.423 905.926,173.426 905.936,173.429 905.945,173.431 905.954,173.434 905.963,173.437 905.972,173.44 905.982,173.443 905.991,173.446 906,173.449 906.009,173.452 906.018,173.455 906.028,173.457 906.037,173.46 906.046,173.463 906.055,173.466 906.064,173.469 906.073,173.472 906.083,173.475 906.092,173.478 906.101,173.481 906.11,173.484 906.119,173.486 906.129,173.489 906.138,173.492 906.147,173.495 906.156,173.498 906.165,173.501 906.175,173.504 906.184,173.507 906.193,173.51 906.202,173.512 906.211,173.515 906.22,173.518 906.23,173.521 906.239,173.524 906.248,173.527 906.257,173.53 906.266,173.533 906.276,173.536 906.285,173.538 906.294,173.541 906.303,173.544 906.312,173.547 906.322,173.55 906.331,173.553 906.34,173.556 906.349,173.559 906.358,173.562 906.368,173.564 906.377,173.567 906.386,173.57 906.395,173.573 906.404,173.576 906.413,173.579 906.423,173.582 906.432,173.585 906.441,173.588 906.45,173.59 906.459,173.593 906.469,173.596 906.478,173.599 906.487,173.602 906.496,173.605 906.505,173.608 906.515,173.611 906.524,173.614 906.533,173.616 906.542,173.619 906.551,173.622 906.56,173.625 906.57,173.628 906.579,173.631 906.588,173.634 906.597,173.637 906.606,173.64 906.616,173.643 906.625,173.645 906.634,173.648 906.643,173.651 906.652,173.654 906.662,173.657 906.671,173.66 906.68,173.663 906.689,173.666 906.698,173.669 906.708,173.671 906.717,173.674 906.726,173.677 906.735,173.68 906.744,173.683 906.753,173.686 906.763,173.689 906.772,173.692 906.781,173.695 906.79,173.697 906.799,173.7 906.809,173.703 906.818,173.706 906.827,173.709 906.836,173.712 906.845,173.715 906.855,173.718 906.864,173.721 906.873,173.723 906.882,173.726 906.891,173.729 906.9,173.732 906.91,173.735 906.919,173.738 906.928,173.741 906.937,173.744 906.946,173.747 906.956,173.749 906.965,173.752 906.974,173.755 906.983,173.758 906.992,173.761 907.002,173.764 907.011,173.767 907.02,173.77 907.029,173.773 907.038,173.775 907.048,173.778 907.057,173.781 907.066,173.784 907.075,173.787 907.084,173.79 907.093,173.793 907.103,173.796 907.112,173.799 907.121,173.801 907.13,173.804 907.139,173.807 907.149,173.81 907.158,173.813 907.167,173.816 907.176,173.819 907.185,173.822 907.195,173.825 907.204,173.827 907.213,173.83 907.222,173.833 907.231,173.836 907.24,173.839 907.25,173.842 907.259,173.845 907.268,173.848 907.277,173.851 907.286,173.853 907.296,173.856 907.305,173.859 907.314,173.862 907.323,173.865 907.332,173.868 907.342,173.871 907.351,173.874 907.36,173.877 907.369,173.879 907.378,173.882 907.388,173.885 907.397,173.888 907.406,173.891 907.415,173.894 907.424,173.897 907.433,173.9 907.443,173.903 907.452,173.905 907.461,173.908 907.47,173.911 907.479,173.914 907.489,173.917 907.498,173.92 907.507,173.923 907.516,173.926 907.525,173.929 907.535,173.931 907.544,173.934 907.553,173.937 907.562,173.94 907.571,173.943 907.58,173.946 907.59,173.949 907.599,173.952 907.608,173.955 907.617,173.957 907.626,173.96 907.636,173.963 907.645,173.966 907.654,173.969 907.663,173.972 907.672,173.975 907.682,173.978 907.691,173.981 907.7,173.983 907.709,173.986 907.718,173.989 907.728,173.992 907.737,173.995 907.746,173.998 907.755,174.001 907.764,174.004 907.773,174.007 907.783,174.009 907.792,174.012 907.801,174.015 907.81,174.018 907.819,174.021 907.829,174.024 907.838,174.027 907.847,174.03 907.856,174.033 907.865,174.035 907.875,174.038 907.884,174.041 907.893,174.044 907.902,174.047 907.911,174.05 907.92,174.053 907.93,174.056 907.939,174.059 907.948,174.061 907.957,174.064 907.966,174.067 907.976,174.07 907.985,174.073 907.994,174.076 908.003,174.079 908.012,174.082 908.022,174.085 908.031,174.087 908.04,174.09 908.049,174.093 908.058,174.096 908.068,174.099 908.077,174.102 908.086,174.105 908.095,174.108 908.104,174.111 908.113,174.113 908.123,174.116 908.132,174.119 908.141,174.122 908.15,174.125 908.159,174.128 908.169,174.131 908.178,174.134 908.187,174.137 908.196,174.139 908.205,174.142 908.215,174.145 908.224,174.148 908.233,174.151 908.242,174.154 908.251,174.157 908.261,174.16 908.27,174.163 908.279,174.165 908.288,174.168 908.297,174.171 908.306,174.174 908.316,174.177 908.325,174.18 908.334,174.183 908.343,174.186 908.352,174.188 908.362,174.191 908.371,174.194 908.38,174.197 908.389,174.2 908.398,174.203 908.408,174.206 908.417,174.209 908.426,174.212 908.435,174.214 908.444,174.217 908.453,174.22 908.463,174.223 908.472,174.226 908.481,174.229 908.49,174.232 908.499,174.235 908.509,174.238 908.518,174.24 908.527,174.243 908.536,174.246 908.545,174.249 908.555,174.252 908.564,174.255 908.573,174.258 908.582,174.261 908.591,174.264 908.601,174.266 908.61,174.269 908.619,174.272 908.628,174.275 908.637,174.278 908.646,174.281 908.656,174.284 908.665,174.287 908.674,174.29 908.683,174.292 908.692,174.295 908.702,174.298 908.711,174.301 908.72,174.304 908.729,174.307 908.738,174.31 908.748,174.313 908.757,174.316 908.766,174.318 908.775,174.321 908.784,174.324 908.793,174.327 908.803,174.33 908.812,174.333 908.821,174.336 908.83,174.339 908.839,174.341 908.849,174.344 908.858,174.347 908.867,174.35 908.876,174.353 908.885,174.356 908.895,174.359 908.904,174.362 908.913,174.365 908.922,174.367 908.931,174.37 908.941,174.373 908.95,174.376 908.959,174.379 908.968,174.382 908.977,174.385 908.986,174.388 908.996,174.391 909.005,174.393 909.014,174.396 909.023,174.399 909.032,174.402 909.042,174.405 909.051,174.408 909.06,174.411 909.069,174.414 909.078,174.417 909.088,174.419 909.097,174.422 909.106,174.425 909.115,174.428 909.124,174.431 909.133,174.434 909.143,174.437 909.152,174.44 909.161,174.443 909.17,174.445 909.179,174.448 909.189,174.451 909.198,174.454 909.207,174.457 909.216,174.46 909.225,174.463 909.235,174.466 909.244,174.468 909.253,174.471 909.262,174.474 909.271,174.477 909.281,174.48 909.29,174.483 909.299,174.486 909.308,174.489 909.317,174.492 909.326,174.494 909.336,174.497 909.345,174.5 909.354,174.503 909.363,174.506 909.372,174.509 909.382,174.512 909.391,174.515 909.4,174.518 909.409,174.52 909.418,174.523 909.428,174.526 909.437,174.529 909.446,174.532 909.455,174.535 909.464,174.538 909.473,174.541 909.483,174.544 909.492,174.546 909.501,174.549 909.51,174.552 909.519,174.555 909.529,174.558 909.538,174.561 909.547,174.564 909.556,174.567 909.565,174.569 909.575,174.572 909.584,174.575 909.593,174.578 909.602,174.581 909.611,174.584 909.621,174.587 909.63,174.59 909.639,174.593 909.648,174.595 909.657,174.598 909.666,174.601 909.676,174.604 909.685,174.607 909.694,174.61 909.703,174.613 909.712,174.616 909.722,174.619 909.731,174.621 909.74,174.624 909.749,174.627 909.758,174.63 909.768,174.633 909.777,174.636 909.786,174.639 909.795,174.642 909.804,174.644 909.813,174.647 909.823,174.65 909.832,174.653 909.841,174.656 909.85,174.659 909.859,174.662 909.869,174.665 909.878,174.668 909.887,174.67 909.896,174.673 909.905,174.676 909.915,174.679 909.924,174.682 909.933,174.685 909.942,174.688 909.951,174.691 909.961,174.694 909.97,174.696 909.979,174.699 909.988,174.702 909.997,174.705 910.006,174.708 910.016,174.711 910.025,174.714 910.034,174.717 910.043,174.719 910.052,174.722 910.062,174.725 910.071,174.728 910.08,174.731 910.089,174.734 910.098,174.737 910.108,174.74 910.117,174.743 910.126,174.745 910.135,174.748 910.144,174.751 910.153,174.754 910.163,174.757 910.172,174.76 910.181,174.763 910.19,174.766 910.199,174.769 910.209,174.771 910.218,174.774 910.227,174.777 910.236,174.78 910.245,174.783 910.255,174.786 910.264,174.789 910.273,174.792 910.282,174.794 910.291,174.797 910.301,174.8 910.31,174.803 910.319,174.806 910.328,174.809 910.337,174.812 910.346,174.815 910.356,174.818 910.365,174.82 910.374,174.823 910.383,174.826 910.392,174.829 910.402,174.832 910.411,174.835 910.42,174.838 910.429,174.841 910.438,174.843 910.448,174.846 910.457,174.849 910.466,174.852 910.475,174.855 910.484,174.858 910.493,174.861 910.503,174.864 910.512,174.867 910.521,174.869 910.53,174.872 910.539,174.875 910.549,174.878 910.558,174.881 910.567,174.884 910.576,174.887 910.585,174.89 910.595,174.893 910.604,174.895 910.613,174.898 910.622,174.901 910.631,174.904 910.641,174.907 910.65,174.91 910.659,174.913 910.668,174.916 910.677,174.918 910.686,174.921 910.696,174.924 910.705,174.927 910.714,174.93 910.723,174.933 910.732,174.936 910.742,174.939 910.751,174.942 910.76,174.944 910.769,174.947 910.778,174.95 910.788,174.953 910.797,174.956 910.806,174.959 910.815,174.962 910.824,174.965 910.834,174.967 910.843,174.97 910.852,174.973 910.861,174.976 910.87,174.979 910.879,174.982 910.889,174.985 910.898,174.988 910.907,174.991 910.916,174.993 910.925,174.996 910.935,174.999 910.944,175.002 910.953,175.005 910.962,175.008 910.971,175.011 910.981,175.014 910.99,175.016 910.999,175.019 911.008,175.022 911.017,175.025 911.026,175.028 911.036,175.031 911.045,175.034 911.054,175.037 911.063,175.04 911.072,175.042 911.082,175.045 911.091,175.048 911.1,175.051 911.109,175.054 911.118,175.057 911.128,175.06 911.137,175.063 911.146,175.065 911.155,175.068 911.164,175.071 911.174,175.074 911.183,175.077 911.192,175.08 911.201,175.083 911.21,175.086 911.219,175.089 911.229,175.091 911.238,175.094 911.247,175.097 911.256,175.1 911.265,175.103 911.275,175.106 911.284,175.109 911.293,175.112 911.302,175.114 911.311,175.117 911.321,175.12 911.33,175.123 911.339,175.126 911.348,175.129 911.357,175.132 911.366,175.135 911.376,175.138 911.385,175.14 911.394,175.143 911.403,175.146 911.412,175.149 911.422,175.152 911.431,175.155 911.44,175.158 911.449,175.161 911.458,175.163 911.468,175.166 911.477,175.169 911.486,175.172 911.495,175.175 911.504,175.178 911.514,175.181 911.523,175.184 911.532,175.187 911.541,175.189 911.55,175.192 911.559,175.195 911.569,175.198 911.578,175.201 911.587,175.204 911.596,175.207 911.605,175.21 911.615,175.212 911.624,175.215 911.633,175.218 911.642,175.221 911.651,175.224 911.661,175.227 911.67,175.23 911.679,175.233 911.688,175.236 911.697,175.238 911.706,175.241 911.716,175.244 911.725,175.247 911.734,175.25 911.743,175.253 911.752,175.256 911.762,175.259 911.771,175.261 911.78,175.264 911.789,175.267 911.798,175.27 911.808,175.273 911.817,175.276 911.826,175.279 911.835,175.282 911.844,175.284 911.854,175.287 911.863,175.29 911.872,175.293 911.881,175.296 911.89,175.299 911.899,175.302 911.909,175.305 911.918,175.308 911.927,175.31 911.936,175.313 911.945,175.316 911.955,175.319 911.964,175.322 911.973,175.325 911.982,175.328 911.991,175.331 912.001,175.333 912.01,175.336 912.019,175.339 912.028,175.342 912.037,175.345 912.046,175.348 912.056,175.351 912.065,175.354 912.074,175.357 912.083,175.359 912.092,175.362 912.102,175.365 912.111,175.368 912.12,175.371 912.129,175.374 912.138,175.377 912.148,175.38 912.157,175.382 912.166,175.385 912.175,175.388 912.184,175.391 912.194,175.394 912.203,175.397 912.212,175.4 912.221,175.403 912.23,175.405 912.239,175.408 912.249,175.411 912.258,175.414 912.267,175.417 912.276,175.42 912.285,175.423 912.295,175.426 912.304,175.429 912.313,175.431 912.322,175.434 912.331,175.437 912.341,175.44 912.35,175.443 912.359,175.446 912.368,175.449 912.377,175.452 912.386,175.454 912.396,175.457 912.405,175.46 912.414,175.463 912.423,175.466 912.432,175.469 912.442,175.472 912.451,175.475 912.46,175.477 912.469,175.48 912.478,175.483 912.488,175.486 912.497,175.489 912.506,175.492 912.515,175.495 912.524,175.498 912.534,175.501 912.543,175.503 912.552,175.506 912.561,175.509 912.57,175.512 912.579,175.515 912.589,175.518 912.598,175.521 912.607,175.524 912.616,175.526 912.625,175.529 912.635,175.532 912.644,175.535 912.653,175.538 912.662,175.541 912.671,175.544 912.681,175.547 912.69,175.549 912.699,175.552 912.708,175.555 912.717,175.558 912.726,175.561 912.736,175.564 912.745,175.567 912.754,175.57 912.763,175.573 912.772,175.575 912.782,175.578 912.791,175.581 912.8,175.584 912.809,175.587 912.818,175.59 912.828,175.593 912.837,175.596 912.846,175.598 912.855,175.601 912.864,175.604 912.874,175.607 912.883,175.61 912.892,175.613 912.901,175.616 912.91,175.619 912.919,175.621 912.929,175.624 912.938,175.627 912.947,175.63 912.956,175.633 912.965,175.636 912.975,175.639 912.984,175.642 912.993,175.644 913.002,175.647 913.011,175.65 913.021,175.653 913.03,175.656 913.039,175.659 913.048,175.662 913.057,175.665 913.066,175.668 913.076,175.67 913.085,175.673 913.094,175.676 913.103,175.679 913.112,175.682 913.122,175.685 913.131,175.688 913.14,175.691 913.149,175.693 913.158,175.696 913.168,175.699 913.177,175.702 913.186,175.705 913.195,175.708 913.204,175.711 913.214,175.714 913.223,175.716 913.232,175.719 913.241,175.722 913.25,175.725 913.259,175.728 913.269,175.731 913.278,175.734 913.287,175.737 913.296,175.739 913.305,175.742 913.315,175.745 913.324,175.748 913.333,175.751 913.342,175.754 913.351,175.757 913.361,175.76 913.37,175.763 913.379,175.765 913.388,175.768 913.397,175.771 913.407,175.774 913.416,175.777 913.425,175.78 913.434,175.783 913.443,175.786 913.452,175.788 913.462,175.791 913.471,175.794 913.48,175.797 913.489,175.8 913.498,175.803 913.508,175.806 913.517,175.809 913.526,175.811 913.535,175.814 913.544,175.817 913.554,175.82 913.563,175.823 913.572,175.826 913.581,175.829 913.59,175.832 913.599,175.834 913.609,175.837 913.618,175.84 913.627,175.843 913.636,175.846 913.645,175.849 913.655,175.852 913.664,175.855 913.673,175.857 913.682,175.86 913.691,175.863 913.701,175.866 913.71,175.869 913.719,175.872 913.728,175.875 913.737,175.878 913.747,175.881 913.756,175.883 913.765,175.886 913.774,175.889 913.783,175.892 913.792,175.895 913.802,175.898 913.811,175.901 913.82,175.904 913.829,175.906 913.838,175.909 913.848,175.912 913.857,175.915 913.866,175.918 913.875,175.921 913.884,175.924 913.894,175.927 913.903,175.929 913.912,175.932 913.921,175.935 913.93,175.938 913.939,175.941 913.949,175.944 913.958,175.947 913.967,175.95 913.976,175.952 913.985,175.955 913.995,175.958 914.004,175.961 914.013,175.964 914.022,175.967 914.031,175.97 914.041,175.973 914.05,175.975 914.059,175.978 914.068,175.981 914.077,175.984 914.087,175.987 914.096,175.99 914.105,175.993 914.114,175.996 914.123,175.998 914.132,176.001 914.142,176.004 914.151,176.007 914.16,176.01 914.169,176.013 914.178,176.016 914.188,176.019 914.197,176.021 914.206,176.024 914.215,176.027 914.224,176.03 914.234,176.033 914.243,176.036 914.252,176.039 914.261,176.042 914.27,176.045 914.279,176.047 914.289,176.05 914.298,176.053 914.307,176.056 914.316,176.059 914.325,176.062 914.335,176.065 914.344,176.068 914.353,176.07 914.362,176.073 914.371,176.076 914.381,176.079 914.39,176.082 914.399,176.085 914.408,176.088 914.417,176.091 914.427,176.093 914.436,176.096 914.445,176.099 914.454,176.102 914.463,176.105 914.472,176.108 914.482,176.111 914.491,176.114 914.5,176.116 914.509,176.119 914.518,176.122 914.528,176.125 914.537,176.128 914.546,176.131 914.555,176.134 914.564,176.137 914.574,176.139 914.583,176.142 914.592,176.145 914.601,176.148 914.61,176.151 914.619,176.154 914.629,176.157 914.638,176.16 914.647,176.162 914.656,176.165 914.665,176.168 914.675,176.171 914.684,176.174 914.693,176.177 914.702,176.18 914.711,176.183 914.721,176.185 914.73,176.188 914.739,176.191 914.748,176.194 914.757,176.197 914.767,176.2 914.776,176.203 914.785,176.206 914.794,176.208 914.803,176.211 914.812,176.214 914.822,176.217 914.831,176.22 914.84,176.223 914.849,176.226 914.858,176.229 914.868,176.231 914.877,176.234 914.886,176.237 914.895,176.24 914.904,176.243 914.914,176.246 914.923,176.249 914.932,176.252 914.941,176.254 914.95,176.257 914.959,176.26 914.969,176.263 914.978,176.266 914.987,176.269 914.996,176.272 915.005,176.275 915.015,176.277 915.024,176.28 915.033,176.283 915.042,176.286 915.051,176.289 915.061,176.292 915.07,176.295 915.079,176.298 915.088,176.3 915.097,176.303 915.107,176.306 915.116,176.309 915.125,176.312 915.134,176.315 915.143,176.318 915.152,176.321 915.162,176.323 915.171,176.326 915.18,176.329 915.189,176.332 915.198,176.335 915.208,176.338 915.217,176.341 915.226,176.344 915.235,176.346 915.244,176.349 915.254,176.352 915.263,176.355 915.272,176.358 915.281,176.361 915.29,176.364 915.299,176.367 915.309,176.369 915.318,176.372 915.327,176.375 915.336,176.378 915.345,176.381 915.355,176.384 915.364,176.387 915.373,176.39 915.382,176.392 915.391,176.395 915.401,176.398 915.41,176.401 915.419,176.404 915.428,176.407 915.437,176.41 915.447,176.413 915.456,176.415 915.465,176.418 915.474,176.421 915.483,176.424 915.492,176.427 915.502,176.43 915.511,176.433 915.52,176.436 915.529,176.438 915.538,176.441 915.548,176.444 915.557,176.447 915.566,176.45 915.575,176.453 915.584,176.456 915.594,176.459 915.603,176.461 915.612,176.464 915.621,176.467 915.63,176.47 915.64,176.473 915.649,176.476 915.658,176.479 915.667,176.482 915.676,176.484 915.685,176.487 915.695,176.49 915.704,176.493 915.713,176.496 915.722,176.499 915.731,176.502 915.741,176.505 915.75,176.507 915.759,176.51 915.768,176.513 915.777,176.516 915.787,176.519 915.796,176.522 915.805,176.525 915.814,176.528 915.823,176.53 915.832,176.533 915.842,176.536 915.851,176.539 915.86,176.542 915.869,176.545 915.878,176.548 915.888,176.551 915.897,176.553 915.906,176.556 915.915,176.559 915.924,176.562 915.934,176.565 915.943,176.568 915.952,176.571 915.961,176.574 915.97,176.576 915.98,176.579 915.989,176.582 915.998,176.585 916.007,176.588 916.016,176.591 916.025,176.594 916.035,176.597 916.044,176.599 916.053,176.602 916.062,176.605 916.071,176.608 916.081,176.611 916.09,176.614 916.099,176.617 916.108,176.62 916.117,176.622 916.127,176.625 916.136,176.628 916.145,176.631 916.154,176.634 916.163,176.637 916.172,176.64 916.182,176.643 916.191,176.645 916.2,176.648 916.209,176.651 916.218,176.654 916.228,176.657 916.237,176.66 916.246,176.663 916.255,176.665 916.264,176.668 916.274,176.671 916.283,176.674 916.292,176.677 916.301,176.68 916.31,176.683 916.32,176.686 916.329,176.688 916.338,176.691 916.347,176.694 916.356,176.697 916.365,176.7 916.375,176.703 916.384,176.706 916.393,176.709 916.402,176.711 916.411,176.714 916.421,176.717 916.43,176.72 916.439,176.723 916.448,176.726 916.457,176.729 916.467,176.732 916.476,176.734 916.485,176.737 916.494,176.74 916.503,176.743 916.512,176.746 916.522,176.749 916.531,176.752 916.54,176.755 916.549,176.757 916.558,176.76 916.568,176.763 916.577,176.766 916.586,176.769 916.595,176.772 916.604,176.775 916.614,176.778 916.623,176.78 916.632,176.783 916.641,176.786 916.65,176.789 916.66,176.792 916.669,176.795 916.678,176.798 916.687,176.801 916.696,176.803 916.705,176.806 916.715,176.809 916.724,176.812 916.733,176.815 916.742,176.818 916.751,176.821 916.761,176.823 916.77,176.826 916.779,176.829 916.788,176.832 916.797,176.835 916.807,176.838 916.816,176.841 916.825,176.844 916.834,176.846 916.843,176.849 916.852,176.852 916.862,176.855 916.871,176.858 916.88,176.861 916.889,176.864 916.898,176.867 916.908,176.869 916.917,176.872 916.926,176.875 916.935,176.878 916.944,176.881 916.954,176.884 916.963,176.887 916.972,176.89 916.981,176.892 916.99,176.895 917,176.898 917.009,176.901 917.018,176.904 917.027,176.907 917.036,176.91 917.045,176.913 917.055,176.915 917.064,176.918 917.073,176.921 917.082,176.924 917.091,176.927 917.101,176.93 917.11,176.933 917.119,176.936 917.128,176.938 917.137,176.941 917.147,176.944 917.156,176.947 917.165,176.95 917.174,176.953 917.183,176.956 917.192,176.958 917.202,176.961 917.211,176.964 917.22,176.967 917.229,176.97 917.238,176.973 917.248,176.976 917.257,176.979 917.266,176.981 917.275,176.984 917.284,176.987 917.294,176.99 917.303,176.993 917.312,176.996 917.321,176.999 917.33,177.002 917.34,177.004 917.349,177.007 917.358,177.01 917.367,177.013 917.376,177.016 917.385,177.019 917.395,177.022 917.404,177.025 917.413,177.027 917.422,177.03 917.431,177.033 917.441,177.036 917.45,177.039 917.459,177.042 917.468,177.045 917.477,177.047 917.487,177.05 917.496,177.053 917.505,177.056 917.514,177.059 917.523,177.062 917.532,177.065 917.542,177.068 917.551,177.07 917.56,177.073 917.569,177.076 917.578,177.079 917.588,177.082 917.597,177.085 917.606,177.088 917.615,177.091 917.624,177.093 917.634,177.096 917.643,177.099 917.652,177.102 917.661,177.105 917.67,177.108 917.68,177.111 917.689,177.114 917.698,177.116 917.707,177.119 917.716,177.122 917.725,177.125 917.735,177.128 917.744,177.131 917.753,177.134 917.762,177.136 917.771,177.139 917.781,177.142 917.79,177.145 917.799,177.148 917.808,177.151 917.817,177.154 917.827,177.157 917.836,177.159 917.845,177.162 917.854,177.165 917.863,177.168 917.872,177.171 917.882,177.174 917.891,177.177 917.9,177.18 917.909,177.182 917.918,177.185 917.928,177.188 917.937,177.191 917.946,177.194 917.955,177.197 917.964,177.2 917.974,177.202 917.983,177.205 917.992,177.208 918.001,177.211 918.01,177.214 918.02,177.217 918.029,177.22 918.038,177.223 918.047,177.225 918.056,177.228 918.065,177.231 918.075,177.234 918.084,177.237 918.093,177.24 918.102,177.243 918.111,177.246 918.121,177.248 918.13,177.251 918.139,177.254 918.148,177.257 918.157,177.26 918.167,177.263 918.176,177.266 918.185,177.268 918.194,177.271 918.203,177.274 918.213,177.277 918.222,177.28 918.231,177.283 918.24,177.286 918.249,177.289 918.258,177.291 918.268,177.294 918.277,177.297 918.286,177.3 918.295,177.303 918.304,177.306 918.314,177.309 918.323,177.312 918.332,177.314 918.341,177.317 918.35,177.32 918.36,177.323 918.369,177.326 918.378,177.329 918.387,177.332 918.396,177.334 918.405,177.337 918.415,177.34 918.424,177.343 918.433,177.346 918.442,177.349 918.451,177.352 918.461,177.355 918.47,177.357 918.479,177.36 918.488,177.363 918.497,177.366 918.507,177.369 918.516,177.372 918.525,177.375 918.534,177.378 918.543,177.38 918.553,177.383 918.562,177.386 918.571,177.389 918.58,177.392 918.589,177.395 918.598,177.398 918.608,177.4 918.617,177.403 918.626,177.406 918.635,177.409 918.644,177.412 918.654,177.415 918.663,177.418 918.672,177.421 918.681,177.423 918.69,177.426 918.7,177.429 918.709,177.432 918.718,177.435 918.727,177.438 918.736,177.441 918.745,177.444 918.755,177.446 918.764,177.449 918.773,177.452 918.782,177.455 918.791,177.458 918.801,177.461 918.81,177.464 918.819,177.466 918.828,177.469 918.837,177.472 918.847,177.475 918.856,177.478 918.865,177.481 918.874,177.484 918.883,177.487 918.893,177.489 918.902,177.492 918.911,177.495 918.92,177.498 918.929,177.501 918.938,177.504 918.948,177.507 918.957,177.509 918.966,177.512 918.975,177.515 918.984,177.518 918.994,177.521 919.003,177.524 919.012,177.527 919.021,177.53 919.03,177.532 919.04,177.535 919.049,177.538 919.058,177.541 919.067,177.544 919.076,177.547 919.085,177.55 919.095,177.553 919.104,177.555 919.113,177.558 919.122,177.561 919.131,177.564 919.141,177.567 919.15,177.57 919.159,177.573 919.168,177.575 919.177,177.578 919.187,177.581 919.196,177.584 919.205,177.587 919.214,177.59 919.223,177.593 919.233,177.596 919.242,177.598 919.251,177.601 919.26,177.604 919.269,177.607 919.278,177.61 919.288,177.613 919.297,177.616 919.306,177.618 919.315,177.621 919.324,177.624 919.334,177.627 919.343,177.63 919.352,177.633 919.361,177.636 919.37,177.639 919.38,177.641 919.389,177.644 919.398,177.647 919.407,177.65 919.416,177.653 919.425,177.656 919.435,177.659 919.444,177.661 919.453,177.664 919.462,177.667 919.471,177.67 919.481,177.673 919.49,177.676 919.499,177.679 919.508,177.682 919.517,177.684 919.527,177.687 919.536,177.69 919.545,177.693 919.554,177.696 919.563,177.699 919.573,177.702 919.582,177.704 919.591,177.707 919.6,177.71 919.609,177.713 919.618,177.716 919.628,177.719 919.637,177.722 919.646,177.725 919.655,177.727 919.664,177.73 919.674,177.733 919.683,177.736 919.692,177.739 919.701,177.742 919.71,177.745 919.72,177.747 919.729,177.75 919.738,177.753 919.747,177.756 919.756,177.759 919.765,177.762 919.775,177.765 919.784,177.768 919.793,177.77 919.802,177.773 919.811,177.776 919.821,177.779 919.83,177.782 919.839,177.785 919.848,177.788 919.857,177.79 919.867,177.793 919.876,177.796 919.885,177.799 919.894,177.802 919.903,177.805 919.913,177.808 919.922,177.811 919.931,177.813 919.94,177.816 919.949,177.819 919.958,177.822 919.968,177.825 919.977,177.828 919.986,177.831 919.995,177.833 920.004,177.836 920.014,177.839 920.023,177.842 920.032,177.845 920.041,177.848 920.05,177.851 920.06,177.854 920.069,177.856 920.078,177.859 920.087,177.862 920.096,177.865 920.105,177.868 920.115,177.871 920.124,177.874 920.133,177.876 920.142,177.879 920.151,177.882 920.161,177.885 920.17,177.888 920.179,177.891 920.188,177.894 920.197,177.897 920.207,177.899 920.216,177.902 920.225,177.905 920.234,177.908 920.243,177.911 920.253,177.914 920.262,177.917 920.271,177.919 920.28,177.922 920.289,177.925 920.298,177.928 920.308,177.931 920.317,177.934 920.326,177.937 920.335,177.94 920.344,177.942 920.354,177.945 920.363,177.948 920.372,177.951 920.381,177.954 920.39,177.957 920.4,177.96 920.409,177.962 920.418,177.965 920.427,177.968 920.436,177.971 920.445,177.974 920.455,177.977 920.464,177.98 920.473,177.983 920.482,177.985 920.491,177.988 920.501,177.991 920.51,177.994 920.519,177.997 920.528,178 920.537,178.003 920.547,178.005 920.556,178.008 920.565,178.011 920.574,178.014 920.583,178.017 920.593,178.02 920.602,178.023 920.611,178.025 920.62,178.028 920.629,178.031 920.638,178.034 920.648,178.037 920.657,178.04 920.666,178.043 920.675,178.046 920.684,178.048 920.694,178.051 920.703,178.054 920.712,178.057 920.721,178.06 920.73,178.063 920.74,178.066 920.749,178.068 920.758,178.071 920.767,178.074 920.776,178.077 920.786,178.08 920.795,178.083 920.804,178.086 920.813,178.089 920.822,178.091 920.831,178.094 920.841,178.097 920.85,178.1 920.859,178.103 920.868,178.106 920.877,178.109 920.887,178.111 920.896,178.114 920.905,178.117 920.914,178.12 920.923,178.123 920.933,178.126 920.942,178.129 920.951,178.131 920.96,178.134 920.969,178.137 920.978,178.14 920.988,178.143 920.997,178.146 921.006,178.149 921.015,178.152 921.024,178.154 921.034,178.157 921.043,178.16 921.052,178.163 921.061,178.166 921.07,178.169 921.08,178.172 921.089,178.174 921.098,178.177 921.107,178.18 921.116,178.183 921.126,178.186 921.135,178.189 921.144,178.192 921.153,178.195 921.162,178.197 921.171,178.2 921.181,178.203 921.19,178.206 921.199,178.209 921.208,178.212 921.217,178.215 921.227,178.217 921.236,178.22 921.245,178.223 921.254,178.226 921.263,178.229 921.273,178.232 921.282,178.235 921.291,178.237 921.3,178.24 921.309,178.243 921.318,178.246 921.328,178.249 921.337,178.252 921.346,178.255 921.355,178.258 921.364,178.26 921.374,178.263 921.383,178.266 921.392,178.269 921.401,178.272 921.41,178.275 921.42,178.278 921.429,178.28 921.438,178.283 921.447,178.286 921.456,178.289 921.466,178.292 921.475,178.295 921.484,178.298 921.493,178.3 921.502,178.303 921.511,178.306 921.521,178.309 921.53,178.312 921.539,178.315 921.548,178.318 921.557,178.321 921.567,178.323 921.576,178.326 921.585,178.329 921.594,178.332 921.603,178.335 921.613,178.338 921.622,178.341 921.631,178.343 921.64,178.346 921.649,178.349 921.658,178.352 921.668,178.355 921.677,178.358 921.686,178.361 921.695,178.363 921.704,178.366 921.714,178.369 921.723,178.372 921.732,178.375 921.741,178.378 921.75,178.381 921.76,178.384 921.769,178.386 921.778,178.389 921.787,178.392 921.796,178.395 921.806,178.398 921.815,178.401 921.824,178.404 921.833,178.406 921.842,178.409 921.851,178.412 921.861,178.415 921.87,178.418 921.879,178.421 921.888,178.424 921.897,178.426 921.907,178.429 921.916,178.432 921.925,178.435 921.934,178.438 921.943,178.441 921.953,178.444 921.962,178.447 921.971,178.449 921.98,178.452 921.989,178.455 921.998,178.458 922.008,178.461 922.017,178.464 922.026,178.467 922.035,178.469 922.044,178.472 922.054,178.475 922.063,178.478 922.072,178.481 922.081,178.484 922.09,178.487 922.1,178.489 922.109,178.492 922.118,178.495 922.127,178.498 922.136,178.501 922.146,178.504 922.155,178.507 922.164,178.509 922.173,178.512 922.182,178.515 922.191,178.518 922.201,178.521 922.21,178.524 922.219,178.527 922.228,178.53 922.237,178.532 922.247,178.535 922.256,178.538 922.265,178.541 922.274,178.544 922.283,178.547 922.293,178.55 922.302,178.552 922.311,178.555 922.32,178.558 922.329,178.561 922.338,178.564 922.348,178.567 922.357,178.57 922.366,178.572 922.375,178.575 922.384,178.578 922.394,178.581 922.403,178.584 922.412,178.587 922.421,178.59 922.43,178.592 922.44,178.595 922.449,178.598 922.458,178.601 922.467,178.604 922.476,178.607 922.486,178.61 922.495,178.613 922.504,178.615 922.513,178.618 922.522,178.621 922.531,178.624 922.541,178.627 922.55,178.63 922.559,178.633 922.568,178.635 922.577,178.638 922.587,178.641 922.596,178.644 922.605,178.647 922.614,178.65 922.623,178.653 922.633,178.655 922.642,178.658 922.651,178.661 922.66,178.664 922.669,178.667 922.678,178.67 922.688,178.673 922.697,178.675 922.706,178.678 922.715,178.681 922.724,178.684 922.734,178.687 922.743,178.69 922.752,178.693 922.761,178.695 922.77,178.698 922.78,178.701 922.789,178.704 922.798,178.707 922.807,178.71 922.816,178.713 922.826,178.716 922.835,178.718 922.844,178.721 922.853,178.724 922.862,178.727 922.871,178.73 922.881,178.733 922.89,178.736 922.899,178.738 922.908,178.741 922.917,178.744 922.927,178.747 922.936,178.75 922.945,178.753 922.954,178.756 922.963,178.758 922.973,178.761 922.982,178.764 922.991,178.767 923,178.77 923.009,178.773 923.019,178.776 923.028,178.778 923.037,178.781 923.046,178.784 923.055,178.787 923.064,178.79 923.074,178.793 923.083,178.796 923.092,178.798 923.101,178.801 923.11,178.804 923.12,178.807 923.129,178.81 923.138,178.813 923.147,178.816 923.156,178.819 923.166,178.821 923.175,178.824 923.184,178.827 923.193,178.83 923.202,178.833 923.211,178.836 923.221,178.839 923.23,178.841 923.239,178.844 923.248,178.847 923.257,178.85 923.267,178.853 923.276,178.856 923.285,178.859 923.294,178.861 923.303,178.864 923.313,178.867 923.322,178.87 923.331,178.873 923.34,178.876 923.349,178.879 923.359,178.881 923.368,178.884 923.377,178.887 923.386,178.89 923.395,178.893 923.404,178.896 923.414,178.899 923.423,178.901 923.432,178.904 923.441,178.907 923.45,178.91 923.46,178.913 923.469,178.916 923.478,178.919 923.487,178.921 923.496,178.924 923.506,178.927 923.515,178.93 923.524,178.933 923.533,178.936 923.542,178.939 923.551,178.942 923.561,178.944 923.57,178.947 923.579,178.95 923.588,178.953 923.597,178.956 923.607,178.959 923.616,178.962 923.625,178.964 923.634,178.967 923.643,178.97 923.653,178.973 923.662,178.976 923.671,178.979 923.68,178.982 923.689,178.984 923.699,178.987 923.708,178.99 923.717,178.993 923.726,178.996 923.735,178.999 923.744,179.002 923.754,179.004 923.763,179.007 923.772,179.01 923.781,179.013 923.79,179.016 923.8,179.019 923.809,179.022 923.818,179.024 923.827,179.027 923.836,179.03 923.846,179.033 923.855,179.036 923.864,179.039 923.873,179.042 923.882,179.044 923.891,179.047 923.901,179.05 923.91,179.053 923.919,179.056 923.928,179.059 923.937,179.062 923.947,179.064 923.956,179.067 923.965,179.07 923.974,179.073 923.983,179.076 923.993,179.079 924.002,179.082 924.011,179.084 924.02,179.087 924.029,179.09 924.039,179.093 924.048,179.096 924.057,179.099 924.066,179.102 924.075,179.104 924.084,179.107 924.094,179.11 924.103,179.113 924.112,179.116 924.121,179.119 924.13,179.122 924.14,179.125 924.149,179.127 924.158,179.13 924.167,179.133 924.176,179.136 924.186,179.139 924.195,179.142 924.204,179.145 924.213,179.147 924.222,179.15 924.231,179.153 924.241,179.156 924.25,179.159 924.259,179.162 924.268,179.165 924.277,179.167 924.287,179.17 924.296,179.173 924.305,179.176 924.314,179.179 924.323,179.182 924.333,179.185 924.342,179.187 924.351,179.19 924.36,179.193 924.369,179.196 924.379,179.199 924.388,179.202 924.397,179.205 924.406,179.207 924.415,179.21 924.424,179.213 924.434,179.216 924.443,179.219 924.452,179.222 924.461,179.225 924.47,179.227 924.48,179.23 924.489,179.233 924.498,179.236 924.507,179.239 924.516,179.242 924.526,179.245 924.535,179.247 924.544,179.25 924.553,179.253 924.562,179.256 924.571,179.259 924.581,179.262 924.59,179.265 924.599,179.267 924.608,179.27 924.617,179.273 924.627,179.276 924.636,179.279 924.645,179.282 924.654,179.285 924.663,179.287 924.673,179.29 924.682,179.293 924.691,179.296 924.7,179.299 924.709,179.302 924.719,179.305 924.728,179.307 924.737,179.31 924.746,179.313 924.755,179.316 924.764,179.319 924.774,179.322 924.783,179.325 924.792,179.327 924.801,179.33 924.81,179.333 924.82,179.336 924.829,179.339 924.838,179.342 924.847,179.345 924.856,179.347 924.866,179.35 924.875,179.353 924.884,179.356 924.893,179.359 924.902,179.362 924.911,179.365 924.921,179.367 924.93,179.37 924.939,179.373 924.948,179.376 924.957,179.379 924.967,179.382 924.976,179.385 924.985,179.387 924.994,179.39 925.003,179.393 925.013,179.396 925.022,179.399 925.031,179.402 925.04,179.405 925.049,179.407 925.059,179.41 925.068,179.413 925.077,179.416 925.086,179.419 925.095,179.422 925.104,179.425 925.114,179.427 925.123,179.43 925.132,179.433 925.141,179.436 925.15,179.439 925.16,179.442 925.169,179.445 925.178,179.447 925.187,179.45 925.196,179.453 925.206,179.456 925.215,179.459 925.224,179.462 925.233,179.465 925.242,179.467 925.251,179.47 925.261,179.473 925.27,179.476 925.279,179.479 925.288,179.482 925.297,179.485 925.307,179.487 925.316,179.49 925.325,179.493 925.334,179.496 925.343,179.499 925.353,179.502 925.362,179.505 925.371,179.507 925.38,179.51 925.389,179.513 925.399,179.516 925.408,179.519 925.417,179.522 925.426,179.525 925.435,179.527 925.444,179.53 925.454,179.533 925.463,179.536 925.472,179.539 925.481,179.542 925.49,179.545 925.5,179.547 925.509,179.55 925.518,179.553 925.527,179.556 925.536,179.559 925.546,179.562 925.555,179.565 925.564,179.567 925.573,179.57 925.582,179.573 925.592,179.576 925.601,179.579 925.61,179.582 925.619,179.585 925.628,179.587 925.637,179.59 925.647,179.593 925.656,179.596 925.665,179.599 925.674,179.602 925.683,179.605 925.693,179.607 925.702,179.61 925.711,179.613 925.72,179.616 925.729,179.619 925.739,179.622 925.748,179.625 925.757,179.627 925.766,179.63 925.775,179.633 925.784,179.636 925.794,179.639 925.803,179.642 925.812,179.645 925.821,179.647 925.83,179.65 925.84,179.653 925.849,179.656 925.858,179.659 925.867,179.662 925.876,179.665 925.886,179.667 925.895,179.67 925.904,179.673 925.913,179.676 925.922,179.679 925.932,179.682 925.941,179.684 925.95,179.687 925.959,179.69 925.968,179.693 925.977,179.696 925.987,179.699 925.996,179.702 926.005,179.704 926.014,179.707 926.023,179.71 926.033,179.713 926.042,179.716 926.051,179.719 926.06,179.722 926.069,179.724 926.079,179.727 926.088,179.73 926.097,179.733 926.106,179.736 926.115,179.739 926.124,179.742 926.134,179.744 926.143,179.747 926.152,179.75 926.161,179.753 926.17,179.756 926.18,179.759 926.189,179.762 926.198,179.764 926.207,179.767 926.216,179.77 926.226,179.773 926.235,179.776 926.244,179.779 926.253,179.782 926.262,179.784 926.272,179.787 926.281,179.79 926.29,179.793 926.299,179.796 926.308,179.799 926.317,179.802 926.327,179.804 926.336,179.807 926.345,179.81 926.354,179.813 926.363,179.816 926.373,179.819 926.382,179.822 926.391,179.824 926.4,179.827 926.409,179.83 926.419,179.833 926.428,179.836 926.437,179.839 926.446,179.842 926.455,179.844 926.464,179.847 926.474,179.85 926.483,179.853 926.492,179.856 926.501,179.859 926.51,179.861 926.52,179.864 926.529,179.867 926.538,179.87 926.547,179.873 926.556,179.876 926.566,179.879 926.575,179.881 926.584,179.884 926.593,179.887 926.602,179.89 926.612,179.893 926.621,179.896 926.63,179.899 926.639,179.901 926.648,179.904 926.657,179.907 926.667,179.91 926.676,179.913 926.685,179.916 926.694,179.919 926.703,179.921 926.713,179.924 926.722,179.927 926.731,179.93 926.74,179.933 926.749,179.936 926.759,179.939 926.768,179.941 926.777,179.944 926.786,179.947 926.795,179.95 926.804,179.953 926.814,179.956 926.823,179.959 926.832,179.961 926.841,179.964 926.85,179.967 926.86,179.97 926.869,179.973 926.878,179.976 926.887,179.979 926.896,179.981 926.906,179.984 926.915,179.987 926.924,179.99 926.933,179.993 926.942,179.996 926.952,179.998 926.961,180.001 926.97,180.004 926.979,180.007 926.988,180.01 926.997,180.013 927.007,180.016 927.016,180.018 927.025,180.021 927.034,180.024 927.043,180.027 927.053,180.03 927.062,180.033 927.071,180.036 927.08,180.038 927.089,180.041 927.099,180.044 927.108,180.047 927.117,180.05 927.126,180.053 927.135,180.056 927.144,180.058 927.154,180.061 927.163,180.064 927.172,180.067 927.181,180.07 927.19,180.073 927.2,180.076 927.209,180.078 927.218,180.081 927.227,180.084 927.236,180.087 927.246,180.09 927.255,180.093 927.264,180.095 927.273,180.098 927.282,180.101 927.292,180.104 927.301,180.107 927.31,180.11 927.319,180.113 927.328,180.115 927.337,180.118 927.347,180.121 927.356,180.124 927.365,180.127 927.374,180.13 927.383,180.133 927.393,180.135 927.402,180.138 927.411,180.141 927.42,180.144 927.429,180.147 927.439,180.15 927.448,180.153 927.457,180.155 927.466,180.158 927.475,180.161 927.484,180.164 927.494,180.167 927.503,180.17 927.512,180.173 927.521,180.175 927.53,180.178 927.54,180.181 927.549,180.184 927.558,180.187 927.567,180.19 927.576,180.192 927.586,180.195 927.595,180.198 927.604,180.201 927.613,180.204 927.622,180.207 927.632,180.21 927.641,180.212 927.65,180.215 927.659,180.218 927.668,180.221 927.677,180.224 927.687,180.227 927.696,180.23 927.705,180.232 927.714,180.235 927.723,180.238 927.733,180.241 927.742,180.244 927.751,180.247 927.76,180.25 927.769,180.252 927.779,180.255 927.788,180.258 927.797,180.261 927.806,180.264 927.815,180.267 927.824,180.269 927.834,180.272 927.843,180.275 927.852,180.278 927.861,180.281 927.87,180.284 927.88,180.287 927.889,180.289 927.898,180.292 927.907,180.295 927.916,180.298 927.926,180.301 927.935,180.304 927.944,180.307 927.953,180.309 927.962,180.312 927.972,180.315 927.981,180.318 927.99,180.321 927.999,180.324 928.008,180.327 928.017,180.329 928.027,180.332 928.036,180.335 928.045,180.338 928.054,180.341 928.063,180.344 928.073,180.346 928.082,180.349 928.091,180.352 928.1,180.355 928.109,180.358 928.119,180.361 928.128,180.364 928.137,180.366 928.146,180.369 928.155,180.372 928.165,180.375 928.174,180.378 928.183,180.381 928.192,180.384 928.201,180.386 928.21,180.389 928.22,180.392 928.229,180.395 928.238,180.398 928.247,180.401 928.256,180.404 928.266,180.406 928.275,180.409 928.284,180.412 928.293,180.415 928.302,180.418 928.312,180.421 928.321,180.423 928.33,180.426 928.339,180.429 928.348,180.432 928.357,180.435 928.367,180.438 928.376,180.441 928.385,180.443 928.394,180.446 928.403,180.449 928.413,180.452 928.422,180.455 928.431,180.458 928.44,180.461 928.449,180.463 928.459,180.466 928.468,180.469 928.477,180.472 928.486,180.475 928.495,180.478 928.505,180.48 928.514,180.483 928.523,180.486 928.532,180.489 928.541,180.492 928.55,180.495 928.56,180.498 928.569,180.5 928.578,180.503 928.587,180.506 928.596,180.509 928.606,180.512 928.615,180.515 928.624,180.518 928.633,180.52 928.642,180.523 928.652,180.526 928.661,180.529 928.67,180.532 928.679,180.535 928.688,180.538 928.697,180.54 928.707,180.543 928.716,180.546 928.725,180.549 928.734,180.552 928.743,180.555 928.753,180.557 928.762,180.56 928.771,180.563 928.78,180.566 928.789,180.569 928.799,180.572 928.808,180.575 928.817,180.577 928.826,180.58 928.835,180.583 928.845,180.586 928.854,180.589 928.863,180.592 928.872,180.595 928.881,180.597 928.89,180.6 928.9,180.603 928.909,180.606 928.918,180.609 928.927,180.612 928.936,180.614 928.946,180.617 928.955,180.62 928.964,180.623 928.973,180.626 928.982,180.629 928.992,180.632 929.001,180.634 929.01,180.637 929.019,180.64 929.028,180.643 929.037,180.646 929.047,180.649 929.056,180.652 929.065,180.654 929.074,180.657 929.083,180.66 929.093,180.663 929.102,180.666 929.111,180.669 929.12,180.671 929.129,180.674 929.139,180.677 929.148,180.68 929.157,180.683 929.166,180.686 929.175,180.689 929.185,180.691 929.194,180.694 929.203,180.697 929.212,180.7 929.221,180.703 929.23,180.706 929.24,180.708 929.249,180.711 929.258,180.714 929.267,180.717 929.276,180.72 929.286,180.723 929.295,180.726 929.304,180.728 929.313,180.731 929.322,180.734 929.332,180.737 929.341,180.74 929.35,180.743 929.359,180.746 929.368,180.748 929.377,180.751 929.387,180.754 929.396,180.757 929.405,180.76 929.414,180.763 929.423,180.765 929.433,180.768 929.442,180.771 929.451,180.774 929.46,180.777 929.469,180.78 929.479,180.783 929.488,180.785 929.497,180.788 929.506,180.791 929.515,180.794 929.525,180.797 929.534,180.8 929.543,180.803 929.552,180.805 929.561,180.808 929.57,180.811 929.58,180.814 929.589,180.817 929.598,180.82 929.607,180.822 929.616,180.825 929.626,180.828 929.635,180.831 929.644,180.834 929.653,180.837 929.662,180.84 929.672,180.842 929.681,180.845 929.69,180.848 929.699,180.851 929.708,180.854 929.717,180.857 929.727,180.859 929.736,180.862 929.745,180.865 929.754,180.868 929.763,180.871 929.773,180.874 929.782,180.877 929.791,180.879 929.8,180.882 929.809,180.885 929.819,180.888 929.828,180.891 929.837,180.894 929.846,180.897 929.855,180.899 929.865,180.902 929.874,180.905 929.883,180.908 929.892,180.911 929.901,180.914 929.91,180.916 929.92,180.919 929.929,180.922 929.938,180.925 929.947,180.928 929.956,180.931 929.966,180.934 929.975,180.936 929.984,180.939 929.993,180.942 930.002,180.945 930.012,180.948 930.021,180.951 930.03,180.953 930.039,180.956 930.048,180.959 930.057,180.962 930.067,180.965 930.076,180.968 930.085,180.971 930.094,180.973 930.103,180.976 930.113,180.979 930.122,180.982 930.131,180.985 930.14,180.988 930.149,180.99 930.159,180.993 930.168,180.996 930.177,180.999 930.186,181.002 930.195,181.005 930.205,181.008 930.214,181.01 930.223,181.013 930.232,181.016 930.241,181.019 930.25,181.022 930.26,181.025 930.269,181.028 930.278,181.03 930.287,181.033 930.296,181.036 930.306,181.039 930.315,181.042 930.324,181.045 930.333,181.047 930.342,181.05 930.352,181.053 930.361,181.056 930.37,181.059 930.379,181.062 930.388,181.065 930.397,181.067 930.407,181.07 930.416,181.073 930.425,181.076 930.434,181.079 930.443,181.082 930.453,181.084 930.462,181.087 930.471,181.09 930.48,181.093 930.489,181.096 930.499,181.099 930.508,181.102 930.517,181.104 930.526,181.107 930.535,181.11 930.545,181.113 930.554,181.116 930.563,181.119 930.572,181.121 930.581,181.124 930.59,181.127 930.6,181.13 930.609,181.133 930.618,181.136 930.627,181.139 930.636,181.141 930.646,181.144 930.655,181.147 930.664,181.15 930.673,181.153 930.682,181.156 930.692,181.158 930.701,181.161 930.71,181.164 930.719,181.167 930.728,181.17 930.738,181.173 930.747,181.176 930.756,181.178 930.765,181.181 930.774,181.184 930.783,181.187 930.793,181.19 930.802,181.193 930.811,181.195 930.82,181.198 930.829,181.201 930.839,181.204 930.848,181.207 930.857,181.21 930.866,181.213 930.875,181.215 930.885,181.218 930.894,181.221 930.903,181.224 930.912,181.227 930.921,181.23 930.93,181.232 930.94,181.235 930.949,181.238 930.958,181.241 930.967,181.244 930.976,181.247 930.986,181.25 930.995,181.252 931.004,181.255 931.013,181.258 931.022,181.261 931.032,181.264 931.041,181.267 931.05,181.269 931.059,181.272 931.068,181.275 931.078,181.278 931.087,181.281 931.096,181.284 931.105,181.287 931.114,181.289 931.123,181.292 931.133,181.295 931.142,181.298 931.151,181.301 931.16,181.304 931.169,181.306 931.179,181.309 931.188,181.312 931.197,181.315 931.206,181.318 931.215,181.321 931.225,181.324 931.234,181.326 931.243,181.329 931.252,181.332 931.261,181.335 931.27,181.338 931.28,181.341 931.289,181.343 931.298,181.346 931.307,181.349 931.316,181.352 931.326,181.355 931.335,181.358 931.344,181.361 931.353,181.363 931.362,181.366 931.372,181.369 931.381,181.372 931.39,181.375 931.399,181.378 931.408,181.38 931.418,181.383 931.427,181.386 931.436,181.389 931.445,181.392 931.454,181.395 931.463,181.398 931.473,181.4 931.482,181.403 931.491,181.406 931.5,181.409 931.509,181.412 931.519,181.415 931.528,181.417 931.537,181.42 931.546,181.423 931.555,181.426 931.565,181.429 931.574,181.432 931.583,181.435 931.592,181.437 931.601,181.44 931.61,181.443 931.62,181.446 931.629,181.449 931.638,181.452 931.647,181.454 931.656,181.457 931.666,181.46 931.675,181.463 931.684,181.466 931.693,181.469 931.702,181.471 931.712,181.474 931.721,181.477 931.73,181.48 931.739,181.483 931.748,181.486 931.758,181.489 931.767,181.491 931.776,181.494 931.785,181.497 931.794,181.5 931.803,181.503 931.813,181.506 931.822,181.508 931.831,181.511 931.84,181.514 931.849,181.517 931.859,181.52 931.868,181.523 931.877,181.526 931.886,181.528 931.895,181.531 931.905,181.534 931.914,181.537 931.923,181.54 931.932,181.543 931.941,181.545 931.95,181.548 931.96,181.551 931.969,181.554 931.978,181.557 931.987,181.56 931.996,181.563 932.006,181.565 932.015,181.568 932.024,181.571 932.033,181.574 932.042,181.577 932.052,181.58 932.061,181.582 932.07,181.585 932.079,181.588 932.088,181.591 932.098,181.594 932.107,181.597 932.116,181.599 932.125,181.602 932.134,181.605 932.143,181.608 932.153,181.611 932.162,181.614 932.171,181.617 932.18,181.619 932.189,181.622 932.199,181.625 932.208,181.628 932.217,181.631 932.226,181.634 932.235,181.636 932.245,181.639 932.254,181.642 932.263,181.645 932.272,181.648 932.281,181.651 932.29,181.654 932.3,181.656 932.309,181.659 932.318,181.662 932.327,181.665 932.336,181.668 932.346,181.671 932.355,181.673 932.364,181.676 932.373,181.679 932.382,181.682 932.392,181.685 932.401,181.688 932.41,181.69 932.419,181.693 932.428,181.696 932.438,181.699 932.447,181.702 932.456,181.705 932.465,181.708 932.474,181.71 932.483,181.713 932.493,181.716 932.502,181.719 932.511,181.722 932.52,181.725 932.529,181.727 932.539,181.73 932.548,181.733 932.557,181.736 932.566,181.739 932.575,181.742 932.585,181.745 932.594,181.747 932.603,181.75 932.612,181.753 932.621,181.756 932.63,181.759 932.64,181.762 932.649,181.764 932.658,181.767 932.667,181.77 932.676,181.773 932.686,181.776 932.695,181.779 932.704,181.781 932.713,181.784 932.722,181.787 932.732,181.79 932.741,181.793 932.75,181.796 932.759,181.799 932.768,181.801 932.778,181.804 932.787,181.807 932.796,181.81 932.805,181.813 932.814,181.816 932.823,181.818 932.833,181.821 932.842,181.824 932.851,181.827 932.86,181.83 932.869,181.833 932.879,181.835 932.888,181.838 932.897,181.841 932.906,181.844 932.915,181.847 932.925,181.85 932.934,181.853 932.943,181.855 932.952,181.858 932.961,181.861 932.971,181.864 932.98,181.867 932.989,181.87 932.998,181.872 933.007,181.875 933.016,181.878 933.026,181.881 933.035,181.884 933.044,181.887 933.053,181.889 933.062,181.892 933.072,181.895 933.081,181.898 933.09,181.901 933.099,181.904 933.108,181.907 933.118,181.909 933.127,181.912 933.136,181.915 933.145,181.918 933.154,181.921 933.163,181.924 933.173,181.926 933.182,181.929 933.191,181.932 933.2,181.935 933.209,181.938 933.219,181.941 933.228,181.943 933.237,181.946 933.246,181.949 933.255,181.952 933.265,181.955 933.274,181.958 933.283,181.961 933.292,181.963 933.301,181.966 933.311,181.969 933.32,181.972 933.329,181.975 933.338,181.978 933.347,181.98 933.356,181.983 933.366,181.986 933.375,181.989 933.384,181.992 933.393,181.995 933.402,181.997 933.412,182 933.421,182.003 933.43,182.006 933.439,182.009 933.448,182.012 933.458,182.015 933.467,182.017 933.476,182.02 933.485,182.023 933.494,182.026 933.503,182.029 933.513,182.032 933.522,182.034 933.531,182.037 933.54,182.04 933.549,182.043 933.559,182.046 933.568,182.049 933.577,182.051 933.586,182.054 933.595,182.057 933.605,182.06 933.614,182.063 933.623,182.066 933.632,182.069 933.641,182.071 933.651,182.074 933.66,182.077 933.669,182.08 933.678,182.083 933.687,182.086 933.696,182.088 933.706,182.091 933.715,182.094 933.724,182.097 933.733,182.1 933.742,182.103 933.752,182.105 933.761,182.108 933.77,182.111 933.779,182.114 933.788,182.117 933.798,182.12 933.807,182.122 933.816,182.125 933.825,182.128 933.834,182.131 933.843,182.134 933.853,182.137 933.862,182.14 933.871,182.142 933.88,182.145 933.889,182.148 933.899,182.151 933.908,182.154 933.917,182.157 933.926,182.159 933.935,182.162 933.945,182.165 933.954,182.168 933.963,182.171 933.972,182.174 933.981,182.176 933.991,182.179 934,182.182 934.009,182.185 934.018,182.188 934.027,182.191 934.036,182.194 934.046,182.196 934.055,182.199 934.064,182.202 934.073,182.205 934.082,182.208 934.092,182.211 934.101,182.213 934.11,182.216 934.119,182.219 934.128,182.222 934.138,182.225 934.147,182.228 934.156,182.23 934.165,182.233 934.174,182.236 934.183,182.239 934.193,182.242 934.202,182.245 934.211,182.247 934.22,182.25 934.229,182.253 934.239,182.256 934.248,182.259 934.257,182.262 934.266,182.265 934.275,182.267 934.285,182.27 934.294,182.273 934.303,182.276 934.312,182.279 934.321,182.282 934.331,182.284 934.34,182.287 934.349,182.29 934.358,182.293 934.367,182.296 934.376,182.299 934.386,182.301 934.395,182.304 934.404,182.307 934.413,182.31 934.422,182.313 934.432,182.316 934.441,182.318 934.45,182.321 934.459,182.324 934.468,182.327 934.478,182.33 934.487,182.333 934.496,182.335 934.505,182.338 934.514,182.341 934.523,182.344 934.533,182.347 934.542,182.35 934.551,182.353 934.56,182.355 934.569,182.358 934.579,182.361 934.588,182.364 934.597,182.367 934.606,182.37 934.615,182.372 934.625,182.375 934.634,182.378 934.643,182.381 934.652,182.384 934.661,182.387 934.671,182.389 934.68,182.392 934.689,182.395 934.698,182.398 934.707,182.401 934.716,182.404 934.726,182.406 934.735,182.409 934.744,182.412 934.753,182.415 934.762,182.418 934.772,182.421 934.781,182.424 934.79,182.426 934.799,182.429 934.808,182.432 934.818,182.435 934.827,182.438 934.836,182.441 934.845,182.443 934.854,182.446 934.863,182.449 934.873,182.452 934.882,182.455 934.891,182.458 934.9,182.46 934.909,182.463 934.919,182.466 934.928,182.469 934.937,182.472 934.946,182.475 934.955,182.477 934.965,182.48 934.974,182.483 934.983,182.486 934.992,182.489 935.001,182.492 935.011,182.494 935.02,182.497 935.029,182.5 935.038,182.503 935.047,182.506 935.056,182.509 935.066,182.512 935.075,182.514 935.084,182.517 935.093,182.52 935.102,182.523 935.112,182.526 935.121,182.529 935.13,182.531 935.139,182.534 935.148,182.537 935.158,182.54 935.167,182.543 935.176,182.546 935.185,182.548 935.194,182.551 935.203,182.554 935.213,182.557 935.222,182.56 935.231,182.563 935.24,182.565 935.249,182.568 935.259,182.571 935.268,182.574 935.277,182.577 935.286,182.58 935.295,182.582 935.305,182.585 935.314,182.588 935.323,182.591 935.332,182.594 935.341,182.597 935.351,182.599 935.36,182.602 935.369,182.605 935.378,182.608 935.387,182.611 935.396,182.614 935.406,182.617 935.415,182.619 935.424,182.622 935.433,182.625 935.442,182.628 935.452,182.631 935.461,182.634 935.47,182.636 935.479,182.639 935.488,182.642 935.498,182.645 935.507,182.648 935.516,182.651 935.525,182.653 935.534,182.656 935.544,182.659 935.553,182.662 935.562,182.665 935.571,182.668 935.58,182.67 935.589,182.673 935.599,182.676 935.608,182.679 935.617,182.682 935.626,182.685 935.635,182.687 935.645,182.69 935.654,182.693 935.663,182.696 935.672,182.699 935.681,182.702 935.691,182.704 935.7,182.707 935.709,182.71 935.718,182.713 935.727,182.716 935.736,182.719 935.746,182.722 935.755,182.724 935.764,182.727 935.773,182.73 935.782,182.733 935.792,182.736 935.801,182.739 935.81,182.741 935.819,182.744 935.828,182.747 935.838,182.75 935.847,182.753 935.856,182.756 935.865,182.758 935.874,182.761 935.884,182.764 935.893,182.767 935.902,182.77 935.911,182.773 935.92,182.775 935.929,182.778 935.939,182.781 935.948,182.784 935.957,182.787 935.966,182.79 935.975,182.792 935.985,182.795 935.994,182.798 936.003,182.801 936.012,182.804 936.021,182.807 936.031,182.809 936.04,182.812 936.049,182.815 936.058,182.818 936.067,182.821 936.076,182.824 936.086,182.826 936.095,182.829 936.104,182.832 936.113,182.835 936.122,182.838 936.132,182.841 936.141,182.843 936.15,182.846 936.159,182.849 936.168,182.852 936.178,182.855 936.187,182.858 936.196,182.861 936.205,182.863 936.214,182.866 936.224,182.869 936.233,182.872 936.242,182.875 936.251,182.878 936.26,182.88 936.269,182.883 936.279,182.886 936.288,182.889 936.297,182.892 936.306,182.895 936.315,182.897 936.325,182.9 936.334,182.903 936.343,182.906 936.352,182.909 936.361,182.912 936.371,182.914 936.38,182.917 936.389,182.92 936.398,182.923 936.407,182.926 936.416,182.929 936.426,182.931 936.435,182.934 936.444,182.937 936.453,182.94 936.462,182.943 936.472,182.946 936.481,182.948 936.49,182.951 936.499,182.954 936.508,182.957 936.518,182.96 936.527,182.963 936.536,182.965 936.545,182.968 936.554,182.971 936.564,182.974 936.573,182.977 936.582,182.98 936.591,182.982 936.6,182.985 936.609,182.988 936.619,182.991 936.628,182.994 936.637,182.997 936.646,182.999 936.655,183.002 936.665,183.005 936.674,183.008 936.683,183.011 936.692,183.014 936.701,183.016 936.711,183.019 936.72,183.022 936.729,183.025 936.738,183.028 936.747,183.031 936.756,183.033 936.766,183.036 936.775,183.039 936.784,183.042 936.793,183.045 936.802,183.048 936.812,183.051 936.821,183.053 936.83,183.056 936.839,183.059 936.848,183.062 936.858,183.065 936.867,183.068 936.876,183.07 936.885,183.073 936.894,183.076 936.904,183.079 936.913,183.082 936.922,183.085 936.931,183.087 936.94,183.09 936.949,183.093 936.959,183.096 936.968,183.099 936.977,183.102 936.986,183.104 936.995,183.107 937.005,183.11 937.014,183.113 937.023,183.116 937.032,183.119 937.041,183.121 937.051,183.124 937.06,183.127 937.069,183.13 937.078,183.133 937.087,183.136 937.096,183.138 937.106,183.141 937.115,183.144 937.124,183.147 937.133,183.15 937.142,183.153 937.152,183.155 937.161,183.158 937.17,183.161 937.179,183.164 937.188,183.167 937.198,183.17 937.207,183.172 937.216,183.175 937.225,183.178 937.234,183.181 937.244,183.184 937.253,183.187 937.262,183.189 937.271,183.192 937.28,183.195 937.289,183.198 937.299,183.201 937.308,183.204 937.317,183.206 937.326,183.209 937.335,183.212 937.345,183.215 937.354,183.218 937.363,183.221 937.372,183.223 937.381,183.226 937.391,183.229 937.4,183.232 937.409,183.235 937.418,183.238 937.427,183.24 937.436,183.243 937.446,183.246 937.455,183.249 937.464,183.252 937.473,183.255 937.482,183.257 937.492,183.26 937.501,183.263 937.51,183.266 937.519,183.269 937.528,183.272 937.538,183.274 937.547,183.277 937.556,183.28 937.565,183.283 937.574,183.286 937.584,183.289 937.593,183.291 937.602,183.294 937.611,183.297 937.62,183.3 937.629,183.303 937.639,183.306 937.648,183.308 937.657,183.311 937.666,183.314 937.675,183.317 937.685,183.32 937.694,183.323 937.703,183.325 937.712,183.328 937.721,183.331 937.731,183.334 937.74,183.337 937.749,183.34 937.758,183.342 937.767,183.345 937.776,183.348 937.786,183.351 937.795,183.354 937.804,183.357 937.813,183.359 937.822,183.362 937.832,183.365 937.841,183.368 937.85,183.371 937.859,183.374 937.868,183.376 937.878,183.379 937.887,183.382 937.896,183.385 937.905,183.388 937.914,183.391 937.924,183.393 937.933,183.396 937.942,183.399 937.951,183.402 937.96,183.405 937.969,183.408 937.979,183.41 937.988,183.413 937.997,183.416 938.006,183.419 938.015,183.422 938.025,183.425 938.034,183.427 938.043,183.43 938.052,183.433 938.061,183.436 938.071,183.439 938.08,183.442 938.089,183.444 938.098,183.447 938.107,183.45 938.117,183.453 938.126,183.456 938.135,183.459 938.144,183.461 938.153,183.464 938.162,183.467 938.172,183.47 938.181,183.473 938.19,183.476 938.199,183.478 938.208,183.481 938.218,183.484 938.227,183.487 938.236,183.49 938.245,183.493 938.254,183.495 938.264,183.498 938.273,183.501 938.282,183.504 938.291,183.507 938.3,183.51 938.309,183.512 938.319,183.515 938.328,183.518 938.337,183.521 938.346,183.524 938.355,183.527 938.365,183.529 938.374,183.532 938.383,183.535 938.392,183.538 938.401,183.541 938.411,183.544 938.42,183.546 938.429,183.549 938.438,183.552 938.447,183.555 938.457,183.558 938.466,183.561 938.475,183.563 938.484,183.566 938.493,183.569 938.502,183.572 938.512,183.575 938.521,183.578 938.53,183.58 938.539,183.583 938.548,183.586 938.558,183.589 938.567,183.592 938.576,183.595 938.585,183.597 938.594,183.6 938.604,183.603 938.613,183.606 938.622,183.609 938.631,183.612 938.64,183.614 938.649,183.617 938.659,183.62 938.668,183.623 938.677,183.626 938.686,183.629 938.695,183.631 938.705,183.634 938.714,183.637 938.723,183.64 938.732,183.643 938.741,183.645 938.751,183.648 938.76,183.651 938.769,183.654 938.778,183.657 938.787,183.66 938.797,183.662 938.806,183.665 938.815,183.668 938.824,183.671 938.833,183.674 938.842,183.677 938.852,183.679 938.861,183.682 938.87,183.685 938.879,183.688 938.888,183.691 938.898,183.694 938.907,183.696 938.916,183.699 938.925,183.702 938.934,183.705 938.944,183.708 938.953,183.711 938.962,183.713 938.971,183.716 938.98,183.719 938.989,183.722 938.999,183.725 939.008,183.728 939.017,183.73 939.026,183.733 939.035,183.736 939.045,183.739 939.054,183.742 939.063,183.745 939.072,183.747 939.081,183.75 939.091,183.753 939.1,183.756 939.109,183.759 939.118,183.762 939.127,183.764 939.137,183.767 939.146,183.77 939.155,183.773 939.164,183.776 939.173,183.779 939.182,183.781 939.192,183.784 939.201,183.787 939.21,183.79 939.219,183.793 939.228,183.796 939.238,183.798 939.247,183.801 939.256,183.804 939.265,183.807 939.274,183.81 939.284,183.813 939.293,183.815 939.302,183.818 939.311,183.821 939.32,183.824 939.329,183.827 939.339,183.83 939.348,183.832 939.357,183.835 939.366,183.838 939.375,183.841 939.385,183.844 939.394,183.846 939.403,183.849 939.412,183.852 939.421,183.855 939.431,183.858 939.44,183.861 939.449,183.863 939.458,183.866 939.467,183.869 939.477,183.872 939.486,183.875 939.495,183.878 939.504,183.88 939.513,183.883 939.522,183.886 939.532,183.889 939.541,183.892 939.55,183.895 939.559,183.897 939.568,183.9 939.578,183.903 939.587,183.906 939.596,183.909 939.605,183.912 939.614,183.914 939.624,183.917 939.633,183.92 939.642,183.923 939.651,183.926 939.66,183.929 939.669,183.931 939.679,183.934 939.688,183.937 939.697,183.94 939.706,183.943 939.715,183.946 939.725,183.948 939.734,183.951 939.743,183.954 939.752,183.957 939.761,183.96 939.771,183.963 939.78,183.965 939.789,183.968 939.798,183.971 939.807,183.974 939.817,183.977 939.826,183.979 939.835,183.982 939.844,183.985 939.853,183.988 939.862,183.991 939.872,183.994 939.881,183.996 939.89,183.999 939.899,184.002 939.908,184.005 939.918,184.008 939.927,184.011 939.936,184.013 939.945,184.016 939.954,184.019 939.964,184.022 939.973,184.025 939.982,184.028 939.991,184.03 940,184.033 940.009,184.036 940.019,184.039 940.028,184.042 940.037,184.045 940.046,184.047 940.055,184.05 940.065,184.053 940.074,184.056 940.083,184.059 940.092,184.062 940.101,184.064 940.111,184.067 940.12,184.07 940.129,184.073 940.138,184.076 940.147,184.079 940.157,184.081 940.166,184.084 940.175,184.087 940.184,184.09 940.193,184.093 940.202,184.095 940.212,184.098 940.221,184.101 940.23,184.104 940.239,184.107 940.248,184.11 940.258,184.112 940.267,184.115 940.276,184.118 940.285,184.121 940.294,184.124 940.304,184.127 940.313,184.129 940.322,184.132 940.331,184.135 940.34,184.138 940.35,184.141 940.359,184.144 940.368,184.146 940.377,184.149 940.386,184.152 940.395,184.155 940.405,184.158 940.414,184.161 940.423,184.163 940.432,184.166 940.441,184.169 940.451,184.172 940.46,184.175 940.469,184.178 940.478,184.18 940.487,184.183 940.497,184.186 940.506,184.189 940.515,184.192 940.524,184.194 940.533,184.197 940.542,184.2 940.552,184.203 940.561,184.206 940.57,184.209 940.579,184.211 940.588,184.214 940.598,184.217 940.607,184.22 940.616,184.223 940.625,184.226 940.634,184.228 940.644,184.231 940.653,184.234 940.662,184.237 940.671,184.24 940.68,184.243 940.69,184.245 940.699,184.248 940.708,184.251 940.717,184.254 940.726,184.257 940.735,184.26 940.745,184.262 940.754,184.265 940.763,184.268 940.772,184.271 940.781,184.274 940.791,184.276 940.8,184.279 940.809,184.282 940.818,184.285 940.827,184.288 940.837,184.291 940.846,184.293 940.855,184.296 940.864,184.299 940.873,184.302 940.882,184.305 940.892,184.308 940.901,184.31 940.91,184.313 940.919,184.316 940.928,184.319 940.938,184.322 940.947,184.325 940.956,184.327 940.965,184.33 940.974,184.333 940.984,184.336 940.993,184.339 941.002,184.342 941.011,184.344 941.02,184.347 941.03,184.35 941.039,184.353 941.048,184.356 941.057,184.358 941.066,184.361 941.075,184.364 941.085,184.367 941.094,184.37 941.103,184.373 941.112,184.375 941.121,184.378 941.131,184.381 941.14,184.384 941.149,184.387 941.158,184.39 941.167,184.392 941.177,184.395 941.186,184.398 941.195,184.401 941.204,184.404 941.213,184.407 941.222,184.409 941.232,184.412 941.241,184.415 941.25,184.418 941.259,184.421 941.268,184.424 941.278,184.426 941.287,184.429 941.296,184.432 941.305,184.435 941.314,184.438 941.324,184.44 941.333,184.443 941.342,184.446 941.351,184.449 941.36,184.452 941.37,184.455 941.379,184.457 941.388,184.46 941.397,184.463 941.406,184.466 941.415,184.469 941.425,184.472 941.434,184.474 941.443,184.477 941.452,184.48 941.461,184.483 941.471,184.486 941.48,184.489 941.489,184.491 941.498,184.494 941.507,184.497 941.517,184.5 941.526,184.503 941.535,184.505 941.544,184.508 941.553,184.511 941.562,184.514 941.572,184.517 941.581,184.52 941.59,184.522 941.599,184.525 941.608,184.528 941.618,184.531 941.627,184.534 941.636,184.537 941.645,184.539 941.654,184.542 941.664,184.545 941.673,184.548 941.682,184.551 941.691,184.554 941.7,184.556 941.71,184.559 941.719,184.562 941.728,184.565 941.737,184.568 941.746,184.57 941.755,184.573 941.765,184.576 941.774,184.579 941.783,184.582 941.792,184.585 941.801,184.587 941.811,184.59 941.82,184.593 941.829,184.596 941.838,184.599 941.847,184.602 941.857,184.604 941.866,184.607 941.875,184.61 941.884,184.613 941.893,184.616 941.902,184.619 941.912,184.621 941.921,184.624 941.93,184.627 941.939,184.63 941.948,184.633 941.958,184.635 941.967,184.638 941.976,184.641 941.985,184.644 941.994,184.647 942.004,184.65 942.013,184.652 942.022,184.655 942.031,184.658 942.04,184.661 942.05,184.664 942.059,184.667 942.068,184.669 942.077,184.672 942.086,184.675 942.095,184.678 942.105,184.681 942.114,184.683 942.123,184.686 942.132,184.689 942.141,184.692 942.151,184.695 942.16,184.698 942.169,184.7 942.178,184.703 942.187,184.706 942.197,184.709 942.206,184.712 942.215,184.715 942.224,184.717 942.233,184.72 942.242,184.723 942.252,184.726 942.261,184.729 942.27,184.732 942.279,184.734 942.288,184.737 942.298,184.74 942.307,184.743 942.316,184.746 942.325,184.748 942.334,184.751 942.344,184.754 942.353,184.757 942.362,184.76 942.371,184.763 942.38,184.765 942.39,184.768 942.399,184.771 942.408,184.774 942.417,184.777 942.426,184.78 942.435,184.782 942.445,184.785 942.454,184.788 942.463,184.791 942.472,184.794 942.481,184.796 942.491,184.799 942.5,184.802 942.509,184.805 942.518,184.808 942.527,184.811 942.537,184.813 942.546,184.816 942.555,184.819 942.564,184.822 942.573,184.825 942.582,184.828 942.592,184.83 942.601,184.833 942.61,184.836 942.619,184.839 942.628,184.842 942.638,184.844 942.647,184.847 942.656,184.85 942.665,184.853 942.674,184.856 942.684,184.859 942.693,184.861 942.702,184.864 942.711,184.867 942.72,184.87 942.73,184.873 942.739,184.876 942.748,184.878 942.757,184.881 942.766,184.884 942.775,184.887 942.785,184.89 942.794,184.892 942.803,184.895 942.812,184.898 942.821,184.901 942.831,184.904 942.84,184.907 942.849,184.909 942.858,184.912 942.867,184.915 942.877,184.918 942.886,184.921 942.895,184.924 942.904,184.926 942.913,184.929 942.923,184.932 942.932,184.935 942.941,184.938 942.95,184.941 942.959,184.943 942.968,184.946 942.978,184.949 942.987,184.952 942.996,184.955 943.005,184.957 943.014,184.96 943.024,184.963 943.033,184.966 943.042,184.969 943.051,184.972 943.06,184.974 943.07,184.977 943.079,184.98 943.088,184.983 943.097,184.986 943.106,184.988 943.115,184.991 943.125,184.994 943.134,184.997 943.143,185 943.152,185.003 943.161,185.005 943.171,185.008 943.18,185.011 943.189,185.014 943.198,185.017 943.207,185.02 943.217,185.022 943.226,185.025 943.235,185.028 943.244,185.031 943.253,185.034 943.263,185.036 943.272,185.039 943.281,185.042 943.29,185.045 943.299,185.048 943.308,185.051 943.318,185.053 943.327,185.056 943.336,185.059 943.345,185.062 943.354,185.065 943.364,185.068 943.373,185.07 943.382,185.073 943.391,185.076 943.4,185.079 943.41,185.082 943.419,185.084 943.428,185.087 943.437,185.09 943.446,185.093 943.455,185.096 943.465,185.099 943.474,185.101 943.483,185.104 943.492,185.107 943.501,185.11 943.511,185.113 943.52,185.116 943.529,185.118 943.538,185.121 943.547,185.124 943.557,185.127 943.566,185.13 943.575,185.132 943.584,185.135 943.593,185.138 943.603,185.141 943.612,185.144 943.621,185.147 943.63,185.149 943.639,185.152 943.648,185.155 943.658,185.158 943.667,185.161 943.676,185.164 943.685,185.166 943.694,185.169 943.704,185.172 943.713,185.175 943.722,185.178 943.731,185.18 943.74,185.183 943.75,185.186 943.759,185.189 943.768,185.192 943.777,185.195 943.786,185.197 943.795,185.2 943.805,185.203 943.814,185.206 943.823,185.209 943.832,185.211 943.841,185.214 943.851,185.217 943.86,185.22 943.869,185.223 943.878,185.226 943.887,185.228 943.897,185.231 943.906,185.234 943.915,185.237 943.924,185.24 943.933,185.243 943.943,185.245 943.952,185.248 943.961,185.251 943.97,185.254 943.979,185.257 943.988,185.259 943.998,185.262 944.007,185.265 944.016,185.268 944.025,185.271 944.034,185.274 944.044,185.276 944.053,185.279 944.062,185.282 944.071,185.285 944.08,185.288 944.09,185.29 944.099,185.293 944.108,185.296 944.117,185.299 944.126,185.302 944.135,185.305 944.145,185.307 944.154,185.31 944.163,185.313 944.172,185.316 944.181,185.319 944.191,185.322 944.2,185.324 944.209,185.327 944.218,185.33 944.227,185.333 944.237,185.336 944.246,185.338 944.255,185.341 944.264,185.344 944.273,185.347 944.283,185.35 944.292,185.353 944.301,185.355 944.31,185.358 944.319,185.361 944.328,185.364 944.338,185.367 944.347,185.369 944.356,185.372 944.365,185.375 944.374,185.378 944.384,185.381 944.393,185.384 944.402,185.386 944.411,185.389 944.42,185.392 944.43,185.395 944.439,185.398 944.448,185.401 944.457,185.403 944.466,185.406 944.475,185.409 944.485,185.412 944.494,185.415 944.503,185.417 944.512,185.42 944.521,185.423 944.531,185.426 944.54,185.429 944.549,185.432 944.558,185.434 944.567,185.437 944.577,185.44 944.586,185.443 944.595,185.446 944.604,185.448 944.613,185.451 944.623,185.454 944.632,185.457 944.641,185.46 944.65,185.463 944.659,185.465 944.668,185.468 944.678,185.471 944.687,185.474 944.696,185.477 944.705,185.479 944.714,185.482 944.724,185.485 944.733,185.488 944.742,185.491 944.751,185.494 944.76,185.496 944.77,185.499 944.779,185.502 944.788,185.505 944.797,185.508 944.806,185.51 944.815,185.513 944.825,185.516 944.834,185.519 944.843,185.522 944.852,185.525 944.861,185.527 944.871,185.53 944.88,185.533 944.889,185.536 944.898,185.539 944.907,185.542 944.917,185.544 944.926,185.547 944.935,185.55 944.944,185.553 944.953,185.556 944.963,185.558 944.972,185.561 944.981,185.564 944.99,185.567 944.999,185.57 945.008,185.573 945.018,185.575 945.027,185.578 945.036,185.581 945.045,185.584 945.054,185.587 945.064,185.589 945.073,185.592 945.082,185.595 945.091,185.598 945.1,185.601 945.11,185.604 945.119,185.606 945.128,185.609 945.137,185.612 945.146,185.615 945.155,185.618 945.165,185.62 945.174,185.623 945.183,185.626 945.192,185.629 945.201,185.632 945.211,185.635 945.22,185.637 945.229,185.64 945.238,185.643 945.247,185.646 945.257,185.649 945.266,185.651 945.275,185.654 945.284,185.657 945.293,185.66 945.303,185.663 945.312,185.666 945.321,185.668 945.33,185.671 945.339,185.674 945.348,185.677 945.358,185.68 945.367,185.682 945.376,185.685 945.385,185.688 945.394,185.691 945.404,185.694 945.413,185.697 945.422,185.699 945.431,185.702 945.44,185.705 945.45,185.708 945.459,185.711 945.468,185.713 945.477,185.716 945.486,185.719 945.496,185.722 945.505,185.725 945.514,185.728 945.523,185.73 945.532,185.733 945.541,185.736 945.551,185.739 945.56,185.742 945.569,185.744 945.578,185.747 945.587,185.75 945.597,185.753 945.606,185.756 945.615,185.759 945.624,185.761 945.633,185.764 945.643,185.767 945.652,185.77 945.661,185.773 945.67,185.776 945.679,185.778 945.688,185.781 945.698,185.784 945.707,185.787 945.716,185.79 945.725,185.792 945.734,185.795 945.744,185.798 945.753,185.801 945.762,185.804 945.771,185.807 945.78,185.809 945.79,185.812 945.799,185.815 945.808,185.818 945.817,185.821 945.826,185.823 945.836,185.826 945.845,185.829 945.854,185.832 945.863,185.835 945.872,185.837 945.881,185.84 945.891,185.843 945.9,185.846 945.909,185.849 945.918,185.852 945.927,185.854 945.937,185.857 945.946,185.86 945.955,185.863 945.964,185.866 945.973,185.868 945.983,185.871 945.992,185.874 946.001,185.877 946.01,185.88 946.019,185.883 946.028,185.885 946.038,185.888 946.047,185.891 946.056,185.894 946.065,185.897 946.074,185.899 946.084,185.902 946.093,185.905 946.102,185.908 946.111,185.911 946.12,185.914 946.13,185.916 946.139,185.919 946.148,185.922 946.157,185.925 946.166,185.928 946.176,185.93 946.185,185.933 946.194,185.936 946.203,185.939 946.212,185.942 946.221,185.945 946.231,185.947 946.24,185.95 946.249,185.953 946.258,185.956 946.267,185.959 946.277,185.961 946.286,185.964 946.295,185.967 946.304,185.97 946.313,185.973 946.323,185.976 946.332,185.978 946.341,185.981 946.35,185.984 946.359,185.987 946.368,185.99 946.378,185.992 946.387,185.995 946.396,185.998 946.405,186.001 946.414,186.004 946.424,186.007 946.433,186.009 946.442,186.012 946.451,186.015 946.46,186.018 946.47,186.021 946.479,186.023 946.488,186.026 946.497,186.029 946.506,186.032 946.516,186.035 946.525,186.038 946.534,186.04 946.543,186.043 946.552,186.046 946.561,186.049 946.571,186.052 946.58,186.054 946.589,186.057 946.598,186.06 946.607,186.063 946.617,186.066 946.626,186.069 946.635,186.071 946.644,186.074 946.653,186.077 946.663,186.08 946.672,186.083 946.681,186.085 946.69,186.088 946.699,186.091 946.708,186.094 946.718,186.097 946.727,186.099 946.736,186.102 946.745,186.105 946.754,186.108 946.764,186.111 946.773,186.114 946.782,186.116 946.791,186.119 946.8,186.122 946.81,186.125 946.819,186.128 946.828,186.13 946.837,186.133 946.846,186.136 946.856,186.139 946.865,186.142 946.874,186.145 946.883,186.147 946.892,186.15 946.901,186.153 946.911,186.156 946.92,186.159 946.929,186.161 946.938,186.164 946.947,186.167 946.957,186.17 946.966,186.173 946.975,186.176 946.984,186.178 946.993,186.181 947.003,186.184 947.012,186.187 947.021,186.19 947.03,186.192 947.039,186.195 947.048,186.198 947.058,186.201 947.067,186.204 947.076,186.207 947.085,186.209 947.094,186.212 947.104,186.215 947.113,186.218 947.122,186.221 947.131,186.223 947.14,186.226 947.15,186.229 947.159,186.232 947.168,186.235 947.177,186.237 947.186,186.24 947.196,186.243 947.205,186.246 947.214,186.249 947.223,186.252 947.232,186.254 947.241,186.257 947.251,186.26 947.26,186.263 947.269,186.266 947.278,186.268 947.287,186.271 947.297,186.274 947.306,186.277 947.315,186.28 947.324,186.283 947.333,186.285 947.343,186.288 947.352,186.291 947.361,186.294 947.37,186.297 947.379,186.299 947.388,186.302 947.398,186.305 947.407,186.308 947.416,186.311 947.425,186.313 947.434,186.316 947.444,186.319 947.453,186.322 947.462,186.325 947.471,186.328 947.48,186.33 947.49,186.333 947.499,186.336 947.508,186.339 947.517,186.342 947.526,186.344 947.536,186.347 947.545,186.35 947.554,186.353 947.563,186.356 947.572,186.359 947.581,186.361 947.591,186.364 947.6,186.367 947.609,186.37 947.618,186.373 947.627,186.375 947.637,186.378 947.646,186.381 947.655,186.384 947.664,186.387 947.673,186.389 947.683,186.392 947.692,186.395 947.701,186.398 947.71,186.401 947.719,186.404 947.729,186.406 947.738,186.409 947.747,186.412 947.756,186.415 947.765,186.418 947.774,186.42 947.784,186.423 947.793,186.426 947.802,186.429 947.811,186.432 947.82,186.435 947.83,186.437 947.839,186.44 947.848,186.443 947.857,186.446 947.866,186.449 947.876,186.451 947.885,186.454 947.894,186.457 947.903,186.46 947.912,186.463 947.921,186.465 947.931,186.468 947.94,186.471 947.949,186.474 947.958,186.477 947.967,186.48 947.977,186.482 947.986,186.485 947.995,186.488 948.004,186.491 948.013,186.494 948.023,186.496 948.032,186.499 948.041,186.502 948.05,186.505 948.059,186.508 948.069,186.51 948.078,186.513 948.087,186.516 948.096,186.519 948.105,186.522 948.114,186.525 948.124,186.527 948.133,186.53 948.142,186.533 948.151,186.536 948.16,186.539 948.17,186.541 948.179,186.544 948.188,186.547 948.197,186.55 948.206,186.553 948.216,186.556 948.225,186.558 948.234,186.561 948.243,186.564 948.252,186.567 948.261,186.57 948.271,186.572 948.28,186.575 948.289,186.578 948.298,186.581 948.307,186.584 948.317,186.586 948.326,186.589 948.335,186.592 948.344,186.595 948.353,186.598 948.363,186.601 948.372,186.603 948.381,186.606 948.39,186.609 948.399,186.612 948.409,186.615 948.418,186.617 948.427,186.62 948.436,186.623 948.445,186.626 948.454,186.629 948.464,186.631 948.473,186.634 948.482,186.637 948.491,186.64 948.5,186.643 948.51,186.646 948.519,186.648 948.528,186.651 948.537,186.654 948.546,186.657 948.556,186.66 948.565,186.662 948.574,186.665 948.583,186.668 948.592,186.671 948.601,186.674 948.611,186.676 948.62,186.679 948.629,186.682 948.638,186.685 948.647,186.688 948.657,186.691 948.666,186.693 948.675,186.696 948.684,186.699 948.693,186.702 948.703,186.705 948.712,186.707 948.721,186.71 948.73,186.713 948.739,186.716 948.749,186.719 948.758,186.721 948.767,186.724 948.776,186.727 948.785,186.73 948.794,186.733 948.804,186.736 948.813,186.738 948.822,186.741 948.831,186.744 948.84,186.747 948.85,186.75 948.859,186.752 948.868,186.755 948.877,186.758 948.886,186.761 948.896,186.764 948.905,186.766 948.914,186.769 948.923,186.772 948.932,186.775 948.941,186.778 948.951,186.781 948.96,186.783 948.969,186.786 948.978,186.789 948.987,186.792 948.997,186.795 949.006,186.797 949.015,186.8 949.024,186.803 949.033,186.806 949.043,186.809 949.052,186.811 949.061,186.814 949.07,186.817 949.079,186.82 949.089,186.823 949.098,186.826 949.107,186.828 949.116,186.831 949.125,186.834 949.134,186.837 949.144,186.84 949.153,186.842 949.162,186.845 949.171,186.848 949.18,186.851 949.19,186.854 949.199,186.856 949.208,186.859 949.217,186.862 949.226,186.865 949.236,186.868 949.245,186.871 949.254,186.873 949.263,186.876 949.272,186.879 949.281,186.882 949.291,186.885 949.3,186.887 949.309,186.89 949.318,186.893 949.327,186.896 949.337,186.899 949.346,186.901 949.355,186.904 949.364,186.907 949.373,186.91 949.383,186.913 949.392,186.915 949.401,186.918 949.41,186.921 949.419,186.924 949.429,186.927 949.438,186.93 949.447,186.932 949.456,186.935 949.465,186.938 949.474,186.941 949.484,186.944 949.493,186.946 949.502,186.949 949.511,186.952 949.52,186.955 949.53,186.958 949.539,186.96 949.548,186.963 949.557,186.966 949.566,186.969 949.576,186.972 949.585,186.975 949.594,186.977 949.603,186.98 949.612,186.983 949.621,186.986 949.631,186.989 949.64,186.991 949.649,186.994 949.658,186.997 949.667,187 949.677,187.003 949.686,187.005 949.695,187.008 949.704,187.011 949.713,187.014 949.723,187.017 949.732,187.019 949.741,187.022 949.75,187.025 949.759,187.028 949.769,187.031 949.778,187.034 949.787,187.036 949.796,187.039 949.805,187.042 949.814,187.045 949.824,187.048 949.833,187.05 949.842,187.053 949.851,187.056 949.86,187.059 949.87,187.062 949.879,187.064 949.888,187.067 949.897,187.07 949.906,187.073 949.916,187.076 949.925,187.079 949.934,187.081 949.943,187.084 949.952,187.087 949.961,187.09 949.971,187.093 949.98,187.095 949.989,187.098 949.998,187.101 950.007,187.104 950.017,187.107 950.026,187.109 950.035,187.112 950.044,187.115 950.053,187.118 950.063,187.121 950.072,187.123 950.081,187.126 950.09,187.129 950.099,187.132 950.109,187.135 950.118,187.138 950.127,187.14 950.136,187.143 950.145,187.146 950.154,187.149 950.164,187.152 950.173,187.154 950.182,187.157 950.191,187.16 950.2,187.163 950.21,187.166 950.219,187.168 950.228,187.171 950.237,187.174 950.246,187.177 950.256,187.18 950.265,187.182 950.274,187.185 950.283,187.188 950.292,187.191 950.302,187.194 950.311,187.197 950.32,187.199 950.329,187.202 950.338,187.205 950.347,187.208 950.357,187.211 950.366,187.213 950.375,187.216 950.384,187.219 950.393,187.222 950.403,187.225 950.412,187.227 950.421,187.23 950.43,187.233 950.439,187.236 950.449,187.239 950.458,187.241 950.467,187.244 950.476,187.247 950.485,187.25 950.494,187.253 950.504,187.256 950.513,187.258 950.522,187.261 950.531,187.264 950.54,187.267 950.55,187.27 950.559,187.272 950.568,187.275 950.577,187.278 950.586,187.281 950.596,187.284 950.605,187.286 950.614,187.289 950.623,187.292 950.632,187.295 950.642,187.298 950.651,187.3 950.66,187.303 950.669,187.306 950.678,187.309 950.687,187.312 950.697,187.315 950.706,187.317 950.715,187.32 950.724,187.323 950.733,187.326 950.743,187.329 950.752,187.331 950.761,187.334 950.77,187.337 950.779,187.34 950.789,187.343 950.798,187.345 950.807,187.348 950.816,187.351 950.825,187.354 950.834,187.357 950.844,187.359 950.853,187.362 950.862,187.365 950.871,187.368 950.88,187.371 950.89,187.373 950.899,187.376 950.908,187.379 950.917,187.382 950.926,187.385 950.936,187.388 950.945,187.39 950.954,187.393 950.963,187.396 950.972,187.399 950.982,187.402 950.991,187.404 951,187.407 951.009,187.41 951.018,187.413 951.027,187.416 951.037,187.418 951.046,187.421 951.055,187.424 951.064,187.427 951.073,187.43 951.083,187.432 951.092,187.435 951.101,187.438 951.11,187.441 951.119,187.444 951.129,187.447 951.138,187.449 951.147,187.452 951.156,187.455 951.165,187.458 951.174,187.461 951.184,187.463 951.193,187.466 951.202,187.469 951.211,187.472 951.22,187.475 951.23,187.477 951.239,187.48 951.248,187.483 951.257,187.486 951.266,187.489 951.276,187.491 951.285,187.494 951.294,187.497 951.303,187.5 951.312,187.503 951.322,187.505 951.331,187.508 951.34,187.511 951.349,187.514 951.358,187.517 951.367,187.52 951.377,187.522 951.386,187.525 951.395,187.528 951.404,187.531 951.413,187.534 951.423,187.536 951.432,187.539 951.441,187.542 951.45,187.545 951.459,187.548 951.469,187.55 951.478,187.553 951.487,187.556 951.496,187.559 951.505,187.562 951.514,187.564 951.524,187.567 951.533,187.57 951.542,187.573 951.551,187.576 951.56,187.578 951.57,187.581 951.579,187.584 951.588,187.587 951.597,187.59 951.606,187.592 951.616,187.595 951.625,187.598 951.634,187.601 951.643,187.604 951.652,187.607 951.662,187.609 951.671,187.612 951.68,187.615 951.689,187.618 951.698,187.621 951.707,187.623 951.717,187.626 951.726,187.629 951.735,187.632 951.744,187.635 951.753,187.637 951.763,187.64 951.772,187.643 951.781,187.646 951.79,187.649 951.799,187.651 951.809,187.654 951.818,187.657 951.827,187.66 951.836,187.663 951.845,187.665 951.854,187.668 951.864,187.671 951.873,187.674 951.882,187.677 951.891,187.679 951.9,187.682 951.91,187.685 951.919,187.688 951.928,187.691 951.937,187.694 951.946,187.696 951.956,187.699 951.965,187.702 951.974,187.705 951.983,187.708 951.992,187.71 952.002,187.713 952.011,187.716 952.02,187.719 952.029,187.722 952.038,187.724 952.047,187.727 952.057,187.73 952.066,187.733 952.075,187.736 952.084,187.738 952.093,187.741 952.103,187.744 952.112,187.747 952.121,187.75 952.13,187.752 952.139,187.755 952.149,187.758 952.158,187.761 952.167,187.764 952.176,187.766 952.185,187.769 952.194,187.772 952.204,187.775 952.213,187.778 952.222,187.781 952.231,187.783 952.24,187.786 952.25,187.789 952.259,187.792 952.268,187.795 952.277,187.797 952.286,187.8 952.296,187.803 952.305,187.806 952.314,187.809 952.323,187.811 952.332,187.814 952.342,187.817 952.351,187.82 952.36,187.823 952.369,187.825 952.378,187.828 952.387,187.831 952.397,187.834 952.406,187.837 952.415,187.839 952.424,187.842 952.433,187.845 952.443,187.848 952.452,187.851 952.461,187.853 952.47,187.856 952.479,187.859 952.489,187.862 952.498,187.865 952.507,187.867 952.516,187.87 952.525,187.873 952.534,187.876 952.544,187.879 952.553,187.882 952.562,187.884 952.571,187.887 952.58,187.89 952.59,187.893 952.599,187.896 952.608,187.898 952.617,187.901 952.626,187.904 952.636,187.907 952.645,187.91 952.654,187.912 952.663,187.915 952.672,187.918 952.682,187.921 952.691,187.924 952.7,187.926 952.709,187.929 952.718,187.932 952.727,187.935 952.737,187.938 952.746,187.94 952.755,187.943 952.764,187.946 952.773,187.949 952.783,187.952 952.792,187.954 952.801,187.957 952.81,187.96 952.819,187.963 952.829,187.966 952.838,187.968 952.847,187.971 952.856,187.974 952.865,187.977 952.875,187.98 952.884,187.982 952.893,187.985 952.902,187.988 952.911,187.991 952.92,187.994 952.93,187.997 952.939,187.999 952.948,188.002 952.957,188.005 952.966,188.008 952.976,188.011 952.985,188.013 952.994,188.016 953.003,188.019 953.012,188.022 953.022,188.025 953.031,188.027 953.04,188.03 953.049,188.033 953.058,188.036 953.067,188.039 953.077,188.041 953.086,188.044 953.095,188.047 953.104,188.05 953.113,188.053 953.123,188.055 953.132,188.058 953.141,188.061 953.15,188.064 953.159,188.067 953.169,188.069 953.178,188.072 953.187,188.075 953.196,188.078 953.205,188.081 953.215,188.083 953.224,188.086 953.233,188.089 953.242,188.092 953.251,188.095 953.26,188.097 953.27,188.1 953.279,188.103 953.288,188.106 953.297,188.109 953.306,188.111 953.316,188.114 953.325,188.117 953.334,188.12 953.343,188.123 953.352,188.125 953.362,188.128 953.371,188.131 953.38,188.134 953.389,188.137 953.398,188.14 953.407,188.142 953.417,188.145 953.426,188.148 953.435,188.151 953.444,188.154 953.453,188.156 953.463,188.159 953.472,188.162 953.481,188.165 953.49,188.168 953.499,188.17 953.509,188.173 953.518,188.176 953.527,188.179 953.536,188.182 953.545,188.184 953.555,188.187 953.564,188.19 953.573,188.193 953.582,188.196 953.591,188.198 953.6,188.201 953.61,188.204 953.619,188.207 953.628,188.21 953.637,188.212 953.646,188.215 953.656,188.218 953.665,188.221 953.674,188.224 953.683,188.226 953.692,188.229 953.702,188.232 953.711,188.235 953.72,188.238 953.729,188.24 953.738,188.243 953.747,188.246 953.757,188.249 953.766,188.252 953.775,188.254 953.784,188.257 953.793,188.26 953.803,188.263 953.812,188.266 953.821,188.268 953.83,188.271 953.839,188.274 953.849,188.277 953.858,188.28 953.867,188.282 953.876,188.285 953.885,188.288 953.895,188.291 953.904,188.294 953.913,188.296 953.922,188.299 953.931,188.302 953.94,188.305 953.95,188.308 953.959,188.311 953.968,188.313 953.977,188.316 953.986,188.319 953.996,188.322 954.005,188.325 954.014,188.327 954.023,188.33 954.032,188.333 954.042,188.336 954.051,188.339 954.06,188.341 954.069,188.344 954.078,188.347 954.087,188.35 954.097,188.353 954.106,188.355 954.115,188.358 954.124,188.361 954.133,188.364 954.143,188.367 954.152,188.369 954.161,188.372 954.17,188.375 954.179,188.378 954.189,188.381 954.198,188.383 954.207,188.386 954.216,188.389 954.225,188.392 954.235,188.395 954.244,188.397 954.253,188.4 954.262,188.403 954.271,188.406 954.28,188.409 954.29,188.411 954.299,188.414 954.308,188.417 954.317,188.42 954.326,188.423 954.336,188.425 954.345,188.428 954.354,188.431 954.363,188.434 954.372,188.437 954.382,188.439 954.391,188.442 954.4,188.445 954.409,188.448 954.418,188.451 954.427,188.453 954.437,188.456 954.446,188.459 954.455,188.462 954.464,188.465 954.473,188.467 954.483,188.47 954.492,188.473 954.501,188.476 954.51,188.479 954.519,188.481 954.529,188.484 954.538,188.487 954.547,188.49 954.556,188.493 954.565,188.495 954.575,188.498 954.584,188.501 954.593,188.504 954.602,188.507 954.611,188.509 954.62,188.512 954.63,188.515 954.639,188.518 954.648,188.521 954.657,188.523 954.666,188.526 954.676,188.529 954.685,188.532 954.694,188.535 954.703,188.537 954.712,188.54 954.722,188.543 954.731,188.546 954.74,188.549 954.749,188.551 954.758,188.554 954.767,188.557 954.777,188.56 954.786,188.563 954.795,188.565 954.804,188.568 954.813,188.571 954.823,188.574 954.832,188.577 954.841,188.579 954.85,188.582 954.859,188.585 954.869,188.588 954.878,188.591 954.887,188.593 954.896,188.596 954.905,188.599 954.915,188.602 954.924,188.605 954.933,188.607 954.942,188.61 954.951,188.613 954.96,188.616 954.97,188.619 954.979,188.621 954.988,188.624 954.997,188.627 955.006,188.63 955.016,188.633 955.025,188.635 955.034,188.638 955.043,188.641 955.052,188.644 955.062,188.647 955.071,188.649 955.08,188.652 955.089,188.655 955.098,188.658 955.108,188.661 955.117,188.663 955.126,188.666 955.135,188.669 955.144,188.672 955.153,188.675 955.163,188.677 955.172,188.68 955.181,188.683 955.19,188.686 955.199,188.689 955.209,188.691 955.218,188.694 955.227,188.697 955.236,188.7 955.245,188.703 955.255,188.705 955.264,188.708 955.273,188.711 955.282,188.714 955.291,188.717 955.3,188.719 955.31,188.722 955.319,188.725 955.328,188.728 955.337,188.731 955.346,188.733 955.356,188.736 955.365,188.739 955.374,188.742 955.383,188.745 955.392,188.747 955.402,188.75 955.411,188.753 955.42,188.756 955.429,188.759 955.438,188.761 955.448,188.764 955.457,188.767 955.466,188.77 955.475,188.773 955.484,188.775 955.493,188.778 955.503,188.781 955.512,188.784 955.521,188.787 955.53,188.789 955.539,188.792 955.549,188.795 955.558,188.798 955.567,188.801 955.576,188.803 955.585,188.806 955.595,188.809 955.604,188.812 955.613,188.815 955.622,188.817 955.631,188.82 955.64,188.823 955.65,188.826 955.659,188.829 955.668,188.831 955.677,188.834 955.686,188.837 955.696,188.84 955.705,188.843 955.714,188.845 955.723,188.848 955.732,188.851 955.742,188.854 955.751,188.857 955.76,188.859 955.769,188.862 955.778,188.865 955.788,188.868 955.797,188.871 955.806,188.873 955.815,188.876 955.824,188.879 955.833,188.882 955.843,188.885 955.852,188.887 955.861,188.89 955.87,188.893 955.879,188.896 955.889,188.899 955.898,188.901 955.907,188.904 955.916,188.907 955.925,188.91 955.935,188.913 955.944,188.915 955.953,188.918 955.962,188.921 955.971,188.924 955.98,188.927 955.99,188.929 955.999,188.932 956.008,188.935 956.017,188.938 956.026,188.941 956.036,188.943 956.045,188.946 956.054,188.949 956.063,188.952 956.072,188.955 956.082,188.957 956.091,188.96 956.1,188.963 956.109,188.966 956.118,188.969 956.128,188.971 956.137,188.974 956.146,188.977 956.155,188.98 956.164,188.983 956.173,188.985 956.183,188.988 956.192,188.991 956.201,188.994 956.21,188.997 956.219,188.999 956.229,189.002 956.238,189.005 956.247,189.008 956.256,189.011 956.265,189.013 956.275,189.016 956.284,189.019 956.293,189.022 956.302,189.025 956.311,189.027 956.32,189.03 956.33,189.033 956.339,189.036 956.348,189.039 956.357,189.041 956.366,189.044 956.376,189.047 956.385,189.05 956.394,189.053 956.403,189.055 956.412,189.058 956.422,189.061 956.431,189.064 956.44,189.067 956.449,189.069 956.458,189.072 956.468,189.075 956.477,189.078 956.486,189.081 956.495,189.083 956.504,189.086 956.513,189.089 956.523,189.092 956.532,189.094 956.541,189.097 956.55,189.1 956.559,189.103 956.569,189.106 956.578,189.108 956.587,189.111 956.596,189.114 956.605,189.117 956.615,189.12 956.624,189.122 956.633,189.125 956.642,189.128 956.651,189.131 956.66,189.134 956.67,189.136 956.679,189.139 956.688,189.142 956.697,189.145 956.706,189.148 956.716,189.15 956.725,189.153 956.734,189.156 956.743,189.159 956.752,189.162 956.762,189.164 956.771,189.167 956.78,189.17 956.789,189.173 956.798,189.176 956.808,189.178 956.817,189.181 956.826,189.184 956.835,189.187 956.844,189.19 956.853,189.192 956.863,189.195 956.872,189.198 956.881,189.201 956.89,189.204 956.899,189.206 956.909,189.209 956.918,189.212 956.927,189.215 956.936,189.218 956.945,189.22 956.955,189.223 956.964,189.226 956.973,189.229 956.982,189.232 956.991,189.234 957,189.237 957.01,189.24 957.019,189.243 957.028,189.246 957.037,189.248 957.046,189.251 957.056,189.254 957.065,189.257 957.074,189.26 957.083,189.262 957.092,189.265 957.102,189.268 957.111,189.271 957.12,189.274 957.129,189.276 957.138,189.279 957.148,189.282 957.157,189.285 957.166,189.287 957.175,189.29 957.184,189.293 957.193,189.296 957.203,189.299 957.212,189.301 957.221,189.304 957.23,189.307 957.239,189.31 957.249,189.313 957.258,189.315 957.267,189.318 957.276,189.321 957.285,189.324 957.295,189.327 957.304,189.329 957.313,189.332 957.322,189.335 957.331,189.338 957.34,189.341 957.35,189.343 957.359,189.346 957.368,189.349 957.377,189.352 957.386,189.355 957.396,189.357 957.405,189.36 957.414,189.363 957.423,189.366 957.432,189.369 957.442,189.371 957.451,189.374 957.46,189.377 957.469,189.38 957.478,189.383 957.488,189.385 957.497,189.388 957.506,189.391 957.515,189.394 957.524,189.397 957.533,189.399 957.543,189.402 957.552,189.405 957.561,189.408 957.57,189.411 957.579,189.413 957.589,189.416 957.598,189.419 957.607,189.422 957.616,189.424 957.625,189.427 957.635,189.43 957.644,189.433 957.653,189.436 957.662,189.438 957.671,189.441 957.681,189.444 957.69,189.447 957.699,189.45 957.708,189.452 957.717,189.455 957.726,189.458 957.736,189.461 957.745,189.464 957.754,189.466 957.763,189.469 957.772,189.472 957.782,189.475 957.791,189.478 957.8,189.48 957.809,189.483 957.818,189.486 957.828,189.489 957.837,189.492 957.846,189.494 957.855,189.497 957.864,189.5 957.873,189.503 957.883,189.506 957.892,189.508 957.901,189.511 957.91,189.514 957.919,189.517 957.929,189.52 957.938,189.522 957.947,189.525 957.956,189.528 957.965,189.531 957.975,189.533 957.984,189.536 957.993,189.539 958.002,189.542 958.011,189.545 958.021,189.547 958.03,189.55 958.039,189.553 958.048,189.556 958.057,189.559 958.066,189.561 958.076,189.564 958.085,189.567 958.094,189.57 958.103,189.573 958.112,189.575 958.122,189.578 958.131,189.581 958.14,189.584 958.149,189.587 958.158,189.589 958.168,189.592 958.177,189.595 958.186,189.598 958.195,189.601 958.204,189.603 958.213,189.606 958.223,189.609 958.232,189.612 958.241,189.615 958.25,189.617 958.259,189.62 958.269,189.623 958.278,189.626 958.287,189.629 958.296,189.631 958.305,189.634 958.315,189.637 958.324,189.64 958.333,189.642 958.342,189.645 958.351,189.648 958.361,189.651 958.37,189.654 958.379,189.656 958.388,189.659 958.397,189.662 958.406,189.665 958.416,189.668 958.425,189.67 958.434,189.673 958.443,189.676 958.452,189.679 958.462,189.682 958.471,189.684 958.48,189.687 958.489,189.69 958.498,189.693 958.508,189.696 958.517,189.698 958.526,189.701 958.535,189.704 958.544,189.707 958.553,189.71 958.563,189.712 958.572,189.715 958.581,189.718 958.59,189.721 958.599,189.723 958.609,189.726 958.618,189.729 958.627,189.732 958.636,189.735 958.645,189.737 958.655,189.74 958.664,189.743 958.673,189.746 958.682,189.749 958.691,189.751 958.701,189.754 958.71,189.757 958.719,189.76 958.728,189.763 958.737,189.765 958.746,189.768 958.756,189.771 958.765,189.774 958.774,189.777 958.783,189.779 958.792,189.782 958.802,189.785 958.811,189.788 958.82,189.791 958.829,189.793 958.838,189.796 958.848,189.799 958.857,189.802 958.866,189.804 958.875,189.807 958.884,189.81 958.893,189.813 958.903,189.816 958.912,189.818 958.921,189.821 958.93,189.824 958.939,189.827 958.949,189.83 958.958,189.832 958.967,189.835 958.976,189.838 958.985,189.841 958.995,189.844 959.004,189.846 959.013,189.849 959.022,189.852 959.031,189.855 959.041,189.858 959.05,189.86 959.059,189.863 959.068,189.866 959.077,189.869 959.086,189.872 959.096,189.874 959.105,189.877 959.114,189.88 959.123,189.883 959.132,189.885 959.142,189.888 959.151,189.891 959.16,189.894 959.169,189.897 959.178,189.899 959.188,189.902 959.197,189.905 959.206,189.908 959.215,189.911 959.224,189.913 959.233,189.916 959.243,189.919 959.252,189.922 959.261,189.925 959.27,189.927 959.279,189.93 959.289,189.933 959.298,189.936 959.307,189.939 959.316,189.941 959.325,189.944 959.335,189.947 959.344,189.95 959.353,189.953 959.362,189.955 959.371,189.958 959.381,189.961 959.39,189.964 959.399,189.966 959.408,189.969 959.417,189.972 959.426,189.975 959.436,189.978 959.445,189.98 959.454,189.983 959.463,189.986 959.472,189.989 959.482,189.992 959.491,189.994 959.5,189.997 959.509,190 959.518,190.003 959.528,190.006 959.537,190.008 959.546,190.011 959.555,190.014 959.564,190.017 959.573,190.02 959.583,190.022 959.592,190.025 959.601,190.028 959.61,190.031 959.619,190.033 959.629,190.036 959.638,190.039 959.647,190.042 959.656,190.045 959.665,190.047 959.675,190.05 959.684,190.053 959.693,190.056 959.702,190.059 959.711,190.061 959.721,190.064 959.73,190.067 959.739,190.07 959.748,190.073 959.757,190.075 959.766,190.078 959.776,190.081 959.785,190.084 959.794,190.087 959.803,190.089 959.812,190.092 959.822,190.095 959.831,190.098 959.84,190.1 959.849,190.103 959.858,190.106 959.868,190.109 959.877,190.112 959.886,190.114 959.895,190.117 959.904,190.12 959.913,190.123 959.923,190.126 959.932,190.128 959.941,190.131 959.95,190.134 959.959,190.137 959.969,190.14 959.978,190.142 959.987,190.145 959.996,190.148 960.005,190.151 960.015,190.153 960.024,190.156 960.033,190.159 960.042,190.162 960.051,190.165 960.061,190.167 960.07,190.17 960.079,190.173 960.088,190.176 960.097,190.179 960.106,190.181 960.116,190.184 960.125,190.187 960.134,190.19 960.143,190.193 960.152,190.195 960.162,190.198 960.171,190.201 960.18,190.204 960.189,190.207 960.198,190.209 960.208,190.212 960.217,190.215 960.226,190.218 960.235,190.22 960.244,190.223 960.254,190.226 960.263,190.229 960.272,190.232 960.281,190.234 960.29,190.237 960.299,190.24 960.309,190.243 960.318,190.246 960.327,190.248 960.336,190.251 960.345,190.254 960.355,190.257 960.364,190.26 960.373,190.262 960.382,190.265 960.391,190.268 960.401,190.271 960.41,190.273 960.419,190.276 960.428,190.279 960.437,190.282 960.446,190.285 960.456,190.287 960.465,190.29 960.474,190.293 960.483,190.296 960.492,190.299 960.502,190.301 960.511,190.304 960.52,190.307 960.529,190.31 960.538,190.313 960.548,190.315 960.557,190.318 960.566,190.321 960.575,190.324 960.584,190.326 960.594,190.329 960.603,190.332 960.612,190.335 960.621,190.338 960.63,190.34 960.639,190.343 960.649,190.346 960.658,190.349 960.667,190.352 960.676,190.354 960.685,190.357 960.695,190.36 960.704,190.363 960.713,190.366 960.722,190.368 960.731,190.371 960.741,190.374 960.75,190.377 960.759,190.379 960.768,190.382 960.777,190.385 960.786,190.388 960.796,190.391 960.805,190.393 960.814,190.396 960.823,190.399 960.832,190.402 960.842,190.405 960.851,190.407 960.86,190.41 960.869,190.413 960.878,190.416 960.888,190.419 960.897,190.421 960.906,190.424 960.915,190.427 960.924,190.43 960.934,190.432 960.943,190.435 960.952,190.438 960.961,190.441 960.97,190.444 960.979,190.446 960.989,190.449 960.998,190.452 961.007,190.455 961.016,190.458 961.025,190.46 961.035,190.463 961.044,190.466 961.053,190.469 961.062,190.472 961.071,190.474 961.081,190.477 961.09,190.48 961.099,190.483 961.108,190.485 961.117,190.488 961.126,190.491 961.136,190.494 961.145,190.497 961.154,190.499 961.163,190.502 961.172,190.505 961.182,190.508 961.191,190.511 961.2,190.513 961.209,190.516 961.218,190.519 961.228,190.522 961.237,190.525 961.246,190.527 961.255,190.53 961.264,190.533 961.274,190.536 961.283,190.538 961.292,190.541 961.301,190.544 961.31,190.547 961.319,190.55 961.329,190.552 961.338,190.555 961.347,190.558 961.356,190.561 961.365,190.564 961.375,190.566 961.384,190.569 961.393,190.572 961.402,190.575 961.411,190.577 961.421,190.58 961.43,190.583 961.439,190.586 961.448,190.589 961.457,190.591 961.466,190.594 961.476,190.597 961.485,190.6 961.494,190.603 961.503,190.605 961.512,190.608 961.522,190.611 961.531,190.614 961.54,190.617 961.549,190.619 961.558,190.622 961.568,190.625 961.577,190.628 961.586,190.63 961.595,190.633 961.604,190.636 961.614,190.639 961.623,190.642 961.632,190.644 961.641,190.647 961.65,190.65 961.659,190.653 961.669,190.656 961.678,190.658 961.687,190.661 961.696,190.664 961.705,190.667 961.715,190.669 961.724,190.672 961.733,190.675 961.742,190.678 961.751,190.681 961.761,190.683 961.77,190.686 961.779,190.689 961.788,190.692 961.797,190.695 961.806,190.697 961.816,190.7 961.825,190.703 961.834,190.706 961.843,190.709 961.852,190.711 961.862,190.714 961.871,190.717 961.88,190.72 961.889,190.722 961.898,190.725 961.908,190.728 961.917,190.731 961.926,190.734 961.935,190.736 961.944,190.739 961.954,190.742 961.963,190.745 961.972,190.748 961.981,190.75 961.99,190.753 961.999,190.756 962.009,190.759 962.018,190.761 962.027,190.764 962.036,190.767 962.045,190.77 962.055,190.773 962.064,190.775 962.073,190.778 962.082,190.781 962.091,190.784 962.101,190.787 962.11,190.789 962.119,190.792 962.128,190.795 962.137,190.798 962.146,190.8 962.156,190.803 962.165,190.806 962.174,190.809 962.183,190.812 962.192,190.814 962.202,190.817 962.211,190.82 962.22,190.823 962.229,190.826 962.238,190.828 962.248,190.831 962.257,190.834 962.266,190.837 962.275,190.839 962.284,190.842 962.294,190.845 962.303,190.848 962.312,190.851 962.321,190.853 962.33,190.856 962.339,190.859 962.349,190.862 962.358,190.865 962.367,190.867 962.376,190.87 962.385,190.873 962.395,190.876 962.404,190.878 962.413,190.881 962.422,190.884 962.431,190.887 962.441,190.89 962.45,190.892 962.459,190.895 962.468,190.898 962.477,190.901 962.487,190.904 962.496,190.906 962.505,190.909 962.514,190.912 962.523,190.915 962.532,190.917 962.542,190.92 962.551,190.923 962.56,190.926 962.569,190.929 962.578,190.931 962.588,190.934 962.597,190.937 962.606,190.94 962.615,190.943 962.624,190.945 962.634,190.948 962.643,190.951 962.652,190.954 962.661,190.956 962.67,190.959 962.679,190.962 962.689,190.965 962.698,190.968 962.707,190.97 962.716,190.973 962.725,190.976 962.735,190.979 962.744,190.982 962.753,190.984 962.762,190.987 962.771,190.99 962.781,190.993 962.79,190.995 962.799,190.998 962.808,191.001 962.817,191.004 962.827,191.007 962.836,191.009 962.845,191.012 962.854,191.015 962.863,191.018 962.872,191.021 962.882,191.023 962.891,191.026 962.9,191.029 962.909,191.032 962.918,191.034 962.928,191.037 962.937,191.04 962.946,191.043 962.955,191.046 962.964,191.048 962.974,191.051 962.983,191.054 962.992,191.057 963.001,191.06 963.01,191.062 963.019,191.065 963.029,191.068 963.038,191.071 963.047,191.073 963.056,191.076 963.065,191.079 963.075,191.082 963.084,191.085 963.093,191.087 963.102,191.09 963.111,191.093 963.121,191.096 963.13,191.099 963.139,191.101 963.148,191.104 963.157,191.107 963.167,191.11 963.176,191.112 963.185,191.115 963.194,191.118 963.203,191.121 963.212,191.124 963.222,191.126 963.231,191.129 963.24,191.132 963.249,191.135 963.258,191.138 963.268,191.14 963.277,191.143 963.286,191.146 963.295,191.149 963.304,191.151 963.314,191.154 963.323,191.157 963.332,191.16 963.341,191.163 963.35,191.165 963.359,191.168 963.369,191.171 963.378,191.174 963.387,191.177 963.396,191.179 963.405,191.182 963.415,191.185 963.424,191.188 963.433,191.19 963.442,191.193 963.451,191.196 963.461,191.199 963.47,191.202 963.479,191.204 963.488,191.207 963.497,191.21 963.507,191.213 963.516,191.215 963.525,191.218 963.534,191.221 963.543,191.224 963.552,191.227 963.562,191.229 963.571,191.232 963.58,191.235 963.589,191.238 963.598,191.241 963.608,191.243 963.617,191.246 963.626,191.249 963.635,191.252 963.644,191.254 963.654,191.257 963.663,191.26 963.672,191.263 963.681,191.266 963.69,191.268 963.699,191.271 963.709,191.274 963.718,191.277 963.727,191.28 963.736,191.282 963.745,191.285 963.755,191.288 963.764,191.291 963.773,191.293 963.782,191.296 963.791,191.299 963.801,191.302 963.81,191.305 963.819,191.307 963.828,191.31 963.837,191.313 963.847,191.316 963.856,191.318 963.865,191.321 963.874,191.324 963.883,191.327 963.892,191.33 963.902,191.332 963.911,191.335 963.92,191.338 963.929,191.341 963.938,191.344 963.948,191.346 963.957,191.349 963.966,191.352 963.975,191.355 963.984,191.357 963.994,191.36 964.003,191.363 964.012,191.366 964.021,191.369 964.03,191.371 964.039,191.374 964.049,191.377 964.058,191.38 964.067,191.382 964.076,191.385 964.085,191.388 964.095,191.391 964.104,191.394 964.113,191.396 964.122,191.399 964.131,191.402 964.141,191.405 964.15,191.408 964.159,191.41 964.168,191.413 964.177,191.416 964.187,191.419 964.196,191.421 964.205,191.424 964.214,191.427 964.223,191.43 964.232,191.433 964.242,191.435 964.251,191.438 964.26,191.441 964.269,191.444 964.278,191.446 964.288,191.449 964.297,191.452 964.306,191.455 964.315,191.458 964.324,191.46 964.334,191.463 964.343,191.466 964.352,191.469 964.361,191.472 964.37,191.474 964.379,191.477 964.389,191.48 964.398,191.483 964.407,191.485 964.416,191.488 964.425,191.491 964.435,191.494 964.444,191.497 964.453,191.499 964.462,191.502 964.471,191.505 964.481,191.508 964.49,191.51 964.499,191.513 964.508,191.516 964.517,191.519 964.527,191.522 964.536,191.524 964.545,191.527 964.554,191.53 964.563,191.533 964.572,191.536 964.582,191.538 964.591,191.541 964.6,191.544 964.609,191.547 964.618,191.549 964.628,191.552 964.637,191.555 964.646,191.558 964.655,191.561 964.664,191.563 964.674,191.566 964.683,191.569 964.692,191.572 964.701,191.574 964.71,191.577 964.719,191.58 964.729,191.583 964.738,191.586 964.747,191.588 964.756,191.591 964.765,191.594 964.775,191.597 964.784,191.6 964.793,191.602 964.802,191.605 964.811,191.608 964.821,191.611 964.83,191.613 964.839,191.616 964.848,191.619 964.857,191.622 964.867,191.625 964.876,191.627 964.885,191.63 964.894,191.633 964.903,191.636 964.912,191.638 964.922,191.641 964.931,191.644 964.94,191.647 964.949,191.65 964.958,191.652 964.968,191.655 964.977,191.658 964.986,191.661 964.995,191.663 965.004,191.666 965.014,191.669 965.023,191.672 965.032,191.675 965.041,191.677 965.05,191.68 965.06,191.683 965.069,191.686 965.078,191.689 965.087,191.691 965.096,191.694 965.105,191.697 965.115,191.7 965.124,191.702 965.133,191.705 965.142,191.708 965.151,191.711 965.161,191.714 965.17,191.716 965.179,191.719 965.188,191.722 965.197,191.725 965.207,191.727 965.216,191.73 965.225,191.733 965.234,191.736 965.243,191.739 965.252,191.741 965.262,191.744 965.271,191.747 965.28,191.75 965.289,191.752 965.298,191.755 965.308,191.758 965.317,191.761 965.326,191.764 965.335,191.766 965.344,191.769 965.354,191.772 965.363,191.775 965.372,191.777 965.381,191.78 965.39,191.783 965.4,191.786 965.409,191.789 965.418,191.791 965.427,191.794 965.436,191.797 965.445,191.8 965.455,191.803 965.464,191.805 965.473,191.808 965.482,191.811 965.491,191.814 965.501,191.816 965.51,191.819 965.519,191.822 965.528,191.825 965.537,191.828 965.547,191.83 965.556,191.833 965.565,191.836 965.574,191.839 965.583,191.841 965.592,191.844 965.602,191.847 965.611,191.85 965.62,191.853 965.629,191.855 965.638,191.858 965.648,191.861 965.657,191.864 965.666,191.866 965.675,191.869 965.684,191.872 965.694,191.875 965.703,191.878 965.712,191.88 965.721,191.883 965.73,191.886 965.74,191.889 965.749,191.891 965.758,191.894 965.767,191.897 965.776,191.9 965.785,191.903 965.795,191.905 965.804,191.908 965.813,191.911 965.822,191.914 965.831,191.916 965.841,191.919 965.85,191.922 965.859,191.925 965.868,191.928 965.877,191.93 965.887,191.933 965.896,191.936 965.905,191.939 965.914,191.942 965.923,191.944 965.932,191.947 965.942,191.95 965.951,191.953 965.96,191.955 965.969,191.958 965.978,191.961 965.988,191.964 965.997,191.967 966.006,191.969 966.015,191.972 966.024,191.975 966.034,191.978 966.043,191.98 966.052,191.983 966.061,191.986 966.07,191.989 966.08,191.992 966.089,191.994 966.098,191.997 966.107,192 966.116,192.003 966.125,192.005 966.135,192.008 966.144,192.011 966.153,192.014 966.162,192.017 966.171,192.019 966.181,192.022 966.19,192.025 966.199,192.028 966.208,192.03 966.217,192.033 966.227,192.036 966.236,192.039 966.245,192.042 966.254,192.044 966.263,192.047 966.272,192.05 966.282,192.053 966.291,192.055 966.3,192.058 966.309,192.061 966.318,192.064 966.328,192.067 966.337,192.069 966.346,192.072 966.355,192.075 966.364,192.078 966.374,192.08 966.383,192.083 966.392,192.086 966.401,192.089 966.41,192.092 966.42,192.094 966.429,192.097 966.438,192.1 966.447,192.103 966.456,192.105 966.465,192.108 966.475,192.111 966.484,192.114 966.493,192.117 966.502,192.119 966.511,192.122 966.521,192.125 966.53,192.128 966.539,192.13 966.548,192.133 966.557,192.136 966.567,192.139 966.576,192.142 966.585,192.144 966.594,192.147 966.603,192.15 966.612,192.153 966.622,192.155 966.631,192.158 966.64,192.161 966.649,192.164 966.658,192.167 966.668,192.169 966.677,192.172 966.686,192.175 966.695,192.178 966.704,192.18 966.714,192.183 966.723,192.186 966.732,192.189 966.741,192.192 966.75,192.194 966.76,192.197 966.769,192.2 966.778,192.203 966.787,192.205 966.796,192.208 966.805,192.211 966.815,192.214 966.824,192.217 966.833,192.219 966.842,192.222 966.851,192.225 966.861,192.228 966.87,192.23 966.879,192.233 966.888,192.236 966.897,192.239 966.907,192.242 966.916,192.244 966.925,192.247 966.934,192.25 966.943,192.253 966.952,192.255 966.962,192.258 966.971,192.261 966.98,192.264 966.989,192.267 966.998,192.269 967.008,192.272 967.017,192.275 967.026,192.278 967.035,192.28 967.044,192.283 967.054,192.286 967.063,192.289 967.072,192.292 967.081,192.294 967.09,192.297 967.1,192.3 967.109,192.303 967.118,192.305 967.127,192.308 967.136,192.311 967.145,192.314 967.155,192.317 967.164,192.319 967.173,192.322 967.182,192.325 967.191,192.328 967.201,192.33 967.21,192.333 967.219,192.336 967.228,192.339 967.237,192.342 967.247,192.344 967.256,192.347 967.265,192.35 967.274,192.353 967.283,192.355 967.292,192.358 967.302,192.361 967.311,192.364 967.32,192.367 967.329,192.369 967.338,192.372 967.348,192.375 967.357,192.378 967.366,192.38 967.375,192.383 967.384,192.386 967.394,192.389 967.403,192.392 967.412,192.394 967.421,192.397 967.43,192.4 967.44,192.403 967.449,192.405 967.458,192.408 967.467,192.411 967.476,192.414 967.485,192.417 967.495,192.419 967.504,192.422 967.513,192.425 967.522,192.428 967.531,192.43 967.541,192.433 967.55,192.436 967.559,192.439 967.568,192.442 967.577,192.444 967.587,192.447 967.596,192.45 967.605,192.453 967.614,192.455 967.623,192.458 967.633,192.461 967.642,192.464 967.651,192.466 967.66,192.469 967.669,192.472 967.678,192.475 967.688,192.478 967.697,192.48 967.706,192.483 967.715,192.486 967.724,192.489 967.734,192.491 967.743,192.494 967.752,192.497 967.761,192.5 967.77,192.503 967.78,192.505 967.789,192.508 967.798,192.511 967.807,192.514 967.816,192.516 967.825,192.519 967.835,192.522 967.844,192.525 967.853,192.528 967.862,192.53 967.871,192.533 967.881,192.536 967.89,192.539 967.899,192.541 967.908,192.544 967.917,192.547 967.927,192.55 967.936,192.553 967.945,192.555 967.954,192.558 967.963,192.561 967.973,192.564 967.982,192.566 967.991,192.569 968,192.572 968.009,192.575 968.018,192.578 968.028,192.58 968.037,192.583 968.046,192.586 968.055,192.589 968.064,192.591 968.074,192.594 968.083,192.597 968.092,192.6 968.101,192.602 968.11,192.605 968.12,192.608 968.129,192.611 968.138,192.614 968.147,192.616 968.156,192.619 968.165,192.622 968.175,192.625 968.184,192.627 968.193,192.63 968.202,192.633 968.211,192.636 968.221,192.639 968.23,192.641 968.239,192.644 968.248,192.647 968.257,192.65 968.267,192.652 968.276,192.655 968.285,192.658 968.294,192.661 968.303,192.664 968.313,192.666 968.322,192.669 968.331,192.672 968.34,192.675 968.349,192.677 968.358,192.68 968.368,192.683 968.377,192.686 968.386,192.689 968.395,192.691 968.404,192.694 968.414,192.697 968.423,192.7 968.432,192.702 968.441,192.705 968.45,192.708 968.46,192.711 968.469,192.713 968.478,192.716 968.487,192.719 968.496,192.722 968.505,192.725 968.515,192.727 968.524,192.73 968.533,192.733 968.542,192.736 968.551,192.738 968.561,192.741 968.57,192.744 968.579,192.747 968.588,192.75 968.597,192.752 968.607,192.755 968.616,192.758 968.625,192.761 968.634,192.763 968.643,192.766 968.653,192.769 968.662,192.772 968.671,192.775 968.68,192.777 968.689,192.78 968.698,192.783 968.708,192.786 968.717,192.788 968.726,192.791 968.735,192.794 968.744,192.797 968.754,192.799 968.763,192.802 968.772,192.805 968.781,192.808 968.79,192.811 968.8,192.813 968.809,192.816 968.818,192.819 968.827,192.822 968.836,192.824 968.845,192.827 968.855,192.83 968.864,192.833 968.873,192.836 968.882,192.838 968.891,192.841 968.901,192.844 968.91,192.847 968.919,192.849 968.928,192.852 968.937,192.855 968.947,192.858 968.956,192.86 968.965,192.863 968.974,192.866 968.983,192.869 968.993,192.872 969.002,192.874 969.011,192.877 969.02,192.88 969.029,192.883 969.038,192.885 969.048,192.888 969.057,192.891 969.066,192.894 969.075,192.897 969.084,192.899 969.094,192.902 969.103,192.905 969.112,192.908 969.121,192.91 969.13,192.913 969.14,192.916 969.149,192.919 969.158,192.922 969.167,192.924 969.176,192.927 969.185,192.93 969.195,192.933 969.204,192.935 969.213,192.938 969.222,192.941 969.231,192.944 969.241,192.946 969.25,192.949 969.259,192.952 969.268,192.955 969.277,192.958 969.287,192.96 969.296,192.963 969.305,192.966 969.314,192.969 969.323,192.971 969.333,192.974 969.342,192.977 969.351,192.98 969.36,192.983 969.369,192.985 969.378,192.988 969.388,192.991 969.397,192.994 969.406,192.996 969.415,192.999 969.424,193.002 969.434,193.005 969.443,193.007 969.452,193.01 969.461,193.013 969.47,193.016 969.48,193.019 969.489,193.021 969.498,193.024 969.507,193.027 969.516,193.03 969.525,193.032 969.535,193.035 969.544,193.038 969.553,193.041 969.562,193.044 969.571,193.046 969.581,193.049 969.59,193.052 969.599,193.055 969.608,193.057 969.617,193.06 969.627,193.063 969.636,193.066 969.645,193.068 969.654,193.071 969.663,193.074 969.673,193.077 969.682,193.08 969.691,193.082 969.7,193.085 969.709,193.088 969.718,193.091 969.728,193.093 969.737,193.096 969.746,193.099 969.755,193.102 969.764,193.104 969.774,193.107 969.783,193.11 969.792,193.113 969.801,193.116 969.81,193.118 969.82,193.121 969.829,193.124 969.838,193.127 969.847,193.129 969.856,193.132 969.866,193.135 969.875,193.138 969.884,193.141 969.893,193.143 969.902,193.146 969.911,193.149 969.921,193.152 969.93,193.154 969.939,193.157 969.948,193.16 969.957,193.163 969.967,193.165 969.976,193.168 969.985,193.171 969.994,193.174 970.003,193.177 970.013,193.179 970.022,193.182 970.031,193.185 970.04,193.188 970.049,193.19 970.058,193.193 970.068,193.196 970.077,193.199 970.086,193.201 970.095,193.204 970.104,193.207 970.114,193.21 970.123,193.213 970.132,193.215 970.141,193.218 970.15,193.221 970.16,193.224 970.169,193.226 970.178,193.229 970.187,193.232 970.196,193.235 970.206,193.238 970.215,193.24 970.224,193.243 970.233,193.246 970.242,193.249 970.251,193.251 970.261,193.254 970.27,193.257 970.279,193.26 970.288,193.262 970.297,193.265 970.307,193.268 970.316,193.271 970.325,193.274 970.334,193.276 970.343,193.279 970.353,193.282 970.362,193.285 970.371,193.287 970.38,193.29 970.389,193.293 970.398,193.296 970.408,193.298 970.417,193.301 970.426,193.304 970.435,193.307 970.444,193.31 970.454,193.312 970.463,193.315 970.472,193.318 970.481,193.321 970.49,193.323 970.5,193.326 970.509,193.329 970.518,193.332 970.527,193.334 970.536,193.337 970.546,193.34 970.555,193.343 970.564,193.346 970.573,193.348 970.582,193.351 970.591,193.354 970.601,193.357 970.61,193.359 970.619,193.362 970.628,193.365 970.637,193.368 970.647,193.371 970.656,193.373 970.665,193.376 970.674,193.379 970.683,193.382 970.693,193.384 970.702,193.387 970.711,193.39 970.72,193.393 970.729,193.395 970.738,193.398 970.748,193.401 970.757,193.404 970.766,193.407 970.775,193.409 970.784,193.412 970.794,193.415 970.803,193.418 970.812,193.42 970.821,193.423 970.83,193.426 970.84,193.429 970.849,193.431 970.858,193.434 970.867,193.437 970.876,193.44 970.886,193.443 970.895,193.445 970.904,193.448 970.913,193.451 970.922,193.454 970.931,193.456 970.941,193.459 970.95,193.462 970.959,193.465 970.968,193.467 970.977,193.47 970.987,193.473 970.996,193.476 971.005,193.479 971.014,193.481 971.023,193.484 971.033,193.487 971.042,193.49 971.051,193.492 971.06,193.495 971.069,193.498 971.078,193.501 971.088,193.503 971.097,193.506 971.106,193.509 971.115,193.512 971.124,193.515 971.134,193.517 971.143,193.52 971.152,193.523 971.161,193.526 971.17,193.528 971.18,193.531 971.189,193.534 971.198,193.537 971.207,193.539 971.216,193.542 971.226,193.545 971.235,193.548 971.244,193.551 971.253,193.553 971.262,193.556 971.271,193.559 971.281,193.562 971.29,193.564 971.299,193.567 971.308,193.57 971.317,193.573 971.327,193.575 971.336,193.578 971.345,193.581 971.354,193.584 971.363,193.587 971.373,193.589 971.382,193.592 971.391,193.595 971.4,193.598 971.409,193.6 971.418,193.603 971.428,193.606 971.437,193.609 971.446,193.611 971.455,193.614 971.464,193.617 971.474,193.62 971.483,193.623 971.492,193.625 971.501,193.628 971.51,193.631 971.52,193.634 971.529,193.636 971.538,193.639 971.547,193.642 971.556,193.645 971.566,193.647 971.575,193.65 971.584,193.653 971.593,193.656 971.602,193.659 971.611,193.661 971.621,193.664 971.63,193.667 971.639,193.67 971.648,193.672 971.657,193.675 971.667,193.678 971.676,193.681 971.685,193.683 971.694,193.686 971.703,193.689 971.713,193.692 971.722,193.694 971.731,193.697 971.74,193.7 971.749,193.703 971.758,193.706 971.768,193.708 971.777,193.711 971.786,193.714 971.795,193.717 971.804,193.719 971.814,193.722 971.823,193.725 971.832,193.728 971.841,193.73 971.85,193.733 971.86,193.736 971.869,193.739 971.878,193.742 971.887,193.744 971.896,193.747 971.906,193.75 971.915,193.753 971.924,193.755 971.933,193.758 971.942,193.761 971.951,193.764 971.961,193.766 971.97,193.769 971.979,193.772 971.988,193.775 971.997,193.778 972.007,193.78 972.016,193.783 972.025,193.786 972.034,193.789 972.043,193.791 972.053,193.794 972.062,193.797 972.071,193.8 972.08,193.802 972.089,193.805 972.098,193.808 972.108,193.811 972.117,193.814 972.126,193.816 972.135,193.819 972.144,193.822 972.154,193.825 972.163,193.827 972.172,193.83 972.181,193.833 972.19,193.836 972.2,193.838 972.209,193.841 972.218,193.844 972.227,193.847 972.236,193.849 972.246,193.852 972.255,193.855 972.264,193.858 972.273,193.861 972.282,193.863 972.291,193.866 972.301,193.869 972.31,193.872 972.319,193.874 972.328,193.877 972.337,193.88 972.347,193.883 972.356,193.885 972.365,193.888 972.374,193.891 972.383,193.894 972.393,193.897 972.402,193.899 972.411,193.902 972.42,193.905 972.429,193.908 972.439,193.91 972.448,193.913 972.457,193.916 972.466,193.919 972.475,193.921 972.484,193.924 972.494,193.927 972.503,193.93 972.512,193.932 972.521,193.935 972.53,193.938 972.54,193.941 972.549,193.944 972.558,193.946 972.567,193.949 972.576,193.952 972.586,193.955 972.595,193.957 972.604,193.96 972.613,193.963 972.622,193.966 972.631,193.968 972.641,193.971 972.65,193.974 972.659,193.977 972.668,193.98 972.677,193.982 972.687,193.985 972.696,193.988 972.705,193.991 972.714,193.993 972.723,193.996 972.733,193.999 972.742,194.002 972.751,194.004 972.76,194.007 972.769,194.01 972.779,194.013 972.788,194.015 972.797,194.018 972.806,194.021 972.815,194.024 972.824,194.027 972.834,194.029 972.843,194.032 972.852,194.035 972.861,194.038 972.87,194.04 972.88,194.043 972.889,194.046 972.898,194.049 972.907,194.051 972.916,194.054 972.926,194.057 972.935,194.06 972.944,194.062 972.953,194.065 972.962,194.068 972.971,194.071 972.981,194.074 972.99,194.076 972.999,194.079 973.008,194.082 973.017,194.085 973.027,194.087 973.036,194.09 973.045,194.093 973.054,194.096 973.063,194.098 973.073,194.101 973.082,194.104 973.091,194.107 973.1,194.11 973.109,194.112 973.119,194.115 973.128,194.118 973.137,194.121 973.146,194.123 973.155,194.126 973.164,194.129 973.174,194.132 973.183,194.134 973.192,194.137 973.201,194.14 973.21,194.143 973.22,194.145 973.229,194.148 973.238,194.151 973.247,194.154 973.256,194.157 973.266,194.159 973.275,194.162 973.284,194.165 973.293,194.168 973.302,194.17 973.311,194.173 973.321,194.176 973.33,194.179 973.339,194.181 973.348,194.184 973.357,194.187 973.367,194.19 973.376,194.192 973.385,194.195 973.394,194.198 973.403,194.201 973.413,194.204 973.422,194.206 973.431,194.209 973.44,194.212 973.449,194.215 973.459,194.217 973.468,194.22 973.477,194.223 973.486,194.226 973.495,194.228 973.504,194.231 973.514,194.234 973.523,194.237 973.532,194.239 973.541,194.242 973.55,194.245 973.56,194.248 973.569,194.251 973.578,194.253 973.587,194.256 973.596,194.259 973.606,194.262 973.615,194.264 973.624,194.267 973.633,194.27 973.642,194.273 973.651,194.275 973.661,194.278 973.67,194.281 973.679,194.284 973.688,194.286 973.697,194.289 973.707,194.292 973.716,194.295 973.725,194.298 973.734,194.3 973.743,194.303 973.753,194.306 973.762,194.309 973.771,194.311 973.78,194.314 973.789,194.317 973.799,194.32 973.808,194.322 973.817,194.325 973.826,194.328 973.835,194.331 973.844,194.333 973.854,194.336 973.863,194.339 973.872,194.342 973.881,194.344 973.89,194.347 973.9,194.35 973.909,194.353 973.918,194.356 973.927,194.358 973.936,194.361 973.946,194.364 973.955,194.367 973.964,194.369 973.973,194.372 973.982,194.375 973.991,194.378 974.001,194.38 974.01,194.383 974.019,194.386 974.028,194.389 974.037,194.391 974.047,194.394 974.056,194.397 974.065,194.4 974.074,194.403 974.083,194.405 974.093,194.408 974.102,194.411 974.111,194.414 974.12,194.416 974.129,194.419 974.139,194.422 974.148,194.425 974.157,194.427 974.166,194.43 974.175,194.433 974.184,194.436 974.194,194.438 974.203,194.441 974.212,194.444 974.221,194.447 974.23,194.45 974.24,194.452 974.249,194.455 974.258,194.458 974.267,194.461 974.276,194.463 974.286,194.466 974.295,194.469 974.304,194.472 974.313,194.474 974.322,194.477 974.331,194.48 974.341,194.483 974.35,194.485 974.359,194.488 974.368,194.491 974.377,194.494 974.387,194.496 974.396,194.499 974.405,194.502 974.414,194.505 974.423,194.508 974.433,194.51 974.442,194.513 974.451,194.516 974.46,194.519 974.469,194.521 974.479,194.524 974.488,194.527 974.497,194.53 974.506,194.532 974.515,194.535 974.524,194.538 974.534,194.541 974.543,194.543 974.552,194.546 974.561,194.549 974.57,194.552 974.58,194.554 974.589,194.557 974.598,194.56 974.607,194.563 974.616,194.566 974.626,194.568 974.635,194.571 974.644,194.574 974.653,194.577 974.662,194.579 974.671,194.582 974.681,194.585 974.69,194.588 974.699,194.59 974.708,194.593 974.717,194.596 974.727,194.599 974.736,194.601 974.745,194.604 974.754,194.607 974.763,194.61 974.773,194.613 974.782,194.615 974.791,194.618 974.8,194.621 974.809,194.624 974.819,194.626 974.828,194.629 974.837,194.632 974.846,194.635 974.855,194.637 974.864,194.64 974.874,194.643 974.883,194.646 974.892,194.648 974.901,194.651 974.91,194.654 974.92,194.657 974.929,194.659 974.938,194.662 974.947,194.665 974.956,194.668 974.966,194.671 974.975,194.673 974.984,194.676 974.993,194.679 975.002,194.682 975.012,194.684 975.021,194.687 975.03,194.69 975.039,194.693 975.048,194.695 975.057,194.698 975.067,194.701 975.076,194.704 975.085,194.706 975.094,194.709 975.103,194.712 975.113,194.715 975.122,194.717 975.131,194.72 975.14,194.723 975.149,194.726 975.159,194.728 975.168,194.731 975.177,194.734 975.186,194.737 975.195,194.74 975.204,194.742 975.214,194.745 975.223,194.748 975.232,194.751 975.241,194.753 975.25,194.756 975.26,194.759 975.269,194.762 975.278,194.764 975.287,194.767 975.296,194.77 975.306,194.773 975.315,194.775 975.324,194.778 975.333,194.781 975.342,194.784 975.352,194.786 975.361,194.789 975.37,194.792 975.379,194.795 975.388,194.798 975.397,194.8 975.407,194.803 975.416,194.806 975.425,194.809 975.434,194.811 975.443,194.814 975.453,194.817 975.462,194.82 975.471,194.822 975.48,194.825 975.489,194.828 975.499,194.831 975.508,194.833 975.517,194.836 975.526,194.839 975.535,194.842 975.544,194.844 975.554,194.847 975.563,194.85 975.572,194.853 975.581,194.855 975.59,194.858 975.6,194.861 975.609,194.864 975.618,194.867 975.627,194.869 975.636,194.872 975.646,194.875 975.655,194.878 975.664,194.88 975.673,194.883 975.682,194.886 975.692,194.889 975.701,194.891 975.71,194.894 975.719,194.897 975.728,194.9 975.737,194.902 975.747,194.905 975.756,194.908 975.765,194.911 975.774,194.913 975.783,194.916 975.793,194.919 975.802,194.922 975.811,194.925 975.82,194.927 975.829,194.93 975.839,194.933 975.848,194.936 975.857,194.938 975.866,194.941 975.875,194.944 975.884,194.947 975.894,194.949 975.903,194.952 975.912,194.955 975.921,194.958 975.93,194.96 975.94,194.963 975.949,194.966 975.958,194.969 975.967,194.971 975.976,194.974 975.986,194.977 975.995,194.98 976.004,194.982 976.013,194.985 976.022,194.988 976.032,194.991 976.041,194.994 976.05,194.996 976.059,194.999 976.068,195.002 976.077,195.005 976.087,195.007 976.096,195.01 976.105,195.013 976.114,195.016 976.123,195.018 976.133,195.021 976.142,195.024 976.151,195.027 976.16,195.029 976.169,195.032 976.179,195.035 976.188,195.038 976.197,195.04 976.206,195.043 976.215,195.046 976.224,195.049 976.234,195.051 976.243,195.054 976.252,195.057 976.261,195.06 976.27,195.062 976.28,195.065 976.289,195.068 976.298,195.071 976.307,195.074 976.316,195.076 976.326,195.079 976.335,195.082 976.344,195.085 976.353,195.087 976.362,195.09 976.372,195.093 976.381,195.096 976.39,195.098 976.399,195.101 976.408,195.104 976.417,195.107 976.427,195.109 976.436,195.112 976.445,195.115 976.454,195.118 976.463,195.12 976.473,195.123 976.482,195.126 976.491,195.129 976.5,195.131 976.509,195.134 976.519,195.137 976.528,195.14 976.537,195.142 976.546,195.145 976.555,195.148 976.564,195.151 976.574,195.154 976.583,195.156 976.592,195.159 976.601,195.162 976.61,195.165 976.62,195.167 976.629,195.17 976.638,195.173 976.647,195.176 976.656,195.178 976.666,195.181 976.675,195.184 976.684,195.187 976.693,195.189 976.702,195.192 976.712,195.195 976.721,195.198 976.73,195.2 976.739,195.203 976.748,195.206 976.757,195.209 976.767,195.211 976.776,195.214 976.785,195.217 976.794,195.22 976.803,195.222 976.813,195.225 976.822,195.228 976.831,195.231 976.84,195.234 976.849,195.236 976.859,195.239 976.868,195.242 976.877,195.245 976.886,195.247 976.895,195.25 976.904,195.253 976.914,195.256 976.923,195.258 976.932,195.261 976.941,195.264 976.95,195.267 976.96,195.269 976.969,195.272 976.978,195.275 976.987,195.278 976.996,195.28 977.006,195.283 977.015,195.286 977.024,195.289 977.033,195.291 977.042,195.294 977.052,195.297 977.061,195.3 977.07,195.302 977.079,195.305 977.088,195.308 977.097,195.311 977.107,195.314 977.116,195.316 977.125,195.319 977.134,195.322 977.143,195.325 977.153,195.327 977.162,195.33 977.171,195.333 977.18,195.336 977.189,195.338 977.199,195.341 977.208,195.344 977.217,195.347 977.226,195.349 977.235,195.352 977.245,195.355 977.254,195.358 977.263,195.36 977.272,195.363 977.281,195.366 977.29,195.369 977.3,195.371 977.309,195.374 977.318,195.377 977.327,195.38 977.336,195.382 977.346,195.385 977.355,195.388 977.364,195.391 977.373,195.393 977.382,195.396 977.392,195.399 977.401,195.402 977.41,195.404 977.419,195.407 977.428,195.41 977.437,195.413 977.447,195.416 977.456,195.418 977.465,195.421 977.474,195.424 977.483,195.427 977.493,195.429 977.502,195.432 977.511,195.435 977.52,195.438 977.529,195.44 977.539,195.443 977.548,195.446 977.557,195.449 977.566,195.451 977.575,195.454 977.585,195.457 977.594,195.46 977.603,195.462 977.612,195.465 977.621,195.468 977.63,195.471 977.64,195.473 977.649,195.476 977.658,195.479 977.667,195.482 977.676,195.484 977.686,195.487 977.695,195.49 977.704,195.493 977.713,195.495 977.722,195.498 977.732,195.501 977.741,195.504 977.75,195.506 977.759,195.509 977.768,195.512 977.777,195.515 977.787,195.518 977.796,195.52 977.805,195.523 977.814,195.526 977.823,195.529 977.833,195.531 977.842,195.534 977.851,195.537 977.86,195.54 977.869,195.542 977.879,195.545 977.888,195.548 977.897,195.551 977.906,195.553 977.915,195.556 977.925,195.559 977.934,195.562 977.943,195.564 977.952,195.567 977.961,195.57 977.97,195.573 977.98,195.575 977.989,195.578 977.998,195.581 978.007,195.584 978.016,195.586 978.026,195.589 978.035,195.592 978.044,195.595 978.053,195.597 978.062,195.6 978.072,195.603 978.081,195.606 978.09,195.608 978.099,195.611 978.108,195.614 978.117,195.617 978.127,195.619 978.136,195.622 978.145,195.625 978.154,195.628 978.163,195.631 978.173,195.633 978.182,195.636 978.191,195.639 978.2,195.642 978.209,195.644 978.219,195.647 978.228,195.65 978.237,195.653 978.246,195.655 978.255,195.658 978.265,195.661 978.274,195.664 978.283,195.666 978.292,195.669 978.301,195.672 978.31,195.675 978.32,195.677 978.329,195.68 978.338,195.683 978.347,195.686 978.356,195.688 978.366,195.691 978.375,195.694 978.384,195.697 978.393,195.699 978.402,195.702 978.412,195.705 978.421,195.708 978.43,195.71 978.439,195.713 978.448,195.716 978.457,195.719 978.467,195.721 978.476,195.724 978.485,195.727 978.494,195.73 978.503,195.732 978.513,195.735 978.522,195.738 978.531,195.741 978.54,195.743 978.549,195.746 978.559,195.749 978.568,195.752 978.577,195.754 978.586,195.757 978.595,195.76 978.605,195.763 978.614,195.765 978.623,195.768 978.632,195.771 978.641,195.774 978.65,195.777 978.66,195.779 978.669,195.782 978.678,195.785 978.687,195.788 978.696,195.79 978.706,195.793 978.715,195.796 978.724,195.799 978.733,195.801 978.742,195.804 978.752,195.807 978.761,195.81 978.77,195.812 978.779,195.815 978.788,195.818 978.797,195.821 978.807,195.823 978.816,195.826 978.825,195.829 978.834,195.832 978.843,195.834 978.853,195.837 978.862,195.84 978.871,195.843 978.88,195.845 978.889,195.848 978.899,195.851 978.908,195.854 978.917,195.856 978.926,195.859 978.935,195.862 978.945,195.865 978.954,195.867 978.963,195.87 978.972,195.873 978.981,195.876 978.99,195.878 979,195.881 979.009,195.884 979.018,195.887 979.027,195.889 979.036,195.892 979.046,195.895 979.055,195.898 979.064,195.9 979.073,195.903 979.082,195.906 979.092,195.909 979.101,195.911 979.11,195.914 979.119,195.917 979.128,195.92 979.137,195.922 979.147,195.925 979.156,195.928 979.165,195.931 979.174,195.933 979.183,195.936 979.193,195.939 979.202,195.942 979.211,195.945 979.22,195.947 979.229,195.95 979.239,195.953 979.248,195.956 979.257,195.958 979.266,195.961 979.275,195.964 979.285,195.967 979.294,195.969 979.303,195.972 979.312,195.975 979.321,195.978 979.33,195.98 979.34,195.983 979.349,195.986 979.358,195.989 979.367,195.991 979.376,195.994 979.386,195.997 979.395,196 979.404,196.002 979.413,196.005 979.422,196.008 979.432,196.011 979.441,196.013 979.45,196.016 979.459,196.019 979.468,196.022 979.477,196.024 979.487,196.027 979.496,196.03 979.505,196.033 979.514,196.035 979.523,196.038 979.533,196.041 979.542,196.044 979.551,196.046 979.56,196.049 979.569,196.052 979.579,196.055 979.588,196.057 979.597,196.06 979.606,196.063 979.615,196.066 979.625,196.068 979.634,196.071 979.643,196.074 979.652,196.077 979.661,196.079 979.67,196.082 979.68,196.085 979.689,196.088 979.698,196.09 979.707,196.093 979.716,196.096 979.726,196.099 979.735,196.101 979.744,196.104 979.753,196.107 979.762,196.11 979.772,196.112 979.781,196.115 979.79,196.118 979.799,196.121 979.808,196.123 979.818,196.126 979.827,196.129 979.836,196.132 979.845,196.134 979.854,196.137 979.863,196.14 979.873,196.143 979.882,196.145 979.891,196.148 979.9,196.151 979.909,196.154 979.919,196.156 979.928,196.159 979.937,196.162 979.946,196.165 979.955,196.167 979.965,196.17 979.974,196.173 979.983,196.176 979.992,196.178 980.001,196.181 980.01,196.184 980.02,196.187 980.029,196.189 980.038,196.192 980.047,196.195 980.056,196.198 980.066,196.201 980.075,196.203 980.084,196.206 980.093,196.209 980.102,196.212 980.112,196.214 980.121,196.217 980.13,196.22 980.139,196.223 980.148,196.225 980.158,196.228 980.167,196.231 980.176,196.234 980.185,196.236 980.194,196.239 980.203,196.242 980.213,196.245 980.222,196.247 980.231,196.25 980.24,196.253 980.249,196.256 980.259,196.258 980.268,196.261 980.277,196.264 980.286,196.267 980.295,196.269 980.305,196.272 980.314,196.275 980.323,196.278 980.332,196.28 980.341,196.283 980.35,196.286 980.36,196.289 980.369,196.291 980.378,196.294 980.387,196.297 980.396,196.3 980.406,196.302 980.415,196.305 980.424,196.308 980.433,196.311 980.442,196.313 980.452,196.316 980.461,196.319 980.47,196.322 980.479,196.324 980.488,196.327 980.498,196.33 980.507,196.333 980.516,196.335 980.525,196.338 980.534,196.341 980.543,196.344 980.553,196.346 980.562,196.349 980.571,196.352 980.58,196.355 980.589,196.357 980.599,196.36 980.608,196.363 980.617,196.366 980.626,196.368 980.635,196.371 980.645,196.374 980.654,196.377 980.663,196.379 980.672,196.382 980.681,196.385 980.69,196.388 980.7,196.39 980.709,196.393 980.718,196.396 980.727,196.399 980.736,196.401 980.746,196.404 980.755,196.407 980.764,196.41 980.773,196.412 980.782,196.415 980.792,196.418 980.801,196.421 980.81,196.423 980.819,196.426 980.828,196.429 980.838,196.432 980.847,196.434 980.856,196.437 980.865,196.44 980.874,196.443 980.883,196.445 980.893,196.448 980.902,196.451 980.911,196.454 980.92,196.456 980.929,196.459 980.939,196.462 980.948,196.465 980.957,196.467 980.966,196.47 980.975,196.473 980.985,196.476 980.994,196.478 981.003,196.481 981.012,196.484 981.021,196.487 981.03,196.489 981.04,196.492 981.049,196.495 981.058,196.498 981.067,196.5 981.076,196.503 981.086,196.506 981.095,196.509 981.104,196.511 981.113,196.514 981.122,196.517 981.132,196.52 981.141,196.522 981.15,196.525 981.159,196.528 981.168,196.531 981.178,196.533 981.187,196.536 981.196,196.539 981.205,196.542 981.214,196.544 981.223,196.547 981.233,196.55 981.242,196.553 981.251,196.555 981.26,196.558 981.269,196.561 981.279,196.564 981.288,196.566 981.297,196.569 981.306,196.572 981.315,196.575 981.325,196.577 981.334,196.58 981.343,196.583 981.352,196.586 981.361,196.588 981.37,196.591 981.38,196.594 981.389,196.597 981.398,196.599 981.407,196.602 981.416,196.605 981.426,196.608 981.435,196.61 981.444,196.613 981.453,196.616 981.462,196.619 981.472,196.621 981.481,196.624 981.49,196.627 981.499,196.63 981.508,196.632 981.518,196.635 981.527,196.638 981.536,196.641 981.545,196.643 981.554,196.646 981.563,196.649 981.573,196.652 981.582,196.654 981.591,196.657 981.6,196.66 981.609,196.663 981.619,196.665 981.628,196.668 981.637,196.671 981.646,196.674 981.655,196.676 981.665,196.679 981.674,196.682 981.683,196.685 981.692,196.687 981.701,196.69 981.71,196.693 981.72,196.696 981.729,196.698 981.738,196.701 981.747,196.704 981.756,196.707 981.766,196.709 981.775,196.712 981.784,196.715 981.793,196.718 981.802,196.72 981.812,196.723 981.821,196.726 981.83,196.729 981.839,196.731 981.848,196.734 981.858,196.737 981.867,196.74 981.876,196.742 981.885,196.745 981.894,196.748 981.903,196.751 981.913,196.753 981.922,196.756 981.931,196.759 981.94,196.761 981.949,196.764 981.959,196.767 981.968,196.77 981.977,196.772 981.986,196.775 981.995,196.778 982.005,196.781 982.014,196.783 982.023,196.786 982.032,196.789 982.041,196.792 982.05,196.794 982.06,196.797 982.069,196.8 982.078,196.803 982.087,196.805 982.096,196.808 982.106,196.811 982.115,196.814 982.124,196.816 982.133,196.819 982.142,196.822 982.152,196.825 982.161,196.827 982.17,196.83 982.179,196.833 982.188,196.836 982.198,196.838 982.207,196.841 982.216,196.844 982.225,196.847 982.234,196.849 982.243,196.852 982.253,196.855 982.262,196.858 982.271,196.86 982.28,196.863 982.289,196.866 982.299,196.869 982.308,196.871 982.317,196.874 982.326,196.877 982.335,196.88 982.345,196.882 982.354,196.885 982.363,196.888 982.372,196.891 982.381,196.893 982.391,196.896 982.4,196.899 982.409,196.902 982.418,196.904 982.427,196.907 982.436,196.91 982.446,196.913 982.455,196.915 982.464,196.918 982.473,196.921 982.482,196.924 982.492,196.926 982.501,196.929 982.51,196.932 982.519,196.935 982.528,196.937 982.538,196.94 982.547,196.943 982.556,196.946 982.565,196.948 982.574,196.951 982.583,196.954 982.593,196.957 982.602,196.959 982.611,196.962 982.62,196.965 982.629,196.968 982.639,196.97 982.648,196.973 982.657,196.976 982.666,196.979 982.675,196.981 982.685,196.984 982.694,196.987 982.703,196.99 982.712,196.992 982.721,196.995 982.731,196.998 982.74,197.001 982.749,197.003 982.758,197.006 982.767,197.009 982.776,197.011 982.786,197.014 982.795,197.017 982.804,197.02 982.813,197.022 982.822,197.025 982.832,197.028 982.841,197.031 982.85,197.033 982.859,197.036 982.868,197.039 982.878,197.042 982.887,197.044 982.896,197.047 982.905,197.05 982.914,197.053 982.923,197.055 982.933,197.058 982.942,197.061 982.951,197.064 982.96,197.066 982.969,197.069 982.979,197.072 982.988,197.075 982.997,197.077 983.006,197.08 983.015,197.083 983.025,197.086 983.034,197.088 983.043,197.091 983.052,197.094 983.061,197.097 983.071,197.099 983.08,197.102 983.089,197.105 983.098,197.108 983.107,197.11 983.116,197.113 983.126,197.116 983.135,197.119 983.144,197.121 983.153,197.124 983.162,197.127 983.172,197.13 983.181,197.132 983.19,197.135 983.199,197.138 983.208,197.141 983.218,197.143 983.227,197.146 983.236,197.149 983.245,197.152 983.254,197.154 983.263,197.157 983.273,197.16 983.282,197.163 983.291,197.165 983.3,197.168 983.309,197.171 983.319,197.174 983.328,197.176 983.337,197.179 983.346,197.182 983.355,197.184 983.365,197.187 983.374,197.19 983.383,197.193 983.392,197.195 983.401,197.198 983.411,197.201 983.42,197.204 983.429,197.206 983.438,197.209 983.447,197.212 983.456,197.215 983.466,197.217 983.475,197.22 983.484,197.223 983.493,197.226 983.502,197.228 983.512,197.231 983.521,197.234 983.53,197.237 983.539,197.239 983.548,197.242 983.558,197.245 983.567,197.248 983.576,197.25 983.585,197.253 983.594,197.256 983.603,197.259 983.613,197.261 983.622,197.264 983.631,197.267 983.64,197.27 983.649,197.272 983.659,197.275 983.668,197.278 983.677,197.281 983.686,197.283 983.695,197.286 983.705,197.289 983.714,197.292 983.723,197.294 983.732,197.297 983.741,197.3 983.751,197.303 983.76,197.305 983.769,197.308 983.778,197.311 983.787,197.314 983.796,197.316 983.806,197.319 983.815,197.322 983.824,197.324 983.833,197.327 983.842,197.33 983.852,197.333 983.861,197.335 983.87,197.338 983.879,197.341 983.888,197.344 983.898,197.346 983.907,197.349 983.916,197.352 983.925,197.355 983.934,197.357 983.943,197.36 983.953,197.363 983.962,197.366 983.971,197.368 983.98,197.371 983.989,197.374 983.999,197.377 984.008,197.379 984.017,197.382 984.026,197.385 984.035,197.388 984.045,197.39 984.054,197.393 984.063,197.396 984.072,197.399 984.081,197.401 984.091,197.404 984.1,197.407 984.109,197.41 984.118,197.412 984.127,197.415 984.136,197.418 984.146,197.421 984.155,197.423 984.164,197.426 984.173,197.429 984.182,197.431 984.192,197.434 984.201,197.437 984.21,197.44 984.219,197.442 984.228,197.445 984.238,197.448 984.247,197.451 984.256,197.453 984.265,197.456 984.274,197.459 984.283,197.462 984.293,197.464 984.302,197.467 984.311,197.47 984.32,197.473 984.329,197.475 984.339,197.478 984.348,197.481 984.357,197.484 984.366,197.486 984.375,197.489 984.385,197.492 984.394,197.495 984.403,197.497 984.412,197.5 984.421,197.503 984.431,197.506 984.44,197.508 984.449,197.511 984.458,197.514 984.467,197.517 984.476,197.519 984.486,197.522 984.495,197.525 984.504,197.528 984.513,197.53 984.522,197.533 984.532,197.536 984.541,197.538 984.55,197.541 984.559,197.544 984.568,197.547 984.578,197.549 984.587,197.552 984.596,197.555 984.605,197.558 984.614,197.56 984.624,197.563 984.633,197.566 984.642,197.569 984.651,197.571 984.66,197.574 984.669,197.577 984.679,197.58 984.688,197.582 984.697,197.585 984.706,197.588 984.715,197.591 984.725,197.593 984.734,197.596 984.743,197.599 984.752,197.602 984.761,197.604 984.771,197.607 984.78,197.61 984.789,197.613 984.798,197.615 984.807,197.618 984.816,197.621 984.826,197.624 984.835,197.626 984.844,197.629 984.853,197.632 984.862,197.634 984.872,197.637 984.881,197.64 984.89,197.643 984.899,197.645 984.908,197.648 984.918,197.651 984.927,197.654 984.936,197.656 984.945,197.659 984.954,197.662 984.964,197.665 984.973,197.667 984.982,197.67 984.991,197.673 985,197.676 985.009,197.678 985.019,197.681 985.028,197.684 985.037,197.687 985.046,197.689 985.055,197.692 985.065,197.695 985.074,197.698 985.083,197.7 985.092,197.703 985.101,197.706 985.111,197.709 985.12,197.711 985.129,197.714 985.138,197.717 985.147,197.719 985.156,197.722 985.166,197.725 985.175,197.728 985.184,197.73 985.193,197.733 985.202,197.736 985.212,197.739 985.221,197.741 985.23,197.744 985.239,197.747 985.248,197.75 985.258,197.752 985.267,197.755 985.276,197.758 985.285,197.761 985.294,197.763 985.304,197.766 985.313,197.769 985.322,197.772 985.331,197.774 985.34,197.777 985.349,197.78 985.359,197.783 985.368,197.785 985.377,197.788 985.386,197.791 985.395,197.794 985.405,197.796 985.414,197.799 985.423,197.802 985.432,197.804 985.441,197.807 985.451,197.81 985.46,197.813 985.469,197.815 985.478,197.818 985.487,197.821 985.496,197.824 985.506,197.826 985.515,197.829 985.524,197.832 985.533,197.835 985.542,197.837 985.552,197.84 985.561,197.843 985.57,197.846 985.579,197.848 985.588,197.851 985.598,197.854 985.607,197.857 985.616,197.859 985.625,197.862 985.634,197.865 985.644,197.868 985.653,197.87 985.662,197.873 985.671,197.876 985.68,197.878 985.689,197.881 985.699,197.884 985.708,197.887 985.717,197.889 985.726,197.892 985.735,197.895 985.745,197.898 985.754,197.9 985.763,197.903 985.772,197.906 985.781,197.909 985.791,197.911 985.8,197.914 985.809,197.917 985.818,197.92 985.827,197.922 985.836,197.925 985.846,197.928 985.855,197.931 985.864,197.933 985.873,197.936 985.882,197.939 985.892,197.942 985.901,197.944 985.91,197.947 985.919,197.95 985.928,197.952 985.938,197.955 985.947,197.958 985.956,197.961 985.965,197.963 985.974,197.966 985.984,197.969 985.993,197.972 986.002,197.974 986.011,197.977 986.02,197.98 986.029,197.983 986.039,197.985 986.048,197.988 986.057,197.991 986.066,197.994 986.075,197.996 986.085,197.999 986.094,198.002 986.103,198.005 986.112,198.007 986.121,198.01 986.131,198.013 986.14,198.016 986.149,198.018 986.158,198.021 986.167,198.024 986.176,198.026 986.186,198.029 986.195,198.032 986.204,198.035 986.213,198.037 986.222,198.04 986.232,198.043 986.241,198.046 986.25,198.048 986.259,198.051 986.268,198.054 986.278,198.057 986.287,198.059 986.296,198.062 986.305,198.065 986.314,198.068 986.324,198.07 986.333,198.073 986.342,198.076 986.351,198.079 986.36,198.081 986.369,198.084 986.379,198.087 986.388,198.089 986.397,198.092 986.406,198.095 986.415,198.098 986.425,198.1 986.434,198.103 986.443,198.106 986.452,198.109 986.461,198.111 986.471,198.114 986.48,198.117 986.489,198.12 986.498,198.122 986.507,198.125 986.516,198.128 986.526,198.131 986.535,198.133 986.544,198.136 986.553,198.139 986.562,198.142 986.572,198.144 986.581,198.147 986.59,198.15 986.599,198.152 986.608,198.155 986.618,198.158 986.627,198.161 986.636,198.163 986.645,198.166 986.654,198.169 986.664,198.172 986.673,198.174 986.682,198.177 986.691,198.18 986.7,198.183 986.709,198.185 986.719,198.188 986.728,198.191 986.737,198.194 986.746,198.196 986.755,198.199 986.765,198.202 986.774,198.205 986.783,198.207 986.792,198.21 986.801,198.213 986.811,198.215 986.82,198.218 986.829,198.221 986.838,198.224 986.847,198.226 986.856,198.229 986.866,198.232 986.875,198.235 986.884,198.237 986.893,198.24 986.902,198.243 986.912,198.246 986.921,198.248 986.93,198.251 986.939,198.254 986.948,198.257 986.958,198.259 986.967,198.262 986.976,198.265 986.985,198.267 986.994,198.27 987.004,198.273 987.013,198.276 987.022,198.278 987.031,198.281 987.04,198.284 987.049,198.287 987.059,198.289 987.068,198.292 987.077,198.295 987.086,198.298 987.095,198.3 987.105,198.303 987.114,198.306 987.123,198.309 987.132,198.311 987.141,198.314 987.151,198.317 987.16,198.32 987.169,198.322 987.178,198.325 987.187,198.328 987.197,198.33 987.206,198.333 987.215,198.336 987.224,198.339 987.233,198.341 987.242,198.344 987.252,198.347 987.261,198.35 987.27,198.352 987.279,198.355 987.288,198.358 987.298,198.361 987.307,198.363 987.316,198.366 987.325,198.369 987.334,198.372 987.344,198.374 987.353,198.377 987.362,198.38 987.371,198.382 987.38,198.385 987.389,198.388 987.399,198.391 987.408,198.393 987.417,198.396 987.426,198.399 987.435,198.402 987.445,198.404 987.454,198.407 987.463,198.41 987.472,198.413 987.481,198.415 987.491,198.418 987.5,198.421 987.509,198.424 987.518,198.426 987.527,198.429 987.537,198.432 987.546,198.434 987.555,198.437 987.564,198.44 987.573,198.443 987.582,198.445 987.592,198.448 987.601,198.451 987.61,198.454 987.619,198.456 987.628,198.459 987.638,198.462 987.647,198.465 987.656,198.467 987.665,198.47 987.674,198.473 987.684,198.476 987.693,198.478 987.702,198.481 987.711,198.484 987.72,198.486 987.729,198.489 987.739,198.492 987.748,198.495 987.757,198.497 987.766,198.5 987.775,198.503 987.785,198.506 987.794,198.508 987.803,198.511 987.812,198.514 987.821,198.517 987.831,198.519 987.84,198.522 987.849,198.525 987.858,198.528 987.867,198.53 987.877,198.533 987.886,198.536 987.895,198.538 987.904,198.541 987.913,198.544 987.922,198.547 987.932,198.549 987.941,198.552 987.95,198.555 987.959,198.558 987.968,198.56 987.978,198.563 987.987,198.566 987.996,198.569 988.005,198.571 988.014,198.574 988.024,198.577 988.033,198.58 988.042,198.582 988.051,198.585 988.06,198.588 988.069,198.59 988.079,198.593 988.088,198.596 988.097,198.599 988.106,198.601 988.115,198.604 988.125,198.607 988.134,198.61 988.143,198.612 988.152,198.615 988.161,198.618 988.171,198.621 988.18,198.623 988.189,198.626 988.198,198.629 988.207,198.632 988.217,198.634 988.226,198.637 988.235,198.64 988.244,198.642 988.253,198.645 988.262,198.648 988.272,198.651 988.281,198.653 988.29,198.656 988.299,198.659 988.308,198.662 988.318,198.664 988.327,198.667 988.336,198.67 988.345,198.673 988.354,198.675 988.364,198.678 988.373,198.681 988.382,198.684 988.391,198.686 988.4,198.689 988.409,198.692 988.419,198.694 988.428,198.697 988.437,198.7 988.446,198.703 988.455,198.705 988.465,198.708 988.474,198.711 988.483,198.714 988.492,198.716 988.501,198.719 988.511,198.722 988.52,198.725 988.529,198.727 988.538,198.73 988.547,198.733 988.557,198.735 988.566,198.738 988.575,198.741 988.584,198.744 988.593,198.746 988.602,198.749 988.612,198.752 988.621,198.755 988.63,198.757 988.639,198.76 988.648,198.763 988.658,198.766 988.667,198.768 988.676,198.771 988.685,198.774 988.694,198.776 988.704,198.779 988.713,198.782 988.722,198.785 988.731,198.787 988.74,198.79 988.749,198.793 988.759,198.796 988.768,198.798 988.777,198.801 988.786,198.804 988.795,198.807 988.805,198.809 988.814,198.812 988.823,198.815 988.832,198.818 988.841,198.82 988.851,198.823 988.86,198.826 988.869,198.828 988.878,198.831 988.887,198.834 988.897,198.837 988.906,198.839 988.915,198.842 988.924,198.845 988.933,198.848 988.942,198.85 988.952,198.853 988.961,198.856 988.97,198.859 988.979,198.861 988.988,198.864 988.998,198.867 989.007,198.869 989.016,198.872 989.025,198.875 989.034,198.878 989.044,198.88 989.053,198.883 989.062,198.886 989.071,198.889 989.08,198.891 989.089,198.894 989.099,198.897 989.108,198.9 989.117,198.902 989.126,198.905 989.135,198.908 989.145,198.91 989.154,198.913 989.163,198.916 989.172,198.919 989.181,198.921 989.191,198.924 989.2,198.927 989.209,198.93 989.218,198.932 989.227,198.935 989.237,198.938 989.246,198.941 989.255,198.943 989.264,198.946 989.273,198.949 989.282,198.951 989.292,198.954 989.301,198.957 989.31,198.96 989.319,198.962 989.328,198.965 989.338,198.968 989.347,198.971 989.356,198.973 989.365,198.976 989.374,198.979 989.384,198.982 989.393,198.984 989.402,198.987 989.411,198.99 989.42,198.992 989.429,198.995 989.439,198.998 989.448,199.001 989.457,199.003 989.466,199.006 989.475,199.009 989.485,199.012 989.494,199.014 989.503,199.017 989.512,199.02 989.521,199.023 989.531,199.025 989.54,199.028 989.549,199.031 989.558,199.033 989.567,199.036 989.577,199.039 989.586,199.042 989.595,199.044 989.604,199.047 989.613,199.05 989.622,199.053 989.632,199.055 989.641,199.058 989.65,199.061 989.659,199.064 989.668,199.066 989.678,199.069 989.687,199.072 989.696,199.074 989.705,199.077 989.714,199.08 989.724,199.083 989.733,199.085 989.742,199.088 989.751,199.091 989.76,199.094 989.77,199.096 989.779,199.099 989.788,199.102 989.797,199.105 989.806,199.107 989.815,199.11 989.825,199.113 989.834,199.115 989.843,199.118 989.852,199.121 989.861,199.124 989.871,199.126 989.88,199.129 989.889,199.132 989.898,199.135 989.907,199.137 989.917,199.14 989.926,199.143 989.935,199.146 989.944,199.148 989.953,199.151 989.962,199.154 989.972,199.156 989.981,199.159 989.99,199.162 989.999,199.165 990.008,199.167 990.018,199.17 990.027,199.173 990.036,199.176 990.045,199.178 990.054,199.181 990.064,199.184 990.073,199.187 990.082,199.189 990.091,199.192 990.1,199.195 990.11,199.197 990.119,199.2 990.128,199.203 990.137,199.206 990.146,199.208 990.155,199.211 990.165,199.214 990.174,199.217 990.183,199.219 990.192,199.222 990.201,199.225 990.211,199.228 990.22,199.23 990.229,199.233 990.238,199.236 990.247,199.238 990.257,199.241 990.266,199.244 990.275,199.247 990.284,199.249 990.293,199.252 990.302,199.255 990.312,199.258 990.321,199.26 990.33,199.263 990.339,199.266 990.348,199.268 990.358,199.271 990.367,199.274 990.376,199.277 990.385,199.279 990.394,199.282 990.404,199.285 990.413,199.288 990.422,199.29 990.431,199.293 990.44,199.296 990.45,199.299 990.459,199.301 990.468,199.304 990.477,199.307 990.486,199.309 990.495,199.312 990.505,199.315 990.514,199.318 990.523,199.32 990.532,199.323 990.541,199.326 990.551,199.329 990.56,199.331 990.569,199.334 990.578,199.337 990.587,199.34 990.597,199.342 990.606,199.345 990.615,199.348 990.624,199.35 990.633,199.353 990.642,199.356 990.652,199.359 990.661,199.361 990.67,199.364 990.679,199.367 990.688,199.37 990.698,199.372 990.707,199.375 990.716,199.378 990.725,199.38 990.734,199.383 990.744,199.386 990.753,199.389 990.762,199.391 990.771,199.394 990.78,199.397 990.79,199.4 990.799,199.402 990.808,199.405 990.817,199.408 990.826,199.411 990.835,199.413 990.845,199.416 990.854,199.419 990.863,199.421 990.872,199.424 990.881,199.427 990.891,199.43 990.9,199.432 990.909,199.435 990.918,199.438 990.927,199.441 990.937,199.443 990.946,199.446 990.955,199.449 990.964,199.451 990.973,199.454 990.982,199.457 990.992,199.46 991.001,199.462 991.01,199.465 991.019,199.468 991.028,199.471 991.038,199.473 991.047,199.476 991.056,199.479 991.065,199.482 991.074,199.484 991.084,199.487 991.093,199.49 991.102,199.492 991.111,199.495 991.12,199.498 991.13,199.501 991.139,199.503 991.148,199.506 991.157,199.509 991.166,199.512 991.175,199.514 991.185,199.517 991.194,199.52 991.203,199.522 991.212,199.525 991.221,199.528 991.231,199.531 991.24,199.533 991.249,199.536 991.258,199.539 991.267,199.542 991.277,199.544 991.286,199.547 991.295,199.55 991.304,199.552 991.313,199.555 991.322,199.558 991.332,199.561 991.341,199.563 991.35,199.566 991.359,199.569 991.368,199.572 991.378,199.574 991.387,199.577 991.396,199.58 991.405,199.583 991.414,199.585 991.424,199.588 991.433,199.591 991.442,199.593 991.451,199.596 991.46,199.599 991.47,199.602 991.479,199.604 991.488,199.607 991.497,199.61 991.506,199.613 991.515,199.615 991.525,199.618 991.534,199.621 991.543,199.623 991.552,199.626 991.561,199.629 991.571,199.632 991.58,199.634 991.589,199.637 991.598,199.64 991.607,199.643 991.617,199.645 991.626,199.648 991.635,199.651 991.644,199.653 991.653,199.656 991.662,199.659 991.672,199.662 991.681,199.664 991.69,199.667 991.699,199.67 991.708,199.673 991.718,199.675 991.727,199.678 991.736,199.681 991.745,199.683 991.754,199.686 991.764,199.689 991.773,199.692 991.782,199.694 991.791,199.697 991.8,199.7 991.81,199.703 991.819,199.705 991.828,199.708 991.837,199.711 991.846,199.714 991.855,199.716 991.865,199.719 991.874,199.722 991.883,199.724 991.892,199.727 991.901,199.73 991.911,199.733 991.92,199.735 991.929,199.738 991.938,199.741 991.947,199.744 991.957,199.746 991.966,199.749 991.975,199.752 991.984,199.754 991.993,199.757 992.002,199.76 992.012,199.763 992.021,199.765 992.03,199.768 992.039,199.771 992.048,199.774 992.058,199.776 992.067,199.779 992.076,199.782 992.085,199.784 992.094,199.787 992.104,199.79 992.113,199.793 992.122,199.795 992.131,199.798 992.14,199.801 992.15,199.804 992.159,199.806 992.168,199.809 992.177,199.812 992.186,199.814 992.195,199.817 992.205,199.82 992.214,199.823 992.223,199.825 992.232,199.828 992.241,199.831 992.251,199.834 992.26,199.836 992.269,199.839 992.278,199.842 992.287,199.844 992.297,199.847 992.306,199.85 992.315,199.853 992.324,199.855 992.333,199.858 992.343,199.861 992.352,199.864 992.361,199.866 992.37,199.869 992.379,199.872 992.388,199.874 992.398,199.877 992.407,199.88 992.416,199.883 992.425,199.885 992.434,199.888 992.444,199.891 992.453,199.894 992.462,199.896 992.471,199.899 992.48,199.902 992.49,199.904 992.499,199.907 992.508,199.91 992.517,199.913 992.526,199.915 992.535,199.918 992.545,199.921 992.554,199.924 992.563,199.926 992.572,199.929 992.581,199.932 992.591,199.934 992.6,199.937 992.609,199.94 992.618,199.943 992.627,199.945 992.637,199.948 992.646,199.951 992.655,199.954 992.664,199.956 992.673,199.959 992.683,199.962 992.692,199.964 992.701,199.967 992.71,199.97 992.719,199.973 992.728,199.975 992.738,199.978 992.747,199.981 992.756,199.984 992.765,199.986 992.774,199.989 992.784,199.992 992.793,199.994 992.802,199.997 992.811,200 992.82,200.003 992.83,200.005 992.839,200.008 992.848,200.011 992.857,200.014 992.866,200.016 992.875,200.019 992.885,200.022 992.894,200.024 992.903,200.027 992.912,200.03 992.921,200.033 992.931,200.035 992.94,200.038 992.949,200.041 992.958,200.044 992.967,200.046 992.977,200.049 992.986,200.052 992.995,200.054 993.004,200.057 993.013,200.06 993.023,200.063 993.032,200.065 993.041,200.068 993.05,200.071 993.059,200.074 993.068,200.076 993.078,200.079 993.087,200.082 993.096,200.084 993.105,200.087 993.114,200.09 993.124,200.093 993.133,200.095 993.142,200.098 993.151,200.101 993.16,200.104 993.17,200.106 993.179,200.109 993.188,200.112 993.197,200.114 993.206,200.117 993.215,200.12 993.225,200.123 993.234,200.125 993.243,200.128 993.252,200.131 993.261,200.134 993.271,200.136 993.28,200.139 993.289,200.142 993.298,200.144 993.307,200.147 993.317,200.15 993.326,200.153 993.335,200.155 993.344,200.158 993.353,200.161 993.363,200.163 993.372,200.166 993.381,200.169 993.39,200.172 993.399,200.174 993.408,200.177 993.418,200.18 993.427,200.183 993.436,200.185 993.445,200.188 993.454,200.191 993.464,200.193 993.473,200.196 993.482,200.199 993.491,200.202 993.5,200.204 993.51,200.207 993.519,200.21 993.528,200.213 993.537,200.215 993.546,200.218 993.555,200.221 993.565,200.223 993.574,200.226 993.583,200.229 993.592,200.232 993.601,200.234 993.611,200.237 993.62,200.24 993.629,200.243 993.638,200.245 993.647,200.248 993.657,200.251 993.666,200.253 993.675,200.256 993.684,200.259 993.693,200.262 993.703,200.264 993.712,200.267 993.721,200.27 993.73,200.273 993.739,200.275 993.748,200.278 993.758,200.281 993.767,200.283 993.776,200.286 993.785,200.289 993.794,200.292 993.804,200.294 993.813,200.297 993.822,200.3 993.831,200.302 993.84,200.305 993.85,200.308 993.859,200.311 993.868,200.313 993.877,200.316 993.886,200.319 993.895,200.322 993.905,200.324 993.914,200.327 993.923,200.33 993.932,200.332 993.941,200.335 993.951,200.338 993.96,200.341 993.969,200.343 993.978,200.346 993.987,200.349 993.997,200.352 994.006,200.354 994.015,200.357 994.024,200.36 994.033,200.362 994.043,200.365 994.052,200.368 994.061,200.371 994.07,200.373 994.079,200.376 994.088,200.379 994.098,200.382 994.107,200.384 994.116,200.387 994.125,200.39 994.134,200.392 994.144,200.395 994.153,200.398 994.162,200.401 994.171,200.403 994.18,200.406 994.19,200.409 994.199,200.411 994.208,200.414 994.217,200.417 994.226,200.42 994.235,200.422 994.245,200.425 994.254,200.428 994.263,200.431 994.272,200.433 994.281,200.436 994.291,200.439 994.3,200.441 994.309,200.444 994.318,200.447 994.327,200.45 994.337,200.452 994.346,200.455 994.355,200.458 994.364,200.46 994.373,200.463 994.383,200.466 994.392,200.469 994.401,200.471 994.41,200.474 994.419,200.477 994.428,200.48 994.438,200.482 994.447,200.485 994.456,200.488 994.465,200.49 994.474,200.493 994.484,200.496 994.493,200.499 994.502,200.501 994.511,200.504 994.52,200.507 994.53,200.51 994.539,200.512 994.548,200.515 994.557,200.518 994.566,200.52 994.576,200.523 994.585,200.526 994.594,200.529 994.603,200.531 994.612,200.534 994.621,200.537 994.631,200.539 994.64,200.542 994.649,200.545 994.658,200.548 994.667,200.55 994.677,200.553 994.686,200.556 994.695,200.559 994.704,200.561 994.713,200.564 994.723,200.567 994.732,200.569 994.741,200.572 994.75,200.575 994.759,200.578 994.768,200.58 994.778,200.583 994.787,200.586 994.796,200.588 994.805,200.591 994.814,200.594 994.824,200.597 994.833,200.599 994.842,200.602 994.851,200.605 994.86,200.608 994.87,200.61 994.879,200.613 994.888,200.616 994.897,200.618 994.906,200.621 994.916,200.624 994.925,200.627 994.934,200.629 994.943,200.632 994.952,200.635 994.961,200.638 994.971,200.64 994.98,200.643 994.989,200.646 994.998,200.648 995.007,200.651 995.017,200.654 995.026,200.657 995.035,200.659 995.044,200.662 995.053,200.665 995.063,200.667 995.072,200.67 995.081,200.673 995.09,200.676 995.099,200.678 995.108,200.681 995.118,200.684 995.127,200.687 995.136,200.689 995.145,200.692 995.154,200.695 995.164,200.697 995.173,200.7 995.182,200.703 995.191,200.706 995.2,200.708 995.21,200.711 995.219,200.714 995.228,200.716 995.237,200.719 995.246,200.722 995.256,200.725 995.265,200.727 995.274,200.73 995.283,200.733 995.292,200.736 995.301,200.738 995.311,200.741 995.32,200.744 995.329,200.746 995.338,200.749 995.347,200.752 995.357,200.755 995.366,200.757 995.375,200.76 995.384,200.763 995.393,200.765 995.403,200.768 995.412,200.771 995.421,200.774 995.43,200.776 995.439,200.779 995.448,200.782 995.458,200.784 995.467,200.787 995.476,200.79 995.485,200.793 995.494,200.795 995.504,200.798 995.513,200.801 995.522,200.804 995.531,200.806 995.54,200.809 995.55,200.812 995.559,200.814 995.568,200.817 995.577,200.82 995.586,200.823 995.596,200.825 995.605,200.828 995.614,200.831 995.623,200.833 995.632,200.836 995.641,200.839 995.651,200.842 995.66,200.844 995.669,200.847 995.678,200.85 995.687,200.853 995.697,200.855 995.706,200.858 995.715,200.861 995.724,200.863 995.733,200.866 995.743,200.869 995.752,200.872 995.761,200.874 995.77,200.877 995.779,200.88 995.788,200.882 995.798,200.885 995.807,200.888 995.816,200.891 995.825,200.893 995.834,200.896 995.844,200.899 995.853,200.902 995.862,200.904 995.871,200.907 995.88,200.91 995.89,200.912 995.899,200.915 995.908,200.918 995.917,200.921 995.926,200.923 995.936,200.926 995.945,200.929 995.954,200.931 995.963,200.934 995.972,200.937 995.981,200.94 995.991,200.942 996,200.945 996.009,200.948 996.018,200.95 996.027,200.953 996.037,200.956 996.046,200.959 996.055,200.961 996.064,200.964 996.073,200.967 996.083,200.97 996.092,200.972 996.101,200.975 996.11,200.978 996.119,200.98 996.128,200.983 996.138,200.986 996.147,200.989 996.156,200.991 996.165,200.994 996.174,200.997 996.184,200.999 996.193,201.002 996.202,201.005 996.211,201.008 996.22,201.01 996.23,201.013 996.239,201.016 996.248,201.018 996.257,201.021 996.266,201.024 996.276,201.027 996.285,201.029 996.294,201.032 996.303,201.035 996.312,201.038 996.321,201.04 996.331,201.043 996.34,201.046 996.349,201.048 996.358,201.051 996.367,201.054 996.377,201.057 996.386,201.059 996.395,201.062 996.404,201.065 996.413,201.067 996.423,201.07 996.432,201.073 996.441,201.076 996.45,201.078 996.459,201.081 996.468,201.084 996.478,201.086 996.487,201.089 996.496,201.092 996.505,201.095 996.514,201.097 996.524,201.1 996.533,201.103 996.542,201.106 996.551,201.108 996.56,201.111 996.57,201.114 996.579,201.116 996.588,201.119 996.597,201.122 996.606,201.125 996.616,201.127 996.625,201.13 996.634,201.133 996.643,201.135 996.652,201.138 996.661,201.141 996.671,201.144 996.68,201.146 996.689,201.149 996.698,201.152 996.707,201.154 996.717,201.157 996.726,201.16 996.735,201.163 996.744,201.165 996.753,201.168 996.763,201.171 996.772,201.174 996.781,201.176 996.79,201.179 996.799,201.182 996.808,201.184 996.818,201.187 996.827,201.19 996.836,201.193 996.845,201.195 996.854,201.198 996.864,201.201 996.873,201.203 996.882,201.206 996.891,201.209 996.9,201.212 996.91,201.214 996.919,201.217 996.928,201.22 996.937,201.222 996.946,201.225 996.956,201.228 996.965,201.231 996.974,201.233 996.983,201.236 996.992,201.239 997.001,201.241 997.011,201.244 997.02,201.247 997.029,201.25 997.038,201.252 997.047,201.255 997.057,201.258 997.066,201.261 997.075,201.263 997.084,201.266 997.093,201.269 997.103,201.271 997.112,201.274 997.121,201.277 997.13,201.28 997.139,201.282 997.149,201.285 997.158,201.288 997.167,201.29 997.176,201.293 997.185,201.296 997.194,201.299 997.204,201.301 997.213,201.304 997.222,201.307 997.231,201.309 997.24,201.312 997.25,201.315 997.259,201.318 997.268,201.32 997.277,201.323 997.286,201.326 997.296,201.328 997.305,201.331 997.314,201.334 997.323,201.337 997.332,201.339 997.341,201.342 997.351,201.345 997.36,201.347 997.369,201.35 997.378,201.353 997.387,201.356 997.397,201.358 997.406,201.361 997.415,201.364 997.424,201.367 997.433,201.369 997.443,201.372 997.452,201.375 997.461,201.377 997.47,201.38 997.479,201.383 997.489,201.386 997.498,201.388 997.507,201.391 997.516,201.394 997.525,201.396 997.534,201.399 997.544,201.402 997.553,201.405 997.562,201.407 997.571,201.41 997.58,201.413 997.59,201.415 997.599,201.418 997.608,201.421 997.617,201.424 997.626,201.426 997.636,201.429 997.645,201.432 997.654,201.434 997.663,201.437 997.672,201.44 997.681,201.443 997.691,201.445 997.7,201.448 997.709,201.451 997.718,201.453 997.727,201.456 997.737,201.459 997.746,201.462 997.755,201.464 997.764,201.467 997.773,201.47 997.783,201.472 997.792,201.475 997.801,201.478 997.81,201.481 997.819,201.483 997.829,201.486 997.838,201.489 997.847,201.492 997.856,201.494 997.865,201.497 997.874,201.5 997.884,201.502 997.893,201.505 997.902,201.508 997.911,201.511 997.92,201.513 997.93,201.516 997.939,201.519 997.948,201.521 997.957,201.524 997.966,201.527 997.976,201.53 997.985,201.532 997.994,201.535 998.003,201.538 998.012,201.54 998.021,201.543 998.031,201.546 998.04,201.549 998.049,201.551 998.058,201.554 998.067,201.557 998.077,201.559 998.086,201.562 998.095,201.565 998.104,201.568 998.113,201.57 998.123,201.573 998.132,201.576 998.141,201.578 998.15,201.581 998.159,201.584 998.169,201.587 998.178,201.589 998.187,201.592 998.196,201.595 998.205,201.597 998.214,201.6 998.224,201.603 998.233,201.606 998.242,201.608 998.251,201.611 998.26,201.614 998.27,201.616 998.279,201.619 998.288,201.622 998.297,201.625 998.306,201.627 998.316,201.63 998.325,201.633 998.334,201.635 998.343,201.638 998.352,201.641 998.361,201.644 998.371,201.646 998.38,201.649 998.389,201.652 998.398,201.654 998.407,201.657 998.417,201.66 998.426,201.663 998.435,201.665 998.444,201.668 998.453,201.671 998.463,201.674 998.472,201.676 998.481,201.679 998.49,201.682 998.499,201.684 998.509,201.687 998.518,201.69 998.527,201.693 998.536,201.695 998.545,201.698 998.554,201.701 998.564,201.703 998.573,201.706 998.582,201.709 998.591,201.712 998.6,201.714 998.61,201.717 998.619,201.72 998.628,201.722 998.637,201.725 998.646,201.728 998.656,201.731 998.665,201.733 998.674,201.736 998.683,201.739 998.692,201.741 998.701,201.744 998.711,201.747 998.72,201.75 998.729,201.752 998.738,201.755 998.747,201.758 998.757,201.76 998.766,201.763 998.775,201.766 998.784,201.769 998.793,201.771 998.803,201.774 998.812,201.777 998.821,201.779 998.83,201.782 998.839,201.785 998.849,201.788 998.858,201.79 998.867,201.793 998.876,201.796 998.885,201.798 998.894,201.801 998.904,201.804 998.913,201.807 998.922,201.809 998.931,201.812 998.94,201.815 998.95,201.817 998.959,201.82 998.968,201.823 998.977,201.826 998.986,201.828 998.996,201.831 999.005,201.834 999.014,201.836 999.023,201.839 999.032,201.842 999.041,201.845 999.051,201.847 999.06,201.85 999.069,201.853 999.078,201.855 999.087,201.858 999.097,201.861 999.106,201.864 999.115,201.866 999.124,201.869 999.133,201.872 999.143,201.874 999.152,201.877 999.161,201.88 999.17,201.883 999.179,201.885 999.189,201.888 999.198,201.891 999.207,201.893 999.216,201.896 999.225,201.899 999.234,201.902 999.244,201.904 999.253,201.907 999.262,201.91 999.271,201.912 999.28,201.915 999.29,201.918 999.299,201.921 999.308,201.923 999.317,201.926 999.326,201.929 999.336,201.931 999.345,201.934 999.354,201.937 999.363,201.94 999.372,201.942 999.381,201.945 999.391,201.948 999.4,201.95 999.409,201.953 999.418,201.956 999.427,201.959 999.437,201.961 999.446,201.964 999.455,201.967 999.464,201.969 999.473,201.972 999.483,201.975 999.492,201.978 999.501,201.98 999.51,201.983 999.519,201.986 999.529,201.988 999.538,201.991 999.547,201.994 999.556,201.997 999.565,201.999 999.574,202.002 999.584,202.005 999.593,202.007 999.602,202.01 999.611,202.013 999.62,202.016 999.63,202.018 999.639,202.021 999.648,202.024 999.657,202.026 999.666,202.029 999.676,202.032 999.685,202.035 999.694,202.037 999.703,202.04 999.712,202.043 999.722,202.045 999.731,202.048 999.74,202.051 999.749,202.054 999.758,202.056 999.767,202.059 999.777,202.062 999.786,202.064 999.795,202.067 999.804,202.07 999.813,202.073 999.823,202.075 999.832,202.078 999.841,202.081 999.85,202.083 999.859,202.086 999.869,202.089 999.878,202.092 999.887,202.094 999.896,202.097 999.905,202.1 999.914,202.102 999.924,202.105 999.933,202.108 999.942,202.111 999.951,202.113 999.96,202.116 999.97,202.119 999.979,202.121 999.988,202.124 999.997,202.127 1000.01,202.13 1000.02,202.132 1000.02,202.135 1000.03,202.138 1000.04,202.14 1000.05,202.143 1000.06,202.146 1000.07,202.148 1000.08,202.151 1000.09,202.154 1000.1,202.157 1000.11,202.159 1000.12,202.162 1000.13,202.165 1000.14,202.167 1000.14,202.17 1000.15,202.173 1000.16,202.176 1000.17,202.178 1000.18,202.181 1000.19,202.184 1000.2,202.186 1000.21,202.189 1000.22,202.192 1000.23,202.195 1000.24,202.197 1000.25,202.2 1000.25,202.203 1000.26,202.205 1000.27,202.208 1000.28,202.211 1000.29,202.214 1000.3,202.216 1000.31,202.219 1000.32,202.222 1000.33,202.224 1000.34,202.227 1000.35,202.23 1000.36,202.233 1000.36,202.235 1000.37,202.238 1000.38,202.241 1000.39,202.243 1000.4,202.246 1000.41,202.249 1000.42,202.252 1000.43,202.254 1000.44,202.257 1000.45,202.26 1000.46,202.262 1000.47,202.265 1000.48,202.268 1000.48,202.271 1000.49,202.273 1000.5,202.276 1000.51,202.279 1000.52,202.281 1000.53,202.284 1000.54,202.287 1000.55,202.29 1000.56,202.292 1000.57,202.295 1000.58,202.298 1000.59,202.3 1000.59,202.303 1000.6,202.306 1000.61,202.309 1000.62,202.311 1000.63,202.314 1000.64,202.317 1000.65,202.319 1000.66,202.322 1000.67,202.325 1000.68,202.327 1000.69,202.33 1000.7,202.333 1000.7,202.336 1000.71,202.338 1000.72,202.341 1000.73,202.344 1000.74,202.346 1000.75,202.349 1000.76,202.352 1000.77,202.355 1000.78,202.357 1000.79,202.36 1000.8,202.363 1000.81,202.365 1000.82,202.368 1000.82,202.371 1000.83,202.374 1000.84,202.376 1000.85,202.379 1000.86,202.382 1000.87,202.384 1000.88,202.387 1000.89,202.39 1000.9,202.393 1000.91,202.395 1000.92,202.398 1000.93,202.401 1000.93,202.403 1000.94,202.406 1000.95,202.409 1000.96,202.412 1000.97,202.414 1000.98,202.417 1000.99,202.42 1001,202.422 1001.01,202.425 1001.02,202.428 1001.03,202.431 1001.04,202.433 1001.04,202.436 1001.05,202.439 1001.06,202.441 1001.07,202.444 1001.08,202.447 1001.09,202.449 1001.1,202.452 1001.11,202.455 1001.12,202.458 1001.13,202.46 1001.14,202.463 1001.15,202.466 1001.16,202.468 1001.16,202.471 1001.17,202.474 1001.18,202.477 1001.19,202.479 1001.2,202.482 1001.21,202.485 1001.22,202.487 1001.23,202.49 1001.24,202.493 1001.25,202.496 1001.26,202.498 1001.27,202.501 1001.27,202.504 1001.28,202.506 1001.29,202.509 1001.3,202.512 1001.31,202.515 1001.32,202.517 1001.33,202.52 1001.34,202.523 1001.35,202.525 1001.36,202.528 1001.37,202.531 1001.38,202.533 1001.38,202.536 1001.39,202.539 1001.4,202.542 1001.41,202.544 1001.42,202.547 1001.43,202.55 1001.44,202.552 1001.45,202.555 1001.46,202.558 1001.47,202.561 1001.48,202.563 1001.49,202.566 1001.5,202.569 1001.5,202.571 1001.51,202.574 1001.52,202.577 1001.53,202.58 1001.54,202.582 1001.55,202.585 1001.56,202.588 1001.57,202.59 1001.58,202.593 1001.59,202.596 1001.6,202.599 1001.61,202.601 1001.61,202.604 1001.62,202.607 1001.63,202.609 1001.64,202.612 1001.65,202.615 1001.66,202.617 1001.67,202.62 1001.68,202.623 1001.69,202.626 1001.7,202.628 1001.71,202.631 1001.72,202.634 1001.72,202.636 1001.73,202.639 1001.74,202.642 1001.75,202.645 1001.76,202.647 1001.77,202.65 1001.78,202.653 1001.79,202.655 1001.8,202.658 1001.81,202.661 1001.82,202.664 1001.83,202.666 1001.84,202.669 1001.84,202.672 1001.85,202.674 1001.86,202.677 1001.87,202.68 1001.88,202.683 1001.89,202.685 1001.9,202.688 1001.91,202.691 1001.92,202.693 1001.93,202.696 1001.94,202.699 1001.95,202.701 1001.95,202.704 1001.96,202.707 1001.97,202.71 1001.98,202.712 1001.99,202.715 1002,202.718 1002.01,202.72 1002.02,202.723 1002.03,202.726 1002.04,202.729 1002.05,202.731 1002.06,202.734 1002.06,202.737 1002.07,202.739 1002.08,202.742 1002.09,202.745 1002.1,202.748 1002.11,202.75 1002.12,202.753 1002.13,202.756 1002.14,202.758 1002.15,202.761 1002.16,202.764 1002.17,202.766 1002.18,202.769 1002.18,202.772 1002.19,202.775 1002.2,202.777 1002.21,202.78 1002.22,202.783 1002.23,202.785 1002.24,202.788 1002.25,202.791 1002.26,202.794 1002.27,202.796 1002.28,202.799 1002.29,202.802 1002.29,202.804 1002.3,202.807 1002.31,202.81 1002.32,202.813 1002.33,202.815 1002.34,202.818 1002.35,202.821 1002.36,202.823 1002.37,202.826 1002.38,202.829 1002.39,202.831 1002.4,202.834 1002.4,202.837 1002.41,202.84 1002.42,202.842 1002.43,202.845 1002.44,202.848 1002.45,202.85 1002.46,202.853 1002.47,202.856 1002.48,202.859 1002.49,202.861 1002.5,202.864 1002.51,202.867 1002.52,202.869 1002.52,202.872 1002.53,202.875 1002.54,202.878 1002.55,202.88 1002.56,202.883 1002.57,202.886 1002.58,202.888 1002.59,202.891 1002.6,202.894 1002.61,202.896 1002.62,202.899 1002.63,202.902 1002.63,202.905 1002.64,202.907 1002.65,202.91 1002.66,202.913 1002.67,202.915 1002.68,202.918 1002.69,202.921 1002.7,202.924 1002.71,202.926 1002.72,202.929 1002.73,202.932 1002.74,202.934 1002.74,202.937 1002.75,202.94 1002.76,202.943 1002.77,202.945 1002.78,202.948 1002.79,202.951 1002.8,202.953 1002.81,202.956 1002.82,202.959 1002.83,202.961 1002.84,202.964 1002.85,202.967 1002.86,202.97 1002.86,202.972 1002.87,202.975 1002.88,202.978 1002.89,202.98 1002.9,202.983 1002.91,202.986 1002.92,202.989 1002.93,202.991 1002.94,202.994 1002.95,202.997 1002.96,202.999 1002.97,203.002 1002.97,203.005 1002.98,203.007 1002.99,203.01 1003,203.013 1003.01,203.016 1003.02,203.018 1003.03,203.021 1003.04,203.024 1003.05,203.026 1003.06,203.029 1003.07,203.032 1003.08,203.035 1003.08,203.037 1003.09,203.04 1003.1,203.043 1003.11,203.045 1003.12,203.048 1003.13,203.051 1003.14,203.053 1003.15,203.056 1003.16,203.059 1003.17,203.062 1003.18,203.064 1003.19,203.067 1003.2,203.07 1003.2,203.072 1003.21,203.075 1003.22,203.078 1003.23,203.081 1003.24,203.083 1003.25,203.086 1003.26,203.089 1003.27,203.091 1003.28,203.094 1003.29,203.097 1003.3,203.099 1003.31,203.102 1003.31,203.105 1003.32,203.108 1003.33,203.11 1003.34,203.113 1003.35,203.116 1003.36,203.118 1003.37,203.121 1003.38,203.124 1003.39,203.127 1003.4,203.129 1003.41,203.132 1003.42,203.135 1003.42,203.137 1003.43,203.14 1003.44,203.143 1003.45,203.146 1003.46,203.148 1003.47,203.151 1003.48,203.154 1003.49,203.156 1003.5,203.159 1003.51,203.162 1003.52,203.164 1003.53,203.167 1003.54,203.17 1003.54,203.173 1003.55,203.175 1003.56,203.178 1003.57,203.181 1003.58,203.183 1003.59,203.186 1003.6,203.189 1003.61,203.191 1003.62,203.194 1003.63,203.197 1003.64,203.2 1003.65,203.202 1003.65,203.205 1003.66,203.208 1003.67,203.21 1003.68,203.213 1003.69,203.216 1003.7,203.219 1003.71,203.221 1003.72,203.224 1003.73,203.227 1003.74,203.229 1003.75,203.232 1003.76,203.235 1003.76,203.237 1003.77,203.24 1003.78,203.243 1003.79,203.246 1003.8,203.248 1003.81,203.251 1003.82,203.254 1003.83,203.256 1003.84,203.259 1003.85,203.262 1003.86,203.265 1003.87,203.267 1003.88,203.27 1003.88,203.273 1003.89,203.275 1003.9,203.278 1003.91,203.281 1003.92,203.283 1003.93,203.286 1003.94,203.289 1003.95,203.292 1003.96,203.294 1003.97,203.297 1003.98,203.3 1003.99,203.302 1003.99,203.305 1004,203.308 1004.01,203.311 1004.02,203.313 1004.03,203.316 1004.04,203.319 1004.05,203.321 1004.06,203.324 1004.07,203.327 1004.08,203.329 1004.09,203.332 1004.1,203.335 1004.1,203.338 1004.11,203.34 1004.12,203.343 1004.13,203.346 1004.14,203.348 1004.15,203.351 1004.16,203.354 1004.17,203.357 1004.18,203.359 1004.19,203.362 1004.2,203.365 1004.21,203.367 1004.22,203.37 1004.22,203.373 1004.23,203.375 1004.24,203.378 1004.25,203.381 1004.26,203.384 1004.27,203.386 1004.28,203.389 1004.29,203.392 1004.3,203.394 1004.31,203.397 1004.32,203.4 1004.33,203.402 1004.33,203.405 1004.34,203.408 1004.35,203.411 1004.36,203.413 1004.37,203.416 1004.38,203.419 1004.39,203.421 1004.4,203.424 1004.41,203.427 1004.42,203.43 1004.43,203.432 1004.44,203.435 1004.44,203.438 1004.45,203.44 1004.46,203.443 1004.47,203.446 1004.48,203.448 1004.49,203.451 1004.5,203.454 1004.51,203.457 1004.52,203.459 1004.53,203.462 1004.54,203.465 1004.55,203.467 1004.56,203.47 1004.56,203.473 1004.57,203.475 1004.58,203.478 1004.59,203.481 1004.6,203.484 1004.61,203.486 1004.62,203.489 1004.63,203.492 1004.64,203.494 1004.65,203.497 1004.66,203.5 1004.67,203.503 1004.67,203.505 1004.68,203.508 1004.69,203.511 1004.7,203.513 1004.71,203.516 1004.72,203.519 1004.73,203.521 1004.74,203.524 1004.75,203.527 1004.76,203.53 1004.77,203.532 1004.78,203.535 1004.78,203.538 1004.79,203.54 1004.8,203.543 1004.81,203.546 1004.82,203.548 1004.83,203.551 1004.84,203.554 1004.85,203.557 1004.86,203.559 1004.87,203.562 1004.88,203.565 1004.89,203.567 1004.9,203.57 1004.9,203.573 1004.91,203.576 1004.92,203.578 1004.93,203.581 1004.94,203.584 1004.95,203.586 1004.96,203.589 1004.97,203.592 1004.98,203.594 1004.99,203.597 1005,203.6 1005.01,203.603 1005.01,203.605 1005.02,203.608 1005.03,203.611 1005.04,203.613 1005.05,203.616 1005.06,203.619 1005.07,203.621 1005.08,203.624 1005.09,203.627 1005.1,203.63 1005.11,203.632 1005.12,203.635 1005.12,203.638 1005.13,203.64 1005.14,203.643 1005.15,203.646 1005.16,203.648 1005.17,203.651 1005.18,203.654 1005.19,203.657 1005.2,203.659 1005.21,203.662 1005.22,203.665 1005.23,203.667 1005.24,203.67 1005.24,203.673 1005.25,203.676 1005.26,203.678 1005.27,203.681 1005.28,203.684 1005.29,203.686 1005.3,203.689 1005.31,203.692 1005.32,203.694 1005.33,203.697 1005.34,203.7 1005.35,203.703 1005.35,203.705 1005.36,203.708 1005.37,203.711 1005.38,203.713 1005.39,203.716 1005.4,203.719 1005.41,203.721 1005.42,203.724 1005.43,203.727 1005.44,203.73 1005.45,203.732 1005.46,203.735 1005.46,203.738 1005.47,203.74 1005.48,203.743 1005.49,203.746 1005.5,203.748 1005.51,203.751 1005.52,203.754 1005.53,203.757 1005.54,203.759 1005.55,203.762 1005.56,203.765 1005.57,203.767 1005.58,203.77 1005.58,203.773 1005.59,203.775 1005.6,203.778 1005.61,203.781 1005.62,203.784 1005.63,203.786 1005.64,203.789 1005.65,203.792 1005.66,203.794 1005.67,203.797 1005.68,203.8 1005.69,203.803 1005.69,203.805 1005.7,203.808 1005.71,203.811 1005.72,203.813 1005.73,203.816 1005.74,203.819 1005.75,203.821 1005.76,203.824 1005.77,203.827 1005.78,203.83 1005.79,203.832 1005.8,203.835 1005.8,203.838 1005.81,203.84 1005.82,203.843 1005.83,203.846 1005.84,203.848 1005.85,203.851 1005.86,203.854 1005.87,203.857 1005.88,203.859 1005.89,203.862 1005.9,203.865 1005.91,203.867 1005.92,203.87 1005.92,203.873 1005.93,203.875 1005.94,203.878 1005.95,203.881 1005.96,203.884 1005.97,203.886 1005.98,203.889 1005.99,203.892 1006,203.894 1006.01,203.897 1006.02,203.9 1006.03,203.902 1006.03,203.905 1006.04,203.908 1006.05,203.911 1006.06,203.913 1006.07,203.916 1006.08,203.919 1006.09,203.921 1006.1,203.924 1006.11,203.927 1006.12,203.929 1006.13,203.932 1006.14,203.935 1006.14,203.938 1006.15,203.94 1006.16,203.943 1006.17,203.946 1006.18,203.948 1006.19,203.951 1006.2,203.954 1006.21,203.956 1006.22,203.959 1006.23,203.962 1006.24,203.965 1006.25,203.967 1006.26,203.97 1006.26,203.973 1006.27,203.975 1006.28,203.978 1006.29,203.981 1006.3,203.983 1006.31,203.986 1006.32,203.989 1006.33,203.992 1006.34,203.994 1006.35,203.997 1006.36,204 1006.37,204.002 1006.37,204.005 1006.38,204.008 1006.39,204.01 1006.4,204.013 1006.41,204.016 1006.42,204.019 1006.43,204.021 1006.44,204.024 1006.45,204.027 1006.46,204.029 1006.47,204.032 1006.48,204.035 1006.48,204.037 1006.49,204.04 1006.5,204.043 1006.51,204.046 1006.52,204.048 1006.53,204.051 1006.54,204.054 1006.55,204.056 1006.56,204.059 1006.57,204.062 1006.58,204.064 1006.59,204.067 1006.6,204.07 1006.6,204.073 1006.61,204.075 1006.62,204.078 1006.63,204.081 1006.64,204.083 1006.65,204.086 1006.66,204.089 1006.67,204.091 1006.68,204.094 1006.69,204.097 1006.7,204.1 1006.71,204.102 1006.71,204.105 1006.72,204.108 1006.73,204.11 1006.74,204.113 1006.75,204.116 1006.76,204.118 1006.77,204.121 1006.78,204.124 1006.79,204.127 1006.8,204.129 1006.81,204.132 1006.82,204.135 1006.82,204.137 1006.83,204.14 1006.84,204.143 1006.85,204.145 1006.86,204.148 1006.87,204.151 1006.88,204.154 1006.89,204.156 1006.9,204.159 1006.91,204.162 1006.92,204.164 1006.93,204.167 1006.94,204.17 1006.94,204.172 1006.95,204.175 1006.96,204.178 1006.97,204.181 1006.98,204.183 1006.99,204.186 1007,204.189 1007.01,204.191 1007.02,204.194 1007.03,204.197 1007.04,204.199 1007.05,204.202 1007.05,204.205 1007.06,204.208 1007.07,204.21 1007.08,204.213 1007.09,204.216 1007.1,204.218 1007.11,204.221 1007.12,204.224 1007.13,204.226 1007.14,204.229 1007.15,204.232 1007.16,204.235 1007.16,204.237 1007.17,204.24 1007.18,204.243 1007.19,204.245 1007.2,204.248 1007.21,204.251 1007.22,204.253 1007.23,204.256 1007.24,204.259 1007.25,204.262 1007.26,204.264 1007.27,204.267 1007.28,204.27 1007.28,204.272 1007.29,204.275 1007.3,204.278 1007.31,204.28 1007.32,204.283 1007.33,204.286 1007.34,204.289 1007.35,204.291 1007.36,204.294 1007.37,204.297 1007.38,204.299 1007.39,204.302 1007.39,204.305 1007.4,204.307 1007.41,204.31 1007.42,204.313 1007.43,204.315 1007.44,204.318 1007.45,204.321 1007.46,204.324 1007.47,204.326 1007.48,204.329 1007.49,204.332 1007.5,204.334 1007.5,204.337 1007.51,204.34 1007.52,204.342 1007.53,204.345 1007.54,204.348 1007.55,204.351 1007.56,204.353 1007.57,204.356 1007.58,204.359 1007.59,204.361 1007.6,204.364 1007.61,204.367 1007.62,204.369 1007.62,204.372 1007.63,204.375 1007.64,204.378 1007.65,204.38 1007.66,204.383 1007.67,204.386 1007.68,204.388 1007.69,204.391 1007.7,204.394 1007.71,204.396 1007.72,204.399 1007.73,204.402 1007.73,204.405 1007.74,204.407 1007.75,204.41 1007.76,204.413 1007.77,204.415 1007.78,204.418 1007.79,204.421 1007.8,204.423 1007.81,204.426 1007.82,204.429 1007.83,204.431 1007.84,204.434 1007.84,204.437 1007.85,204.44 1007.86,204.442 1007.87,204.445 1007.88,204.448 1007.89,204.45 1007.9,204.453 1007.91,204.456 1007.92,204.458 1007.93,204.461 1007.94,204.464 1007.95,204.467 1007.96,204.469 1007.96,204.472 1007.97,204.475 1007.98,204.477 1007.99,204.48 1008,204.483 1008.01,204.485 1008.02,204.488 1008.03,204.491 1008.04,204.494 1008.05,204.496 1008.06,204.499 1008.07,204.502 1008.07,204.504 1008.08,204.507 1008.09,204.51 1008.1,204.512 1008.11,204.515 1008.12,204.518 1008.13,204.52 1008.14,204.523 1008.15,204.526 1008.16,204.529 1008.17,204.531 1008.18,204.534 1008.18,204.537 1008.19,204.539 1008.2,204.542 1008.21,204.545 1008.22,204.547 1008.23,204.55 1008.24,204.553 1008.25,204.556 1008.26,204.558 1008.27,204.561 1008.28,204.564 1008.29,204.566 1008.3,204.569 1008.3,204.572 1008.31,204.574 1008.32,204.577 1008.33,204.58 1008.34,204.583 1008.35,204.585 1008.36,204.588 1008.37,204.591 1008.38,204.593 1008.39,204.596 1008.4,204.599 1008.41,204.601 1008.41,204.604 1008.42,204.607 1008.43,204.609 1008.44,204.612 1008.45,204.615 1008.46,204.618 1008.47,204.62 1008.48,204.623 1008.49,204.626 1008.5,204.628 1008.51,204.631 1008.52,204.634 1008.52,204.636 1008.53,204.639 1008.54,204.642 1008.55,204.645 1008.56,204.647 1008.57,204.65 1008.58,204.653 1008.59,204.655 1008.6,204.658 1008.61,204.661 1008.62,204.663 1008.63,204.666 1008.64,204.669 1008.64,204.671 1008.65,204.674 1008.66,204.677 1008.67,204.68 1008.68,204.682 1008.69,204.685 1008.7,204.688 1008.71,204.69 1008.72,204.693 1008.73,204.696 1008.74,204.698 1008.75,204.701 1008.75,204.704 1008.76,204.707 1008.77,204.709 1008.78,204.712 1008.79,204.715 1008.8,204.717 1008.81,204.72 1008.82,204.723 1008.83,204.725 1008.84,204.728 1008.85,204.731 1008.86,204.733 1008.86,204.736 1008.87,204.739 1008.88,204.742 1008.89,204.744 1008.9,204.747 1008.91,204.75 1008.92,204.752 1008.93,204.755 1008.94,204.758 1008.95,204.76 1008.96,204.763 1008.97,204.766 1008.98,204.769 1008.98,204.771 1008.99,204.774 1009,204.777 1009.01,204.779 1009.02,204.782 1009.03,204.785 1009.04,204.787 1009.05,204.79 1009.06,204.793 1009.07,204.795 1009.08,204.798 1009.09,204.801 1009.09,204.804 1009.1,204.806 1009.11,204.809 1009.12,204.812 1009.13,204.814 1009.14,204.817 1009.15,204.82 1009.16,204.822 1009.17,204.825 1009.18,204.828 1009.19,204.831 1009.2,204.833 1009.2,204.836 1009.21,204.839 1009.22,204.841 1009.23,204.844 1009.24,204.847 1009.25,204.849 1009.26,204.852 1009.27,204.855 1009.28,204.857 1009.29,204.86 1009.3,204.863 1009.31,204.866 1009.32,204.868 1009.32,204.871 1009.33,204.874 1009.34,204.876 1009.35,204.879 1009.36,204.882 1009.37,204.884 1009.38,204.887 1009.39,204.89 1009.4,204.892 1009.41,204.895 1009.42,204.898 1009.43,204.901 1009.43,204.903 1009.44,204.906 1009.45,204.909 1009.46,204.911 1009.47,204.914 1009.48,204.917 1009.49,204.919 1009.5,204.922 1009.51,204.925 1009.52,204.928 1009.53,204.93 1009.54,204.933 1009.54,204.936 1009.55,204.938 1009.56,204.941 1009.57,204.944 1009.58,204.946 1009.59,204.949 1009.6,204.952 1009.61,204.954 1009.62,204.957 1009.63,204.96 1009.64,204.963 1009.65,204.965 1009.66,204.968 1009.66,204.971 1009.67,204.973 1009.68,204.976 1009.69,204.979 1009.7,204.981 1009.71,204.984 1009.72,204.987 1009.73,204.989 1009.74,204.992 1009.75,204.995 1009.76,204.998 1009.77,205 1009.77,205.003 1009.78,205.006 1009.79,205.008 1009.8,205.011 1009.81,205.014 1009.82,205.016 1009.83,205.019 1009.84,205.022 1009.85,205.024 1009.86,205.027 1009.87,205.03 1009.88,205.033 1009.88,205.035 1009.89,205.038 1009.9,205.041 1009.91,205.043 1009.92,205.046 1009.93,205.049 1009.94,205.051 1009.95,205.054 1009.96,205.057 1009.97,205.059 1009.98,205.062 1009.99,205.065 1010,205.068 1010,205.07 1010.01,205.073 1010.02,205.076 1010.03,205.078 1010.04,205.081 1010.05,205.084 1010.06,205.086 1010.07,205.089 1010.08,205.092 1010.09,205.095 1010.1,205.097 1010.11,205.1 1010.11,205.103 1010.12,205.105 1010.13,205.108 1010.14,205.111 1010.15,205.113 1010.16,205.116 1010.17,205.119 1010.18,205.121 1010.19,205.124 1010.2,205.127 1010.21,205.13 1010.22,205.132 1010.22,205.135 1010.23,205.138 1010.24,205.14 1010.25,205.143 1010.26,205.146 1010.27,205.148 1010.28,205.151 1010.29,205.154 1010.3,205.156 1010.31,205.159 1010.32,205.162 1010.33,205.165 1010.34,205.167 1010.34,205.17 1010.35,205.173 1010.36,205.175 1010.37,205.178 1010.38,205.181 1010.39,205.183 1010.4,205.186 1010.41,205.189 1010.42,205.191 1010.43,205.194 1010.44,205.197 1010.45,205.2 1010.45,205.202 1010.46,205.205 1010.47,205.208 1010.48,205.21 1010.49,205.213 1010.5,205.216 1010.51,205.218 1010.52,205.221 1010.53,205.224 1010.54,205.226 1010.55,205.229 1010.56,205.232 1010.56,205.235 1010.57,205.237 1010.58,205.24 1010.59,205.243 1010.6,205.245 1010.61,205.248 1010.62,205.251 1010.63,205.253 1010.64,205.256 1010.65,205.259 1010.66,205.261 1010.67,205.264 1010.68,205.267 1010.68,205.27 1010.69,205.272 1010.7,205.275 1010.71,205.278 1010.72,205.28 1010.73,205.283 1010.74,205.286 1010.75,205.288 1010.76,205.291 1010.77,205.294 1010.78,205.296 1010.79,205.299 1010.79,205.302 1010.8,205.304 1010.81,205.307 1010.82,205.31 1010.83,205.313 1010.84,205.315 1010.85,205.318 1010.86,205.321 1010.87,205.323 1010.88,205.326 1010.89,205.329 1010.9,205.331 1010.9,205.334 1010.91,205.337 1010.92,205.339 1010.93,205.342 1010.94,205.345 1010.95,205.348 1010.96,205.35 1010.97,205.353 1010.98,205.356 1010.99,205.358 1011,205.361 1011.01,205.364 1011.02,205.366 1011.02,205.369 1011.03,205.372 1011.04,205.374 1011.05,205.377 1011.06,205.38 1011.07,205.383 1011.08,205.385 1011.09,205.388 1011.1,205.391 1011.11,205.393 1011.12,205.396 1011.13,205.399 1011.13,205.401 1011.14,205.404 1011.15,205.407 1011.16,205.409 1011.17,205.412 1011.18,205.415 1011.19,205.418 1011.2,205.42 1011.21,205.423 1011.22,205.426 1011.23,205.428 1011.24,205.431 1011.24,205.434 1011.25,205.436 1011.26,205.439 1011.27,205.442 1011.28,205.444 1011.29,205.447 1011.3,205.45 1011.31,205.453 1011.32,205.455 1011.33,205.458 1011.34,205.461 1011.35,205.463 1011.36,205.466 1011.36,205.469 1011.37,205.471 1011.38,205.474 1011.39,205.477 1011.4,205.479 1011.41,205.482 1011.42,205.485 1011.43,205.487 1011.44,205.49 1011.45,205.493 1011.46,205.496 1011.47,205.498 1011.47,205.501 1011.48,205.504 1011.49,205.506 1011.5,205.509 1011.51,205.512 1011.52,205.514 1011.53,205.517 1011.54,205.52 1011.55,205.522 1011.56,205.525 1011.57,205.528 1011.58,205.531 1011.58,205.533 1011.59,205.536 1011.6,205.539 1011.61,205.541 1011.62,205.544 1011.63,205.547 1011.64,205.549 1011.65,205.552 1011.66,205.555 1011.67,205.557 1011.68,205.56 1011.69,205.563 1011.7,205.565 1011.7,205.568 1011.71,205.571 1011.72,205.574 1011.73,205.576 1011.74,205.579 1011.75,205.582 1011.76,205.584 1011.77,205.587 1011.78,205.59 1011.79,205.592 1011.8,205.595 1011.81,205.598 1011.81,205.6 1011.82,205.603 1011.83,205.606 1011.84,205.609 1011.85,205.611 1011.86,205.614 1011.87,205.617 1011.88,205.619 1011.89,205.622 1011.9,205.625 1011.91,205.627 1011.92,205.63 1011.92,205.633 1011.93,205.635 1011.94,205.638 1011.95,205.641 1011.96,205.643 1011.97,205.646 1011.98,205.649 1011.99,205.652 1012,205.654 1012.01,205.657 1012.02,205.66 1012.03,205.662 1012.04,205.665 1012.04,205.668 1012.05,205.67 1012.06,205.673 1012.07,205.676 1012.08,205.678 1012.09,205.681 1012.1,205.684 1012.11,205.687 1012.12,205.689 1012.13,205.692 1012.14,205.695 1012.15,205.697 1012.15,205.7 1012.16,205.703 1012.17,205.705 1012.18,205.708 1012.19,205.711 1012.2,205.713 1012.21,205.716 1012.22,205.719 1012.23,205.721 1012.24,205.724 1012.25,205.727 1012.26,205.73 1012.26,205.732 1012.27,205.735 1012.28,205.738 1012.29,205.74 1012.3,205.743 1012.31,205.746 1012.32,205.748 1012.33,205.751 1012.34,205.754 1012.35,205.756 1012.36,205.759 1012.37,205.762 1012.38,205.764 1012.38,205.767 1012.39,205.77 1012.4,205.773 1012.41,205.775 1012.42,205.778 1012.43,205.781 1012.44,205.783 1012.45,205.786 1012.46,205.789 1012.47,205.791 1012.48,205.794 1012.49,205.797 1012.49,205.799 1012.5,205.802 1012.51,205.805 1012.52,205.808 1012.53,205.81 1012.54,205.813 1012.55,205.816 1012.56,205.818 1012.57,205.821 1012.58,205.824 1012.59,205.826 1012.6,205.829 1012.6,205.832 1012.61,205.834 1012.62,205.837 1012.63,205.84 1012.64,205.842 1012.65,205.845 1012.66,205.848 1012.67,205.851 1012.68,205.853 1012.69,205.856 1012.7,205.859 1012.71,205.861 1012.72,205.864 1012.72,205.867 1012.73,205.869 1012.74,205.872 1012.75,205.875 1012.76,205.877 1012.77,205.88 1012.78,205.883 1012.79,205.885 1012.8,205.888 1012.81,205.891 1012.82,205.894 1012.83,205.896 1012.83,205.899 1012.84,205.902 1012.85,205.904 1012.86,205.907 1012.87,205.91 1012.88,205.912 1012.89,205.915 1012.9,205.918 1012.91,205.92 1012.92,205.923 1012.93,205.926 1012.94,205.928 1012.94,205.931 1012.95,205.934 1012.96,205.937 1012.97,205.939 1012.98,205.942 1012.99,205.945 1013,205.947 1013.01,205.95 1013.02,205.953 1013.03,205.955 1013.04,205.958 1013.05,205.961 1013.06,205.963 1013.06,205.966 1013.07,205.969 1013.08,205.971 1013.09,205.974 1013.1,205.977 1013.11,205.98 1013.12,205.982 1013.13,205.985 1013.14,205.988 1013.15,205.99 1013.16,205.993 1013.17,205.996 1013.17,205.998 1013.18,206.001 1013.19,206.004 1013.2,206.006 1013.21,206.009 1013.22,206.012 1013.23,206.014 1013.24,206.017 1013.25,206.02 1013.26,206.022 1013.27,206.025 1013.28,206.028 1013.28,206.031 1013.29,206.033 1013.3,206.036 1013.31,206.039 1013.32,206.041 1013.33,206.044 1013.34,206.047 1013.35,206.049 1013.36,206.052 1013.37,206.055 1013.38,206.057 1013.39,206.06 1013.4,206.063 1013.4,206.065 1013.41,206.068 1013.42,206.071 1013.43,206.074 1013.44,206.076 1013.45,206.079 1013.46,206.082 1013.47,206.084 1013.48,206.087 1013.49,206.09 1013.5,206.092 1013.51,206.095 1013.51,206.098 1013.52,206.1 1013.53,206.103 1013.54,206.106 1013.55,206.108 1013.56,206.111 1013.57,206.114 1013.58,206.117 1013.59,206.119 1013.6,206.122 1013.61,206.125 1013.62,206.127 1013.62,206.13 1013.63,206.133 1013.64,206.135 1013.65,206.138 1013.66,206.141 1013.67,206.143 1013.68,206.146 1013.69,206.149 1013.7,206.151 1013.71,206.154 1013.72,206.157 1013.73,206.159 1013.74,206.162 1013.74,206.165 1013.75,206.168 1013.76,206.17 1013.77,206.173 1013.78,206.176 1013.79,206.178 1013.8,206.181 1013.81,206.184 1013.82,206.186 1013.83,206.189 1013.84,206.192 1013.85,206.194 1013.85,206.197 1013.86,206.2 1013.87,206.202 1013.88,206.205 1013.89,206.208 1013.9,206.211 1013.91,206.213 1013.92,206.216 1013.93,206.219 1013.94,206.221 1013.95,206.224 1013.96,206.227 1013.96,206.229 1013.97,206.232 1013.98,206.235 1013.99,206.237 1014,206.24 1014.01,206.243 1014.02,206.245 1014.03,206.248 1014.04,206.251 1014.05,206.253 1014.06,206.256 1014.07,206.259 1014.08,206.262 1014.08,206.264 1014.09,206.267 1014.1,206.27 1014.11,206.272 1014.12,206.275 1014.13,206.278 1014.14,206.28 1014.15,206.283 1014.16,206.286 1014.17,206.288 1014.18,206.291 1014.19,206.294 1014.19,206.296 1014.2,206.299 1014.21,206.302 1014.22,206.305 1014.23,206.307 1014.24,206.31 1014.25,206.313 1014.26,206.315 1014.27,206.318 1014.28,206.321 1014.29,206.323 1014.3,206.326 1014.3,206.329 1014.31,206.331 1014.32,206.334 1014.33,206.337 1014.34,206.339 1014.35,206.342 1014.36,206.345 1014.37,206.347 1014.38,206.35 1014.39,206.353 1014.4,206.356 1014.41,206.358 1014.42,206.361 1014.42,206.364 1014.43,206.366 1014.44,206.369 1014.45,206.372 1014.46,206.374 1014.47,206.377 1014.48,206.38 1014.49,206.382 1014.5,206.385 1014.51,206.388 1014.52,206.39 1014.53,206.393 1014.53,206.396 1014.54,206.398 1014.55,206.401 1014.56,206.404 1014.57,206.407 1014.58,206.409 1014.59,206.412 1014.6,206.415 1014.61,206.417 1014.62,206.42 1014.63,206.423 1014.64,206.425 1014.64,206.428 1014.65,206.431 1014.66,206.433 1014.67,206.436 1014.68,206.439 1014.69,206.441 1014.7,206.444 1014.71,206.447 1014.72,206.449 1014.73,206.452 1014.74,206.455 1014.75,206.458 1014.76,206.46 1014.76,206.463 1014.77,206.466 1014.78,206.468 1014.79,206.471 1014.8,206.474 1014.81,206.476 1014.82,206.479 1014.83,206.482 1014.84,206.484 1014.85,206.487 1014.86,206.49 1014.87,206.492 1014.87,206.495 1014.88,206.498 1014.89,206.5 1014.9,206.503 1014.91,206.506 1014.92,206.509 1014.93,206.511 1014.94,206.514 1014.95,206.517 1014.96,206.519 1014.97,206.522 1014.98,206.525 1014.98,206.527 1014.99,206.53 1015,206.533 1015.01,206.535 1015.02,206.538 1015.03,206.541 1015.04,206.543 1015.05,206.546 1015.06,206.549 1015.07,206.551 1015.08,206.554 1015.09,206.557 1015.1,206.559 1015.1,206.562 1015.11,206.565 1015.12,206.568 1015.13,206.57 1015.14,206.573 1015.15,206.576 1015.16,206.578 1015.17,206.581 1015.18,206.584 1015.19,206.586 1015.2,206.589 1015.21,206.592 1015.21,206.594 1015.22,206.597 1015.23,206.6 1015.24,206.602 1015.25,206.605 1015.26,206.608 1015.27,206.61 1015.28,206.613 1015.29,206.616 1015.3,206.619 1015.31,206.621 1015.32,206.624 1015.32,206.627 1015.33,206.629 1015.34,206.632 1015.35,206.635 1015.36,206.637 1015.37,206.64 1015.38,206.643 1015.39,206.645 1015.4,206.648 1015.41,206.651 1015.42,206.653 1015.43,206.656 1015.44,206.659 1015.44,206.661 1015.45,206.664 1015.46,206.667 1015.47,206.669 1015.48,206.672 1015.49,206.675 1015.5,206.678 1015.51,206.68 1015.52,206.683 1015.53,206.686 1015.54,206.688 1015.55,206.691 1015.55,206.694 1015.56,206.696 1015.57,206.699 1015.58,206.702 1015.59,206.704 1015.6,206.707 1015.61,206.71 1015.62,206.712 1015.63,206.715 1015.64,206.718 1015.65,206.72 1015.66,206.723 1015.66,206.726 1015.67,206.728 1015.68,206.731 1015.69,206.734 1015.7,206.737 1015.71,206.739 1015.72,206.742 1015.73,206.745 1015.74,206.747 1015.75,206.75 1015.76,206.753 1015.77,206.755 1015.78,206.758 1015.78,206.761 1015.79,206.763 1015.8,206.766 1015.81,206.769 1015.82,206.771 1015.83,206.774 1015.84,206.777 1015.85,206.779 1015.86,206.782 1015.87,206.785 1015.88,206.787 1015.89,206.79 1015.89,206.793 1015.9,206.796 1015.91,206.798 1015.92,206.801 1015.93,206.804 1015.94,206.806 1015.95,206.809 1015.96,206.812 1015.97,206.814 1015.98,206.817 1015.99,206.82 1016,206.822 1016,206.825 1016.01,206.828 1016.02,206.83 1016.03,206.833 1016.04,206.836 1016.05,206.838 1016.06,206.841 1016.07,206.844 1016.08,206.846 1016.09,206.849 1016.1,206.852 1016.11,206.855 1016.12,206.857 1016.12,206.86 1016.13,206.863 1016.14,206.865 1016.15,206.868 1016.16,206.871 1016.17,206.873 1016.18,206.876 1016.19,206.879 1016.2,206.881 1016.21,206.884 1016.22,206.887 1016.23,206.889 1016.23,206.892 1016.24,206.895 1016.25,206.897 1016.26,206.9 1016.27,206.903 1016.28,206.905 1016.29,206.908 1016.3,206.911 1016.31,206.914 1016.32,206.916 1016.33,206.919 1016.34,206.922 1016.34,206.924 1016.35,206.927 1016.36,206.93 1016.37,206.932 1016.38,206.935 1016.39,206.938 1016.4,206.94 1016.41,206.943 1016.42,206.946 1016.43,206.948 1016.44,206.951 1016.45,206.954 1016.46,206.956 1016.46,206.959 1016.47,206.962 1016.48,206.964 1016.49,206.967 1016.5,206.97 1016.51,206.972 1016.52,206.975 1016.53,206.978 1016.54,206.981 1016.55,206.983 1016.56,206.986 1016.57,206.989 1016.57,206.991 1016.58,206.994 1016.59,206.997 1016.6,206.999 1016.61,207.002 1016.62,207.005 1016.63,207.007 1016.64,207.01 1016.65,207.013 1016.66,207.015 1016.67,207.018 1016.68,207.021 1016.68,207.023 1016.69,207.026 1016.7,207.029 1016.71,207.031 1016.72,207.034 1016.73,207.037 1016.74,207.039 1016.75,207.042 1016.76,207.045 1016.77,207.048 1016.78,207.05 1016.79,207.053 1016.8,207.056 1016.8,207.058 1016.81,207.061 1016.82,207.064 1016.83,207.066 1016.84,207.069 1016.85,207.072 1016.86,207.074 1016.87,207.077 1016.88,207.08 1016.89,207.082 1016.9,207.085 1016.91,207.088 1016.91,207.09 1016.92,207.093 1016.93,207.096 1016.94,207.098 1016.95,207.101 1016.96,207.104 1016.97,207.106 1016.98,207.109 1016.99,207.112 1017,207.115 1017.01,207.117 1017.02,207.12 1017.02,207.123 1017.03,207.125 1017.04,207.128 1017.05,207.131 1017.06,207.133 1017.07,207.136 1017.08,207.139 1017.09,207.141 1017.1,207.144 1017.11,207.147 1017.12,207.149 1017.13,207.152 1017.14,207.155 1017.14,207.157 1017.15,207.16 1017.16,207.163 1017.17,207.165 1017.18,207.168 1017.19,207.171 1017.2,207.173 1017.21,207.176 1017.22,207.179 1017.23,207.181 1017.24,207.184 1017.25,207.187 1017.25,207.19 1017.26,207.192 1017.27,207.195 1017.28,207.198 1017.29,207.2 1017.3,207.203 1017.31,207.206 1017.32,207.208 1017.33,207.211 1017.34,207.214 1017.35,207.216 1017.36,207.219 1017.36,207.222 1017.37,207.224 1017.38,207.227 1017.39,207.23 1017.4,207.232 1017.41,207.235 1017.42,207.238 1017.43,207.24 1017.44,207.243 1017.45,207.246 1017.46,207.248 1017.47,207.251 1017.48,207.254 1017.48,207.256 1017.49,207.259 1017.5,207.262 1017.51,207.265 1017.52,207.267 1017.53,207.27 1017.54,207.273 1017.55,207.275 1017.56,207.278 1017.57,207.281 1017.58,207.283 1017.59,207.286 1017.59,207.289 1017.6,207.291 1017.61,207.294 1017.62,207.297 1017.63,207.299 1017.64,207.302 1017.65,207.305 1017.66,207.307 1017.67,207.31 1017.68,207.313 1017.69,207.315 1017.7,207.318 1017.7,207.321 1017.71,207.323 1017.72,207.326 1017.73,207.329 1017.74,207.331 1017.75,207.334 1017.76,207.337 1017.77,207.34 1017.78,207.342 1017.79,207.345 1017.8,207.348 1017.81,207.35 1017.82,207.353 1017.82,207.356 1017.83,207.358 1017.84,207.361 1017.85,207.364 1017.86,207.366 1017.87,207.369 1017.88,207.372 1017.89,207.374 1017.9,207.377 1017.91,207.38 1017.92,207.382 1017.93,207.385 1017.93,207.388 1017.94,207.39 1017.95,207.393 1017.96,207.396 1017.97,207.398 1017.98,207.401 1017.99,207.404 1018,207.406 1018.01,207.409 1018.02,207.412 1018.03,207.414 1018.04,207.417 1018.04,207.42 1018.05,207.423 1018.06,207.425 1018.07,207.428 1018.08,207.431 1018.09,207.433 1018.1,207.436 1018.11,207.439 1018.12,207.441 1018.13,207.444 1018.14,207.447 1018.15,207.449 1018.16,207.452 1018.16,207.455 1018.17,207.457 1018.18,207.46 1018.19,207.463 1018.2,207.465 1018.21,207.468 1018.22,207.471 1018.23,207.473 1018.24,207.476 1018.25,207.479 1018.26,207.481 1018.27,207.484 1018.27,207.487 1018.28,207.489 1018.29,207.492 1018.3,207.495 1018.31,207.497 1018.32,207.5 1018.33,207.503 1018.34,207.506 1018.35,207.508 1018.36,207.511 1018.37,207.514 1018.38,207.516 1018.38,207.519 1018.39,207.522 1018.4,207.524 1018.41,207.527 1018.42,207.53 1018.43,207.532 1018.44,207.535 1018.45,207.538 1018.46,207.54 1018.47,207.543 1018.48,207.546 1018.49,207.548 1018.5,207.551 1018.5,207.554 1018.51,207.556 1018.52,207.559 1018.53,207.562 1018.54,207.564 1018.55,207.567 1018.56,207.57 1018.57,207.572 1018.58,207.575 1018.59,207.578 1018.6,207.58 1018.61,207.583 1018.61,207.586 1018.62,207.588 1018.63,207.591 1018.64,207.594 1018.65,207.597 1018.66,207.599 1018.67,207.602 1018.68,207.605 1018.69,207.607 1018.7,207.61 1018.71,207.613 1018.72,207.615 1018.72,207.618 1018.73,207.621 1018.74,207.623 1018.75,207.626 1018.76,207.629 1018.77,207.631 1018.78,207.634 1018.79,207.637 1018.8,207.639 1018.81,207.642 1018.82,207.645 1018.83,207.647 1018.84,207.65 1018.84,207.653 1018.85,207.655 1018.86,207.658 1018.87,207.661 1018.88,207.663 1018.89,207.666 1018.9,207.669 1018.91,207.671 1018.92,207.674 1018.93,207.677 1018.94,207.679 1018.95,207.682 1018.95,207.685 1018.96,207.687 1018.97,207.69 1018.98,207.693 1018.99,207.696 1019,207.698 1019.01,207.701 1019.02,207.704 1019.03,207.706 1019.04,207.709 1019.05,207.712 1019.06,207.714 1019.06,207.717 1019.07,207.72 1019.08,207.722 1019.09,207.725 1019.1,207.728 1019.11,207.73 1019.12,207.733 1019.13,207.736 1019.14,207.738 1019.15,207.741 1019.16,207.744 1019.17,207.746 1019.18,207.749 1019.18,207.752 1019.19,207.754 1019.2,207.757 1019.21,207.76 1019.22,207.762 1019.23,207.765 1019.24,207.768 1019.25,207.77 1019.26,207.773 1019.27,207.776 1019.28,207.778 1019.29,207.781 1019.29,207.784 1019.3,207.786 1019.31,207.789 1019.32,207.792 1019.33,207.794 1019.34,207.797 1019.35,207.8 1019.36,207.803 1019.37,207.805 1019.38,207.808 1019.39,207.811 1019.4,207.813 1019.4,207.816 1019.41,207.819 1019.42,207.821 1019.43,207.824 1019.44,207.827 1019.45,207.829 1019.46,207.832 1019.47,207.835 1019.48,207.837 1019.49,207.84 1019.5,207.843 1019.51,207.845 1019.52,207.848 1019.52,207.851 1019.53,207.853 1019.54,207.856 1019.55,207.859 1019.56,207.861 1019.57,207.864 1019.58,207.867 1019.59,207.869 1019.6,207.872 1019.61,207.875 1019.62,207.877 1019.63,207.88 1019.63,207.883 1019.64,207.885 1019.65,207.888 1019.66,207.891 1019.67,207.893 1019.68,207.896 1019.69,207.899 1019.7,207.901 1019.71,207.904 1019.72,207.907 1019.73,207.91 1019.74,207.912 1019.74,207.915 1019.75,207.918 1019.76,207.92 1019.77,207.923 1019.78,207.926 1019.79,207.928 1019.8,207.931 1019.81,207.934 1019.82,207.936 1019.83,207.939 1019.84,207.942 1019.85,207.944 1019.86,207.947 1019.86,207.95 1019.87,207.952 1019.88,207.955 1019.89,207.958 1019.9,207.96 1019.91,207.963 1019.92,207.966 1019.93,207.968 1019.94,207.971 1019.95,207.974 1019.96,207.976 1019.97,207.979 1019.97,207.982 1019.98,207.984 1019.99,207.987 1020,207.99 1020.01,207.992 1020.02,207.995 1020.03,207.998 1020.04,208 1020.05,208.003 1020.06,208.006 1020.07,208.008 1020.08,208.011 1020.08,208.014 1020.09,208.016 1020.1,208.019 1020.11,208.022 1020.12,208.024 1020.13,208.027 1020.14,208.03 1020.15,208.032 1020.16,208.035 1020.17,208.038 1020.18,208.041 1020.19,208.043 1020.2,208.046 1020.2,208.049 1020.21,208.051 1020.22,208.054 1020.23,208.057 1020.24,208.059 1020.25,208.062 1020.26,208.065 1020.27,208.067 1020.28,208.07 1020.29,208.073 1020.3,208.075 1020.31,208.078 1020.31,208.081 1020.32,208.083 1020.33,208.086 1020.34,208.089 1020.35,208.091 1020.36,208.094 1020.37,208.097 1020.38,208.099 1020.39,208.102 1020.4,208.105 1020.41,208.107 1020.42,208.11 1020.42,208.113 1020.43,208.115 1020.44,208.118 1020.45,208.121 1020.46,208.123 1020.47,208.126 1020.48,208.129 1020.49,208.131 1020.5,208.134 1020.51,208.137 1020.52,208.139 1020.53,208.142 1020.54,208.145 1020.54,208.147 1020.55,208.15 1020.56,208.153 1020.57,208.155 1020.58,208.158 1020.59,208.161 1020.6,208.163 1020.61,208.166 1020.62,208.169 1020.63,208.171 1020.64,208.174 1020.65,208.177 1020.65,208.179 1020.66,208.182 1020.67,208.185 1020.68,208.188 1020.69,208.19 1020.7,208.193 1020.71,208.196 1020.72,208.198 1020.73,208.201 1020.74,208.204 1020.75,208.206 1020.76,208.209 1020.76,208.212 1020.77,208.214 1020.78,208.217 1020.79,208.22 1020.8,208.222 1020.81,208.225 1020.82,208.228 1020.83,208.23 1020.84,208.233 1020.85,208.236 1020.86,208.238 1020.87,208.241 1020.88,208.244 1020.88,208.246 1020.89,208.249 1020.9,208.252 1020.91,208.254 1020.92,208.257 1020.93,208.26 1020.94,208.262 1020.95,208.265 1020.96,208.268 1020.97,208.27 1020.98,208.273 1020.99,208.276 1020.99,208.278 1021,208.281 1021.01,208.284 1021.02,208.286 1021.03,208.289 1021.04,208.292 1021.05,208.294 1021.06,208.297 1021.07,208.3 1021.08,208.302 1021.09,208.305 1021.1,208.308 1021.1,208.31 1021.11,208.313 1021.12,208.316 1021.13,208.318 1021.14,208.321 1021.15,208.324 1021.16,208.326 1021.17,208.329 1021.18,208.332 1021.19,208.334 1021.2,208.337 1021.21,208.34 1021.22,208.342 1021.22,208.345 1021.23,208.348 1021.24,208.35 1021.25,208.353 1021.26,208.356 1021.27,208.358 1021.28,208.361 1021.29,208.364 1021.3,208.367 1021.31,208.369 1021.32,208.372 1021.33,208.375 1021.33,208.377 1021.34,208.38 1021.35,208.383 1021.36,208.385 1021.37,208.388 1021.38,208.391 1021.39,208.393 1021.4,208.396 1021.41,208.399 1021.42,208.401 1021.43,208.404 1021.44,208.407 1021.44,208.409 1021.45,208.412 1021.46,208.415 1021.47,208.417 1021.48,208.42 1021.49,208.423 1021.5,208.425 1021.51,208.428 1021.52,208.431 1021.53,208.433 1021.54,208.436 1021.55,208.439 1021.56,208.441 1021.56,208.444 1021.57,208.447 1021.58,208.449 1021.59,208.452 1021.6,208.455 1021.61,208.457 1021.62,208.46 1021.63,208.463 1021.64,208.465 1021.65,208.468 1021.66,208.471 1021.67,208.473 1021.67,208.476 1021.68,208.479 1021.69,208.481 1021.7,208.484 1021.71,208.487 1021.72,208.489 1021.73,208.492 1021.74,208.495 1021.75,208.497 1021.76,208.5 1021.77,208.503 1021.78,208.505 1021.78,208.508 1021.79,208.511 1021.8,208.513 1021.81,208.516 1021.82,208.519 1021.83,208.521 1021.84,208.524 1021.85,208.527 1021.86,208.529 1021.87,208.532 1021.88,208.535 1021.89,208.537 1021.9,208.54 1021.9,208.543 1021.91,208.545 1021.92,208.548 1021.93,208.551 1021.94,208.553 1021.95,208.556 1021.96,208.559 1021.97,208.561 1021.98,208.564 1021.99,208.567 1022,208.569 1022.01,208.572 1022.01,208.575 1022.02,208.577 1022.03,208.58 1022.04,208.583 1022.05,208.585 1022.06,208.588 1022.07,208.591 1022.08,208.593 1022.09,208.596 1022.1,208.599 1022.11,208.601 1022.12,208.604 1022.12,208.607 1022.13,208.609 1022.14,208.612 1022.15,208.615 1022.16,208.617 1022.17,208.62 1022.18,208.623 1022.19,208.626 1022.2,208.628 1022.21,208.631 1022.22,208.634 1022.23,208.636 1022.24,208.639 1022.24,208.642 1022.25,208.644 1022.26,208.647 1022.27,208.65 1022.28,208.652 1022.29,208.655 1022.3,208.658 1022.31,208.66 1022.32,208.663 1022.33,208.666 1022.34,208.668 1022.35,208.671 1022.35,208.674 1022.36,208.676 1022.37,208.679 1022.38,208.682 1022.39,208.684 1022.4,208.687 1022.41,208.69 1022.42,208.692 1022.43,208.695 1022.44,208.698 1022.45,208.7 1022.46,208.703 1022.46,208.706 1022.47,208.708 1022.48,208.711 1022.49,208.714 1022.5,208.716 1022.51,208.719 1022.52,208.722 1022.53,208.724 1022.54,208.727 1022.55,208.73 1022.56,208.732 1022.57,208.735 1022.58,208.738 1022.58,208.74 1022.59,208.743 1022.6,208.746 1022.61,208.748 1022.62,208.751 1022.63,208.754 1022.64,208.756 1022.65,208.759 1022.66,208.762 1022.67,208.764 1022.68,208.767 1022.69,208.77 1022.69,208.772 1022.7,208.775 1022.71,208.778 1022.72,208.78 1022.73,208.783 1022.74,208.786 1022.75,208.788 1022.76,208.791 1022.77,208.794 1022.78,208.796 1022.79,208.799 1022.8,208.802 1022.8,208.804 1022.81,208.807 1022.82,208.81 1022.83,208.812 1022.84,208.815 1022.85,208.818 1022.86,208.82 1022.87,208.823 1022.88,208.826 1022.89,208.828 1022.9,208.831 1022.91,208.834 1022.92,208.836 1022.92,208.839 1022.93,208.842 1022.94,208.844 1022.95,208.847 1022.96,208.85 1022.97,208.852 1022.98,208.855 1022.99,208.858 1023,208.86 1023.01,208.863 1023.02,208.866 1023.03,208.868 1023.03,208.871 1023.04,208.874 1023.05,208.876 1023.06,208.879 1023.07,208.882 1023.08,208.884 1023.09,208.887 1023.1,208.89 1023.11,208.892 1023.12,208.895 1023.13,208.898 1023.14,208.9 1023.15,208.903 1023.15,208.906 1023.16,208.908 1023.17,208.911 1023.18,208.914 1023.19,208.916 1023.2,208.919 1023.21,208.922 1023.22,208.924 1023.23,208.927 1023.24,208.93 1023.25,208.932 1023.26,208.935 1023.26,208.938 1023.27,208.94 1023.28,208.943 1023.29,208.946 1023.3,208.948 1023.31,208.951 1023.32,208.954 1023.33,208.956 1023.34,208.959 1023.35,208.962 1023.36,208.964 1023.37,208.967 1023.37,208.97 1023.38,208.972 1023.39,208.975 1023.4,208.978 1023.41,208.98 1023.42,208.983 1023.43,208.986 1023.44,208.988 1023.45,208.991 1023.46,208.994 1023.47,208.996 1023.48,208.999 1023.49,209.002 1023.49,209.004 1023.5,209.007 1023.51,209.01 1023.52,209.012 1023.53,209.015 1023.54,209.018 1023.55,209.02 1023.56,209.023 1023.57,209.026 1023.58,209.028 1023.59,209.031 1023.6,209.034 1023.6,209.036 1023.61,209.039 1023.62,209.042 1023.63,209.044 1023.64,209.047 1023.65,209.05 1023.66,209.052 1023.67,209.055 1023.68,209.058 1023.69,209.06 1023.7,209.063 1023.71,209.066 1023.71,209.068 1023.72,209.071 1023.73,209.074 1023.74,209.076 1023.75,209.079 1023.76,209.082 1023.77,209.084 1023.78,209.087 1023.79,209.09 1023.8,209.092 1023.81,209.095 1023.82,209.098 1023.83,209.1 1023.83,209.103 1023.84,209.106 1023.85,209.108 1023.86,209.111 1023.87,209.114 1023.88,209.116 1023.89,209.119 1023.9,209.122 1023.91,209.124 1023.92,209.127 1023.93,209.13 1023.94,209.132 1023.94,209.135 1023.95,209.138 1023.96,209.14 1023.97,209.143 1023.98,209.146 1023.99,209.148 1024,209.151 1024.01,209.154 1024.02,209.156 1024.03,209.159 1024.04,209.162 1024.05,209.164 1024.05,209.167 1024.06,209.17 1024.07,209.172 1024.08,209.175 1024.09,209.178 1024.1,209.18 1024.11,209.183 1024.12,209.186 1024.13,209.188 1024.14,209.191 1024.15,209.194 1024.16,209.196 1024.17,209.199 1024.17,209.202 1024.18,209.204 1024.19,209.207 1024.2,209.21 1024.21,209.212 1024.22,209.215 1024.23,209.218 1024.24,209.22 1024.25,209.223 1024.26,209.226 1024.27,209.228 1024.28,209.231 1024.28,209.234 1024.29,209.236 1024.3,209.239 1024.31,209.242 1024.32,209.244 1024.33,209.247 1024.34,209.25 1024.35,209.252 1024.36,209.255 1024.37,209.258 1024.38,209.26 1024.39,209.263 1024.39,209.266 1024.4,209.268 1024.41,209.271 1024.42,209.274 1024.43,209.276 1024.44,209.279 1024.45,209.282 1024.46,209.284 1024.47,209.287 1024.48,209.29 1024.49,209.292 1024.5,209.295 1024.51,209.298 1024.51,209.3 1024.52,209.303 1024.53,209.306 1024.54,209.308 1024.55,209.311 1024.56,209.314 1024.57,209.316 1024.58,209.319 1024.59,209.322 1024.6,209.324 1024.61,209.327 1024.62,209.33 1024.62,209.332 1024.63,209.335 1024.64,209.338 1024.65,209.34 1024.66,209.343 1024.67,209.346 1024.68,209.348 1024.69,209.351 1024.7,209.354 1024.71,209.356 1024.72,209.359 1024.73,209.362 1024.73,209.364 1024.74,209.367 1024.75,209.37 1024.76,209.372 1024.77,209.375 1024.78,209.378 1024.79,209.38 1024.8,209.383 1024.81,209.386 1024.82,209.388 1024.83,209.391 1024.84,209.394 1024.85,209.396 1024.85,209.399 1024.86,209.401 1024.87,209.404 1024.88,209.407 1024.89,209.409 1024.9,209.412 1024.91,209.415 1024.92,209.417 1024.93,209.42 1024.94,209.423 1024.95,209.425 1024.96,209.428 1024.96,209.431 1024.97,209.433 1024.98,209.436 1024.99,209.439 1025,209.441 1025.01,209.444 1025.02,209.447 1025.03,209.449 1025.04,209.452 1025.05,209.455 1025.06,209.457 1025.07,209.46 1025.07,209.463 1025.08,209.465 1025.09,209.468 1025.1,209.471 1025.11,209.473 1025.12,209.476 1025.13,209.479 1025.14,209.481 1025.15,209.484 1025.16,209.487 1025.17,209.489 1025.18,209.492 1025.19,209.495 1025.19,209.497 1025.2,209.5 1025.21,209.503 1025.22,209.505 1025.23,209.508 1025.24,209.511 1025.25,209.513 1025.26,209.516 1025.27,209.519 1025.28,209.521 1025.29,209.524 1025.3,209.527 1025.3,209.529 1025.31,209.532 1025.32,209.535 1025.33,209.537 1025.34,209.54 1025.35,209.543 1025.36,209.545 1025.37,209.548 1025.38,209.551 1025.39,209.553 1025.4,209.556 1025.41,209.559 1025.41,209.561 1025.42,209.564 1025.43,209.567 1025.44,209.569 1025.45,209.572 1025.46,209.575 1025.47,209.577 1025.48,209.58 1025.49,209.583 1025.5,209.585 1025.51,209.588 1025.52,209.591 1025.53,209.593 1025.53,209.596 1025.54,209.599 1025.55,209.601 1025.56,209.604 1025.57,209.607 1025.58,209.609 1025.59,209.612 1025.6,209.615 1025.61,209.617 1025.62,209.62 1025.63,209.623 1025.64,209.625 1025.64,209.628 1025.65,209.631 1025.66,209.633 1025.67,209.636 1025.68,209.639 1025.69,209.641 1025.7,209.644 1025.71,209.647 1025.72,209.649 1025.73,209.652 1025.74,209.654 1025.75,209.657 1025.75,209.66 1025.76,209.662 1025.77,209.665 1025.78,209.668 1025.79,209.67 1025.8,209.673 1025.81,209.676 1025.82,209.678 1025.83,209.681 1025.84,209.684 1025.85,209.686 1025.86,209.689 1025.87,209.692 1025.87,209.694 1025.88,209.697 1025.89,209.7 1025.9,209.702 1025.91,209.705 1025.92,209.708 1025.93,209.71 1025.94,209.713 1025.95,209.716 1025.96,209.718 1025.97,209.721 1025.98,209.724 1025.98,209.726 1025.99,209.729 1026,209.732 1026.01,209.734 1026.02,209.737 1026.03,209.74 1026.04,209.742 1026.05,209.745 1026.06,209.748 1026.07,209.75 1026.08,209.753 1026.09,209.756 1026.09,209.758 1026.1,209.761 1026.11,209.764 1026.12,209.766 1026.13,209.769 1026.14,209.772 1026.15,209.774 1026.16,209.777 1026.17,209.78 1026.18,209.782 1026.19,209.785 1026.2,209.788 1026.21,209.79 1026.21,209.793 1026.22,209.796 1026.23,209.798 1026.24,209.801 1026.25,209.804 1026.26,209.806 1026.27,209.809 1026.28,209.812 1026.29,209.814 1026.3,209.817 1026.31,209.82 1026.32,209.822 1026.32,209.825 1026.33,209.828 1026.34,209.83 1026.35,209.833 1026.36,209.835 1026.37,209.838 1026.38,209.841 1026.39,209.843 1026.4,209.846 1026.41,209.849 1026.42,209.851 1026.43,209.854 1026.43,209.857 1026.44,209.859 1026.45,209.862 1026.46,209.865 1026.47,209.867 1026.48,209.87 1026.49,209.873 1026.5,209.875 1026.51,209.878 1026.52,209.881 1026.53,209.883 1026.54,209.886 1026.55,209.889 1026.55,209.891 1026.56,209.894 1026.57,209.897 1026.58,209.899 1026.59,209.902 1026.6,209.905 1026.61,209.907 1026.62,209.91 1026.63,209.913 1026.64,209.915 1026.65,209.918 1026.66,209.921 1026.66,209.923 1026.67,209.926 1026.68,209.929 1026.69,209.931 1026.7,209.934 1026.71,209.937 1026.72,209.939 1026.73,209.942 1026.74,209.945 1026.75,209.947 1026.76,209.95 1026.77,209.953 1026.77,209.955 1026.78,209.958 1026.79,209.961 1026.8,209.963 1026.81,209.966 1026.82,209.969 1026.83,209.971 1026.84,209.974 1026.85,209.977 1026.86,209.979 1026.87,209.982 1026.88,209.984 1026.89,209.987 1026.89,209.99 1026.9,209.992 1026.91,209.995 1026.92,209.998 1026.93,210 1026.94,210.003 1026.95,210.006 1026.96,210.008 1026.97,210.011 1026.98,210.014 1026.99,210.016 1027,210.019 1027,210.022 1027.01,210.024 1027.02,210.027 1027.03,210.03 1027.04,210.032 1027.05,210.035 1027.06,210.038 1027.07,210.04 1027.08,210.043 1027.09,210.046 1027.1,210.048 1027.11,210.051 1027.11,210.054 1027.12,210.056 1027.13,210.059 1027.14,210.062 1027.15,210.064 1027.16,210.067 1027.17,210.07 1027.18,210.072 1027.19,210.075 1027.2,210.078 1027.21,210.08 1027.22,210.083 1027.23,210.086 1027.23,210.088 1027.24,210.091 1027.25,210.094 1027.26,210.096 1027.27,210.099 1027.28,210.102 1027.29,210.104 1027.3,210.107 1027.31,210.109 1027.32,210.112 1027.33,210.115 1027.34,210.117 1027.34,210.12 1027.35,210.123 1027.36,210.125 1027.37,210.128 1027.38,210.131 1027.39,210.133 1027.4,210.136 1027.41,210.139 1027.42,210.141 1027.43,210.144 1027.44,210.147 1027.45,210.149 1027.45,210.152 1027.46,210.155 1027.47,210.157 1027.48,210.16 1027.49,210.163 1027.5,210.165 1027.51,210.168 1027.52,210.171 1027.53,210.173 1027.54,210.176 1027.55,210.179 1027.56,210.181 1027.57,210.184 1027.57,210.187 1027.58,210.189 1027.59,210.192 1027.6,210.195 1027.61,210.197 1027.62,210.2 1027.63,210.203 1027.64,210.205 1027.65,210.208 1027.66,210.211 1027.67,210.213 1027.68,210.216 1027.68,210.219 1027.69,210.221 1027.7,210.224 1027.71,210.226 1027.72,210.229 1027.73,210.232 1027.74,210.234 1027.75,210.237 1027.76,210.24 1027.77,210.242 1027.78,210.245 1027.79,210.248 1027.79,210.25 1027.8,210.253 1027.81,210.256 1027.82,210.258 1027.83,210.261 1027.84,210.264 1027.85,210.266 1027.86,210.269 1027.87,210.272 1027.88,210.274 1027.89,210.277 1027.9,210.28 1027.91,210.282 1027.91,210.285 1027.92,210.288 1027.93,210.29 1027.94,210.293 1027.95,210.296 1027.96,210.298 1027.97,210.301 1027.98,210.304 1027.99,210.306 1028,210.309 1028.01,210.312 1028.02,210.314 1028.02,210.317 1028.03,210.32 1028.04,210.322 1028.05,210.325 1028.06,210.327 1028.07,210.33 1028.08,210.333 1028.09,210.335 1028.1,210.338 1028.11,210.341 1028.12,210.343 1028.13,210.346 1028.13,210.349 1028.14,210.351 1028.15,210.354 1028.16,210.357 1028.17,210.359 1028.18,210.362 1028.19,210.365 1028.2,210.367 1028.21,210.37 1028.22,210.373 1028.23,210.375 1028.24,210.378 1028.25,210.381 1028.25,210.383 1028.26,210.386 1028.27,210.389 1028.28,210.391 1028.29,210.394 1028.3,210.397 1028.31,210.399 1028.32,210.402 1028.33,210.405 1028.34,210.407 1028.35,210.41 1028.36,210.413 1028.36,210.415 1028.37,210.418 1028.38,210.42 1028.39,210.423 1028.4,210.426 1028.41,210.428 1028.42,210.431 1028.43,210.434 1028.44,210.436 1028.45,210.439 1028.46,210.442 1028.47,210.444 1028.47,210.447 1028.48,210.45 1028.49,210.452 1028.5,210.455 1028.51,210.458 1028.52,210.46 1028.53,210.463 1028.54,210.466 1028.55,210.468 1028.56,210.471 1028.57,210.474 1028.58,210.476 1028.59,210.479 1028.59,210.482 1028.6,210.484 1028.61,210.487 1028.62,210.49 1028.63,210.492 1028.64,210.495 1028.65,210.498 1028.66,210.5 1028.67,210.503 1028.68,210.506 1028.69,210.508 1028.7,210.511 1028.7,210.513 1028.71,210.516 1028.72,210.519 1028.73,210.521 1028.74,210.524 1028.75,210.527 1028.76,210.529 1028.77,210.532 1028.78,210.535 1028.79,210.537 1028.8,210.54 1028.81,210.543 1028.81,210.545 1028.82,210.548 1028.83,210.551 1028.84,210.553 1028.85,210.556 1028.86,210.559 1028.87,210.561 1028.88,210.564 1028.89,210.567 1028.9,210.569 1028.91,210.572 1028.92,210.575 1028.93,210.577 1028.93,210.58 1028.94,210.583 1028.95,210.585 1028.96,210.588 1028.97,210.591 1028.98,210.593 1028.99,210.596 1029,210.598 1029.01,210.601 1029.02,210.604 1029.03,210.606 1029.04,210.609 1029.04,210.612 1029.05,210.614 1029.06,210.617 1029.07,210.62 1029.08,210.622 1029.09,210.625 1029.1,210.628 1029.11,210.63 1029.12,210.633 1029.13,210.636 1029.14,210.638 1029.15,210.641 1029.15,210.644 1029.16,210.646 1029.17,210.649 1029.18,210.652 1029.19,210.654 1029.2,210.657 1029.21,210.66 1029.22,210.662 1029.23,210.665 1029.24,210.668 1029.25,210.67 1029.26,210.673 1029.27,210.676 1029.27,210.678 1029.28,210.681 1029.29,210.683 1029.3,210.686 1029.31,210.689 1029.32,210.691 1029.33,210.694 1029.34,210.697 1029.35,210.699 1029.36,210.702 1029.37,210.705 1029.38,210.707 1029.38,210.71 1029.39,210.713 1029.4,210.715 1029.41,210.718 1029.42,210.721 1029.43,210.723 1029.44,210.726 1029.45,210.729 1029.46,210.731 1029.47,210.734 1029.48,210.737 1029.49,210.739 1029.49,210.742 1029.5,210.745 1029.51,210.747 1029.52,210.75 1029.53,210.753 1029.54,210.755 1029.55,210.758 1029.56,210.76 1029.57,210.763 1029.58,210.766 1029.59,210.768 1029.6,210.771 1029.61,210.774 1029.61,210.776 1029.62,210.779 1029.63,210.782 1029.64,210.784 1029.65,210.787 1029.66,210.79 1029.67,210.792 1029.68,210.795 1029.69,210.798 1029.7,210.8 1029.71,210.803 1029.72,210.806 1029.72,210.808 1029.73,210.811 1029.74,210.814 1029.75,210.816 1029.76,210.819 1029.77,210.822 1029.78,210.824 1029.79,210.827 1029.8,210.829 1029.81,210.832 1029.82,210.835 1029.83,210.837 1029.83,210.84 1029.84,210.843 1029.85,210.845 1029.86,210.848 1029.87,210.851 1029.88,210.853 1029.89,210.856 1029.9,210.859 1029.91,210.861 1029.92,210.864 1029.93,210.867 1029.94,210.869 1029.95,210.872 1029.95,210.875 1029.96,210.877 1029.97,210.88 1029.98,210.883 1029.99,210.885 1030,210.888 1030.01,210.891 1030.02,210.893 1030.03,210.896 1030.04,210.898 1030.05,210.901 1030.06,210.904 1030.06,210.906 1030.07,210.909 1030.08,210.912 1030.09,210.914 1030.1,210.917 1030.11,210.92 1030.12,210.922 1030.13,210.925 1030.14,210.928 1030.15,210.93 1030.16,210.933 1030.17,210.936 1030.17,210.938 1030.18,210.941 1030.19,210.944 1030.2,210.946 1030.21,210.949 1030.22,210.952 1030.23,210.954 1030.24,210.957 1030.25,210.96 1030.26,210.962 1030.27,210.965 1030.28,210.967 1030.29,210.97 1030.29,210.973 1030.3,210.975 1030.31,210.978 1030.32,210.981 1030.33,210.983 1030.34,210.986 1030.35,210.989 1030.36,210.991 1030.37,210.994 1030.38,210.997 1030.39,210.999 1030.4,211.002 1030.4,211.005 1030.41,211.007 1030.42,211.01 1030.43,211.013 1030.44,211.015 1030.45,211.018 1030.46,211.021 1030.47,211.023 1030.48,211.026 1030.49,211.029 1030.5,211.031 1030.51,211.034 1030.51,211.036 1030.52,211.039 1030.53,211.042 1030.54,211.044 1030.55,211.047 1030.56,211.05 1030.57,211.052 1030.58,211.055 1030.59,211.058 1030.6,211.06 1030.61,211.063 1030.62,211.066 1030.63,211.068 1030.63,211.071 1030.64,211.074 1030.65,211.076 1030.66,211.079 1030.67,211.082 1030.68,211.084 1030.69,211.087 1030.7,211.09 1030.71,211.092 1030.72,211.095 1030.73,211.097 1030.74,211.1 1030.74,211.103 1030.75,211.105 1030.76,211.108 1030.77,211.111 1030.78,211.113 1030.79,211.116 1030.8,211.119 1030.81,211.121 1030.82,211.124 1030.83,211.127 1030.84,211.129 1030.85,211.132 1030.85,211.135 1030.86,211.137 1030.87,211.14 1030.88,211.143 1030.89,211.145 1030.9,211.148 1030.91,211.151 1030.92,211.153 1030.93,211.156 1030.94,211.158 1030.95,211.161 1030.96,211.164 1030.97,211.166 1030.97,211.169 1030.98,211.172 1030.99,211.174 1031,211.177 1031.01,211.18 1031.02,211.182 1031.03,211.185 1031.04,211.188 1031.05,211.19 1031.06,211.193 1031.07,211.196 1031.08,211.198 1031.08,211.201 1031.09,211.204 1031.1,211.206 1031.11,211.209 1031.12,211.212 1031.13,211.214 1031.14,211.217 1031.15,211.219 1031.16,211.222 1031.17,211.225 1031.18,211.227 1031.19,211.23 1031.19,211.233 1031.2,211.235 1031.21,211.238 1031.22,211.241 1031.23,211.243 1031.24,211.246 1031.25,211.249 1031.26,211.251 1031.27,211.254 1031.28,211.257 1031.29,211.259 1031.3,211.262 1031.31,211.265 1031.31,211.267 1031.32,211.27 1031.33,211.273 1031.34,211.275 1031.35,211.278 1031.36,211.28 1031.37,211.283 1031.38,211.286 1031.39,211.288 1031.4,211.291 1031.41,211.294 1031.42,211.296 1031.42,211.299 1031.43,211.302 1031.44,211.304 1031.45,211.307 1031.46,211.31 1031.47,211.312 1031.48,211.315 1031.49,211.318 1031.5,211.32 1031.51,211.323 1031.52,211.326 1031.53,211.328 1031.53,211.331 1031.54,211.333 1031.55,211.336 1031.56,211.339 1031.57,211.341 1031.58,211.344 1031.59,211.347 1031.6,211.349 1031.61,211.352 1031.62,211.355 1031.63,211.357 1031.64,211.36 1031.65,211.363 1031.65,211.365 1031.66,211.368 1031.67,211.371 1031.68,211.373 1031.69,211.376 1031.7,211.379 1031.71,211.381 1031.72,211.384 1031.73,211.387 1031.74,211.389 1031.75,211.392 1031.76,211.394 1031.76,211.397 1031.77,211.4 1031.78,211.402 1031.79,211.405 1031.8,211.408 1031.81,211.41 1031.82,211.413 1031.83,211.416 1031.84,211.418 1031.85,211.421 1031.86,211.424 1031.87,211.426 1031.87,211.429 1031.88,211.432 1031.89,211.434 1031.9,211.437 1031.91,211.44 1031.92,211.442 1031.93,211.445 1031.94,211.447 1031.95,211.45 1031.96,211.453 1031.97,211.455 1031.98,211.458 1031.99,211.461 1031.99,211.463 1032,211.466 1032.01,211.469 1032.02,211.471 1032.03,211.474 1032.04,211.477 1032.05,211.479 1032.06,211.482 1032.07,211.485 1032.08,211.487 1032.09,211.49 1032.1,211.493 1032.1,211.495 1032.11,211.498 1032.12,211.5 1032.13,211.503 1032.14,211.506 1032.15,211.508 1032.16,211.511 1032.17,211.514 1032.18,211.516 1032.19,211.519 1032.2,211.522 1032.21,211.524 1032.21,211.527 1032.22,211.53 1032.23,211.532 1032.24,211.535 1032.25,211.538 1032.26,211.54 1032.27,211.543 1032.28,211.546 1032.29,211.548 1032.3,211.551 1032.31,211.553 1032.32,211.556 1032.33,211.559 1032.33,211.561 1032.34,211.564 1032.35,211.567 1032.36,211.569 1032.37,211.572 1032.38,211.575 1032.39,211.577 1032.4,211.58 1032.41,211.583 1032.42,211.585 1032.43,211.588 1032.44,211.591 1032.44,211.593 1032.45,211.596 1032.46,211.599 1032.47,211.601 1032.48,211.604 1032.49,211.606 1032.5,211.609 1032.51,211.612 1032.52,211.614 1032.53,211.617 1032.54,211.62 1032.55,211.622 1032.55,211.625 1032.56,211.628 1032.57,211.63 1032.58,211.633 1032.59,211.636 1032.6,211.638 1032.61,211.641 1032.62,211.644 1032.63,211.646 1032.64,211.649 1032.65,211.651 1032.66,211.654 1032.67,211.657 1032.67,211.659 1032.68,211.662 1032.69,211.665 1032.7,211.667 1032.71,211.67 1032.72,211.673 1032.73,211.675 1032.74,211.678 1032.75,211.681 1032.76,211.683 1032.77,211.686 1032.78,211.689 1032.78,211.691 1032.79,211.694 1032.8,211.697 1032.81,211.699 1032.82,211.702 1032.83,211.704 1032.84,211.707 1032.85,211.71 1032.86,211.712 1032.87,211.715 1032.88,211.718 1032.89,211.72 1032.89,211.723 1032.9,211.726 1032.91,211.728 1032.92,211.731 1032.93,211.734 1032.94,211.736 1032.95,211.739 1032.96,211.742 1032.97,211.744 1032.98,211.747 1032.99,211.749 1033,211.752 1033.01,211.755 1033.01,211.757 1033.02,211.76 1033.03,211.763 1033.04,211.765 1033.05,211.768 1033.06,211.771 1033.07,211.773 1033.08,211.776 1033.09,211.779 1033.1,211.781 1033.11,211.784 1033.12,211.787 1033.12,211.789 1033.13,211.792 1033.14,211.794 1033.15,211.797 1033.16,211.8 1033.17,211.802 1033.18,211.805 1033.19,211.808 1033.2,211.81 1033.21,211.813 1033.22,211.816 1033.23,211.818 1033.23,211.821 1033.24,211.824 1033.25,211.826 1033.26,211.829 1033.27,211.832 1033.28,211.834 1033.29,211.837 1033.3,211.84 1033.31,211.842 1033.32,211.845 1033.33,211.847 1033.34,211.85 1033.35,211.853 1033.35,211.855 1033.36,211.858 1033.37,211.861 1033.38,211.863 1033.39,211.866 1033.4,211.869 1033.41,211.871 1033.42,211.874 1033.43,211.877 1033.44,211.879 1033.45,211.882 1033.46,211.885 1033.46,211.887 1033.47,211.89 1033.48,211.892 1033.49,211.895 1033.5,211.898 1033.51,211.9 1033.52,211.903 1033.53,211.906 1033.54,211.908 1033.55,211.911 1033.56,211.914 1033.57,211.916 1033.57,211.919 1033.58,211.922 1033.59,211.924 1033.6,211.927 1033.61,211.93 1033.62,211.932 1033.63,211.935 1033.64,211.937 1033.65,211.94 1033.66,211.943 1033.67,211.945 1033.68,211.948 1033.69,211.951 1033.69,211.953 1033.7,211.956 1033.71,211.959 1033.72,211.961 1033.73,211.964 1033.74,211.967 1033.75,211.969 1033.76,211.972 1033.77,211.975 1033.78,211.977 1033.79,211.98 1033.8,211.982 1033.8,211.985 1033.81,211.988 1033.82,211.99 1033.83,211.993 1033.84,211.996 1033.85,211.998 1033.86,212.001 1033.87,212.004 1033.88,212.006 1033.89,212.009 1033.9,212.012 1033.91,212.014 1033.91,212.017 1033.92,212.019 1033.93,212.022 1033.94,212.025 1033.95,212.027 1033.96,212.03 1033.97,212.033 1033.98,212.035 1033.99,212.038 1034,212.041 1034.01,212.043 1034.02,212.046 1034.03,212.049 1034.03,212.051 1034.04,212.054 1034.05,212.057 1034.06,212.059 1034.07,212.062 1034.08,212.064 1034.09,212.067 1034.1,212.07 1034.11,212.072 1034.12,212.075 1034.13,212.078 1034.14,212.08 1034.14,212.083 1034.15,212.086 1034.16,212.088 1034.17,212.091 1034.18,212.094 1034.19,212.096 1034.2,212.099 1034.21,212.102 1034.22,212.104 1034.23,212.107 1034.24,212.109 1034.25,212.112 1034.25,212.115 1034.26,212.117 1034.27,212.12 1034.28,212.123 1034.29,212.125 1034.3,212.128 1034.31,212.131 1034.32,212.133 1034.33,212.136 1034.34,212.139 1034.35,212.141 1034.36,212.144 1034.37,212.146 1034.37,212.149 1034.38,212.152 1034.39,212.154 1034.4,212.157 1034.41,212.16 1034.42,212.162 1034.43,212.165 1034.44,212.168 1034.45,212.17 1034.46,212.173 1034.47,212.176 1034.48,212.178 1034.48,212.181 1034.49,212.184 1034.5,212.186 1034.51,212.189 1034.52,212.191 1034.53,212.194 1034.54,212.197 1034.55,212.199 1034.56,212.202 1034.57,212.205 1034.58,212.207 1034.59,212.21 1034.59,212.213 1034.6,212.215 1034.61,212.218 1034.62,212.221 1034.63,212.223 1034.64,212.226 1034.65,212.228 1034.66,212.231 1034.67,212.234 1034.68,212.236 1034.69,212.239 1034.7,212.242 1034.71,212.244 1034.71,212.247 1034.72,212.25 1034.73,212.252 1034.74,212.255 1034.75,212.258 1034.76,212.26 1034.77,212.263 1034.78,212.266 1034.79,212.268 1034.8,212.271 1034.81,212.273 1034.82,212.276 1034.82,212.279 1034.83,212.281 1034.84,212.284 1034.85,212.287 1034.86,212.289 1034.87,212.292 1034.88,212.295 1034.89,212.297 1034.9,212.3 1034.91,212.303 1034.92,212.305 1034.93,212.308 1034.93,212.31 1034.94,212.313 1034.95,212.316 1034.96,212.318 1034.97,212.321 1034.98,212.324 1034.99,212.326 1035,212.329 1035.01,212.332 1035.02,212.334 1035.03,212.337 1035.04,212.34 1035.05,212.342 1035.05,212.345 1035.06,212.348 1035.07,212.35 1035.08,212.353 1035.09,212.355 1035.1,212.358 1035.11,212.361 1035.12,212.363 1035.13,212.366 1035.14,212.369 1035.15,212.371 1035.16,212.374 1035.16,212.377 1035.17,212.379 1035.18,212.382 1035.19,212.385 1035.2,212.387 1035.21,212.39 1035.22,212.392 1035.23,212.395 1035.24,212.398 1035.25,212.4 1035.26,212.403 1035.27,212.406 1035.27,212.408 1035.28,212.411 1035.29,212.414 1035.3,212.416 1035.31,212.419 1035.32,212.422 1035.33,212.424 1035.34,212.427 1035.35,212.429 1035.36,212.432 1035.37,212.435 1035.38,212.437 1035.39,212.44 1035.39,212.443 1035.4,212.445 1035.41,212.448 1035.42,212.451 1035.43,212.453 1035.44,212.456 1035.45,212.459 1035.46,212.461 1035.47,212.464 1035.48,212.466 1035.49,212.469 1035.5,212.472 1035.5,212.474 1035.51,212.477 1035.52,212.48 1035.53,212.482 1035.54,212.485 1035.55,212.488 1035.56,212.49 1035.57,212.493 1035.58,212.496 1035.59,212.498 1035.6,212.501 1035.61,212.503 1035.61,212.506 1035.62,212.509 1035.63,212.511 1035.64,212.514 1035.65,212.517 1035.66,212.519 1035.67,212.522 1035.68,212.525 1035.69,212.527 1035.7,212.53 1035.71,212.533 1035.72,212.535 1035.73,212.538 1035.73,212.54 1035.74,212.543 1035.75,212.546 1035.76,212.548 1035.77,212.551 1035.78,212.554 1035.79,212.556 1035.8,212.559 1035.81,212.562 1035.82,212.564 1035.83,212.567 1035.84,212.57 1035.84,212.572 1035.85,212.575 1035.86,212.577 1035.87,212.58 1035.88,212.583 1035.89,212.585 1035.9,212.588 1035.91,212.591 1035.92,212.593 1035.93,212.596 1035.94,212.599 1035.95,212.601 1035.95,212.604 1035.96,212.607 1035.97,212.609 1035.98,212.612 1035.99,212.614 1036,212.617 1036.01,212.62 1036.02,212.622 1036.03,212.625 1036.04,212.628 1036.05,212.63 1036.06,212.633 1036.07,212.636 1036.07,212.638 1036.08,212.641 1036.09,212.644 1036.1,212.646 1036.11,212.649 1036.12,212.651 1036.13,212.654 1036.14,212.657 1036.15,212.659 1036.16,212.662 1036.17,212.665 1036.18,212.667 1036.18,212.67 1036.19,212.673 1036.2,212.675 1036.21,212.678 1036.22,212.681 1036.23,212.683 1036.24,212.686 1036.25,212.688 1036.26,212.691 1036.27,212.694 1036.28,212.696 1036.29,212.699 1036.29,212.702 1036.3,212.704 1036.31,212.707 1036.32,212.71 1036.33,212.712 1036.34,212.715 1036.35,212.718 1036.36,212.72 1036.37,212.723 1036.38,212.725 1036.39,212.728 1036.4,212.731 1036.41,212.733 1036.41,212.736 1036.42,212.739 1036.43,212.741 1036.44,212.744 1036.45,212.747 1036.46,212.749 1036.47,212.752 1036.48,212.754 1036.49,212.757 1036.5,212.76 1036.51,212.762 1036.52,212.765 1036.52,212.768 1036.53,212.77 1036.54,212.773 1036.55,212.776 1036.56,212.778 1036.57,212.781 1036.58,212.784 1036.59,212.786 1036.6,212.789 1036.61,212.791 1036.62,212.794 1036.63,212.797 1036.63,212.799 1036.64,212.802 1036.65,212.805 1036.66,212.807 1036.67,212.81 1036.68,212.813 1036.69,212.815 1036.7,212.818 1036.71,212.821 1036.72,212.823 1036.73,212.826 1036.74,212.828 1036.75,212.831 1036.75,212.834 1036.76,212.836 1036.77,212.839 1036.78,212.842 1036.79,212.844 1036.8,212.847 1036.81,212.85 1036.82,212.852 1036.83,212.855 1036.84,212.857 1036.85,212.86 1036.86,212.863 1036.86,212.865 1036.87,212.868 1036.88,212.871 1036.89,212.873 1036.9,212.876 1036.91,212.879 1036.92,212.881 1036.93,212.884 1036.94,212.887 1036.95,212.889 1036.96,212.892 1036.97,212.894 1036.97,212.897 1036.98,212.9 1036.99,212.902 1037,212.905 1037.01,212.908 1037.02,212.91 1037.03,212.913 1037.04,212.916 1037.05,212.918 1037.06,212.921 1037.07,212.923 1037.08,212.926 1037.09,212.929 1037.09,212.931 1037.1,212.934 1037.11,212.937 1037.12,212.939 1037.13,212.942 1037.14,212.945 1037.15,212.947 1037.16,212.95 1037.17,212.953 1037.18,212.955 1037.19,212.958 1037.2,212.96 1037.2,212.963 1037.21,212.966 1037.22,212.968 1037.23,212.971 1037.24,212.974 1037.25,212.976 1037.26,212.979 1037.27,212.982 1037.28,212.984 1037.29,212.987 1037.3,212.989 1037.31,212.992 1037.31,212.995 1037.32,212.997 1037.33,213 1037.34,213.003 1037.35,213.005 1037.36,213.008 1037.37,213.011 1037.38,213.013 1037.39,213.016 1037.4,213.019 1037.41,213.021 1037.42,213.024 1037.43,213.026 1037.43,213.029 1037.44,213.032 1037.45,213.034 1037.46,213.037 1037.47,213.04 1037.48,213.042 1037.49,213.045 1037.5,213.048 1037.51,213.05 1037.52,213.053 1037.53,213.055 1037.54,213.058 1037.54,213.061 1037.55,213.063 1037.56,213.066 1037.57,213.069 1037.58,213.071 1037.59,213.074 1037.6,213.077 1037.61,213.079 1037.62,213.082 1037.63,213.085 1037.64,213.087 1037.65,213.09 1037.65,213.092 1037.66,213.095 1037.67,213.098 1037.68,213.1 1037.69,213.103 1037.7,213.106 1037.71,213.108 1037.72,213.111 1037.73,213.114 1037.74,213.116 1037.75,213.119 1037.76,213.121 1037.77,213.124 1037.77,213.127 1037.78,213.129 1037.79,213.132 1037.8,213.135 1037.81,213.137 1037.82,213.14 1037.83,213.143 1037.84,213.145 1037.85,213.148 1037.86,213.15 1037.87,213.153 1037.88,213.156 1037.88,213.158 1037.89,213.161 1037.9,213.164 1037.91,213.166 1037.92,213.169 1037.93,213.172 1037.94,213.174 1037.95,213.177 1037.96,213.18 1037.97,213.182 1037.98,213.185 1037.99,213.187 1037.99,213.19 1038,213.193 1038.01,213.195 1038.02,213.198 1038.03,213.201 1038.04,213.203 1038.05,213.206 1038.06,213.209 1038.07,213.211 1038.08,213.214 1038.09,213.216 1038.1,213.219 1038.11,213.222 1038.11,213.224 1038.12,213.227 1038.13,213.23 1038.14,213.232 1038.15,213.235 1038.16,213.238 1038.17,213.24 1038.18,213.243 1038.19,213.245 1038.2,213.248 1038.21,213.251 1038.22,213.253 1038.22,213.256 1038.23,213.259 1038.24,213.261 1038.25,213.264 1038.26,213.267 1038.27,213.269 1038.28,213.272 1038.29,213.274 1038.3,213.277 1038.31,213.28 1038.32,213.282 1038.33,213.285 1038.33,213.288 1038.34,213.29 1038.35,213.293 1038.36,213.296 1038.37,213.298 1038.38,213.301 1038.39,213.303 1038.4,213.306 1038.41,213.309 1038.42,213.311 1038.43,213.314 1038.44,213.317 1038.45,213.319 1038.45,213.322 1038.46,213.325 1038.47,213.327 1038.48,213.33 1038.49,213.333 1038.5,213.335 1038.51,213.338 1038.52,213.34 1038.53,213.343 1038.54,213.346 1038.55,213.348 1038.56,213.351 1038.56,213.354 1038.57,213.356 1038.58,213.359 1038.59,213.362 1038.6,213.364 1038.61,213.367 1038.62,213.369 1038.63,213.372 1038.64,213.375 1038.65,213.377 1038.66,213.38 1038.67,213.383 1038.67,213.385 1038.68,213.388 1038.69,213.391 1038.7,213.393 1038.71,213.396 1038.72,213.398 1038.73,213.401 1038.74,213.404 1038.75,213.406 1038.76,213.409 1038.77,213.412 1038.78,213.414 1038.79,213.417 1038.79,213.42 1038.8,213.422 1038.81,213.425 1038.82,213.427 1038.83,213.43 1038.84,213.433 1038.85,213.435 1038.86,213.438 1038.87,213.441 1038.88,213.443 1038.89,213.446 1038.9,213.449 1038.9,213.451 1038.91,213.454 1038.92,213.456 1038.93,213.459 1038.94,213.462 1038.95,213.464 1038.96,213.467 1038.97,213.47 1038.98,213.472 1038.99,213.475 1039,213.478 1039.01,213.48 1039.01,213.483 1039.02,213.485 1039.03,213.488 1039.04,213.491 1039.05,213.493 1039.06,213.496 1039.07,213.499 1039.08,213.501 1039.09,213.504 1039.1,213.507 1039.11,213.509 1039.12,213.512 1039.13,213.514 1039.13,213.517 1039.14,213.52 1039.15,213.522 1039.16,213.525 1039.17,213.528 1039.18,213.53 1039.19,213.533 1039.2,213.536 1039.21,213.538 1039.22,213.541 1039.23,213.543 1039.24,213.546 1039.24,213.549 1039.25,213.551 1039.26,213.554 1039.27,213.557 1039.28,213.559 1039.29,213.562 1039.3,213.565 1039.31,213.567 1039.32,213.57 1039.33,213.572 1039.34,213.575 1039.35,213.578 1039.35,213.58 1039.36,213.583 1039.37,213.586 1039.38,213.588 1039.39,213.591 1039.4,213.594 1039.41,213.596 1039.42,213.599 1039.43,213.601 1039.44,213.604 1039.45,213.607 1039.46,213.609 1039.47,213.612 1039.47,213.615 1039.48,213.617 1039.49,213.62 1039.5,213.623 1039.51,213.625 1039.52,213.628 1039.53,213.63 1039.54,213.633 1039.55,213.636 1039.56,213.638 1039.57,213.641 1039.58,213.644 1039.58,213.646 1039.59,213.649 1039.6,213.652 1039.61,213.654 1039.62,213.657 1039.63,213.659 1039.64,213.662 1039.65,213.665 1039.66,213.667 1039.67,213.67 1039.68,213.673 1039.69,213.675 1039.69,213.678 1039.7,213.68 1039.71,213.683 1039.72,213.686 1039.73,213.688 1039.74,213.691 1039.75,213.694 1039.76,213.696 1039.77,213.699 1039.78,213.702 1039.79,213.704 1039.8,213.707 1039.81,213.709 1039.81,213.712 1039.82,213.715 1039.83,213.717 1039.84,213.72 1039.85,213.723 1039.86,213.725 1039.87,213.728 1039.88,213.731 1039.89,213.733 1039.9,213.736 1039.91,213.738 1039.92,213.741 1039.92,213.744 1039.93,213.746 1039.94,213.749 1039.95,213.752 1039.96,213.754 1039.97,213.757 1039.98,213.76 1039.99,213.762 1040,213.765 1040.01,213.767 1040.02,213.77 1040.03,213.773 1040.03,213.775 1040.04,213.778 1040.05,213.781 1040.06,213.783 1040.07,213.786 1040.08,213.789 1040.09,213.791 1040.1,213.794 1040.11,213.796 1040.12,213.799 1040.13,213.802 1040.14,213.804 1040.15,213.807 1040.15,213.81 1040.16,213.812 1040.17,213.815 1040.18,213.817 1040.19,213.82 1040.2,213.823 1040.21,213.825 1040.22,213.828 1040.23,213.831 1040.24,213.833 1040.25,213.836 1040.26,213.839 1040.26,213.841 1040.27,213.844 1040.28,213.846 1040.29,213.849 1040.3,213.852 1040.31,213.854 1040.32,213.857 1040.33,213.86 1040.34,213.862 1040.35,213.865 1040.36,213.868 1040.37,213.87 1040.37,213.873 1040.38,213.875 1040.39,213.878 1040.4,213.881 1040.41,213.883 1040.42,213.886 1040.43,213.889 1040.44,213.891 1040.45,213.894 1040.46,213.897 1040.47,213.899 1040.48,213.902 1040.49,213.904 1040.49,213.907 1040.5,213.91 1040.51,213.912 1040.52,213.915 1040.53,213.918 1040.54,213.92 1040.55,213.923 1040.56,213.925 1040.57,213.928 1040.58,213.931 1040.59,213.933 1040.6,213.936 1040.6,213.939 1040.61,213.941 1040.62,213.944 1040.63,213.947 1040.64,213.949 1040.65,213.952 1040.66,213.954 1040.67,213.957 1040.68,213.96 1040.69,213.962 1040.7,213.965 1040.71,213.968 1040.71,213.97 1040.72,213.973 1040.73,213.976 1040.74,213.978 1040.75,213.981 1040.76,213.983 1040.77,213.986 1040.78,213.989 1040.79,213.991 1040.8,213.994 1040.81,213.997 1040.82,213.999 1040.83,214.002 1040.83,214.004 1040.84,214.007 1040.85,214.01 1040.86,214.012 1040.87,214.015 1040.88,214.018 1040.89,214.02 1040.9,214.023 1040.91,214.026 1040.92,214.028 1040.93,214.031 1040.94,214.033 1040.94,214.036 1040.95,214.039 1040.96,214.041 1040.97,214.044 1040.98,214.047 1040.99,214.049 1041,214.052 1041.01,214.054 1041.02,214.057 1041.03,214.06 1041.04,214.062 1041.05,214.065 1041.05,214.068 1041.06,214.07 1041.07,214.073 1041.08,214.076 1041.09,214.078 1041.1,214.081 1041.11,214.083 1041.12,214.086 1041.13,214.089 1041.14,214.091 1041.15,214.094 1041.16,214.097 1041.17,214.099 1041.17,214.102 1041.18,214.105 1041.19,214.107 1041.2,214.11 1041.21,214.112 1041.22,214.115 1041.23,214.118 1041.24,214.12 1041.25,214.123 1041.26,214.126 1041.27,214.128 1041.28,214.131 1041.28,214.133 1041.29,214.136 1041.3,214.139 1041.31,214.141 1041.32,214.144 1041.33,214.147 1041.34,214.149 1041.35,214.152 1041.36,214.155 1041.37,214.157 1041.38,214.16 1041.39,214.162 1041.39,214.165 1041.4,214.168 1041.41,214.17 1041.42,214.173 1041.43,214.176 1041.44,214.178 1041.45,214.181 1041.46,214.183 1041.47,214.186 1041.48,214.189 1041.49,214.191 1041.5,214.194 1041.51,214.197 1041.51,214.199 1041.52,214.202 1041.53,214.205 1041.54,214.207 1041.55,214.21 1041.56,214.212 1041.57,214.215 1041.58,214.218 1041.59,214.22 1041.6,214.223 1041.61,214.226 1041.62,214.228 1041.62,214.231 1041.63,214.233 1041.64,214.236 1041.65,214.239 1041.66,214.241 1041.67,214.244 1041.68,214.247 1041.69,214.249 1041.7,214.252 1041.71,214.255 1041.72,214.257 1041.73,214.26 1041.73,214.262 1041.74,214.265 1041.75,214.268 1041.76,214.27 1041.77,214.273 1041.78,214.276 1041.79,214.278 1041.8,214.281 1041.81,214.283 1041.82,214.286 1041.83,214.289 1041.84,214.291 1041.85,214.294 1041.85,214.297 1041.86,214.299 1041.87,214.302 1041.88,214.305 1041.89,214.307 1041.9,214.31 1041.91,214.312 1041.92,214.315 1041.93,214.318 1041.94,214.32 1041.95,214.323 1041.96,214.326 1041.96,214.328 1041.97,214.331 1041.98,214.333 1041.99,214.336 1042,214.339 1042.01,214.341 1042.02,214.344 1042.03,214.347 1042.04,214.349 1042.05,214.352 1042.06,214.354 1042.07,214.357 1042.07,214.36 1042.08,214.362 1042.09,214.365 1042.1,214.368 1042.11,214.37 1042.12,214.373 1042.13,214.376 1042.14,214.378 1042.15,214.381 1042.16,214.383 1042.17,214.386 1042.18,214.389 1042.19,214.391 1042.19,214.394 1042.2,214.397 1042.21,214.399 1042.22,214.402 1042.23,214.404 1042.24,214.407 1042.25,214.41 1042.26,214.412 1042.27,214.415 1042.28,214.418 1042.29,214.42 1042.3,214.423 1042.3,214.426 1042.31,214.428 1042.32,214.431 1042.33,214.433 1042.34,214.436 1042.35,214.439 1042.36,214.441 1042.37,214.444 1042.38,214.447 1042.39,214.449 1042.4,214.452 1042.41,214.454 1042.41,214.457 1042.42,214.46 1042.43,214.462 1042.44,214.465 1042.45,214.468 1042.46,214.47 1042.47,214.473 1042.48,214.475 1042.49,214.478 1042.5,214.481 1042.51,214.483 1042.52,214.486 1042.53,214.489 1042.53,214.491 1042.54,214.494 1042.55,214.497 1042.56,214.499 1042.57,214.502 1042.58,214.504 1042.59,214.507 1042.6,214.51 1042.61,214.512 1042.62,214.515 1042.63,214.518 1042.64,214.52 1042.64,214.523 1042.65,214.525 1042.66,214.528 1042.67,214.531 1042.68,214.533 1042.69,214.536 1042.7,214.539 1042.71,214.541 1042.72,214.544 1042.73,214.546 1042.74,214.549 1042.75,214.552 1042.75,214.554 1042.76,214.557 1042.77,214.56 1042.78,214.562 1042.79,214.565 1042.8,214.568 1042.81,214.57 1042.82,214.573 1042.83,214.575 1042.84,214.578 1042.85,214.581 1042.86,214.583 1042.87,214.586 1042.87,214.589 1042.88,214.591 1042.89,214.594 1042.9,214.596 1042.91,214.599 1042.92,214.602 1042.93,214.604 1042.94,214.607 1042.95,214.61 1042.96,214.612 1042.97,214.615 1042.98,214.617 1042.98,214.62 1042.99,214.623 1043,214.625 1043.01,214.628 1043.02,214.631 1043.03,214.633 1043.04,214.636 1043.05,214.638 1043.06,214.641 1043.07,214.644 1043.08,214.646 1043.09,214.649 1043.09,214.652 1043.1,214.654 1043.11,214.657 1043.12,214.66 1043.13,214.662 1043.14,214.665 1043.15,214.667 1043.16,214.67 1043.17,214.673 1043.18,214.675 1043.19,214.678 1043.2,214.681 1043.21,214.683 1043.21,214.686 1043.22,214.688 1043.23,214.691 1043.24,214.694 1043.25,214.696 1043.26,214.699 1043.27,214.702 1043.28,214.704 1043.29,214.707 1043.3,214.709 1043.31,214.712 1043.32,214.715 1043.32,214.717 1043.33,214.72 1043.34,214.723 1043.35,214.725 1043.36,214.728 1043.37,214.73 1043.38,214.733 1043.39,214.736 1043.4,214.738 1043.41,214.741 1043.42,214.744 1043.43,214.746 1043.43,214.749 1043.44,214.751 1043.45,214.754 1043.46,214.757 1043.47,214.759 1043.48,214.762 1043.49,214.765 1043.5,214.767 1043.51,214.77 1043.52,214.773 1043.53,214.775 1043.54,214.778 1043.55,214.78 1043.55,214.783 1043.56,214.786 1043.57,214.788 1043.58,214.791 1043.59,214.794 1043.6,214.796 1043.61,214.799 1043.62,214.801 1043.63,214.804 1043.64,214.807 1043.65,214.809 1043.66,214.812 1043.66,214.815 1043.67,214.817 1043.68,214.82 1043.69,214.822 1043.7,214.825 1043.71,214.828 1043.72,214.83 1043.73,214.833 1043.74,214.836 1043.75,214.838 1043.76,214.841 1043.77,214.843 1043.77,214.846 1043.78,214.849 1043.79,214.851 1043.8,214.854 1043.81,214.857 1043.82,214.859 1043.83,214.862 1043.84,214.864 1043.85,214.867 1043.86,214.87 1043.87,214.872 1043.88,214.875 1043.89,214.878 1043.89,214.88 1043.9,214.883 1043.91,214.885 1043.92,214.888 1043.93,214.891 1043.94,214.893 1043.95,214.896 1043.96,214.899 1043.97,214.901 1043.98,214.904 1043.99,214.906 1044,214.909 1044,214.912 1044.01,214.914 1044.02,214.917 1044.03,214.92 1044.04,214.922 1044.05,214.925 1044.06,214.928 1044.07,214.93 1044.08,214.933 1044.09,214.935 1044.1,214.938 1044.11,214.941 1044.11,214.943 1044.12,214.946 1044.13,214.949 1044.14,214.951 1044.15,214.954 1044.16,214.956 1044.17,214.959 1044.18,214.962 1044.19,214.964 1044.2,214.967 1044.21,214.97 1044.22,214.972 1044.23,214.975 1044.23,214.977 1044.24,214.98 1044.25,214.983 1044.26,214.985 1044.27,214.988 1044.28,214.991 1044.29,214.993 1044.3,214.996 1044.31,214.998 1044.32,215.001 1044.33,215.004 1044.34,215.006 1044.34,215.009 1044.35,215.012 1044.36,215.014 1044.37,215.017 1044.38,215.019 1044.39,215.022 1044.4,215.025 1044.41,215.027 1044.42,215.03 1044.43,215.033 1044.44,215.035 1044.45,215.038 1044.45,215.04 1044.46,215.043 1044.47,215.046 1044.48,215.048 1044.49,215.051 1044.5,215.054 1044.51,215.056 1044.52,215.059 1044.53,215.061 1044.54,215.064 1044.55,215.067 1044.56,215.069 1044.57,215.072 1044.57,215.075 1044.58,215.077 1044.59,215.08 1044.6,215.082 1044.61,215.085 1044.62,215.088 1044.63,215.09 1044.64,215.093 1044.65,215.096 1044.66,215.098 1044.67,215.101 1044.68,215.103 1044.68,215.106 1044.69,215.109 1044.7,215.111 1044.71,215.114 1044.72,215.117 1044.73,215.119 1044.74,215.122 1044.75,215.124 1044.76,215.127 1044.77,215.13 1044.78,215.132 1044.79,215.135 1044.79,215.138 1044.8,215.14 1044.81,215.143 1044.82,215.145 1044.83,215.148 1044.84,215.151 1044.85,215.153 1044.86,215.156 1044.87,215.159 1044.88,215.161 1044.89,215.164 1044.9,215.166 1044.91,215.169 1044.91,215.172 1044.92,215.174 1044.93,215.177 1044.94,215.18 1044.95,215.182 1044.96,215.185 1044.97,215.187 1044.98,215.19 1044.99,215.193 1045,215.195 1045.01,215.198 1045.02,215.201 1045.02,215.203 1045.03,215.206 1045.04,215.208 1045.05,215.211 1045.06,215.214 1045.07,215.216 1045.08,215.219 1045.09,215.222 1045.1,215.224 1045.11,215.227 1045.12,215.229 1045.13,215.232 1045.13,215.235 1045.14,215.237 1045.15,215.24 1045.16,215.243 1045.17,215.245 1045.18,215.248 1045.19,215.25 1045.2,215.253 1045.21,215.256 1045.22,215.258 1045.23,215.261 1045.24,215.264 1045.25,215.266 1045.25,215.269 1045.26,215.271 1045.27,215.274 1045.28,215.277 1045.29,215.279 1045.3,215.282 1045.31,215.285 1045.32,215.287 1045.33,215.29 1045.34,215.292 1045.35,215.295 1045.36,215.298 1045.36,215.3 1045.37,215.303 1045.38,215.306 1045.39,215.308 1045.4,215.311 1045.41,215.313 1045.42,215.316 1045.43,215.319 1045.44,215.321 1045.45,215.324 1045.46,215.327 1045.47,215.329 1045.47,215.332 1045.48,215.334 1045.49,215.337 1045.5,215.34 1045.51,215.342 1045.52,215.345 1045.53,215.348 1045.54,215.35 1045.55,215.353 1045.56,215.355 1045.57,215.358 1045.58,215.361 1045.59,215.363 1045.59,215.366 1045.6,215.369 1045.61,215.371 1045.62,215.374 1045.63,215.376 1045.64,215.379 1045.65,215.382 1045.66,215.384 1045.67,215.387 1045.68,215.39 1045.69,215.392 1045.7,215.395 1045.7,215.397 1045.71,215.4 1045.72,215.403 1045.73,215.405 1045.74,215.408 1045.75,215.411 1045.76,215.413 1045.77,215.416 1045.78,215.418 1045.79,215.421 1045.8,215.424 1045.81,215.426 1045.81,215.429 1045.82,215.431 1045.83,215.434 1045.84,215.437 1045.85,215.439 1045.86,215.442 1045.87,215.445 1045.88,215.447 1045.89,215.45 1045.9,215.452 1045.91,215.455 1045.92,215.458 1045.93,215.46 1045.93,215.463 1045.94,215.466 1045.95,215.468 1045.96,215.471 1045.97,215.473 1045.98,215.476 1045.99,215.479 1046,215.481 1046.01,215.484 1046.02,215.487 1046.03,215.489 1046.04,215.492 1046.04,215.494 1046.05,215.497 1046.06,215.5 1046.07,215.502 1046.08,215.505 1046.09,215.508 1046.1,215.51 1046.11,215.513 1046.12,215.515 1046.13,215.518 1046.14,215.521 1046.15,215.523 1046.15,215.526 1046.16,215.529 1046.17,215.531 1046.18,215.534 1046.19,215.536 1046.2,215.539 1046.21,215.542 1046.22,215.544 1046.23,215.547 1046.24,215.55 1046.25,215.552 1046.26,215.555 1046.27,215.557 1046.27,215.56 1046.28,215.563 1046.29,215.565 1046.3,215.568 1046.31,215.57 1046.32,215.573 1046.33,215.576 1046.34,215.578 1046.35,215.581 1046.36,215.584 1046.37,215.586 1046.38,215.589 1046.38,215.591 1046.39,215.594 1046.4,215.597 1046.41,215.599 1046.42,215.602 1046.43,215.605 1046.44,215.607 1046.45,215.61 1046.46,215.612 1046.47,215.615 1046.48,215.618 1046.49,215.62 1046.49,215.623 1046.5,215.626 1046.51,215.628 1046.52,215.631 1046.53,215.633 1046.54,215.636 1046.55,215.639 1046.56,215.641 1046.57,215.644 1046.58,215.647 1046.59,215.649 1046.6,215.652 1046.61,215.654 1046.61,215.657 1046.62,215.66 1046.63,215.662 1046.64,215.665 1046.65,215.668 1046.66,215.67 1046.67,215.673 1046.68,215.675 1046.69,215.678 1046.7,215.681 1046.71,215.683 1046.72,215.686 1046.72,215.688 1046.73,215.691 1046.74,215.694 1046.75,215.696 1046.76,215.699 1046.77,215.702 1046.78,215.704 1046.79,215.707 1046.8,215.709 1046.81,215.712 1046.82,215.715 1046.83,215.717 1046.83,215.72 1046.84,215.723 1046.85,215.725 1046.86,215.728 1046.87,215.73 1046.88,215.733 1046.89,215.736 1046.9,215.738 1046.91,215.741 1046.92,215.744 1046.93,215.746 1046.94,215.749 1046.95,215.751 1046.95,215.754 1046.96,215.757 1046.97,215.759 1046.98,215.762 1046.99,215.764 1047,215.767 1047.01,215.77 1047.02,215.772 1047.03,215.775 1047.04,215.778 1047.05,215.78 1047.06,215.783 1047.06,215.785 1047.07,215.788 1047.08,215.791 1047.09,215.793 1047.1,215.796 1047.11,215.799 1047.12,215.801 1047.13,215.804 1047.14,215.806 1047.15,215.809 1047.16,215.812 1047.17,215.814 1047.17,215.817 1047.18,215.82 1047.19,215.822 1047.2,215.825 1047.21,215.827 1047.22,215.83 1047.23,215.833 1047.24,215.835 1047.25,215.838 1047.26,215.84 1047.27,215.843 1047.28,215.846 1047.29,215.848 1047.29,215.851 1047.3,215.854 1047.31,215.856 1047.32,215.859 1047.33,215.861 1047.34,215.864 1047.35,215.867 1047.36,215.869 1047.37,215.872 1047.38,215.875 1047.39,215.877 1047.4,215.88 1047.4,215.882 1047.41,215.885 1047.42,215.888 1047.43,215.89 1047.44,215.893 1047.45,215.896 1047.46,215.898 1047.47,215.901 1047.48,215.903 1047.49,215.906 1047.5,215.909 1047.51,215.911 1047.52,215.914 1047.52,215.916 1047.53,215.919 1047.54,215.922 1047.55,215.924 1047.56,215.927 1047.57,215.93 1047.58,215.932 1047.59,215.935 1047.6,215.937 1047.61,215.94 1047.62,215.943 1047.63,215.945 1047.63,215.948 1047.64,215.951 1047.65,215.953 1047.66,215.956 1047.67,215.958 1047.68,215.961 1047.69,215.964 1047.7,215.966 1047.71,215.969 1047.72,215.971 1047.73,215.974 1047.74,215.977 1047.74,215.979 1047.75,215.982 1047.76,215.985 1047.77,215.987 1047.78,215.99 1047.79,215.992 1047.8,215.995 1047.81,215.998 1047.82,216 1047.83,216.003 1047.84,216.006 1047.85,216.008 1047.86,216.011 1047.86,216.013 1047.87,216.016 1047.88,216.019 1047.89,216.021 1047.9,216.024 1047.91,216.026 1047.92,216.029 1047.93,216.032 1047.94,216.034 1047.95,216.037 1047.96,216.04 1047.97,216.042 1047.97,216.045 1047.98,216.047 1047.99,216.05 1048,216.053 1048.01,216.055 1048.02,216.058 1048.03,216.061 1048.04,216.063 1048.05,216.066 1048.06,216.068 1048.07,216.071 1048.08,216.074 1048.08,216.076 1048.09,216.079 1048.1,216.081 1048.11,216.084 1048.12,216.087 1048.13,216.089 1048.14,216.092 1048.15,216.095 1048.16,216.097 1048.17,216.1 1048.18,216.102 1048.19,216.105 1048.2,216.108 1048.2,216.11 1048.21,216.113 1048.22,216.116 1048.23,216.118 1048.24,216.121 1048.25,216.123 1048.26,216.126 1048.27,216.129 1048.28,216.131 1048.29,216.134 1048.3,216.136 1048.31,216.139 1048.31,216.142 1048.32,216.144 1048.33,216.147 1048.34,216.15 1048.35,216.152 1048.36,216.155 1048.37,216.157 1048.38,216.16 1048.39,216.163 1048.4,216.165 1048.41,216.168 1048.42,216.171 1048.42,216.173 1048.43,216.176 1048.44,216.178 1048.45,216.181 1048.46,216.184 1048.47,216.186 1048.48,216.189 1048.49,216.191 1048.5,216.194 1048.51,216.197 1048.52,216.199 1048.53,216.202 1048.54,216.205 1048.54,216.207 1048.55,216.21 1048.56,216.212 1048.57,216.215 1048.58,216.218 1048.59,216.22 1048.6,216.223 1048.61,216.225 1048.62,216.228 1048.63,216.231 1048.64,216.233 1048.65,216.236 1048.65,216.239 1048.66,216.241 1048.67,216.244 1048.68,216.246 1048.69,216.249 1048.7,216.252 1048.71,216.254 1048.72,216.257 1048.73,216.26 1048.74,216.262 1048.75,216.265 1048.76,216.267 1048.76,216.27 1048.77,216.273 1048.78,216.275 1048.79,216.278 1048.8,216.28 1048.81,216.283 1048.82,216.286 1048.83,216.288 1048.84,216.291 1048.85,216.294 1048.86,216.296 1048.87,216.299 1048.88,216.301 1048.88,216.304 1048.89,216.307 1048.9,216.309 1048.91,216.312 1048.92,216.314 1048.93,216.317 1048.94,216.32 1048.95,216.322 1048.96,216.325 1048.97,216.328 1048.98,216.33 1048.99,216.333 1048.99,216.335 1049,216.338 1049.01,216.341 1049.02,216.343 1049.03,216.346 1049.04,216.349 1049.05,216.351 1049.06,216.354 1049.07,216.356 1049.08,216.359 1049.09,216.362 1049.1,216.364 1049.1,216.367 1049.11,216.369 1049.12,216.372 1049.13,216.375 1049.14,216.377 1049.15,216.38 1049.16,216.383 1049.17,216.385 1049.18,216.388 1049.19,216.39 1049.2,216.393 1049.21,216.396 1049.22,216.398 1049.22,216.401 1049.23,216.403 1049.24,216.406 1049.25,216.409 1049.26,216.411 1049.27,216.414 1049.28,216.417 1049.29,216.419 1049.3,216.422 1049.31,216.424 1049.32,216.427 1049.33,216.43 1049.33,216.432 1049.34,216.435 1049.35,216.437 1049.36,216.44 1049.37,216.443 1049.38,216.445 1049.39,216.448 1049.4,216.451 1049.41,216.453 1049.42,216.456 1049.43,216.458 1049.44,216.461 1049.44,216.464 1049.45,216.466 1049.46,216.469 1049.47,216.471 1049.48,216.474 1049.49,216.477 1049.5,216.479 1049.51,216.482 1049.52,216.485 1049.53,216.487 1049.54,216.49 1049.55,216.492 1049.56,216.495 1049.56,216.498 1049.57,216.5 1049.58,216.503 1049.59,216.505 1049.6,216.508 1049.61,216.511 1049.62,216.513 1049.63,216.516 1049.64,216.519 1049.65,216.521 1049.66,216.524 1049.67,216.526 1049.67,216.529 1049.68,216.532 1049.69,216.534 1049.7,216.537 1049.71,216.54 1049.72,216.542 1049.73,216.545 1049.74,216.547 1049.75,216.55 1049.76,216.553 1049.77,216.555 1049.78,216.558 1049.78,216.56 1049.79,216.563 1049.8,216.566 1049.81,216.568 1049.82,216.571 1049.83,216.574 1049.84,216.576 1049.85,216.579 1049.86,216.581 1049.87,216.584 1049.88,216.587 1049.89,216.589 1049.9,216.592 1049.9,216.594 1049.91,216.597 1049.92,216.6 1049.93,216.602 1049.94,216.605 1049.95,216.608 1049.96,216.61 1049.97,216.613 1049.98,216.615 1049.99,216.618 1050,216.621 1050.01,216.623 1050.01,216.626 1050.02,216.628 1050.03,216.631 1050.04,216.634 1050.05,216.636 1050.06,216.639 1050.07,216.642 1050.08,216.644 1050.09,216.647 1050.1,216.649 1050.11,216.652 1050.12,216.655 1050.12,216.657 1050.13,216.66 1050.14,216.662 1050.15,216.665 1050.16,216.668 1050.17,216.67 1050.18,216.673 1050.19,216.675 1050.2,216.678 1050.21,216.681 1050.22,216.683 1050.23,216.686 1050.24,216.689 1050.24,216.691 1050.25,216.694 1050.26,216.696 1050.27,216.699 1050.28,216.702 1050.29,216.704 1050.3,216.707 1050.31,216.709 1050.32,216.712 1050.33,216.715 1050.34,216.717 1050.35,216.72 1050.35,216.723 1050.36,216.725 1050.37,216.728 1050.38,216.73 1050.39,216.733 1050.4,216.736 1050.41,216.738 1050.42,216.741 1050.43,216.743 1050.44,216.746 1050.45,216.749 1050.46,216.751 1050.46,216.754 1050.47,216.757 1050.48,216.759 1050.49,216.762 1050.5,216.764 1050.51,216.767 1050.52,216.77 1050.53,216.772 1050.54,216.775 1050.55,216.777 1050.56,216.78 1050.57,216.783 1050.58,216.785 1050.58,216.788 1050.59,216.791 1050.6,216.793 1050.61,216.796 1050.62,216.798 1050.63,216.801 1050.64,216.804 1050.65,216.806 1050.66,216.809 1050.67,216.811 1050.68,216.814 1050.69,216.817 1050.69,216.819 1050.7,216.822 1050.71,216.825 1050.72,216.827 1050.73,216.83 1050.74,216.832 1050.75,216.835 1050.76,216.838 1050.77,216.84 1050.78,216.843 1050.79,216.845 1050.8,216.848 1050.8,216.851 1050.81,216.853 1050.82,216.856 1050.83,216.858 1050.84,216.861 1050.85,216.864 1050.86,216.866 1050.87,216.869 1050.88,216.872 1050.89,216.874 1050.9,216.877 1050.91,216.879 1050.92,216.882 1050.92,216.885 1050.93,216.887 1050.94,216.89 1050.95,216.892 1050.96,216.895 1050.97,216.898 1050.98,216.9 1050.99,216.903 1051,216.906 1051.01,216.908 1051.02,216.911 1051.03,216.913 1051.03,216.916 1051.04,216.919 1051.05,216.921 1051.06,216.924 1051.07,216.926 1051.08,216.929 1051.09,216.932 1051.1,216.934 1051.11,216.937 1051.12,216.939 1051.13,216.942 1051.14,216.945 1051.14,216.947 1051.15,216.95 1051.16,216.953 1051.17,216.955 1051.18,216.958 1051.19,216.96 1051.2,216.963 1051.21,216.966 1051.22,216.968 1051.23,216.971 1051.24,216.973 1051.25,216.976 1051.26,216.979 1051.26,216.981 1051.27,216.984 1051.28,216.987 1051.29,216.989 1051.3,216.992 1051.31,216.994 1051.32,216.997 1051.33,217 1051.34,217.002 1051.35,217.005 1051.36,217.007 1051.37,217.01 1051.37,217.013 1051.38,217.015 1051.39,217.018 1051.4,217.02 1051.41,217.023 1051.42,217.026 1051.43,217.028 1051.44,217.031 1051.45,217.034 1051.46,217.036 1051.47,217.039 1051.48,217.041 1051.48,217.044 1051.49,217.047 1051.5,217.049 1051.51,217.052 1051.52,217.054 1051.53,217.057 1051.54,217.06 1051.55,217.062 1051.56,217.065 1051.57,217.068 1051.58,217.07 1051.59,217.073 1051.6,217.075 1051.6,217.078 1051.61,217.081 1051.62,217.083 1051.63,217.086 1051.64,217.088 1051.65,217.091 1051.66,217.094 1051.67,217.096 1051.68,217.099 1051.69,217.101 1051.7,217.104 1051.71,217.107 1051.71,217.109 1051.72,217.112 1051.73,217.115 1051.74,217.117 1051.75,217.12 1051.76,217.122 1051.77,217.125 1051.78,217.128 1051.79,217.13 1051.8,217.133 1051.81,217.135 1051.82,217.138 1051.82,217.141 1051.83,217.143 1051.84,217.146 1051.85,217.148 1051.86,217.151 1051.87,217.154 1051.88,217.156 1051.89,217.159 1051.9,217.162 1051.91,217.164 1051.92,217.167 1051.93,217.169 1051.94,217.172 1051.94,217.175 1051.95,217.177 1051.96,217.18 1051.97,217.182 1051.98,217.185 1051.99,217.188 1052,217.19 1052.01,217.193 1052.02,217.195 1052.03,217.198 1052.04,217.201 1052.05,217.203 1052.05,217.206 1052.06,217.209 1052.07,217.211 1052.08,217.214 1052.09,217.216 1052.1,217.219 1052.11,217.222 1052.12,217.224 1052.13,217.227 1052.14,217.229 1052.15,217.232 1052.16,217.235 1052.16,217.237 1052.17,217.24 1052.18,217.242 1052.19,217.245 1052.2,217.248 1052.21,217.25 1052.22,217.253 1052.23,217.256 1052.24,217.258 1052.25,217.261 1052.26,217.263 1052.27,217.266 1052.28,217.269 1052.28,217.271 1052.29,217.274 1052.3,217.276 1052.31,217.279 1052.32,217.282 1052.33,217.284 1052.34,217.287 1052.35,217.289 1052.36,217.292 1052.37,217.295 1052.38,217.297 1052.39,217.3 1052.39,217.303 1052.4,217.305 1052.41,217.308 1052.42,217.31 1052.43,217.313 1052.44,217.316 1052.45,217.318 1052.46,217.321 1052.47,217.323 1052.48,217.326 1052.49,217.329 1052.5,217.331 1052.5,217.334 1052.51,217.336 1052.52,217.339 1052.53,217.342 1052.54,217.344 1052.55,217.347 1052.56,217.349 1052.57,217.352 1052.58,217.355 1052.59,217.357 1052.6,217.36 1052.61,217.363 1052.62,217.365 1052.62,217.368 1052.63,217.37 1052.64,217.373 1052.65,217.376 1052.66,217.378 1052.67,217.381 1052.68,217.383 1052.69,217.386 1052.7,217.389 1052.71,217.391 1052.72,217.394 1052.73,217.396 1052.73,217.399 1052.74,217.402 1052.75,217.404 1052.76,217.407 1052.77,217.41 1052.78,217.412 1052.79,217.415 1052.8,217.417 1052.81,217.42 1052.82,217.423 1052.83,217.425 1052.84,217.428 1052.84,217.43 1052.85,217.433 1052.86,217.436 1052.87,217.438 1052.88,217.441 1052.89,217.443 1052.9,217.446 1052.91,217.449 1052.92,217.451 1052.93,217.454 1052.94,217.456 1052.95,217.459 1052.96,217.462 1052.96,217.464 1052.97,217.467 1052.98,217.47 1052.99,217.472 1053,217.475 1053.01,217.477 1053.02,217.48 1053.03,217.483 1053.04,217.485 1053.05,217.488 1053.06,217.49 1053.07,217.493 1053.07,217.496 1053.08,217.498 1053.09,217.501 1053.1,217.503 1053.11,217.506 1053.12,217.509 1053.13,217.511 1053.14,217.514 1053.15,217.517 1053.16,217.519 1053.17,217.522 1053.18,217.524 1053.18,217.527 1053.19,217.53 1053.2,217.532 1053.21,217.535 1053.22,217.537 1053.23,217.54 1053.24,217.543 1053.25,217.545 1053.26,217.548 1053.27,217.55 1053.28,217.553 1053.29,217.556 1053.3,217.558 1053.3,217.561 1053.31,217.563 1053.32,217.566 1053.33,217.569 1053.34,217.571 1053.35,217.574 1053.36,217.577 1053.37,217.579 1053.38,217.582 1053.39,217.584 1053.4,217.587 1053.41,217.59 1053.41,217.592 1053.42,217.595 1053.43,217.597 1053.44,217.6 1053.45,217.603 1053.46,217.605 1053.47,217.608 1053.48,217.61 1053.49,217.613 1053.5,217.616 1053.51,217.618 1053.52,217.621 1053.52,217.623 1053.53,217.626 1053.54,217.629 1053.55,217.631 1053.56,217.634 1053.57,217.637 1053.58,217.639 1053.59,217.642 1053.6,217.644 1053.61,217.647 1053.62,217.65 1053.63,217.652 1053.64,217.655 1053.64,217.657 1053.65,217.66 1053.66,217.663 1053.67,217.665 1053.68,217.668 1053.69,217.67 1053.7,217.673 1053.71,217.676 1053.72,217.678 1053.73,217.681 1053.74,217.683 1053.75,217.686 1053.75,217.689 1053.76,217.691 1053.77,217.694 1053.78,217.696 1053.79,217.699 1053.8,217.702 1053.81,217.704 1053.82,217.707 1053.83,217.71 1053.84,217.712 1053.85,217.715 1053.86,217.717 1053.86,217.72 1053.87,217.723 1053.88,217.725 1053.89,217.728 1053.9,217.73 1053.91,217.733 1053.92,217.736 1053.93,217.738 1053.94,217.741 1053.95,217.743 1053.96,217.746 1053.97,217.749 1053.98,217.751 1053.98,217.754 1053.99,217.756 1054,217.759 1054.01,217.762 1054.02,217.764 1054.03,217.767 1054.04,217.769 1054.05,217.772 1054.06,217.775 1054.07,217.777 1054.08,217.78 1054.09,217.783 1054.09,217.785 1054.1,217.788 1054.11,217.79 1054.12,217.793 1054.13,217.796 1054.14,217.798 1054.15,217.801 1054.16,217.803 1054.17,217.806 1054.18,217.809 1054.19,217.811 1054.2,217.814 1054.2,217.816 1054.21,217.819 1054.22,217.822 1054.23,217.824 1054.24,217.827 1054.25,217.829 1054.26,217.832 1054.27,217.835 1054.28,217.837 1054.29,217.84 1054.3,217.842 1054.31,217.845 1054.32,217.848 1054.32,217.85 1054.33,217.853 1054.34,217.856 1054.35,217.858 1054.36,217.861 1054.37,217.863 1054.38,217.866 1054.39,217.869 1054.4,217.871 1054.41,217.874 1054.42,217.876 1054.43,217.879 1054.43,217.882 1054.44,217.884 1054.45,217.887 1054.46,217.889 1054.47,217.892 1054.48,217.895 1054.49,217.897 1054.5,217.9 1054.51,217.902 1054.52,217.905 1054.53,217.908 1054.54,217.91 1054.54,217.913 1054.55,217.915 1054.56,217.918 1054.57,217.921 1054.58,217.923 1054.59,217.926 1054.6,217.929 1054.61,217.931 1054.62,217.934 1054.63,217.936 1054.64,217.939 1054.65,217.942 1054.66,217.944 1054.66,217.947 1054.67,217.949 1054.68,217.952 1054.69,217.955 1054.7,217.957 1054.71,217.96 1054.72,217.962 1054.73,217.965 1054.74,217.968 1054.75,217.97 1054.76,217.973 1054.77,217.975 1054.77,217.978 1054.78,217.981 1054.79,217.983 1054.8,217.986 1054.81,217.988 1054.82,217.991 1054.83,217.994 1054.84,217.996 1054.85,217.999 1054.86,218.001 1054.87,218.004 1054.88,218.007 1054.88,218.009 1054.89,218.012 1054.9,218.015 1054.91,218.017 1054.92,218.02 1054.93,218.022 1054.94,218.025 1054.95,218.028 1054.96,218.03 1054.97,218.033 1054.98,218.035 1054.99,218.038 1055,218.041 1055,218.043 1055.01,218.046 1055.02,218.048 1055.03,218.051 1055.04,218.054 1055.05,218.056 1055.06,218.059 1055.07,218.061 1055.08,218.064 1055.09,218.067 1055.1,218.069 1055.11,218.072 1055.11,218.074 1055.12,218.077 1055.13,218.08 1055.14,218.082 1055.15,218.085 1055.16,218.087 1055.17,218.09 1055.18,218.093 1055.19,218.095 1055.2,218.098 1055.21,218.1 1055.22,218.103 1055.22,218.106 1055.23,218.108 1055.24,218.111 1055.25,218.114 1055.26,218.116 1055.27,218.119 1055.28,218.121 1055.29,218.124 1055.3,218.127 1055.31,218.129 1055.32,218.132 1055.33,218.134 1055.34,218.137 1055.34,218.14 1055.35,218.142 1055.36,218.145 1055.37,218.147 1055.38,218.15 1055.39,218.153 1055.4,218.155 1055.41,218.158 1055.42,218.16 1055.43,218.163 1055.44,218.166 1055.45,218.168 1055.45,218.171 1055.46,218.173 1055.47,218.176 1055.48,218.179 1055.49,218.181 1055.5,218.184 1055.51,218.186 1055.52,218.189 1055.53,218.192 1055.54,218.194 1055.55,218.197 1055.56,218.199 1055.56,218.202 1055.57,218.205 1055.58,218.207 1055.59,218.21 1055.6,218.212 1055.61,218.215 1055.62,218.218 1055.63,218.22 1055.64,218.223 1055.65,218.225 1055.66,218.228 1055.67,218.231 1055.68,218.233 1055.68,218.236 1055.69,218.239 1055.7,218.241 1055.71,218.244 1055.72,218.246 1055.73,218.249 1055.74,218.252 1055.75,218.254 1055.76,218.257 1055.77,218.259 1055.78,218.262 1055.79,218.265 1055.79,218.267 1055.8,218.27 1055.81,218.272 1055.82,218.275 1055.83,218.278 1055.84,218.28 1055.85,218.283 1055.86,218.285 1055.87,218.288 1055.88,218.291 1055.89,218.293 1055.9,218.296 1055.9,218.298 1055.91,218.301 1055.92,218.304 1055.93,218.306 1055.94,218.309 1055.95,218.311 1055.96,218.314 1055.97,218.317 1055.98,218.319 1055.99,218.322 1056,218.324 1056.01,218.327 1056.02,218.33 1056.02,218.332 1056.03,218.335 1056.04,218.337 1056.05,218.34 1056.06,218.343 1056.07,218.345 1056.08,218.348 1056.09,218.35 1056.1,218.353 1056.11,218.356 1056.12,218.358 1056.13,218.361 1056.13,218.363 1056.14,218.366 1056.15,218.369 1056.16,218.371 1056.17,218.374 1056.18,218.377 1056.19,218.379 1056.2,218.382 1056.21,218.384 1056.22,218.387 1056.23,218.39 1056.24,218.392 1056.24,218.395 1056.25,218.397 1056.26,218.4 1056.27,218.403 1056.28,218.405 1056.29,218.408 1056.3,218.41 1056.31,218.413 1056.32,218.416 1056.33,218.418 1056.34,218.421 1056.35,218.423 1056.36,218.426 1056.36,218.429 1056.37,218.431 1056.38,218.434 1056.39,218.436 1056.4,218.439 1056.41,218.442 1056.42,218.444 1056.43,218.447 1056.44,218.449 1056.45,218.452 1056.46,218.455 1056.47,218.457 1056.47,218.46 1056.48,218.462 1056.49,218.465 1056.5,218.468 1056.51,218.47 1056.52,218.473 1056.53,218.475 1056.54,218.478 1056.55,218.481 1056.56,218.483 1056.57,218.486 1056.58,218.488 1056.58,218.491 1056.59,218.494 1056.6,218.496 1056.61,218.499 1056.62,218.501 1056.63,218.504 1056.64,218.507 1056.65,218.509 1056.66,218.512 1056.67,218.514 1056.68,218.517 1056.69,218.52 1056.7,218.522 1056.7,218.525 1056.71,218.527 1056.72,218.53 1056.73,218.533 1056.74,218.535 1056.75,218.538 1056.76,218.54 1056.77,218.543 1056.78,218.546 1056.79,218.548 1056.8,218.551 1056.81,218.553 1056.81,218.556 1056.82,218.559 1056.83,218.561 1056.84,218.564 1056.85,218.566 1056.86,218.569 1056.87,218.572 1056.88,218.574 1056.89,218.577 1056.9,218.579 1056.91,218.582 1056.92,218.585 1056.92,218.587 1056.93,218.59 1056.94,218.593 1056.95,218.595 1056.96,218.598 1056.97,218.6 1056.98,218.603 1056.99,218.606 1057,218.608 1057.01,218.611 1057.02,218.613 1057.03,218.616 1057.04,218.619 1057.04,218.621 1057.05,218.624 1057.06,218.626 1057.07,218.629 1057.08,218.632 1057.09,218.634 1057.1,218.637 1057.11,218.639 1057.12,218.642 1057.13,218.645 1057.14,218.647 1057.15,218.65 1057.15,218.652 1057.16,218.655 1057.17,218.658 1057.18,218.66 1057.19,218.663 1057.2,218.665 1057.21,218.668 1057.22,218.671 1057.23,218.673 1057.24,218.676 1057.25,218.678 1057.26,218.681 1057.26,218.684 1057.27,218.686 1057.28,218.689 1057.29,218.691 1057.3,218.694 1057.31,218.697 1057.32,218.699 1057.33,218.702 1057.34,218.704 1057.35,218.707 1057.36,218.71 1057.37,218.712 1057.38,218.715 1057.38,218.717 1057.39,218.72 1057.4,218.723 1057.41,218.725 1057.42,218.728 1057.43,218.73 1057.44,218.733 1057.45,218.736 1057.46,218.738 1057.47,218.741 1057.48,218.743 1057.49,218.746 1057.49,218.749 1057.5,218.751 1057.51,218.754 1057.52,218.756 1057.53,218.759 1057.54,218.762 1057.55,218.764 1057.56,218.767 1057.57,218.769 1057.58,218.772 1057.59,218.775 1057.6,218.777 1057.6,218.78 1057.61,218.782 1057.62,218.785 1057.63,218.788 1057.64,218.79 1057.65,218.793 1057.66,218.795 1057.67,218.798 1057.68,218.801 1057.69,218.803 1057.7,218.806 1057.71,218.808 1057.72,218.811 1057.72,218.814 1057.73,218.816 1057.74,218.819 1057.75,218.821 1057.76,218.824 1057.77,218.827 1057.78,218.829 1057.79,218.832 1057.8,218.834 1057.81,218.837 1057.82,218.84 1057.83,218.842 1057.83,218.845 1057.84,218.847 1057.85,218.85 1057.86,218.853 1057.87,218.855 1057.88,218.858 1057.89,218.86 1057.9,218.863 1057.91,218.866 1057.92,218.868 1057.93,218.871 1057.94,218.873 1057.94,218.876 1057.95,218.879 1057.96,218.881 1057.97,218.884 1057.98,218.886 1057.99,218.889 1058,218.892 1058.01,218.894 1058.02,218.897 1058.03,218.899 1058.04,218.902 1058.05,218.905 1058.06,218.907 1058.06,218.91 1058.07,218.912 1058.08,218.915 1058.09,218.918 1058.1,218.92 1058.11,218.923 1058.12,218.925 1058.13,218.928 1058.14,218.931 1058.15,218.933 1058.16,218.936 1058.17,218.938 1058.17,218.941 1058.18,218.944 1058.19,218.946 1058.2,218.949 1058.21,218.951 1058.22,218.954 1058.23,218.957 1058.24,218.959 1058.25,218.962 1058.26,218.964 1058.27,218.967 1058.28,218.97 1058.28,218.972 1058.29,218.975 1058.3,218.977 1058.31,218.98 1058.32,218.983 1058.33,218.985 1058.34,218.988 1058.35,218.99 1058.36,218.993 1058.37,218.996 1058.38,218.998 1058.39,219.001 1058.4,219.003 1058.4,219.006 1058.41,219.009 1058.42,219.011 1058.43,219.014 1058.44,219.016 1058.45,219.019 1058.46,219.022 1058.47,219.024 1058.48,219.027 1058.49,219.029 1058.5,219.032 1058.51,219.035 1058.51,219.037 1058.52,219.04 1058.53,219.042 1058.54,219.045 1058.55,219.048 1058.56,219.05 1058.57,219.053 1058.58,219.055 1058.59,219.058 1058.6,219.061 1058.61,219.063 1058.62,219.066 1058.62,219.068 1058.63,219.071 1058.64,219.074 1058.65,219.076 1058.66,219.079 1058.67,219.081 1058.68,219.084 1058.69,219.087 1058.7,219.089 1058.71,219.092 1058.72,219.094 1058.73,219.097 1058.74,219.099 1058.74,219.102 1058.75,219.105 1058.76,219.107 1058.77,219.11 1058.78,219.112 1058.79,219.115 1058.8,219.118 1058.81,219.12 1058.82,219.123 1058.83,219.125 1058.84,219.128 1058.85,219.131 1058.85,219.133 1058.86,219.136 1058.87,219.138 1058.88,219.141 1058.89,219.144 1058.9,219.146 1058.91,219.149 1058.92,219.151 1058.93,219.154 1058.94,219.157 1058.95,219.159 1058.96,219.162 1058.96,219.164 1058.97,219.167 1058.98,219.17 1058.99,219.172 1059,219.175 1059.01,219.177 1059.02,219.18 1059.03,219.183 1059.04,219.185 1059.05,219.188 1059.06,219.19 1059.07,219.193 1059.08,219.196 1059.08,219.198 1059.09,219.201 1059.1,219.203 1059.11,219.206 1059.12,219.209 1059.13,219.211 1059.14,219.214 1059.15,219.216 1059.16,219.219 1059.17,219.222 1059.18,219.224 1059.19,219.227 1059.19,219.229 1059.2,219.232 1059.21,219.235 1059.22,219.237 1059.23,219.24 1059.24,219.242 1059.25,219.245 1059.26,219.248 1059.27,219.25 1059.28,219.253 1059.29,219.255 1059.3,219.258 1059.3,219.261 1059.31,219.263 1059.32,219.266 1059.33,219.268 1059.34,219.271 1059.35,219.274 1059.36,219.276 1059.37,219.279 1059.38,219.281 1059.39,219.284 1059.4,219.287 1059.41,219.289 1059.42,219.292 1059.42,219.294 1059.43,219.297 1059.44,219.3 1059.45,219.302 1059.46,219.305 1059.47,219.307 1059.48,219.31 1059.49,219.312 1059.5,219.315 1059.51,219.318 1059.52,219.32 1059.53,219.323 1059.53,219.325 1059.54,219.328 1059.55,219.331 1059.56,219.333 1059.57,219.336 1059.58,219.338 1059.59,219.341 1059.6,219.344 1059.61,219.346 1059.62,219.349 1059.63,219.351 1059.64,219.354 1059.64,219.357 1059.65,219.359 1059.66,219.362 1059.67,219.364 1059.68,219.367 1059.69,219.37 1059.7,219.372 1059.71,219.375 1059.72,219.377 1059.73,219.38 1059.74,219.383 1059.75,219.385 1059.76,219.388 1059.76,219.39 1059.77,219.393 1059.78,219.396 1059.79,219.398 1059.8,219.401 1059.81,219.403 1059.82,219.406 1059.83,219.409 1059.84,219.411 1059.85,219.414 1059.86,219.416 1059.87,219.419 1059.87,219.422 1059.88,219.424 1059.89,219.427 1059.9,219.429 1059.91,219.432 1059.92,219.435 1059.93,219.437 1059.94,219.44 1059.95,219.442 1059.96,219.445 1059.97,219.447 1059.98,219.45 1059.98,219.453 1059.99,219.455 1060,219.458 1060.01,219.46 1060.02,219.463 1060.03,219.466 1060.04,219.468 1060.05,219.471 1060.06,219.473 1060.07,219.476 1060.08,219.479 1060.09,219.481 1060.1,219.484 1060.1,219.486 1060.11,219.489 1060.12,219.492 1060.13,219.494 1060.14,219.497 1060.15,219.499 1060.16,219.502 1060.17,219.505 1060.18,219.507 1060.19,219.51 1060.2,219.512 1060.21,219.515 1060.21,219.518 1060.22,219.52 1060.23,219.523 1060.24,219.525 1060.25,219.528 1060.26,219.531 1060.27,219.533 1060.28,219.536 1060.29,219.538 1060.3,219.541 1060.31,219.544 1060.32,219.546 1060.32,219.549 1060.33,219.551 1060.34,219.554 1060.35,219.557 1060.36,219.559 1060.37,219.562 1060.38,219.564 1060.39,219.567 1060.4,219.569 1060.41,219.572 1060.42,219.575 1060.43,219.577 1060.44,219.58 1060.44,219.582 1060.45,219.585 1060.46,219.588 1060.47,219.59 1060.48,219.593 1060.49,219.595 1060.5,219.598 1060.51,219.601 1060.52,219.603 1060.53,219.606 1060.54,219.608 1060.55,219.611 1060.55,219.614 1060.56,219.616 1060.57,219.619 1060.58,219.621 1060.59,219.624 1060.6,219.627 1060.61,219.629 1060.62,219.632 1060.63,219.634 1060.64,219.637 1060.65,219.64 1060.66,219.642 1060.66,219.645 1060.67,219.647 1060.68,219.65 1060.69,219.653 1060.7,219.655 1060.71,219.658 1060.72,219.66 1060.73,219.663 1060.74,219.665 1060.75,219.668 1060.76,219.671 1060.77,219.673 1060.78,219.676 1060.78,219.678 1060.79,219.681 1060.8,219.684 1060.81,219.686 1060.82,219.689 1060.83,219.691 1060.84,219.694 1060.85,219.697 1060.86,219.699 1060.87,219.702 1060.88,219.704 1060.89,219.707 1060.89,219.71 1060.9,219.712 1060.91,219.715 1060.92,219.717 1060.93,219.72 1060.94,219.723 1060.95,219.725 1060.96,219.728 1060.97,219.73 1060.98,219.733 1060.99,219.736 1061,219.738 1061,219.741 1061.01,219.743 1061.02,219.746 1061.03,219.748 1061.04,219.751 1061.05,219.754 1061.06,219.756 1061.07,219.759 1061.08,219.761 1061.09,219.764 1061.1,219.767 1061.11,219.769 1061.12,219.772 1061.12,219.774 1061.13,219.777 1061.14,219.78 1061.15,219.782 1061.16,219.785 1061.17,219.787 1061.18,219.79 1061.19,219.793 1061.2,219.795 1061.21,219.798 1061.22,219.8 1061.23,219.803 1061.23,219.806 1061.24,219.808 1061.25,219.811 1061.26,219.813 1061.27,219.816 1061.28,219.819 1061.29,219.821 1061.3,219.824 1061.31,219.826 1061.32,219.829 1061.33,219.831 1061.34,219.834 1061.34,219.837 1061.35,219.839 1061.36,219.842 1061.37,219.844 1061.38,219.847 1061.39,219.85 1061.4,219.852 1061.41,219.855 1061.42,219.857 1061.43,219.86 1061.44,219.863 1061.45,219.865 1061.46,219.868 1061.46,219.87 1061.47,219.873 1061.48,219.876 1061.49,219.878 1061.5,219.881 1061.51,219.883 1061.52,219.886 1061.53,219.889 1061.54,219.891 1061.55,219.894 1061.56,219.896 1061.57,219.899 1061.57,219.901 1061.58,219.904 1061.59,219.907 1061.6,219.909 1061.61,219.912 1061.62,219.914 1061.63,219.917 1061.64,219.92 1061.65,219.922 1061.66,219.925 1061.67,219.927 1061.68,219.93 1061.68,219.933 1061.69,219.935 1061.7,219.938 1061.71,219.94 1061.72,219.943 1061.73,219.946 1061.74,219.948 1061.75,219.951 1061.76,219.953 1061.77,219.956 1061.78,219.959 1061.79,219.961 1061.8,219.964 1061.8,219.966 1061.81,219.969 1061.82,219.971 1061.83,219.974 1061.84,219.977 1061.85,219.979 1061.86,219.982 1061.87,219.984 1061.88,219.987 1061.89,219.99 1061.9,219.992 1061.91,219.995 1061.91,219.997 1061.92,220 1061.93,220.003 1061.94,220.005 1061.95,220.008 1061.96,220.01 1061.97,220.013 1061.98,220.016 1061.99,220.018 1062,220.021 1062.01,220.023 1062.02,220.026 1062.02,220.029 1062.03,220.031 1062.04,220.034 1062.05,220.036 1062.06,220.039 1062.07,220.041 1062.08,220.044 1062.09,220.047 1062.1,220.049 1062.11,220.052 1062.12,220.054 1062.13,220.057 1062.14,220.06 1062.14,220.062 1062.15,220.065 1062.16,220.067 1062.17,220.07 1062.18,220.073 1062.19,220.075 1062.2,220.078 1062.21,220.08 1062.22,220.083 1062.23,220.086 1062.24,220.088 1062.25,220.091 1062.25,220.093 1062.26,220.096 1062.27,220.098 1062.28,220.101 1062.29,220.104 1062.3,220.106 1062.31,220.109 1062.32,220.111 1062.33,220.114 1062.34,220.117 1062.35,220.119 1062.36,220.122 1062.36,220.124 1062.37,220.127 1062.38,220.13 1062.39,220.132 1062.4,220.135 1062.41,220.137 1062.42,220.14 1062.43,220.143 1062.44,220.145 1062.45,220.148 1062.46,220.15 1062.47,220.153 1062.48,220.155 1062.48,220.158 1062.49,220.161 1062.5,220.163 1062.51,220.166 1062.52,220.168 1062.53,220.171 1062.54,220.174 1062.55,220.176 1062.56,220.179 1062.57,220.181 1062.58,220.184 1062.59,220.187 1062.59,220.189 1062.6,220.192 1062.61,220.194 1062.62,220.197 1062.63,220.2 1062.64,220.202 1062.65,220.205 1062.66,220.207 1062.67,220.21 1062.68,220.212 1062.69,220.215 1062.7,220.218 1062.7,220.22 1062.71,220.223 1062.72,220.225 1062.73,220.228 1062.74,220.231 1062.75,220.233 1062.76,220.236 1062.77,220.238 1062.78,220.241 1062.79,220.244 1062.8,220.246 1062.81,220.249 1062.82,220.251 1062.82,220.254 1062.83,220.257 1062.84,220.259 1062.85,220.262 1062.86,220.264 1062.87,220.267 1062.88,220.269 1062.89,220.272 1062.9,220.275 1062.91,220.277 1062.92,220.28 1062.93,220.282 1062.93,220.285 1062.94,220.288 1062.95,220.29 1062.96,220.293 1062.97,220.295 1062.98,220.298 1062.99,220.301 1063,220.303 1063.01,220.306 1063.02,220.308 1063.03,220.311 1063.04,220.314 1063.04,220.316 1063.05,220.319 1063.06,220.321 1063.07,220.324 1063.08,220.326 1063.09,220.329 1063.1,220.332 1063.11,220.334 1063.12,220.337 1063.13,220.339 1063.14,220.342 1063.15,220.345 1063.16,220.347 1063.16,220.35 1063.17,220.352 1063.18,220.355 1063.19,220.358 1063.2,220.36 1063.21,220.363 1063.22,220.365 1063.23,220.368 1063.24,220.37 1063.25,220.373 1063.26,220.376 1063.27,220.378 1063.27,220.381 1063.28,220.383 1063.29,220.386 1063.3,220.389 1063.31,220.391 1063.32,220.394 1063.33,220.396 1063.34,220.399 1063.35,220.402 1063.36,220.404 1063.37,220.407 1063.38,220.409 1063.38,220.412 1063.39,220.414 1063.4,220.417 1063.41,220.42 1063.42,220.422 1063.43,220.425 1063.44,220.427 1063.45,220.43 1063.46,220.433 1063.47,220.435 1063.48,220.438 1063.49,220.44 1063.5,220.443 1063.5,220.446 1063.51,220.448 1063.52,220.451 1063.53,220.453 1063.54,220.456 1063.55,220.459 1063.56,220.461 1063.57,220.464 1063.58,220.466 1063.59,220.469 1063.6,220.471 1063.61,220.474 1063.61,220.477 1063.62,220.479 1063.63,220.482 1063.64,220.484 1063.65,220.487 1063.66,220.49 1063.67,220.492 1063.68,220.495 1063.69,220.497 1063.7,220.5 1063.71,220.503 1063.72,220.505 1063.72,220.508 1063.73,220.51 1063.74,220.513 1063.75,220.515 1063.76,220.518 1063.77,220.521 1063.78,220.523 1063.79,220.526 1063.8,220.528 1063.81,220.531 1063.82,220.534 1063.83,220.536 1063.84,220.539 1063.84,220.541 1063.85,220.544 1063.86,220.547 1063.87,220.549 1063.88,220.552 1063.89,220.554 1063.9,220.557 1063.91,220.559 1063.92,220.562 1063.93,220.565 1063.94,220.567 1063.95,220.57 1063.95,220.572 1063.96,220.575 1063.97,220.578 1063.98,220.58 1063.99,220.583 1064,220.585 1064.01,220.588 1064.02,220.591 1064.03,220.593 1064.04,220.596 1064.05,220.598 1064.06,220.601 1064.06,220.603 1064.07,220.606 1064.08,220.609 1064.09,220.611 1064.1,220.614 1064.11,220.616 1064.12,220.619 1064.13,220.622 1064.14,220.624 1064.15,220.627 1064.16,220.629 1064.17,220.632 1064.18,220.635 1064.18,220.637 1064.19,220.64 1064.2,220.642 1064.21,220.645 1064.22,220.647 1064.23,220.65 1064.24,220.653 1064.25,220.655 1064.26,220.658 1064.27,220.66 1064.28,220.663 1064.29,220.666 1064.29,220.668 1064.3,220.671 1064.31,220.673 1064.32,220.676 1064.33,220.679 1064.34,220.681 1064.35,220.684 1064.36,220.686 1064.37,220.689 1064.38,220.691 1064.39,220.694 1064.4,220.697 1064.4,220.699 1064.41,220.702 1064.42,220.704 1064.43,220.707 1064.44,220.71 1064.45,220.712 1064.46,220.715 1064.47,220.717 1064.48,220.72 1064.49,220.722 1064.5,220.725 1064.51,220.728 1064.52,220.73 1064.52,220.733 1064.53,220.735 1064.54,220.738 1064.55,220.741 1064.56,220.743 1064.57,220.746 1064.58,220.748 1064.59,220.751 1064.6,220.754 1064.61,220.756 1064.62,220.759 1064.63,220.761 1064.63,220.764 1064.64,220.766 1064.65,220.769 1064.66,220.772 1064.67,220.774 1064.68,220.777 1064.69,220.779 1064.7,220.782 1064.71,220.785 1064.72,220.787 1064.73,220.79 1064.74,220.792 1064.74,220.795 1064.75,220.798 1064.76,220.8 1064.77,220.803 1064.78,220.805 1064.79,220.808 1064.8,220.81 1064.81,220.813 1064.82,220.816 1064.83,220.818 1064.84,220.821 1064.85,220.823 1064.86,220.826 1064.86,220.829 1064.87,220.831 1064.88,220.834 1064.89,220.836 1064.9,220.839 1064.91,220.841 1064.92,220.844 1064.93,220.847 1064.94,220.849 1064.95,220.852 1064.96,220.854 1064.97,220.857 1064.97,220.86 1064.98,220.862 1064.99,220.865 1065,220.867 1065.01,220.87 1065.02,220.873 1065.03,220.875 1065.04,220.878 1065.05,220.88 1065.06,220.883 1065.07,220.885 1065.08,220.888 1065.08,220.891 1065.09,220.893 1065.1,220.896 1065.11,220.898 1065.12,220.901 1065.13,220.904 1065.14,220.906 1065.15,220.909 1065.16,220.911 1065.17,220.914 1065.18,220.916 1065.19,220.919 1065.2,220.922 1065.2,220.924 1065.21,220.927 1065.22,220.929 1065.23,220.932 1065.24,220.935 1065.25,220.937 1065.26,220.94 1065.27,220.942 1065.28,220.945 1065.29,220.948 1065.3,220.95 1065.31,220.953 1065.31,220.955 1065.32,220.958 1065.33,220.96 1065.34,220.963 1065.35,220.966 1065.36,220.968 1065.37,220.971 1065.38,220.973 1065.39,220.976 1065.4,220.979 1065.41,220.981 1065.42,220.984 1065.42,220.986 1065.43,220.989 1065.44,220.991 1065.45,220.994 1065.46,220.997 1065.47,220.999 1065.48,221.002 1065.49,221.004 1065.5,221.007 1065.51,221.01 1065.52,221.012 1065.53,221.015 1065.54,221.017 1065.54,221.02 1065.55,221.022 1065.56,221.025 1065.57,221.028 1065.58,221.03 1065.59,221.033 1065.6,221.035 1065.61,221.038 1065.62,221.041 1065.63,221.043 1065.64,221.046 1065.65,221.048 1065.65,221.051 1065.66,221.053 1065.67,221.056 1065.68,221.059 1065.69,221.061 1065.7,221.064 1065.71,221.066 1065.72,221.069 1065.73,221.072 1065.74,221.074 1065.75,221.077 1065.76,221.079 1065.76,221.082 1065.77,221.085 1065.78,221.087 1065.79,221.09 1065.8,221.092 1065.81,221.095 1065.82,221.097 1065.83,221.1 1065.84,221.103 1065.85,221.105 1065.86,221.108 1065.87,221.11 1065.88,221.113 1065.88,221.116 1065.89,221.118 1065.9,221.121 1065.91,221.123 1065.92,221.126 1065.93,221.128 1065.94,221.131 1065.95,221.134 1065.96,221.136 1065.97,221.139 1065.98,221.141 1065.99,221.144 1065.99,221.147 1066,221.149 1066.01,221.152 1066.02,221.154 1066.03,221.157 1066.04,221.159 1066.05,221.162 1066.06,221.165 1066.07,221.167 1066.08,221.17 1066.09,221.172 1066.1,221.175 1066.1,221.178 1066.11,221.18 1066.12,221.183 1066.13,221.185 1066.14,221.188 1066.15,221.19 1066.16,221.193 1066.17,221.196 1066.18,221.198 1066.19,221.201 1066.2,221.203 1066.21,221.206 1066.22,221.209 1066.22,221.211 1066.23,221.214 1066.24,221.216 1066.25,221.219 1066.26,221.221 1066.27,221.224 1066.28,221.227 1066.29,221.229 1066.3,221.232 1066.31,221.234 1066.32,221.237 1066.33,221.24 1066.33,221.242 1066.34,221.245 1066.35,221.247 1066.36,221.25 1066.37,221.252 1066.38,221.255 1066.39,221.258 1066.4,221.26 1066.41,221.263 1066.42,221.265 1066.43,221.268 1066.44,221.271 1066.44,221.273 1066.45,221.276 1066.46,221.278 1066.47,221.281 1066.48,221.283 1066.49,221.286 1066.5,221.289 1066.51,221.291 1066.52,221.294 1066.53,221.296 1066.54,221.299 1066.55,221.302 1066.56,221.304 1066.56,221.307 1066.57,221.309 1066.58,221.312 1066.59,221.314 1066.6,221.317 1066.61,221.32 1066.62,221.322 1066.63,221.325 1066.64,221.327 1066.65,221.33 1066.66,221.333 1066.67,221.335 1066.67,221.338 1066.68,221.34 1066.69,221.343 1066.7,221.345 1066.71,221.348 1066.72,221.351 1066.73,221.353 1066.74,221.356 1066.75,221.358 1066.76,221.361 1066.77,221.364 1066.78,221.366 1066.78,221.369 1066.79,221.371 1066.8,221.374 1066.81,221.376 1066.82,221.379 1066.83,221.382 1066.84,221.384 1066.85,221.387 1066.86,221.389 1066.87,221.392 1066.88,221.395 1066.89,221.397 1066.9,221.4 1066.9,221.402 1066.91,221.405 1066.92,221.407 1066.93,221.41 1066.94,221.413 1066.95,221.415 1066.96,221.418 1066.97,221.42 1066.98,221.423 1066.99,221.426 1067,221.428 1067.01,221.431 1067.01,221.433 1067.02,221.436 1067.03,221.438 1067.04,221.441 1067.05,221.444 1067.06,221.446 1067.07,221.449 1067.08,221.451 1067.09,221.454 1067.1,221.457 1067.11,221.459 1067.12,221.462 1067.12,221.464 1067.13,221.467 1067.14,221.469 1067.15,221.472 1067.16,221.475 1067.17,221.477 1067.18,221.48 1067.19,221.482 1067.2,221.485 1067.21,221.488 1067.22,221.49 1067.23,221.493 1067.24,221.495 1067.24,221.498 1067.25,221.5 1067.26,221.503 1067.27,221.506 1067.28,221.508 1067.29,221.511 1067.3,221.513 1067.31,221.516 1067.32,221.518 1067.33,221.521 1067.34,221.524 1067.35,221.526 1067.35,221.529 1067.36,221.531 1067.37,221.534 1067.38,221.537 1067.39,221.539 1067.4,221.542 1067.41,221.544 1067.42,221.547 1067.43,221.549 1067.44,221.552 1067.45,221.555 1067.46,221.557 1067.46,221.56 1067.47,221.562 1067.48,221.565 1067.49,221.568 1067.5,221.57 1067.51,221.573 1067.52,221.575 1067.53,221.578 1067.54,221.58 1067.55,221.583 1067.56,221.586 1067.57,221.588 1067.58,221.591 1067.58,221.593 1067.59,221.596 1067.6,221.599 1067.61,221.601 1067.62,221.604 1067.63,221.606 1067.64,221.609 1067.65,221.611 1067.66,221.614 1067.67,221.617 1067.68,221.619 1067.69,221.622 1067.69,221.624 1067.7,221.627 1067.71,221.629 1067.72,221.632 1067.73,221.635 1067.74,221.637 1067.75,221.64 1067.76,221.642 1067.77,221.645 1067.78,221.648 1067.79,221.65 1067.8,221.653 1067.8,221.655 1067.81,221.658 1067.82,221.66 1067.83,221.663 1067.84,221.666 1067.85,221.668 1067.86,221.671 1067.87,221.673 1067.88,221.676 1067.89,221.679 1067.9,221.681 1067.91,221.684 1067.92,221.686 1067.92,221.689 1067.93,221.691 1067.94,221.694 1067.95,221.697 1067.96,221.699 1067.97,221.702 1067.98,221.704 1067.99,221.707 1068,221.709 1068.01,221.712 1068.02,221.715 1068.03,221.717 1068.03,221.72 1068.04,221.722 1068.05,221.725 1068.06,221.728 1068.07,221.73 1068.08,221.733 1068.09,221.735 1068.1,221.738 1068.11,221.74 1068.12,221.743 1068.13,221.746 1068.14,221.748 1068.14,221.751 1068.15,221.753 1068.16,221.756 1068.17,221.759 1068.18,221.761 1068.19,221.764 1068.2,221.766 1068.21,221.769 1068.22,221.771 1068.23,221.774 1068.24,221.777 1068.25,221.779 1068.26,221.782 1068.26,221.784 1068.27,221.787 1068.28,221.789 1068.29,221.792 1068.3,221.795 1068.31,221.797 1068.32,221.8 1068.33,221.802 1068.34,221.805 1068.35,221.808 1068.36,221.81 1068.37,221.813 1068.37,221.815 1068.38,221.818 1068.39,221.82 1068.4,221.823 1068.41,221.826 1068.42,221.828 1068.43,221.831 1068.44,221.833 1068.45,221.836 1068.46,221.838 1068.47,221.841 1068.48,221.844 1068.48,221.846 1068.49,221.849 1068.5,221.851 1068.51,221.854 1068.52,221.857 1068.53,221.859 1068.54,221.862 1068.55,221.864 1068.56,221.867 1068.57,221.869 1068.58,221.872 1068.59,221.875 1068.6,221.877 1068.6,221.88 1068.61,221.882 1068.62,221.885 1068.63,221.887 1068.64,221.89 1068.65,221.893 1068.66,221.895 1068.67,221.898 1068.68,221.9 1068.69,221.903 1068.7,221.906 1068.71,221.908 1068.71,221.911 1068.72,221.913 1068.73,221.916 1068.74,221.918 1068.75,221.921 1068.76,221.924 1068.77,221.926 1068.78,221.929 1068.79,221.931 1068.8,221.934 1068.81,221.936 1068.82,221.939 1068.82,221.942 1068.83,221.944 1068.84,221.947 1068.85,221.949 1068.86,221.952 1068.87,221.955 1068.88,221.957 1068.89,221.96 1068.9,221.962 1068.91,221.965 1068.92,221.967 1068.93,221.97 1068.94,221.973 1068.94,221.975 1068.95,221.978 1068.96,221.98 1068.97,221.983 1068.98,221.985 1068.99,221.988 1069,221.991 1069.01,221.993 1069.02,221.996 1069.03,221.998 1069.04,222.001 1069.05,222.004 1069.05,222.006 1069.06,222.009 1069.07,222.011 1069.08,222.014 1069.09,222.016 1069.1,222.019 1069.11,222.022 1069.12,222.024 1069.13,222.027 1069.14,222.029 1069.15,222.032 1069.16,222.034 1069.16,222.037 1069.17,222.04 1069.18,222.042 1069.19,222.045 1069.2,222.047 1069.21,222.05 1069.22,222.053 1069.23,222.055 1069.24,222.058 1069.25,222.06 1069.26,222.063 1069.27,222.065 1069.28,222.068 1069.28,222.071 1069.29,222.073 1069.3,222.076 1069.31,222.078 1069.32,222.081 1069.33,222.083 1069.34,222.086 1069.35,222.089 1069.36,222.091 1069.37,222.094 1069.38,222.096 1069.39,222.099 1069.39,222.101 1069.4,222.104 1069.41,222.107 1069.42,222.109 1069.43,222.112 1069.44,222.114 1069.45,222.117 1069.46,222.12 1069.47,222.122 1069.48,222.125 1069.49,222.127 1069.5,222.13 1069.5,222.132 1069.51,222.135 1069.52,222.138 1069.53,222.14 1069.54,222.143 1069.55,222.145 1069.56,222.148 1069.57,222.15 1069.58,222.153 1069.59,222.156 1069.6,222.158 1069.61,222.161 1069.62,222.163 1069.62,222.166 1069.63,222.169 1069.64,222.171 1069.65,222.174 1069.66,222.176 1069.67,222.179 1069.68,222.181 1069.69,222.184 1069.7,222.187 1069.71,222.189 1069.72,222.192 1069.73,222.194 1069.73,222.197 1069.74,222.199 1069.75,222.202 1069.76,222.205 1069.77,222.207 1069.78,222.21 1069.79,222.212 1069.8,222.215 1069.81,222.217 1069.82,222.22 1069.83,222.223 1069.84,222.225 1069.84,222.228 1069.85,222.23 1069.86,222.233 1069.87,222.236 1069.88,222.238 1069.89,222.241 1069.9,222.243 1069.91,222.246 1069.92,222.248 1069.93,222.251 1069.94,222.254 1069.95,222.256 1069.96,222.259 1069.96,222.261 1069.97,222.264 1069.98,222.266 1069.99,222.269 1070,222.272 1070.01,222.274 1070.02,222.277 1070.03,222.279 1070.04,222.282 1070.05,222.284 1070.06,222.287 1070.07,222.29 1070.07,222.292 1070.08,222.295 1070.09,222.297 1070.1,222.3 1070.11,222.302 1070.12,222.305 1070.13,222.308 1070.14,222.31 1070.15,222.313 1070.16,222.315 1070.17,222.318 1070.18,222.321 1070.18,222.323 1070.19,222.326 1070.2,222.328 1070.21,222.331 1070.22,222.333 1070.23,222.336 1070.24,222.339 1070.25,222.341 1070.26,222.344 1070.27,222.346 1070.28,222.349 1070.29,222.351 1070.3,222.354 1070.3,222.357 1070.31,222.359 1070.32,222.362 1070.33,222.364 1070.34,222.367 1070.35,222.369 1070.36,222.372 1070.37,222.375 1070.38,222.377 1070.39,222.38 1070.4,222.382 1070.41,222.385 1070.41,222.388 1070.42,222.39 1070.43,222.393 1070.44,222.395 1070.45,222.398 1070.46,222.4 1070.47,222.403 1070.48,222.406 1070.49,222.408 1070.5,222.411 1070.51,222.413 1070.52,222.416 1070.52,222.418 1070.53,222.421 1070.54,222.424 1070.55,222.426 1070.56,222.429 1070.57,222.431 1070.58,222.434 1070.59,222.436 1070.6,222.439 1070.61,222.442 1070.62,222.444 1070.63,222.447 1070.64,222.449 1070.64,222.452 1070.65,222.454 1070.66,222.457 1070.67,222.46 1070.68,222.462 1070.69,222.465 1070.7,222.467 1070.71,222.47 1070.72,222.472 1070.73,222.475 1070.74,222.478 1070.75,222.48 1070.75,222.483 1070.76,222.485 1070.77,222.488 1070.78,222.491 1070.79,222.493 1070.8,222.496 1070.81,222.498 1070.82,222.501 1070.83,222.503 1070.84,222.506 1070.85,222.509 1070.86,222.511 1070.86,222.514 1070.87,222.516 1070.88,222.519 1070.89,222.521 1070.9,222.524 1070.91,222.527 1070.92,222.529 1070.93,222.532 1070.94,222.534 1070.95,222.537 1070.96,222.539 1070.97,222.542 1070.98,222.545 1070.98,222.547 1070.99,222.55 1071,222.552 1071.01,222.555 1071.02,222.557 1071.03,222.56 1071.04,222.563 1071.05,222.565 1071.06,222.568 1071.07,222.57 1071.08,222.573 1071.09,222.575 1071.09,222.578 1071.1,222.581 1071.11,222.583 1071.12,222.586 1071.13,222.588 1071.14,222.591 1071.15,222.594 1071.16,222.596 1071.17,222.599 1071.18,222.601 1071.19,222.604 1071.2,222.606 1071.2,222.609 1071.21,222.612 1071.22,222.614 1071.23,222.617 1071.24,222.619 1071.25,222.622 1071.26,222.624 1071.27,222.627 1071.28,222.63 1071.29,222.632 1071.3,222.635 1071.31,222.637 1071.32,222.64 1071.32,222.642 1071.33,222.645 1071.34,222.648 1071.35,222.65 1071.36,222.653 1071.37,222.655 1071.38,222.658 1071.39,222.66 1071.4,222.663 1071.41,222.666 1071.42,222.668 1071.43,222.671 1071.43,222.673 1071.44,222.676 1071.45,222.678 1071.46,222.681 1071.47,222.684 1071.48,222.686 1071.49,222.689 1071.5,222.691 1071.51,222.694 1071.52,222.696 1071.53,222.699 1071.54,222.702 1071.54,222.704 1071.55,222.707 1071.56,222.709 1071.57,222.712 1071.58,222.714 1071.59,222.717 1071.6,222.72 1071.61,222.722 1071.62,222.725 1071.63,222.727 1071.64,222.73 1071.65,222.732 1071.66,222.735 1071.66,222.738 1071.67,222.74 1071.68,222.743 1071.69,222.745 1071.7,222.748 1071.71,222.751 1071.72,222.753 1071.73,222.756 1071.74,222.758 1071.75,222.761 1071.76,222.763 1071.77,222.766 1071.77,222.769 1071.78,222.771 1071.79,222.774 1071.8,222.776 1071.81,222.779 1071.82,222.781 1071.83,222.784 1071.84,222.787 1071.85,222.789 1071.86,222.792 1071.87,222.794 1071.88,222.797 1071.88,222.799 1071.89,222.802 1071.9,222.805 1071.91,222.807 1071.92,222.81 1071.93,222.812 1071.94,222.815 1071.95,222.817 1071.96,222.82 1071.97,222.823 1071.98,222.825 1071.99,222.828 1072,222.83 1072,222.833 1072.01,222.835 1072.02,222.838 1072.03,222.841 1072.04,222.843 1072.05,222.846 1072.06,222.848 1072.07,222.851 1072.08,222.853 1072.09,222.856 1072.1,222.859 1072.11,222.861 1072.11,222.864 1072.12,222.866 1072.13,222.869 1072.14,222.871 1072.15,222.874 1072.16,222.877 1072.17,222.879 1072.18,222.882 1072.19,222.884 1072.2,222.887 1072.21,222.889 1072.22,222.892 1072.23,222.895 1072.23,222.897 1072.24,222.9 1072.25,222.902 1072.26,222.905 1072.27,222.907 1072.28,222.91 1072.29,222.913 1072.3,222.915 1072.31,222.918 1072.32,222.92 1072.33,222.923 1072.34,222.925 1072.34,222.928 1072.35,222.931 1072.36,222.933 1072.37,222.936 1072.38,222.938 1072.39,222.941 1072.4,222.943 1072.41,222.946 1072.42,222.949 1072.43,222.951 1072.44,222.954 1072.45,222.956 1072.45,222.959 1072.46,222.961 1072.47,222.964 1072.48,222.967 1072.49,222.969 1072.5,222.972 1072.51,222.974 1072.52,222.977 1072.53,222.979 1072.54,222.982 1072.55,222.985 1072.56,222.987 1072.57,222.99 1072.57,222.992 1072.58,222.995 1072.59,222.997 1072.6,223 1072.61,223.003 1072.62,223.005 1072.63,223.008 1072.64,223.01 1072.65,223.013 1072.66,223.015 1072.67,223.018 1072.68,223.021 1072.68,223.023 1072.69,223.026 1072.7,223.028 1072.71,223.031 1072.72,223.033 1072.73,223.036 1072.74,223.039 1072.75,223.041 1072.76,223.044 1072.77,223.046 1072.78,223.049 1072.79,223.051 1072.79,223.054 1072.8,223.057 1072.81,223.059 1072.82,223.062 1072.83,223.064 1072.84,223.067 1072.85,223.069 1072.86,223.072 1072.87,223.075 1072.88,223.077 1072.89,223.08 1072.9,223.082 1072.91,223.085 1072.91,223.087 1072.92,223.09 1072.93,223.093 1072.94,223.095 1072.95,223.098 1072.96,223.1 1072.97,223.103 1072.98,223.105 1072.99,223.108 1073,223.111 1073.01,223.113 1073.02,223.116 1073.02,223.118 1073.03,223.121 1073.04,223.123 1073.05,223.126 1073.06,223.129 1073.07,223.131 1073.08,223.134 1073.09,223.136 1073.1,223.139 1073.11,223.141 1073.12,223.144 1073.13,223.147 1073.13,223.149 1073.14,223.152 1073.15,223.154 1073.16,223.157 1073.17,223.159 1073.18,223.162 1073.19,223.165 1073.2,223.167 1073.21,223.17 1073.22,223.172 1073.23,223.175 1073.24,223.177 1073.25,223.18 1073.25,223.183 1073.26,223.185 1073.27,223.188 1073.28,223.19 1073.29,223.193 1073.3,223.195 1073.31,223.198 1073.32,223.201 1073.33,223.203 1073.34,223.206 1073.35,223.208 1073.36,223.211 1073.36,223.213 1073.37,223.216 1073.38,223.219 1073.39,223.221 1073.4,223.224 1073.41,223.226 1073.42,223.229 1073.43,223.231 1073.44,223.234 1073.45,223.237 1073.46,223.239 1073.47,223.242 1073.47,223.244 1073.48,223.247 1073.49,223.249 1073.5,223.252 1073.51,223.255 1073.52,223.257 1073.53,223.26 1073.54,223.262 1073.55,223.265 1073.56,223.267 1073.57,223.27 1073.58,223.273 1073.59,223.275 1073.59,223.278 1073.6,223.28 1073.61,223.283 1073.62,223.285 1073.63,223.288 1073.64,223.29 1073.65,223.293 1073.66,223.296 1073.67,223.298 1073.68,223.301 1073.69,223.303 1073.7,223.306 1073.7,223.308 1073.71,223.311 1073.72,223.314 1073.73,223.316 1073.74,223.319 1073.75,223.321 1073.76,223.324 1073.77,223.326 1073.78,223.329 1073.79,223.332 1073.8,223.334 1073.81,223.337 1073.81,223.339 1073.82,223.342 1073.83,223.344 1073.84,223.347 1073.85,223.35 1073.86,223.352 1073.87,223.355 1073.88,223.357 1073.89,223.36 1073.9,223.362 1073.91,223.365 1073.92,223.368 1073.93,223.37 1073.93,223.373 1073.94,223.375 1073.95,223.378 1073.96,223.38 1073.97,223.383 1073.98,223.386 1073.99,223.388 1074,223.391 1074.01,223.393 1074.02,223.396 1074.03,223.398 1074.04,223.401 1074.04,223.404 1074.05,223.406 1074.06,223.409 1074.07,223.411 1074.08,223.414 1074.09,223.416 1074.1,223.419 1074.11,223.422 1074.12,223.424 1074.13,223.427 1074.14,223.429 1074.15,223.432 1074.15,223.434 1074.16,223.437 1074.17,223.439 1074.18,223.442 1074.19,223.445 1074.2,223.447 1074.21,223.45 1074.22,223.452 1074.23,223.455 1074.24,223.457 1074.25,223.46 1074.26,223.463 1074.27,223.465 1074.27,223.468 1074.28,223.47 1074.29,223.473 1074.3,223.475 1074.31,223.478 1074.32,223.481 1074.33,223.483 1074.34,223.486 1074.35,223.488 1074.36,223.491 1074.37,223.493 1074.38,223.496 1074.38,223.499 1074.39,223.501 1074.4,223.504 1074.41,223.506 1074.42,223.509 1074.43,223.511 1074.44,223.514 1074.45,223.517 1074.46,223.519 1074.47,223.522 1074.48,223.524 1074.49,223.527 1074.49,223.529 1074.5,223.532 1074.51,223.535 1074.52,223.537 1074.53,223.54 1074.54,223.542 1074.55,223.545 1074.56,223.547 1074.57,223.55 1074.58,223.552 1074.59,223.555 1074.6,223.558 1074.61,223.56 1074.61,223.563 1074.62,223.565 1074.63,223.568 1074.64,223.57 1074.65,223.573 1074.66,223.576 1074.67,223.578 1074.68,223.581 1074.69,223.583 1074.7,223.586 1074.71,223.588 1074.72,223.591 1074.72,223.594 1074.73,223.596 1074.74,223.599 1074.75,223.601 1074.76,223.604 1074.77,223.606 1074.78,223.609 1074.79,223.612 1074.8,223.614 1074.81,223.617 1074.82,223.619 1074.83,223.622 1074.83,223.624 1074.84,223.627 1074.85,223.63 1074.86,223.632 1074.87,223.635 1074.88,223.637 1074.89,223.64 1074.9,223.642 1074.91,223.645 1074.92,223.647 1074.93,223.65 1074.94,223.653 1074.95,223.655 1074.95,223.658 1074.96,223.66 1074.97,223.663 1074.98,223.665 1074.99,223.668 1075,223.671 1075.01,223.673 1075.02,223.676 1075.03,223.678 1075.04,223.681 1075.05,223.683 1075.06,223.686 1075.06,223.689 1075.07,223.691 1075.08,223.694 1075.09,223.696 1075.1,223.699 1075.11,223.701 1075.12,223.704 1075.13,223.707 1075.14,223.709 1075.15,223.712 1075.16,223.714 1075.17,223.717 1075.17,223.719 1075.18,223.722 1075.19,223.724 1075.2,223.727 1075.21,223.73 1075.22,223.732 1075.23,223.735 1075.24,223.737 1075.25,223.74 1075.26,223.742 1075.27,223.745 1075.28,223.748 1075.29,223.75 1075.29,223.753 1075.3,223.755 1075.31,223.758 1075.32,223.76 1075.33,223.763 1075.34,223.766 1075.35,223.768 1075.36,223.771 1075.37,223.773 1075.38,223.776 1075.39,223.778 1075.4,223.781 1075.4,223.784 1075.41,223.786 1075.42,223.789 1075.43,223.791 1075.44,223.794 1075.45,223.796 1075.46,223.799 1075.47,223.801 1075.48,223.804 1075.49,223.807 1075.5,223.809 1075.51,223.812 1075.51,223.814 1075.52,223.817 1075.53,223.819 1075.54,223.822 1075.55,223.825 1075.56,223.827 1075.57,223.83 1075.58,223.832 1075.59,223.835 1075.6,223.837 1075.61,223.84 1075.62,223.843 1075.63,223.845 1075.63,223.848 1075.64,223.85 1075.65,223.853 1075.66,223.855 1075.67,223.858 1075.68,223.86 1075.69,223.863 1075.7,223.866 1075.71,223.868 1075.72,223.871 1075.73,223.873 1075.74,223.876 1075.74,223.878 1075.75,223.881 1075.76,223.884 1075.77,223.886 1075.78,223.889 1075.79,223.891 1075.8,223.894 1075.81,223.896 1075.82,223.899 1075.83,223.902 1075.84,223.904 1075.85,223.907 1075.85,223.909 1075.86,223.912 1075.87,223.914 1075.88,223.917 1075.89,223.92 1075.9,223.922 1075.91,223.925 1075.92,223.927 1075.93,223.93 1075.94,223.932 1075.95,223.935 1075.96,223.937 1075.97,223.94 1075.97,223.943 1075.98,223.945 1075.99,223.948 1076,223.95 1076.01,223.953 1076.02,223.955 1076.03,223.958 1076.04,223.961 1076.05,223.963 1076.06,223.966 1076.07,223.968 1076.08,223.971 1076.08,223.973 1076.09,223.976 1076.1,223.978 1076.11,223.981 1076.12,223.984 1076.13,223.986 1076.14,223.989 1076.15,223.991 1076.16,223.994 1076.17,223.996 1076.18,223.999 1076.19,224.002 1076.19,224.004 1076.2,224.007 1076.21,224.009 1076.22,224.012 1076.23,224.014 1076.24,224.017 1076.25,224.02 1076.26,224.022 1076.27,224.025 1076.28,224.027 1076.29,224.03 1076.3,224.032 1076.31,224.035 1076.31,224.037 1076.32,224.04 1076.33,224.043 1076.34,224.045 1076.35,224.048 1076.36,224.05 1076.37,224.053 1076.38,224.055 1076.39,224.058 1076.4,224.061 1076.41,224.063 1076.42,224.066 1076.42,224.068 1076.43,224.071 1076.44,224.073 1076.45,224.076 1076.46,224.079 1076.47,224.081 1076.48,224.084 1076.49,224.086 1076.5,224.089 1076.51,224.091 1076.52,224.094 1076.53,224.096 1076.53,224.099 1076.54,224.102 1076.55,224.104 1076.56,224.107 1076.57,224.109 1076.58,224.112 1076.59,224.114 1076.6,224.117 1076.61,224.12 1076.62,224.122 1076.63,224.125 1076.64,224.127 1076.65,224.13 1076.65,224.132 1076.66,224.135 1076.67,224.137 1076.68,224.14 1076.69,224.143 1076.7,224.145 1076.71,224.148 1076.72,224.15 1076.73,224.153 1076.74,224.155 1076.75,224.158 1076.76,224.161 1076.76,224.163 1076.77,224.166 1076.78,224.168 1076.79,224.171 1076.8,224.173 1076.81,224.176 1076.82,224.179 1076.83,224.181 1076.84,224.184 1076.85,224.186 1076.86,224.189 1076.87,224.191 1076.87,224.194 1076.88,224.196 1076.89,224.199 1076.9,224.202 1076.91,224.204 1076.92,224.207 1076.93,224.209 1076.94,224.212 1076.95,224.214 1076.96,224.217 1076.97,224.22 1076.98,224.222 1076.99,224.225 1076.99,224.227 1077,224.23 1077.01,224.232 1077.02,224.235 1077.03,224.237 1077.04,224.24 1077.05,224.243 1077.06,224.245 1077.07,224.248 1077.08,224.25 1077.09,224.253 1077.1,224.255 1077.1,224.258 1077.11,224.261 1077.12,224.263 1077.13,224.266 1077.14,224.268 1077.15,224.271 1077.16,224.273 1077.17,224.276 1077.18,224.278 1077.19,224.281 1077.2,224.284 1077.21,224.286 1077.21,224.289 1077.22,224.291 1077.23,224.294 1077.24,224.296 1077.25,224.299 1077.26,224.302 1077.27,224.304 1077.28,224.307 1077.29,224.309 1077.3,224.312 1077.31,224.314 1077.32,224.317 1077.33,224.319 1077.33,224.322 1077.34,224.325 1077.35,224.327 1077.36,224.33 1077.37,224.332 1077.38,224.335 1077.39,224.337 1077.4,224.34 1077.41,224.343 1077.42,224.345 1077.43,224.348 1077.44,224.35 1077.44,224.353 1077.45,224.355 1077.46,224.358 1077.47,224.36 1077.48,224.363 1077.49,224.366 1077.5,224.368 1077.51,224.371 1077.52,224.373 1077.53,224.376 1077.54,224.378 1077.55,224.381 1077.55,224.384 1077.56,224.386 1077.57,224.389 1077.58,224.391 1077.59,224.394 1077.6,224.396 1077.61,224.399 1077.62,224.401 1077.63,224.404 1077.64,224.407 1077.65,224.409 1077.66,224.412 1077.67,224.414 1077.67,224.417 1077.68,224.419 1077.69,224.422 1077.7,224.425 1077.71,224.427 1077.72,224.43 1077.73,224.432 1077.74,224.435 1077.75,224.437 1077.76,224.44 1077.77,224.442 1077.78,224.445 1077.78,224.448 1077.79,224.45 1077.8,224.453 1077.81,224.455 1077.82,224.458 1077.83,224.46 1077.84,224.463 1077.85,224.465 1077.86,224.468 1077.87,224.471 1077.88,224.473 1077.89,224.476 1077.89,224.478 1077.9,224.481 1077.91,224.483 1077.92,224.486 1077.93,224.489 1077.94,224.491 1077.95,224.494 1077.96,224.496 1077.97,224.499 1077.98,224.501 1077.99,224.504 1078,224.506 1078.01,224.509 1078.01,224.512 1078.02,224.514 1078.03,224.517 1078.04,224.519 1078.05,224.522 1078.06,224.524 1078.07,224.527 1078.08,224.53 1078.09,224.532 1078.1,224.535 1078.11,224.537 1078.12,224.54 1078.12,224.542 1078.13,224.545 1078.14,224.547 1078.15,224.55 1078.16,224.553 1078.17,224.555 1078.18,224.558 1078.19,224.56 1078.2,224.563 1078.21,224.565 1078.22,224.568 1078.23,224.571 1078.23,224.573 1078.24,224.576 1078.25,224.578 1078.26,224.581 1078.27,224.583 1078.28,224.586 1078.29,224.588 1078.3,224.591 1078.31,224.594 1078.32,224.596 1078.33,224.599 1078.34,224.601 1078.35,224.604 1078.35,224.606 1078.36,224.609 1078.37,224.611 1078.38,224.614 1078.39,224.617 1078.4,224.619 1078.41,224.622 1078.42,224.624 1078.43,224.627 1078.44,224.629 1078.45,224.632 1078.46,224.635 1078.46,224.637 1078.47,224.64 1078.48,224.642 1078.49,224.645 1078.5,224.647 1078.51,224.65 1078.52,224.652 1078.53,224.655 1078.54,224.658 1078.55,224.66 1078.56,224.663 1078.57,224.665 1078.57,224.668 1078.58,224.67 1078.59,224.673 1078.6,224.675 1078.61,224.678 1078.62,224.681 1078.63,224.683 1078.64,224.686 1078.65,224.688 1078.66,224.691 1078.67,224.693 1078.68,224.696 1078.69,224.699 1078.69,224.701 1078.7,224.704 1078.71,224.706 1078.72,224.709 1078.73,224.711 1078.74,224.714 1078.75,224.716 1078.76,224.719 1078.77,224.722 1078.78,224.724 1078.79,224.727 1078.8,224.729 1078.8,224.732 1078.81,224.734 1078.82,224.737 1078.83,224.739 1078.84,224.742 1078.85,224.745 1078.86,224.747 1078.87,224.75 1078.88,224.752 1078.89,224.755 1078.9,224.757 1078.91,224.76 1078.91,224.763 1078.92,224.765 1078.93,224.768 1078.94,224.77 1078.95,224.773 1078.96,224.775 1078.97,224.778 1078.98,224.78 1078.99,224.783 1079,224.786 1079.01,224.788 1079.02,224.791 1079.03,224.793 1079.03,224.796 1079.04,224.798 1079.05,224.801 1079.06,224.803 1079.07,224.806 1079.08,224.809 1079.09,224.811 1079.1,224.814 1079.11,224.816 1079.12,224.819 1079.13,224.821 1079.14,224.824 1079.14,224.826 1079.15,224.829 1079.16,224.832 1079.17,224.834 1079.18,224.837 1079.19,224.839 1079.2,224.842 1079.21,224.844 1079.22,224.847 1079.23,224.85 1079.24,224.852 1079.25,224.855 1079.25,224.857 1079.26,224.86 1079.27,224.862 1079.28,224.865 1079.29,224.867 1079.3,224.87 1079.31,224.873 1079.32,224.875 1079.33,224.878 1079.34,224.88 1079.35,224.883 1079.36,224.885 1079.37,224.888 1079.37,224.89 1079.38,224.893 1079.39,224.896 1079.4,224.898 1079.41,224.901 1079.42,224.903 1079.43,224.906 1079.44,224.908 1079.45,224.911 1079.46,224.913 1079.47,224.916 1079.48,224.919 1079.48,224.921 1079.49,224.924 1079.5,224.926 1079.51,224.929 1079.52,224.931 1079.53,224.934 1079.54,224.937 1079.55,224.939 1079.56,224.942 1079.57,224.944 1079.58,224.947 1079.59,224.949 1079.59,224.952 1079.6,224.954 1079.61,224.957 1079.62,224.96 1079.63,224.962 1079.64,224.965 1079.65,224.967 1079.66,224.97 1079.67,224.972 1079.68,224.975 1079.69,224.977 1079.7,224.98 1079.71,224.983 1079.71,224.985 1079.72,224.988 1079.73,224.99 1079.74,224.993 1079.75,224.995 1079.76,224.998 1079.77,225 1079.78,225.003 1079.79,225.006 1079.8,225.008 1079.81,225.011 1079.82,225.013 1079.82,225.016 1079.83,225.018 1079.84,225.021 1079.85,225.023 1079.86,225.026 1079.87,225.029 1079.88,225.031 1079.89,225.034 1079.9,225.036 1079.91,225.039 1079.92,225.041 1079.93,225.044 1079.93,225.047 1079.94,225.049 1079.95,225.052 1079.96,225.054 1079.97,225.057 1079.98,225.059 1079.99,225.062 1080,225.064 1080.01,225.067 1080.02,225.07 1080.03,225.072 1080.04,225.075 1080.05,225.077 1080.05,225.08 1080.06,225.082 1080.07,225.085 1080.08,225.087 1080.09,225.09 1080.1,225.093 1080.11,225.095 1080.12,225.098 1080.13,225.1 1080.14,225.103 1080.15,225.105 1080.16,225.108 1080.16,225.11 1080.17,225.113 1080.18,225.116 1080.19,225.118 1080.2,225.121 1080.21,225.123 1080.22,225.126 1080.23,225.128 1080.24,225.131 1080.25,225.133 1080.26,225.136 1080.27,225.139 1080.27,225.141 1080.28,225.144 1080.29,225.146 1080.3,225.149 1080.31,225.151 1080.32,225.154 1080.33,225.156 1080.34,225.159 1080.35,225.162 1080.36,225.164 1080.37,225.167 1080.38,225.169 1080.39,225.172 1080.39,225.174 1080.4,225.177 1080.41,225.179 1080.42,225.182 1080.43,225.185 1080.44,225.187 1080.45,225.19 1080.46,225.192 1080.47,225.195 1080.48,225.197 1080.49,225.2 1080.5,225.202 1080.5,225.205 1080.51,225.208 1080.52,225.21 1080.53,225.213 1080.54,225.215 1080.55,225.218 1080.56,225.22 1080.57,225.223 1080.58,225.225 1080.59,225.228 1080.6,225.231 1080.61,225.233 1080.61,225.236 1080.62,225.238 1080.63,225.241 1080.64,225.243 1080.65,225.246 1080.66,225.248 1080.67,225.251 1080.68,225.254 1080.69,225.256 1080.7,225.259 1080.71,225.261 1080.72,225.264 1080.73,225.266 1080.73,225.269 1080.74,225.271 1080.75,225.274 1080.76,225.277 1080.77,225.279 1080.78,225.282 1080.79,225.284 1080.8,225.287 1080.81,225.289 1080.82,225.292 1080.83,225.295 1080.84,225.297 1080.84,225.3 1080.85,225.302 1080.86,225.305 1080.87,225.307 1080.88,225.31 1080.89,225.312 1080.9,225.315 1080.91,225.318 1080.92,225.32 1080.93,225.323 1080.94,225.325 1080.95,225.328 1080.95,225.33 1080.96,225.333 1080.97,225.335 1080.98,225.338 1080.99,225.341 1081,225.343 1081.01,225.346 1081.02,225.348 1081.03,225.351 1081.04,225.353 1081.05,225.356 1081.06,225.358 1081.07,225.361 1081.07,225.364 1081.08,225.366 1081.09,225.369 1081.1,225.371 1081.11,225.374 1081.12,225.376 1081.13,225.379 1081.14,225.381 1081.15,225.384 1081.16,225.386 1081.17,225.389 1081.18,225.392 1081.18,225.394 1081.19,225.397 1081.2,225.399 1081.21,225.402 1081.22,225.404 1081.23,225.407 1081.24,225.409 1081.25,225.412 1081.26,225.415 1081.27,225.417 1081.28,225.42 1081.29,225.422 1081.29,225.425 1081.3,225.427 1081.31,225.43 1081.32,225.432 1081.33,225.435 1081.34,225.438 1081.35,225.44 1081.36,225.443 1081.37,225.445 1081.38,225.448 1081.39,225.45 1081.4,225.453 1081.41,225.455 1081.41,225.458 1081.42,225.461 1081.43,225.463 1081.44,225.466 1081.45,225.468 1081.46,225.471 1081.47,225.473 1081.48,225.476 1081.49,225.478 1081.5,225.481 1081.51,225.484 1081.52,225.486 1081.52,225.489 1081.53,225.491 1081.54,225.494 1081.55,225.496 1081.56,225.499 1081.57,225.501 1081.58,225.504 1081.59,225.507 1081.6,225.509 1081.61,225.512 1081.62,225.514 1081.63,225.517 1081.63,225.519 1081.64,225.522 1081.65,225.524 1081.66,225.527 1081.67,225.53 1081.68,225.532 1081.69,225.535 1081.7,225.537 1081.71,225.54 1081.72,225.542 1081.73,225.545 1081.74,225.547 1081.75,225.55 1081.75,225.553 1081.76,225.555 1081.77,225.558 1081.78,225.56 1081.79,225.563 1081.8,225.565 1081.81,225.568 1081.82,225.57 1081.83,225.573 1081.84,225.576 1081.85,225.578 1081.86,225.581 1081.86,225.583 1081.87,225.586 1081.88,225.588 1081.89,225.591 1081.9,225.593 1081.91,225.596 1081.92,225.599 1081.93,225.601 1081.94,225.604 1081.95,225.606 1081.96,225.609 1081.97,225.611 1081.97,225.614 1081.98,225.616 1081.99,225.619 1082,225.622 1082.01,225.624 1082.02,225.627 1082.03,225.629 1082.04,225.632 1082.05,225.634 1082.06,225.637 1082.07,225.639 1082.08,225.642 1082.09,225.644 1082.09,225.647 1082.1,225.65 1082.11,225.652 1082.12,225.655 1082.13,225.657 1082.14,225.66 1082.15,225.662 1082.16,225.665 1082.17,225.667 1082.18,225.67 1082.19,225.673 1082.2,225.675 1082.2,225.678 1082.21,225.68 1082.22,225.683 1082.23,225.685 1082.24,225.688 1082.25,225.69 1082.26,225.693 1082.27,225.696 1082.28,225.698 1082.29,225.701 1082.3,225.703 1082.31,225.706 1082.31,225.708 1082.32,225.711 1082.33,225.713 1082.34,225.716 1082.35,225.719 1082.36,225.721 1082.37,225.724 1082.38,225.726 1082.39,225.729 1082.4,225.731 1082.41,225.734 1082.42,225.736 1082.43,225.739 1082.43,225.741 1082.44,225.744 1082.45,225.747 1082.46,225.749 1082.47,225.752 1082.48,225.754 1082.49,225.757 1082.5,225.759 1082.51,225.762 1082.52,225.764 1082.53,225.767 1082.54,225.77 1082.54,225.772 1082.55,225.775 1082.56,225.777 1082.57,225.78 1082.58,225.782 1082.59,225.785 1082.6,225.787 1082.61,225.79 1082.62,225.793 1082.63,225.795 1082.64,225.798 1082.65,225.8 1082.65,225.803 1082.66,225.805 1082.67,225.808 1082.68,225.81 1082.69,225.813 1082.7,225.816 1082.71,225.818 1082.72,225.821 1082.73,225.823 1082.74,225.826 1082.75,225.828 1082.76,225.831 1082.77,225.833 1082.77,225.836 1082.78,225.838 1082.79,225.841 1082.8,225.844 1082.81,225.846 1082.82,225.849 1082.83,225.851 1082.84,225.854 1082.85,225.856 1082.86,225.859 1082.87,225.861 1082.88,225.864 1082.88,225.867 1082.89,225.869 1082.9,225.872 1082.91,225.874 1082.92,225.877 1082.93,225.879 1082.94,225.882 1082.95,225.884 1082.96,225.887 1082.97,225.89 1082.98,225.892 1082.99,225.895 1082.99,225.897 1083,225.9 1083.01,225.902 1083.02,225.905 1083.03,225.907 1083.04,225.91 1083.05,225.912 1083.06,225.915 1083.07,225.918 1083.08,225.92 1083.09,225.923 1083.1,225.925 1083.11,225.928 1083.11,225.93 1083.12,225.933 1083.13,225.935 1083.14,225.938 1083.15,225.941 1083.16,225.943 1083.17,225.946 1083.18,225.948 1083.19,225.951 1083.2,225.953 1083.21,225.956 1083.22,225.958 1083.22,225.961 1083.23,225.964 1083.24,225.966 1083.25,225.969 1083.26,225.971 1083.27,225.974 1083.28,225.976 1083.29,225.979 1083.3,225.981 1083.31,225.984 1083.32,225.986 1083.33,225.989 1083.33,225.992 1083.34,225.994 1083.35,225.997 1083.36,225.999 1083.37,226.002 1083.38,226.004 1083.39,226.007 1083.4,226.009 1083.41,226.012 1083.42,226.015 1083.43,226.017 1083.44,226.02 1083.45,226.022 1083.45,226.025 1083.46,226.027 1083.47,226.03 1083.48,226.032 1083.49,226.035 1083.5,226.037 1083.51,226.04 1083.52,226.043 1083.53,226.045 1083.54,226.048 1083.55,226.05 1083.56,226.053 1083.56,226.055 1083.57,226.058 1083.58,226.06 1083.59,226.063 1083.6,226.066 1083.61,226.068 1083.62,226.071 1083.63,226.073 1083.64,226.076 1083.65,226.078 1083.66,226.081 1083.67,226.083 1083.67,226.086 1083.68,226.089 1083.69,226.091 1083.7,226.094 1083.71,226.096 1083.72,226.099 1083.73,226.101 1083.74,226.104 1083.75,226.106 1083.76,226.109 1083.77,226.111 1083.78,226.114 1083.79,226.117 1083.79,226.119 1083.8,226.122 1083.81,226.124 1083.82,226.127 1083.83,226.129 1083.84,226.132 1083.85,226.134 1083.86,226.137 1083.87,226.14 1083.88,226.142 1083.89,226.145 1083.9,226.147 1083.9,226.15 1083.91,226.152 1083.92,226.155 1083.93,226.157 1083.94,226.16 1083.95,226.162 1083.96,226.165 1083.97,226.168 1083.98,226.17 1083.99,226.173 1084,226.175 1084.01,226.178 1084.01,226.18 1084.02,226.183 1084.03,226.185 1084.04,226.188 1084.05,226.191 1084.06,226.193 1084.07,226.196 1084.08,226.198 1084.09,226.201 1084.1,226.203 1084.11,226.206 1084.12,226.208 1084.13,226.211 1084.13,226.213 1084.14,226.216 1084.15,226.219 1084.16,226.221 1084.17,226.224 1084.18,226.226 1084.19,226.229 1084.2,226.231 1084.21,226.234 1084.22,226.236 1084.23,226.239 1084.24,226.241 1084.24,226.244 1084.25,226.247 1084.26,226.249 1084.27,226.252 1084.28,226.254 1084.29,226.257 1084.3,226.259 1084.31,226.262 1084.32,226.264 1084.33,226.267 1084.34,226.27 1084.35,226.272 1084.35,226.275 1084.36,226.277 1084.37,226.28 1084.38,226.282 1084.39,226.285 1084.4,226.287 1084.41,226.29 1084.42,226.292 1084.43,226.295 1084.44,226.298 1084.45,226.3 1084.46,226.303 1084.47,226.305 1084.47,226.308 1084.48,226.31 1084.49,226.313 1084.5,226.315 1084.51,226.318 1084.52,226.321 1084.53,226.323 1084.54,226.326 1084.55,226.328 1084.56,226.331 1084.57,226.333 1084.58,226.336 1084.58,226.338 1084.59,226.341 1084.6,226.343 1084.61,226.346 1084.62,226.349 1084.63,226.351 1084.64,226.354 1084.65,226.356 1084.66,226.359 1084.67,226.361 1084.68,226.364 1084.69,226.366 1084.69,226.369 1084.7,226.371 1084.71,226.374 1084.72,226.377 1084.73,226.379 1084.74,226.382 1084.75,226.384 1084.76,226.387 1084.77,226.389 1084.78,226.392 1084.79,226.394 1084.8,226.397 1084.81,226.4 1084.81,226.402 1084.82,226.405 1084.83,226.407 1084.84,226.41 1084.85,226.412 1084.86,226.415 1084.87,226.417 1084.88,226.42 1084.89,226.422 1084.9,226.425 1084.91,226.428 1084.92,226.43 1084.92,226.433 1084.93,226.435 1084.94,226.438 1084.95,226.44 1084.96,226.443 1084.97,226.445 1084.98,226.448 1084.99,226.45 1085,226.453 1085.01,226.456 1085.02,226.458 1085.03,226.461 1085.03,226.463 1085.04,226.466 1085.05,226.468 1085.06,226.471 1085.07,226.473 1085.08,226.476 1085.09,226.479 1085.1,226.481 1085.11,226.484 1085.12,226.486 1085.13,226.489 1085.14,226.491 1085.15,226.494 1085.15,226.496 1085.16,226.499 1085.17,226.501 1085.18,226.504 1085.19,226.507 1085.2,226.509 1085.21,226.512 1085.22,226.514 1085.23,226.517 1085.24,226.519 1085.25,226.522 1085.26,226.524 1085.26,226.527 1085.27,226.529 1085.28,226.532 1085.29,226.535 1085.3,226.537 1085.31,226.54 1085.32,226.542 1085.33,226.545 1085.34,226.547 1085.35,226.55 1085.36,226.552 1085.37,226.555 1085.37,226.557 1085.38,226.56 1085.39,226.563 1085.4,226.565 1085.41,226.568 1085.42,226.57 1085.43,226.573 1085.44,226.575 1085.45,226.578 1085.46,226.58 1085.47,226.583 1085.48,226.585 1085.49,226.588 1085.49,226.591 1085.5,226.593 1085.51,226.596 1085.52,226.598 1085.53,226.601 1085.54,226.603 1085.55,226.606 1085.56,226.608 1085.57,226.611 1085.58,226.614 1085.59,226.616 1085.6,226.619 1085.6,226.621 1085.61,226.624 1085.62,226.626 1085.63,226.629 1085.64,226.631 1085.65,226.634 1085.66,226.636 1085.67,226.639 1085.68,226.642 1085.69,226.644 1085.7,226.647 1085.71,226.649 1085.71,226.652 1085.72,226.654 1085.73,226.657 1085.74,226.659 1085.75,226.662 1085.76,226.664 1085.77,226.667 1085.78,226.67 1085.79,226.672 1085.8,226.675 1085.81,226.677 1085.82,226.68 1085.83,226.682 1085.83,226.685 1085.84,226.687 1085.85,226.69 1085.86,226.692 1085.87,226.695 1085.88,226.698 1085.89,226.7 1085.9,226.703 1085.91,226.705 1085.92,226.708 1085.93,226.71 1085.94,226.713 1085.94,226.715 1085.95,226.718 1085.96,226.72 1085.97,226.723 1085.98,226.726 1085.99,226.728 1086,226.731 1086.01,226.733 1086.02,226.736 1086.03,226.738 1086.04,226.741 1086.05,226.743 1086.05,226.746 1086.06,226.748 1086.07,226.751 1086.08,226.754 1086.09,226.756 1086.1,226.759 1086.11,226.761 1086.12,226.764 1086.13,226.766 1086.14,226.769 1086.15,226.771 1086.16,226.774 1086.17,226.776 1086.17,226.779 1086.18,226.782 1086.19,226.784 1086.2,226.787 1086.21,226.789 1086.22,226.792 1086.23,226.794 1086.24,226.797 1086.25,226.799 1086.26,226.802 1086.27,226.804 1086.28,226.807 1086.28,226.81 1086.29,226.812 1086.3,226.815 1086.31,226.817 1086.32,226.82 1086.33,226.822 1086.34,226.825 1086.35,226.827 1086.36,226.83 1086.37,226.832 1086.38,226.835 1086.39,226.838 1086.39,226.84 1086.4,226.843 1086.41,226.845 1086.42,226.848 1086.43,226.85 1086.44,226.853 1086.45,226.855 1086.46,226.858 1086.47,226.86 1086.48,226.863 1086.49,226.866 1086.5,226.868 1086.51,226.871 1086.51,226.873 1086.52,226.876 1086.53,226.878 1086.54,226.881 1086.55,226.883 1086.56,226.886 1086.57,226.888 1086.58,226.891 1086.59,226.894 1086.6,226.896 1086.61,226.899 1086.62,226.901 1086.62,226.904 1086.63,226.906 1086.64,226.909 1086.65,226.911 1086.66,226.914 1086.67,226.916 1086.68,226.919 1086.69,226.922 1086.7,226.924 1086.71,226.927 1086.72,226.929 1086.73,226.932 1086.73,226.934 1086.74,226.937 1086.75,226.939 1086.76,226.942 1086.77,226.944 1086.78,226.947 1086.79,226.95 1086.8,226.952 1086.81,226.955 1086.82,226.957 1086.83,226.96 1086.84,226.962 1086.85,226.965 1086.85,226.967 1086.86,226.97 1086.87,226.972 1086.88,226.975 1086.89,226.978 1086.9,226.98 1086.91,226.983 1086.92,226.985 1086.93,226.988 1086.94,226.99 1086.95,226.993 1086.96,226.995 1086.96,226.998 1086.97,227 1086.98,227.003 1086.99,227.006 1087,227.008 1087.01,227.011 1087.02,227.013 1087.03,227.016 1087.04,227.018 1087.05,227.021 1087.06,227.023 1087.07,227.026 1087.07,227.028 1087.08,227.031 1087.09,227.033 1087.1,227.036 1087.11,227.039 1087.12,227.041 1087.13,227.044 1087.14,227.046 1087.15,227.049 1087.16,227.051 1087.17,227.054 1087.18,227.056 1087.19,227.059 1087.19,227.061 1087.2,227.064 1087.21,227.067 1087.22,227.069 1087.23,227.072 1087.24,227.074 1087.25,227.077 1087.26,227.079 1087.27,227.082 1087.28,227.084 1087.29,227.087 1087.3,227.089 1087.3,227.092 1087.31,227.095 1087.32,227.097 1087.33,227.1 1087.34,227.102 1087.35,227.105 1087.36,227.107 1087.37,227.11 1087.38,227.112 1087.39,227.115 1087.4,227.117 1087.41,227.12 1087.41,227.123 1087.42,227.125 1087.43,227.128 1087.44,227.13 1087.45,227.133 1087.46,227.135 1087.47,227.138 1087.48,227.14 1087.49,227.143 1087.5,227.145 1087.51,227.148 1087.52,227.15 1087.53,227.153 1087.53,227.156 1087.54,227.158 1087.55,227.161 1087.56,227.163 1087.57,227.166 1087.58,227.168 1087.59,227.171 1087.6,227.173 1087.61,227.176 1087.62,227.178 1087.63,227.181 1087.64,227.184 1087.64,227.186 1087.65,227.189 1087.66,227.191 1087.67,227.194 1087.68,227.196 1087.69,227.199 1087.7,227.201 1087.71,227.204 1087.72,227.206 1087.73,227.209 1087.74,227.212 1087.75,227.214 1087.75,227.217 1087.76,227.219 1087.77,227.222 1087.78,227.224 1087.79,227.227 1087.8,227.229 1087.81,227.232 1087.82,227.234 1087.83,227.237 1087.84,227.239 1087.85,227.242 1087.86,227.245 1087.87,227.247 1087.87,227.25 1087.88,227.252 1087.89,227.255 1087.9,227.257 1087.91,227.26 1087.92,227.262 1087.93,227.265 1087.94,227.267 1087.95,227.27 1087.96,227.273 1087.97,227.275 1087.98,227.278 1087.98,227.28 1087.99,227.283 1088,227.285 1088.01,227.288 1088.02,227.29 1088.03,227.293 1088.04,227.295 1088.05,227.298 1088.06,227.3 1088.07,227.303 1088.08,227.306 1088.09,227.308 1088.09,227.311 1088.1,227.313 1088.11,227.316 1088.12,227.318 1088.13,227.321 1088.14,227.323 1088.15,227.326 1088.16,227.328 1088.17,227.331 1088.18,227.334 1088.19,227.336 1088.2,227.339 1088.21,227.341 1088.21,227.344 1088.22,227.346 1088.23,227.349 1088.24,227.351 1088.25,227.354 1088.26,227.356 1088.27,227.359 1088.28,227.362 1088.29,227.364 1088.3,227.367 1088.31,227.369 1088.32,227.372 1088.32,227.374 1088.33,227.377 1088.34,227.379 1088.35,227.382 1088.36,227.384 1088.37,227.387 1088.38,227.389 1088.39,227.392 1088.4,227.395 1088.41,227.397 1088.42,227.4 1088.43,227.402 1088.43,227.405 1088.44,227.407 1088.45,227.41 1088.46,227.412 1088.47,227.415 1088.48,227.417 1088.49,227.42 1088.5,227.422 1088.51,227.425 1088.52,227.428 1088.53,227.43 1088.54,227.433 1088.55,227.435 1088.55,227.438 1088.56,227.44 1088.57,227.443 1088.58,227.445 1088.59,227.448 1088.6,227.45 1088.61,227.453 1088.62,227.456 1088.63,227.458 1088.64,227.461 1088.65,227.463 1088.66,227.466 1088.66,227.468 1088.67,227.471 1088.68,227.473 1088.69,227.476 1088.7,227.478 1088.71,227.481 1088.72,227.483 1088.73,227.486 1088.74,227.489 1088.75,227.491 1088.76,227.494 1088.77,227.496 1088.77,227.499 1088.78,227.501 1088.79,227.504 1088.8,227.506 1088.81,227.509 1088.82,227.511 1088.83,227.514 1088.84,227.517 1088.85,227.519 1088.86,227.522 1088.87,227.524 1088.88,227.527 1088.89,227.529 1088.89,227.532 1088.9,227.534 1088.91,227.537 1088.92,227.539 1088.93,227.542 1088.94,227.544 1088.95,227.547 1088.96,227.55 1088.97,227.552 1088.98,227.555 1088.99,227.557 1089,227.56 1089,227.562 1089.01,227.565 1089.02,227.567 1089.03,227.57 1089.04,227.572 1089.05,227.575 1089.06,227.577 1089.07,227.58 1089.08,227.583 1089.09,227.585 1089.1,227.588 1089.11,227.59 1089.11,227.593 1089.12,227.595 1089.13,227.598 1089.14,227.6 1089.15,227.603 1089.16,227.605 1089.17,227.608 1089.18,227.61 1089.19,227.613 1089.2,227.616 1089.21,227.618 1089.22,227.621 1089.23,227.623 1089.23,227.626 1089.24,227.628 1089.25,227.631 1089.26,227.633 1089.27,227.636 1089.28,227.638 1089.29,227.641 1089.3,227.644 1089.31,227.646 1089.32,227.649 1089.33,227.651 1089.34,227.654 1089.34,227.656 1089.35,227.659 1089.36,227.661 1089.37,227.664 1089.38,227.666 1089.39,227.669 1089.4,227.671 1089.41,227.674 1089.42,227.677 1089.43,227.679 1089.44,227.682 1089.45,227.684 1089.45,227.687 1089.46,227.689 1089.47,227.692 1089.48,227.694 1089.49,227.697 1089.5,227.699 1089.51,227.702 1089.52,227.704 1089.53,227.707 1089.54,227.71 1089.55,227.712 1089.56,227.715 1089.57,227.717 1089.57,227.72 1089.58,227.722 1089.59,227.725 1089.6,227.727 1089.61,227.73 1089.62,227.732 1089.63,227.735 1089.64,227.737 1089.65,227.74 1089.66,227.743 1089.67,227.745 1089.68,227.748 1089.68,227.75 1089.69,227.753 1089.7,227.755 1089.71,227.758 1089.72,227.76 1089.73,227.763 1089.74,227.765 1089.75,227.768 1089.76,227.77 1089.77,227.773 1089.78,227.776 1089.79,227.778 1089.79,227.781 1089.8,227.783 1089.81,227.786 1089.82,227.788 1089.83,227.791 1089.84,227.793 1089.85,227.796 1089.86,227.798 1089.87,227.801 1089.88,227.803 1089.89,227.806 1089.9,227.809 1089.91,227.811 1089.91,227.814 1089.92,227.816 1089.93,227.819 1089.94,227.821 1089.95,227.824 1089.96,227.826 1089.97,227.829 1089.98,227.831 1089.99,227.834 1090,227.836 1090.01,227.839 1090.02,227.842 1090.02,227.844 1090.03,227.847 1090.04,227.849 1090.05,227.852 1090.06,227.854 1090.07,227.857 1090.08,227.859 1090.09,227.862 1090.1,227.864 1090.11,227.867 1090.12,227.869 1090.13,227.872 1090.13,227.875 1090.14,227.877 1090.15,227.88 1090.16,227.882 1090.17,227.885 1090.18,227.887 1090.19,227.89 1090.2,227.892 1090.21,227.895 1090.22,227.897 1090.23,227.9 1090.24,227.902 1090.25,227.905 1090.25,227.908 1090.26,227.91 1090.27,227.913 1090.28,227.915 1090.29,227.918 1090.3,227.92 1090.31,227.923 1090.32,227.925 1090.33,227.928 1090.34,227.93 1090.35,227.933 1090.36,227.935 1090.36,227.938 1090.37,227.941 1090.38,227.943 1090.39,227.946 1090.4,227.948 1090.41,227.951 1090.42,227.953 1090.43,227.956 1090.44,227.958 1090.45,227.961 1090.46,227.963 1090.47,227.966 1090.47,227.968 1090.48,227.971 1090.49,227.974 1090.5,227.976 1090.51,227.979 1090.52,227.981 1090.53,227.984 1090.54,227.986 1090.55,227.989 1090.56,227.991 1090.57,227.994 1090.58,227.996 1090.59,227.999 1090.59,228.001 1090.6,228.004 1090.61,228.007 1090.62,228.009 1090.63,228.012 1090.64,228.014 1090.65,228.017 1090.66,228.019 1090.67,228.022 1090.68,228.024 1090.69,228.027 1090.7,228.029 1090.7,228.032 1090.71,228.034 1090.72,228.037 1090.73,228.039 1090.74,228.042 1090.75,228.045 1090.76,228.047 1090.77,228.05 1090.78,228.052 1090.79,228.055 1090.8,228.057 1090.81,228.06 1090.81,228.062 1090.82,228.065 1090.83,228.067 1090.84,228.07 1090.85,228.072 1090.86,228.075 1090.87,228.078 1090.88,228.08 1090.89,228.083 1090.9,228.085 1090.91,228.088 1090.92,228.09 1090.93,228.093 1090.93,228.095 1090.94,228.098 1090.95,228.1 1090.96,228.103 1090.97,228.105 1090.98,228.108 1090.99,228.111 1091,228.113 1091.01,228.116 1091.02,228.118 1091.03,228.121 1091.04,228.123 1091.04,228.126 1091.05,228.128 1091.06,228.131 1091.07,228.133 1091.08,228.136 1091.09,228.138 1091.1,228.141 1091.11,228.143 1091.12,228.146 1091.13,228.149 1091.14,228.151 1091.15,228.154 1091.15,228.156 1091.16,228.159 1091.17,228.161 1091.18,228.164 1091.19,228.166 1091.2,228.169 1091.21,228.171 1091.22,228.174 1091.23,228.176 1091.24,228.179 1091.25,228.182 1091.26,228.184 1091.27,228.187 1091.27,228.189 1091.28,228.192 1091.29,228.194 1091.3,228.197 1091.31,228.199 1091.32,228.202 1091.33,228.204 1091.34,228.207 1091.35,228.209 1091.36,228.212 1091.37,228.215 1091.38,228.217 1091.38,228.22 1091.39,228.222 1091.4,228.225 1091.41,228.227 1091.42,228.23 1091.43,228.232 1091.44,228.235 1091.45,228.237 1091.46,228.24 1091.47,228.242 1091.48,228.245 1091.49,228.247 1091.49,228.25 1091.5,228.253 1091.51,228.255 1091.52,228.258 1091.53,228.26 1091.54,228.263 1091.55,228.265 1091.56,228.268 1091.57,228.27 1091.58,228.273 1091.59,228.275 1091.6,228.278 1091.61,228.28 1091.61,228.283 1091.62,228.285 1091.63,228.288 1091.64,228.291 1091.65,228.293 1091.66,228.296 1091.67,228.298 1091.68,228.301 1091.69,228.303 1091.7,228.306 1091.71,228.308 1091.72,228.311 1091.72,228.313 1091.73,228.316 1091.74,228.318 1091.75,228.321 1091.76,228.324 1091.77,228.326 1091.78,228.329 1091.79,228.331 1091.8,228.334 1091.81,228.336 1091.82,228.339 1091.83,228.341 1091.83,228.344 1091.84,228.346 1091.85,228.349 1091.86,228.351 1091.87,228.354 1091.88,228.356 1091.89,228.359 1091.9,228.362 1091.91,228.364 1091.92,228.367 1091.93,228.369 1091.94,228.372 1091.95,228.374 1091.95,228.377 1091.96,228.379 1091.97,228.382 1091.98,228.384 1091.99,228.387 1092,228.389 1092.01,228.392 1092.02,228.394 1092.03,228.397 1092.04,228.4 1092.05,228.402 1092.06,228.405 1092.06,228.407 1092.07,228.41 1092.08,228.412 1092.09,228.415 1092.1,228.417 1092.11,228.42 1092.12,228.422 1092.13,228.425 1092.14,228.427 1092.15,228.43 1092.16,228.433 1092.17,228.435 1092.17,228.438 1092.18,228.44 1092.19,228.443 1092.2,228.445 1092.21,228.448 1092.22,228.45 1092.23,228.453 1092.24,228.455 1092.25,228.458 1092.26,228.46 1092.27,228.463 1092.28,228.465 1092.29,228.468 1092.29,228.471 1092.3,228.473 1092.31,228.476 1092.32,228.478 1092.33,228.481 1092.34,228.483 1092.35,228.486 1092.36,228.488 1092.37,228.491 1092.38,228.493 1092.39,228.496 1092.4,228.498 1092.4,228.501 1092.41,228.503 1092.42,228.506 1092.43,228.509 1092.44,228.511 1092.45,228.514 1092.46,228.516 1092.47,228.519 1092.48,228.521 1092.49,228.524 1092.5,228.526 1092.51,228.529 1092.51,228.531 1092.52,228.534 1092.53,228.536 1092.54,228.539 1092.55,228.541 1092.56,228.544 1092.57,228.547 1092.58,228.549 1092.59,228.552 1092.6,228.554 1092.61,228.557 1092.62,228.559 1092.63,228.562 1092.63,228.564 1092.64,228.567 1092.65,228.569 1092.66,228.572 1092.67,228.574 1092.68,228.577 1092.69,228.579 1092.7,228.582 1092.71,228.585 1092.72,228.587 1092.73,228.59 1092.74,228.592 1092.74,228.595 1092.75,228.597 1092.76,228.6 1092.77,228.602 1092.78,228.605 1092.79,228.607 1092.8,228.61 1092.81,228.612 1092.82,228.615 1092.83,228.617 1092.84,228.62 1092.85,228.623 1092.85,228.625 1092.86,228.628 1092.87,228.63 1092.88,228.633 1092.89,228.635 1092.9,228.638 1092.91,228.64 1092.92,228.643 1092.93,228.645 1092.94,228.648 1092.95,228.65 1092.96,228.653 1092.97,228.655 1092.97,228.658 1092.98,228.661 1092.99,228.663 1093,228.666 1093.01,228.668 1093.02,228.671 1093.03,228.673 1093.04,228.676 1093.05,228.678 1093.06,228.681 1093.07,228.683 1093.08,228.686 1093.08,228.688 1093.09,228.691 1093.1,228.693 1093.11,228.696 1093.12,228.699 1093.13,228.701 1093.14,228.704 1093.15,228.706 1093.16,228.709 1093.17,228.711 1093.18,228.714 1093.19,228.716 1093.19,228.719 1093.2,228.721 1093.21,228.724 1093.22,228.726 1093.23,228.729 1093.24,228.731 1093.25,228.734 1093.26,228.737 1093.27,228.739 1093.28,228.742 1093.29,228.744 1093.3,228.747 1093.31,228.749 1093.31,228.752 1093.32,228.754 1093.33,228.757 1093.34,228.759 1093.35,228.762 1093.36,228.764 1093.37,228.767 1093.38,228.769 1093.39,228.772 1093.4,228.774 1093.41,228.777 1093.42,228.78 1093.42,228.782 1093.43,228.785 1093.44,228.787 1093.45,228.79 1093.46,228.792 1093.47,228.795 1093.48,228.797 1093.49,228.8 1093.5,228.802 1093.51,228.805 1093.52,228.807 1093.53,228.81 1093.53,228.812 1093.54,228.815 1093.55,228.818 1093.56,228.82 1093.57,228.823 1093.58,228.825 1093.59,228.828 1093.6,228.83 1093.61,228.833 1093.62,228.835 1093.63,228.838 1093.64,228.84 1093.65,228.843 1093.65,228.845 1093.66,228.848 1093.67,228.85 1093.68,228.853 1093.69,228.855 1093.7,228.858 1093.71,228.861 1093.72,228.863 1093.73,228.866 1093.74,228.868 1093.75,228.871 1093.76,228.873 1093.76,228.876 1093.77,228.878 1093.78,228.881 1093.79,228.883 1093.8,228.886 1093.81,228.888 1093.82,228.891 1093.83,228.893 1093.84,228.896 1093.85,228.899 1093.86,228.901 1093.87,228.904 1093.87,228.906 1093.88,228.909 1093.89,228.911 1093.9,228.914 1093.91,228.916 1093.92,228.919 1093.93,228.921 1093.94,228.924 1093.95,228.926 1093.96,228.929 1093.97,228.931 1093.98,228.934 1093.99,228.936 1093.99,228.939 1094,228.942 1094.01,228.944 1094.02,228.947 1094.03,228.949 1094.04,228.952 1094.05,228.954 1094.06,228.957 1094.07,228.959 1094.08,228.962 1094.09,228.964 1094.1,228.967 1094.1,228.969 1094.11,228.972 1094.12,228.974 1094.13,228.977 1094.14,228.98 1094.15,228.982 1094.16,228.985 1094.17,228.987 1094.18,228.99 1094.19,228.992 1094.2,228.995 1094.21,228.997 1094.21,229 1094.22,229.002 1094.23,229.005 1094.24,229.007 1094.25,229.01 1094.26,229.012 1094.27,229.015 1094.28,229.017 1094.29,229.02 1094.3,229.023 1094.31,229.025 1094.32,229.028 1094.33,229.03 1094.33,229.033 1094.34,229.035 1094.35,229.038 1094.36,229.04 1094.37,229.043 1094.38,229.045 1094.39,229.048 1094.4,229.05 1094.41,229.053 1094.42,229.055 1094.43,229.058 1094.44,229.06 1094.44,229.063 1094.45,229.066 1094.46,229.068 1094.47,229.071 1094.48,229.073 1094.49,229.076 1094.5,229.078 1094.51,229.081 1094.52,229.083 1094.53,229.086 1094.54,229.088 1094.55,229.091 1094.55,229.093 1094.56,229.096 1094.57,229.098 1094.58,229.101 1094.59,229.103 1094.6,229.106 1094.61,229.109 1094.62,229.111 1094.63,229.114 1094.64,229.116 1094.65,229.119 1094.66,229.121 1094.67,229.124 1094.67,229.126 1094.68,229.129 1094.69,229.131 1094.7,229.134 1094.71,229.136 1094.72,229.139 1094.73,229.141 1094.74,229.144 1094.75,229.146 1094.76,229.149 1094.77,229.152 1094.78,229.154 1094.78,229.157 1094.79,229.159 1094.8,229.162 1094.81,229.164 1094.82,229.167 1094.83,229.169 1094.84,229.172 1094.85,229.174 1094.86,229.177 1094.87,229.179 1094.88,229.182 1094.89,229.184 1094.89,229.187 1094.9,229.189 1094.91,229.192 1094.92,229.195 1094.93,229.197 1094.94,229.2 1094.95,229.202 1094.96,229.205 1094.97,229.207 1094.98,229.21 1094.99,229.212 1095,229.215 1095.01,229.217 1095.01,229.22 1095.02,229.222 1095.03,229.225 1095.04,229.227 1095.05,229.23 1095.06,229.232 1095.07,229.235 1095.08,229.238 1095.09,229.24 1095.1,229.243 1095.11,229.245 1095.12,229.248 1095.12,229.25 1095.13,229.253 1095.14,229.255 1095.15,229.258 1095.16,229.26 1095.17,229.263 1095.18,229.265 1095.19,229.268 1095.2,229.27 1095.21,229.273 1095.22,229.275 1095.23,229.278 1095.23,229.281 1095.24,229.283 1095.25,229.286 1095.26,229.288 1095.27,229.291 1095.28,229.293 1095.29,229.296 1095.3,229.298 1095.31,229.301 1095.32,229.303 1095.33,229.306 1095.34,229.308 1095.35,229.311 1095.35,229.313 1095.36,229.316 1095.37,229.318 1095.38,229.321 1095.39,229.323 1095.4,229.326 1095.41,229.329 1095.42,229.331 1095.43,229.334 1095.44,229.336 1095.45,229.339 1095.46,229.341 1095.46,229.344 1095.47,229.346 1095.48,229.349 1095.49,229.351 1095.5,229.354 1095.51,229.356 1095.52,229.359 1095.53,229.361 1095.54,229.364 1095.55,229.366 1095.56,229.369 1095.57,229.372 1095.57,229.374 1095.58,229.377 1095.59,229.379 1095.6,229.382 1095.61,229.384 1095.62,229.387 1095.63,229.389 1095.64,229.392 1095.65,229.394 1095.66,229.397 1095.67,229.399 1095.68,229.402 1095.69,229.404 1095.69,229.407 1095.7,229.409 1095.71,229.412 1095.72,229.414 1095.73,229.417 1095.74,229.42 1095.75,229.422 1095.76,229.425 1095.77,229.427 1095.78,229.43 1095.79,229.432 1095.8,229.435 1095.8,229.437 1095.81,229.44 1095.82,229.442 1095.83,229.445 1095.84,229.447 1095.85,229.45 1095.86,229.452 1095.87,229.455 1095.88,229.457 1095.89,229.46 1095.9,229.463 1095.91,229.465 1095.91,229.468 1095.92,229.47 1095.93,229.473 1095.94,229.475 1095.95,229.478 1095.96,229.48 1095.97,229.483 1095.98,229.485 1095.99,229.488 1096,229.49 1096.01,229.493 1096.02,229.495 1096.03,229.498 1096.03,229.5 1096.04,229.503 1096.05,229.505 1096.06,229.508 1096.07,229.511 1096.08,229.513 1096.09,229.516 1096.1,229.518 1096.11,229.521 1096.12,229.523 1096.13,229.526 1096.14,229.528 1096.14,229.531 1096.15,229.533 1096.16,229.536 1096.17,229.538 1096.18,229.541 1096.19,229.543 1096.2,229.546 1096.21,229.548 1096.22,229.551 1096.23,229.553 1096.24,229.556 1096.25,229.559 1096.25,229.561 1096.26,229.564 1096.27,229.566 1096.28,229.569 1096.29,229.571 1096.3,229.574 1096.31,229.576 1096.32,229.579 1096.33,229.581 1096.34,229.584 1096.35,229.586 1096.36,229.589 1096.37,229.591 1096.37,229.594 1096.38,229.596 1096.39,229.599 1096.4,229.601 1096.41,229.604 1096.42,229.607 1096.43,229.609 1096.44,229.612 1096.45,229.614 1096.46,229.617 1096.47,229.619 1096.48,229.622 1096.48,229.624 1096.49,229.627 1096.5,229.629 1096.51,229.632 1096.52,229.634 1096.53,229.637 1096.54,229.639 1096.55,229.642 1096.56,229.644 1096.57,229.647 1096.58,229.649 1096.59,229.652 1096.59,229.655 1096.6,229.657 1096.61,229.66 1096.62,229.662 1096.63,229.665 1096.64,229.667 1096.65,229.67 1096.66,229.672 1096.67,229.675 1096.68,229.677 1096.69,229.68 1096.7,229.682 1096.71,229.685 1096.71,229.687 1096.72,229.69 1096.73,229.692 1096.74,229.695 1096.75,229.697 1096.76,229.7 1096.77,229.703 1096.78,229.705 1096.79,229.708 1096.8,229.71 1096.81,229.713 1096.82,229.715 1096.82,229.718 1096.83,229.72 1096.84,229.723 1096.85,229.725 1096.86,229.728 1096.87,229.73 1096.88,229.733 1096.89,229.735 1096.9,229.738 1096.91,229.74 1096.92,229.743 1096.93,229.745 1096.94,229.748 1096.94,229.751 1096.95,229.753 1096.96,229.756 1096.97,229.758 1096.98,229.761 1096.99,229.763 1097,229.766 1097.01,229.768 1097.02,229.771 1097.03,229.773 1097.04,229.776 1097.05,229.778 1097.05,229.781 1097.06,229.783 1097.07,229.786 1097.08,229.788 1097.09,229.791 1097.1,229.793 1097.11,229.796 1097.12,229.798 1097.13,229.801 1097.14,229.804 1097.15,229.806 1097.16,229.809 1097.16,229.811 1097.17,229.814 1097.18,229.816 1097.19,229.819 1097.2,229.821 1097.21,229.824 1097.22,229.826 1097.23,229.829 1097.24,229.831 1097.25,229.834 1097.26,229.836 1097.27,229.839 1097.28,229.841 1097.28,229.844 1097.29,229.846 1097.3,229.849 1097.31,229.851 1097.32,229.854 1097.33,229.857 1097.34,229.859 1097.35,229.862 1097.36,229.864 1097.37,229.867 1097.38,229.869 1097.39,229.872 1097.39,229.874 1097.4,229.877 1097.41,229.879 1097.42,229.882 1097.43,229.884 1097.44,229.887 1097.45,229.889 1097.46,229.892 1097.47,229.894 1097.48,229.897 1097.49,229.899 1097.5,229.902 1097.5,229.905 1097.51,229.907 1097.52,229.91 1097.53,229.912 1097.54,229.915 1097.55,229.917 1097.56,229.92 1097.57,229.922 1097.58,229.925 1097.59,229.927 1097.6,229.93 1097.61,229.932 1097.62,229.935 1097.62,229.937 1097.63,229.94 1097.64,229.942 1097.65,229.945 1097.66,229.947 1097.67,229.95 1097.68,229.952 1097.69,229.955 1097.7,229.958 1097.71,229.96 1097.72,229.963 1097.73,229.965 1097.73,229.968 1097.74,229.97 1097.75,229.973 1097.76,229.975 1097.77,229.978 1097.78,229.98 1097.79,229.983 1097.8,229.985 1097.81,229.988 1097.82,229.99 1097.83,229.993 1097.84,229.995 1097.84,229.998 1097.85,230 1097.86,230.003 1097.87,230.005 1097.88,230.008 1097.89,230.011 1097.9,230.013 1097.91,230.016 1097.92,230.018 1097.93,230.021 1097.94,230.023 1097.95,230.026 1097.96,230.028 1097.96,230.031 1097.97,230.033 1097.98,230.036 1097.99,230.038 1098,230.041 1098.01,230.043 1098.02,230.046 1098.03,230.048 1098.04,230.051 1098.05,230.053 1098.06,230.056 1098.07,230.058 1098.07,230.061 1098.08,230.063 1098.09,230.066 1098.1,230.069 1098.11,230.071 1098.12,230.074 1098.13,230.076 1098.14,230.079 1098.15,230.081 1098.16,230.084 1098.17,230.086 1098.18,230.089 1098.18,230.091 1098.19,230.094 1098.2,230.096 1098.21,230.099 1098.22,230.101 1098.23,230.104 1098.24,230.106 1098.25,230.109 1098.26,230.111 1098.27,230.114 1098.28,230.116 1098.29,230.119 1098.3,230.122 1098.3,230.124 1098.31,230.127 1098.32,230.129 1098.33,230.132 1098.34,230.134 1098.35,230.137 1098.36,230.139 1098.37,230.142 1098.38,230.144 1098.39,230.147 1098.4,230.149 1098.41,230.152 1098.41,230.154 1098.42,230.157 1098.43,230.159 1098.44,230.162 1098.45,230.164 1098.46,230.167 1098.47,230.169 1098.48,230.172 1098.49,230.174 1098.5,230.177 1098.51,230.18 1098.52,230.182 1098.52,230.185 1098.53,230.187 1098.54,230.19 1098.55,230.192 1098.56,230.195 1098.57,230.197 1098.58,230.2 1098.59,230.202 1098.6,230.205 1098.61,230.207 1098.62,230.21 1098.63,230.212 1098.64,230.215 1098.64,230.217 1098.65,230.22 1098.66,230.222 1098.67,230.225 1098.68,230.227 1098.69,230.23 1098.7,230.233 1098.71,230.235 1098.72,230.238 1098.73,230.24 1098.74,230.243 1098.75,230.245 1098.75,230.248 1098.76,230.25 1098.77,230.253 1098.78,230.255 1098.79,230.258 1098.8,230.26 1098.81,230.263 1098.82,230.265 1098.83,230.268 1098.84,230.27 1098.85,230.273 1098.86,230.275 1098.86,230.278 1098.87,230.28 1098.88,230.283 1098.89,230.285 1098.9,230.288 1098.91,230.291 1098.92,230.293 1098.93,230.296 1098.94,230.298 1098.95,230.301 1098.96,230.303 1098.97,230.306 1098.98,230.308 1098.98,230.311 1098.99,230.313 1099,230.316 1099.01,230.318 1099.02,230.321 1099.03,230.323 1099.04,230.326 1099.05,230.328 1099.06,230.331 1099.07,230.333 1099.08,230.336 1099.09,230.338 1099.09,230.341 1099.1,230.343 1099.11,230.346 1099.12,230.348 1099.13,230.351 1099.14,230.354 1099.15,230.356 1099.16,230.359 1099.17,230.361 1099.18,230.364 1099.19,230.366 1099.2,230.369 1099.2,230.371 1099.21,230.374 1099.22,230.376 1099.23,230.379 1099.24,230.381 1099.25,230.384 1099.26,230.386 1099.27,230.389 1099.28,230.391 1099.29,230.394 1099.3,230.396 1099.31,230.399 1099.32,230.401 1099.32,230.404 1099.33,230.406 1099.34,230.409 1099.35,230.412 1099.36,230.414 1099.37,230.417 1099.38,230.419 1099.39,230.422 1099.4,230.424 1099.41,230.427 1099.42,230.429 1099.43,230.432 1099.43,230.434 1099.44,230.437 1099.45,230.439 1099.46,230.442 1099.47,230.444 1099.48,230.447 1099.49,230.449 1099.5,230.452 1099.51,230.454 1099.52,230.457 1099.53,230.459 1099.54,230.462 1099.54,230.464 1099.55,230.467 1099.56,230.469 1099.57,230.472 1099.58,230.475 1099.59,230.477 1099.6,230.48 1099.61,230.482 1099.62,230.485 1099.63,230.487 1099.64,230.49 1099.65,230.492 1099.66,230.495 1099.66,230.497 1099.67,230.5 1099.68,230.502 1099.69,230.505 1099.7,230.507 1099.71,230.51 1099.72,230.512 1099.73,230.515 1099.74,230.517 1099.75,230.52 1099.76,230.522 1099.77,230.525 1099.77,230.527 1099.78,230.53 1099.79,230.532 1099.8,230.535 1099.81,230.538 1099.82,230.54 1099.83,230.543 1099.84,230.545 1099.85,230.548 1099.86,230.55 1099.87,230.553 1099.88,230.555 1099.88,230.558 1099.89,230.56 1099.9,230.563 1099.91,230.565 1099.92,230.568 1099.93,230.57 1099.94,230.573 1099.95,230.575 1099.96,230.578 1099.97,230.58 1099.98,230.583 1099.99,230.585 1100,230.588 1100,230.59 1100.01,230.593 1100.02,230.595 1100.03,230.598 1100.04,230.601 1100.05,230.603 1100.06,230.606 1100.07,230.608 1100.08,230.611 1100.09,230.613 1100.1,230.616 1100.11,230.618 1100.11,230.621 1100.12,230.623 1100.13,230.626 1100.14,230.628 1100.15,230.631 1100.16,230.633 1100.17,230.636 1100.18,230.638 1100.19,230.641 1100.2,230.643 1100.21,230.646 1100.22,230.648 1100.22,230.651 1100.23,230.653 1100.24,230.656 1100.25,230.658 1100.26,230.661 1100.27,230.663 1100.28,230.666 1100.29,230.669 1100.3,230.671 1100.31,230.674 1100.32,230.676 1100.33,230.679 1100.34,230.681 1100.34,230.684 1100.35,230.686 1100.36,230.689 1100.37,230.691 1100.38,230.694 1100.39,230.696 1100.4,230.699 1100.41,230.701 1100.42,230.704 1100.43,230.706 1100.44,230.709 1100.45,230.711 1100.45,230.714 1100.46,230.716 1100.47,230.719 1100.48,230.721 1100.49,230.724 1100.5,230.726 1100.51,230.729 1100.52,230.731 1100.53,230.734 1100.54,230.737 1100.55,230.739 1100.56,230.742 1100.56,230.744 1100.57,230.747 1100.58,230.749 1100.59,230.752 1100.6,230.754 1100.61,230.757 1100.62,230.759 1100.63,230.762 1100.64,230.764 1100.65,230.767 1100.66,230.769 1100.67,230.772 1100.68,230.774 1100.68,230.777 1100.69,230.779 1100.7,230.782 1100.71,230.784 1100.72,230.787 1100.73,230.789 1100.74,230.792 1100.75,230.794 1100.76,230.797 1100.77,230.799 1100.78,230.802 1100.79,230.805 1100.79,230.807 1100.8,230.81 1100.81,230.812 1100.82,230.815 1100.83,230.817 1100.84,230.82 1100.85,230.822 1100.86,230.825 1100.87,230.827 1100.88,230.83 1100.89,230.832 1100.9,230.835 1100.9,230.837 1100.91,230.84 1100.92,230.842 1100.93,230.845 1100.94,230.847 1100.95,230.85 1100.96,230.852 1100.97,230.855 1100.98,230.857 1100.99,230.86 1101,230.862 1101.01,230.865 1101.02,230.867 1101.02,230.87 1101.03,230.873 1101.04,230.875 1101.05,230.878 1101.06,230.88 1101.07,230.883 1101.08,230.885 1101.09,230.888 1101.1,230.89 1101.11,230.893 1101.12,230.895 1101.13,230.898 1101.13,230.9 1101.14,230.903 1101.15,230.905 1101.16,230.908 1101.17,230.91 1101.18,230.913 1101.19,230.915 1101.2,230.918 1101.21,230.92 1101.22,230.923 1101.23,230.925 1101.24,230.928 1101.24,230.93 1101.25,230.933 1101.26,230.935 1101.27,230.938 1101.28,230.94 1101.29,230.943 1101.3,230.946 1101.31,230.948 1101.32,230.951 1101.33,230.953 1101.34,230.956 1101.35,230.958 1101.36,230.961 1101.36,230.963 1101.37,230.966 1101.38,230.968 1101.39,230.971 1101.4,230.973 1101.41,230.976 1101.42,230.978 1101.43,230.981 1101.44,230.983 1101.45,230.986 1101.46,230.988 1101.47,230.991 1101.47,230.993 1101.48,230.996 1101.49,230.998 1101.5,231.001 1101.51,231.003 1101.52,231.006 1101.53,231.008 1101.54,231.011 1101.55,231.013 1101.56,231.016 1101.57,231.018 1101.58,231.021 1101.58,231.024 1101.59,231.026 1101.6,231.029 1101.61,231.031 1101.62,231.034 1101.63,231.036 1101.64,231.039 1101.65,231.041 1101.66,231.044 1101.67,231.046 1101.68,231.049 1101.69,231.051 1101.7,231.054 1101.7,231.056 1101.71,231.059 1101.72,231.061 1101.73,231.064 1101.74,231.066 1101.75,231.069 1101.76,231.071 1101.77,231.074 1101.78,231.076 1101.79,231.079 1101.8,231.081 1101.81,231.084 1101.81,231.086 1101.82,231.089 1101.83,231.091 1101.84,231.094 1101.85,231.096 1101.86,231.099 1101.87,231.102 1101.88,231.104 1101.89,231.107 1101.9,231.109 1101.91,231.112 1101.92,231.114 1101.92,231.117 1101.93,231.119 1101.94,231.122 1101.95,231.124 1101.96,231.127 1101.97,231.129 1101.98,231.132 1101.99,231.134 1102,231.137 1102.01,231.139 1102.02,231.142 1102.03,231.144 1102.04,231.147 1102.04,231.149 1102.05,231.152 1102.06,231.154 1102.07,231.157 1102.08,231.159 1102.09,231.162 1102.1,231.164 1102.11,231.167 1102.12,231.169 1102.13,231.172 1102.14,231.174 1102.15,231.177 1102.15,231.18 1102.16,231.182 1102.17,231.185 1102.18,231.187 1102.19,231.19 1102.2,231.192 1102.21,231.195 1102.22,231.197 1102.23,231.2 1102.24,231.202 1102.25,231.205 1102.26,231.207 1102.26,231.21 1102.27,231.212 1102.28,231.215 1102.29,231.217 1102.3,231.22 1102.31,231.222 1102.32,231.225 1102.33,231.227 1102.34,231.23 1102.35,231.232 1102.36,231.235 1102.37,231.237 1102.38,231.24 1102.38,231.242 1102.39,231.245 1102.4,231.247 1102.41,231.25 1102.42,231.252 1102.43,231.255 1102.44,231.257 1102.45,231.26 1102.46,231.263 1102.47,231.265 1102.48,231.268 1102.49,231.27 1102.49,231.273 1102.5,231.275 1102.51,231.278 1102.52,231.28 1102.53,231.283 1102.54,231.285 1102.55,231.288 1102.56,231.29 1102.57,231.293 1102.58,231.295 1102.59,231.298 1102.6,231.3 1102.6,231.303 1102.61,231.305 1102.62,231.308 1102.63,231.31 1102.64,231.313 1102.65,231.315 1102.66,231.318 1102.67,231.32 1102.68,231.323 1102.69,231.325 1102.7,231.328 1102.71,231.33 1102.72,231.333 1102.72,231.335 1102.73,231.338 1102.74,231.34 1102.75,231.343 1102.76,231.345 1102.77,231.348 1102.78,231.351 1102.79,231.353 1102.8,231.356 1102.81,231.358 1102.82,231.361 1102.83,231.363 1102.83,231.366 1102.84,231.368 1102.85,231.371 1102.86,231.373 1102.87,231.376 1102.88,231.378 1102.89,231.381 1102.9,231.383 1102.91,231.386 1102.92,231.388 1102.93,231.391 1102.94,231.393 1102.94,231.396 1102.95,231.398 1102.96,231.401 1102.97,231.403 1102.98,231.406 1102.99,231.408 1103,231.411 1103.01,231.413 1103.02,231.416 1103.03,231.418 1103.04,231.421 1103.05,231.423 1103.06,231.426 1103.06,231.428 1103.07,231.431 1103.08,231.433 1103.09,231.436 1103.1,231.439 1103.11,231.441 1103.12,231.444 1103.13,231.446 1103.14,231.449 1103.15,231.451 1103.16,231.454 1103.17,231.456 1103.17,231.459 1103.18,231.461 1103.19,231.464 1103.2,231.466 1103.21,231.469 1103.22,231.471 1103.23,231.474 1103.24,231.476 1103.25,231.479 1103.26,231.481 1103.27,231.484 1103.28,231.486 1103.28,231.489 1103.29,231.491 1103.3,231.494 1103.31,231.496 1103.32,231.499 1103.33,231.501 1103.34,231.504 1103.35,231.506 1103.36,231.509 1103.37,231.511 1103.38,231.514 1103.39,231.516 1103.4,231.519 1103.4,231.521 1103.41,231.524 1103.42,231.526 1103.43,231.529 1103.44,231.531 1103.45,231.534 1103.46,231.537 1103.47,231.539 1103.48,231.542 1103.49,231.544 1103.5,231.547 1103.51,231.549 1103.51,231.552 1103.52,231.554 1103.53,231.557 1103.54,231.559 1103.55,231.562 1103.56,231.564 1103.57,231.567 1103.58,231.569 1103.59,231.572 1103.6,231.574 1103.61,231.577 1103.62,231.579 1103.62,231.582 1103.63,231.584 1103.64,231.587 1103.65,231.589 1103.66,231.592 1103.67,231.594 1103.68,231.597 1103.69,231.599 1103.7,231.602 1103.71,231.604 1103.72,231.607 1103.73,231.609 1103.74,231.612 1103.74,231.614 1103.75,231.617 1103.76,231.619 1103.77,231.622 1103.78,231.624 1103.79,231.627 1103.8,231.629 1103.81,231.632 1103.82,231.635 1103.83,231.637 1103.84,231.64 1103.85,231.642 1103.85,231.645 1103.86,231.647 1103.87,231.65 1103.88,231.652 1103.89,231.655 1103.9,231.657 1103.91,231.66 1103.92,231.662 1103.93,231.665 1103.94,231.667 1103.95,231.67 1103.96,231.672 1103.96,231.675 1103.97,231.677 1103.98,231.68 1103.99,231.682 1104,231.685 1104.01,231.687 1104.02,231.69 1104.03,231.692 1104.04,231.695 1104.05,231.697 1104.06,231.7 1104.07,231.702 1104.08,231.705 1104.08,231.707 1104.09,231.71 1104.1,231.712 1104.11,231.715 1104.12,231.717 1104.13,231.72 1104.14,231.722 1104.15,231.725 1104.16,231.727 1104.17,231.73 1104.18,231.732 1104.19,231.735 1104.19,231.737 1104.2,231.74 1104.21,231.743 1104.22,231.745 1104.23,231.748 1104.24,231.75 1104.25,231.753 1104.26,231.755 1104.27,231.758 1104.28,231.76 1104.29,231.763 1104.3,231.765 1104.3,231.768 1104.31,231.77 1104.32,231.773 1104.33,231.775 1104.34,231.778 1104.35,231.78 1104.36,231.783 1104.37,231.785 1104.38,231.788 1104.39,231.79 1104.4,231.793 1104.41,231.795 1104.42,231.798 1104.42,231.8 1104.43,231.803 1104.44,231.805 1104.45,231.808 1104.46,231.81 1104.47,231.813 1104.48,231.815 1104.49,231.818 1104.5,231.82 1104.51,231.823 1104.52,231.825 1104.53,231.828 1104.53,231.83 1104.54,231.833 1104.55,231.835 1104.56,231.838 1104.57,231.84 1104.58,231.843 1104.59,231.845 1104.6,231.848 1104.61,231.85 1104.62,231.853 1104.63,231.856 1104.64,231.858 1104.64,231.861 1104.65,231.863 1104.66,231.866 1104.67,231.868 1104.68,231.871 1104.69,231.873 1104.7,231.876 1104.71,231.878 1104.72,231.881 1104.73,231.883 1104.74,231.886 1104.75,231.888 1104.76,231.891 1104.76,231.893 1104.77,231.896 1104.78,231.898 1104.79,231.901 1104.8,231.903 1104.81,231.906 1104.82,231.908 1104.83,231.911 1104.84,231.913 1104.85,231.916 1104.86,231.918 1104.87,231.921 1104.87,231.923 1104.88,231.926 1104.89,231.928 1104.9,231.931 1104.91,231.933 1104.92,231.936 1104.93,231.938 1104.94,231.941 1104.95,231.943 1104.96,231.946 1104.97,231.948 1104.98,231.951 1104.98,231.953 1104.99,231.956 1105,231.958 1105.01,231.961 1105.02,231.963 1105.03,231.966 1105.04,231.968 1105.05,231.971 1105.06,231.974 1105.07,231.976 1105.08,231.979 1105.09,231.981 1105.1,231.984 1105.1,231.986 1105.11,231.989 1105.12,231.991 1105.13,231.994 1105.14,231.996 1105.15,231.999 1105.16,232.001 1105.17,232.004 1105.18,232.006 1105.19,232.009 1105.2,232.011 1105.21,232.014 1105.21,232.016 1105.22,232.019 1105.23,232.021 1105.24,232.024 1105.25,232.026 1105.26,232.029 1105.27,232.031 1105.28,232.034 1105.29,232.036 1105.3,232.039 1105.31,232.041 1105.32,232.044 1105.32,232.046 1105.33,232.049 1105.34,232.051 1105.35,232.054 1105.36,232.056 1105.37,232.059 1105.38,232.061 1105.39,232.064 1105.4,232.066 1105.41,232.069 1105.42,232.071 1105.43,232.074 1105.44,232.076 1105.44,232.079 1105.45,232.081 1105.46,232.084 1105.47,232.086 1105.48,232.089 1105.49,232.091 1105.5,232.094 1105.51,232.096 1105.52,232.099 1105.53,232.101 1105.54,232.104 1105.55,232.107 1105.55,232.109 1105.56,232.112 1105.57,232.114 1105.58,232.117 1105.59,232.119 1105.6,232.122 1105.61,232.124 1105.62,232.127 1105.63,232.129 1105.64,232.132 1105.65,232.134 1105.66,232.137 1105.66,232.139 1105.67,232.142 1105.68,232.144 1105.69,232.147 1105.7,232.149 1105.71,232.152 1105.72,232.154 1105.73,232.157 1105.74,232.159 1105.75,232.162 1105.76,232.164 1105.77,232.167 1105.78,232.169 1105.78,232.172 1105.79,232.174 1105.8,232.177 1105.81,232.179 1105.82,232.182 1105.83,232.184 1105.84,232.187 1105.85,232.189 1105.86,232.192 1105.87,232.194 1105.88,232.197 1105.89,232.199 1105.89,232.202 1105.9,232.204 1105.91,232.207 1105.92,232.209 1105.93,232.212 1105.94,232.214 1105.95,232.217 1105.96,232.219 1105.97,232.222 1105.98,232.224 1105.99,232.227 1106,232.229 1106,232.232 1106.01,232.234 1106.02,232.237 1106.03,232.239 1106.04,232.242 1106.05,232.244 1106.06,232.247 1106.07,232.249 1106.08,232.252 1106.09,232.255 1106.1,232.257 1106.11,232.26 1106.12,232.262 1106.12,232.265 1106.13,232.267 1106.14,232.27 1106.15,232.272 1106.16,232.275 1106.17,232.277 1106.18,232.28 1106.19,232.282 1106.2,232.285 1106.21,232.287 1106.22,232.29 1106.23,232.292 1106.23,232.295 1106.24,232.297 1106.25,232.3 1106.26,232.302 1106.27,232.305 1106.28,232.307 1106.29,232.31 1106.3,232.312 1106.31,232.315 1106.32,232.317 1106.33,232.32 1106.34,232.322 1106.34,232.325 1106.35,232.327 1106.36,232.33 1106.37,232.332 1106.38,232.335 1106.39,232.337 1106.4,232.34 1106.41,232.342 1106.42,232.345 1106.43,232.347 1106.44,232.35 1106.45,232.352 1106.46,232.355 1106.46,232.357 1106.47,232.36 1106.48,232.362 1106.49,232.365 1106.5,232.367 1106.51,232.37 1106.52,232.372 1106.53,232.375 1106.54,232.377 1106.55,232.38 1106.56,232.382 1106.57,232.385 1106.57,232.387 1106.58,232.39 1106.59,232.392 1106.6,232.395 1106.61,232.397 1106.62,232.4 1106.63,232.402 1106.64,232.405 1106.65,232.407 1106.66,232.41 1106.67,232.412 1106.68,232.415 1106.68,232.417 1106.69,232.42 1106.7,232.423 1106.71,232.425 1106.72,232.428 1106.73,232.43 1106.74,232.433 1106.75,232.435 1106.76,232.438 1106.77,232.44 1106.78,232.443 1106.79,232.445 1106.8,232.448 1106.8,232.45 1106.81,232.453 1106.82,232.455 1106.83,232.458 1106.84,232.46 1106.85,232.463 1106.86,232.465 1106.87,232.468 1106.88,232.47 1106.89,232.473 1106.9,232.475 1106.91,232.478 1106.91,232.48 1106.92,232.483 1106.93,232.485 1106.94,232.488 1106.95,232.49 1106.96,232.493 1106.97,232.495 1106.98,232.498 1106.99,232.5 1107,232.503 1107.01,232.505 1107.02,232.508 1107.02,232.51 1107.03,232.513 1107.04,232.515 1107.05,232.518 1107.06,232.52 1107.07,232.523 1107.08,232.525 1107.09,232.528 1107.1,232.53 1107.11,232.533 1107.12,232.535 1107.13,232.538 1107.14,232.54 1107.14,232.543 1107.15,232.545 1107.16,232.548 1107.17,232.55 1107.18,232.553 1107.19,232.555 1107.2,232.558 1107.21,232.56 1107.22,232.563 1107.23,232.565 1107.24,232.568 1107.25,232.57 1107.25,232.573 1107.26,232.575 1107.27,232.578 1107.28,232.58 1107.29,232.583 1107.3,232.585 1107.31,232.588 1107.32,232.59 1107.33,232.593 1107.34,232.595 1107.35,232.598 1107.36,232.6 1107.36,232.603 1107.37,232.605 1107.38,232.608 1107.39,232.61 1107.4,232.613 1107.41,232.615 1107.42,232.618 1107.43,232.62 1107.44,232.623 1107.45,232.625 1107.46,232.628 1107.47,232.631 1107.48,232.633 1107.48,232.636 1107.49,232.638 1107.5,232.641 1107.51,232.643 1107.52,232.646 1107.53,232.648 1107.54,232.651 1107.55,232.653 1107.56,232.656 1107.57,232.658 1107.58,232.661 1107.59,232.663 1107.59,232.666 1107.6,232.668 1107.61,232.671 1107.62,232.673 1107.63,232.676 1107.64,232.678 1107.65,232.681 1107.66,232.683 1107.67,232.686 1107.68,232.688 1107.69,232.691 1107.7,232.693 1107.7,232.696 1107.71,232.698 1107.72,232.701 1107.73,232.703 1107.74,232.706 1107.75,232.708 1107.76,232.711 1107.77,232.713 1107.78,232.716 1107.79,232.718 1107.8,232.721 1107.81,232.723 1107.82,232.726 1107.82,232.728 1107.83,232.731 1107.84,232.733 1107.85,232.736 1107.86,232.738 1107.87,232.741 1107.88,232.743 1107.89,232.746 1107.9,232.748 1107.91,232.751 1107.92,232.753 1107.93,232.756 1107.93,232.758 1107.94,232.761 1107.95,232.763 1107.96,232.766 1107.97,232.768 1107.98,232.771 1107.99,232.773 1108,232.776 1108.01,232.778 1108.02,232.781 1108.03,232.783 1108.04,232.786 1108.04,232.788 1108.05,232.791 1108.06,232.793 1108.07,232.796 1108.08,232.798 1108.09,232.801 1108.1,232.803 1108.11,232.806 1108.12,232.808 1108.13,232.811 1108.14,232.813 1108.15,232.816 1108.16,232.818 1108.16,232.821 1108.17,232.823 1108.18,232.826 1108.19,232.828 1108.2,232.831 1108.21,232.833 1108.22,232.836 1108.23,232.838 1108.24,232.841 1108.25,232.843 1108.26,232.846 1108.27,232.848 1108.27,232.851 1108.28,232.853 1108.29,232.856 1108.3,232.858 1108.31,232.861 1108.32,232.863 1108.33,232.866 1108.34,232.868 1108.35,232.871 1108.36,232.873 1108.37,232.876 1108.38,232.878 1108.38,232.881 1108.39,232.883 1108.4,232.886 1108.41,232.888 1108.42,232.891 1108.43,232.893 1108.44,232.896 1108.45,232.898 1108.46,232.901 1108.47,232.903 1108.48,232.906 1108.49,232.909 1108.5,232.911 1108.5,232.914 1108.51,232.916 1108.52,232.919 1108.53,232.921 1108.54,232.924 1108.55,232.926 1108.56,232.929 1108.57,232.931 1108.58,232.934 1108.59,232.936 1108.6,232.939 1108.61,232.941 1108.61,232.944 1108.62,232.946 1108.63,232.949 1108.64,232.951 1108.65,232.954 1108.66,232.956 1108.67,232.959 1108.68,232.961 1108.69,232.964 1108.7,232.966 1108.71,232.969 1108.72,232.971 1108.72,232.974 1108.73,232.976 1108.74,232.979 1108.75,232.981 1108.76,232.984 1108.77,232.986 1108.78,232.989 1108.79,232.991 1108.8,232.994 1108.81,232.996 1108.82,232.999 1108.83,233.001 1108.84,233.004 1108.84,233.006 1108.85,233.009 1108.86,233.011 1108.87,233.014 1108.88,233.016 1108.89,233.019 1108.9,233.021 1108.91,233.024 1108.92,233.026 1108.93,233.029 1108.94,233.031 1108.95,233.034 1108.95,233.036 1108.96,233.039 1108.97,233.041 1108.98,233.044 1108.99,233.046 1109,233.049 1109.01,233.051 1109.02,233.054 1109.03,233.056 1109.04,233.059 1109.05,233.061 1109.06,233.064 1109.06,233.066 1109.07,233.069 1109.08,233.071 1109.09,233.074 1109.1,233.076 1109.11,233.079 1109.12,233.081 1109.13,233.084 1109.14,233.086 1109.15,233.089 1109.16,233.091 1109.17,233.094 1109.18,233.096 1109.18,233.099 1109.19,233.101 1109.2,233.104 1109.21,233.106 1109.22,233.109 1109.23,233.111 1109.24,233.114 1109.25,233.116 1109.26,233.119 1109.27,233.121 1109.28,233.124 1109.29,233.126 1109.29,233.129 1109.3,233.131 1109.31,233.134 1109.32,233.136 1109.33,233.139 1109.34,233.141 1109.35,233.144 1109.36,233.146 1109.37,233.149 1109.38,233.151 1109.39,233.154 1109.4,233.156 1109.4,233.159 1109.41,233.161 1109.42,233.164 1109.43,233.166 1109.44,233.169 1109.45,233.171 1109.46,233.174 1109.47,233.176 1109.48,233.179 1109.49,233.181 1109.5,233.184 1109.51,233.186 1109.52,233.189 1109.52,233.191 1109.53,233.194 1109.54,233.196 1109.55,233.199 1109.56,233.201 1109.57,233.204 1109.58,233.206 1109.59,233.209 1109.6,233.211 1109.61,233.214 1109.62,233.216 1109.63,233.219 1109.63,233.221 1109.64,233.224 1109.65,233.226 1109.66,233.229 1109.67,233.231 1109.68,233.234 1109.69,233.236 1109.7,233.239 1109.71,233.241 1109.72,233.244 1109.73,233.246 1109.74,233.249 1109.74,233.251 1109.75,233.254 1109.76,233.256 1109.77,233.259 1109.78,233.261 1109.79,233.264 1109.8,233.266 1109.81,233.269 1109.82,233.271 1109.83,233.274 1109.84,233.276 1109.85,233.279 1109.86,233.281 1109.86,233.284 1109.87,233.286 1109.88,233.289 1109.89,233.291 1109.9,233.294 1109.91,233.296 1109.92,233.299 1109.93,233.301 1109.94,233.304 1109.95,233.306 1109.96,233.309 1109.97,233.311 1109.97,233.314 1109.98,233.316 1109.99,233.319 1110,233.321 1110.01,233.324 1110.02,233.326 1110.03,233.329 1110.04,233.331 1110.05,233.334 1110.06,233.336 1110.07,233.339 1110.08,233.341 1110.08,233.344 1110.09,233.346 1110.1,233.349 1110.11,233.351 1110.12,233.354 1110.13,233.356 1110.14,233.359 1110.15,233.361 1110.16,233.364 1110.17,233.366 1110.18,233.369 1110.19,233.371 1110.2,233.374 1110.2,233.376 1110.21,233.379 1110.22,233.381 1110.23,233.384 1110.24,233.386 1110.25,233.389 1110.26,233.391 1110.27,233.394 1110.28,233.396 1110.29,233.399 1110.3,233.401 1110.31,233.404 1110.31,233.406 1110.32,233.409 1110.33,233.411 1110.34,233.414 1110.35,233.416 1110.36,233.419 1110.37,233.421 1110.38,233.424 1110.39,233.426 1110.4,233.429 1110.41,233.431 1110.42,233.434 1110.42,233.436 1110.43,233.439 1110.44,233.441 1110.45,233.444 1110.46,233.446 1110.47,233.449 1110.48,233.451 1110.49,233.454 1110.5,233.456 1110.51,233.459 1110.52,233.461 1110.53,233.464 1110.54,233.466 1110.54,233.469 1110.55,233.471 1110.56,233.474 1110.57,233.476 1110.58,233.479 1110.59,233.481 1110.6,233.484 1110.61,233.486 1110.62,233.489 1110.63,233.491 1110.64,233.494 1110.65,233.496 1110.65,233.499 1110.66,233.501 1110.67,233.504 1110.68,233.506 1110.69,233.509 1110.7,233.511 1110.71,233.514 1110.72,233.516 1110.73,233.519 1110.74,233.521 1110.75,233.524 1110.76,233.526 1110.76,233.529 1110.77,233.531 1110.78,233.534 1110.79,233.536 1110.8,233.539 1110.81,233.541 1110.82,233.544 1110.83,233.546 1110.84,233.549 1110.85,233.551 1110.86,233.554 1110.87,233.556 1110.88,233.559 1110.88,233.561 1110.89,233.564 1110.9,233.566 1110.91,233.569 1110.92,233.571 1110.93,233.574 1110.94,233.576 1110.95,233.579 1110.96,233.581 1110.97,233.584 1110.98,233.586 1110.99,233.589 1110.99,233.591 1111,233.594 1111.01,233.596 1111.02,233.599 1111.03,233.601 1111.04,233.604 1111.05,233.606 1111.06,233.609 1111.07,233.611 1111.08,233.614 1111.09,233.616 1111.1,233.619 1111.1,233.621 1111.11,233.624 1111.12,233.626 1111.13,233.629 1111.14,233.631 1111.15,233.634 1111.16,233.636 1111.17,233.639 1111.18,233.641 1111.19,233.644 1111.2,233.646 1111.21,233.649 1111.22,233.651 1111.22,233.654 1111.23,233.656 1111.24,233.659 1111.25,233.661 1111.26,233.664 1111.27,233.666 1111.28,233.669 1111.29,233.671 1111.3,233.674 1111.31,233.676 1111.32,233.679 1111.33,233.681 1111.33,233.684 1111.34,233.686 1111.35,233.689 1111.36,233.691 1111.37,233.694 1111.38,233.696 1111.39,233.699 1111.4,233.701 1111.41,233.704 1111.42,233.706 1111.43,233.709 1111.44,233.711 1111.44,233.714 1111.45,233.716 1111.46,233.719 1111.47,233.721 1111.48,233.724 1111.49,233.726 1111.5,233.729 1111.51,233.731 1111.52,233.734 1111.53,233.736 1111.54,233.739 1111.55,233.741 1111.56,233.744 1111.56,233.746 1111.57,233.749 1111.58,233.751 1111.59,233.754 1111.6,233.756 1111.61,233.759 1111.62,233.761 1111.63,233.764 1111.64,233.766 1111.65,233.769 1111.66,233.771 1111.67,233.774 1111.67,233.776 1111.68,233.779 1111.69,233.781 1111.7,233.784 1111.71,233.786 1111.72,233.789 1111.73,233.791 1111.74,233.794 1111.75,233.796 1111.76,233.799 1111.77,233.801 1111.78,233.804 1111.78,233.806 1111.79,233.809 1111.8,233.811 1111.81,233.814 1111.82,233.816 1111.83,233.819 1111.84,233.821 1111.85,233.824 1111.86,233.826 1111.87,233.829 1111.88,233.831 1111.89,233.834 1111.9,233.836 1111.9,233.839 1111.91,233.841 1111.92,233.844 1111.93,233.846 1111.94,233.849 1111.95,233.851 1111.96,233.854 1111.97,233.856 1111.98,233.859 1111.99,233.861 1112,233.864 1112.01,233.866 1112.01,233.869 1112.02,233.871 1112.03,233.874 1112.04,233.876 1112.05,233.879 1112.06,233.881 1112.07,233.884 1112.08,233.886 1112.09,233.889 1112.1,233.891 1112.11,233.894 1112.12,233.896 1112.12,233.899 1112.13,233.901 1112.14,233.904 1112.15,233.906 1112.16,233.909 1112.17,233.911 1112.18,233.914 1112.19,233.916 1112.2,233.919 1112.21,233.921 1112.22,233.923 1112.23,233.926 1112.24,233.928 1112.24,233.931 1112.25,233.933 1112.26,233.936 1112.27,233.938 1112.28,233.941 1112.29,233.943 1112.3,233.946 1112.31,233.948 1112.32,233.951 1112.33,233.953 1112.34,233.956 1112.35,233.958 1112.35,233.961 1112.36,233.963 1112.37,233.966 1112.38,233.968 1112.39,233.971 1112.4,233.973 1112.41,233.976 1112.42,233.978 1112.43,233.981 1112.44,233.983 1112.45,233.986 1112.46,233.988 1112.46,233.991 1112.47,233.993 1112.48,233.996 1112.49,233.998 1112.5,234.001 1112.51,234.003 1112.52,234.006 1112.53,234.008 1112.54,234.011 1112.55,234.013 1112.56,234.016 1112.57,234.018 1112.58,234.021 1112.58,234.023 1112.59,234.026 1112.6,234.028 1112.61,234.031 1112.62,234.033 1112.63,234.036 1112.64,234.038 1112.65,234.041 1112.66,234.043 1112.67,234.046 1112.68,234.048 1112.69,234.051 1112.69,234.053 1112.7,234.056 1112.71,234.058 1112.72,234.061 1112.73,234.063 1112.74,234.066 1112.75,234.068 1112.76,234.071 1112.77,234.073 1112.78,234.076 1112.79,234.078 1112.8,234.081 1112.8,234.083 1112.81,234.086 1112.82,234.088 1112.83,234.091 1112.84,234.093 1112.85,234.096 1112.86,234.098 1112.87,234.101 1112.88,234.103 1112.89,234.106 1112.9,234.108 1112.91,234.111 1112.92,234.113 1112.92,234.116 1112.93,234.118 1112.94,234.121 1112.95,234.123 1112.96,234.126 1112.97,234.128 1112.98,234.131 1112.99,234.133 1113,234.136 1113.01,234.138 1113.02,234.141 1113.03,234.143 1113.03,234.146 1113.04,234.148 1113.05,234.151 1113.06,234.153 1113.07,234.156 1113.08,234.158 1113.09,234.161 1113.1,234.163 1113.11,234.166 1113.12,234.168 1113.13,234.171 1113.14,234.173 1113.14,234.176 1113.15,234.178 1113.16,234.181 1113.17,234.183 1113.18,234.186 1113.19,234.188 1113.2,234.191 1113.21,234.193 1113.22,234.196 1113.23,234.198 1113.24,234.201 1113.25,234.203 1113.26,234.205 1113.26,234.208 1113.27,234.21 1113.28,234.213 1113.29,234.215 1113.3,234.218 1113.31,234.22 1113.32,234.223 1113.33,234.225 1113.34,234.228 1113.35,234.23 1113.36,234.233 1113.37,234.235 1113.37,234.238 1113.38,234.24 1113.39,234.243 1113.4,234.245 1113.41,234.248 1113.42,234.25 1113.43,234.253 1113.44,234.255 1113.45,234.258 1113.46,234.26 1113.47,234.263 1113.48,234.265 1113.48,234.268 1113.49,234.27 1113.5,234.273 1113.51,234.275 1113.52,234.278 1113.53,234.28 1113.54,234.283 1113.55,234.285 1113.56,234.288 1113.57,234.29 1113.58,234.293 1113.59,234.295 1113.6,234.298 1113.6,234.3 1113.61,234.303 1113.62,234.305 1113.63,234.308 1113.64,234.31 1113.65,234.313 1113.66,234.315 1113.67,234.318 1113.68,234.32 1113.69,234.323 1113.7,234.325 1113.71,234.328 1113.71,234.33 1113.72,234.333 1113.73,234.335 1113.74,234.338 1113.75,234.34 1113.76,234.343 1113.77,234.345 1113.78,234.348 1113.79,234.35 1113.8,234.353 1113.81,234.355 1113.82,234.358 1113.82,234.36 1113.83,234.363 1113.84,234.365 1113.85,234.368 1113.86,234.37 1113.87,234.373 1113.88,234.375 1113.89,234.378 1113.9,234.38 1113.91,234.383 1113.92,234.385 1113.93,234.388 1113.94,234.39 1113.94,234.393 1113.95,234.395 1113.96,234.398 1113.97,234.4 1113.98,234.403 1113.99,234.405 1114,234.407 1114.01,234.41 1114.02,234.412 1114.03,234.415 1114.04,234.417 1114.05,234.42 1114.05,234.422 1114.06,234.425 1114.07,234.427 1114.08,234.43 1114.09,234.432 1114.1,234.435 1114.11,234.437 1114.12,234.44 1114.13,234.442 1114.14,234.445 1114.15,234.447 1114.16,234.45 1114.16,234.452 1114.17,234.455 1114.18,234.457 1114.19,234.46 1114.2,234.462 1114.21,234.465 1114.22,234.467 1114.23,234.47 1114.24,234.472 1114.25,234.475 1114.26,234.477 1114.27,234.48 1114.28,234.482 1114.28,234.485 1114.29,234.487 1114.3,234.49 1114.31,234.492 1114.32,234.495 1114.33,234.497 1114.34,234.5 1114.35,234.502 1114.36,234.505 1114.37,234.507 1114.38,234.51 1114.39,234.512 1114.39,234.515 1114.4,234.517 1114.41,234.52 1114.42,234.522 1114.43,234.525 1114.44,234.527 1114.45,234.53 1114.46,234.532 1114.47,234.535 1114.48,234.537 1114.49,234.54 1114.5,234.542 1114.5,234.545 1114.51,234.547 1114.52,234.55 1114.53,234.552 1114.54,234.555 1114.55,234.557 1114.56,234.56 1114.57,234.562 1114.58,234.565 1114.59,234.567 1114.6,234.57 1114.61,234.572 1114.62,234.574 1114.62,234.577 1114.63,234.579 1114.64,234.582 1114.65,234.584 1114.66,234.587 1114.67,234.589 1114.68,234.592 1114.69,234.594 1114.7,234.597 1114.71,234.599 1114.72,234.602 1114.73,234.604 1114.73,234.607 1114.74,234.609 1114.75,234.612 1114.76,234.614 1114.77,234.617 1114.78,234.619 1114.79,234.622 1114.8,234.624 1114.81,234.627 1114.82,234.629 1114.83,234.632 1114.84,234.634 1114.84,234.637 1114.85,234.639 1114.86,234.642 1114.87,234.644 1114.88,234.647 1114.89,234.649 1114.9,234.652 1114.91,234.654 1114.92,234.657 1114.93,234.659 1114.94,234.662 1114.95,234.664 1114.96,234.667 1114.96,234.669 1114.97,234.672 1114.98,234.674 1114.99,234.677 1115,234.679 1115.01,234.682 1115.02,234.684 1115.03,234.687 1115.04,234.689 1115.05,234.692 1115.06,234.694 1115.07,234.697 1115.07,234.699 1115.08,234.702 1115.09,234.704 1115.1,234.707 1115.11,234.709 1115.12,234.712 1115.13,234.714 1115.14,234.717 1115.15,234.719 1115.16,234.721 1115.17,234.724 1115.18,234.726 1115.18,234.729 1115.19,234.731 1115.2,234.734 1115.21,234.736 1115.22,234.739 1115.23,234.741 1115.24,234.744 1115.25,234.746 1115.26,234.749 1115.27,234.751 1115.28,234.754 1115.29,234.756 1115.3,234.759 1115.3,234.761 1115.31,234.764 1115.32,234.766 1115.33,234.769 1115.34,234.771 1115.35,234.774 1115.36,234.776 1115.37,234.779 1115.38,234.781 1115.39,234.784 1115.4,234.786 1115.41,234.789 1115.41,234.791 1115.42,234.794 1115.43,234.796 1115.44,234.799 1115.45,234.801 1115.46,234.804 1115.47,234.806 1115.48,234.809 1115.49,234.811 1115.5,234.814 1115.51,234.816 1115.52,234.819 1115.52,234.821 1115.53,234.824 1115.54,234.826 1115.55,234.829 1115.56,234.831 1115.57,234.834 1115.58,234.836 1115.59,234.839 1115.6,234.841 1115.61,234.844 1115.62,234.846 1115.63,234.849 1115.64,234.851 1115.64,234.853 1115.65,234.856 1115.66,234.858 1115.67,234.861 1115.68,234.863 1115.69,234.866 1115.7,234.868 1115.71,234.871 1115.72,234.873 1115.73,234.876 1115.74,234.878 1115.75,234.881 1115.75,234.883 1115.76,234.886 1115.77,234.888 1115.78,234.891 1115.79,234.893 1115.8,234.896 1115.81,234.898 1115.82,234.901 1115.83,234.903 1115.84,234.906 1115.85,234.908 1115.86,234.911 1115.86,234.913 1115.87,234.916 1115.88,234.918 1115.89,234.921 1115.9,234.923 1115.91,234.926 1115.92,234.928 1115.93,234.931 1115.94,234.933 1115.95,234.936 1115.96,234.938 1115.97,234.941 1115.98,234.943 1115.98,234.946 1115.99,234.948 1116,234.951 1116.01,234.953 1116.02,234.956 1116.03,234.958 1116.04,234.961 1116.05,234.963 1116.06,234.966 1116.07,234.968 1116.08,234.971 1116.09,234.973 1116.09,234.975 1116.1,234.978 1116.11,234.98 1116.12,234.983 1116.13,234.985 1116.14,234.988 1116.15,234.99 1116.16,234.993 1116.17,234.995 1116.18,234.998 1116.19,235 1116.2,235.003 1116.2,235.005 1116.21,235.008 1116.22,235.01 1116.23,235.013 1116.24,235.015 1116.25,235.018 1116.26,235.02 1116.27,235.023 1116.28,235.025 1116.29,235.028 1116.3,235.03 1116.31,235.033 1116.32,235.035 1116.32,235.038 1116.33,235.04 1116.34,235.043 1116.35,235.045 1116.36,235.048 1116.37,235.05 1116.38,235.053 1116.39,235.055 1116.4,235.058 1116.41,235.06 1116.42,235.063 1116.43,235.065 1116.43,235.068 1116.44,235.07 1116.45,235.073 1116.46,235.075 1116.47,235.078 1116.48,235.08 1116.49,235.083 1116.5,235.085 1116.51,235.087 1116.52,235.09 1116.53,235.092 1116.54,235.095 1116.54,235.097 1116.55,235.1 1116.56,235.102 1116.57,235.105 1116.58,235.107 1116.59,235.11 1116.6,235.112 1116.61,235.115 1116.62,235.117 1116.63,235.12 1116.64,235.122 1116.65,235.125 1116.66,235.127 1116.66,235.13 1116.67,235.132 1116.68,235.135 1116.69,235.137 1116.7,235.14 1116.71,235.142 1116.72,235.145 1116.73,235.147 1116.74,235.15 1116.75,235.152 1116.76,235.155 1116.77,235.157 1116.77,235.16 1116.78,235.162 1116.79,235.165 1116.8,235.167 1116.81,235.17 1116.82,235.172 1116.83,235.175 1116.84,235.177 1116.85,235.18 1116.86,235.182 1116.87,235.185 1116.88,235.187 1116.88,235.189 1116.89,235.192 1116.9,235.194 1116.91,235.197 1116.92,235.199 1116.93,235.202 1116.94,235.204 1116.95,235.207 1116.96,235.209 1116.97,235.212 1116.98,235.214 1116.99,235.217 1117,235.219 1117,235.222 1117.01,235.224 1117.02,235.227 1117.03,235.229 1117.04,235.232 1117.05,235.234 1117.06,235.237 1117.07,235.239 1117.08,235.242 1117.09,235.244 1117.1,235.247 1117.11,235.249 1117.11,235.252 1117.12,235.254 1117.13,235.257 1117.14,235.259 1117.15,235.262 1117.16,235.264 1117.17,235.267 1117.18,235.269 1117.19,235.272 1117.2,235.274 1117.21,235.277 1117.22,235.279 1117.22,235.282 1117.23,235.284 1117.24,235.287 1117.25,235.289 1117.26,235.291 1117.27,235.294 1117.28,235.296 1117.29,235.299 1117.3,235.301 1117.31,235.304 1117.32,235.306 1117.33,235.309 1117.34,235.311 1117.34,235.314 1117.35,235.316 1117.36,235.319 1117.37,235.321 1117.38,235.324 1117.39,235.326 1117.4,235.329 1117.41,235.331 1117.42,235.334 1117.43,235.336 1117.44,235.339 1117.45,235.341 1117.45,235.344 1117.46,235.346 1117.47,235.349 1117.48,235.351 1117.49,235.354 1117.5,235.356 1117.51,235.359 1117.52,235.361 1117.53,235.364 1117.54,235.366 1117.55,235.369 1117.56,235.371 1117.56,235.374 1117.57,235.376 1117.58,235.379 1117.59,235.381 1117.6,235.383 1117.61,235.386 1117.62,235.388 1117.63,235.391 1117.64,235.393 1117.65,235.396 1117.66,235.398 1117.67,235.401 1117.68,235.403 1117.68,235.406 1117.69,235.408 1117.7,235.411 1117.71,235.413 1117.72,235.416 1117.73,235.418 1117.74,235.421 1117.75,235.423 1117.76,235.426 1117.77,235.428 1117.78,235.431 1117.79,235.433 1117.79,235.436 1117.8,235.438 1117.81,235.441 1117.82,235.443 1117.83,235.446 1117.84,235.448 1117.85,235.451 1117.86,235.453 1117.87,235.456 1117.88,235.458 1117.89,235.461 1117.9,235.463 1117.9,235.466 1117.91,235.468 1117.92,235.471 1117.93,235.473 1117.94,235.475 1117.95,235.478 1117.96,235.48 1117.97,235.483 1117.98,235.485 1117.99,235.488 1118,235.49 1118.01,235.493 1118.02,235.495 1118.02,235.498 1118.03,235.5 1118.04,235.503 1118.05,235.505 1118.06,235.508 1118.07,235.51 1118.08,235.513 1118.09,235.515 1118.1,235.518 1118.11,235.52 1118.12,235.523 1118.13,235.525 1118.13,235.528 1118.14,235.53 1118.15,235.533 1118.16,235.535 1118.17,235.538 1118.18,235.54 1118.19,235.543 1118.2,235.545 1118.21,235.548 1118.22,235.55 1118.23,235.553 1118.24,235.555 1118.24,235.557 1118.25,235.56 1118.26,235.562 1118.27,235.565 1118.28,235.567 1118.29,235.57 1118.3,235.572 1118.31,235.575 1118.32,235.577 1118.33,235.58 1118.34,235.582 1118.35,235.585 1118.36,235.587 1118.36,235.59 1118.37,235.592 1118.38,235.595 1118.39,235.597 1118.4,235.6 1118.41,235.602 1118.42,235.605 1118.43,235.607 1118.44,235.61 1118.45,235.612 1118.46,235.615 1118.47,235.617 1118.47,235.62 1118.48,235.622 1118.49,235.625 1118.5,235.627 1118.51,235.63 1118.52,235.632 1118.53,235.635 1118.54,235.637 1118.55,235.64 1118.56,235.642 1118.57,235.644 1118.58,235.647 1118.58,235.649 1118.59,235.652 1118.6,235.654 1118.61,235.657 1118.62,235.659 1118.63,235.662 1118.64,235.664 1118.65,235.667 1118.66,235.669 1118.67,235.672 1118.68,235.674 1118.69,235.677 1118.7,235.679 1118.7,235.682 1118.71,235.684 1118.72,235.687 1118.73,235.689 1118.74,235.692 1118.75,235.694 1118.76,235.697 1118.77,235.699 1118.78,235.702 1118.79,235.704 1118.8,235.707 1118.81,235.709 1118.81,235.712 1118.82,235.714 1118.83,235.717 1118.84,235.719 1118.85,235.721 1118.86,235.724 1118.87,235.726 1118.88,235.729 1118.89,235.731 1118.9,235.734 1118.91,235.736 1118.92,235.739 1118.92,235.741 1118.93,235.744 1118.94,235.746 1118.95,235.749 1118.96,235.751 1118.97,235.754 1118.98,235.756 1118.99,235.759 1119,235.761 1119.01,235.764 1119.02,235.766 1119.03,235.769 1119.04,235.771 1119.04,235.774 1119.05,235.776 1119.06,235.779 1119.07,235.781 1119.08,235.784 1119.09,235.786 1119.1,235.789 1119.11,235.791 1119.12,235.794 1119.13,235.796 1119.14,235.798 1119.15,235.801 1119.15,235.803 1119.16,235.806 1119.17,235.808 1119.18,235.811 1119.19,235.813 1119.2,235.816 1119.21,235.818 1119.22,235.821 1119.23,235.823 1119.24,235.826 1119.25,235.828 1119.26,235.831 1119.26,235.833 1119.27,235.836 1119.28,235.838 1119.29,235.841 1119.3,235.843 1119.31,235.846 1119.32,235.848 1119.33,235.851 1119.34,235.853 1119.35,235.856 1119.36,235.858 1119.37,235.861 1119.38,235.863 1119.38,235.866 1119.39,235.868 1119.4,235.871 1119.41,235.873 1119.42,235.875 1119.43,235.878 1119.44,235.88 1119.45,235.883 1119.46,235.885 1119.47,235.888 1119.48,235.89 1119.49,235.893 1119.49,235.895 1119.5,235.898 1119.51,235.9 1119.52,235.903 1119.53,235.905 1119.54,235.908 1119.55,235.91 1119.56,235.913 1119.57,235.915 1119.58,235.918 1119.59,235.92 1119.6,235.923 1119.6,235.925 1119.61,235.928 1119.62,235.93 1119.63,235.933 1119.64,235.935 1119.65,235.938 1119.66,235.94 1119.67,235.943 1119.68,235.945 1119.69,235.947 1119.7,235.95 1119.71,235.952 1119.72,235.955 1119.72,235.957 1119.73,235.96 1119.74,235.962 1119.75,235.965 1119.76,235.967 1119.77,235.97 1119.78,235.972 1119.79,235.975 1119.8,235.977 1119.81,235.98 1119.82,235.982 1119.83,235.985 1119.83,235.987 1119.84,235.99 1119.85,235.992 1119.86,235.995 1119.87,235.997 1119.88,236 1119.89,236.002 1119.9,236.005 1119.91,236.007 1119.92,236.01 1119.93,236.012 1119.94,236.014 1119.94,236.017 1119.95,236.019 1119.96,236.022 1119.97,236.024 1119.98,236.027 1119.99,236.029 1120,236.032 1120.01,236.034 1120.02,236.037 1120.03,236.039 1120.04,236.042 1120.05,236.044 1120.06,236.047 1120.06,236.049 1120.07,236.052 1120.08,236.054 1120.09,236.057 1120.1,236.059 1120.11,236.062 1120.12,236.064 1120.13,236.067 1120.14,236.069 1120.15,236.072 1120.16,236.074 1120.17,236.077 1120.17,236.079 1120.18,236.082 1120.19,236.084 1120.2,236.086 1120.21,236.089 1120.22,236.091 1120.23,236.094 1120.24,236.096 1120.25,236.099 1120.26,236.101 1120.27,236.104 1120.28,236.106 1120.28,236.109 1120.29,236.111 1120.3,236.114 1120.31,236.116 1120.32,236.119 1120.33,236.121 1120.34,236.124 1120.35,236.126 1120.36,236.129 1120.37,236.131 1120.38,236.134 1120.39,236.136 1120.4,236.139 1120.4,236.141 1120.41,236.144 1120.42,236.146 1120.43,236.148 1120.44,236.151 1120.45,236.153 1120.46,236.156 1120.47,236.158 1120.48,236.161 1120.49,236.163 1120.5,236.166 1120.51,236.168 1120.51,236.171 1120.52,236.173 1120.53,236.176 1120.54,236.178 1120.55,236.181 1120.56,236.183 1120.57,236.186 1120.58,236.188 1120.59,236.191 1120.6,236.193 1120.61,236.196 1120.62,236.198 1120.62,236.201 1120.63,236.203 1120.64,236.206 1120.65,236.208 1120.66,236.211 1120.67,236.213 1120.68,236.215 1120.69,236.218 1120.7,236.22 1120.71,236.223 1120.72,236.225 1120.73,236.228 1120.74,236.23 1120.74,236.233 1120.75,236.235 1120.76,236.238 1120.77,236.24 1120.78,236.243 1120.79,236.245 1120.8,236.248 1120.81,236.25 1120.82,236.253 1120.83,236.255 1120.84,236.258 1120.85,236.26 1120.85,236.263 1120.86,236.265 1120.87,236.268 1120.88,236.27 1120.89,236.273 1120.9,236.275 1120.91,236.277 1120.92,236.28 1120.93,236.282 1120.94,236.285 1120.95,236.287 1120.96,236.29 1120.96,236.292 1120.97,236.295 1120.98,236.297 1120.99,236.3 1121,236.302 1121.01,236.305 1121.02,236.307 1121.03,236.31 1121.04,236.312 1121.05,236.315 1121.06,236.317 1121.07,236.32 1121.08,236.322 1121.08,236.325 1121.09,236.327 1121.1,236.33 1121.11,236.332 1121.12,236.335 1121.13,236.337 1121.14,236.339 1121.15,236.342 1121.16,236.344 1121.17,236.347 1121.18,236.349 1121.19,236.352 1121.19,236.354 1121.2,236.357 1121.21,236.359 1121.22,236.362 1121.23,236.364 1121.24,236.367 1121.25,236.369 1121.26,236.372 1121.27,236.374 1121.28,236.377 1121.29,236.379 1121.3,236.382 1121.3,236.384 1121.31,236.387 1121.32,236.389 1121.33,236.392 1121.34,236.394 1121.35,236.397 1121.36,236.399 1121.37,236.401 1121.38,236.404 1121.39,236.406 1121.4,236.409 1121.41,236.411 1121.42,236.414 1121.42,236.416 1121.43,236.419 1121.44,236.421 1121.45,236.424 1121.46,236.426 1121.47,236.429 1121.48,236.431 1121.49,236.434 1121.5,236.436 1121.51,236.439 1121.52,236.441 1121.53,236.444 1121.53,236.446 1121.54,236.449 1121.55,236.451 1121.56,236.454 1121.57,236.456 1121.58,236.459 1121.59,236.461 1121.6,236.463 1121.61,236.466 1121.62,236.468 1121.63,236.471 1121.64,236.473 1121.65,236.476 1121.65,236.478 1121.66,236.481 1121.67,236.483 1121.68,236.486 1121.69,236.488 1121.7,236.491 1121.71,236.493 1121.72,236.496 1121.73,236.498 1121.74,236.501 1121.75,236.503 1121.76,236.506 1121.76,236.508 1121.77,236.511 1121.78,236.513 1121.79,236.516 1121.8,236.518 1121.81,236.52 1121.82,236.523 1121.83,236.525 1121.84,236.528 1121.85,236.53 1121.86,236.533 1121.87,236.535 1121.87,236.538 1121.88,236.54 1121.89,236.543 1121.9,236.545 1121.91,236.548 1121.92,236.55 1121.93,236.553 1121.94,236.555 1121.95,236.558 1121.96,236.56 1121.97,236.563 1121.98,236.565 1121.99,236.568 1121.99,236.57 1122,236.573 1122.01,236.575 1122.02,236.577 1122.03,236.58 1122.04,236.582 1122.05,236.585 1122.06,236.587 1122.07,236.59 1122.08,236.592 1122.09,236.595 1122.1,236.597 1122.1,236.6 1122.11,236.602 1122.12,236.605 1122.13,236.607 1122.14,236.61 1122.15,236.612 1122.16,236.615 1122.17,236.617 1122.18,236.62 1122.19,236.622 1122.2,236.625 1122.21,236.627 1122.21,236.63 1122.22,236.632 1122.23,236.634 1122.24,236.637 1122.25,236.639 1122.26,236.642 1122.27,236.644 1122.28,236.647 1122.29,236.649 1122.3,236.652 1122.31,236.654 1122.32,236.657 1122.33,236.659 1122.33,236.662 1122.34,236.664 1122.35,236.667 1122.36,236.669 1122.37,236.672 1122.38,236.674 1122.39,236.677 1122.4,236.679 1122.41,236.682 1122.42,236.684 1122.43,236.687 1122.44,236.689 1122.44,236.691 1122.45,236.694 1122.46,236.696 1122.47,236.699 1122.48,236.701 1122.49,236.704 1122.5,236.706 1122.51,236.709 1122.52,236.711 1122.53,236.714 1122.54,236.716 1122.55,236.719 1122.55,236.721 1122.56,236.724 1122.57,236.726 1122.58,236.729 1122.59,236.731 1122.6,236.734 1122.61,236.736 1122.62,236.739 1122.63,236.741 1122.64,236.743 1122.65,236.746 1122.66,236.748 1122.67,236.751 1122.67,236.753 1122.68,236.756 1122.69,236.758 1122.7,236.761 1122.71,236.763 1122.72,236.766 1122.73,236.768 1122.74,236.771 1122.75,236.773 1122.76,236.776 1122.77,236.778 1122.78,236.781 1122.78,236.783 1122.79,236.786 1122.8,236.788 1122.81,236.791 1122.82,236.793 1122.83,236.795 1122.84,236.798 1122.85,236.8 1122.86,236.803 1122.87,236.805 1122.88,236.808 1122.89,236.81 1122.89,236.813 1122.9,236.815 1122.91,236.818 1122.92,236.82 1122.93,236.823 1122.94,236.825 1122.95,236.828 1122.96,236.83 1122.97,236.833 1122.98,236.835 1122.99,236.838 1123,236.84 1123.01,236.843 1123.01,236.845 1123.02,236.848 1123.03,236.85 1123.04,236.852 1123.05,236.855 1123.06,236.857 1123.07,236.86 1123.08,236.862 1123.09,236.865 1123.1,236.867 1123.11,236.87 1123.12,236.872 1123.12,236.875 1123.13,236.877 1123.14,236.88 1123.15,236.882 1123.16,236.885 1123.17,236.887 1123.18,236.89 1123.19,236.892 1123.2,236.895 1123.21,236.897 1123.22,236.9 1123.23,236.902 1123.23,236.904 1123.24,236.907 1123.25,236.909 1123.26,236.912 1123.27,236.914 1123.28,236.917 1123.29,236.919 1123.3,236.922 1123.31,236.924 1123.32,236.927 1123.33,236.929 1123.34,236.932 1123.35,236.934 1123.35,236.937 1123.36,236.939 1123.37,236.942 1123.38,236.944 1123.39,236.947 1123.4,236.949 1123.41,236.951 1123.42,236.954 1123.43,236.956 1123.44,236.959 1123.45,236.961 1123.46,236.964 1123.46,236.966 1123.47,236.969 1123.48,236.971 1123.49,236.974 1123.5,236.976 1123.51,236.979 1123.52,236.981 1123.53,236.984 1123.54,236.986 1123.55,236.989 1123.56,236.991 1123.57,236.994 1123.57,236.996 1123.58,236.999 1123.59,237.001 1123.6,237.003 1123.61,237.006 1123.62,237.008 1123.63,237.011 1123.64,237.013 1123.65,237.016 1123.66,237.018 1123.67,237.021 1123.68,237.023 1123.69,237.026 1123.69,237.028 1123.7,237.031 1123.71,237.033 1123.72,237.036 1123.73,237.038 1123.74,237.041 1123.75,237.043 1123.76,237.046 1123.77,237.048 1123.78,237.051 1123.79,237.053 1123.8,237.055 1123.8,237.058 1123.81,237.06 1123.82,237.063 1123.83,237.065 1123.84,237.068 1123.85,237.07 1123.86,237.073 1123.87,237.075 1123.88,237.078 1123.89,237.08 1123.9,237.083 1123.91,237.085 1123.91,237.088 1123.92,237.09 1123.93,237.093 1123.94,237.095 1123.95,237.098 1123.96,237.1 1123.97,237.102 1123.98,237.105 1123.99,237.107 1124,237.11 1124.01,237.112 1124.02,237.115 1124.03,237.117 1124.03,237.12 1124.04,237.122 1124.05,237.125 1124.06,237.127 1124.07,237.13 1124.08,237.132 1124.09,237.135 1124.1,237.137 1124.11,237.14 1124.12,237.142 1124.13,237.145 1124.14,237.147 1124.14,237.149 1124.15,237.152 1124.16,237.154 1124.17,237.157 1124.18,237.159 1124.19,237.162 1124.2,237.164 1124.21,237.167 1124.22,237.169 1124.23,237.172 1124.24,237.174 1124.25,237.177 1124.25,237.179 1124.26,237.182 1124.27,237.184 1124.28,237.187 1124.29,237.189 1124.3,237.192 1124.31,237.194 1124.32,237.197 1124.33,237.199 1124.34,237.201 1124.35,237.204 1124.36,237.206 1124.37,237.209 1124.37,237.211 1124.38,237.214 1124.39,237.216 1124.4,237.219 1124.41,237.221 1124.42,237.224 1124.43,237.226 1124.44,237.229 1124.45,237.231 1124.46,237.234 1124.47,237.236 1124.48,237.239 1124.48,237.241 1124.49,237.244 1124.5,237.246 1124.51,237.248 1124.52,237.251 1124.53,237.253 1124.54,237.256 1124.55,237.258 1124.56,237.261 1124.57,237.263 1124.58,237.266 1124.59,237.268 1124.59,237.271 1124.6,237.273 1124.61,237.276 1124.62,237.278 1124.63,237.281 1124.64,237.283 1124.65,237.286 1124.66,237.288 1124.67,237.29 1124.68,237.293 1124.69,237.295 1124.7,237.298 1124.71,237.3 1124.71,237.303 1124.72,237.305 1124.73,237.308 1124.74,237.31 1124.75,237.313 1124.76,237.315 1124.77,237.318 1124.78,237.32 1124.79,237.323 1124.8,237.325 1124.81,237.328 1124.82,237.33 1124.82,237.333 1124.83,237.335 1124.84,237.337 1124.85,237.34 1124.86,237.342 1124.87,237.345 1124.88,237.347 1124.89,237.35 1124.9,237.352 1124.91,237.355 1124.92,237.357 1124.93,237.36 1124.93,237.362 1124.94,237.365 1124.95,237.367 1124.96,237.37 1124.97,237.372 1124.98,237.375 1124.99,237.377 1125,237.38 1125.01,237.382 1125.02,237.384 1125.03,237.387 1125.04,237.389 1125.05,237.392 1125.05,237.394 1125.06,237.397 1125.07,237.399 1125.08,237.402 1125.09,237.404 1125.1,237.407 1125.11,237.409 1125.12,237.412 1125.13,237.414 1125.14,237.417 1125.15,237.419 1125.16,237.422 1125.16,237.424 1125.17,237.427 1125.18,237.429 1125.19,237.431 1125.2,237.434 1125.21,237.436 1125.22,237.439 1125.23,237.441 1125.24,237.444 1125.25,237.446 1125.26,237.449 1125.27,237.451 1125.27,237.454 1125.28,237.456 1125.29,237.459 1125.3,237.461 1125.31,237.464 1125.32,237.466 1125.33,237.469 1125.34,237.471 1125.35,237.473 1125.36,237.476 1125.37,237.478 1125.38,237.481 1125.39,237.483 1125.39,237.486 1125.4,237.488 1125.41,237.491 1125.42,237.493 1125.43,237.496 1125.44,237.498 1125.45,237.501 1125.46,237.503 1125.47,237.506 1125.48,237.508 1125.49,237.511 1125.5,237.513 1125.5,237.515 1125.51,237.518 1125.52,237.52 1125.53,237.523 1125.54,237.525 1125.55,237.528 1125.56,237.53 1125.57,237.533 1125.58,237.535 1125.59,237.538 1125.6,237.54 1125.61,237.543 1125.61,237.545 1125.62,237.548 1125.63,237.55 1125.64,237.553 1125.65,237.555 1125.66,237.558 1125.67,237.56 1125.68,237.562 1125.69,237.565 1125.7,237.567 1125.71,237.57 1125.72,237.572 1125.73,237.575 1125.73,237.577 1125.74,237.58 1125.75,237.582 1125.76,237.585 1125.77,237.587 1125.78,237.59 1125.79,237.592 1125.8,237.595 1125.81,237.597 1125.82,237.6 1125.83,237.602 1125.84,237.604 1125.84,237.607 1125.85,237.609 1125.86,237.612 1125.87,237.614 1125.88,237.617 1125.89,237.619 1125.9,237.622 1125.91,237.624 1125.92,237.627 1125.93,237.629 1125.94,237.632 1125.95,237.634 1125.95,237.637 1125.96,237.639 1125.97,237.642 1125.98,237.644 1125.99,237.646 1126,237.649 1126.01,237.651 1126.02,237.654 1126.03,237.656 1126.04,237.659 1126.05,237.661 1126.06,237.664 1126.07,237.666 1126.07,237.669 1126.08,237.671 1126.09,237.674 1126.1,237.676 1126.11,237.679 1126.12,237.681 1126.13,237.684 1126.14,237.686 1126.15,237.688 1126.16,237.691 1126.17,237.693 1126.18,237.696 1126.18,237.698 1126.19,237.701 1126.2,237.703 1126.21,237.706 1126.22,237.708 1126.23,237.711 1126.24,237.713 1126.25,237.716 1126.26,237.718 1126.27,237.721 1126.28,237.723 1126.29,237.726 1126.29,237.728 1126.3,237.73 1126.31,237.733 1126.32,237.735 1126.33,237.738 1126.34,237.74 1126.35,237.743 1126.36,237.745 1126.37,237.748 1126.38,237.75 1126.39,237.753 1126.4,237.755 1126.41,237.758 1126.41,237.76 1126.42,237.763 1126.43,237.765 1126.44,237.768 1126.45,237.77 1126.46,237.772 1126.47,237.775 1126.48,237.777 1126.49,237.78 1126.5,237.782 1126.51,237.785 1126.52,237.787 1126.52,237.79 1126.53,237.792 1126.54,237.795 1126.55,237.797 1126.56,237.8 1126.57,237.802 1126.58,237.805 1126.59,237.807 1126.6,237.81 1126.61,237.812 1126.62,237.814 1126.63,237.817 1126.63,237.819 1126.64,237.822 1126.65,237.824 1126.66,237.827 1126.67,237.829 1126.68,237.832 1126.69,237.834 1126.7,237.837 1126.71,237.839 1126.72,237.842 1126.73,237.844 1126.74,237.847 1126.75,237.849 1126.75,237.851 1126.76,237.854 1126.77,237.856 1126.78,237.859 1126.79,237.861 1126.8,237.864 1126.81,237.866 1126.82,237.869 1126.83,237.871 1126.84,237.874 1126.85,237.876 1126.86,237.879 1126.86,237.881 1126.87,237.884 1126.88,237.886 1126.89,237.889 1126.9,237.891 1126.91,237.893 1126.92,237.896 1126.93,237.898 1126.94,237.901 1126.95,237.903 1126.96,237.906 1126.97,237.908 1126.97,237.911 1126.98,237.913 1126.99,237.916 1127,237.918 1127.01,237.921 1127.02,237.923 1127.03,237.926 1127.04,237.928 1127.05,237.931 1127.06,237.933 1127.07,237.935 1127.08,237.938 1127.09,237.94 1127.09,237.943 1127.1,237.945 1127.11,237.948 1127.12,237.95 1127.13,237.953 1127.14,237.955 1127.15,237.958 1127.16,237.96 1127.17,237.963 1127.18,237.965 1127.19,237.968 1127.2,237.97 1127.2,237.972 1127.21,237.975 1127.22,237.977 1127.23,237.98 1127.24,237.982 1127.25,237.985 1127.26,237.987 1127.27,237.99 1127.28,237.992 1127.29,237.995 1127.3,237.997 1127.31,238 1127.31,238.002 1127.32,238.005 1127.33,238.007 1127.34,238.01 1127.35,238.012 1127.36,238.014 1127.37,238.017 1127.38,238.019 1127.39,238.022 1127.4,238.024 1127.41,238.027 1127.42,238.029 1127.43,238.032 1127.43,238.034 1127.44,238.037 1127.45,238.039 1127.46,238.042 1127.47,238.044 1127.48,238.047 1127.49,238.049 1127.5,238.051 1127.51,238.054 1127.52,238.056 1127.53,238.059 1127.54,238.061 1127.54,238.064 1127.55,238.066 1127.56,238.069 1127.57,238.071 1127.58,238.074 1127.59,238.076 1127.6,238.079 1127.61,238.081 1127.62,238.084 1127.63,238.086 1127.64,238.088 1127.65,238.091 1127.65,238.093 1127.66,238.096 1127.67,238.098 1127.68,238.101 1127.69,238.103 1127.7,238.106 1127.71,238.108 1127.72,238.111 1127.73,238.113 1127.74,238.116 1127.75,238.118 1127.76,238.121 1127.77,238.123 1127.77,238.125 1127.78,238.128 1127.79,238.13 1127.8,238.133 1127.81,238.135 1127.82,238.138 1127.83,238.14 1127.84,238.143 1127.85,238.145 1127.86,238.148 1127.87,238.15 1127.88,238.153 1127.88,238.155 1127.89,238.158 1127.9,238.16 1127.91,238.163 1127.92,238.165 1127.93,238.167 1127.94,238.17 1127.95,238.172 1127.96,238.175 1127.97,238.177 1127.98,238.18 1127.99,238.182 1127.99,238.185 1128,238.187 1128.01,238.19 1128.02,238.192 1128.03,238.195 1128.04,238.197 1128.05,238.2 1128.06,238.202 1128.07,238.204 1128.08,238.207 1128.09,238.209 1128.1,238.212 1128.11,238.214 1128.11,238.217 1128.12,238.219 1128.13,238.222 1128.14,238.224 1128.15,238.227 1128.16,238.229 1128.17,238.232 1128.18,238.234 1128.19,238.237 1128.2,238.239 1128.21,238.241 1128.22,238.244 1128.22,238.246 1128.23,238.249 1128.24,238.251 1128.25,238.254 1128.26,238.256 1128.27,238.259 1128.28,238.261 1128.29,238.264 1128.3,238.266 1128.31,238.269 1128.32,238.271 1128.33,238.274 1128.33,238.276 1128.34,238.278 1128.35,238.281 1128.36,238.283 1128.37,238.286 1128.38,238.288 1128.39,238.291 1128.4,238.293 1128.41,238.296 1128.42,238.298 1128.43,238.301 1128.44,238.303 1128.45,238.306 1128.45,238.308 1128.46,238.311 1128.47,238.313 1128.48,238.315 1128.49,238.318 1128.5,238.32 1128.51,238.323 1128.52,238.325 1128.53,238.328 1128.54,238.33 1128.55,238.333 1128.56,238.335 1128.56,238.338 1128.57,238.34 1128.58,238.343 1128.59,238.345 1128.6,238.348 1128.61,238.35 1128.62,238.352 1128.63,238.355 1128.64,238.357 1128.65,238.36 1128.66,238.362 1128.67,238.365 1128.67,238.367 1128.68,238.37 1128.69,238.372 1128.7,238.375 1128.71,238.377 1128.72,238.38 1128.73,238.382 1128.74,238.384 1128.75,238.387 1128.76,238.389 1128.77,238.392 1128.78,238.394 1128.79,238.397 1128.79,238.399 1128.8,238.402 1128.81,238.404 1128.82,238.407 1128.83,238.409 1128.84,238.412 1128.85,238.414 1128.86,238.417 1128.87,238.419 1128.88,238.421 1128.89,238.424 1128.9,238.426 1128.9,238.429 1128.91,238.431 1128.92,238.434 1128.93,238.436 1128.94,238.439 1128.95,238.441 1128.96,238.444 1128.97,238.446 1128.98,238.449 1128.99,238.451 1129,238.454 1129.01,238.456 1129.01,238.458 1129.02,238.461 1129.03,238.463 1129.04,238.466 1129.05,238.468 1129.06,238.471 1129.07,238.473 1129.08,238.476 1129.09,238.478 1129.1,238.481 1129.11,238.483 1129.12,238.486 1129.13,238.488 1129.13,238.491 1129.14,238.493 1129.15,238.495 1129.16,238.498 1129.17,238.5 1129.18,238.503 1129.19,238.505 1129.2,238.508 1129.21,238.51 1129.22,238.513 1129.23,238.515 1129.24,238.518 1129.24,238.52 1129.25,238.523 1129.26,238.525 1129.27,238.527 1129.28,238.53 1129.29,238.532 1129.3,238.535 1129.31,238.537 1129.32,238.54 1129.33,238.542 1129.34,238.545 1129.35,238.547 1129.35,238.55 1129.36,238.552 1129.37,238.555 1129.38,238.557 1129.39,238.56 1129.4,238.562 1129.41,238.564 1129.42,238.567 1129.43,238.569 1129.44,238.572 1129.45,238.574 1129.46,238.577 1129.47,238.579 1129.47,238.582 1129.48,238.584 1129.49,238.587 1129.5,238.589 1129.51,238.592 1129.52,238.594 1129.53,238.596 1129.54,238.599 1129.55,238.601 1129.56,238.604 1129.57,238.606 1129.58,238.609 1129.58,238.611 1129.59,238.614 1129.6,238.616 1129.61,238.619 1129.62,238.621 1129.63,238.624 1129.64,238.626 1129.65,238.629 1129.66,238.631 1129.67,238.633 1129.68,238.636 1129.69,238.638 1129.69,238.641 1129.7,238.643 1129.71,238.646 1129.72,238.648 1129.73,238.651 1129.74,238.653 1129.75,238.656 1129.76,238.658 1129.77,238.661 1129.78,238.663 1129.79,238.665 1129.8,238.668 1129.81,238.67 1129.81,238.673 1129.82,238.675 1129.83,238.678 1129.84,238.68 1129.85,238.683 1129.86,238.685 1129.87,238.688 1129.88,238.69 1129.89,238.693 1129.9,238.695 1129.91,238.698 1129.92,238.7 1129.92,238.702 1129.93,238.705 1129.94,238.707 1129.95,238.71 1129.96,238.712 1129.97,238.715 1129.98,238.717 1129.99,238.72 1130,238.722 1130.01,238.725 1130.02,238.727 1130.03,238.73 1130.03,238.732 1130.04,238.734 1130.05,238.737 1130.06,238.739 1130.07,238.742 1130.08,238.744 1130.09,238.747 1130.1,238.749 1130.11,238.752 1130.12,238.754 1130.13,238.757 1130.14,238.759 1130.15,238.762 1130.15,238.764 1130.16,238.766 1130.17,238.769 1130.18,238.771 1130.19,238.774 1130.2,238.776 1130.21,238.779 1130.22,238.781 1130.23,238.784 1130.24,238.786 1130.25,238.789 1130.26,238.791 1130.26,238.794 1130.27,238.796 1130.28,238.798 1130.29,238.801 1130.3,238.803 1130.31,238.806 1130.32,238.808 1130.33,238.811 1130.34,238.813 1130.35,238.816 1130.36,238.818 1130.37,238.821 1130.37,238.823 1130.38,238.826 1130.39,238.828 1130.4,238.831 1130.41,238.833 1130.42,238.835 1130.43,238.838 1130.44,238.84 1130.45,238.843 1130.46,238.845 1130.47,238.848 1130.48,238.85 1130.49,238.853 1130.49,238.855 1130.5,238.858 1130.51,238.86 1130.52,238.863 1130.53,238.865 1130.54,238.867 1130.55,238.87 1130.56,238.872 1130.57,238.875 1130.58,238.877 1130.59,238.88 1130.6,238.882 1130.6,238.885 1130.61,238.887 1130.62,238.89 1130.63,238.892 1130.64,238.895 1130.65,238.897 1130.66,238.899 1130.67,238.902 1130.68,238.904 1130.69,238.907 1130.7,238.909 1130.71,238.912 1130.71,238.914 1130.72,238.917 1130.73,238.919 1130.74,238.922 1130.75,238.924 1130.76,238.927 1130.77,238.929 1130.78,238.931 1130.79,238.934 1130.8,238.936 1130.81,238.939 1130.82,238.941 1130.83,238.944 1130.83,238.946 1130.84,238.949 1130.85,238.951 1130.86,238.954 1130.87,238.956 1130.88,238.959 1130.89,238.961 1130.9,238.963 1130.91,238.966 1130.92,238.968 1130.93,238.971 1130.94,238.973 1130.94,238.976 1130.95,238.978 1130.96,238.981 1130.97,238.983 1130.98,238.986 1130.99,238.988 1131,238.991 1131.01,238.993 1131.02,238.995 1131.03,238.998 1131.04,239 1131.05,239.003 1131.05,239.005 1131.06,239.008 1131.07,239.01 1131.08,239.013 1131.09,239.015 1131.1,239.018 1131.11,239.02 1131.12,239.023 1131.13,239.025 1131.14,239.027 1131.15,239.03 1131.16,239.032 1131.17,239.035 1131.17,239.037 1131.18,239.04 1131.19,239.042 1131.2,239.045 1131.21,239.047 1131.22,239.05 1131.23,239.052 1131.24,239.055 1131.25,239.057 1131.26,239.059 1131.27,239.062 1131.28,239.064 1131.28,239.067 1131.29,239.069 1131.3,239.072 1131.31,239.074 1131.32,239.077 1131.33,239.079 1131.34,239.082 1131.35,239.084 1131.36,239.087 1131.37,239.089 1131.38,239.091 1131.39,239.094 1131.39,239.096 1131.4,239.099 1131.41,239.101 1131.42,239.104 1131.43,239.106 1131.44,239.109 1131.45,239.111 1131.46,239.114 1131.47,239.116 1131.48,239.119 1131.49,239.121 1131.5,239.123 1131.51,239.126 1131.51,239.128 1131.52,239.131 1131.53,239.133 1131.54,239.136 1131.55,239.138 1131.56,239.141 1131.57,239.143 1131.58,239.146 1131.59,239.148 1131.6,239.151 1131.61,239.153 1131.62,239.155 1131.62,239.158 1131.63,239.16 1131.64,239.163 1131.65,239.165 1131.66,239.168 1131.67,239.17 1131.68,239.173 1131.69,239.175 1131.7,239.178 1131.71,239.18 1131.72,239.182 1131.73,239.185 1131.73,239.187 1131.74,239.19 1131.75,239.192 1131.76,239.195 1131.77,239.197 1131.78,239.2 1131.79,239.202 1131.8,239.205 1131.81,239.207 1131.82,239.21 1131.83,239.212 1131.84,239.214 1131.85,239.217 1131.85,239.219 1131.86,239.222 1131.87,239.224 1131.88,239.227 1131.89,239.229 1131.9,239.232 1131.91,239.234 1131.92,239.237 1131.93,239.239 1131.94,239.242 1131.95,239.244 1131.96,239.246 1131.96,239.249 1131.97,239.251 1131.98,239.254 1131.99,239.256 1132,239.259 1132.01,239.261 1132.02,239.264 1132.03,239.266 1132.04,239.269 1132.05,239.271 1132.06,239.274 1132.07,239.276 1132.07,239.278 1132.08,239.281 1132.09,239.283 1132.1,239.286 1132.11,239.288 1132.12,239.291 1132.13,239.293 1132.14,239.296 1132.15,239.298 1132.16,239.301 1132.17,239.303 1132.18,239.305 1132.19,239.308 1132.19,239.31 1132.2,239.313 1132.21,239.315 1132.22,239.318 1132.23,239.32 1132.24,239.323 1132.25,239.325 1132.26,239.328 1132.27,239.33 1132.28,239.333 1132.29,239.335 1132.3,239.337 1132.3,239.34 1132.31,239.342 1132.32,239.345 1132.33,239.347 1132.34,239.35 1132.35,239.352 1132.36,239.355 1132.37,239.357 1132.38,239.36 1132.39,239.362 1132.4,239.365 1132.41,239.367 1132.41,239.369 1132.42,239.372 1132.43,239.374 1132.44,239.377 1132.45,239.379 1132.46,239.382 1132.47,239.384 1132.48,239.387 1132.49,239.389 1132.5,239.392 1132.51,239.394 1132.52,239.396 1132.53,239.399 1132.53,239.401 1132.54,239.404 1132.55,239.406 1132.56,239.409 1132.57,239.411 1132.58,239.414 1132.59,239.416 1132.6,239.419 1132.61,239.421 1132.62,239.424 1132.63,239.426 1132.64,239.428 1132.64,239.431 1132.65,239.433 1132.66,239.436 1132.67,239.438 1132.68,239.441 1132.69,239.443 1132.7,239.446 1132.71,239.448 1132.72,239.451 1132.73,239.453 1132.74,239.455 1132.75,239.458 1132.75,239.46 1132.76,239.463 1132.77,239.465 1132.78,239.468 1132.79,239.47 1132.8,239.473 1132.81,239.475 1132.82,239.478 1132.83,239.48 1132.84,239.483 1132.85,239.485 1132.86,239.487 1132.87,239.49 1132.87,239.492 1132.88,239.495 1132.89,239.497 1132.9,239.5 1132.91,239.502 1132.92,239.505 1132.93,239.507 1132.94,239.51 1132.95,239.512 1132.96,239.514 1132.97,239.517 1132.98,239.519 1132.98,239.522 1132.99,239.524 1133,239.527 1133.01,239.529 1133.02,239.532 1133.03,239.534 1133.04,239.537 1133.05,239.539 1133.06,239.542 1133.07,239.544 1133.08,239.546 1133.09,239.549 1133.09,239.551 1133.1,239.554 1133.11,239.556 1133.12,239.559 1133.13,239.561 1133.14,239.564 1133.15,239.566 1133.16,239.569 1133.17,239.571 1133.18,239.573 1133.19,239.576 1133.2,239.578 1133.21,239.581 1133.21,239.583 1133.22,239.586 1133.23,239.588 1133.24,239.591 1133.25,239.593 1133.26,239.596 1133.27,239.598 1133.28,239.6 1133.29,239.603 1133.3,239.605 1133.31,239.608 1133.32,239.61 1133.32,239.613 1133.33,239.615 1133.34,239.618 1133.35,239.62 1133.36,239.623 1133.37,239.625 1133.38,239.628 1133.39,239.63 1133.4,239.632 1133.41,239.635 1133.42,239.637 1133.43,239.64 1133.43,239.642 1133.44,239.645 1133.45,239.647 1133.46,239.65 1133.47,239.652 1133.48,239.655 1133.49,239.657 1133.5,239.659 1133.51,239.662 1133.52,239.664 1133.53,239.667 1133.54,239.669 1133.55,239.672 1133.55,239.674 1133.56,239.677 1133.57,239.679 1133.58,239.682 1133.59,239.684 1133.6,239.686 1133.61,239.689 1133.62,239.691 1133.63,239.694 1133.64,239.696 1133.65,239.699 1133.66,239.701 1133.66,239.704 1133.67,239.706 1133.68,239.709 1133.69,239.711 1133.7,239.714 1133.71,239.716 1133.72,239.718 1133.73,239.721 1133.74,239.723 1133.75,239.726 1133.76,239.728 1133.77,239.731 1133.77,239.733 1133.78,239.736 1133.79,239.738 1133.8,239.741 1133.81,239.743 1133.82,239.745 1133.83,239.748 1133.84,239.75 1133.85,239.753 1133.86,239.755 1133.87,239.758 1133.88,239.76 1133.89,239.763 1133.89,239.765 1133.9,239.768 1133.91,239.77 1133.92,239.772 1133.93,239.775 1133.94,239.777 1133.95,239.78 1133.96,239.782 1133.97,239.785 1133.98,239.787 1133.99,239.79 1134,239.792 1134,239.795 1134.01,239.797 1134.02,239.799 1134.03,239.802 1134.04,239.804 1134.05,239.807 1134.06,239.809 1134.07,239.812 1134.08,239.814 1134.09,239.817 1134.1,239.819 1134.11,239.822 1134.11,239.824 1134.12,239.826 1134.13,239.829 1134.14,239.831 1134.15,239.834 1134.16,239.836 1134.17,239.839 1134.18,239.841 1134.19,239.844 1134.2,239.846 1134.21,239.849 1134.22,239.851 1134.23,239.854 1134.23,239.856 1134.24,239.858 1134.25,239.861 1134.26,239.863 1134.27,239.866 1134.28,239.868 1134.29,239.871 1134.3,239.873 1134.31,239.876 1134.32,239.878 1134.33,239.881 1134.34,239.883 1134.34,239.885 1134.35,239.888 1134.36,239.89 1134.37,239.893 1134.38,239.895 1134.39,239.898 1134.4,239.9 1134.41,239.903 1134.42,239.905 1134.43,239.908 1134.44,239.91 1134.45,239.912 1134.45,239.915 1134.46,239.917 1134.47,239.92 1134.48,239.922 1134.49,239.925 1134.5,239.927 1134.51,239.93 1134.52,239.932 1134.53,239.935 1134.54,239.937 1134.55,239.939 1134.56,239.942 1134.57,239.944 1134.57,239.947 1134.58,239.949 1134.59,239.952 1134.6,239.954 1134.61,239.957 1134.62,239.959 1134.63,239.962 1134.64,239.964 1134.65,239.966 1134.66,239.969 1134.67,239.971 1134.68,239.974 1134.68,239.976 1134.69,239.979 1134.7,239.981 1134.71,239.984 1134.72,239.986 1134.73,239.989 1134.74,239.991 1134.75,239.993 1134.76,239.996 1134.77,239.998 1134.78,240.001 1134.79,240.003 1134.79,240.006 1134.8,240.008 1134.81,240.011 1134.82,240.013 1134.83,240.016 1134.84,240.018 1134.85,240.02 1134.86,240.023 1134.87,240.025 1134.88,240.028 1134.89,240.03 1134.9,240.033 1134.91,240.035 1134.91,240.038 1134.92,240.04 1134.93,240.043 1134.94,240.045 1134.95,240.047 1134.96,240.05 1134.97,240.052 1134.98,240.055 1134.99,240.057 1135,240.06 1135.01,240.062 1135.02,240.065 1135.02,240.067 1135.03,240.07 1135.04,240.072 1135.05,240.074 1135.06,240.077 1135.07,240.079 1135.08,240.082 1135.09,240.084 1135.1,240.087 1135.11,240.089 1135.12,240.092 1135.13,240.094 1135.13,240.097 1135.14,240.099 1135.15,240.101 1135.16,240.104 1135.17,240.106 1135.18,240.109 1135.19,240.111 1135.2,240.114 1135.21,240.116 1135.22,240.119 1135.23,240.121 1135.24,240.124 1135.25,240.126 1135.25,240.128 1135.26,240.131 1135.27,240.133 1135.28,240.136 1135.29,240.138 1135.3,240.141 1135.31,240.143 1135.32,240.146 1135.33,240.148 1135.34,240.151 1135.35,240.153 1135.36,240.155 1135.36,240.158 1135.37,240.16 1135.38,240.163 1135.39,240.165 1135.4,240.168 1135.41,240.17 1135.42,240.173 1135.43,240.175 1135.44,240.178 1135.45,240.18 1135.46,240.182 1135.47,240.185 1135.47,240.187 1135.48,240.19 1135.49,240.192 1135.5,240.195 1135.51,240.197 1135.52,240.2 1135.53,240.202 1135.54,240.204 1135.55,240.207 1135.56,240.209 1135.57,240.212 1135.58,240.214 1135.59,240.217 1135.59,240.219 1135.6,240.222 1135.61,240.224 1135.62,240.227 1135.63,240.229 1135.64,240.231 1135.65,240.234 1135.66,240.236 1135.67,240.239 1135.68,240.241 1135.69,240.244 1135.7,240.246 1135.7,240.249 1135.71,240.251 1135.72,240.254 1135.73,240.256 1135.74,240.258 1135.75,240.261 1135.76,240.263 1135.77,240.266 1135.78,240.268 1135.79,240.271 1135.8,240.273 1135.81,240.276 1135.81,240.278 1135.82,240.281 1135.83,240.283 1135.84,240.285 1135.85,240.288 1135.86,240.29 1135.87,240.293 1135.88,240.295 1135.89,240.298 1135.9,240.3 1135.91,240.303 1135.92,240.305 1135.93,240.308 1135.93,240.31 1135.94,240.312 1135.95,240.315 1135.96,240.317 1135.97,240.32 1135.98,240.322 1135.99,240.325 1136,240.327 1136.01,240.33 1136.02,240.332 1136.03,240.334 1136.04,240.337 1136.04,240.339 1136.05,240.342 1136.06,240.344 1136.07,240.347 1136.08,240.349 1136.09,240.352 1136.1,240.354 1136.11,240.357 1136.12,240.359 1136.13,240.361 1136.14,240.364 1136.15,240.366 1136.15,240.369 1136.16,240.371 1136.17,240.374 1136.18,240.376 1136.19,240.379 1136.2,240.381 1136.21,240.384 1136.22,240.386 1136.23,240.388 1136.24,240.391 1136.25,240.393 1136.26,240.396 1136.27,240.398 1136.27,240.401 1136.28,240.403 1136.29,240.406 1136.3,240.408 1136.31,240.41 1136.32,240.413 1136.33,240.415 1136.34,240.418 1136.35,240.42 1136.36,240.423 1136.37,240.425 1136.38,240.428 1136.38,240.43 1136.39,240.433 1136.4,240.435 1136.41,240.437 1136.42,240.44 1136.43,240.442 1136.44,240.445 1136.45,240.447 1136.46,240.45 1136.47,240.452 1136.48,240.455 1136.49,240.457 1136.49,240.46 1136.5,240.462 1136.51,240.464 1136.52,240.467 1136.53,240.469 1136.54,240.472 1136.55,240.474 1136.56,240.477 1136.57,240.479 1136.58,240.482 1136.59,240.484 1136.6,240.486 1136.61,240.489 1136.61,240.491 1136.62,240.494 1136.63,240.496 1136.64,240.499 1136.65,240.501 1136.66,240.504 1136.67,240.506 1136.68,240.509 1136.69,240.511 1136.7,240.513 1136.71,240.516 1136.72,240.518 1136.72,240.521 1136.73,240.523 1136.74,240.526 1136.75,240.528 1136.76,240.531 1136.77,240.533 1136.78,240.536 1136.79,240.538 1136.8,240.54 1136.81,240.543 1136.82,240.545 1136.83,240.548 1136.83,240.55 1136.84,240.553 1136.85,240.555 1136.86,240.558 1136.87,240.56 1136.88,240.562 1136.89,240.565 1136.9,240.567 1136.91,240.57 1136.92,240.572 1136.93,240.575 1136.94,240.577 1136.95,240.58 1136.95,240.582 1136.96,240.585 1136.97,240.587 1136.98,240.589 1136.99,240.592 1137,240.594 1137.01,240.597 1137.02,240.599 1137.03,240.602 1137.04,240.604 1137.05,240.607 1137.06,240.609 1137.06,240.611 1137.07,240.614 1137.08,240.616 1137.09,240.619 1137.1,240.621 1137.11,240.624 1137.12,240.626 1137.13,240.629 1137.14,240.631 1137.15,240.634 1137.16,240.636 1137.17,240.638 1137.17,240.641 1137.18,240.643 1137.19,240.646 1137.2,240.648 1137.21,240.651 1137.22,240.653 1137.23,240.656 1137.24,240.658 1137.25,240.66 1137.26,240.663 1137.27,240.665 1137.28,240.668 1137.29,240.67 1137.29,240.673 1137.3,240.675 1137.31,240.678 1137.32,240.68 1137.33,240.683 1137.34,240.685 1137.35,240.687 1137.36,240.69 1137.37,240.692 1137.38,240.695 1137.39,240.697 1137.4,240.7 1137.4,240.702 1137.41,240.705 1137.42,240.707 1137.43,240.709 1137.44,240.712 1137.45,240.714 1137.46,240.717 1137.47,240.719 1137.48,240.722 1137.49,240.724 1137.5,240.727 1137.51,240.729 1137.51,240.732 1137.52,240.734 1137.53,240.736 1137.54,240.739 1137.55,240.741 1137.56,240.744 1137.57,240.746 1137.58,240.749 1137.59,240.751 1137.6,240.754 1137.61,240.756 1137.62,240.758 1137.63,240.761 1137.63,240.763 1137.64,240.766 1137.65,240.768 1137.66,240.771 1137.67,240.773 1137.68,240.776 1137.69,240.778 1137.7,240.781 1137.71,240.783 1137.72,240.785 1137.73,240.788 1137.74,240.79 1137.74,240.793 1137.75,240.795 1137.76,240.798 1137.77,240.8 1137.78,240.803 1137.79,240.805 1137.8,240.807 1137.81,240.81 1137.82,240.812 1137.83,240.815 1137.84,240.817 1137.85,240.82 1137.85,240.822 1137.86,240.825 1137.87,240.827 1137.88,240.83 1137.89,240.832 1137.9,240.834 1137.91,240.837 1137.92,240.839 1137.93,240.842 1137.94,240.844 1137.95,240.847 1137.96,240.849 1137.97,240.852 1137.97,240.854 1137.98,240.856 1137.99,240.859 1138,240.861 1138.01,240.864 1138.02,240.866 1138.03,240.869 1138.04,240.871 1138.05,240.874 1138.06,240.876 1138.07,240.878 1138.08,240.881 1138.08,240.883 1138.09,240.886 1138.1,240.888 1138.11,240.891 1138.12,240.893 1138.13,240.896 1138.14,240.898 1138.15,240.901 1138.16,240.903 1138.17,240.905 1138.18,240.908 1138.19,240.91 1138.19,240.913 1138.2,240.915 1138.21,240.918 1138.22,240.92 1138.23,240.923 1138.24,240.925 1138.25,240.927 1138.26,240.93 1138.27,240.932 1138.28,240.935 1138.29,240.937 1138.3,240.94 1138.31,240.942 1138.31,240.945 1138.32,240.947 1138.33,240.949 1138.34,240.952 1138.35,240.954 1138.36,240.957 1138.37,240.959 1138.38,240.962 1138.39,240.964 1138.4,240.967 1138.41,240.969 1138.42,240.972 1138.42,240.974 1138.43,240.976 1138.44,240.979 1138.45,240.981 1138.46,240.984 1138.47,240.986 1138.48,240.989 1138.49,240.991 1138.5,240.994 1138.51,240.996 1138.52,240.998 1138.53,241.001 1138.53,241.003 1138.54,241.006 1138.55,241.008 1138.56,241.011 1138.57,241.013 1138.58,241.016 1138.59,241.018 1138.6,241.02 1138.61,241.023 1138.62,241.025 1138.63,241.028 1138.64,241.03 1138.65,241.033 1138.65,241.035 1138.66,241.038 1138.67,241.04 1138.68,241.042 1138.69,241.045 1138.7,241.047 1138.71,241.05 1138.72,241.052 1138.73,241.055 1138.74,241.057 1138.75,241.06 1138.76,241.062 1138.76,241.065 1138.77,241.067 1138.78,241.069 1138.79,241.072 1138.8,241.074 1138.81,241.077 1138.82,241.079 1138.83,241.082 1138.84,241.084 1138.85,241.087 1138.86,241.089 1138.87,241.091 1138.87,241.094 1138.88,241.096 1138.89,241.099 1138.9,241.101 1138.91,241.104 1138.92,241.106 1138.93,241.109 1138.94,241.111 1138.95,241.113 1138.96,241.116 1138.97,241.118 1138.98,241.121 1138.99,241.123 1138.99,241.126 1139,241.128 1139.01,241.131 1139.02,241.133 1139.03,241.135 1139.04,241.138 1139.05,241.14 1139.06,241.143 1139.07,241.145 1139.08,241.148 1139.09,241.15 1139.1,241.153 1139.1,241.155 1139.11,241.157 1139.12,241.16 1139.13,241.162 1139.14,241.165 1139.15,241.167 1139.16,241.17 1139.17,241.172 1139.18,241.175 1139.19,241.177 1139.2,241.18 1139.21,241.182 1139.21,241.184 1139.22,241.187 1139.23,241.189 1139.24,241.192 1139.25,241.194 1139.26,241.197 1139.27,241.199 1139.28,241.202 1139.29,241.204 1139.3,241.206 1139.31,241.209 1139.32,241.211 1139.33,241.214 1139.33,241.216 1139.34,241.219 1139.35,241.221 1139.36,241.224 1139.37,241.226 1139.38,241.228 1139.39,241.231 1139.4,241.233 1139.41,241.236 1139.42,241.238 1139.43,241.241 1139.44,241.243 1139.44,241.246 1139.45,241.248 1139.46,241.25 1139.47,241.253 1139.48,241.255 1139.49,241.258 1139.5,241.26 1139.51,241.263 1139.52,241.265 1139.53,241.268 1139.54,241.27 1139.55,241.272 1139.55,241.275 1139.56,241.277 1139.57,241.28 1139.58,241.282 1139.59,241.285 1139.6,241.287 1139.61,241.29 1139.62,241.292 1139.63,241.294 1139.64,241.297 1139.65,241.299 1139.66,241.302 1139.67,241.304 1139.67,241.307 1139.68,241.309 1139.69,241.312 1139.7,241.314 1139.71,241.316 1139.72,241.319 1139.73,241.321 1139.74,241.324 1139.75,241.326 1139.76,241.329 1139.77,241.331 1139.78,241.334 1139.78,241.336 1139.79,241.339 1139.8,241.341 1139.81,241.343 1139.82,241.346 1139.83,241.348 1139.84,241.351 1139.85,241.353 1139.86,241.356 1139.87,241.358 1139.88,241.361 1139.89,241.363 1139.89,241.365 1139.9,241.368 1139.91,241.37 1139.92,241.373 1139.93,241.375 1139.94,241.378 1139.95,241.38 1139.96,241.383 1139.97,241.385 1139.98,241.387 1139.99,241.39 1140,241.392 1140.01,241.395 1140.01,241.397 1140.02,241.4 1140.03,241.402 1140.04,241.405 1140.05,241.407 1140.06,241.409 1140.07,241.412 1140.08,241.414 1140.09,241.417 1140.1,241.419 1140.11,241.422 1140.12,241.424 1140.12,241.427 1140.13,241.429 1140.14,241.431 1140.15,241.434 1140.16,241.436 1140.17,241.439 1140.18,241.441 1140.19,241.444 1140.2,241.446 1140.21,241.449 1140.22,241.451 1140.23,241.453 1140.23,241.456 1140.24,241.458 1140.25,241.461 1140.26,241.463 1140.27,241.466 1140.28,241.468 1140.29,241.471 1140.3,241.473 1140.31,241.475 1140.32,241.478 1140.33,241.48 1140.34,241.483 1140.35,241.485 1140.35,241.488 1140.36,241.49 1140.37,241.493 1140.38,241.495 1140.39,241.497 1140.4,241.5 1140.41,241.502 1140.42,241.505 1140.43,241.507 1140.44,241.51 1140.45,241.512 1140.46,241.515 1140.46,241.517 1140.47,241.519 1140.48,241.522 1140.49,241.524 1140.5,241.527 1140.51,241.529 1140.52,241.532 1140.53,241.534 1140.54,241.537 1140.55,241.539 1140.56,241.541 1140.57,241.544 1140.57,241.546 1140.58,241.549 1140.59,241.551 1140.6,241.554 1140.61,241.556 1140.62,241.559 1140.63,241.561 1140.64,241.563 1140.65,241.566 1140.66,241.568 1140.67,241.571 1140.68,241.573 1140.69,241.576 1140.69,241.578 1140.7,241.581 1140.71,241.583 1140.72,241.585 1140.73,241.588 1140.74,241.59 1140.75,241.593 1140.76,241.595 1140.77,241.598 1140.78,241.6 1140.79,241.603 1140.8,241.605 1140.8,241.607 1140.81,241.61 1140.82,241.612 1140.83,241.615 1140.84,241.617 1140.85,241.62 1140.86,241.622 1140.87,241.624 1140.88,241.627 1140.89,241.629 1140.9,241.632 1140.91,241.634 1140.91,241.637 1140.92,241.639 1140.93,241.642 1140.94,241.644 1140.95,241.646 1140.96,241.649 1140.97,241.651 1140.98,241.654 1140.99,241.656 1141,241.659 1141.01,241.661 1141.02,241.664 1141.03,241.666 1141.03,241.668 1141.04,241.671 1141.05,241.673 1141.06,241.676 1141.07,241.678 1141.08,241.681 1141.09,241.683 1141.1,241.686 1141.11,241.688 1141.12,241.69 1141.13,241.693 1141.14,241.695 1141.14,241.698 1141.15,241.7 1141.16,241.703 1141.17,241.705 1141.18,241.708 1141.19,241.71 1141.2,241.712 1141.21,241.715 1141.22,241.717 1141.23,241.72 1141.24,241.722 1141.25,241.725 1141.25,241.727 1141.26,241.73 1141.27,241.732 1141.28,241.734 1141.29,241.737 1141.3,241.739 1141.31,241.742 1141.32,241.744 1141.33,241.747 1141.34,241.749 1141.35,241.752 1141.36,241.754 1141.37,241.756 1141.37,241.759 1141.38,241.761 1141.39,241.764 1141.4,241.766 1141.41,241.769 1141.42,241.771 1141.43,241.774 1141.44,241.776 1141.45,241.778 1141.46,241.781 1141.47,241.783 1141.48,241.786 1141.48,241.788 1141.49,241.791 1141.5,241.793 1141.51,241.795 1141.52,241.798 1141.53,241.8 1141.54,241.803 1141.55,241.805 1141.56,241.808 1141.57,241.81 1141.58,241.813 1141.59,241.815 1141.59,241.817 1141.6,241.82 1141.61,241.822 1141.62,241.825 1141.63,241.827 1141.64,241.83 1141.65,241.832 1141.66,241.835 1141.67,241.837 1141.68,241.839 1141.69,241.842 1141.7,241.844 1141.71,241.847 1141.71,241.849 1141.72,241.852 1141.73,241.854 1141.74,241.857 1141.75,241.859 1141.76,241.861 1141.77,241.864 1141.78,241.866 1141.79,241.869 1141.8,241.871 1141.81,241.874 1141.82,241.876 1141.82,241.879 1141.83,241.881 1141.84,241.883 1141.85,241.886 1141.86,241.888 1141.87,241.891 1141.88,241.893 1141.89,241.896 1141.9,241.898 1141.91,241.9 1141.92,241.903 1141.93,241.905 1141.93,241.908 1141.94,241.91 1141.95,241.913 1141.96,241.915 1141.97,241.918 1141.98,241.92 1141.99,241.922 1142,241.925 1142.01,241.927 1142.02,241.93 1142.03,241.932 1142.04,241.935 1142.05,241.937 1142.05,241.94 1142.06,241.942 1142.07,241.944 1142.08,241.947 1142.09,241.949 1142.1,241.952 1142.11,241.954 1142.12,241.957 1142.13,241.959 1142.14,241.962 1142.15,241.964 1142.16,241.966 1142.16,241.969 1142.17,241.971 1142.18,241.974 1142.19,241.976 1142.2,241.979 1142.21,241.981 1142.22,241.983 1142.23,241.986 1142.24,241.988 1142.25,241.991 1142.26,241.993 1142.27,241.996 1142.27,241.998 1142.28,242.001 1142.29,242.003 1142.3,242.005 1142.31,242.008 1142.32,242.01 1142.33,242.013 1142.34,242.015 1142.35,242.018 1142.36,242.02 1142.37,242.023 1142.38,242.025 1142.39,242.027 1142.39,242.03 1142.4,242.032 1142.41,242.035 1142.42,242.037 1142.43,242.04 1142.44,242.042 1142.45,242.045 1142.46,242.047 1142.47,242.049 1142.48,242.052 1142.49,242.054 1142.5,242.057 1142.5,242.059 1142.51,242.062 1142.52,242.064 1142.53,242.066 1142.54,242.069 1142.55,242.071 1142.56,242.074 1142.57,242.076 1142.58,242.079 1142.59,242.081 1142.6,242.084 1142.61,242.086 1142.61,242.088 1142.62,242.091 1142.63,242.093 1142.64,242.096 1142.65,242.098 1142.66,242.101 1142.67,242.103 1142.68,242.106 1142.69,242.108 1142.7,242.11 1142.71,242.113 1142.72,242.115 1142.73,242.118 1142.73,242.12 1142.74,242.123 1142.75,242.125 1142.76,242.127 1142.77,242.13 1142.78,242.132 1142.79,242.135 1142.8,242.137 1142.81,242.14 1142.82,242.142 1142.83,242.145 1142.84,242.147 1142.84,242.149 1142.85,242.152 1142.86,242.154 1142.87,242.157 1142.88,242.159 1142.89,242.162 1142.9,242.164 1142.91,242.167 1142.92,242.169 1142.93,242.171 1142.94,242.174 1142.95,242.176 1142.95,242.179 1142.96,242.181 1142.97,242.184 1142.98,242.186 1142.99,242.188 1143,242.191 1143.01,242.193 1143.02,242.196 1143.03,242.198 1143.04,242.201 1143.05,242.203 1143.06,242.206 1143.07,242.208 1143.07,242.21 1143.08,242.213 1143.09,242.215 1143.1,242.218 1143.11,242.22 1143.12,242.223 1143.13,242.225 1143.14,242.227 1143.15,242.23 1143.16,242.232 1143.17,242.235 1143.18,242.237 1143.18,242.24 1143.19,242.242 1143.2,242.245 1143.21,242.247 1143.22,242.249 1143.23,242.252 1143.24,242.254 1143.25,242.257 1143.26,242.259 1143.27,242.262 1143.28,242.264 1143.29,242.267 1143.29,242.269 1143.3,242.271 1143.31,242.274 1143.32,242.276 1143.33,242.279 1143.34,242.281 1143.35,242.284 1143.36,242.286 1143.37,242.288 1143.38,242.291 1143.39,242.293 1143.4,242.296 1143.41,242.298 1143.41,242.301 1143.42,242.303 1143.43,242.306 1143.44,242.308 1143.45,242.31 1143.46,242.313 1143.47,242.315 1143.48,242.318 1143.49,242.32 1143.5,242.323 1143.51,242.325 1143.52,242.327 1143.52,242.33 1143.53,242.332 1143.54,242.335 1143.55,242.337 1143.56,242.34 1143.57,242.342 1143.58,242.345 1143.59,242.347 1143.6,242.349 1143.61,242.352 1143.62,242.354 1143.63,242.357 1143.63,242.359 1143.64,242.362 1143.65,242.364 1143.66,242.367 1143.67,242.369 1143.68,242.371 1143.69,242.374 1143.7,242.376 1143.71,242.379 1143.72,242.381 1143.73,242.384 1143.74,242.386 1143.75,242.388 1143.75,242.391 1143.76,242.393 1143.77,242.396 1143.78,242.398 1143.79,242.401 1143.8,242.403 1143.81,242.406 1143.82,242.408 1143.83,242.41 1143.84,242.413 1143.85,242.415 1143.86,242.418 1143.86,242.42 1143.87,242.423 1143.88,242.425 1143.89,242.427 1143.9,242.43 1143.91,242.432 1143.92,242.435 1143.93,242.437 1143.94,242.44 1143.95,242.442 1143.96,242.445 1143.97,242.447 1143.97,242.449 1143.98,242.452 1143.99,242.454 1144,242.457 1144.01,242.459 1144.02,242.462 1144.03,242.464 1144.04,242.466 1144.05,242.469 1144.06,242.471 1144.07,242.474 1144.08,242.476 1144.09,242.479 1144.09,242.481 1144.1,242.484 1144.11,242.486 1144.12,242.488 1144.13,242.491 1144.14,242.493 1144.15,242.496 1144.16,242.498 1144.17,242.501 1144.18,242.503 1144.19,242.505 1144.2,242.508 1144.2,242.51 1144.21,242.513 1144.22,242.515 1144.23,242.518 1144.24,242.52 1144.25,242.523 1144.26,242.525 1144.27,242.527 1144.28,242.53 1144.29,242.532 1144.3,242.535 1144.31,242.537 1144.31,242.54 1144.32,242.542 1144.33,242.544 1144.34,242.547 1144.35,242.549 1144.36,242.552 1144.37,242.554 1144.38,242.557 1144.39,242.559 1144.4,242.562 1144.41,242.564 1144.42,242.566 1144.43,242.569 1144.43,242.571 1144.44,242.574 1144.45,242.576 1144.46,242.579 1144.47,242.581 1144.48,242.583 1144.49,242.586 1144.5,242.588 1144.51,242.591 1144.52,242.593 1144.53,242.596 1144.54,242.598 1144.54,242.6 1144.55,242.603 1144.56,242.605 1144.57,242.608 1144.58,242.61 1144.59,242.613 1144.6,242.615 1144.61,242.618 1144.62,242.62 1144.63,242.622 1144.64,242.625 1144.65,242.627 1144.65,242.63 1144.66,242.632 1144.67,242.635 1144.68,242.637 1144.69,242.639 1144.7,242.642 1144.71,242.644 1144.72,242.647 1144.73,242.649 1144.74,242.652 1144.75,242.654 1144.76,242.657 1144.77,242.659 1144.77,242.661 1144.78,242.664 1144.79,242.666 1144.8,242.669 1144.81,242.671 1144.82,242.674 1144.83,242.676 1144.84,242.678 1144.85,242.681 1144.86,242.683 1144.87,242.686 1144.88,242.688 1144.88,242.691 1144.89,242.693 1144.9,242.696 1144.91,242.698 1144.92,242.7 1144.93,242.703 1144.94,242.705 1144.95,242.708 1144.96,242.71 1144.97,242.713 1144.98,242.715 1144.99,242.717 1144.99,242.72 1145,242.722 1145.01,242.725 1145.02,242.727 1145.03,242.73 1145.04,242.732 1145.05,242.734 1145.06,242.737 1145.07,242.739 1145.08,242.742 1145.09,242.744 1145.1,242.747 1145.11,242.749 1145.11,242.752 1145.12,242.754 1145.13,242.756 1145.14,242.759 1145.15,242.761 1145.16,242.764 1145.17,242.766 1145.18,242.769 1145.19,242.771 1145.2,242.773 1145.21,242.776 1145.22,242.778 1145.22,242.781 1145.23,242.783 1145.24,242.786 1145.25,242.788 1145.26,242.791 1145.27,242.793 1145.28,242.795 1145.29,242.798 1145.3,242.8 1145.31,242.803 1145.32,242.805 1145.33,242.808 1145.33,242.81 1145.34,242.812 1145.35,242.815 1145.36,242.817 1145.37,242.82 1145.38,242.822 1145.39,242.825 1145.4,242.827 1145.41,242.829 1145.42,242.832 1145.43,242.834 1145.44,242.837 1145.45,242.839 1145.45,242.842 1145.46,242.844 1145.47,242.847 1145.48,242.849 1145.49,242.851 1145.5,242.854 1145.51,242.856 1145.52,242.859 1145.53,242.861 1145.54,242.864 1145.55,242.866 1145.56,242.868 1145.56,242.871 1145.57,242.873 1145.58,242.876 1145.59,242.878 1145.6,242.881 1145.61,242.883 1145.62,242.885 1145.63,242.888 1145.64,242.89 1145.65,242.893 1145.66,242.895 1145.67,242.898 1145.67,242.9 1145.68,242.903 1145.69,242.905 1145.7,242.907 1145.71,242.91 1145.72,242.912 1145.73,242.915 1145.74,242.917 1145.75,242.92 1145.76,242.922 1145.77,242.924 1145.78,242.927 1145.79,242.929 1145.79,242.932 1145.8,242.934 1145.81,242.937 1145.82,242.939 1145.83,242.941 1145.84,242.944 1145.85,242.946 1145.86,242.949 1145.87,242.951 1145.88,242.954 1145.89,242.956 1145.9,242.959 1145.9,242.961 1145.91,242.963 1145.92,242.966 1145.93,242.968 1145.94,242.971 1145.95,242.973 1145.96,242.976 1145.97,242.978 1145.98,242.98 1145.99,242.983 1146,242.985 1146.01,242.988 1146.01,242.99 1146.02,242.993 1146.03,242.995 1146.04,242.997 1146.05,243 1146.06,243.002 1146.07,243.005 1146.08,243.007 1146.09,243.01 1146.1,243.012 1146.11,243.014 1146.12,243.017 1146.13,243.019 1146.13,243.022 1146.14,243.024 1146.15,243.027 1146.16,243.029 1146.17,243.032 1146.18,243.034 1146.19,243.036 1146.2,243.039 1146.21,243.041 1146.22,243.044 1146.23,243.046 1146.24,243.049 1146.24,243.051 1146.25,243.053 1146.26,243.056 1146.27,243.058 1146.28,243.061 1146.29,243.063 1146.3,243.066 1146.31,243.068 1146.32,243.07 1146.33,243.073 1146.34,243.075 1146.35,243.078 1146.36,243.08 1146.36,243.083 1146.37,243.085 1146.38,243.087 1146.39,243.09 1146.4,243.092 1146.41,243.095 1146.42,243.097 1146.43,243.1 1146.44,243.102 1146.45,243.105 1146.46,243.107 1146.47,243.109 1146.47,243.112 1146.48,243.114 1146.49,243.117 1146.5,243.119 1146.51,243.122 1146.52,243.124 1146.53,243.126 1146.54,243.129 1146.55,243.131 1146.56,243.134 1146.57,243.136 1146.58,243.139 1146.58,243.141 1146.59,243.143 1146.6,243.146 1146.61,243.148 1146.62,243.151 1146.63,243.153 1146.64,243.156 1146.65,243.158 1146.66,243.16 1146.67,243.163 1146.68,243.165 1146.69,243.168 1146.7,243.17 1146.7,243.173 1146.71,243.175 1146.72,243.178 1146.73,243.18 1146.74,243.182 1146.75,243.185 1146.76,243.187 1146.77,243.19 1146.78,243.192 1146.79,243.195 1146.8,243.197 1146.81,243.199 1146.81,243.202 1146.82,243.204 1146.83,243.207 1146.84,243.209 1146.85,243.212 1146.86,243.214 1146.87,243.216 1146.88,243.219 1146.89,243.221 1146.9,243.224 1146.91,243.226 1146.92,243.229 1146.92,243.231 1146.93,243.233 1146.94,243.236 1146.95,243.238 1146.96,243.241 1146.97,243.243 1146.98,243.246 1146.99,243.248 1147,243.25 1147.01,243.253 1147.02,243.255 1147.03,243.258 1147.04,243.26 1147.04,243.263 1147.05,243.265 1147.06,243.268 1147.07,243.27 1147.08,243.272 1147.09,243.275 1147.1,243.277 1147.11,243.28 1147.12,243.282 1147.13,243.285 1147.14,243.287 1147.15,243.289 1147.15,243.292 1147.16,243.294 1147.17,243.297 1147.18,243.299 1147.19,243.302 1147.2,243.304 1147.21,243.306 1147.22,243.309 1147.23,243.311 1147.24,243.314 1147.25,243.316 1147.26,243.319 1147.26,243.321 1147.27,243.323 1147.28,243.326 1147.29,243.328 1147.3,243.331 1147.31,243.333 1147.32,243.336 1147.33,243.338 1147.34,243.34 1147.35,243.343 1147.36,243.345 1147.37,243.348 1147.38,243.35 1147.38,243.353 1147.39,243.355 1147.4,243.357 1147.41,243.36 1147.42,243.362 1147.43,243.365 1147.44,243.367 1147.45,243.37 1147.46,243.372 1147.47,243.375 1147.48,243.377 1147.49,243.379 1147.49,243.382 1147.5,243.384 1147.51,243.387 1147.52,243.389 1147.53,243.392 1147.54,243.394 1147.55,243.396 1147.56,243.399 1147.57,243.401 1147.58,243.404 1147.59,243.406 1147.6,243.409 1147.6,243.411 1147.61,243.413 1147.62,243.416 1147.63,243.418 1147.64,243.421 1147.65,243.423 1147.66,243.426 1147.67,243.428 1147.68,243.43 1147.69,243.433 1147.7,243.435 1147.71,243.438 1147.72,243.44 1147.72,243.443 1147.73,243.445 1147.74,243.447 1147.75,243.45 1147.76,243.452 1147.77,243.455 1147.78,243.457 1147.79,243.46 1147.8,243.462 1147.81,243.464 1147.82,243.467 1147.83,243.469 1147.83,243.472 1147.84,243.474 1147.85,243.477 1147.86,243.479 1147.87,243.481 1147.88,243.484 1147.89,243.486 1147.9,243.489 1147.91,243.491 1147.92,243.494 1147.93,243.496 1147.94,243.498 1147.94,243.501 1147.95,243.503 1147.96,243.506 1147.97,243.508 1147.98,243.511 1147.99,243.513 1148,243.515 1148.01,243.518 1148.02,243.52 1148.03,243.523 1148.04,243.525 1148.05,243.528 1148.06,243.53 1148.06,243.533 1148.07,243.535 1148.08,243.537 1148.09,243.54 1148.1,243.542 1148.11,243.545 1148.12,243.547 1148.13,243.55 1148.14,243.552 1148.15,243.554 1148.16,243.557 1148.17,243.559 1148.17,243.562 1148.18,243.564 1148.19,243.567 1148.2,243.569 1148.21,243.571 1148.22,243.574 1148.23,243.576 1148.24,243.579 1148.25,243.581 1148.26,243.584 1148.27,243.586 1148.28,243.588 1148.28,243.591 1148.29,243.593 1148.3,243.596 1148.31,243.598 1148.32,243.601 1148.33,243.603 1148.34,243.605 1148.35,243.608 1148.36,243.61 1148.37,243.613 1148.38,243.615 1148.39,243.618 1148.4,243.62 1148.4,243.622 1148.41,243.625 1148.42,243.627 1148.43,243.63 1148.44,243.632 1148.45,243.635 1148.46,243.637 1148.47,243.639 1148.48,243.642 1148.49,243.644 1148.5,243.647 1148.51,243.649 1148.51,243.652 1148.52,243.654 1148.53,243.656 1148.54,243.659 1148.55,243.661 1148.56,243.664 1148.57,243.666 1148.58,243.669 1148.59,243.671 1148.6,243.673 1148.61,243.676 1148.62,243.678 1148.62,243.681 1148.63,243.683 1148.64,243.686 1148.65,243.688 1148.66,243.69 1148.67,243.693 1148.68,243.695 1148.69,243.698 1148.7,243.7 1148.71,243.703 1148.72,243.705 1148.73,243.707 1148.74,243.71 1148.74,243.712 1148.75,243.715 1148.76,243.717 1148.77,243.72 1148.78,243.722 1148.79,243.724 1148.8,243.727 1148.81,243.729 1148.82,243.732 1148.83,243.734 1148.84,243.737 1148.85,243.739 1148.85,243.741 1148.86,243.744 1148.87,243.746 1148.88,243.749 1148.89,243.751 1148.9,243.754 1148.91,243.756 1148.92,243.758 1148.93,243.761 1148.94,243.763 1148.95,243.766 1148.96,243.768 1148.96,243.771 1148.97,243.773 1148.98,243.775 1148.99,243.778 1149,243.78 1149.01,243.783 1149.02,243.785 1149.03,243.788 1149.04,243.79 1149.05,243.792 1149.06,243.795 1149.07,243.797 1149.08,243.8 1149.08,243.802 1149.09,243.805 1149.1,243.807 1149.11,243.809 1149.12,243.812 1149.13,243.814 1149.14,243.817 1149.15,243.819 1149.16,243.822 1149.17,243.824 1149.18,243.826 1149.19,243.829 1149.19,243.831 1149.2,243.834 1149.21,243.836 1149.22,243.839 1149.23,243.841 1149.24,243.843 1149.25,243.846 1149.26,243.848 1149.27,243.851 1149.28,243.853 1149.29,243.856 1149.3,243.858 1149.3,243.86 1149.31,243.863 1149.32,243.865 1149.33,243.868 1149.34,243.87 1149.35,243.873 1149.36,243.875 1149.37,243.877 1149.38,243.88 1149.39,243.882 1149.4,243.885 1149.41,243.887 1149.42,243.89 1149.42,243.892 1149.43,243.894 1149.44,243.897 1149.45,243.899 1149.46,243.902 1149.47,243.904 1149.48,243.907 1149.49,243.909 1149.5,243.911 1149.51,243.914 1149.52,243.916 1149.53,243.919 1149.53,243.921 1149.54,243.924 1149.55,243.926 1149.56,243.928 1149.57,243.931 1149.58,243.933 1149.59,243.936 1149.6,243.938 1149.61,243.941 1149.62,243.943 1149.63,243.945 1149.64,243.948 1149.64,243.95 1149.65,243.953 1149.66,243.955 1149.67,243.958 1149.68,243.96 1149.69,243.962 1149.7,243.965 1149.71,243.967 1149.72,243.97 1149.73,243.972 1149.74,243.975 1149.75,243.977 1149.76,243.979 1149.76,243.982 1149.77,243.984 1149.78,243.987 1149.79,243.989 1149.8,243.992 1149.81,243.994 1149.82,243.996 1149.83,243.999 1149.84,244.001 1149.85,244.004 1149.86,244.006 1149.87,244.009 1149.87,244.011 1149.88,244.013 1149.89,244.016 1149.9,244.018 1149.91,244.021 1149.92,244.023 1149.93,244.025 1149.94,244.028 1149.95,244.03 1149.96,244.033 1149.97,244.035 1149.98,244.038 1149.98,244.04 1149.99,244.042 1150,244.045 1150.01,244.047 1150.02,244.05 1150.03,244.052 1150.04,244.055 1150.05,244.057 1150.06,244.059 1150.07,244.062 1150.08,244.064 1150.09,244.067 1150.1,244.069 1150.1,244.072 1150.11,244.074 1150.12,244.076 1150.13,244.079 1150.14,244.081 1150.15,244.084 1150.16,244.086 1150.17,244.089 1150.18,244.091 1150.19,244.093 1150.2,244.096 1150.21,244.098 1150.21,244.101 1150.22,244.103 1150.23,244.106 1150.24,244.108 1150.25,244.11 1150.26,244.113 1150.27,244.115 1150.28,244.118 1150.29,244.12 1150.3,244.123 1150.31,244.125 1150.32,244.127 1150.32,244.13 1150.33,244.132 1150.34,244.135 1150.35,244.137 1150.36,244.14 1150.37,244.142 1150.38,244.144 1150.39,244.147 1150.4,244.149 1150.41,244.152 1150.42,244.154 1150.43,244.157 1150.44,244.159 1150.44,244.161 1150.45,244.164 1150.46,244.166 1150.47,244.169 1150.48,244.171 1150.49,244.173 1150.5,244.176 1150.51,244.178 1150.52,244.181 1150.53,244.183 1150.54,244.186 1150.55,244.188 1150.55,244.19 1150.56,244.193 1150.57,244.195 1150.58,244.198 1150.59,244.2 1150.6,244.203 1150.61,244.205 1150.62,244.207 1150.63,244.21 1150.64,244.212 1150.65,244.215 1150.66,244.217 1150.66,244.22 1150.67,244.222 1150.68,244.224 1150.69,244.227 1150.7,244.229 1150.71,244.232 1150.72,244.234 1150.73,244.237 1150.74,244.239 1150.75,244.241 1150.76,244.244 1150.77,244.246 1150.78,244.249 1150.78,244.251 1150.79,244.254 1150.8,244.256 1150.81,244.258 1150.82,244.261 1150.83,244.263 1150.84,244.266 1150.85,244.268 1150.86,244.271 1150.87,244.273 1150.88,244.275 1150.89,244.278 1150.89,244.28 1150.9,244.283 1150.91,244.285 1150.92,244.287 1150.93,244.29 1150.94,244.292 1150.95,244.295 1150.96,244.297 1150.97,244.3 1150.98,244.302 1150.99,244.304 1151,244.307 1151,244.309 1151.01,244.312 1151.02,244.314 1151.03,244.317 1151.04,244.319 1151.05,244.321 1151.06,244.324 1151.07,244.326 1151.08,244.329 1151.09,244.331 1151.1,244.334 1151.11,244.336 1151.12,244.338 1151.12,244.341 1151.13,244.343 1151.14,244.346 1151.15,244.348 1151.16,244.351 1151.17,244.353 1151.18,244.355 1151.19,244.358 1151.2,244.36 1151.21,244.363 1151.22,244.365 1151.23,244.368 1151.23,244.37 1151.24,244.372 1151.25,244.375 1151.26,244.377 1151.27,244.38 1151.28,244.382 1151.29,244.384 1151.3,244.387 1151.31,244.389 1151.32,244.392 1151.33,244.394 1151.34,244.397 1151.34,244.399 1151.35,244.401 1151.36,244.404 1151.37,244.406 1151.38,244.409 1151.39,244.411 1151.4,244.414 1151.41,244.416 1151.42,244.418 1151.43,244.421 1151.44,244.423 1151.45,244.426 1151.46,244.428 1151.46,244.431 1151.47,244.433 1151.48,244.435 1151.49,244.438 1151.5,244.44 1151.51,244.443 1151.52,244.445 1151.53,244.447 1151.54,244.45 1151.55,244.452 1151.56,244.455 1151.57,244.457 1151.57,244.46 1151.58,244.462 1151.59,244.464 1151.6,244.467 1151.61,244.469 1151.62,244.472 1151.63,244.474 1151.64,244.477 1151.65,244.479 1151.66,244.481 1151.67,244.484 1151.68,244.486 1151.68,244.489 1151.69,244.491 1151.7,244.494 1151.71,244.496 1151.72,244.498 1151.73,244.501 1151.74,244.503 1151.75,244.506 1151.76,244.508 1151.77,244.511 1151.78,244.513 1151.79,244.515 1151.8,244.518 1151.8,244.52 1151.81,244.523 1151.82,244.525 1151.83,244.527 1151.84,244.53 1151.85,244.532 1151.86,244.535 1151.87,244.537 1151.88,244.54 1151.89,244.542 1151.9,244.544 1151.91,244.547 1151.91,244.549 1151.92,244.552 1151.93,244.554 1151.94,244.557 1151.95,244.559 1151.96,244.561 1151.97,244.564 1151.98,244.566 1151.99,244.569 1152,244.571 1152.01,244.574 1152.02,244.576 1152.02,244.578 1152.03,244.581 1152.04,244.583 1152.05,244.586 1152.06,244.588 1152.07,244.59 1152.08,244.593 1152.09,244.595 1152.1,244.598 1152.11,244.6 1152.12,244.603 1152.13,244.605 1152.14,244.607 1152.14,244.61 1152.15,244.612 1152.16,244.615 1152.17,244.617 1152.18,244.62 1152.19,244.622 1152.2,244.624 1152.21,244.627 1152.22,244.629 1152.23,244.632 1152.24,244.634 1152.25,244.637 1152.25,244.639 1152.26,244.641 1152.27,244.644 1152.28,244.646 1152.29,244.649 1152.3,244.651 1152.31,244.653 1152.32,244.656 1152.33,244.658 1152.34,244.661 1152.35,244.663 1152.36,244.666 1152.36,244.668 1152.37,244.67 1152.38,244.673 1152.39,244.675 1152.4,244.678 1152.41,244.68 1152.42,244.683 1152.43,244.685 1152.44,244.687 1152.45,244.69 1152.46,244.692 1152.47,244.695 1152.48,244.697 1152.48,244.699 1152.49,244.702 1152.5,244.704 1152.51,244.707 1152.52,244.709 1152.53,244.712 1152.54,244.714 1152.55,244.716 1152.56,244.719 1152.57,244.721 1152.58,244.724 1152.59,244.726 1152.59,244.729 1152.6,244.731 1152.61,244.733 1152.62,244.736 1152.63,244.738 1152.64,244.741 1152.65,244.743 1152.66,244.746 1152.67,244.748 1152.68,244.75 1152.69,244.753 1152.7,244.755 1152.7,244.758 1152.71,244.76 1152.72,244.762 1152.73,244.765 1152.74,244.767 1152.75,244.77 1152.76,244.772 1152.77,244.775 1152.78,244.777 1152.79,244.779 1152.8,244.782 1152.81,244.784 1152.82,244.787 1152.82,244.789 1152.83,244.792 1152.84,244.794 1152.85,244.796 1152.86,244.799 1152.87,244.801 1152.88,244.804 1152.89,244.806 1152.9,244.808 1152.91,244.811 1152.92,244.813 1152.93,244.816 1152.93,244.818 1152.94,244.821 1152.95,244.823 1152.96,244.825 1152.97,244.828 1152.98,244.83 1152.99,244.833 1153,244.835 1153.01,244.838 1153.02,244.84 1153.03,244.842 1153.04,244.845 1153.04,244.847 1153.05,244.85 1153.06,244.852 1153.07,244.854 1153.08,244.857 1153.09,244.859 1153.1,244.862 1153.11,244.864 1153.12,244.867 1153.13,244.869 1153.14,244.871 1153.15,244.874 1153.16,244.876 1153.16,244.879 1153.17,244.881 1153.18,244.884 1153.19,244.886 1153.2,244.888 1153.21,244.891 1153.22,244.893 1153.23,244.896 1153.24,244.898 1153.25,244.9 1153.26,244.903 1153.27,244.905 1153.27,244.908 1153.28,244.91 1153.29,244.913 1153.3,244.915 1153.31,244.917 1153.32,244.92 1153.33,244.922 1153.34,244.925 1153.35,244.927 1153.36,244.93 1153.37,244.932 1153.38,244.934 1153.38,244.937 1153.39,244.939 1153.4,244.942 1153.41,244.944 1153.42,244.946 1153.43,244.949 1153.44,244.951 1153.45,244.954 1153.46,244.956 1153.47,244.959 1153.48,244.961 1153.49,244.963 1153.5,244.966 1153.5,244.968 1153.51,244.971 1153.52,244.973 1153.53,244.976 1153.54,244.978 1153.55,244.98 1153.56,244.983 1153.57,244.985 1153.58,244.988 1153.59,244.99 1153.6,244.992 1153.61,244.995 1153.61,244.997 1153.62,245 1153.63,245.002 1153.64,245.005 1153.65,245.007 1153.66,245.009 1153.67,245.012 1153.68,245.014 1153.69,245.017 1153.7,245.019 1153.71,245.021 1153.72,245.024 1153.72,245.026 1153.73,245.029 1153.74,245.031 1153.75,245.034 1153.76,245.036 1153.77,245.038 1153.78,245.041 1153.79,245.043 1153.8,245.046 1153.81,245.048 1153.82,245.051 1153.83,245.053 1153.84,245.055 1153.84,245.058 1153.85,245.06 1153.86,245.063 1153.87,245.065 1153.88,245.067 1153.89,245.07 1153.9,245.072 1153.91,245.075 1153.92,245.077 1153.93,245.08 1153.94,245.082 1153.95,245.084 1153.95,245.087 1153.96,245.089 1153.97,245.092 1153.98,245.094 1153.99,245.097 1154,245.099 1154.01,245.101 1154.02,245.104 1154.03,245.106 1154.04,245.109 1154.05,245.111 1154.06,245.113 1154.06,245.116 1154.07,245.118 1154.08,245.121 1154.09,245.123 1154.1,245.126 1154.11,245.128 1154.12,245.13 1154.13,245.133 1154.14,245.135 1154.15,245.138 1154.16,245.14 1154.17,245.142 1154.18,245.145 1154.18,245.147 1154.19,245.15 1154.2,245.152 "/>
<path clip-path="url(#clip400)" d="M772.63 221.962 L1123.57 221.962 L1123.57 66.442 L772.63 66.442  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="772.63,221.962 1123.57,221.962 1123.57,66.442 772.63,66.442 772.63,221.962 "/>
<polyline clip-path="url(#clip400)" style="stroke:#009af9; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="782.841,118.282 844.102,118.282 "/>
<path clip-path="url(#clip400)" d="M854.312 101.002 L858.988 101.002 L858.988 131.627 L875.817 131.627 L875.817 135.562 L854.312 135.562 L854.312 101.002 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M884.428 135.562 L871.233 101.002 L876.118 101.002 L887.067 130.099 L898.039 101.002 L902.9 101.002 L889.729 135.562 L884.428 135.562 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M902.252 129.682 L907.136 129.682 L907.136 135.562 L902.252 135.562 L902.252 129.682 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M920.84 131.673 L920.84 145.423 L916.557 145.423 L916.557 109.636 L920.84 109.636 L920.84 113.571 Q922.182 111.257 924.219 110.145 Q926.279 109.011 929.127 109.011 Q933.849 109.011 936.789 112.761 Q939.752 116.511 939.752 122.622 Q939.752 128.733 936.789 132.483 Q933.849 136.233 929.127 136.233 Q926.279 136.233 924.219 135.122 Q922.182 133.988 920.84 131.673 M935.33 122.622 Q935.33 117.923 933.386 115.261 Q931.465 112.576 928.085 112.576 Q924.705 112.576 922.761 115.261 Q920.84 117.923 920.84 122.622 Q920.84 127.321 922.761 130.006 Q924.705 132.668 928.085 132.668 Q931.465 132.668 933.386 130.006 Q935.33 127.321 935.33 122.622 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M957.043 99.5899 Q953.941 104.914 952.437 110.122 Q950.932 115.331 950.932 120.678 Q950.932 126.025 952.437 131.28 Q953.964 136.511 957.043 141.812 L953.339 141.812 Q949.867 136.372 948.131 131.118 Q946.418 125.863 946.418 120.678 Q946.418 115.516 948.131 110.284 Q949.844 105.053 953.339 99.5899 L957.043 99.5899 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M969.52 102.275 L969.52 109.636 L978.293 109.636 L978.293 112.946 L969.52 112.946 L969.52 127.02 Q969.52 130.192 970.376 131.094 Q971.256 131.997 973.918 131.997 L978.293 131.997 L978.293 135.562 L973.918 135.562 Q968.988 135.562 967.113 133.733 Q965.238 131.881 965.238 127.02 L965.238 112.946 L962.113 112.946 L962.113 109.636 L965.238 109.636 L965.238 102.275 L969.52 102.275 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M983.224 99.5899 L986.927 99.5899 Q990.399 105.053 992.112 110.284 Q993.849 115.516 993.849 120.678 Q993.849 125.863 992.112 131.118 Q990.399 136.372 986.927 141.812 L983.224 141.812 Q986.302 136.511 987.807 131.28 Q989.335 126.025 989.335 120.678 Q989.335 115.331 987.807 110.122 Q986.302 104.914 983.224 99.5899 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip400)" style="stroke:#e26f46; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="782.841,170.122 844.102,170.122 "/>
<path clip-path="url(#clip400)" d="M882.182 155.504 L882.182 160.435 Q879.821 158.235 877.136 157.147 Q874.474 156.06 871.465 156.06 Q865.539 156.06 862.391 159.694 Q859.243 163.305 859.243 170.157 Q859.243 176.985 862.391 180.62 Q865.539 184.231 871.465 184.231 Q874.474 184.231 877.136 183.143 Q879.821 182.055 882.182 179.856 L882.182 184.74 Q879.729 186.407 876.974 187.24 Q874.243 188.073 871.187 188.073 Q863.34 188.073 858.826 183.282 Q854.312 178.467 854.312 170.157 Q854.312 161.823 858.826 157.032 Q863.34 152.217 871.187 152.217 Q874.289 152.217 877.02 153.05 Q879.775 153.86 882.182 155.504 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M905.747 162.24 L905.747 166.268 Q903.942 165.342 901.997 164.879 Q900.053 164.416 897.969 164.416 Q894.798 164.416 893.201 165.388 Q891.627 166.36 891.627 168.305 Q891.627 169.786 892.761 170.643 Q893.895 171.476 897.321 172.24 L898.78 172.564 Q903.317 173.536 905.215 175.319 Q907.136 177.078 907.136 180.249 Q907.136 183.86 904.266 185.967 Q901.418 188.073 896.418 188.073 Q894.335 188.073 892.067 187.657 Q889.821 187.263 887.321 186.453 L887.321 182.055 Q889.682 183.282 891.974 183.907 Q894.266 184.508 896.511 184.508 Q899.52 184.508 901.141 183.49 Q902.761 182.448 902.761 180.573 Q902.761 178.837 901.581 177.911 Q900.423 176.985 896.465 176.129 L894.983 175.782 Q891.025 174.948 889.266 173.235 Q887.507 171.499 887.507 168.49 Q887.507 164.833 890.099 162.842 Q892.692 160.851 897.46 160.851 Q899.821 160.851 901.905 161.198 Q903.988 161.546 905.747 162.24 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M925.701 174.37 Q920.539 174.37 918.548 175.55 Q916.557 176.731 916.557 179.578 Q916.557 181.846 918.039 183.189 Q919.543 184.508 922.113 184.508 Q925.654 184.508 927.784 182.008 Q929.937 179.485 929.937 175.319 L929.937 174.37 L925.701 174.37 M934.196 172.61 L934.196 187.402 L929.937 187.402 L929.937 183.467 Q928.479 185.828 926.303 186.962 Q924.127 188.073 920.979 188.073 Q916.997 188.073 914.636 185.851 Q912.298 183.606 912.298 179.856 Q912.298 175.481 915.215 173.259 Q918.154 171.036 923.965 171.036 L929.937 171.036 L929.937 170.62 Q929.937 167.68 927.992 166.083 Q926.071 164.462 922.576 164.462 Q920.354 164.462 918.247 164.995 Q916.141 165.527 914.196 166.592 L914.196 162.657 Q916.534 161.754 918.733 161.314 Q920.932 160.851 923.016 160.851 Q928.641 160.851 931.418 163.768 Q934.196 166.684 934.196 172.61 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M952.228 170.759 L952.228 177.981 L960.353 177.981 L960.353 180.18 L952.228 180.18 L952.228 187.402 L949.798 187.402 L949.798 180.18 L941.673 180.18 L941.673 177.981 L949.798 177.981 L949.798 170.759 L952.228 170.759 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M967.992 161.476 L972.251 161.476 L972.251 187.402 L967.992 187.402 L967.992 161.476 M967.992 151.384 L972.251 151.384 L972.251 156.777 L967.992 156.777 L967.992 151.384 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1002.71 171.754 L1002.71 187.402 L998.455 187.402 L998.455 171.893 Q998.455 168.212 997.02 166.384 Q995.585 164.555 992.714 164.555 Q989.265 164.555 987.274 166.754 Q985.284 168.953 985.284 172.749 L985.284 187.402 L981.001 187.402 L981.001 161.476 L985.284 161.476 L985.284 165.504 Q986.812 163.166 988.872 162.009 Q990.955 160.851 993.663 160.851 Q998.131 160.851 1000.42 163.629 Q1002.71 166.384 1002.71 171.754 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1020.47 170.759 L1020.47 177.981 L1028.59 177.981 L1028.59 180.18 L1020.47 180.18 L1020.47 187.402 L1018.04 187.402 L1018.04 180.18 L1009.91 180.18 L1009.91 177.981 L1018.04 177.981 L1018.04 170.759 L1020.47 170.759 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1040.35 183.513 L1040.35 197.263 L1036.07 197.263 L1036.07 161.476 L1040.35 161.476 L1040.35 165.411 Q1041.7 163.097 1043.73 161.985 Q1045.79 160.851 1048.64 160.851 Q1053.36 160.851 1056.3 164.601 Q1059.26 168.351 1059.26 174.462 Q1059.26 180.573 1056.3 184.323 Q1053.36 188.073 1048.64 188.073 Q1045.79 188.073 1043.73 186.962 Q1041.7 185.828 1040.35 183.513 M1054.84 174.462 Q1054.84 169.763 1052.9 167.101 Q1050.98 164.416 1047.6 164.416 Q1044.22 164.416 1042.27 167.101 Q1040.35 169.763 1040.35 174.462 Q1040.35 179.161 1042.27 181.846 Q1044.22 184.508 1047.6 184.508 Q1050.98 184.508 1052.9 181.846 Q1054.84 179.161 1054.84 174.462 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1076.56 151.43 Q1073.45 156.754 1071.95 161.962 Q1070.45 167.171 1070.45 172.518 Q1070.45 177.865 1071.95 183.12 Q1073.48 188.351 1076.56 193.652 L1072.85 193.652 Q1069.38 188.212 1067.64 182.958 Q1065.93 177.703 1065.93 172.518 Q1065.93 167.356 1067.64 162.124 Q1069.36 156.893 1072.85 151.43 L1076.56 151.43 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1089.03 154.115 L1089.03 161.476 L1097.81 161.476 L1097.81 164.786 L1089.03 164.786 L1089.03 178.86 Q1089.03 182.032 1089.89 182.934 Q1090.77 183.837 1093.43 183.837 L1097.81 183.837 L1097.81 187.402 L1093.43 187.402 Q1088.5 187.402 1086.63 185.573 Q1084.75 183.721 1084.75 178.86 L1084.75 164.786 L1081.63 164.786 L1081.63 161.476 L1084.75 161.476 L1084.75 154.115 L1089.03 154.115 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1102.74 151.43 L1106.44 151.43 Q1109.91 156.893 1111.63 162.124 Q1113.36 167.356 1113.36 172.518 Q1113.36 177.703 1111.63 182.958 Q1109.91 188.212 1106.44 193.652 L1102.74 193.652 Q1105.82 188.351 1107.32 183.12 Q1108.85 177.865 1108.85 172.518 Q1108.85 167.171 1107.32 161.962 Q1105.82 156.754 1102.74 151.43 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1433.84 623.18 L2352.76 623.18 L2352.76 47.2441 L1433.84 47.2441  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip403">
    <rect x="1433" y="47" width="920" height="577"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip403)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1433.84,623.18 1433.84,47.2441 "/>
<polyline clip-path="url(#clip403)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1650.05,623.18 1650.05,47.2441 "/>
<polyline clip-path="url(#clip403)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1866.27,623.18 1866.27,47.2441 "/>
<polyline clip-path="url(#clip403)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2082.49,623.18 2082.49,47.2441 "/>
<polyline clip-path="url(#clip403)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2298.7,623.18 2298.7,47.2441 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1433.84,623.18 2352.76,623.18 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1433.84,623.18 1433.84,604.282 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1650.05,623.18 1650.05,604.282 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1866.27,623.18 1866.27,604.282 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2082.49,623.18 2082.49,604.282 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2298.7,623.18 2298.7,604.282 "/>
<path clip-path="url(#clip400)" d="M1385.83 681.645 L1393.47 681.645 L1393.47 655.279 L1385.16 656.946 L1385.16 652.687 L1393.42 651.02 L1398.1 651.02 L1398.1 681.645 L1405.73 681.645 L1405.73 685.58 L1385.83 685.58 L1385.83 681.645 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1429.35 666.946 Q1432.7 667.663 1434.58 669.932 Q1436.47 672.2 1436.47 675.534 Q1436.47 680.649 1432.96 683.45 Q1429.44 686.251 1422.96 686.251 Q1420.78 686.251 1418.47 685.811 Q1416.17 685.395 1413.72 684.538 L1413.72 680.024 Q1415.66 681.159 1417.98 681.737 Q1420.29 682.316 1422.82 682.316 Q1427.22 682.316 1429.51 680.58 Q1431.82 678.844 1431.82 675.534 Q1431.82 672.478 1429.67 670.765 Q1427.54 669.029 1423.72 669.029 L1419.69 669.029 L1419.69 665.186 L1423.91 665.186 Q1427.35 665.186 1429.18 663.821 Q1431.01 662.432 1431.01 659.839 Q1431.01 657.177 1429.11 655.765 Q1427.24 654.33 1423.72 654.33 Q1421.8 654.33 1419.6 654.747 Q1417.4 655.163 1414.76 656.043 L1414.76 651.876 Q1417.42 651.136 1419.74 650.765 Q1422.08 650.395 1424.14 650.395 Q1429.46 650.395 1432.56 652.825 Q1435.66 655.233 1435.66 659.353 Q1435.66 662.223 1434.02 664.214 Q1432.38 666.182 1429.35 666.946 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1445.34 679.7 L1450.22 679.7 L1450.22 685.58 L1445.34 685.58 L1445.34 679.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1470.99 666.436 Q1467.84 666.436 1465.99 668.589 Q1464.16 670.742 1464.16 674.492 Q1464.16 678.219 1465.99 680.395 Q1467.84 682.547 1470.99 682.547 Q1474.14 682.547 1475.97 680.395 Q1477.82 678.219 1477.82 674.492 Q1477.82 670.742 1475.97 668.589 Q1474.14 666.436 1470.99 666.436 M1480.27 651.784 L1480.27 656.043 Q1478.51 655.21 1476.71 654.77 Q1474.92 654.33 1473.16 654.33 Q1468.53 654.33 1466.08 657.455 Q1463.65 660.58 1463.3 666.899 Q1464.67 664.886 1466.73 663.821 Q1468.79 662.733 1471.27 662.733 Q1476.47 662.733 1479.48 665.904 Q1482.52 669.052 1482.52 674.492 Q1482.52 679.816 1479.37 683.034 Q1476.22 686.251 1470.99 686.251 Q1464.99 686.251 1461.82 681.668 Q1458.65 677.061 1458.65 668.335 Q1458.65 660.14 1462.54 655.279 Q1466.43 650.395 1472.98 650.395 Q1474.74 650.395 1476.52 650.742 Q1478.33 651.089 1480.27 651.784 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1602.17 681.645 L1609.81 681.645 L1609.81 655.279 L1601.5 656.946 L1601.5 652.687 L1609.76 651.02 L1614.44 651.02 L1614.44 681.645 L1622.08 681.645 L1622.08 685.58 L1602.17 685.58 L1602.17 681.645 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1645.69 666.946 Q1649.05 667.663 1650.92 669.932 Q1652.82 672.2 1652.82 675.534 Q1652.82 680.649 1649.3 683.45 Q1645.78 686.251 1639.3 686.251 Q1637.12 686.251 1634.81 685.811 Q1632.52 685.395 1630.06 684.538 L1630.06 680.024 Q1632.01 681.159 1634.32 681.737 Q1636.64 682.316 1639.16 682.316 Q1643.56 682.316 1645.85 680.58 Q1648.17 678.844 1648.17 675.534 Q1648.17 672.478 1646.01 670.765 Q1643.88 669.029 1640.06 669.029 L1636.04 669.029 L1636.04 665.186 L1640.25 665.186 Q1643.7 665.186 1645.53 663.821 Q1647.36 662.432 1647.36 659.839 Q1647.36 657.177 1645.46 655.765 Q1643.58 654.33 1640.06 654.33 Q1638.14 654.33 1635.94 654.747 Q1633.74 655.163 1631.11 656.043 L1631.11 651.876 Q1633.77 651.136 1636.08 650.765 Q1638.42 650.395 1640.48 650.395 Q1645.8 650.395 1648.91 652.825 Q1652.01 655.233 1652.01 659.353 Q1652.01 662.223 1650.37 664.214 Q1648.72 666.182 1645.69 666.946 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1661.68 679.7 L1666.57 679.7 L1666.57 685.58 L1661.68 685.58 L1661.68 679.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1686.75 669.168 Q1683.42 669.168 1681.5 670.95 Q1679.6 672.733 1679.6 675.858 Q1679.6 678.983 1681.5 680.765 Q1683.42 682.547 1686.75 682.547 Q1690.09 682.547 1692.01 680.765 Q1693.93 678.96 1693.93 675.858 Q1693.93 672.733 1692.01 670.95 Q1690.11 669.168 1686.75 669.168 M1682.08 667.177 Q1679.07 666.436 1677.38 664.376 Q1675.71 662.316 1675.71 659.353 Q1675.71 655.21 1678.65 652.802 Q1681.61 650.395 1686.75 650.395 Q1691.92 650.395 1694.86 652.802 Q1697.8 655.21 1697.8 659.353 Q1697.8 662.316 1696.11 664.376 Q1694.44 666.436 1691.45 667.177 Q1694.83 667.964 1696.71 670.256 Q1698.61 672.548 1698.61 675.858 Q1698.61 680.881 1695.53 683.566 Q1692.47 686.251 1686.75 686.251 Q1681.04 686.251 1677.96 683.566 Q1674.9 680.881 1674.9 675.858 Q1674.9 672.548 1676.8 670.256 Q1678.7 667.964 1682.08 667.177 M1680.36 659.793 Q1680.36 662.478 1682.03 663.983 Q1683.72 665.487 1686.75 665.487 Q1689.76 665.487 1691.45 663.983 Q1693.17 662.478 1693.17 659.793 Q1693.17 657.108 1691.45 655.603 Q1689.76 654.099 1686.75 654.099 Q1683.72 654.099 1682.03 655.603 Q1680.36 657.108 1680.36 659.793 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1818.34 681.645 L1825.98 681.645 L1825.98 655.279 L1817.67 656.946 L1817.67 652.687 L1825.93 651.02 L1830.61 651.02 L1830.61 681.645 L1838.25 681.645 L1838.25 685.58 L1818.34 685.58 L1818.34 681.645 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1860.54 655.094 L1848.73 673.543 L1860.54 673.543 L1860.54 655.094 M1859.31 651.02 L1865.19 651.02 L1865.19 673.543 L1870.12 673.543 L1870.12 677.432 L1865.19 677.432 L1865.19 685.58 L1860.54 685.58 L1860.54 677.432 L1844.94 677.432 L1844.94 672.918 L1859.31 651.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1877.85 679.7 L1882.74 679.7 L1882.74 685.58 L1877.85 685.58 L1877.85 679.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1902.92 654.099 Q1899.31 654.099 1897.48 657.663 Q1895.68 661.205 1895.68 668.335 Q1895.68 675.441 1897.48 679.006 Q1899.31 682.547 1902.92 682.547 Q1906.56 682.547 1908.36 679.006 Q1910.19 675.441 1910.19 668.335 Q1910.19 661.205 1908.36 657.663 Q1906.56 654.099 1902.92 654.099 M1902.92 650.395 Q1908.73 650.395 1911.79 655.001 Q1914.87 659.585 1914.87 668.335 Q1914.87 677.061 1911.79 681.668 Q1908.73 686.251 1902.92 686.251 Q1897.11 686.251 1894.04 681.668 Q1890.98 677.061 1890.98 668.335 Q1890.98 659.585 1894.04 655.001 Q1897.11 650.395 1902.92 650.395 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2035.36 681.645 L2042.99 681.645 L2042.99 655.279 L2034.68 656.946 L2034.68 652.687 L2042.95 651.02 L2047.62 651.02 L2047.62 681.645 L2055.26 681.645 L2055.26 685.58 L2035.36 685.58 L2035.36 681.645 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2077.55 655.094 L2065.75 673.543 L2077.55 673.543 L2077.55 655.094 M2076.33 651.02 L2082.21 651.02 L2082.21 673.543 L2087.14 673.543 L2087.14 677.432 L2082.21 677.432 L2082.21 685.58 L2077.55 685.58 L2077.55 677.432 L2061.95 677.432 L2061.95 672.918 L2076.33 651.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2094.87 679.7 L2099.75 679.7 L2099.75 685.58 L2094.87 685.58 L2094.87 679.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2113.97 681.645 L2130.29 681.645 L2130.29 685.58 L2108.34 685.58 L2108.34 681.645 Q2111 678.89 2115.59 674.26 Q2120.19 669.608 2121.37 668.265 Q2123.62 665.742 2124.5 664.006 Q2125.4 662.247 2125.4 660.557 Q2125.4 657.802 2123.46 656.066 Q2121.54 654.33 2118.43 654.33 Q2116.24 654.33 2113.78 655.094 Q2111.35 655.858 2108.57 657.409 L2108.57 652.687 Q2111.4 651.552 2113.85 650.974 Q2116.3 650.395 2118.34 650.395 Q2123.71 650.395 2126.91 653.08 Q2130.1 655.765 2130.1 660.256 Q2130.1 662.386 2129.29 664.307 Q2128.5 666.205 2126.4 668.798 Q2125.82 669.469 2122.72 672.686 Q2119.61 675.881 2113.97 681.645 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2250.53 681.645 L2258.17 681.645 L2258.17 655.279 L2249.86 656.946 L2249.86 652.687 L2258.12 651.02 L2262.8 651.02 L2262.8 681.645 L2270.44 681.645 L2270.44 685.58 L2250.53 685.58 L2250.53 681.645 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2292.73 655.094 L2280.92 673.543 L2292.73 673.543 L2292.73 655.094 M2291.5 651.02 L2297.38 651.02 L2297.38 673.543 L2302.31 673.543 L2302.31 677.432 L2297.38 677.432 L2297.38 685.58 L2292.73 685.58 L2292.73 677.432 L2277.13 677.432 L2277.13 672.918 L2291.5 651.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2310.04 679.7 L2314.93 679.7 L2314.93 685.58 L2310.04 685.58 L2310.04 679.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2337.96 655.094 L2326.16 673.543 L2337.96 673.543 L2337.96 655.094 M2336.73 651.02 L2342.61 651.02 L2342.61 673.543 L2347.54 673.543 L2347.54 677.432 L2342.61 677.432 L2342.61 685.58 L2337.96 685.58 L2337.96 677.432 L2322.36 677.432 L2322.36 672.918 L2336.73 651.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1763.47 720.524 L1803.67 720.524 L1803.67 725.935 L1786.8 725.935 L1786.8 768.044 L1780.34 768.044 L1780.34 725.935 L1763.47 725.935 L1763.47 720.524 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1807.61 732.396 L1813.47 732.396 L1813.47 768.044 L1807.61 768.044 L1807.61 732.396 M1807.61 718.519 L1813.47 718.519 L1813.47 725.935 L1807.61 725.935 L1807.61 718.519 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1853.48 739.239 Q1855.67 735.292 1858.73 733.414 Q1861.79 731.537 1865.92 731.537 Q1871.49 731.537 1874.52 735.451 Q1877.54 739.335 1877.54 746.528 L1877.54 768.044 L1871.65 768.044 L1871.65 746.719 Q1871.65 741.594 1869.84 739.112 Q1868.02 736.629 1864.3 736.629 Q1859.75 736.629 1857.11 739.653 Q1854.47 742.677 1854.47 747.896 L1854.47 768.044 L1848.58 768.044 L1848.58 746.719 Q1848.58 741.563 1846.76 739.112 Q1844.95 736.629 1841.16 736.629 Q1836.67 736.629 1834.03 739.685 Q1831.39 742.708 1831.39 747.896 L1831.39 768.044 L1825.5 768.044 L1825.5 732.396 L1831.39 732.396 L1831.39 737.934 Q1833.39 734.656 1836.2 733.096 Q1839 731.537 1842.85 731.537 Q1846.73 731.537 1849.44 733.51 Q1852.17 735.483 1853.48 739.239 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1919.71 748.756 L1919.71 751.62 L1892.79 751.62 Q1893.17 757.668 1896.42 760.851 Q1899.69 764.002 1905.52 764.002 Q1908.89 764.002 1912.04 763.174 Q1915.23 762.347 1918.35 760.691 L1918.35 766.23 Q1915.19 767.566 1911.88 768.267 Q1908.57 768.967 1905.17 768.967 Q1896.64 768.967 1891.64 764.002 Q1886.68 759.036 1886.68 750.57 Q1886.68 741.817 1891.39 736.693 Q1896.13 731.537 1904.15 731.537 Q1911.34 731.537 1915.51 736.183 Q1919.71 740.799 1919.71 748.756 M1913.86 747.037 Q1913.79 742.231 1911.15 739.366 Q1908.54 736.502 1904.21 736.502 Q1899.31 736.502 1896.35 739.271 Q1893.42 742.04 1892.98 747.069 L1913.86 747.037 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1949.51 718.519 L1963 718.519 L1963 723.07 L1955.36 723.07 L1955.36 772.086 L1963 772.086 L1963 776.638 L1949.51 776.638 L1949.51 718.519 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1998.2 733.446 L1998.2 738.984 Q1995.72 737.711 1993.05 737.075 Q1990.37 736.438 1987.51 736.438 Q1983.15 736.438 1980.95 737.775 Q1978.79 739.112 1978.79 741.785 Q1978.79 743.822 1980.35 745 Q1981.91 746.146 1986.62 747.196 L1988.62 747.642 Q1994.86 748.979 1997.47 751.429 Q2000.11 753.848 2000.11 758.209 Q2000.11 763.174 1996.17 766.07 Q1992.25 768.967 1985.38 768.967 Q1982.51 768.967 1979.39 768.394 Q1976.3 767.853 1972.87 766.739 L1972.87 760.691 Q1976.11 762.378 1979.26 763.238 Q1982.42 764.065 1985.5 764.065 Q1989.64 764.065 1991.87 762.665 Q1994.1 761.233 1994.1 758.654 Q1994.1 756.267 1992.47 754.994 Q1990.88 753.721 1985.44 752.543 L1983.4 752.066 Q1977.96 750.92 1975.54 748.565 Q1973.12 746.178 1973.12 742.04 Q1973.12 737.011 1976.69 734.274 Q1980.25 731.537 1986.81 731.537 Q1990.05 731.537 1992.92 732.014 Q1995.78 732.491 1998.2 733.446 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2023.12 718.519 L2023.12 776.638 L2009.63 776.638 L2009.63 772.086 L2017.24 772.086 L2017.24 723.07 L2009.63 723.07 L2009.63 718.519 L2023.12 718.519 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip403)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1433.84,500.638 2352.76,500.638 "/>
<polyline clip-path="url(#clip403)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1433.84,358.127 2352.76,358.127 "/>
<polyline clip-path="url(#clip403)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1433.84,215.616 2352.76,215.616 "/>
<polyline clip-path="url(#clip403)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1433.84,73.1058 2352.76,73.1058 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1433.84,623.18 1433.84,47.2441 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1433.84,500.638 1452.73,500.638 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1433.84,358.127 1452.73,358.127 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1433.84,215.616 1452.73,215.616 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1433.84,73.1058 1452.73,73.1058 "/>
<path clip-path="url(#clip400)" d="M1316.38 513.983 L1324.02 513.983 L1324.02 487.617 L1315.71 489.284 L1315.71 485.024 L1323.97 483.358 L1328.65 483.358 L1328.65 513.983 L1336.29 513.983 L1336.29 517.918 L1316.38 517.918 L1316.38 513.983 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1355.73 486.436 Q1352.12 486.436 1350.29 490.001 Q1348.48 493.543 1348.48 500.672 Q1348.48 507.779 1350.29 511.344 Q1352.12 514.885 1355.73 514.885 Q1359.36 514.885 1361.17 511.344 Q1363 507.779 1363 500.672 Q1363 493.543 1361.17 490.001 Q1359.36 486.436 1355.73 486.436 M1355.73 482.733 Q1361.54 482.733 1364.6 487.339 Q1367.67 491.922 1367.67 500.672 Q1367.67 509.399 1364.6 514.006 Q1361.54 518.589 1355.73 518.589 Q1349.92 518.589 1346.84 514.006 Q1343.79 509.399 1343.79 500.672 Q1343.79 491.922 1346.84 487.339 Q1349.92 482.733 1355.73 482.733 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1385.89 486.436 Q1382.28 486.436 1380.45 490.001 Q1378.65 493.543 1378.65 500.672 Q1378.65 507.779 1380.45 511.344 Q1382.28 514.885 1385.89 514.885 Q1389.53 514.885 1391.33 511.344 Q1393.16 507.779 1393.16 500.672 Q1393.16 493.543 1391.33 490.001 Q1389.53 486.436 1385.89 486.436 M1385.89 482.733 Q1391.7 482.733 1394.76 487.339 Q1397.84 491.922 1397.84 500.672 Q1397.84 509.399 1394.76 514.006 Q1391.7 518.589 1385.89 518.589 Q1380.08 518.589 1377 514.006 Q1373.95 509.399 1373.95 500.672 Q1373.95 491.922 1377 487.339 Q1380.08 482.733 1385.89 482.733 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1316.38 371.472 L1324.02 371.472 L1324.02 345.106 L1315.71 346.773 L1315.71 342.514 L1323.97 340.847 L1328.65 340.847 L1328.65 371.472 L1336.29 371.472 L1336.29 375.407 L1316.38 375.407 L1316.38 371.472 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1349.76 371.472 L1366.08 371.472 L1366.08 375.407 L1344.13 375.407 L1344.13 371.472 Q1346.79 368.717 1351.38 364.088 Q1355.98 359.435 1357.17 358.092 Q1359.41 355.569 1360.29 353.833 Q1361.19 352.074 1361.19 350.384 Q1361.19 347.629 1359.25 345.893 Q1357.33 344.157 1354.23 344.157 Q1352.03 344.157 1349.57 344.921 Q1347.14 345.685 1344.36 347.236 L1344.36 342.514 Q1347.19 341.379 1349.64 340.801 Q1352.1 340.222 1354.13 340.222 Q1359.5 340.222 1362.7 342.907 Q1365.89 345.592 1365.89 350.083 Q1365.89 352.213 1365.08 354.134 Q1364.29 356.032 1362.19 358.625 Q1361.61 359.296 1358.51 362.514 Q1355.41 365.708 1349.76 371.472 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1385.89 343.926 Q1382.28 343.926 1380.45 347.491 Q1378.65 351.032 1378.65 358.162 Q1378.65 365.268 1380.45 368.833 Q1382.28 372.375 1385.89 372.375 Q1389.53 372.375 1391.33 368.833 Q1393.16 365.268 1393.16 358.162 Q1393.16 351.032 1391.33 347.491 Q1389.53 343.926 1385.89 343.926 M1385.89 340.222 Q1391.7 340.222 1394.76 344.829 Q1397.84 349.412 1397.84 358.162 Q1397.84 366.889 1394.76 371.495 Q1391.7 376.078 1385.89 376.078 Q1380.08 376.078 1377 371.495 Q1373.95 366.889 1373.95 358.162 Q1373.95 349.412 1377 344.829 Q1380.08 340.222 1385.89 340.222 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1316.38 228.961 L1324.02 228.961 L1324.02 202.596 L1315.71 204.262 L1315.71 200.003 L1323.97 198.336 L1328.65 198.336 L1328.65 228.961 L1336.29 228.961 L1336.29 232.896 L1316.38 232.896 L1316.38 228.961 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1358.58 202.411 L1346.77 220.859 L1358.58 220.859 L1358.58 202.411 M1357.35 198.336 L1363.23 198.336 L1363.23 220.859 L1368.16 220.859 L1368.16 224.748 L1363.23 224.748 L1363.23 232.896 L1358.58 232.896 L1358.58 224.748 L1342.98 224.748 L1342.98 220.234 L1357.35 198.336 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1385.89 201.415 Q1382.28 201.415 1380.45 204.98 Q1378.65 208.522 1378.65 215.651 Q1378.65 222.758 1380.45 226.322 Q1382.28 229.864 1385.89 229.864 Q1389.53 229.864 1391.33 226.322 Q1393.16 222.758 1393.16 215.651 Q1393.16 208.522 1391.33 204.98 Q1389.53 201.415 1385.89 201.415 M1385.89 197.711 Q1391.7 197.711 1394.76 202.318 Q1397.84 206.901 1397.84 215.651 Q1397.84 224.378 1394.76 228.984 Q1391.7 233.568 1385.89 233.568 Q1380.08 233.568 1377 228.984 Q1373.95 224.378 1373.95 215.651 Q1373.95 206.901 1377 202.318 Q1380.08 197.711 1385.89 197.711 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1316.38 86.4507 L1324.02 86.4507 L1324.02 60.0851 L1315.71 61.7517 L1315.71 57.4925 L1323.97 55.8258 L1328.65 55.8258 L1328.65 86.4507 L1336.29 86.4507 L1336.29 90.3858 L1316.38 90.3858 L1316.38 86.4507 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1356.31 71.2424 Q1353.16 71.2424 1351.31 73.3952 Q1349.48 75.5479 1349.48 79.2979 Q1349.48 83.0248 1351.31 85.2007 Q1353.16 87.3534 1356.31 87.3534 Q1359.46 87.3534 1361.29 85.2007 Q1363.14 83.0248 1363.14 79.2979 Q1363.14 75.5479 1361.29 73.3952 Q1359.46 71.2424 1356.31 71.2424 M1365.59 56.5897 L1365.59 60.849 Q1363.83 60.0156 1362.03 59.5758 Q1360.24 59.136 1358.48 59.136 Q1353.85 59.136 1351.4 62.261 Q1348.97 65.386 1348.62 71.7054 Q1349.99 69.6915 1352.05 68.6267 Q1354.11 67.5387 1356.59 67.5387 Q1361.79 67.5387 1364.8 70.71 Q1367.84 73.8581 1367.84 79.2979 Q1367.84 84.622 1364.69 87.8395 Q1361.54 91.0571 1356.31 91.0571 Q1350.31 91.0571 1347.14 86.4738 Q1343.97 81.8674 1343.97 73.1406 Q1343.97 64.9462 1347.86 60.0851 Q1351.75 55.2008 1358.3 55.2008 Q1360.06 55.2008 1361.84 55.5481 Q1363.65 55.8953 1365.59 56.5897 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1385.89 58.9045 Q1382.28 58.9045 1380.45 62.4693 Q1378.65 66.011 1378.65 73.1406 Q1378.65 80.247 1380.45 83.8118 Q1382.28 87.3534 1385.89 87.3534 Q1389.53 87.3534 1391.33 83.8118 Q1393.16 80.247 1393.16 73.1406 Q1393.16 66.011 1391.33 62.4693 Q1389.53 58.9045 1385.89 58.9045 M1385.89 55.2008 Q1391.7 55.2008 1394.76 59.8073 Q1397.84 64.3906 1397.84 73.1406 Q1397.84 81.8674 1394.76 86.4738 Q1391.7 91.0571 1385.89 91.0571 Q1380.08 91.0571 1377 86.4738 Q1373.95 81.8674 1373.95 73.1406 Q1373.95 64.3906 1377 59.8073 Q1380.08 55.2008 1385.89 55.2008 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1265.45 511.828 L1217.93 529.971 L1217.93 523.255 L1257.94 508.2 L1217.93 493.113 L1217.93 486.429 L1265.45 504.54 L1265.45 511.828 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1233.91 470.992 Q1233.91 475.703 1237.6 478.44 Q1241.26 481.178 1247.66 481.178 Q1254.06 481.178 1257.75 478.472 Q1261.41 475.735 1261.41 470.992 Q1261.41 466.314 1257.72 463.576 Q1254.02 460.839 1247.66 460.839 Q1241.32 460.839 1237.63 463.576 Q1233.91 466.314 1233.91 470.992 M1228.94 470.992 Q1228.94 463.354 1233.91 458.993 Q1238.87 454.633 1247.66 454.633 Q1256.41 454.633 1261.41 458.993 Q1266.37 463.354 1266.37 470.992 Q1266.37 478.663 1261.41 483.024 Q1256.41 487.352 1247.66 487.352 Q1238.87 487.352 1233.91 483.024 Q1228.94 478.663 1228.94 470.992 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1215.93 444.925 L1215.93 439.068 L1265.45 439.068 L1265.45 444.925 L1215.93 444.925 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1251.38 427.419 L1229.8 427.419 L1229.8 421.563 L1251.16 421.563 Q1256.22 421.563 1258.77 419.589 Q1261.28 417.616 1261.28 413.669 Q1261.28 408.927 1258.26 406.19 Q1255.23 403.421 1250.01 403.421 L1229.8 403.421 L1229.8 397.564 L1265.45 397.564 L1265.45 403.421 L1259.98 403.421 Q1263.22 405.553 1264.81 408.386 Q1266.37 411.187 1266.37 414.911 Q1266.37 421.054 1262.55 424.236 Q1258.74 427.419 1251.38 427.419 M1228.94 412.683 L1228.94 412.683 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1236.65 357.747 Q1232.7 355.55 1230.82 352.495 Q1228.94 349.439 1228.94 345.302 Q1228.94 339.732 1232.86 336.708 Q1236.74 333.684 1243.93 333.684 L1265.45 333.684 L1265.45 339.572 L1244.13 339.572 Q1239 339.572 1236.52 341.387 Q1234.04 343.201 1234.04 346.925 Q1234.04 351.476 1237.06 354.118 Q1240.08 356.76 1245.3 356.76 L1265.45 356.76 L1265.45 362.648 L1244.13 362.648 Q1238.97 362.648 1236.52 364.462 Q1234.04 366.277 1234.04 370.064 Q1234.04 374.552 1237.09 377.194 Q1240.12 379.836 1245.3 379.836 L1265.45 379.836 L1265.45 385.724 L1229.8 385.724 L1229.8 379.836 L1235.34 379.836 Q1232.06 377.83 1230.5 375.029 Q1228.94 372.229 1228.94 368.377 Q1228.94 364.494 1230.92 361.789 Q1232.89 359.052 1236.65 357.747 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1246.16 291.511 L1249.03 291.511 L1249.03 318.438 Q1255.07 318.056 1258.26 314.81 Q1261.41 311.532 1261.41 305.707 Q1261.41 302.333 1260.58 299.182 Q1259.75 295.999 1258.1 292.88 L1263.64 292.88 Q1264.97 296.031 1265.67 299.341 Q1266.37 302.651 1266.37 306.057 Q1266.37 314.587 1261.41 319.584 Q1256.44 324.549 1247.98 324.549 Q1239.22 324.549 1234.1 319.839 Q1228.94 315.096 1228.94 307.076 Q1228.94 299.882 1233.59 295.713 Q1238.21 291.511 1246.16 291.511 M1244.44 297.368 Q1239.64 297.431 1236.77 300.073 Q1233.91 302.683 1233.91 307.012 Q1233.91 311.913 1236.68 314.874 Q1239.45 317.802 1244.48 318.247 L1244.44 297.368 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1215.93 261.72 L1215.93 248.225 L1220.48 248.225 L1220.48 255.863 L1269.49 255.863 L1269.49 248.225 L1274.04 248.225 L1274.04 261.72 L1215.93 261.72 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1236.65 207.993 Q1232.7 205.797 1230.82 202.742 Q1228.94 199.686 1228.94 195.548 Q1228.94 189.978 1232.86 186.955 Q1236.74 183.931 1243.93 183.931 L1265.45 183.931 L1265.45 189.819 L1244.13 189.819 Q1239 189.819 1236.52 191.633 Q1234.04 193.448 1234.04 197.172 Q1234.04 201.723 1237.06 204.365 Q1240.08 207.007 1245.3 207.007 L1265.45 207.007 L1265.45 212.895 L1244.13 212.895 Q1238.97 212.895 1236.52 214.709 Q1234.04 216.523 1234.04 220.311 Q1234.04 224.799 1237.09 227.441 Q1240.12 230.082 1245.3 230.082 L1265.45 230.082 L1265.45 235.971 L1229.8 235.971 L1229.8 230.082 L1235.34 230.082 Q1232.06 228.077 1230.5 225.276 Q1228.94 222.475 1228.94 218.624 Q1228.94 214.741 1230.92 212.036 Q1232.89 209.298 1236.65 207.993 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1215.93 172.25 L1215.93 166.393 L1265.45 166.393 L1265.45 172.25 L1215.93 172.25 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1215.93 140.453 L1274.04 140.453 L1274.04 153.948 L1269.49 153.948 L1269.49 146.341 L1220.48 146.341 L1220.48 153.948 L1215.93 153.948 L1215.93 140.453 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip403)" style="stroke:#009af9; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1433.84,63.891 1433.85,63.8591 1433.85,63.8555 1433.86,63.8518 1433.87,63.8482 1433.88,63.8445 1433.89,63.8409 1433.9,63.8373 1433.91,63.8337 1433.92,63.8301 1433.93,63.8265 1433.94,63.8229 1433.95,63.8194 1433.96,63.8158 1433.96,63.8123 1433.97,63.8088 1433.98,63.8053 1433.99,63.8018 1434,63.7983 1434.01,63.7949 1434.02,63.7915 1434.03,63.7881 1434.04,63.7847 1434.05,63.7813 1434.06,63.7779 1434.07,63.7746 1434.08,63.7712 1434.08,63.7679 1434.09,63.7646 1434.1,63.7614 1434.11,63.7581 1434.12,63.7549 1434.13,63.7517 1434.14,63.7485 1434.15,63.7453 1434.16,63.7421 1434.17,63.739 1434.18,63.7359 1434.19,63.7328 1434.19,63.7297 1434.2,63.7267 1434.21,63.7236 1434.22,63.7206 1434.23,63.7176 1434.24,63.7147 1434.25,63.7117 1434.26,63.7088 1434.27,63.7059 1434.28,63.703 1434.29,63.7001 1434.3,63.6973 1434.3,63.6945 1434.31,63.6917 1434.32,63.6889 1434.33,63.6862 1434.34,63.6834 1434.35,63.6807 1434.36,63.6781 1434.37,63.6754 1434.38,63.6728 1434.39,63.6702 1434.4,63.6676 1434.41,63.665 1434.42,63.6625 1434.42,63.66 1434.43,63.6575 1434.44,63.655 1434.45,63.6526 1434.46,63.6502 1434.47,63.6478 1434.48,63.6454 1434.49,63.6431 1434.5,63.6407 1434.51,63.6384 1434.52,63.6362 1434.53,63.6339 1434.53,63.6317 1434.54,63.6295 1434.55,63.6274 1434.56,63.6252 1434.57,63.6231 1434.58,63.621 1434.59,63.619 1434.6,63.6169 1434.61,63.6149 1434.62,63.6129 1434.63,63.611 1434.64,63.609 1434.64,63.6071 1434.65,63.6052 1434.66,63.6034 1434.67,63.6016 1434.68,63.5998 1434.69,63.598 1434.7,63.5963 1434.71,63.5945 1434.72,63.5928 1434.73,63.5912 1434.74,63.5896 1434.75,63.5879 1434.76,63.5864 1434.76,63.5848 1434.77,63.5833 1434.78,63.5818 1434.79,63.5803 1434.8,63.5789 1434.81,63.5775 1434.82,63.5761 1434.83,63.5747 1434.84,63.5734 1434.85,63.5721 1434.86,63.5708 1434.87,63.5696 1434.87,63.5684 1434.88,63.5672 1434.89,63.566 1434.9,63.5649 1434.91,63.5638 1434.92,63.5627 1434.93,63.5617 1434.94,63.5607 1434.95,63.5597 1434.96,63.5588 1434.97,63.5578 1434.98,63.5569 1434.98,63.5561 1434.99,63.5552 1435,63.5544 1435.01,63.5537 1435.02,63.5529 1435.03,63.5522 1435.04,63.5515 1435.05,63.5509 1435.06,63.5502 1435.07,63.5496 1435.08,63.5491 1435.09,63.5485 1435.1,63.548 1435.1,63.5476 1435.11,63.5471 1435.12,63.5467 1435.13,63.5463 1435.14,63.546 1435.15,63.5457 1435.16,63.5454 1435.17,63.5451 1435.18,63.5449 1435.19,63.5447 1435.2,63.5445 1435.21,63.5444 1435.21,63.5443 1435.22,63.5442 1435.23,63.5442 1435.24,63.5442 1435.25,63.5442 1435.26,63.5442 1435.27,63.5442 1435.28,63.5442 1435.29,63.5442 1435.3,63.5442 1435.31,63.5442 1435.32,63.5442 1435.32,63.5442 1435.33,63.5442 1435.34,63.5442 1435.35,63.5442 1435.36,63.5442 1435.37,63.5442 1435.38,63.5442 1435.39,63.5442 1435.4,63.5442 1435.41,63.5442 1435.42,63.5442 1435.43,63.5442 1435.44,63.5442 1435.44,63.5442 1435.45,63.5442 1435.46,63.5442 1435.47,63.5442 1435.48,63.5442 1435.49,63.5442 1435.5,63.5442 1435.51,63.5442 1435.52,63.5442 1435.53,63.5442 1435.54,63.5442 1435.55,63.5442 1435.55,63.5442 1435.56,63.5442 1435.57,63.5442 1435.58,63.5442 1435.59,63.5442 1435.6,63.5442 1435.61,63.5442 1435.62,63.5442 1435.63,63.5442 1435.64,63.5442 1435.65,63.5442 1435.66,63.5442 1435.66,63.5442 1435.67,63.5442 1435.68,63.5442 1435.69,63.5442 1435.7,63.5442 1435.71,63.5442 1435.72,63.5442 1435.73,63.5442 1435.74,63.5442 1435.75,63.5442 1435.76,63.5442 1435.77,63.5442 1435.78,63.5442 1435.78,63.5442 1435.79,63.5442 1435.8,63.5442 1435.81,63.5442 1435.82,63.5442 1435.83,63.5442 1435.84,63.5442 1435.85,63.5442 1435.86,63.5442 1435.87,63.5442 1435.88,63.5442 1435.89,63.5442 1435.89,63.5442 1435.9,63.5442 1435.91,63.5442 1435.92,63.5442 1435.93,63.5442 1435.94,63.5442 1435.95,63.5442 1435.96,63.5442 1435.97,63.5442 1435.98,63.5442 1435.99,63.5442 1436,63.5442 1436,63.5442 1436.01,63.5442 1436.02,63.5442 1436.03,63.5442 1436.04,63.5442 1436.05,63.5442 1436.06,63.5442 1436.07,63.5442 1436.08,63.5442 1436.09,63.5442 1436.1,63.5442 1436.11,63.5442 1436.12,63.5442 1436.12,63.5442 1436.13,63.5442 1436.14,63.5442 1436.15,63.5442 1436.16,63.5442 1436.17,63.5442 1436.18,63.5442 1436.19,63.5442 1436.2,63.5442 1436.21,63.5442 1436.22,63.5442 1436.23,63.5442 1436.23,63.5442 1436.24,63.5442 1436.25,63.5442 1436.26,63.5442 1436.27,63.5442 1436.28,63.5442 1436.29,63.5442 1436.3,63.5442 1436.31,63.5442 1436.32,63.5442 1436.33,63.5442 1436.34,63.5442 1436.34,63.5442 1436.35,63.5442 1436.36,63.5442 1436.37,63.5442 1436.38,63.5442 1436.39,63.5442 1436.4,63.5442 1436.41,63.5442 1436.42,63.5442 1436.43,63.5442 1436.44,63.5442 1436.45,63.5442 1436.46,63.5442 1436.46,63.5442 1436.47,63.5442 1436.48,63.5442 1436.49,63.5442 1436.5,63.5442 1436.51,63.5442 1436.52,63.5442 1436.53,63.5442 1436.54,63.5442 1436.55,63.5442 1436.56,63.5442 1436.57,63.5442 1436.57,63.5442 1436.58,63.5442 1436.59,63.5442 1436.6,63.5442 1436.61,63.5442 1436.62,63.5442 1436.63,63.5442 1436.64,63.5442 1436.65,63.5442 1436.66,63.5442 1436.67,63.5442 1436.68,63.5442 1436.68,63.5442 1436.69,63.5442 1436.7,63.5442 1436.71,63.5442 1436.72,63.5442 1436.73,63.5442 1436.74,63.5442 1436.75,63.5442 1436.76,63.5442 1436.77,63.5442 1436.78,63.5442 1436.79,63.5442 1436.8,63.5442 1436.8,63.5442 1436.81,63.5442 1436.82,63.5442 1436.83,63.5442 1436.84,63.5442 1436.85,63.5442 1436.86,63.5442 1436.87,63.5442 1436.88,63.5442 1436.89,63.5442 1436.9,63.5442 1436.91,63.5442 1436.91,63.5442 1436.92,63.5442 1436.93,63.5442 1436.94,63.5442 1436.95,63.5442 1436.96,63.5442 1436.97,63.5442 1436.98,63.5442 1436.99,63.5442 1437,63.5442 1437.01,63.5442 1437.02,63.5442 1437.02,63.5442 1437.03,63.5442 1437.04,63.5442 1437.05,63.5442 1437.06,63.5442 1437.07,63.5442 1437.08,63.5442 1437.09,63.5442 1437.1,63.5442 1437.11,63.5442 1437.12,63.5442 1437.13,63.5442 1437.14,63.5442 1437.14,63.5442 1437.15,63.5442 1437.16,63.5442 1437.17,63.5442 1437.18,63.5442 1437.19,63.5442 1437.2,63.5442 1437.21,63.5442 1437.22,63.5442 1437.23,63.5442 1437.24,63.5442 1437.25,63.5442 1437.25,63.5442 1437.26,63.5442 1437.27,63.5442 1437.28,63.5442 1437.29,63.5442 1437.3,63.5442 1437.31,63.5442 1437.32,63.5442 1437.33,63.5442 1437.34,63.5442 1437.35,63.5442 1437.36,63.5442 1437.36,63.5442 1437.37,63.5442 1437.38,63.5442 1437.39,63.5442 1437.4,63.5442 1437.41,63.5442 1437.42,63.5442 1437.43,63.5442 1437.44,63.5442 1437.45,63.5442 1437.46,63.5442 1437.47,63.5442 1437.48,63.5442 1437.48,63.5442 1437.49,63.5442 1437.5,63.5442 1437.51,63.5442 1437.52,63.5442 1437.53,63.5442 1437.54,63.5442 1437.55,63.5442 1437.56,63.5442 1437.57,63.5442 1437.58,63.5442 1437.59,63.5442 1437.59,63.5442 1437.6,63.5442 1437.61,63.5442 1437.62,63.5442 1437.63,63.5442 1437.64,63.5442 1437.65,63.5442 1437.66,63.5442 1437.67,63.5442 1437.68,63.5442 1437.69,63.5442 1437.7,63.5442 1437.7,63.5442 1437.71,63.5442 1437.72,63.5442 1437.73,63.5442 1437.74,63.5442 1437.75,63.5442 1437.76,63.5442 1437.77,63.5442 1437.78,63.5442 1437.79,63.5442 1437.8,63.5442 1437.81,63.5442 1437.82,63.5442 1437.82,63.5442 1437.83,63.5442 1437.84,63.5442 1437.85,63.5442 1437.86,63.5442 1437.87,63.5442 1437.88,63.5442 1437.89,63.5442 1437.9,63.5442 1437.91,63.5442 1437.92,63.5442 1437.93,63.5442 1437.93,63.5442 1437.94,63.5442 1437.95,63.5442 1437.96,63.5442 1437.97,63.5442 1437.98,63.5442 1437.99,63.5442 1438,63.5442 1438.01,63.5442 1438.02,63.5442 1438.03,63.5442 1438.04,63.5442 1438.04,63.5442 1438.05,63.5442 1438.06,63.5442 1438.07,63.5442 1438.08,63.5442 1438.09,63.5442 1438.1,63.5442 1438.11,63.5442 1438.12,63.5442 1438.13,63.5442 1438.14,63.5442 1438.15,63.5442 1438.16,63.5442 1438.16,63.5442 1438.17,63.5442 1438.18,63.5442 1438.19,63.5442 1438.2,63.5442 1438.21,63.5442 1438.22,63.5442 1438.23,63.5442 1438.24,63.5442 1438.25,63.5442 1438.26,63.5442 1438.27,63.5442 1438.27,63.5442 1438.28,63.5442 1438.29,63.5442 1438.3,63.5442 1438.31,63.5442 1438.32,63.5442 1438.33,63.5442 1438.34,63.5442 1438.35,63.5442 1438.36,63.5442 1438.37,63.5442 1438.38,63.5442 1438.38,63.5442 1438.39,63.5442 1438.4,63.5442 1438.41,63.5442 1438.42,63.5442 1438.43,63.5442 1438.44,63.5442 1438.45,63.5442 1438.46,63.5442 1438.47,63.5442 1438.48,63.5442 1438.49,63.5442 1438.5,63.5442 1438.5,63.5442 1438.51,63.5442 1438.52,63.5442 1438.53,63.5442 1438.54,63.5442 1438.55,63.5442 1438.56,63.5442 1438.57,63.5442 1438.58,63.5442 1438.59,63.5442 1438.6,63.5442 1438.61,63.5442 1438.61,63.5442 1438.62,63.5442 1438.63,63.5442 1438.64,63.5442 1438.65,63.5442 1438.66,63.5442 1438.67,63.5442 1438.68,63.5442 1438.69,63.5442 1438.7,63.5442 1438.71,63.5442 1438.72,63.5442 1438.72,63.5442 1438.73,63.5442 1438.74,63.5442 1438.75,63.5442 1438.76,63.5442 1438.77,63.5442 1438.78,63.5442 1438.79,63.5442 1438.8,63.5442 1438.81,63.5442 1438.82,63.5442 1438.83,63.5442 1438.84,63.5442 1438.84,63.5442 1438.85,63.5442 1438.86,63.5442 1438.87,63.5442 1438.88,63.5442 1438.89,63.5442 1438.9,63.5442 1438.91,63.5442 1438.92,63.5442 1438.93,63.5442 1438.94,63.5442 1438.95,63.5442 1438.95,63.5442 1438.96,63.5442 1438.97,63.5442 1438.98,63.5442 1438.99,63.5442 1439,63.5442 1439.01,63.5442 1439.02,63.5442 1439.03,63.5442 1439.04,63.5442 1439.05,63.5442 1439.06,63.5442 1439.06,63.5442 1439.07,63.5442 1439.08,63.5442 1439.09,63.5442 1439.1,63.5442 1439.11,63.5442 1439.12,63.5442 1439.13,63.5442 1439.14,63.5442 1439.15,63.5442 1439.16,63.5442 1439.17,63.5442 1439.18,63.5442 1439.18,63.5442 1439.19,63.5442 1439.2,63.5442 1439.21,63.5442 1439.22,63.5442 1439.23,63.5442 1439.24,63.5442 1439.25,63.5442 1439.26,63.5442 1439.27,63.5442 1439.28,63.5442 1439.29,63.5442 1439.29,63.5442 1439.3,63.5442 1439.31,63.5442 1439.32,63.5442 1439.33,63.5442 1439.34,63.5442 1439.35,63.5442 1439.36,63.5442 1439.37,63.5442 1439.38,63.5442 1439.39,63.5442 1439.4,63.5442 1439.4,63.5442 1439.41,63.5442 1439.42,63.5442 1439.43,63.5442 1439.44,63.5442 1439.45,63.5442 1439.46,63.5442 1439.47,63.5442 1439.48,63.5442 1439.49,63.5442 1439.5,63.5442 1439.51,63.5442 1439.52,63.5442 1439.52,63.5442 1439.53,63.5442 1439.54,63.5442 1439.55,63.5442 1439.56,63.5442 1439.57,63.5442 1439.58,63.5442 1439.59,63.5442 1439.6,63.5442 1439.61,63.5442 1439.62,63.5442 1439.63,63.5442 1439.63,63.5442 1439.64,63.5442 1439.65,63.5442 1439.66,63.5442 1439.67,63.5442 1439.68,63.5442 1439.69,63.5442 1439.7,63.5442 1439.71,63.5442 1439.72,63.5442 1439.73,63.5442 1439.74,63.5442 1439.74,63.5442 1439.75,63.5442 1439.76,63.5442 1439.77,63.5442 1439.78,63.5442 1439.79,63.5442 1439.8,63.5442 1439.81,63.5442 1439.82,63.5442 1439.83,63.5442 1439.84,63.5442 1439.85,63.5442 1439.86,63.5442 1439.86,63.5442 1439.87,63.5442 1439.88,63.5442 1439.89,63.5442 1439.9,63.5442 1439.91,63.5442 1439.92,63.5442 1439.93,63.5442 1439.94,63.5442 1439.95,63.5442 1439.96,63.5442 1439.97,63.5442 1439.97,63.5442 1439.98,63.5442 1439.99,63.5442 1440,63.5442 1440.01,63.5442 1440.02,63.5442 1440.03,63.5442 1440.04,63.5442 1440.05,63.5442 1440.06,63.5442 1440.07,63.5442 1440.08,63.5442 1440.08,63.5442 1440.09,63.5442 1440.1,63.5442 1440.11,63.5442 1440.12,63.5442 1440.13,63.5442 1440.14,63.5442 1440.15,63.5442 1440.16,63.5442 1440.17,63.5442 1440.18,63.5442 1440.19,63.5442 1440.2,63.5442 1440.2,63.5442 1440.21,63.5442 1440.22,63.5442 1440.23,63.5442 1440.24,63.5442 1440.25,63.5442 1440.26,63.5442 1440.27,63.5442 1440.28,63.5442 1440.29,63.5442 1440.3,63.5442 1440.31,63.5442 1440.31,63.5442 1440.32,63.5442 1440.33,63.5442 1440.34,63.5442 1440.35,63.5442 1440.36,63.5442 1440.37,63.5442 1440.38,63.5442 1440.39,63.5442 1440.4,63.5442 1440.41,63.5442 1440.42,63.5442 1440.42,63.5442 1440.43,63.5442 1440.44,63.5442 1440.45,63.5442 1440.46,63.5442 1440.47,63.5442 1440.48,63.5442 1440.49,63.5442 1440.5,63.5442 1440.51,63.5442 1440.52,63.5442 1440.53,63.5442 1440.54,63.5442 1440.54,63.5442 1440.55,63.5442 1440.56,63.5442 1440.57,63.5442 1440.58,63.5442 1440.59,63.5442 1440.6,63.5442 1440.61,63.5442 1440.62,63.5442 1440.63,63.5442 1440.64,63.5442 1440.65,63.5442 1440.65,63.5442 1440.66,63.5442 1440.67,63.5442 1440.68,63.5442 1440.69,63.5442 1440.7,63.5442 1440.71,63.5442 1440.72,63.5442 1440.73,63.5442 1440.74,63.5442 1440.75,63.5442 1440.76,63.5442 1440.76,63.5442 1440.77,63.5442 1440.78,63.5442 1440.79,63.5442 1440.8,63.5442 1440.81,63.5442 1440.82,63.5442 1440.83,63.5442 1440.84,63.5442 1440.85,63.5442 1440.86,63.5442 1440.87,63.5442 1440.88,63.5442 1440.88,63.5442 1440.89,63.5442 1440.9,63.5442 1440.91,63.5442 1440.92,63.5442 1440.93,63.5442 1440.94,63.5442 1440.95,63.5442 1440.96,63.5442 1440.97,63.5442 1440.98,63.5442 1440.99,63.5442 1440.99,63.5442 1441,63.5442 1441.01,63.5442 1441.02,63.5442 1441.03,63.5442 1441.04,63.5442 1441.05,63.5442 1441.06,63.5442 1441.07,63.5442 1441.08,63.5442 1441.09,63.5442 1441.1,63.5442 1441.1,63.5442 1441.11,63.5442 1441.12,63.5442 1441.13,63.5442 1441.14,63.5442 1441.15,63.5442 1441.16,63.5442 1441.17,63.5442 1441.18,63.5442 1441.19,63.5442 1441.2,63.5442 1441.21,63.5442 1441.22,63.5442 1441.22,63.5442 1441.23,63.5442 1441.24,63.5442 1441.25,63.5442 1441.26,63.5442 1441.27,63.5442 1441.28,63.5442 1441.29,63.5442 1441.3,63.5442 1441.31,63.5442 1441.32,63.5442 1441.33,63.5442 1441.33,63.5442 1441.34,63.5442 1441.35,63.5442 1441.36,63.5442 1441.37,63.5442 1441.38,63.5442 1441.39,63.5442 1441.4,63.5442 1441.41,63.5442 1441.42,63.5442 1441.43,63.5442 1441.44,63.5442 1441.44,63.5442 1441.45,63.5442 1441.46,63.5442 1441.47,63.5442 1441.48,63.5442 1441.49,63.5442 1441.5,63.5442 1441.51,63.5442 1441.52,63.5442 1441.53,63.5442 1441.54,63.5442 1441.55,63.5442 1441.56,63.5442 1441.56,63.5442 1441.57,63.5442 1441.58,63.5442 1441.59,63.5442 1441.6,63.5442 1441.61,63.5442 1441.62,63.5442 1441.63,63.5442 1441.64,63.5442 1441.65,63.5442 1441.66,63.5442 1441.67,63.5442 1441.67,63.5442 1441.68,63.5442 1441.69,63.5442 1441.7,63.5442 1441.71,63.5442 1441.72,63.5442 1441.73,63.5442 1441.74,63.5442 1441.75,63.5442 1441.76,63.5442 1441.77,63.5442 1441.78,63.5442 1441.78,63.5442 1441.79,63.5442 1441.8,63.5442 1441.81,63.5442 1441.82,63.5442 1441.83,63.5442 1441.84,63.5442 1441.85,63.5442 1441.86,63.5442 1441.87,63.5442 1441.88,63.5442 1441.89,63.5442 1441.9,63.5442 1441.9,63.5442 1441.91,63.5442 1441.92,63.5442 1441.93,63.5442 1441.94,63.5442 1441.95,63.5442 1441.96,63.5442 1441.97,63.5442 1441.98,63.5442 1441.99,63.5442 1442,63.5442 1442.01,63.5442 1442.01,63.5442 1442.02,63.5442 1442.03,63.5442 1442.04,63.5442 1442.05,63.5442 1442.06,63.5442 1442.07,63.5442 1442.08,63.5442 1442.09,63.5442 1442.1,63.5442 1442.11,63.5442 1442.12,63.5442 1442.12,63.5442 1442.13,63.5442 1442.14,63.5442 1442.15,63.5442 1442.16,63.5442 1442.17,63.5442 1442.18,63.5442 1442.19,63.5442 1442.2,63.5442 1442.21,63.5442 1442.22,63.5442 1442.23,63.5442 1442.24,63.5442 1442.24,63.5442 1442.25,63.5442 1442.26,63.5442 1442.27,63.5442 1442.28,63.5442 1442.29,63.5442 1442.3,63.5442 1442.31,63.5442 1442.32,63.5442 1442.33,63.5442 1442.34,63.5442 1442.35,63.5442 1442.35,63.5442 1442.36,63.5442 1442.37,63.5442 1442.38,63.5442 1442.39,63.5442 1442.4,63.5442 1442.41,63.5442 1442.42,63.5442 1442.43,63.5442 1442.44,63.5442 1442.45,63.5442 1442.46,63.5442 1442.46,63.5442 1442.47,63.5442 1442.48,63.5442 1442.49,63.5442 1442.5,63.5442 1442.51,63.5442 1442.52,63.5442 1442.53,63.5442 1442.54,63.5442 1442.55,63.5442 1442.56,63.5442 1442.57,63.5442 1442.58,63.5442 1442.58,63.5442 1442.59,63.5442 1442.6,63.5442 1442.61,63.5442 1442.62,63.5442 1442.63,63.5442 1442.64,63.5442 1442.65,63.5442 1442.66,63.5442 1442.67,63.5442 1442.68,63.5442 1442.69,63.5442 1442.69,63.5442 1442.7,63.5442 1442.71,63.5442 1442.72,63.5442 1442.73,63.5442 1442.74,63.5442 1442.75,63.5442 1442.76,63.5442 1442.77,63.5442 1442.78,63.5442 1442.79,63.5442 1442.8,63.5442 1442.8,63.5442 1442.81,63.5442 1442.82,63.5442 1442.83,63.5442 1442.84,63.5442 1442.85,63.5442 1442.86,63.5442 1442.87,63.5442 1442.88,63.5442 1442.89,63.5442 1442.9,63.5442 1442.91,63.5442 1442.92,63.5442 1442.92,63.5442 1442.93,63.5442 1442.94,63.5442 1442.95,63.5442 1442.96,63.5442 1442.97,63.5442 1442.98,63.5442 1442.99,63.5442 1443,63.5442 1443.01,63.5442 1443.02,63.5442 1443.03,63.5442 1443.03,63.5442 1443.04,63.5442 1443.05,63.5442 1443.06,63.5442 1443.07,63.5442 1443.08,63.5442 1443.09,63.5442 1443.1,63.5442 1443.11,63.5442 1443.12,63.5442 1443.13,63.5442 1443.14,63.5442 1443.14,63.5442 1443.15,63.5442 1443.16,63.5442 1443.17,63.5442 1443.18,63.5442 1443.19,63.5442 1443.2,63.5442 1443.21,63.5442 1443.22,63.5442 1443.23,63.5442 1443.24,63.5442 1443.25,63.5442 1443.26,63.5442 1443.26,63.5442 1443.27,63.5442 1443.28,63.5442 1443.29,63.5442 1443.3,63.5442 1443.31,63.5442 1443.32,63.5442 1443.33,63.5442 1443.34,63.5442 1443.35,63.5442 1443.36,63.5442 1443.37,63.5442 1443.37,63.5442 1443.38,63.5442 1443.39,63.5442 1443.4,63.5442 1443.41,63.5442 1443.42,63.5442 1443.43,63.5442 1443.44,63.5442 1443.45,63.5442 1443.46,63.5442 1443.47,63.5442 1443.48,63.5442 1443.48,63.5442 1443.49,63.5442 1443.5,63.5442 1443.51,63.5442 1443.52,63.5442 1443.53,63.5442 1443.54,63.5442 1443.55,63.5442 1443.56,63.5442 1443.57,63.5442 1443.58,63.5442 1443.59,63.5442 1443.6,63.5442 1443.6,63.5442 1443.61,63.5442 1443.62,63.5442 1443.63,63.5442 1443.64,63.5442 1443.65,63.5442 1443.66,63.5442 1443.67,63.5442 1443.68,63.5442 1443.69,63.5442 1443.7,63.5442 1443.71,63.5442 1443.71,63.5442 1443.72,63.5442 1443.73,63.5442 1443.74,63.5442 1443.75,63.5442 1443.76,63.5442 1443.77,63.5442 1443.78,63.5442 1443.79,63.5442 1443.8,63.5442 1443.81,63.5442 1443.82,63.5442 1443.82,63.5442 1443.83,63.5442 1443.84,63.5442 1443.85,63.5442 1443.86,63.5442 1443.87,63.5442 1443.88,63.5442 1443.89,63.5442 1443.9,63.5442 1443.91,63.5442 1443.92,63.5442 1443.93,63.5442 1443.94,63.5442 1443.94,63.5442 1443.95,63.5442 1443.96,63.5442 1443.97,63.5442 1443.98,63.5442 1443.99,63.5442 1444,63.5442 1444.01,63.5442 1444.02,63.5442 1444.03,63.5442 1444.04,63.5442 1444.05,63.5442 1444.05,63.5442 1444.06,63.5442 1444.07,63.5442 1444.08,63.5442 1444.09,63.5442 1444.1,63.5442 1444.11,63.5442 1444.12,63.5442 1444.13,63.5442 1444.14,63.5442 1444.15,63.5442 1444.16,63.5442 1444.16,63.5442 1444.17,63.5442 1444.18,63.5442 1444.19,63.5442 1444.2,63.5442 1444.21,63.5442 1444.22,63.5442 1444.23,63.5442 1444.24,63.5442 1444.25,63.5442 1444.26,63.5442 1444.27,63.5442 1444.28,63.5442 1444.28,63.5442 1444.29,63.5442 1444.3,63.5442 1444.31,63.5442 1444.32,63.5442 1444.33,63.5442 1444.34,63.5442 1444.35,63.5442 1444.36,63.5442 1444.37,63.5442 1444.38,63.5442 1444.39,63.5442 1444.39,63.5442 1444.4,63.5442 1444.41,63.5442 1444.42,63.5442 1444.43,63.5442 1444.44,63.5442 1444.45,63.5442 1444.46,63.5442 1444.47,63.5442 1444.48,63.5442 1444.49,63.5442 1444.5,63.5442 1444.5,63.5442 1444.51,63.5442 1444.52,63.5442 1444.53,63.5442 1444.54,63.5442 1444.55,63.5442 1444.56,63.5442 1444.57,63.5442 1444.58,63.5442 1444.59,63.5442 1444.6,63.5442 1444.61,63.5442 1444.62,63.5442 1444.62,63.5442 1444.63,63.5442 1444.64,63.5442 1444.65,63.5442 1444.66,63.5442 1444.67,63.5442 1444.68,63.5442 1444.69,63.5442 1444.7,63.5442 1444.71,63.5442 1444.72,63.5442 1444.73,63.5442 1444.73,63.5442 1444.74,63.5442 1444.75,63.5442 1444.76,63.5442 1444.77,63.5442 1444.78,63.5442 1444.79,63.5442 1444.8,63.5442 1444.81,63.5442 1444.82,63.5442 1444.83,63.5442 1444.84,63.5442 1444.84,63.5442 1444.85,63.5442 1444.86,63.5442 1444.87,63.5442 1444.88,63.5442 1444.89,63.5442 1444.9,63.5442 1444.91,63.5442 1444.92,63.5442 1444.93,63.5442 1444.94,63.5442 1444.95,63.5442 1444.96,63.5442 1444.96,63.5442 1444.97,63.5442 1444.98,63.5442 1444.99,63.5442 1445,63.5442 1445.01,63.5442 1445.02,63.5442 1445.03,63.5442 1445.04,63.5442 1445.05,63.5442 1445.06,63.5442 1445.07,63.5442 1445.07,63.5442 1445.08,63.5442 1445.09,63.5442 1445.1,63.5442 1445.11,63.5442 1445.12,63.5442 1445.13,63.5442 1445.14,63.5442 1445.15,63.5442 1445.16,63.5442 1445.17,63.5442 1445.18,63.5442 1445.18,63.5442 1445.19,63.5442 1445.2,63.5442 1445.21,63.5442 1445.22,63.5442 1445.23,63.5442 1445.24,63.5442 1445.25,63.5442 1445.26,63.5442 1445.27,63.5442 1445.28,63.5442 1445.29,63.5442 1445.3,63.5442 1445.3,63.5442 1445.31,63.5442 1445.32,63.5442 1445.33,63.5442 1445.34,63.5442 1445.35,63.5442 1445.36,63.5442 1445.37,63.5442 1445.38,63.5442 1445.39,63.5442 1445.4,63.5442 1445.41,63.5442 1445.41,63.5442 1445.42,63.5442 1445.43,63.5442 1445.44,63.5442 1445.45,63.5442 1445.46,63.5442 1445.47,63.5442 1445.48,63.5442 1445.49,63.5442 1445.5,63.5442 1445.51,63.5442 1445.52,63.5442 1445.52,63.5442 1445.53,63.5442 1445.54,63.5442 1445.55,63.5442 1445.56,63.5442 1445.57,63.5442 1445.58,63.5442 1445.59,63.5442 1445.6,63.5442 1445.61,63.5442 1445.62,63.5442 1445.63,63.5442 1445.64,63.5442 1445.64,63.5442 1445.65,63.5442 1445.66,63.5442 1445.67,63.5442 1445.68,63.5442 1445.69,63.5442 1445.7,63.5442 1445.71,63.5442 1445.72,63.5442 1445.73,63.5442 1445.74,63.5442 1445.75,63.5442 1445.75,63.5442 1445.76,63.5442 1445.77,63.5442 1445.78,63.5442 1445.79,63.5442 1445.8,63.5442 1445.81,63.5442 1445.82,63.5442 1445.83,63.5442 1445.84,63.5442 1445.85,63.5442 1445.86,63.5442 1445.86,63.5442 1445.87,63.5442 1445.88,63.5442 1445.89,63.5442 1445.9,63.5442 1445.91,63.5442 1445.92,63.5442 1445.93,63.5442 1445.94,63.5442 1445.95,63.5442 1445.96,63.5442 1445.97,63.5442 1445.98,63.5442 1445.98,63.5442 1445.99,63.5442 1446,63.5442 1446.01,63.5442 1446.02,63.5442 1446.03,63.5442 1446.04,63.5442 1446.05,63.5442 1446.06,63.5442 1446.07,63.5442 1446.08,63.5442 1446.09,63.5442 1446.09,63.5442 1446.1,63.5442 1446.11,63.5442 1446.12,63.5442 1446.13,63.5442 1446.14,63.5442 1446.15,63.5442 1446.16,63.5442 1446.17,63.5442 1446.18,63.5442 1446.19,63.5442 1446.2,63.5442 1446.2,63.5442 1446.21,63.5442 1446.22,63.5442 1446.23,63.5442 1446.24,63.5442 1446.25,63.5442 1446.26,63.5442 1446.27,63.5442 1446.28,63.5442 1446.29,63.5442 1446.3,63.5442 1446.31,63.5442 1446.32,63.5442 1446.32,63.5442 1446.33,63.5442 1446.34,63.5442 1446.35,63.5442 1446.36,63.5442 1446.37,63.5442 1446.38,63.5442 1446.39,63.5442 1446.4,63.5442 1446.41,63.5442 1446.42,63.5442 1446.43,63.5442 1446.43,63.5442 1446.44,63.5442 1446.45,63.5442 1446.46,63.5442 1446.47,63.5442 1446.48,63.5442 1446.49,63.5442 1446.5,63.5442 1446.51,63.5442 1446.52,63.5442 1446.53,63.5442 1446.54,63.5442 1446.54,63.5442 1446.55,63.5442 1446.56,63.5442 1446.57,63.5442 1446.58,63.5442 1446.59,63.5442 1446.6,63.5442 1446.61,63.5442 1446.62,63.5442 1446.63,63.5442 1446.64,63.5442 1446.65,63.5442 1446.66,63.5442 1446.66,63.5442 1446.67,63.5442 1446.68,63.5442 1446.69,63.5442 1446.7,63.5442 1446.71,63.5442 1446.72,63.5442 1446.73,63.5442 1446.74,63.5442 1446.75,63.5442 1446.76,63.5442 1446.77,63.5442 1446.77,63.5442 1446.78,63.5442 1446.79,63.5442 1446.8,63.5442 1446.81,63.5442 1446.82,63.5442 1446.83,63.5442 1446.84,63.5442 1446.85,63.5442 1446.86,63.5442 1446.87,63.5442 1446.88,63.5442 1446.88,63.5442 1446.89,63.5442 1446.9,63.5442 1446.91,63.5442 1446.92,63.5442 1446.93,63.5442 1446.94,63.5442 1446.95,63.5442 1446.96,63.5442 1446.97,63.5442 1446.98,63.5442 1446.99,63.5442 1447,63.5442 1447,63.5442 1447.01,63.5442 1447.02,63.5442 1447.03,63.5442 1447.04,63.5442 1447.05,63.5442 1447.06,63.5442 1447.07,63.5442 1447.08,63.5442 1447.09,63.5442 1447.1,63.5442 1447.11,63.5442 1447.11,63.5442 1447.12,63.5442 1447.13,63.5442 1447.14,63.5442 1447.15,63.5442 1447.16,63.5442 1447.17,63.5442 1447.18,63.5442 1447.19,63.5442 1447.2,63.5442 1447.21,63.5442 1447.22,63.5442 1447.22,63.5442 1447.23,63.5442 1447.24,63.5442 1447.25,63.5442 1447.26,63.5442 1447.27,63.5442 1447.28,63.5442 1447.29,63.5442 1447.3,63.5442 1447.31,63.5442 1447.32,63.5442 1447.33,63.5442 1447.34,63.5442 1447.34,63.5442 1447.35,63.5442 1447.36,63.5442 1447.37,63.5442 1447.38,63.5442 1447.39,63.5442 1447.4,63.5442 1447.41,63.5442 1447.42,63.5442 1447.43,63.5442 1447.44,63.5442 1447.45,63.5442 1447.45,63.5442 1447.46,63.5442 1447.47,63.5442 1447.48,63.5442 1447.49,63.5442 1447.5,63.5442 1447.51,63.5442 1447.52,63.5442 1447.53,63.5442 1447.54,63.5442 1447.55,63.5442 1447.56,63.5442 1447.56,63.5442 1447.57,63.5442 1447.58,63.5442 1447.59,63.5442 1447.6,63.5442 1447.61,63.5442 1447.62,63.5442 1447.63,63.5442 1447.64,63.5442 1447.65,63.5442 1447.66,63.5442 1447.67,63.5442 1447.68,63.5442 1447.68,63.5442 1447.69,63.5442 1447.7,63.5442 1447.71,63.5442 1447.72,63.5442 1447.73,63.5442 1447.74,63.5442 1447.75,63.5442 1447.76,63.5442 1447.77,63.5442 1447.78,63.5442 1447.79,63.5442 1447.79,63.5442 1447.8,63.5442 1447.81,63.5442 1447.82,63.5442 1447.83,63.5442 1447.84,63.5442 1447.85,63.5442 1447.86,63.5442 1447.87,63.5442 1447.88,63.5442 1447.89,63.5442 1447.9,63.5442 1447.9,63.5442 1447.91,63.5442 1447.92,63.5442 1447.93,63.5442 1447.94,63.5442 1447.95,63.5442 1447.96,63.5442 1447.97,63.5442 1447.98,63.5442 1447.99,63.5442 1448,63.5442 1448.01,63.5442 1448.02,63.5442 1448.02,63.5442 1448.03,63.5442 1448.04,63.5442 1448.05,63.5442 1448.06,63.5442 1448.07,63.5442 1448.08,63.5442 1448.09,63.5442 1448.1,63.5442 1448.11,63.5442 1448.12,63.5442 1448.13,63.5442 1448.13,63.5442 1448.14,63.5442 1448.15,63.5442 1448.16,63.5442 1448.17,63.5442 1448.18,63.5442 1448.19,63.5442 1448.2,63.5442 1448.21,63.5442 1448.22,63.5442 1448.23,63.5442 1448.24,63.5442 1448.24,63.5442 1448.25,63.5442 1448.26,63.5442 1448.27,63.5442 1448.28,63.5442 1448.29,63.5442 1448.3,63.5442 1448.31,63.5442 1448.32,63.5442 1448.33,63.5442 1448.34,63.5442 1448.35,63.5442 1448.36,63.5442 1448.36,63.5442 1448.37,63.5442 1448.38,63.5442 1448.39,63.5442 1448.4,63.5442 1448.41,63.5442 1448.42,63.5442 1448.43,63.5442 1448.44,63.5442 1448.45,63.5442 1448.46,63.5442 1448.47,63.5442 1448.47,63.5442 1448.48,63.5442 1448.49,63.5442 1448.5,63.5442 1448.51,63.5442 1448.52,63.5442 1448.53,63.5442 1448.54,63.5442 1448.55,63.5442 1448.56,63.5442 1448.57,63.5442 1448.58,63.5442 1448.58,63.5442 1448.59,63.5442 1448.6,63.5442 1448.61,63.5442 1448.62,63.5442 1448.63,63.5442 1448.64,63.5442 1448.65,63.5442 1448.66,63.5442 1448.67,63.5442 1448.68,63.5442 1448.69,63.5442 1448.7,63.5442 1448.7,63.5442 1448.71,63.5442 1448.72,63.5442 1448.73,63.5442 1448.74,63.5442 1448.75,63.5442 1448.76,63.5442 1448.77,63.5442 1448.78,63.5442 1448.79,63.5442 1448.8,63.5442 1448.81,63.5442 1448.81,63.5442 1448.82,63.5442 1448.83,63.5442 1448.84,63.5442 1448.85,63.5442 1448.86,63.5442 1448.87,63.5442 1448.88,63.5442 1448.89,63.5442 1448.9,63.5442 1448.91,63.5442 1448.92,63.5442 1448.92,63.5442 1448.93,63.5442 1448.94,63.5442 1448.95,63.5442 1448.96,63.5442 1448.97,63.5442 1448.98,63.5442 1448.99,63.5442 1449,63.5442 1449.01,63.5442 1449.02,63.5442 1449.03,63.5442 1449.04,63.5442 1449.04,63.5442 1449.05,63.5442 1449.06,63.5442 1449.07,63.5442 1449.08,63.5442 1449.09,63.5442 1449.1,63.5442 1449.11,63.5442 1449.12,63.5442 1449.13,63.5442 1449.14,63.5442 1449.15,63.5442 1449.15,63.5442 1449.16,63.5442 1449.17,63.5442 1449.18,63.5442 1449.19,63.5442 1449.2,63.5442 1449.21,63.5442 1449.22,63.5442 1449.23,63.5442 1449.24,63.5442 1449.25,63.5442 1449.26,63.5442 1449.26,63.5442 1449.27,63.5442 1449.28,63.5442 1449.29,63.5442 1449.3,63.5442 1449.31,63.5442 1449.32,63.5442 1449.33,63.5442 1449.34,63.5442 1449.35,63.5442 1449.36,63.5442 1449.37,63.5442 1449.38,63.5442 1449.38,63.5442 1449.39,63.5442 1449.4,63.5442 1449.41,63.5442 1449.42,63.5442 1449.43,63.5442 1449.44,63.5442 1449.45,63.5442 1449.46,63.5442 1449.47,63.5442 1449.48,63.5442 1449.49,63.5442 1449.49,63.5442 1449.5,63.5442 1449.51,63.5442 1449.52,63.5442 1449.53,63.5442 1449.54,63.5442 1449.55,63.5442 1449.56,63.5442 1449.57,63.5442 1449.58,63.5442 1449.59,63.5442 1449.6,63.5442 1449.6,63.5442 1449.61,63.5442 1449.62,63.5442 1449.63,63.5442 1449.64,63.5442 1449.65,63.5442 1449.66,63.5442 1449.67,63.5442 1449.68,63.5442 1449.69,63.5442 1449.7,63.5442 1449.71,63.5442 1449.72,63.5442 1449.72,63.5442 1449.73,63.5442 1449.74,63.5442 1449.75,63.5442 1449.76,63.5442 1449.77,63.5442 1449.78,63.5442 1449.79,63.5442 1449.8,63.5442 1449.81,63.5442 1449.82,63.5442 1449.83,63.5442 1449.83,63.5442 1449.84,63.5442 1449.85,63.5442 1449.86,63.5442 1449.87,63.5442 1449.88,63.5442 1449.89,63.5442 1449.9,63.5442 1449.91,63.5442 1449.92,63.5442 1449.93,63.5442 1449.94,63.5442 1449.94,63.5442 1449.95,63.5442 1449.96,63.5442 1449.97,63.5442 1449.98,63.5442 1449.99,63.5442 1450,63.5442 1450.01,63.5442 1450.02,63.5442 1450.03,63.5442 1450.04,63.5442 1450.05,63.5442 1450.06,63.5442 1450.06,63.5442 1450.07,63.5442 1450.08,63.5442 1450.09,63.5442 1450.1,63.5442 1450.11,63.5442 1450.12,63.5442 1450.13,63.5442 1450.14,63.5442 1450.15,63.5442 1450.16,63.5442 1450.17,63.5442 1450.17,63.5442 1450.18,63.5442 1450.19,63.5442 1450.2,63.5442 1450.21,63.5442 1450.22,63.5442 1450.23,63.5442 1450.24,63.5442 1450.25,63.5442 1450.26,63.5442 1450.27,63.5442 1450.28,63.5442 1450.28,63.5442 1450.29,63.5442 1450.3,63.5442 1450.31,63.5442 1450.32,63.5442 1450.33,63.5442 1450.34,63.5442 1450.35,63.5442 1450.36,63.5442 1450.37,63.5442 1450.38,63.5442 1450.39,63.5442 1450.4,63.5442 1450.4,63.5442 1450.41,63.5442 1450.42,63.5442 1450.43,63.5442 1450.44,63.5442 1450.45,63.5442 1450.46,63.5442 1450.47,63.5442 1450.48,63.5442 1450.49,63.5442 1450.5,63.5442 1450.51,63.5442 1450.51,63.5442 1450.52,63.5442 1450.53,63.5442 1450.54,63.5442 1450.55,63.5442 1450.56,63.5442 1450.57,63.5442 1450.58,63.5442 1450.59,63.5442 1450.6,63.5442 1450.61,63.5442 1450.62,63.5442 1450.62,63.5442 1450.63,63.5442 1450.64,63.5442 1450.65,63.5442 1450.66,63.5442 1450.67,63.5442 1450.68,63.5442 1450.69,63.5442 1450.7,63.5442 1450.71,63.5442 1450.72,63.5442 1450.73,63.5442 1450.74,63.5442 1450.74,63.5442 1450.75,63.5442 1450.76,63.5442 1450.77,63.5442 1450.78,63.5442 1450.79,63.5442 1450.8,63.5442 1450.81,63.5442 1450.82,63.5442 1450.83,63.5442 1450.84,63.5442 1450.85,63.5442 1450.85,63.5442 1450.86,63.5442 1450.87,63.5442 1450.88,63.5442 1450.89,63.5442 1450.9,63.5442 1450.91,63.5442 1450.92,63.5442 1450.93,63.5442 1450.94,63.5442 1450.95,63.5442 1450.96,63.5442 1450.96,63.5442 1450.97,63.5442 1450.98,63.5442 1450.99,63.5442 1451,63.5442 1451.01,63.5442 1451.02,63.5442 1451.03,63.5442 1451.04,63.5442 1451.05,63.5442 1451.06,63.5442 1451.07,63.5442 1451.08,63.5442 1451.08,63.5442 1451.09,63.5442 1451.1,63.5442 1451.11,63.5442 1451.12,63.5442 1451.13,63.5442 1451.14,63.5442 1451.15,63.5442 1451.16,63.5442 1451.17,63.5442 1451.18,63.5442 1451.19,63.5442 1451.19,63.5442 1451.2,63.5442 1451.21,63.5442 1451.22,63.5442 1451.23,63.5442 1451.24,63.5442 1451.25,63.5442 1451.26,63.5442 1451.27,63.5442 1451.28,63.5442 1451.29,63.5442 1451.3,63.5442 1451.3,63.5442 1451.31,63.5442 1451.32,63.5442 1451.33,63.5442 1451.34,63.5442 1451.35,63.5442 1451.36,63.5442 1451.37,63.5442 1451.38,63.5442 1451.39,63.5442 1451.4,63.5442 1451.41,63.5442 1451.42,63.5442 1451.42,63.5442 1451.43,63.5442 1451.44,63.5442 1451.45,63.5442 1451.46,63.5442 1451.47,63.5442 1451.48,63.5442 1451.49,63.5442 1451.5,63.5442 1451.51,63.5442 1451.52,63.5442 1451.53,63.5442 1451.53,63.5442 1451.54,63.5442 1451.55,63.5442 1451.56,63.5442 1451.57,63.5442 1451.58,63.5442 1451.59,63.5442 1451.6,63.5442 1451.61,63.5442 1451.62,63.5442 1451.63,63.5442 1451.64,63.5442 1451.64,63.5442 1451.65,63.5442 1451.66,63.5442 1451.67,63.5442 1451.68,63.5442 1451.69,63.5442 1451.7,63.5442 1451.71,63.5442 1451.72,63.5442 1451.73,63.5442 1451.74,63.5442 1451.75,63.5442 1451.76,63.5442 1451.76,63.5442 1451.77,63.5442 1451.78,63.5442 1451.79,63.5442 1451.8,63.5442 1451.81,63.5442 1451.82,63.5442 1451.83,63.5442 1451.84,63.5442 1451.85,63.5442 1451.86,63.5442 1451.87,63.5442 1451.87,63.5442 1451.88,63.5442 1451.89,63.5442 1451.9,63.5442 1451.91,63.5442 1451.92,63.5442 1451.93,63.5442 1451.94,63.5442 1451.95,63.5442 1451.96,63.5442 1451.97,63.5442 1451.98,63.5442 1451.98,63.5442 1451.99,63.5442 1452,63.5442 1452.01,63.5442 1452.02,63.5442 1452.03,63.5442 1452.04,63.5442 1452.05,63.5442 1452.06,63.5442 1452.07,63.5442 1452.08,63.5442 1452.09,63.5442 1452.1,63.5442 1452.1,63.5442 1452.11,63.5442 1452.12,63.5442 1452.13,63.5442 1452.14,63.5442 1452.15,63.5442 1452.16,63.5442 1452.17,63.5442 1452.18,63.5442 1452.19,63.5442 1452.2,63.5442 1452.21,63.5442 1452.21,63.5442 1452.22,63.5442 1452.23,63.5442 1452.24,63.5442 1452.25,63.5442 1452.26,63.5442 1452.27,63.5442 1452.28,63.5442 1452.29,63.5442 1452.3,63.5442 1452.31,63.5442 1452.32,63.5442 1452.32,63.5442 1452.33,63.5442 1452.34,63.5442 1452.35,63.5442 1452.36,63.5442 1452.37,63.5442 1452.38,63.5442 1452.39,63.5442 1452.4,63.5442 1452.41,63.5442 1452.42,63.5442 1452.43,63.5442 1452.44,63.5442 1452.44,63.5442 1452.45,63.5442 1452.46,63.5442 1452.47,63.5442 1452.48,63.5442 1452.49,63.5442 1452.5,63.5442 1452.51,63.5442 1452.52,63.5442 1452.53,63.5442 1452.54,63.5442 1452.55,63.5442 1452.55,63.5442 1452.56,63.5442 1452.57,63.5442 1452.58,63.5442 1452.59,63.5442 1452.6,63.5442 1452.61,63.5442 1452.62,63.5442 1452.63,63.5442 1452.64,63.5442 1452.65,63.5442 1452.66,63.5442 1452.66,63.5442 1452.67,63.5442 1452.68,63.5442 1452.69,63.5442 1452.7,63.5442 1452.71,63.5442 1452.72,63.5442 1452.73,63.5442 1452.74,63.5442 1452.75,63.5442 1452.76,63.5442 1452.77,63.5442 1452.78,63.5442 1452.78,63.5442 1452.79,63.5442 1452.8,63.5442 1452.81,63.5442 1452.82,63.5442 1452.83,63.5442 1452.84,63.5442 1452.85,63.5442 1452.86,63.5442 1452.87,63.5442 1452.88,63.5442 1452.89,63.5442 1452.89,63.5442 1452.9,63.5442 1452.91,63.5442 1452.92,63.5442 1452.93,63.5442 1452.94,63.5442 1452.95,63.5442 1452.96,63.5442 1452.97,63.5442 1452.98,63.5442 1452.99,63.5442 1453,63.5442 1453,63.5442 1453.01,63.5442 1453.02,63.5442 1453.03,63.5442 1453.04,63.5442 1453.05,63.5442 1453.06,63.5442 1453.07,63.5442 1453.08,63.5442 1453.09,63.5442 1453.1,63.5442 1453.11,63.5442 1453.12,63.5442 1453.12,63.5442 1453.13,63.5442 1453.14,63.5442 1453.15,63.5442 1453.16,63.5442 1453.17,63.5442 1453.18,63.5442 1453.19,63.5442 1453.2,63.5442 1453.21,63.5442 1453.22,63.5442 1453.23,63.5442 1453.23,63.5442 1453.24,63.5442 1453.25,63.5442 1453.26,63.5442 1453.27,63.5442 1453.28,63.5442 1453.29,63.5442 1453.3,63.5442 1453.31,63.5442 1453.32,63.5442 1453.33,63.5442 1453.34,63.5442 1453.34,63.5442 1453.35,63.5442 1453.36,63.5442 1453.37,63.5442 1453.38,63.5442 1453.39,63.5442 1453.4,63.5442 1453.41,63.5442 1453.42,63.5442 1453.43,63.5442 1453.44,63.5442 1453.45,63.5442 1453.46,63.5442 1453.46,63.5442 1453.47,63.5442 1453.48,63.5442 1453.49,63.5442 1453.5,63.5442 1453.51,63.5442 1453.52,63.5442 1453.53,63.5442 1453.54,63.5442 1453.55,63.5442 1453.56,63.5442 1453.57,63.5442 1453.57,63.5442 1453.58,63.5442 1453.59,63.5442 1453.6,63.5442 1453.61,63.5442 1453.62,63.5442 1453.63,63.5442 1453.64,63.5442 1453.65,63.5442 1453.66,63.5442 1453.67,63.5442 1453.68,63.5442 1453.68,63.5442 1453.69,63.5442 1453.7,63.5442 1453.71,63.5442 1453.72,63.5442 1453.73,63.5442 1453.74,63.5442 1453.75,63.5442 1453.76,63.5442 1453.77,63.5442 1453.78,63.5442 1453.79,63.5442 1453.8,63.5442 1453.8,63.5442 1453.81,63.5442 1453.82,63.5442 1453.83,63.5442 1453.84,63.5442 1453.85,63.5442 1453.86,63.5442 1453.87,63.5442 1453.88,63.5442 1453.89,63.5442 1453.9,63.5442 1453.91,63.5442 1453.91,63.5442 1453.92,63.5442 1453.93,63.5442 1453.94,63.5442 1453.95,63.5442 1453.96,63.5442 1453.97,63.5442 1453.98,63.5442 1453.99,63.5442 1454,63.5442 1454.01,63.5442 1454.02,63.5442 1454.02,63.5442 1454.03,63.5442 1454.04,63.5442 1454.05,63.5442 1454.06,63.5442 1454.07,63.5442 1454.08,63.5442 1454.09,63.5442 1454.1,63.5442 1454.11,63.5442 1454.12,63.5442 1454.13,63.5442 1454.14,63.5442 1454.14,63.5442 1454.15,63.5442 1454.16,63.5442 1454.17,63.5442 1454.18,63.5442 1454.19,63.5442 1454.2,63.5442 1454.21,63.5442 1454.22,63.5442 1454.23,63.5442 1454.24,63.5442 1454.25,63.5442 1454.25,63.5442 1454.26,63.5442 1454.27,63.5442 1454.28,63.5442 1454.29,63.5442 1454.3,63.5442 1454.31,63.5442 1454.32,63.5442 1454.33,63.5442 1454.34,63.5442 1454.35,63.5442 1454.36,63.5442 1454.36,63.5442 1454.37,63.5442 1454.38,63.5442 1454.39,63.5442 1454.4,63.5442 1454.41,63.5442 1454.42,63.5442 1454.43,63.5442 1454.44,63.5442 1454.45,63.5442 1454.46,63.5442 1454.47,63.5442 1454.48,63.5442 1454.48,63.5442 1454.49,63.5442 1454.5,63.5442 1454.51,63.5442 1454.52,63.5442 1454.53,63.5442 1454.54,63.5442 1454.55,63.5442 1454.56,63.5442 1454.57,63.5442 1454.58,63.5442 1454.59,63.5442 1454.59,63.5442 1454.6,63.5442 1454.61,63.5442 1454.62,63.5442 1454.63,63.5442 1454.64,63.5442 1454.65,63.5442 1454.66,63.5442 1454.67,63.5442 1454.68,63.5442 1454.69,63.5442 1454.7,63.5442 1454.7,63.5442 1454.71,63.5442 1454.72,63.5442 1454.73,63.5442 1454.74,63.5442 1454.75,63.5442 1454.76,63.5442 1454.77,63.5442 1454.78,63.5442 1454.79,63.5442 1454.8,63.5442 1454.81,63.5442 1454.82,63.5442 1454.82,63.5442 1454.83,63.5442 1454.84,63.5442 1454.85,63.5442 1454.86,63.5442 1454.87,63.5442 1454.88,63.5442 1454.89,63.5442 1454.9,63.5442 1454.91,63.5442 1454.92,63.5442 1454.93,63.5442 1454.93,63.5442 1454.94,63.5442 1454.95,63.5442 1454.96,63.5442 1454.97,63.5442 1454.98,63.5442 1454.99,63.5442 1455,63.5442 1455.01,63.5442 1455.02,63.5442 1455.03,63.5442 1455.04,63.5442 1455.04,63.5442 1455.05,63.5442 1455.06,63.5442 1455.07,63.5442 1455.08,63.5442 1455.09,63.5442 1455.1,63.5442 1455.11,63.5442 1455.12,63.5442 1455.13,63.5442 1455.14,63.5442 1455.15,63.5442 1455.16,63.5442 1455.16,63.5442 1455.17,63.5442 1455.18,63.5442 1455.19,63.5442 1455.2,63.5442 1455.21,63.5442 1455.22,63.5442 1455.23,63.5442 1455.24,63.5442 1455.25,63.5442 1455.26,63.5442 1455.27,63.5442 1455.27,63.5442 1455.28,63.5442 1455.29,63.5442 1455.3,63.5442 1455.31,63.5442 1455.32,63.5442 1455.33,63.5442 1455.34,63.5442 1455.35,63.5442 1455.36,63.5442 1455.37,63.5442 1455.38,63.5442 1455.38,63.5442 1455.39,63.5442 1455.4,63.5442 1455.41,63.5442 1455.42,63.5442 1455.43,63.5442 1455.44,63.5442 1455.45,63.5442 1455.46,63.5442 1455.47,63.5442 1455.48,63.5442 1455.49,63.5442 1455.5,63.5442 1455.5,63.5442 1455.51,63.5442 1455.52,63.5442 1455.53,63.5442 1455.54,63.5442 1455.55,63.5442 1455.56,63.5442 1455.57,63.5442 1455.58,63.5442 1455.59,63.5442 1455.6,63.5442 1455.61,63.5442 1455.61,63.5442 1455.62,63.5442 1455.63,63.5442 1455.64,63.5442 1455.65,63.5442 1455.66,63.5442 1455.67,63.5442 1455.68,63.5442 1455.69,63.5442 1455.7,63.5442 1455.71,63.5442 1455.72,63.5442 1455.72,63.5442 1455.73,63.5442 1455.74,63.5442 1455.75,63.5442 1455.76,63.5442 1455.77,63.5442 1455.78,63.5442 1455.79,63.5442 1455.8,63.5442 1455.81,63.5442 1455.82,63.5442 1455.83,63.5442 1455.84,63.5442 1455.84,63.5442 1455.85,63.5442 1455.86,63.5442 1455.87,63.5442 1455.88,63.5442 1455.89,63.5442 1455.9,63.5442 1455.91,63.5442 1455.92,63.5442 1455.93,63.5442 1455.94,63.5442 1455.95,63.5442 1455.95,63.5442 1455.96,63.5442 1455.97,63.5442 1455.98,63.5442 1455.99,63.5442 1456,63.5442 1456.01,63.5442 1456.02,63.5442 1456.03,63.5442 1456.04,63.5442 1456.05,63.5442 1456.06,63.5442 1456.06,63.5442 1456.07,63.5442 1456.08,63.5442 1456.09,63.5442 1456.1,63.5442 1456.11,63.5442 1456.12,63.5442 1456.13,63.5442 1456.14,63.5442 1456.15,63.5442 1456.16,63.5442 1456.17,63.5442 1456.18,63.5442 1456.18,63.5442 1456.19,63.5442 1456.2,63.5442 1456.21,63.5442 1456.22,63.5442 1456.23,63.5442 1456.24,63.5442 1456.25,63.5442 1456.26,63.5442 1456.27,63.5442 1456.28,63.5442 1456.29,63.5442 1456.29,63.5442 1456.3,63.5442 1456.31,63.5442 1456.32,63.5442 1456.33,63.5442 1456.34,63.5442 1456.35,63.5442 1456.36,63.5442 1456.37,63.5442 1456.38,63.5442 1456.39,63.5442 1456.4,63.5442 1456.4,63.5442 1456.41,63.5442 1456.42,63.5442 1456.43,63.5442 1456.44,63.5442 1456.45,63.5442 1456.46,63.5442 1456.47,63.5442 1456.48,63.5442 1456.49,63.5442 1456.5,63.5442 1456.51,63.5442 1456.52,63.5442 1456.52,63.5442 1456.53,63.5442 1456.54,63.5442 1456.55,63.5442 1456.56,63.5442 1456.57,63.5442 1456.58,63.5442 1456.59,63.5442 1456.6,63.5442 1456.61,63.5442 1456.62,63.5442 1456.63,63.5442 1456.63,63.5442 1456.64,63.5442 1456.65,63.5442 1456.66,63.5442 1456.67,63.5442 1456.68,63.5442 1456.69,63.5442 1456.7,63.5442 1456.71,63.5442 1456.72,63.5442 1456.73,63.5442 1456.74,63.5442 1456.74,63.5442 1456.75,63.5442 1456.76,63.5442 1456.77,63.5442 1456.78,63.5442 1456.79,63.5442 1456.8,63.5442 1456.81,63.5442 1456.82,63.5442 1456.83,63.5442 1456.84,63.5442 1456.85,63.5442 1456.86,63.5442 1456.86,63.5442 1456.87,63.5442 1456.88,63.5442 1456.89,63.5442 1456.9,63.5442 1456.91,63.5442 1456.92,63.5442 1456.93,63.5442 1456.94,63.5442 1456.95,63.5442 1456.96,63.5442 1456.97,63.5442 1456.97,63.5442 1456.98,63.5442 1456.99,63.5442 1457,63.5442 1457.01,63.5442 1457.02,63.5442 1457.03,63.5442 1457.04,63.5442 1457.05,63.5442 1457.06,63.5442 1457.07,63.5442 1457.08,63.5442 1457.09,63.5442 1457.09,63.5442 1457.1,63.5442 1457.11,63.5442 1457.12,63.5442 1457.13,63.5442 1457.14,63.5442 1457.15,63.5442 1457.16,63.5442 1457.17,63.5442 1457.18,63.5442 1457.19,63.5442 1457.2,63.5442 1457.2,63.5442 1457.21,63.5442 1457.22,63.5442 1457.23,63.5442 1457.24,63.5442 1457.25,63.5442 1457.26,63.5442 1457.27,63.5442 1457.28,63.5442 1457.29,63.5442 1457.3,63.5442 1457.31,63.5442 1457.31,63.5442 1457.32,63.5442 1457.33,63.5442 1457.34,63.5442 1457.35,63.5442 1457.36,63.5442 1457.37,63.5442 1457.38,63.5442 1457.39,63.5442 1457.4,63.5442 1457.41,63.5442 1457.42,63.5442 1457.43,63.5442 1457.43,63.5442 1457.44,63.5442 1457.45,63.5442 1457.46,63.5442 1457.47,63.5442 1457.48,63.5442 1457.49,63.5442 1457.5,63.5442 1457.51,63.5442 1457.52,63.5442 1457.53,63.5442 1457.54,63.5442 1457.54,63.5442 1457.55,63.5442 1457.56,63.5442 1457.57,63.5442 1457.58,63.5442 1457.59,63.5442 1457.6,63.5442 1457.61,63.5442 1457.62,63.5442 1457.63,63.5442 1457.64,63.5442 1457.65,63.5442 1457.65,63.5442 1457.66,63.5442 1457.67,63.5442 1457.68,63.5442 1457.69,63.5442 1457.7,63.5442 1457.71,63.5442 1457.72,63.5442 1457.73,63.5442 1457.74,63.5442 1457.75,63.5442 1457.76,63.5442 1457.77,63.5442 1457.77,63.5442 1457.78,63.5442 1457.79,63.5442 1457.8,63.5442 1457.81,63.5442 1457.82,63.5442 1457.83,63.5442 1457.84,63.5442 1457.85,63.5442 1457.86,63.5442 1457.87,63.5442 1457.88,63.5442 1457.88,63.5442 1457.89,63.5442 1457.9,63.5442 1457.91,63.5442 1457.92,63.5442 1457.93,63.5442 1457.94,63.5442 1457.95,63.5442 1457.96,63.5442 1457.97,63.5442 1457.98,63.5442 1457.99,63.5442 1457.99,63.5442 1458,63.5442 1458.01,63.5442 1458.02,63.5442 1458.03,63.5442 1458.04,63.5442 1458.05,63.5442 1458.06,63.5442 1458.07,63.5442 1458.08,63.5442 1458.09,63.5442 1458.1,63.5442 1458.11,63.5442 1458.11,63.5442 1458.12,63.5442 1458.13,63.5442 1458.14,63.5442 1458.15,63.5442 1458.16,63.5442 1458.17,63.5442 1458.18,63.5442 1458.19,63.5442 1458.2,63.5442 1458.21,63.5442 1458.22,63.5442 1458.22,63.5442 1458.23,63.5442 1458.24,63.5442 1458.25,63.5442 1458.26,63.5442 1458.27,63.5442 1458.28,63.5442 1458.29,63.5442 1458.3,63.5442 1458.31,63.5442 1458.32,63.5442 1458.33,63.5442 1458.33,63.5442 1458.34,63.5442 1458.35,63.5442 1458.36,63.5442 1458.37,63.5442 1458.38,63.5442 1458.39,63.5442 1458.4,63.5442 1458.41,63.5442 1458.42,63.5442 1458.43,63.5442 1458.44,63.5442 1458.45,63.5442 1458.45,63.5442 1458.46,63.5442 1458.47,63.5442 1458.48,63.5442 1458.49,63.5442 1458.5,63.5442 1458.51,63.5442 1458.52,63.5442 1458.53,63.5442 1458.54,63.5442 1458.55,63.5442 1458.56,63.5442 1458.56,63.5442 1458.57,63.5442 1458.58,63.5442 1458.59,63.5442 1458.6,63.5442 1458.61,63.5442 1458.62,63.5442 1458.63,63.5442 1458.64,63.5442 1458.65,63.5442 1458.66,63.5442 1458.67,63.5442 1458.67,63.5442 1458.68,63.5442 1458.69,63.5442 1458.7,63.5442 1458.71,63.5442 1458.72,63.5442 1458.73,63.5442 1458.74,63.5442 1458.75,63.5442 1458.76,63.5442 1458.77,63.5442 1458.78,63.5442 1458.79,63.5442 1458.79,63.5442 1458.8,63.5442 1458.81,63.5442 1458.82,63.5442 1458.83,63.5442 1458.84,63.5442 1458.85,63.5442 1458.86,63.5442 1458.87,63.5442 1458.88,63.5442 1458.89,63.5442 1458.9,63.5442 1458.9,63.5442 1458.91,63.5442 1458.92,63.5442 1458.93,63.5442 1458.94,63.5442 1458.95,63.5442 1458.96,63.5442 1458.97,63.5442 1458.98,63.5442 1458.99,63.5442 1459,63.5442 1459.01,63.5442 1459.01,63.5442 1459.02,63.5442 1459.03,63.5442 1459.04,63.5442 1459.05,63.5442 1459.06,63.5442 1459.07,63.5442 1459.08,63.5442 1459.09,63.5442 1459.1,63.5442 1459.11,63.5442 1459.12,63.5442 1459.13,63.5442 1459.13,63.5442 1459.14,63.5442 1459.15,63.5442 1459.16,63.5442 1459.17,63.5442 1459.18,63.5442 1459.19,63.5442 1459.2,63.5442 1459.21,63.5442 1459.22,63.5442 1459.23,63.5442 1459.24,63.5442 1459.24,63.5442 1459.25,63.5442 1459.26,63.5442 1459.27,63.5442 1459.28,63.5442 1459.29,63.5442 1459.3,63.5442 1459.31,63.5442 1459.32,63.5442 1459.33,63.5442 1459.34,63.5442 1459.35,63.5442 1459.35,63.5442 1459.36,63.5442 1459.37,63.5442 1459.38,63.5442 1459.39,63.5442 1459.4,63.5442 1459.41,63.5442 1459.42,63.5442 1459.43,63.5442 1459.44,63.5442 1459.45,63.5442 1459.46,63.5442 1459.47,63.5442 1459.47,63.5442 1459.48,63.5442 1459.49,63.5442 1459.5,63.5442 1459.51,63.5442 1459.52,63.5442 1459.53,63.5442 1459.54,63.5442 1459.55,63.5442 1459.56,63.5442 1459.57,63.5442 1459.58,63.5442 1459.58,63.5442 1459.59,63.5442 1459.6,63.5442 1459.61,63.5442 1459.62,63.5442 1459.63,63.5442 1459.64,63.5442 1459.65,63.5442 1459.66,63.5442 1459.67,63.5442 1459.68,63.5442 1459.69,63.5442 1459.69,63.5442 1459.7,63.5442 1459.71,63.5442 1459.72,63.5442 1459.73,63.5442 1459.74,63.5442 1459.75,63.5442 1459.76,63.5442 1459.77,63.5442 1459.78,63.5442 1459.79,63.5442 1459.8,63.5442 1459.81,63.5442 1459.81,63.5442 1459.82,63.5442 1459.83,63.5442 1459.84,63.5442 1459.85,63.5442 1459.86,63.5442 1459.87,63.5442 1459.88,63.5442 1459.89,63.5442 1459.9,63.5442 1459.91,63.5442 1459.92,63.5442 1459.92,63.5442 1459.93,63.5442 1459.94,63.5442 1459.95,63.5442 1459.96,63.5442 1459.97,63.5442 1459.98,63.5442 1459.99,63.5442 1460,63.5442 1460.01,63.5442 1460.02,63.5442 1460.03,63.5442 1460.03,63.5442 1460.04,63.5442 1460.05,63.5442 1460.06,63.5442 1460.07,63.5442 1460.08,63.5442 1460.09,63.5442 1460.1,63.5442 1460.11,63.5442 1460.12,63.5442 1460.13,63.5442 1460.14,63.5442 1460.15,63.5442 1460.15,63.5442 1460.16,63.5442 1460.17,63.5442 1460.18,63.5442 1460.19,63.5442 1460.2,63.5442 1460.21,63.5442 1460.22,63.5442 1460.23,63.5442 1460.24,63.5442 1460.25,63.5442 1460.26,63.5442 1460.26,63.5442 1460.27,63.5442 1460.28,63.5442 1460.29,63.5442 1460.3,63.5442 1460.31,63.5442 1460.32,63.5442 1460.33,63.5442 1460.34,63.5442 1460.35,63.5442 1460.36,63.5442 1460.37,63.5442 1460.37,63.5442 1460.38,63.5442 1460.39,63.5442 1460.4,63.5442 1460.41,63.5442 1460.42,63.5442 1460.43,63.5442 1460.44,63.5442 1460.45,63.5442 1460.46,63.5442 1460.47,63.5442 1460.48,63.5442 1460.49,63.5442 1460.49,63.5442 1460.5,63.5442 1460.51,63.5442 1460.52,63.5442 1460.53,63.5442 1460.54,63.5442 1460.55,63.5442 1460.56,63.5442 1460.57,63.5442 1460.58,63.5442 1460.59,63.5442 1460.6,63.5442 1460.6,63.5442 1460.61,63.5442 1460.62,63.5442 1460.63,63.5442 1460.64,63.5442 1460.65,63.5442 1460.66,63.5442 1460.67,63.5442 1460.68,63.5442 1460.69,63.5442 1460.7,63.5442 1460.71,63.5442 1460.71,63.5442 1460.72,63.5442 1460.73,63.5442 1460.74,63.5442 1460.75,63.5442 1460.76,63.5442 1460.77,63.5442 1460.78,63.5442 1460.79,63.5442 1460.8,63.5442 1460.81,63.5442 1460.82,63.5442 1460.83,63.5442 1460.83,63.5442 1460.84,63.5442 1460.85,63.5442 1460.86,63.5442 1460.87,63.5442 1460.88,63.5442 1460.89,63.5442 1460.9,63.5442 1460.91,63.5442 1460.92,63.5442 1460.93,63.5442 1460.94,63.5442 1460.94,63.5442 1460.95,63.5442 1460.96,63.5442 1460.97,63.5442 1460.98,63.5442 1460.99,63.5442 1461,63.5442 1461.01,63.5442 1461.02,63.5442 1461.03,63.5442 1461.04,63.5442 1461.05,63.5442 1461.05,63.5442 1461.06,63.5442 1461.07,63.5442 1461.08,63.5442 1461.09,63.5442 1461.1,63.5442 1461.11,63.5442 1461.12,63.5442 1461.13,63.5442 1461.14,63.5442 1461.15,63.5442 1461.16,63.5442 1461.17,63.5442 1461.17,63.5442 1461.18,63.5442 1461.19,63.5442 1461.2,63.5442 1461.21,63.5442 1461.22,63.5442 1461.23,63.5442 1461.24,63.5442 1461.25,63.5442 1461.26,63.5442 1461.27,63.5442 1461.28,63.5442 1461.28,63.5442 1461.29,63.5442 1461.3,63.5442 1461.31,63.5442 1461.32,63.5442 1461.33,63.5442 1461.34,63.5442 1461.35,63.5442 1461.36,63.5442 1461.37,63.5442 1461.38,63.5442 1461.39,63.5442 1461.39,63.5442 1461.4,63.5442 1461.41,63.5442 1461.42,63.5442 1461.43,63.5442 1461.44,63.5442 1461.45,63.5442 1461.46,63.5442 1461.47,63.5442 1461.48,63.5442 1461.49,63.5442 1461.5,63.5442 1461.51,63.5442 1461.51,63.5442 1461.52,63.5442 1461.53,63.5442 1461.54,63.5442 1461.55,63.5442 1461.56,63.5442 1461.57,63.5442 1461.58,63.5442 1461.59,63.5442 1461.6,63.5442 1461.61,63.5442 1461.62,63.5442 1461.62,63.5442 1461.63,63.5442 1461.64,63.5442 1461.65,63.5442 1461.66,63.5442 1461.67,63.5442 1461.68,63.5442 1461.69,63.5442 1461.7,63.5442 1461.71,63.5442 1461.72,63.5442 1461.73,63.5442 1461.73,63.5442 1461.74,63.5442 1461.75,63.5442 1461.76,63.5442 1461.77,63.5442 1461.78,63.5442 1461.79,63.5442 1461.8,63.5442 1461.81,63.5442 1461.82,63.5442 1461.83,63.5442 1461.84,63.5442 1461.85,63.5442 1461.85,63.5442 1461.86,63.5442 1461.87,63.5442 1461.88,63.5442 1461.89,63.5442 1461.9,63.5442 1461.91,63.5442 1461.92,63.5442 1461.93,63.5442 1461.94,63.5442 1461.95,63.5442 1461.96,63.5442 1461.96,63.5442 1461.97,63.5442 1461.98,63.5442 1461.99,63.5442 1462,63.5442 1462.01,63.5442 1462.02,63.5442 1462.03,63.5442 1462.04,63.5442 1462.05,63.5442 1462.06,63.5442 1462.07,63.5442 1462.07,63.5442 1462.08,63.5442 1462.09,63.5442 1462.1,63.5442 1462.11,63.5442 1462.12,63.5442 1462.13,63.5442 1462.14,63.5442 1462.15,63.5442 1462.16,63.5442 1462.17,63.5442 1462.18,63.5442 1462.19,63.5442 1462.19,63.5442 1462.2,63.5442 1462.21,63.5442 1462.22,63.5442 1462.23,63.5442 1462.24,63.5442 1462.25,63.5442 1462.26,63.5442 1462.27,63.5442 1462.28,63.5442 1462.29,63.5442 1462.3,63.5442 1462.3,63.5442 1462.31,63.5442 1462.32,63.5442 1462.33,63.5442 1462.34,63.5442 1462.35,63.5442 1462.36,63.5442 1462.37,63.5442 1462.38,63.5442 1462.39,63.5442 1462.4,63.5442 1462.41,63.5442 1462.41,63.5442 1462.42,63.5442 1462.43,63.5442 1462.44,63.5442 1462.45,63.5442 1462.46,63.5442 1462.47,63.5442 1462.48,63.5442 1462.49,63.5442 1462.5,63.5442 1462.51,63.5442 1462.52,63.5442 1462.53,63.5442 1462.53,63.5442 1462.54,63.5442 1462.55,63.5442 1462.56,63.5442 1462.57,63.5442 1462.58,63.5442 1462.59,63.5442 1462.6,63.5442 1462.61,63.5442 1462.62,63.5442 1462.63,63.5442 1462.64,63.5442 1462.64,63.5442 1462.65,63.5442 1462.66,63.5442 1462.67,63.5442 1462.68,63.5442 1462.69,63.5442 1462.7,63.5442 1462.71,63.5442 1462.72,63.5442 1462.73,63.5442 1462.74,63.5442 1462.75,63.5442 1462.75,63.5442 1462.76,63.5442 1462.77,63.5442 1462.78,63.5442 1462.79,63.5442 1462.8,63.5442 1462.81,63.5442 1462.82,63.5442 1462.83,63.5442 1462.84,63.5442 1462.85,63.5442 1462.86,63.5442 1462.87,63.5442 1462.87,63.5442 1462.88,63.5442 1462.89,63.5442 1462.9,63.5442 1462.91,63.5442 1462.92,63.5442 1462.93,63.5442 1462.94,63.5442 1462.95,63.5442 1462.96,63.5442 1462.97,63.5442 1462.98,63.5442 1462.98,63.5442 1462.99,63.5442 1463,63.5442 1463.01,63.5442 1463.02,63.5442 1463.03,63.5442 1463.04,63.5442 1463.05,63.5442 1463.06,63.5442 1463.07,63.5442 1463.08,63.5442 1463.09,63.5442 1463.09,63.5442 1463.1,63.5442 1463.11,63.5442 1463.12,63.5442 1463.13,63.5442 1463.14,63.5442 1463.15,63.5442 1463.16,63.5442 1463.17,63.5442 1463.18,63.5442 1463.19,63.5442 1463.2,63.5442 1463.21,63.5442 1463.21,63.5442 1463.22,63.5442 1463.23,63.5442 1463.24,63.5442 1463.25,63.5442 1463.26,63.5442 1463.27,63.5442 1463.28,63.5442 1463.29,63.5442 1463.3,63.5442 1463.31,63.5442 1463.32,63.5442 1463.32,63.5442 1463.33,63.5442 1463.34,63.5442 1463.35,63.5442 1463.36,63.5442 1463.37,63.5442 1463.38,63.5442 1463.39,63.5442 1463.4,63.5442 1463.41,63.5442 1463.42,63.5442 1463.43,63.5442 1463.43,63.5442 1463.44,63.5442 1463.45,63.5442 1463.46,63.5442 1463.47,63.5442 1463.48,63.5442 1463.49,63.5442 1463.5,63.5442 1463.51,63.5442 1463.52,63.5442 1463.53,63.5442 1463.54,63.5442 1463.55,63.5442 1463.55,63.5442 1463.56,63.5442 1463.57,63.5442 1463.58,63.5442 1463.59,63.5442 1463.6,63.5442 1463.61,63.5442 1463.62,63.5442 1463.63,63.5442 1463.64,63.5442 1463.65,63.5442 1463.66,63.5442 1463.66,63.5442 1463.67,63.5442 1463.68,63.5442 1463.69,63.5442 1463.7,63.5442 1463.71,63.5442 1463.72,63.5442 1463.73,63.5442 1463.74,63.5442 1463.75,63.5442 1463.76,63.5442 1463.77,63.5442 1463.77,63.5442 1463.78,63.5442 1463.79,63.5442 1463.8,63.5442 1463.81,63.5442 1463.82,63.5442 1463.83,63.5442 1463.84,63.5442 1463.85,63.5442 1463.86,63.5442 1463.87,63.5442 1463.88,63.5442 1463.89,63.5442 1463.89,63.5442 1463.9,63.5442 1463.91,63.5442 1463.92,63.5442 1463.93,63.5442 1463.94,63.5442 1463.95,63.5442 1463.96,63.5442 1463.97,63.5442 1463.98,63.5442 1463.99,63.5442 1464,63.5442 1464,63.5442 1464.01,63.5442 1464.02,63.5442 1464.03,63.5442 1464.04,63.5442 1464.05,63.5442 1464.06,63.5442 1464.07,63.5442 1464.08,63.5442 1464.09,63.5442 1464.1,63.5442 1464.11,63.5442 1464.11,63.5442 1464.12,63.5442 1464.13,63.5442 1464.14,63.5442 1464.15,63.5442 1464.16,63.5442 1464.17,63.5442 1464.18,63.5442 1464.19,63.5442 1464.2,63.5442 1464.21,63.5442 1464.22,63.5442 1464.23,63.5442 1464.23,63.5442 1464.24,63.5442 1464.25,63.5442 1464.26,63.5442 1464.27,63.5442 1464.28,63.5442 1464.29,63.5442 1464.3,63.5442 1464.31,63.5442 1464.32,63.5442 1464.33,63.5442 1464.34,63.5442 1464.34,63.5442 1464.35,63.5442 1464.36,63.5442 1464.37,63.5442 1464.38,63.5442 1464.39,63.5442 1464.4,63.5442 1464.41,63.5442 1464.42,63.5442 1464.43,63.5442 1464.44,63.5442 1464.45,63.5442 1464.45,63.5442 1464.46,63.5442 1464.47,63.5442 1464.48,63.5442 1464.49,63.5442 1464.5,63.5442 1464.51,63.5442 1464.52,63.5442 1464.53,63.5442 1464.54,63.5442 1464.55,63.5442 1464.56,63.5442 1464.57,63.5442 1464.57,63.5442 1464.58,63.5442 1464.59,63.5442 1464.6,63.5442 1464.61,63.5442 1464.62,63.5442 1464.63,63.5442 1464.64,63.5442 1464.65,63.5442 1464.66,63.5442 1464.67,63.5442 1464.68,63.5442 1464.68,63.5442 1464.69,63.5442 1464.7,63.5442 1464.71,63.5442 1464.72,63.5442 1464.73,63.5442 1464.74,63.5442 1464.75,63.5442 1464.76,63.5442 1464.77,63.5442 1464.78,63.5442 1464.79,63.5442 1464.79,63.5442 1464.8,63.5442 1464.81,63.5442 1464.82,63.5442 1464.83,63.5442 1464.84,63.5442 1464.85,63.5442 1464.86,63.5442 1464.87,63.5442 1464.88,63.5442 1464.89,63.5442 1464.9,63.5442 1464.91,63.5442 1464.91,63.5442 1464.92,63.5442 1464.93,63.5442 1464.94,63.5442 1464.95,63.5442 1464.96,63.5442 1464.97,63.5442 1464.98,63.5442 1464.99,63.5442 1465,63.5442 1465.01,63.5442 1465.02,63.5442 1465.02,63.5442 1465.03,63.5442 1465.04,63.5442 1465.05,63.5442 1465.06,63.5442 1465.07,63.5442 1465.08,63.5442 1465.09,63.5442 1465.1,63.5442 1465.11,63.5442 1465.12,63.5442 1465.13,63.5442 1465.13,63.5442 1465.14,63.5442 1465.15,63.5442 1465.16,63.5442 1465.17,63.5442 1465.18,63.5442 1465.19,63.5442 1465.2,63.5442 1465.21,63.5442 1465.22,63.5442 1465.23,63.5442 1465.24,63.5442 1465.25,63.5442 1465.25,63.5442 1465.26,63.5442 1465.27,63.5442 1465.28,63.5442 1465.29,63.5442 1465.3,63.5442 1465.31,63.5442 1465.32,63.5442 1465.33,63.5442 1465.34,63.5442 1465.35,63.5442 1465.36,63.5442 1465.36,63.5442 1465.37,63.5442 1465.38,63.5442 1465.39,63.5442 1465.4,63.5442 1465.41,63.5442 1465.42,63.5442 1465.43,63.5442 1465.44,63.5442 1465.45,63.5442 1465.46,63.5442 1465.47,63.5442 1465.47,63.5442 1465.48,63.5442 1465.49,63.5442 1465.5,63.5442 1465.51,63.5442 1465.52,63.5442 1465.53,63.5442 1465.54,63.5442 1465.55,63.5442 1465.56,63.5442 1465.57,63.5442 1465.58,63.5442 1465.59,63.5442 1465.59,63.5442 1465.6,63.5442 1465.61,63.5442 1465.62,63.5442 1465.63,63.5442 1465.64,63.5442 1465.65,63.5442 1465.66,63.5442 1465.67,63.5442 1465.68,63.5442 1465.69,63.5442 1465.7,63.5442 1465.7,63.5442 1465.71,63.5442 1465.72,63.5442 1465.73,63.5442 1465.74,63.5442 1465.75,63.5442 1465.76,63.5442 1465.77,63.5442 1465.78,63.5442 1465.79,63.5442 1465.8,63.5442 1465.81,63.5442 1465.81,63.5442 1465.82,63.5442 1465.83,63.5442 1465.84,63.5442 1465.85,63.5442 1465.86,63.5442 1465.87,63.5442 1465.88,63.5442 1465.89,63.5442 1465.9,63.5442 1465.91,63.5442 1465.92,63.5442 1465.93,63.5442 1465.93,63.5442 1465.94,63.5442 1465.95,63.5442 1465.96,63.5442 1465.97,63.5442 1465.98,63.5442 1465.99,63.5442 1466,63.5442 1466.01,63.5442 1466.02,63.5442 1466.03,63.5442 1466.04,63.5442 1466.04,63.5442 1466.05,63.5442 1466.06,63.5442 1466.07,63.5442 1466.08,63.5442 1466.09,63.5442 1466.1,63.5442 1466.11,63.5442 1466.12,63.5442 1466.13,63.5442 1466.14,63.5442 1466.15,63.5442 1466.15,63.5442 1466.16,63.5442 1466.17,63.5442 1466.18,63.5442 1466.19,63.5442 1466.2,63.5442 1466.21,63.5442 1466.22,63.5442 1466.23,63.5442 1466.24,63.5442 1466.25,63.5442 1466.26,63.5442 1466.27,63.5442 1466.27,63.5442 1466.28,63.5442 1466.29,63.5442 1466.3,63.5442 1466.31,63.5442 1466.32,63.5442 1466.33,63.5442 1466.34,63.5442 1466.35,63.5442 1466.36,63.5442 1466.37,63.5442 1466.38,63.5442 1466.38,63.5442 1466.39,63.5442 1466.4,63.5442 1466.41,63.5442 1466.42,63.5442 1466.43,63.5442 1466.44,63.5442 1466.45,63.5442 1466.46,63.5442 1466.47,63.5442 1466.48,63.5442 1466.49,63.5442 1466.49,63.5442 1466.5,63.5442 1466.51,63.5442 1466.52,63.5442 1466.53,63.5442 1466.54,63.5442 1466.55,63.5442 1466.56,63.5442 1466.57,63.5442 1466.58,63.5442 1466.59,63.5442 1466.6,63.5442 1466.61,63.5442 1466.61,63.5442 1466.62,63.5442 1466.63,63.5442 1466.64,63.5442 1466.65,63.5442 1466.66,63.5442 1466.67,63.5442 1466.68,63.5442 1466.69,63.5442 1466.7,63.5442 1466.71,63.5442 1466.72,63.5442 1466.72,63.5442 1466.73,63.5442 1466.74,63.5442 1466.75,63.5442 1466.76,63.5442 1466.77,63.5442 1466.78,63.5442 1466.79,63.5442 1466.8,63.5442 1466.81,63.5442 1466.82,63.5442 1466.83,63.5442 1466.83,63.5442 1466.84,63.5442 1466.85,63.5442 1466.86,63.5442 1466.87,63.5442 1466.88,63.5442 1466.89,63.5442 1466.9,63.5442 1466.91,63.5442 1466.92,63.5442 1466.93,63.5442 1466.94,63.5442 1466.95,63.5442 1466.95,63.5442 1466.96,63.5442 1466.97,63.5442 1466.98,63.5442 1466.99,63.5442 1467,63.5442 1467.01,63.5442 1467.02,63.5442 1467.03,63.5442 1467.04,63.5442 1467.05,63.5442 1467.06,63.5442 1467.06,63.5442 1467.07,63.5442 1467.08,63.5442 1467.09,63.5442 1467.1,63.5442 1467.11,63.5442 1467.12,63.5442 1467.13,63.5442 1467.14,63.5442 1467.15,63.5442 1467.16,63.5442 1467.17,63.5442 1467.17,63.5442 1467.18,63.5442 1467.19,63.5442 1467.2,63.5442 1467.21,63.5442 1467.22,63.5442 1467.23,63.5442 1467.24,63.5442 1467.25,63.5442 1467.26,63.5442 1467.27,63.5442 1467.28,63.5442 1467.29,63.5442 1467.29,63.5442 1467.3,63.5442 1467.31,63.5442 1467.32,63.5442 1467.33,63.5442 1467.34,63.5442 1467.35,63.5442 1467.36,63.5442 1467.37,63.5442 1467.38,63.5442 1467.39,63.5442 1467.4,63.5442 1467.4,63.5442 1467.41,63.5442 1467.42,63.5442 1467.43,63.5442 1467.44,63.5442 1467.45,63.5442 1467.46,63.5442 1467.47,63.5442 1467.48,63.5442 1467.49,63.5442 1467.5,63.5442 1467.51,63.5442 1467.51,63.5442 1467.52,63.5442 1467.53,63.5442 1467.54,63.5442 1467.55,63.5442 1467.56,63.5442 1467.57,63.5442 1467.58,63.5442 1467.59,63.5442 1467.6,63.5442 1467.61,63.5442 1467.62,63.5442 1467.63,63.5442 1467.63,63.5442 1467.64,63.5442 1467.65,63.5442 1467.66,63.5442 1467.67,63.5442 1467.68,63.5442 1467.69,63.5442 1467.7,63.5442 1467.71,63.5442 1467.72,63.5442 1467.73,63.5442 1467.74,63.5442 1467.74,63.5442 1467.75,63.5442 1467.76,63.5442 1467.77,63.5442 1467.78,63.5442 1467.79,63.5442 1467.8,63.5442 1467.81,63.5442 1467.82,63.5442 1467.83,63.5442 1467.84,63.5442 1467.85,63.5442 1467.85,63.5442 1467.86,63.5442 1467.87,63.5442 1467.88,63.5442 1467.89,63.5442 1467.9,63.5442 1467.91,63.5442 1467.92,63.5442 1467.93,63.5442 1467.94,63.5442 1467.95,63.5442 1467.96,63.5442 1467.97,63.5442 1467.97,63.5442 1467.98,63.5442 1467.99,63.5442 1468,63.5442 1468.01,63.5442 1468.02,63.5442 1468.03,63.5442 1468.04,63.5442 1468.05,63.5442 1468.06,63.5442 1468.07,63.5442 1468.08,63.5442 1468.08,63.5442 1468.09,63.5442 1468.1,63.5442 1468.11,63.5442 1468.12,63.5442 1468.13,63.5442 1468.14,63.5442 1468.15,63.5442 1468.16,63.5442 1468.17,63.5442 1468.18,63.5442 1468.19,63.5442 1468.19,63.5442 1468.2,63.5442 1468.21,63.5442 1468.22,63.5442 1468.23,63.5442 1468.24,63.5442 1468.25,63.5442 1468.26,63.5442 1468.27,63.5442 1468.28,63.5442 1468.29,63.5442 1468.3,63.5442 1468.31,63.5442 1468.31,63.5442 1468.32,63.5442 1468.33,63.5442 1468.34,63.5442 1468.35,63.5442 1468.36,63.5442 1468.37,63.5442 1468.38,63.5442 1468.39,63.5442 1468.4,63.5442 1468.41,63.5442 1468.42,63.5442 1468.42,63.5442 1468.43,63.5442 1468.44,63.5442 1468.45,63.5442 1468.46,63.5442 1468.47,63.5442 1468.48,63.5442 1468.49,63.5442 1468.5,63.5442 1468.51,63.5442 1468.52,63.5442 1468.53,63.5442 1468.53,63.5442 1468.54,63.5442 1468.55,63.5442 1468.56,63.5442 1468.57,63.5442 1468.58,63.5442 1468.59,63.5442 1468.6,63.5442 1468.61,63.5442 1468.62,63.5442 1468.63,63.5442 1468.64,63.5442 1468.65,63.5442 1468.65,63.5442 1468.66,63.5442 1468.67,63.5442 1468.68,63.5442 1468.69,63.5442 1468.7,63.5442 1468.71,63.5442 1468.72,63.5442 1468.73,63.5442 1468.74,63.5442 1468.75,63.5442 1468.76,63.5442 1468.76,63.5442 1468.77,63.5442 1468.78,63.5442 1468.79,63.5442 1468.8,63.5442 1468.81,63.5442 1468.82,63.5442 1468.83,63.5442 1468.84,63.5442 1468.85,63.5442 1468.86,63.5442 1468.87,63.5442 1468.87,63.5442 1468.88,63.5442 1468.89,63.5442 1468.9,63.5442 1468.91,63.5442 1468.92,63.5442 1468.93,63.5442 1468.94,63.5442 1468.95,63.5442 1468.96,63.5442 1468.97,63.5442 1468.98,63.5442 1468.99,63.5442 1468.99,63.5442 1469,63.5442 1469.01,63.5442 1469.02,63.5442 1469.03,63.5442 1469.04,63.5442 1469.05,63.5442 1469.06,63.5442 1469.07,63.5442 1469.08,63.5442 1469.09,63.5442 1469.1,63.5442 1469.1,63.5442 1469.11,63.5442 1469.12,63.5442 1469.13,63.5442 1469.14,63.5442 1469.15,63.5442 1469.16,63.5442 1469.17,63.5442 1469.18,63.5442 1469.19,63.5442 1469.2,63.5442 1469.21,63.5442 1469.21,63.5442 1469.22,63.5442 1469.23,63.5442 1469.24,63.5442 1469.25,63.5442 1469.26,63.5442 1469.27,63.5442 1469.28,63.5442 1469.29,63.5442 1469.3,63.5442 1469.31,63.5442 1469.32,63.5442 1469.33,63.5442 1469.33,63.5442 1469.34,63.5442 1469.35,63.5442 1469.36,63.5442 1469.37,63.5442 1469.38,63.5442 1469.39,63.5442 1469.4,63.5442 1469.41,63.5442 1469.42,63.5442 1469.43,63.5442 1469.44,63.5442 1469.44,63.5442 1469.45,63.5442 1469.46,63.5442 1469.47,63.5442 1469.48,63.5442 1469.49,63.5442 1469.5,63.5442 1469.51,63.5442 1469.52,63.5442 1469.53,63.5442 1469.54,63.5442 1469.55,63.5442 1469.55,63.5442 1469.56,63.5442 1469.57,63.5442 1469.58,63.5442 1469.59,63.5442 1469.6,63.5442 1469.61,63.5442 1469.62,63.5442 1469.63,63.5442 1469.64,63.5442 1469.65,63.5442 1469.66,63.5442 1469.67,63.5442 1469.67,63.5442 1469.68,63.5442 1469.69,63.5442 1469.7,63.5442 1469.71,63.5442 1469.72,63.5442 1469.73,63.5442 1469.74,63.5442 1469.75,63.5442 1469.76,63.5442 1469.77,63.5442 1469.78,63.5442 1469.78,63.5442 1469.79,63.5442 1469.8,63.5442 1469.81,63.5442 1469.82,63.5442 1469.83,63.5442 1469.84,63.5442 1469.85,63.5442 1469.86,63.5442 1469.87,63.5442 1469.88,63.5442 1469.89,63.5442 1469.89,63.5442 1469.9,63.5442 1469.91,63.5442 1469.92,63.5442 1469.93,63.5442 1469.94,63.5442 1469.95,63.5442 1469.96,63.5442 1469.97,63.5442 1469.98,63.5442 1469.99,63.5442 1470,63.5442 1470.01,63.5442 1470.01,63.5442 1470.02,63.5442 1470.03,63.5442 1470.04,63.5442 1470.05,63.5442 1470.06,63.5442 1470.07,63.5442 1470.08,63.5442 1470.09,63.5442 1470.1,63.5442 1470.11,63.5442 1470.12,63.5442 1470.12,63.5442 1470.13,63.5442 1470.14,63.5442 1470.15,63.5442 1470.16,63.5442 1470.17,63.5442 1470.18,63.5442 1470.19,63.5442 1470.2,63.5442 1470.21,63.5442 1470.22,63.5442 1470.23,63.5442 1470.23,63.5442 1470.24,63.5442 1470.25,63.5442 1470.26,63.5442 1470.27,63.5442 1470.28,63.5442 1470.29,63.5442 1470.3,63.5442 1470.31,63.5442 1470.32,63.5442 1470.33,63.5442 1470.34,63.5442 1470.35,63.5442 1470.35,63.5442 1470.36,63.5442 1470.37,63.5442 1470.38,63.5442 1470.39,63.5442 1470.4,63.5442 1470.41,63.5442 1470.42,63.5442 1470.43,63.5442 1470.44,63.5442 1470.45,63.5442 1470.46,63.5442 1470.46,63.5442 1470.47,63.5442 1470.48,63.5442 1470.49,63.5442 1470.5,63.5442 1470.51,63.5442 1470.52,63.5442 1470.53,63.5442 1470.54,63.5442 1470.55,63.5442 1470.56,63.5442 1470.57,63.5442 1470.57,63.5442 1470.58,63.5442 1470.59,63.5442 1470.6,63.5442 1470.61,63.5442 1470.62,63.5442 1470.63,63.5442 1470.64,63.5442 1470.65,63.5442 1470.66,63.5442 1470.67,63.5442 1470.68,63.5442 1470.69,63.5442 1470.69,63.5442 1470.7,63.5442 1470.71,63.5442 1470.72,63.5442 1470.73,63.5442 1470.74,63.5442 1470.75,63.5442 1470.76,63.5442 1470.77,63.5442 1470.78,63.5442 1470.79,63.5442 1470.8,63.5442 1470.8,63.5442 1470.81,63.5442 1470.82,63.5442 1470.83,63.5442 1470.84,63.5442 1470.85,63.5442 1470.86,63.5442 1470.87,63.5442 1470.88,63.5442 1470.89,63.5442 1470.9,63.5442 1470.91,63.5442 1470.91,63.5442 1470.92,63.5442 1470.93,63.5442 1470.94,63.5442 1470.95,63.5442 1470.96,63.5442 1470.97,63.5442 1470.98,63.5442 1470.99,63.5442 1471,63.5442 1471.01,63.5442 1471.02,63.5442 1471.03,63.5442 1471.03,63.5442 1471.04,63.5442 1471.05,63.5442 1471.06,63.5442 1471.07,63.5442 1471.08,63.5442 1471.09,63.5442 1471.1,63.5442 1471.11,63.5442 1471.12,63.5442 1471.13,63.5442 1471.14,63.5442 1471.14,63.5442 1471.15,63.5442 1471.16,63.5442 1471.17,63.5442 1471.18,63.5442 1471.19,63.5442 1471.2,63.5442 1471.21,63.5442 1471.22,63.5442 1471.23,63.5442 1471.24,63.5442 1471.25,63.5442 1471.25,63.5442 1471.26,63.5442 1471.27,63.5442 1471.28,63.5442 1471.29,63.5442 1471.3,63.5442 1471.31,63.5442 1471.32,63.5442 1471.33,63.5442 1471.34,63.5442 1471.35,63.5442 1471.36,63.5442 1471.37,63.5442 1471.37,63.5442 1471.38,63.5442 1471.39,63.5442 1471.4,63.5442 1471.41,63.5442 1471.42,63.5442 1471.43,63.5442 1471.44,63.5442 1471.45,63.5442 1471.46,63.5442 1471.47,63.5442 1471.48,63.5442 1471.48,63.5442 1471.49,63.5442 1471.5,63.5442 1471.51,63.5442 1471.52,63.5442 1471.53,63.5442 1471.54,63.5442 1471.55,63.5442 1471.56,63.5442 1471.57,63.5442 1471.58,63.5442 1471.59,63.5442 1471.59,63.5442 1471.6,63.5442 1471.61,63.5442 1471.62,63.5442 1471.63,63.5442 1471.64,63.5442 1471.65,63.5442 1471.66,63.5442 1471.67,63.5442 1471.68,63.5442 1471.69,63.5442 1471.7,63.5442 1471.71,63.5442 1471.71,63.5442 1471.72,63.5442 1471.73,63.5442 1471.74,63.5442 1471.75,63.5442 1471.76,63.5442 1471.77,63.5442 1471.78,63.5442 1471.79,63.5442 1471.8,63.5442 1471.81,63.5442 1471.82,63.5442 1471.82,63.5442 1471.83,63.5442 1471.84,63.5442 1471.85,63.5442 1471.86,63.5442 1471.87,63.5442 1471.88,63.5442 1471.89,63.5442 1471.9,63.5442 1471.91,63.5442 1471.92,63.5442 1471.93,63.5442 1471.93,63.5442 1471.94,63.5442 1471.95,63.5442 1471.96,63.5442 1471.97,63.5442 1471.98,63.5442 1471.99,63.5442 1472,63.5442 1472.01,63.5442 1472.02,63.5442 1472.03,63.5442 1472.04,63.5442 1472.05,63.5442 1472.05,63.5442 1472.06,63.5442 1472.07,63.5442 1472.08,63.5442 1472.09,63.5442 1472.1,63.5442 1472.11,63.5442 1472.12,63.5442 1472.13,63.5442 1472.14,63.5442 1472.15,63.5442 1472.16,63.5442 1472.16,63.5442 1472.17,63.5442 1472.18,63.5442 1472.19,63.5442 1472.2,63.5442 1472.21,63.5442 1472.22,63.5442 1472.23,63.5442 1472.24,63.5442 1472.25,63.5442 1472.26,63.5442 1472.27,63.5442 1472.27,63.5442 1472.28,63.5442 1472.29,63.5442 1472.3,63.5442 1472.31,63.5442 1472.32,63.5442 1472.33,63.5442 1472.34,63.5442 1472.35,63.5442 1472.36,63.5442 1472.37,63.5442 1472.38,63.5442 1472.39,63.5442 1472.39,63.5442 1472.4,63.5442 1472.41,63.5442 1472.42,63.5442 1472.43,63.5442 1472.44,63.5442 1472.45,63.5442 1472.46,63.5442 1472.47,63.5442 1472.48,63.5442 1472.49,63.5442 1472.5,63.5442 1472.5,63.5442 1472.51,63.5442 1472.52,63.5442 1472.53,63.5442 1472.54,63.5442 1472.55,63.5442 1472.56,63.5442 1472.57,63.5442 1472.58,63.5442 1472.59,63.5442 1472.6,63.5442 1472.61,63.5442 1472.61,63.5442 1472.62,63.5442 1472.63,63.5442 1472.64,63.5442 1472.65,63.5442 1472.66,63.5442 1472.67,63.5442 1472.68,63.5442 1472.69,63.5442 1472.7,63.5442 1472.71,63.5442 1472.72,63.5442 1472.73,63.5442 1472.73,63.5442 1472.74,63.5442 1472.75,63.5442 1472.76,63.5442 1472.77,63.5442 1472.78,63.5442 1472.79,63.5442 1472.8,63.5442 1472.81,63.5442 1472.82,63.5442 1472.83,63.5442 1472.84,63.5442 1472.84,63.5442 1472.85,63.5442 1472.86,63.5442 1472.87,63.5442 1472.88,63.5442 1472.89,63.5442 1472.9,63.5442 1472.91,63.5442 1472.92,63.5442 1472.93,63.5442 1472.94,63.5442 1472.95,63.5442 1472.95,63.5442 1472.96,63.5442 1472.97,63.5442 1472.98,63.5442 1472.99,63.5442 1473,63.5442 1473.01,63.5442 1473.02,63.5442 1473.03,63.5442 1473.04,63.5442 1473.05,63.5442 1473.06,63.5442 1473.07,63.5442 1473.07,63.5442 1473.08,63.5442 1473.09,63.5442 1473.1,63.5442 1473.11,63.5442 1473.12,63.5442 1473.13,63.5442 1473.14,63.5442 1473.15,63.5442 1473.16,63.5442 1473.17,63.5442 1473.18,63.5442 1473.18,63.5442 1473.19,63.5442 1473.2,63.5442 1473.21,63.5442 1473.22,63.5442 1473.23,63.5442 1473.24,63.5442 1473.25,63.5442 1473.26,63.5442 1473.27,63.5442 1473.28,63.5442 1473.29,63.5442 1473.29,63.5442 1473.3,63.5442 1473.31,63.5442 1473.32,63.5442 1473.33,63.5442 1473.34,63.5442 1473.35,63.5442 1473.36,63.5442 1473.37,63.5442 1473.38,63.5442 1473.39,63.5442 1473.4,63.5442 1473.41,63.5442 1473.41,63.5442 1473.42,63.5442 1473.43,63.5442 1473.44,63.5442 1473.45,63.5442 1473.46,63.5442 1473.47,63.5442 1473.48,63.5442 1473.49,63.5442 1473.5,63.5442 1473.51,63.5442 1473.52,63.5442 1473.52,63.5442 1473.53,63.5442 1473.54,63.5442 1473.55,63.5442 1473.56,63.5442 1473.57,63.5442 1473.58,63.5442 1473.59,63.5442 1473.6,63.5442 1473.61,63.5442 1473.62,63.5442 1473.63,63.5442 1473.63,63.5442 1473.64,63.5442 1473.65,63.5442 1473.66,63.5442 1473.67,63.5442 1473.68,63.5442 1473.69,63.5442 1473.7,63.5442 1473.71,63.5442 1473.72,63.5442 1473.73,63.5442 1473.74,63.5442 1473.75,63.5442 1473.75,63.5442 1473.76,63.5442 1473.77,63.5442 1473.78,63.5442 1473.79,63.5442 1473.8,63.5442 1473.81,63.5442 1473.82,63.5442 1473.83,63.5442 1473.84,63.5442 1473.85,63.5442 1473.86,63.5442 1473.86,63.5442 1473.87,63.5442 1473.88,63.5442 1473.89,63.5442 1473.9,63.5442 1473.91,63.5442 1473.92,63.5442 1473.93,63.5442 1473.94,63.5442 1473.95,63.5442 1473.96,63.5442 1473.97,63.5442 1473.97,63.5442 1473.98,63.5442 1473.99,63.5442 1474,63.5442 1474.01,63.5442 1474.02,63.5442 1474.03,63.5442 1474.04,63.5442 1474.05,63.5442 1474.06,63.5442 1474.07,63.5442 1474.08,63.5442 1474.09,63.5442 1474.09,63.5442 1474.1,63.5442 1474.11,63.5442 1474.12,63.5442 1474.13,63.5442 1474.14,63.5442 1474.15,63.5442 1474.16,63.5442 1474.17,63.5442 1474.18,63.5442 1474.19,63.5442 1474.2,63.5442 1474.2,63.5442 1474.21,63.5442 1474.22,63.5442 1474.23,63.5442 1474.24,63.5442 1474.25,63.5442 1474.26,63.5442 1474.27,63.5442 1474.28,63.5442 1474.29,63.5442 1474.3,63.5442 1474.31,63.5442 1474.31,63.5442 1474.32,63.5442 1474.33,63.5442 1474.34,63.5442 1474.35,63.5442 1474.36,63.5442 1474.37,63.5442 1474.38,63.5442 1474.39,63.5442 1474.4,63.5442 1474.41,63.5442 1474.42,63.5442 1474.43,63.5442 1474.43,63.5442 1474.44,63.5442 1474.45,63.5442 1474.46,63.5442 1474.47,63.5442 1474.48,63.5442 1474.49,63.5442 1474.5,63.5442 1474.51,63.5442 1474.52,63.5442 1474.53,63.5442 1474.54,63.5442 1474.54,63.5442 1474.55,63.5442 1474.56,63.5442 1474.57,63.5442 1474.58,63.5442 1474.59,63.5442 1474.6,63.5442 1474.61,63.5442 1474.62,63.5442 1474.63,63.5442 1474.64,63.5442 1474.65,63.5442 1474.65,63.5442 1474.66,63.5442 1474.67,63.5442 1474.68,63.5442 1474.69,63.5442 1474.7,63.5442 1474.71,63.5442 1474.72,63.5442 1474.73,63.5442 1474.74,63.5442 1474.75,63.5442 1474.76,63.5442 1474.77,63.5442 1474.77,63.5442 1474.78,63.5442 1474.79,63.5442 1474.8,63.5442 1474.81,63.5442 1474.82,63.5442 1474.83,63.5442 1474.84,63.5442 1474.85,63.5442 1474.86,63.5442 1474.87,63.5442 1474.88,63.5442 1474.88,63.5442 1474.89,63.5442 1474.9,63.5442 1474.91,63.5442 1474.92,63.5442 1474.93,63.5442 1474.94,63.5442 1474.95,63.5442 1474.96,63.5442 1474.97,63.5442 1474.98,63.5442 1474.99,63.5442 1474.99,63.5442 1475,63.5442 1475.01,63.5442 1475.02,63.5442 1475.03,63.5442 1475.04,63.5442 1475.05,63.5442 1475.06,63.5442 1475.07,63.5442 1475.08,63.5442 1475.09,63.5442 1475.1,63.5442 1475.11,63.5442 1475.11,63.5442 1475.12,63.5442 1475.13,63.5442 1475.14,63.5442 1475.15,63.5442 1475.16,63.5442 1475.17,63.5442 1475.18,63.5442 1475.19,63.5442 1475.2,63.5442 1475.21,63.5442 1475.22,63.5442 1475.22,63.5442 1475.23,63.5442 1475.24,63.5442 1475.25,63.5442 1475.26,63.5442 1475.27,63.5442 1475.28,63.5442 1475.29,63.5442 1475.3,63.5442 1475.31,63.5442 1475.32,63.5442 1475.33,63.5442 1475.33,63.5442 1475.34,63.5442 1475.35,63.5442 1475.36,63.5442 1475.37,63.5442 1475.38,63.5442 1475.39,63.5442 1475.4,63.5442 1475.41,63.5442 1475.42,63.5442 1475.43,63.5442 1475.44,63.5442 1475.45,63.5442 1475.45,63.5442 1475.46,63.5442 1475.47,63.5442 1475.48,63.5442 1475.49,63.5442 1475.5,63.5442 1475.51,63.5442 1475.52,63.5442 1475.53,63.5442 1475.54,63.5442 1475.55,63.5442 1475.56,63.5442 1475.56,63.5442 1475.57,63.5442 1475.58,63.5442 1475.59,63.5442 1475.6,63.5442 1475.61,63.5442 1475.62,63.5442 1475.63,63.5442 1475.64,63.5442 1475.65,63.5442 1475.66,63.5442 1475.67,63.5442 1475.67,63.5442 1475.68,63.5442 1475.69,63.5442 1475.7,63.5442 1475.71,63.5442 1475.72,63.5442 1475.73,63.5442 1475.74,63.5442 1475.75,63.5442 1475.76,63.5442 1475.77,63.5442 1475.78,63.5442 1475.79,63.5442 1475.79,63.5442 1475.8,63.5442 1475.81,63.5442 1475.82,63.5442 1475.83,63.5442 1475.84,63.5442 1475.85,63.5442 1475.86,63.5442 1475.87,63.5442 1475.88,63.5442 1475.89,63.5442 1475.9,63.5442 1475.9,63.5442 1475.91,63.5442 1475.92,63.5442 1475.93,63.5442 1475.94,63.5442 1475.95,63.5442 1475.96,63.5442 1475.97,63.5442 1475.98,63.5442 1475.99,63.5442 1476,63.5442 1476.01,63.5442 1476.01,63.5442 1476.02,63.5442 1476.03,63.5442 1476.04,63.5442 1476.05,63.5442 1476.06,63.5442 1476.07,63.5442 1476.08,63.5442 1476.09,63.5442 1476.1,63.5442 1476.11,63.5442 1476.12,63.5442 1476.13,63.5442 1476.13,63.5442 1476.14,63.5442 1476.15,63.5442 1476.16,63.5442 1476.17,63.5442 1476.18,63.5442 1476.19,63.5442 1476.2,63.5442 1476.21,63.5442 1476.22,63.5442 1476.23,63.5442 1476.24,63.5442 1476.24,63.5442 1476.25,63.5442 1476.26,63.5442 1476.27,63.5442 1476.28,63.5442 1476.29,63.5442 1476.3,63.5442 1476.31,63.5442 1476.32,63.5442 1476.33,63.5442 1476.34,63.5442 1476.35,63.5442 1476.35,63.5442 1476.36,63.5442 1476.37,63.5442 1476.38,63.5442 1476.39,63.5442 1476.4,63.5442 1476.41,63.5442 1476.42,63.5442 1476.43,63.5442 1476.44,63.5442 1476.45,63.5442 1476.46,63.5442 1476.47,63.5442 1476.47,63.5442 1476.48,63.5442 1476.49,63.5442 1476.5,63.5442 1476.51,63.5442 1476.52,63.5442 1476.53,63.5442 1476.54,63.5442 1476.55,63.5442 1476.56,63.5442 1476.57,63.5442 1476.58,63.5442 1476.58,63.5442 1476.59,63.5442 1476.6,63.5442 1476.61,63.5442 1476.62,63.5442 1476.63,63.5442 1476.64,63.5442 1476.65,63.5442 1476.66,63.5442 1476.67,63.5442 1476.68,63.5442 1476.69,63.5442 1476.69,63.5442 1476.7,63.5442 1476.71,63.5442 1476.72,63.5442 1476.73,63.5442 1476.74,63.5442 1476.75,63.5442 1476.76,63.5442 1476.77,63.5442 1476.78,63.5442 1476.79,63.5442 1476.8,63.5442 1476.81,63.5442 1476.81,63.5442 1476.82,63.5442 1476.83,63.5442 1476.84,63.5442 1476.85,63.5442 1476.86,63.5442 1476.87,63.5442 1476.88,63.5442 1476.89,63.5442 1476.9,63.5442 1476.91,63.5442 1476.92,63.5442 1476.92,63.5442 1476.93,63.5442 1476.94,63.5442 1476.95,63.5442 1476.96,63.5442 1476.97,63.5442 1476.98,63.5442 1476.99,63.5442 1477,63.5442 1477.01,63.5442 1477.02,63.5442 1477.03,63.5442 1477.03,63.5442 1477.04,63.5442 1477.05,63.5442 1477.06,63.5442 1477.07,63.5442 1477.08,63.5442 1477.09,63.5442 1477.1,63.5442 1477.11,63.5442 1477.12,63.5442 1477.13,63.5442 1477.14,63.5442 1477.15,63.5442 1477.15,63.5442 1477.16,63.5442 1477.17,63.5442 1477.18,63.5442 1477.19,63.5442 1477.2,63.5442 1477.21,63.5442 1477.22,63.5442 1477.23,63.5442 1477.24,63.5442 1477.25,63.5442 1477.26,63.5442 1477.26,63.5442 1477.27,63.5442 1477.28,63.5442 1477.29,63.5442 1477.3,63.5442 1477.31,63.5442 1477.32,63.5442 1477.33,63.5442 1477.34,63.5442 1477.35,63.5442 1477.36,63.5442 1477.37,63.5442 1477.37,63.5442 1477.38,63.5442 1477.39,63.5442 1477.4,63.5442 1477.41,63.5442 1477.42,63.5442 1477.43,63.5442 1477.44,63.5442 1477.45,63.5442 1477.46,63.5442 1477.47,63.5442 1477.48,63.5442 1477.49,63.5442 1477.49,63.5442 1477.5,63.5442 1477.51,63.5442 1477.52,63.5442 1477.53,63.5442 1477.54,63.5442 1477.55,63.5442 1477.56,63.5442 1477.57,63.5442 1477.58,63.5442 1477.59,63.5442 1477.6,63.5442 1477.6,63.5442 1477.61,63.5442 1477.62,63.5442 1477.63,63.5442 1477.64,63.5442 1477.65,63.5442 1477.66,63.5442 1477.67,63.5442 1477.68,63.5442 1477.69,63.5442 1477.7,63.5442 1477.71,63.5442 1477.71,63.5442 1477.72,63.5442 1477.73,63.5442 1477.74,63.5442 1477.75,63.5442 1477.76,63.5442 1477.77,63.5442 1477.78,63.5442 1477.79,63.5442 1477.8,63.5442 1477.81,63.5442 1477.82,63.5442 1477.83,63.5442 1477.83,63.5442 1477.84,63.5442 1477.85,63.5442 1477.86,63.5442 1477.87,63.5442 1477.88,63.5442 1477.89,63.5442 1477.9,63.5442 1477.91,63.5442 1477.92,63.5442 1477.93,63.5442 1477.94,63.5442 1477.94,63.5442 1477.95,63.5442 1477.96,63.5442 1477.97,63.5442 1477.98,63.5442 1477.99,63.5442 1478,63.5442 1478.01,63.5442 1478.02,63.5442 1478.03,63.5442 1478.04,63.5442 1478.05,63.5442 1478.05,63.5442 1478.06,63.5442 1478.07,63.5442 1478.08,63.5442 1478.09,63.5442 1478.1,63.5442 1478.11,63.5442 1478.12,63.5442 1478.13,63.5442 1478.14,63.5442 1478.15,63.5442 1478.16,63.5442 1478.17,63.5442 1478.17,63.5442 1478.18,63.5442 1478.19,63.5442 1478.2,63.5442 1478.21,63.5442 1478.22,63.5442 1478.23,63.5442 1478.24,63.5442 1478.25,63.5442 1478.26,63.5442 1478.27,63.5442 1478.28,63.5442 1478.28,63.5442 1478.29,63.5442 1478.3,63.5442 1478.31,63.5442 1478.32,63.5442 1478.33,63.5442 1478.34,63.5442 1478.35,63.5442 1478.36,63.5442 1478.37,63.5442 1478.38,63.5442 1478.39,63.5442 1478.39,63.5442 1478.4,63.5442 1478.41,63.5442 1478.42,63.5442 1478.43,63.5442 1478.44,63.5442 1478.45,63.5442 1478.46,63.5442 1478.47,63.5442 1478.48,63.5442 1478.49,63.5442 1478.5,63.5442 1478.51,63.5442 1478.51,63.5442 1478.52,63.5442 1478.53,63.5442 1478.54,63.5442 1478.55,63.5442 1478.56,63.5442 1478.57,63.5442 1478.58,63.5442 1478.59,63.5442 1478.6,63.5442 1478.61,63.5442 1478.62,63.5442 1478.62,63.5442 1478.63,63.5442 1478.64,63.5442 1478.65,63.5442 1478.66,63.5442 1478.67,63.5442 1478.68,63.5442 1478.69,63.5442 1478.7,63.5442 1478.71,63.5442 1478.72,63.5442 1478.73,63.5442 1478.73,63.5442 1478.74,63.5442 1478.75,63.5442 1478.76,63.5442 1478.77,63.5442 1478.78,63.5442 1478.79,63.5442 1478.8,63.5442 1478.81,63.5442 1478.82,63.5442 1478.83,63.5442 1478.84,63.5442 1478.85,63.5442 1478.85,63.5442 1478.86,63.5442 1478.87,63.5442 1478.88,63.5442 1478.89,63.5442 1478.9,63.5442 1478.91,63.5442 1478.92,63.5442 1478.93,63.5442 1478.94,63.5442 1478.95,63.5442 1478.96,63.5442 1478.96,63.5442 1478.97,63.5442 1478.98,63.5442 1478.99,63.5442 1479,63.5442 1479.01,63.5442 1479.02,63.5442 1479.03,63.5442 1479.04,63.5442 1479.05,63.5442 1479.06,63.5442 1479.07,63.5442 1479.07,63.5442 1479.08,63.5442 1479.09,63.5442 1479.1,63.5442 1479.11,63.5442 1479.12,63.5442 1479.13,63.5442 1479.14,63.5442 1479.15,63.5442 1479.16,63.5442 1479.17,63.5442 1479.18,63.5442 1479.19,63.5442 1479.19,63.5442 1479.2,63.5442 1479.21,63.5442 1479.22,63.5442 1479.23,63.5442 1479.24,63.5442 1479.25,63.5442 1479.26,63.5442 1479.27,63.5442 1479.28,63.5442 1479.29,63.5442 1479.3,63.5442 1479.3,63.5442 1479.31,63.5442 1479.32,63.5442 1479.33,63.5442 1479.34,63.5442 1479.35,63.5442 1479.36,63.5442 1479.37,63.5442 1479.38,63.5442 1479.39,63.5442 1479.4,63.5442 1479.41,63.5442 1479.41,63.5442 1479.42,63.5442 1479.43,63.5442 1479.44,63.5442 1479.45,63.5442 1479.46,63.5442 1479.47,63.5442 1479.48,63.5442 1479.49,63.5442 1479.5,63.5442 1479.51,63.5442 1479.52,63.5442 1479.53,63.5442 1479.53,63.5442 1479.54,63.5442 1479.55,63.5442 1479.56,63.5442 1479.57,63.5442 1479.58,63.5442 1479.59,63.5442 1479.6,63.5442 1479.61,63.5442 1479.62,63.5442 1479.63,63.5442 1479.64,63.5442 1479.64,63.5442 1479.65,63.5442 1479.66,63.5442 1479.67,63.5442 1479.68,63.5442 1479.69,63.5442 1479.7,63.5442 1479.71,63.5442 1479.72,63.5442 1479.73,63.5442 1479.74,63.5442 1479.75,63.5442 1479.75,63.5442 1479.76,63.5442 1479.77,63.5442 1479.78,63.5442 1479.79,63.5442 1479.8,63.5442 1479.81,63.5442 1479.82,63.5442 1479.83,63.5442 1479.84,63.5442 1479.85,63.5442 1479.86,63.5442 1479.87,63.5442 1479.87,63.5442 1479.88,63.5442 1479.89,63.5442 1479.9,63.5442 1479.91,63.5442 1479.92,63.5442 1479.93,63.5442 1479.94,63.5442 1479.95,63.5442 1479.96,63.5442 1479.97,63.5442 1479.98,63.5442 1479.98,63.5442 1479.99,63.5442 1480,63.5442 1480.01,63.5442 1480.02,63.5442 1480.03,63.5442 1480.04,63.5442 1480.05,63.5442 1480.06,63.5442 1480.07,63.5442 1480.08,63.5442 1480.09,63.5442 1480.09,63.5442 1480.1,63.5442 1480.11,63.5442 1480.12,63.5442 1480.13,63.5442 1480.14,63.5442 1480.15,63.5442 1480.16,63.5442 1480.17,63.5442 1480.18,63.5442 1480.19,63.5442 1480.2,63.5442 1480.21,63.5442 1480.21,63.5442 1480.22,63.5442 1480.23,63.5442 1480.24,63.5442 1480.25,63.5442 1480.26,63.5442 1480.27,63.5442 1480.28,63.5442 1480.29,63.5442 1480.3,63.5442 1480.31,63.5442 1480.32,63.5442 1480.32,63.5442 1480.33,63.5442 1480.34,63.5442 1480.35,63.5442 1480.36,63.5442 1480.37,63.5442 1480.38,63.5442 1480.39,63.5442 1480.4,63.5442 1480.41,63.5442 1480.42,63.5442 1480.43,63.5442 1480.43,63.5442 1480.44,63.5442 1480.45,63.5442 1480.46,63.5442 1480.47,63.5442 1480.48,63.5442 1480.49,63.5442 1480.5,63.5442 1480.51,63.5442 1480.52,63.5442 1480.53,63.5442 1480.54,63.5442 1480.55,63.5442 1480.55,63.5442 1480.56,63.5442 1480.57,63.5442 1480.58,63.5442 1480.59,63.5442 1480.6,63.5442 1480.61,63.5442 1480.62,63.5442 1480.63,63.5442 1480.64,63.5442 1480.65,63.5442 1480.66,63.5442 1480.66,63.5442 1480.67,63.5442 1480.68,63.5442 1480.69,63.5442 1480.7,63.5442 1480.71,63.5442 1480.72,63.5442 1480.73,63.5442 1480.74,63.5442 1480.75,63.5442 1480.76,63.5442 1480.77,63.5442 1480.77,63.5442 1480.78,63.5442 1480.79,63.5442 1480.8,63.5442 1480.81,63.5442 1480.82,63.5442 1480.83,63.5442 1480.84,63.5442 1480.85,63.5442 1480.86,63.5442 1480.87,63.5442 1480.88,63.5442 1480.89,63.5442 1480.89,63.5442 1480.9,63.5442 1480.91,63.5442 1480.92,63.5442 1480.93,63.5442 1480.94,63.5442 1480.95,63.5442 1480.96,63.5442 1480.97,63.5442 1480.98,63.5442 1480.99,63.5442 1481,63.5442 1481,63.5442 1481.01,63.5442 1481.02,63.5442 1481.03,63.5442 1481.04,63.5442 1481.05,63.5442 1481.06,63.5442 1481.07,63.5442 1481.08,63.5442 1481.09,63.5442 1481.1,63.5442 1481.11,63.5442 1481.11,63.5442 1481.12,63.5442 1481.13,63.5442 1481.14,63.5442 1481.15,63.5442 1481.16,63.5442 1481.17,63.5442 1481.18,63.5442 1481.19,63.5442 1481.2,63.5442 1481.21,63.5442 1481.22,63.5442 1481.23,63.5442 1481.23,63.5442 1481.24,63.5442 1481.25,63.5442 1481.26,63.5442 1481.27,63.5442 1481.28,63.5442 1481.29,63.5442 1481.3,63.5442 1481.31,63.5442 1481.32,63.5442 1481.33,63.5442 1481.34,63.5442 1481.34,63.5442 1481.35,63.5442 1481.36,63.5442 1481.37,63.5442 1481.38,63.5442 1481.39,63.5442 1481.4,63.5442 1481.41,63.5442 1481.42,63.5442 1481.43,63.5442 1481.44,63.5442 1481.45,63.5442 1481.45,63.5442 1481.46,63.5442 1481.47,63.5442 1481.48,63.5442 1481.49,63.5442 1481.5,63.5442 1481.51,63.5442 1481.52,63.5442 1481.53,63.5442 1481.54,63.5442 1481.55,63.5442 1481.56,63.5442 1481.57,63.5442 1481.57,63.5442 1481.58,63.5442 1481.59,63.5442 1481.6,63.5442 1481.61,63.5442 1481.62,63.5442 1481.63,63.5442 1481.64,63.5442 1481.65,63.5442 1481.66,63.5442 1481.67,63.5442 1481.68,63.5442 1481.68,63.5442 1481.69,63.5442 1481.7,63.5442 1481.71,63.5442 1481.72,63.5442 1481.73,63.5442 1481.74,63.5442 1481.75,63.5442 1481.76,63.5442 1481.77,63.5442 1481.78,63.5442 1481.79,63.5442 1481.8,63.5442 1481.8,63.5442 1481.81,63.5442 1481.82,63.5442 1481.83,63.5442 1481.84,63.5442 1481.85,63.5442 1481.86,63.5442 1481.87,63.5442 1481.88,63.5442 1481.89,63.5442 1481.9,63.5442 1481.91,63.5442 1481.91,63.5442 1481.92,63.5442 1481.93,63.5442 1481.94,63.5442 1481.95,63.5442 1481.96,63.5442 1481.97,63.5442 1481.98,63.5442 1481.99,63.5442 1482,63.5442 1482.01,63.5442 1482.02,63.5442 1482.02,63.5442 1482.03,63.5442 1482.04,63.5442 1482.05,63.5442 1482.06,63.5442 1482.07,63.5442 1482.08,63.5442 1482.09,63.5442 1482.1,63.5442 1482.11,63.5442 1482.12,63.5442 1482.13,63.5442 1482.14,63.5442 1482.14,63.5442 1482.15,63.5442 1482.16,63.5442 1482.17,63.5442 1482.18,63.5442 1482.19,63.5442 1482.2,63.5442 1482.21,63.5442 1482.22,63.5442 1482.23,63.5442 1482.24,63.5442 1482.25,63.5442 1482.25,63.5442 1482.26,63.5442 1482.27,63.5442 1482.28,63.5442 1482.29,63.5442 1482.3,63.5442 1482.31,63.5442 1482.32,63.5442 1482.33,63.5442 1482.34,63.5442 1482.35,63.5442 1482.36,63.5442 1482.36,63.5442 1482.37,63.5442 1482.38,63.5442 1482.39,63.5442 1482.4,63.5442 1482.41,63.5442 1482.42,63.5442 1482.43,63.5442 1482.44,63.5442 1482.45,63.5442 1482.46,63.5442 1482.47,63.5442 1482.48,63.5442 1482.48,63.5442 1482.49,63.5442 1482.5,63.5442 1482.51,63.5442 1482.52,63.5442 1482.53,63.5442 1482.54,63.5442 1482.55,63.5442 1482.56,63.5442 1482.57,63.5442 1482.58,63.5442 1482.59,63.5442 1482.59,63.5442 1482.6,63.5442 1482.61,63.5442 1482.62,63.5442 1482.63,63.5442 1482.64,63.5442 1482.65,63.5442 1482.66,63.5442 1482.67,63.5442 1482.68,63.5442 1482.69,63.5442 1482.7,63.5442 1482.7,63.5442 1482.71,63.5442 1482.72,63.5442 1482.73,63.5442 1482.74,63.5442 1482.75,63.5442 1482.76,63.5442 1482.77,63.5442 1482.78,63.5442 1482.79,63.5442 1482.8,63.5442 1482.81,63.5442 1482.82,63.5442 1482.82,63.5442 1482.83,63.5442 1482.84,63.5442 1482.85,63.5442 1482.86,63.5442 1482.87,63.5442 1482.88,63.5442 1482.89,63.5442 1482.9,63.5442 1482.91,63.5442 1482.92,63.5442 1482.93,63.5442 1482.93,63.5442 1482.94,63.5442 1482.95,63.5442 1482.96,63.5442 1482.97,63.5442 1482.98,63.5442 1482.99,63.5442 1483,63.5442 1483.01,63.5442 1483.02,63.5442 1483.03,63.5442 1483.04,63.5442 1483.04,63.5442 1483.05,63.5442 1483.06,63.5442 1483.07,63.5442 1483.08,63.5442 1483.09,63.5442 1483.1,63.5442 1483.11,63.5442 1483.12,63.5442 1483.13,63.5442 1483.14,63.5442 1483.15,63.5442 1483.16,63.5442 1483.16,63.5442 1483.17,63.5442 1483.18,63.5442 1483.19,63.5442 1483.2,63.5442 1483.21,63.5442 1483.22,63.5442 1483.23,63.5442 1483.24,63.5442 1483.25,63.5442 1483.26,63.5442 1483.27,63.5442 1483.27,63.5442 1483.28,63.5442 1483.29,63.5442 1483.3,63.5442 1483.31,63.5442 1483.32,63.5442 1483.33,63.5442 1483.34,63.5442 1483.35,63.5442 1483.36,63.5442 1483.37,63.5442 1483.38,63.5442 1483.38,63.5442 1483.39,63.5442 1483.4,63.5442 1483.41,63.5442 1483.42,63.5442 1483.43,63.5442 1483.44,63.5442 1483.45,63.5442 1483.46,63.5442 1483.47,63.5442 1483.48,63.5442 1483.49,63.5442 1483.5,63.5442 1483.5,63.5442 1483.51,63.5442 1483.52,63.5442 1483.53,63.5442 1483.54,63.5442 1483.55,63.5442 1483.56,63.5442 1483.57,63.5442 1483.58,63.5442 1483.59,63.5442 1483.6,63.5442 1483.61,63.5442 1483.61,63.5442 1483.62,63.5442 1483.63,63.5442 1483.64,63.5442 1483.65,63.5442 1483.66,63.5442 1483.67,63.5442 1483.68,63.5442 1483.69,63.5442 1483.7,63.5442 1483.71,63.5442 1483.72,63.5442 1483.72,63.5442 1483.73,63.5442 1483.74,63.5442 1483.75,63.5442 1483.76,63.5442 1483.77,63.5442 1483.78,63.5442 1483.79,63.5442 1483.8,63.5442 1483.81,63.5442 1483.82,63.5442 1483.83,63.5442 1483.84,63.5442 1483.84,63.5442 1483.85,63.5442 1483.86,63.5442 1483.87,63.5442 1483.88,63.5442 1483.89,63.5442 1483.9,63.5442 1483.91,63.5442 1483.92,63.5442 1483.93,63.5442 1483.94,63.5442 1483.95,63.5442 1483.95,63.5442 1483.96,63.5442 1483.97,63.5442 1483.98,63.5442 1483.99,63.5442 1484,63.5442 1484.01,63.5442 1484.02,63.5442 1484.03,63.5442 1484.04,63.5442 1484.05,63.5442 1484.06,63.5442 1484.06,63.5442 1484.07,63.5442 1484.08,63.5442 1484.09,63.5442 1484.1,63.5442 1484.11,63.5442 1484.12,63.5442 1484.13,63.5442 1484.14,63.5442 1484.15,63.5442 1484.16,63.5442 1484.17,63.5442 1484.18,63.5442 1484.18,63.5442 1484.19,63.5442 1484.2,63.5442 1484.21,63.5442 1484.22,63.5442 1484.23,63.5442 1484.24,63.5442 1484.25,63.5442 1484.26,63.5442 1484.27,63.5442 1484.28,63.5442 1484.29,63.5442 1484.29,63.5442 1484.3,63.5442 1484.31,63.5442 1484.32,63.5442 1484.33,63.5442 1484.34,63.5442 1484.35,63.5442 1484.36,63.5442 1484.37,63.5442 1484.38,63.5442 1484.39,63.5442 1484.4,63.5442 1484.4,63.5442 1484.41,63.5442 1484.42,63.5442 1484.43,63.5442 1484.44,63.5442 1484.45,63.5442 1484.46,63.5442 1484.47,63.5442 1484.48,63.5442 1484.49,63.5442 1484.5,63.5442 1484.51,63.5442 1484.52,63.5442 1484.52,63.5442 1484.53,63.5442 1484.54,63.5442 1484.55,63.5442 1484.56,63.5442 1484.57,63.5442 1484.58,63.5442 1484.59,63.5442 1484.6,63.5442 1484.61,63.5442 1484.62,63.5442 1484.63,63.5442 1484.63,63.5442 1484.64,63.5442 1484.65,63.5442 1484.66,63.5442 1484.67,63.5442 1484.68,63.5442 1484.69,63.5442 1484.7,63.5442 1484.71,63.5442 1484.72,63.5442 1484.73,63.5442 1484.74,63.5442 1484.74,63.5442 1484.75,63.5442 1484.76,63.5442 1484.77,63.5442 1484.78,63.5442 1484.79,63.5442 1484.8,63.5442 1484.81,63.5442 1484.82,63.5442 1484.83,63.5442 1484.84,63.5442 1484.85,63.5442 1484.86,63.5442 1484.86,63.5442 1484.87,63.5442 1484.88,63.5442 1484.89,63.5442 1484.9,63.5442 1484.91,63.5442 1484.92,63.5442 1484.93,63.5442 1484.94,63.5442 1484.95,63.5442 1484.96,63.5442 1484.97,63.5442 1484.97,63.5442 1484.98,63.5442 1484.99,63.5442 1485,63.5442 1485.01,63.5442 1485.02,63.5442 1485.03,63.5442 1485.04,63.5442 1485.05,63.5442 1485.06,63.5442 1485.07,63.5442 1485.08,63.5442 1485.08,63.5442 1485.09,63.5442 1485.1,63.5442 1485.11,63.5442 1485.12,63.5442 1485.13,63.5442 1485.14,63.5442 1485.15,63.5442 1485.16,63.5442 1485.17,63.5442 1485.18,63.5442 1485.19,63.5442 1485.2,63.5442 1485.2,63.5442 1485.21,63.5442 1485.22,63.5442 1485.23,63.5442 1485.24,63.5442 1485.25,63.5442 1485.26,63.5442 1485.27,63.5442 1485.28,63.5442 1485.29,63.5442 1485.3,63.5442 1485.31,63.5442 1485.31,63.5442 1485.32,63.5442 1485.33,63.5442 1485.34,63.5442 1485.35,63.5442 1485.36,63.5442 1485.37,63.5442 1485.38,63.5442 1485.39,63.5442 1485.4,63.5442 1485.41,63.5442 1485.42,63.5442 1485.42,63.5442 1485.43,63.5442 1485.44,63.5442 1485.45,63.5442 1485.46,63.5442 1485.47,63.5442 1485.48,63.5442 1485.49,63.5442 1485.5,63.5442 1485.51,63.5442 1485.52,63.5442 1485.53,63.5442 1485.54,63.5442 1485.54,63.5442 1485.55,63.5442 1485.56,63.5442 1485.57,63.5442 1485.58,63.5442 1485.59,63.5442 1485.6,63.5442 1485.61,63.5442 1485.62,63.5442 1485.63,63.5442 1485.64,63.5442 1485.65,63.5442 1485.65,63.5442 1485.66,63.5442 1485.67,63.5442 1485.68,63.5442 1485.69,63.5442 1485.7,63.5442 1485.71,63.5442 1485.72,63.5442 1485.73,63.5442 1485.74,63.5442 1485.75,63.5442 1485.76,63.5442 1485.76,63.5442 1485.77,63.5442 1485.78,63.5442 1485.79,63.5442 1485.8,63.5442 1485.81,63.5442 1485.82,63.5442 1485.83,63.5442 1485.84,63.5442 1485.85,63.5442 1485.86,63.5442 1485.87,63.5442 1485.88,63.5442 1485.88,63.5442 1485.89,63.5442 1485.9,63.5442 1485.91,63.5442 1485.92,63.5442 1485.93,63.5442 1485.94,63.5442 1485.95,63.5442 1485.96,63.5442 1485.97,63.5442 1485.98,63.5442 1485.99,63.5442 1485.99,63.5442 1486,63.5442 1486.01,63.5442 1486.02,63.5442 1486.03,63.5442 1486.04,63.5442 1486.05,63.5442 1486.06,63.5442 1486.07,63.5442 1486.08,63.5442 1486.09,63.5442 1486.1,63.5442 1486.1,63.5442 1486.11,63.5442 1486.12,63.5442 1486.13,63.5442 1486.14,63.5442 1486.15,63.5442 1486.16,63.5442 1486.17,63.5442 1486.18,63.5442 1486.19,63.5442 1486.2,63.5442 1486.21,63.5442 1486.22,63.5442 1486.22,63.5442 1486.23,63.5442 1486.24,63.5442 1486.25,63.5442 1486.26,63.5442 1486.27,63.5442 1486.28,63.5442 1486.29,63.5442 1486.3,63.5442 1486.31,63.5442 1486.32,63.5442 1486.33,63.5442 1486.33,63.5442 1486.34,63.5442 1486.35,63.5442 1486.36,63.5442 1486.37,63.5442 1486.38,63.5442 1486.39,63.5442 1486.4,63.5442 1486.41,63.5442 1486.42,63.5442 1486.43,63.5442 1486.44,63.5442 1486.44,63.5442 1486.45,63.5442 1486.46,63.5442 1486.47,63.5442 1486.48,63.5442 1486.49,63.5442 1486.5,63.5442 1486.51,63.5442 1486.52,63.5442 1486.53,63.5442 1486.54,63.5442 1486.55,63.5442 1486.56,63.5442 1486.56,63.5442 1486.57,63.5442 1486.58,63.5442 1486.59,63.5442 1486.6,63.5442 1486.61,63.5442 1486.62,63.5442 1486.63,63.5442 1486.64,63.5442 1486.65,63.5442 1486.66,63.5442 1486.67,63.5442 1486.67,63.5442 1486.68,63.5442 1486.69,63.5442 1486.7,63.5442 1486.71,63.5442 1486.72,63.5442 1486.73,63.5442 1486.74,63.5442 1486.75,63.5442 1486.76,63.5442 1486.77,63.5442 1486.78,63.5442 1486.78,63.5442 1486.79,63.5442 1486.8,63.5442 1486.81,63.5442 1486.82,63.5442 1486.83,63.5442 1486.84,63.5442 1486.85,63.5442 1486.86,63.5442 1486.87,63.5442 1486.88,63.5442 1486.89,63.5442 1486.9,63.5442 1486.9,63.5442 1486.91,63.5442 1486.92,63.5442 1486.93,63.5442 1486.94,63.5442 1486.95,63.5442 1486.96,63.5442 1486.97,63.5442 1486.98,63.5442 1486.99,63.5442 1487,63.5442 1487.01,63.5442 1487.01,63.5442 1487.02,63.5442 1487.03,63.5442 1487.04,63.5442 1487.05,63.5442 1487.06,63.5442 1487.07,63.5442 1487.08,63.5442 1487.09,63.5442 1487.1,63.5442 1487.11,63.5442 1487.12,63.5442 1487.12,63.5442 1487.13,63.5442 1487.14,63.5442 1487.15,63.5442 1487.16,63.5442 1487.17,63.5442 1487.18,63.5442 1487.19,63.5442 1487.2,63.5442 1487.21,63.5442 1487.22,63.5442 1487.23,63.5442 1487.24,63.5442 1487.24,63.5442 1487.25,63.5442 1487.26,63.5442 1487.27,63.5442 1487.28,63.5442 1487.29,63.5442 1487.3,63.5442 1487.31,63.5442 1487.32,63.5442 1487.33,63.5442 1487.34,63.5442 1487.35,63.5442 1487.35,63.5442 1487.36,63.5442 1487.37,63.5442 1487.38,63.5442 1487.39,63.5442 1487.4,63.5442 1487.41,63.5442 1487.42,63.5442 1487.43,63.5442 1487.44,63.5442 1487.45,63.5442 1487.46,63.5442 1487.46,63.5442 1487.47,63.5442 1487.48,63.5442 1487.49,63.5442 1487.5,63.5442 1487.51,63.5442 1487.52,63.5442 1487.53,63.5442 1487.54,63.5442 1487.55,63.5442 1487.56,63.5442 1487.57,63.5442 1487.58,63.5442 1487.58,63.5442 1487.59,63.5442 1487.6,63.5442 1487.61,63.5442 1487.62,63.5442 1487.63,63.5442 1487.64,63.5442 1487.65,63.5442 1487.66,63.5442 1487.67,63.5442 1487.68,63.5442 1487.69,63.5442 1487.69,63.5442 1487.7,63.5442 1487.71,63.5442 1487.72,63.5442 1487.73,63.5442 1487.74,63.5442 1487.75,63.5442 1487.76,63.5442 1487.77,63.5442 1487.78,63.5442 1487.79,63.5442 1487.8,63.5442 1487.8,63.5442 1487.81,63.5442 1487.82,63.5442 1487.83,63.5442 1487.84,63.5442 1487.85,63.5442 1487.86,63.5442 1487.87,63.5442 1487.88,63.5442 1487.89,63.5442 1487.9,63.5442 1487.91,63.5442 1487.92,63.5442 1487.92,63.5442 1487.93,63.5442 1487.94,63.5442 1487.95,63.5442 1487.96,63.5442 1487.97,63.5442 1487.98,63.5442 1487.99,63.5442 1488,63.5442 1488.01,63.5442 1488.02,63.5442 1488.03,63.5442 1488.03,63.5442 1488.04,63.5442 1488.05,63.5442 1488.06,63.5442 1488.07,63.5442 1488.08,63.5442 1488.09,63.5442 1488.1,63.5442 1488.11,63.5442 1488.12,63.5442 1488.13,63.5442 1488.14,63.5442 1488.14,63.5442 1488.15,63.5442 1488.16,63.5442 1488.17,63.5442 1488.18,63.5442 1488.19,63.5442 1488.2,63.5442 1488.21,63.5442 1488.22,63.5442 1488.23,63.5442 1488.24,63.5442 1488.25,63.5442 1488.26,63.5442 1488.26,63.5442 1488.27,63.5442 1488.28,63.5442 1488.29,63.5442 1488.3,63.5442 1488.31,63.5442 1488.32,63.5442 1488.33,63.5442 1488.34,63.5442 1488.35,63.5442 1488.36,63.5442 1488.37,63.5442 1488.37,63.5442 1488.38,63.5442 1488.39,63.5442 1488.4,63.5442 1488.41,63.5442 1488.42,63.5442 1488.43,63.5442 1488.44,63.5442 1488.45,63.5442 1488.46,63.5442 1488.47,63.5442 1488.48,63.5442 1488.48,63.5442 1488.49,63.5442 1488.5,63.5442 1488.51,63.5442 1488.52,63.5442 1488.53,63.5442 1488.54,63.5442 1488.55,63.5442 1488.56,63.5442 1488.57,63.5442 1488.58,63.5442 1488.59,63.5442 1488.6,63.5442 1488.6,63.5442 1488.61,63.5442 1488.62,63.5442 1488.63,63.5442 1488.64,63.5442 1488.65,63.5442 1488.66,63.5442 1488.67,63.5442 1488.68,63.5442 1488.69,63.5442 1488.7,63.5442 1488.71,63.5442 1488.71,63.5442 1488.72,63.5442 1488.73,63.5442 1488.74,63.5442 1488.75,63.5442 1488.76,63.5442 1488.77,63.5442 1488.78,63.5442 1488.79,63.5442 1488.8,63.5442 1488.81,63.5442 1488.82,63.5442 1488.82,63.5442 1488.83,63.5442 1488.84,63.5442 1488.85,63.5442 1488.86,63.5442 1488.87,63.5442 1488.88,63.5442 1488.89,63.5442 1488.9,63.5442 1488.91,63.5442 1488.92,63.5442 1488.93,63.5442 1488.94,63.5442 1488.94,63.5442 1488.95,63.5442 1488.96,63.5442 1488.97,63.5442 1488.98,63.5442 1488.99,63.5442 1489,63.5442 1489.01,63.5442 1489.02,63.5442 1489.03,63.5442 1489.04,63.5442 1489.05,63.5442 1489.05,63.5442 1489.06,63.5442 1489.07,63.5442 1489.08,63.5442 1489.09,63.5442 1489.1,63.5442 1489.11,63.5442 1489.12,63.5442 1489.13,63.5442 1489.14,63.5442 1489.15,63.5442 1489.16,63.5442 1489.16,63.5442 1489.17,63.5442 1489.18,63.5442 1489.19,63.5442 1489.2,63.5442 1489.21,63.5442 1489.22,63.5442 1489.23,63.5442 1489.24,63.5442 1489.25,63.5442 1489.26,63.5442 1489.27,63.5442 1489.28,63.5442 1489.28,63.5442 1489.29,63.5442 1489.3,63.5442 1489.31,63.5442 1489.32,63.5442 1489.33,63.5442 1489.34,63.5442 1489.35,63.5442 1489.36,63.5442 1489.37,63.5442 1489.38,63.5442 1489.39,63.5442 1489.39,63.5442 1489.4,63.5442 1489.41,63.5442 1489.42,63.5442 1489.43,63.5442 1489.44,63.5442 1489.45,63.5442 1489.46,63.5442 1489.47,63.5442 1489.48,63.5442 1489.49,63.5442 1489.5,63.5442 1489.5,63.5442 1489.51,63.5442 1489.52,63.5442 1489.53,63.5442 1489.54,63.5442 1489.55,63.5442 1489.56,63.5442 1489.57,63.5442 1489.58,63.5442 1489.59,63.5442 1489.6,63.5442 1489.61,63.5442 1489.62,63.5442 1489.62,63.5442 1489.63,63.5442 1489.64,63.5442 1489.65,63.5442 1489.66,63.5442 1489.67,63.5442 1489.68,63.5442 1489.69,63.5442 1489.7,63.5442 1489.71,63.5442 1489.72,63.5442 1489.73,63.5442 1489.73,63.5442 1489.74,63.5442 1489.75,63.5442 1489.76,63.5442 1489.77,63.5442 1489.78,63.5442 1489.79,63.5442 1489.8,63.5442 1489.81,63.5442 1489.82,63.5442 1489.83,63.5442 1489.84,63.5442 1489.84,63.5442 1489.85,63.5442 1489.86,63.5442 1489.87,63.5442 1489.88,63.5442 1489.89,63.5442 1489.9,63.5442 1489.91,63.5442 1489.92,63.5442 1489.93,63.5442 1489.94,63.5442 1489.95,63.5442 1489.96,63.5442 1489.96,63.5442 1489.97,63.5442 1489.98,63.5442 1489.99,63.5442 1490,63.5442 1490.01,63.5442 1490.02,63.5442 1490.03,63.5442 1490.04,63.5442 1490.05,63.5442 1490.06,63.5442 1490.07,63.5442 1490.07,63.5442 1490.08,63.5442 1490.09,63.5442 1490.1,63.5442 1490.11,63.5442 1490.12,63.5442 1490.13,63.5442 1490.14,63.5442 1490.15,63.5442 1490.16,63.5442 1490.17,63.5442 1490.18,63.5442 1490.18,63.5442 1490.19,63.5442 1490.2,63.5442 1490.21,63.5442 1490.22,63.5442 1490.23,63.5442 1490.24,63.5442 1490.25,63.5442 1490.26,63.5442 1490.27,63.5442 1490.28,63.5442 1490.29,63.5442 1490.3,63.5442 1490.3,63.5442 1490.31,63.5442 1490.32,63.5442 1490.33,63.5442 1490.34,63.5442 1490.35,63.5442 1490.36,63.5442 1490.37,63.5442 1490.38,63.5442 1490.39,63.5442 1490.4,63.5442 1490.41,63.5442 1490.41,63.5442 1490.42,63.5442 1490.43,63.5442 1490.44,63.5442 1490.45,63.5442 1490.46,63.5442 1490.47,63.5442 1490.48,63.5442 1490.49,63.5442 1490.5,63.5442 1490.51,63.5442 1490.52,63.5442 1490.52,63.5442 1490.53,63.5442 1490.54,63.5442 1490.55,63.5442 1490.56,63.5442 1490.57,63.5442 1490.58,63.5442 1490.59,63.5442 1490.6,63.5442 1490.61,63.5442 1490.62,63.5442 1490.63,63.5442 1490.64,63.5442 1490.64,63.5442 1490.65,63.5442 1490.66,63.5442 1490.67,63.5442 1490.68,63.5442 1490.69,63.5442 1490.7,63.5442 1490.71,63.5442 1490.72,63.5442 1490.73,63.5442 1490.74,63.5442 1490.75,63.5442 1490.75,63.5442 1490.76,63.5442 1490.77,63.5442 1490.78,63.5442 1490.79,63.5442 1490.8,63.5442 1490.81,63.5442 1490.82,63.5442 1490.83,63.5442 1490.84,63.5442 1490.85,63.5442 1490.86,63.5442 1490.86,63.5442 1490.87,63.5442 1490.88,63.5442 1490.89,63.5442 1490.9,63.5442 1490.91,63.5442 1490.92,63.5442 1490.93,63.5442 1490.94,63.5442 1490.95,63.5442 1490.96,63.5442 1490.97,63.5442 1490.98,63.5442 1490.98,63.5442 1490.99,63.5442 1491,63.5442 1491.01,63.5442 1491.02,63.5442 1491.03,63.5442 1491.04,63.5442 1491.05,63.5442 1491.06,63.5442 1491.07,63.5442 1491.08,63.5442 1491.09,63.5442 1491.09,63.5442 1491.1,63.5442 1491.11,63.5442 1491.12,63.5442 1491.13,63.5442 1491.14,63.5442 1491.15,63.5442 1491.16,63.5442 1491.17,63.5442 1491.18,63.5442 1491.19,63.5442 1491.2,63.5442 1491.2,63.5442 1491.21,63.5442 1491.22,63.5442 1491.23,63.5442 1491.24,63.5442 1491.25,63.5442 1491.26,63.5442 1491.27,63.5442 1491.28,63.5442 1491.29,63.5442 1491.3,63.5442 1491.31,63.5442 1491.32,63.5442 1491.32,63.5442 1491.33,63.5442 1491.34,63.5442 1491.35,63.5442 1491.36,63.5442 1491.37,63.5442 1491.38,63.5442 1491.39,63.5442 1491.4,63.5442 1491.41,63.5442 1491.42,63.5442 1491.43,63.5442 1491.43,63.5442 1491.44,63.5442 1491.45,63.5442 1491.46,63.5442 1491.47,63.5442 1491.48,63.5442 1491.49,63.5442 1491.5,63.5442 1491.51,63.5442 1491.52,63.5442 1491.53,63.5442 1491.54,63.5442 1491.54,63.5442 1491.55,63.5442 1491.56,63.5442 1491.57,63.5442 1491.58,63.5442 1491.59,63.5442 1491.6,63.5442 1491.61,63.5442 1491.62,63.5442 1491.63,63.5442 1491.64,63.5442 1491.65,63.5442 1491.66,63.5442 1491.66,63.5442 1491.67,63.5442 1491.68,63.5442 1491.69,63.5442 1491.7,63.5442 1491.71,63.5442 1491.72,63.5442 1491.73,63.5442 1491.74,63.5442 1491.75,63.5442 1491.76,63.5442 1491.77,63.5442 1491.77,63.5442 1491.78,63.5442 1491.79,63.5442 1491.8,63.5442 1491.81,63.5442 1491.82,63.5442 1491.83,63.5442 1491.84,63.5442 1491.85,63.5442 1491.86,63.5442 1491.87,63.5442 1491.88,63.5442 1491.88,63.5442 1491.89,63.5442 1491.9,63.5442 1491.91,63.5442 1491.92,63.5442 1491.93,63.5442 1491.94,63.5442 1491.95,63.5442 1491.96,63.5442 1491.97,63.5442 1491.98,63.5442 1491.99,63.5442 1492,63.5442 1492,63.5442 1492.01,63.5442 1492.02,63.5442 1492.03,63.5442 1492.04,63.5442 1492.05,63.5442 1492.06,63.5442 1492.07,63.5442 1492.08,63.5442 1492.09,63.5442 1492.1,63.5442 1492.11,63.5442 1492.11,63.5442 1492.12,63.5442 1492.13,63.5442 1492.14,63.5442 1492.15,63.5442 1492.16,63.5442 1492.17,63.5442 1492.18,63.5442 1492.19,63.5442 1492.2,63.5442 1492.21,63.5442 1492.22,63.5442 1492.22,63.5442 1492.23,63.5442 1492.24,63.5442 1492.25,63.5442 1492.26,63.5442 1492.27,63.5442 1492.28,63.5442 1492.29,63.5442 1492.3,63.5442 1492.31,63.5442 1492.32,63.5442 1492.33,63.5442 1492.34,63.5442 1492.34,63.5442 1492.35,63.5442 1492.36,63.5442 1492.37,63.5442 1492.38,63.5442 1492.39,63.5442 1492.4,63.5442 1492.41,63.5442 1492.42,63.5442 1492.43,63.5442 1492.44,63.5442 1492.45,63.5442 1492.45,63.5442 1492.46,63.5442 1492.47,63.5442 1492.48,63.5442 1492.49,63.5442 1492.5,63.5442 1492.51,63.5442 1492.52,63.5442 1492.53,63.5442 1492.54,63.5442 1492.55,63.5442 1492.56,63.5442 1492.56,63.5442 1492.57,63.5442 1492.58,63.5442 1492.59,63.5442 1492.6,63.5442 1492.61,63.5442 1492.62,63.5442 1492.63,63.5442 1492.64,63.5442 1492.65,63.5442 1492.66,63.5442 1492.67,63.5442 1492.68,63.5442 1492.68,63.5442 1492.69,63.5442 1492.7,63.5442 1492.71,63.5442 1492.72,63.5442 1492.73,63.5442 1492.74,63.5442 1492.75,63.5442 1492.76,63.5442 1492.77,63.5442 1492.78,63.5442 1492.79,63.5442 1492.79,63.5442 1492.8,63.5442 1492.81,63.5442 1492.82,63.5442 1492.83,63.5442 1492.84,63.5442 1492.85,63.5442 1492.86,63.5442 1492.87,63.5442 1492.88,63.5442 1492.89,63.5442 1492.9,63.5442 1492.9,63.5442 1492.91,63.5442 1492.92,63.5442 1492.93,63.5442 1492.94,63.5442 1492.95,63.5442 1492.96,63.5442 1492.97,63.5442 1492.98,63.5442 1492.99,63.5442 1493,63.5442 1493.01,63.5442 1493.02,63.5442 1493.02,63.5442 1493.03,63.5442 1493.04,63.5442 1493.05,63.5442 1493.06,63.5442 1493.07,63.5442 1493.08,63.5442 1493.09,63.5442 1493.1,63.5442 1493.11,63.5442 1493.12,63.5442 1493.13,63.5442 1493.13,63.5442 1493.14,63.5442 1493.15,63.5442 1493.16,63.5442 1493.17,63.5442 1493.18,63.5442 1493.19,63.5442 1493.2,63.5442 1493.21,63.5442 1493.22,63.5442 1493.23,63.5442 1493.24,63.5442 1493.24,63.5442 1493.25,63.5442 1493.26,63.5442 1493.27,63.5442 1493.28,63.5442 1493.29,63.5442 1493.3,63.5442 1493.31,63.5442 1493.32,63.5442 1493.33,63.5442 1493.34,63.5442 1493.35,63.5442 1493.36,63.5442 1493.36,63.5442 1493.37,63.5442 1493.38,63.5442 1493.39,63.5442 1493.4,63.5442 1493.41,63.5442 1493.42,63.5442 1493.43,63.5442 1493.44,63.5442 1493.45,63.5442 1493.46,63.5442 1493.47,63.5442 1493.47,63.5442 1493.48,63.5442 1493.49,63.5442 1493.5,63.5442 1493.51,63.5442 1493.52,63.5442 1493.53,63.5442 1493.54,63.5442 1493.55,63.5442 1493.56,63.5442 1493.57,63.5442 1493.58,63.5442 1493.58,63.5442 1493.59,63.5442 1493.6,63.5442 1493.61,63.5442 1493.62,63.5442 1493.63,63.5442 1493.64,63.5442 1493.65,63.5442 1493.66,63.5442 1493.67,63.5442 1493.68,63.5442 1493.69,63.5442 1493.7,63.5442 1493.7,63.5442 1493.71,63.5442 1493.72,63.5442 1493.73,63.5442 1493.74,63.5442 1493.75,63.5442 1493.76,63.5442 1493.77,63.5442 1493.78,63.5442 1493.79,63.5442 1493.8,63.5442 1493.81,63.5442 1493.81,63.5442 1493.82,63.5442 1493.83,63.5442 1493.84,63.5442 1493.85,63.5442 1493.86,63.5442 1493.87,63.5442 1493.88,63.5442 1493.89,63.5442 1493.9,63.5442 1493.91,63.5442 1493.92,63.5442 1493.92,63.5442 1493.93,63.5442 1493.94,63.5442 1493.95,63.5442 1493.96,63.5442 1493.97,63.5442 1493.98,63.5442 1493.99,63.5442 1494,63.5442 1494.01,63.5442 1494.02,63.5442 1494.03,63.5442 1494.04,63.5442 1494.04,63.5442 1494.05,63.5442 1494.06,63.5442 1494.07,63.5442 1494.08,63.5442 1494.09,63.5442 1494.1,63.5442 1494.11,63.5442 1494.12,63.5442 1494.13,63.5442 1494.14,63.5442 1494.15,63.5442 1494.15,63.5442 1494.16,63.5442 1494.17,63.5442 1494.18,63.5442 1494.19,63.5442 1494.2,63.5442 1494.21,63.5442 1494.22,63.5442 1494.23,63.5442 1494.24,63.5442 1494.25,63.5442 1494.26,63.5442 1494.26,63.5442 1494.27,63.5442 1494.28,63.5442 1494.29,63.5442 1494.3,63.5442 1494.31,63.5442 1494.32,63.5442 1494.33,63.5442 1494.34,63.5442 1494.35,63.5442 1494.36,63.5442 1494.37,63.5442 1494.38,63.5442 1494.38,63.5442 1494.39,63.5442 1494.4,63.5442 1494.41,63.5442 1494.42,63.5442 1494.43,63.5442 1494.44,63.5442 1494.45,63.5442 1494.46,63.5442 1494.47,63.5442 1494.48,63.5442 1494.49,63.5442 1494.49,63.5442 1494.5,63.5442 1494.51,63.5442 1494.52,63.5442 1494.53,63.5442 1494.54,63.5442 1494.55,63.5442 1494.56,63.5442 1494.57,63.5442 1494.58,63.5442 1494.59,63.5442 1494.6,63.5442 1494.6,63.5442 1494.61,63.5442 1494.62,63.5442 1494.63,63.5442 1494.64,63.5442 1494.65,63.5442 1494.66,63.5442 1494.67,63.5442 1494.68,63.5442 1494.69,63.5442 1494.7,63.5442 1494.71,63.5442 1494.72,63.5442 1494.72,63.5442 1494.73,63.5442 1494.74,63.5442 1494.75,63.5442 1494.76,63.5442 1494.77,63.5442 1494.78,63.5442 1494.79,63.5442 1494.8,63.5442 1494.81,63.5442 1494.82,63.5442 1494.83,63.5442 1494.83,63.5442 1494.84,63.5442 1494.85,63.5442 1494.86,63.5442 1494.87,63.5442 1494.88,63.5442 1494.89,63.5442 1494.9,63.5442 1494.91,63.5442 1494.92,63.5442 1494.93,63.5442 1494.94,63.5442 1494.94,63.5442 1494.95,63.5442 1494.96,63.5442 1494.97,63.5442 1494.98,63.5442 1494.99,63.5442 1495,63.5442 1495.01,63.5442 1495.02,63.5442 1495.03,63.5442 1495.04,63.5442 1495.05,63.5442 1495.06,63.5442 1495.06,63.5442 1495.07,63.5442 1495.08,63.5442 1495.09,63.5442 1495.1,63.5442 1495.11,63.5442 1495.12,63.5442 1495.13,63.5442 1495.14,63.5442 1495.15,63.5442 1495.16,63.5442 1495.17,63.5442 1495.17,63.5442 1495.18,63.5442 1495.19,63.5442 1495.2,63.5442 1495.21,63.5442 1495.22,63.5442 1495.23,63.5442 1495.24,63.5442 1495.25,63.5442 1495.26,63.5442 1495.27,63.5442 1495.28,63.5442 1495.28,63.5442 1495.29,63.5442 1495.3,63.5442 1495.31,63.5442 1495.32,63.5442 1495.33,63.5442 1495.34,63.5442 1495.35,63.5442 1495.36,63.5442 1495.37,63.5442 1495.38,63.5442 1495.39,63.5442 1495.4,63.5442 1495.4,63.5442 1495.41,63.5442 1495.42,63.5442 1495.43,63.5442 1495.44,63.5442 1495.45,63.5442 1495.46,63.5442 1495.47,63.5442 1495.48,63.5442 1495.49,63.5442 1495.5,63.5442 1495.51,63.5442 1495.51,63.5442 1495.52,63.5442 1495.53,63.5442 1495.54,63.5442 1495.55,63.5442 1495.56,63.5442 1495.57,63.5442 1495.58,63.5442 1495.59,63.5442 1495.6,63.5442 1495.61,63.5442 1495.62,63.5442 1495.62,63.5442 1495.63,63.5442 1495.64,63.5442 1495.65,63.5442 1495.66,63.5442 1495.67,63.5442 1495.68,63.5442 1495.69,63.5442 1495.7,63.5442 1495.71,63.5442 1495.72,63.5442 1495.73,63.5442 1495.74,63.5442 1495.74,63.5442 1495.75,63.5442 1495.76,63.5442 1495.77,63.5442 1495.78,63.5442 1495.79,63.5442 1495.8,63.5442 1495.81,63.5442 1495.82,63.5442 1495.83,63.5442 1495.84,63.5442 1495.85,63.5442 1495.85,63.5442 1495.86,63.5442 1495.87,63.5442 1495.88,63.5442 1495.89,63.5442 1495.9,63.5442 1495.91,63.5442 1495.92,63.5442 1495.93,63.5442 1495.94,63.5442 1495.95,63.5442 1495.96,63.5442 1495.96,63.5442 1495.97,63.5442 1495.98,63.5442 1495.99,63.5442 1496,63.5442 1496.01,63.5442 1496.02,63.5442 1496.03,63.5442 1496.04,63.5442 1496.05,63.5442 1496.06,63.5442 1496.07,63.5442 1496.08,63.5442 1496.08,63.5442 1496.09,63.5442 1496.1,63.5442 1496.11,63.5442 1496.12,63.5442 1496.13,63.5442 1496.14,63.5442 1496.15,63.5442 1496.16,63.5442 1496.17,63.5442 1496.18,63.5442 1496.19,63.5442 1496.19,63.5442 1496.2,63.5442 1496.21,63.5442 1496.22,63.5442 1496.23,63.5442 1496.24,63.5442 1496.25,63.5442 1496.26,63.5442 1496.27,63.5442 1496.28,63.5442 1496.29,63.5442 1496.3,63.5442 1496.3,63.5442 1496.31,63.5442 1496.32,63.5442 1496.33,63.5442 1496.34,63.5442 1496.35,63.5442 1496.36,63.5442 1496.37,63.5442 1496.38,63.5442 1496.39,63.5442 1496.4,63.5442 1496.41,63.5442 1496.42,63.5442 1496.42,63.5442 1496.43,63.5442 1496.44,63.5442 1496.45,63.5442 1496.46,63.5442 1496.47,63.5442 1496.48,63.5442 1496.49,63.5442 1496.5,63.5442 1496.51,63.5442 1496.52,63.5442 1496.53,63.5442 1496.53,63.5442 1496.54,63.5442 1496.55,63.5442 1496.56,63.5442 1496.57,63.5442 1496.58,63.5442 1496.59,63.5442 1496.6,63.5442 1496.61,63.5442 1496.62,63.5442 1496.63,63.5442 1496.64,63.5442 1496.64,63.5442 1496.65,63.5442 1496.66,63.5442 1496.67,63.5442 1496.68,63.5442 1496.69,63.5442 1496.7,63.5442 1496.71,63.5442 1496.72,63.5442 1496.73,63.5442 1496.74,63.5442 1496.75,63.5442 1496.76,63.5442 1496.76,63.5442 1496.77,63.5442 1496.78,63.5442 1496.79,63.5442 1496.8,63.5442 1496.81,63.5442 1496.82,63.5442 1496.83,63.5442 1496.84,63.5442 1496.85,63.5442 1496.86,63.5442 1496.87,63.5442 1496.87,63.5442 1496.88,63.5442 1496.89,63.5442 1496.9,63.5442 1496.91,63.5442 1496.92,63.5442 1496.93,63.5442 1496.94,63.5442 1496.95,63.5442 1496.96,63.5442 1496.97,63.5442 1496.98,63.5442 1496.98,63.5442 1496.99,63.5442 1497,63.5442 1497.01,63.5442 1497.02,63.5442 1497.03,63.5442 1497.04,63.5442 1497.05,63.5442 1497.06,63.5442 1497.07,63.5442 1497.08,63.5442 1497.09,63.5442 1497.1,63.5442 1497.1,63.5442 1497.11,63.5442 1497.12,63.5442 1497.13,63.5442 1497.14,63.5442 1497.15,63.5442 1497.16,63.5442 1497.17,63.5442 1497.18,63.5442 1497.19,63.5442 1497.2,63.5442 1497.21,63.5442 1497.21,63.5442 1497.22,63.5442 1497.23,63.5442 1497.24,63.5442 1497.25,63.5442 1497.26,63.5442 1497.27,63.5442 1497.28,63.5442 1497.29,63.5442 1497.3,63.5442 1497.31,63.5442 1497.32,63.5442 1497.32,63.5442 1497.33,63.5442 1497.34,63.5442 1497.35,63.5442 1497.36,63.5442 1497.37,63.5442 1497.38,63.5442 1497.39,63.5442 1497.4,63.5442 1497.41,63.5442 1497.42,63.5442 1497.43,63.5442 1497.44,63.5442 1497.44,63.5442 1497.45,63.5442 1497.46,63.5442 1497.47,63.5442 1497.48,63.5442 1497.49,63.5442 1497.5,63.5442 1497.51,63.5442 1497.52,63.5442 1497.53,63.5442 1497.54,63.5442 1497.55,63.5442 1497.55,63.5442 1497.56,63.5442 1497.57,63.5442 1497.58,63.5442 1497.59,63.5442 1497.6,63.5442 1497.61,63.5442 1497.62,63.5442 1497.63,63.5442 1497.64,63.5442 1497.65,63.5442 1497.66,63.5442 1497.66,63.5442 1497.67,63.5442 1497.68,63.5442 1497.69,63.5442 1497.7,63.5442 1497.71,63.5442 1497.72,63.5442 1497.73,63.5442 1497.74,63.5442 1497.75,63.5442 1497.76,63.5442 1497.77,63.5442 1497.78,63.5442 1497.78,63.5442 1497.79,63.5442 1497.8,63.5442 1497.81,63.5442 1497.82,63.5442 1497.83,63.5442 1497.84,63.5442 1497.85,63.5442 1497.86,63.5442 1497.87,63.5442 1497.88,63.5442 1497.89,63.5442 1497.89,63.5442 1497.9,63.5442 1497.91,63.5442 1497.92,63.5442 1497.93,63.5442 1497.94,63.5442 1497.95,63.5442 1497.96,63.5442 1497.97,63.5442 1497.98,63.5442 1497.99,63.5442 1498,63.5442 1498,63.5442 1498.01,63.5442 1498.02,63.5442 1498.03,63.5442 1498.04,63.5442 1498.05,63.5442 1498.06,63.5442 1498.07,63.5442 1498.08,63.5442 1498.09,63.5442 1498.1,63.5442 1498.11,63.5442 1498.12,63.5442 1498.12,63.5442 1498.13,63.5442 1498.14,63.5442 1498.15,63.5442 1498.16,63.5442 1498.17,63.5442 1498.18,63.5442 1498.19,63.5442 1498.2,63.5442 1498.21,63.5442 1498.22,63.5442 1498.23,63.5442 1498.23,63.5442 1498.24,63.5442 1498.25,63.5442 1498.26,63.5442 1498.27,63.5442 1498.28,63.5442 1498.29,63.5442 1498.3,63.5442 1498.31,63.5442 1498.32,63.5442 1498.33,63.5442 1498.34,63.5442 1498.34,63.5442 1498.35,63.5442 1498.36,63.5442 1498.37,63.5442 1498.38,63.5442 1498.39,63.5442 1498.4,63.5442 1498.41,63.5442 1498.42,63.5442 1498.43,63.5442 1498.44,63.5442 1498.45,63.5442 1498.46,63.5442 1498.46,63.5442 1498.47,63.5442 1498.48,63.5442 1498.49,63.5442 1498.5,63.5442 1498.51,63.5442 1498.52,63.5442 1498.53,63.5442 1498.54,63.5442 1498.55,63.5442 1498.56,63.5442 1498.57,63.5442 1498.57,63.5442 1498.58,63.5442 1498.59,63.5442 1498.6,63.5442 1498.61,63.5442 1498.62,63.5442 1498.63,63.5442 1498.64,63.5442 1498.65,63.5442 1498.66,63.5442 1498.67,63.5442 1498.68,63.5442 1498.68,63.5442 1498.69,63.5442 1498.7,63.5442 1498.71,63.5442 1498.72,63.5442 1498.73,63.5442 1498.74,63.5442 1498.75,63.5442 1498.76,63.5442 1498.77,63.5442 1498.78,63.5442 1498.79,63.5442 1498.8,63.5442 1498.8,63.5442 1498.81,63.5442 1498.82,63.5442 1498.83,63.5442 1498.84,63.5442 1498.85,63.5442 1498.86,63.5442 1498.87,63.5442 1498.88,63.5442 1498.89,63.5442 1498.9,63.5442 1498.91,63.5442 1498.91,63.5442 1498.92,63.5442 1498.93,63.5442 1498.94,63.5442 1498.95,63.5442 1498.96,63.5442 1498.97,63.5442 1498.98,63.5442 1498.99,63.5442 1499,63.5442 1499.01,63.5442 1499.02,63.5442 1499.02,63.5442 1499.03,63.5442 1499.04,63.5442 1499.05,63.5442 1499.06,63.5442 1499.07,63.5442 1499.08,63.5442 1499.09,63.5442 1499.1,63.5442 1499.11,63.5442 1499.12,63.5442 1499.13,63.5442 1499.14,63.5442 1499.14,63.5442 1499.15,63.5442 1499.16,63.5442 1499.17,63.5442 1499.18,63.5442 1499.19,63.5442 1499.2,63.5442 1499.21,63.5442 1499.22,63.5442 1499.23,63.5442 1499.24,63.5442 1499.25,63.5442 1499.25,63.5442 1499.26,63.5442 1499.27,63.5442 1499.28,63.5442 1499.29,63.5442 1499.3,63.5442 1499.31,63.5442 1499.32,63.5442 1499.33,63.5442 1499.34,63.5442 1499.35,63.5442 1499.36,63.5442 1499.36,63.5442 1499.37,63.5442 1499.38,63.5442 1499.39,63.5442 1499.4,63.5442 1499.41,63.5442 1499.42,63.5442 1499.43,63.5442 1499.44,63.5442 1499.45,63.5442 1499.46,63.5442 1499.47,63.5442 1499.48,63.5442 1499.48,63.5442 1499.49,63.5442 1499.5,63.5442 1499.51,63.5442 1499.52,63.5442 1499.53,63.5442 1499.54,63.5442 1499.55,63.5442 1499.56,63.5442 1499.57,63.5442 1499.58,63.5442 1499.59,63.5442 1499.59,63.5442 1499.6,63.5442 1499.61,63.5442 1499.62,63.5442 1499.63,63.5442 1499.64,63.5442 1499.65,63.5442 1499.66,63.5442 1499.67,63.5442 1499.68,63.5442 1499.69,63.5442 1499.7,63.5442 1499.7,63.5442 1499.71,63.5442 1499.72,63.5442 1499.73,63.5442 1499.74,63.5442 1499.75,63.5442 1499.76,63.5442 1499.77,63.5442 1499.78,63.5442 1499.79,63.5442 1499.8,63.5442 1499.81,63.5442 1499.82,63.5442 1499.82,63.5442 1499.83,63.5442 1499.84,63.5442 1499.85,63.5442 1499.86,63.5442 1499.87,63.5442 1499.88,63.5442 1499.89,63.5442 1499.9,63.5442 1499.91,63.5442 1499.92,63.5442 1499.93,63.5442 1499.93,63.5442 1499.94,63.5442 1499.95,63.5442 1499.96,63.5442 1499.97,63.5442 1499.98,63.5442 1499.99,63.5442 1500,63.5442 1500.01,63.5442 1500.02,63.5442 1500.03,63.5442 1500.04,63.5442 1500.04,63.5442 1500.05,63.5442 1500.06,63.5442 1500.07,63.5442 1500.08,63.5442 1500.09,63.5442 1500.1,63.5442 1500.11,63.5442 1500.12,63.5442 1500.13,63.5442 1500.14,63.5442 1500.15,63.5442 1500.16,63.5442 1500.16,63.5442 1500.17,63.5442 1500.18,63.5442 1500.19,63.5442 1500.2,63.5442 1500.21,63.5442 1500.22,63.5442 1500.23,63.5442 1500.24,63.5442 1500.25,63.5442 1500.26,63.5442 1500.27,63.5442 1500.27,63.5442 1500.28,63.5442 1500.29,63.5442 1500.3,63.5442 1500.31,63.5442 1500.32,63.5442 1500.33,63.5442 1500.34,63.5442 1500.35,63.5442 1500.36,63.5442 1500.37,63.5442 1500.38,63.5442 1500.38,63.5442 1500.39,63.5442 1500.4,63.5442 1500.41,63.5442 1500.42,63.5442 1500.43,63.5442 1500.44,63.5442 1500.45,63.5442 1500.46,63.5442 1500.47,63.5442 1500.48,63.5442 1500.49,63.5442 1500.5,63.5442 1500.5,63.5442 1500.51,63.5442 1500.52,63.5442 1500.53,63.5442 1500.54,63.5442 1500.55,63.5442 1500.56,63.5442 1500.57,63.5442 1500.58,63.5442 1500.59,63.5442 1500.6,63.5442 1500.61,63.5442 1500.61,63.5442 1500.62,63.5442 1500.63,63.5442 1500.64,63.5442 1500.65,63.5442 1500.66,63.5442 1500.67,63.5442 1500.68,63.5442 1500.69,63.5442 1500.7,63.5442 1500.71,63.5442 1500.72,63.5442 1500.72,63.5442 1500.73,63.5442 1500.74,63.5442 1500.75,63.5442 1500.76,63.5442 1500.77,63.5442 1500.78,63.5442 1500.79,63.5442 1500.8,63.5442 1500.81,63.5442 1500.82,63.5442 1500.83,63.5442 1500.84,63.5442 1500.84,63.5442 1500.85,63.5442 1500.86,63.5442 1500.87,63.5442 1500.88,63.5442 1500.89,63.5442 1500.9,63.5442 1500.91,63.5442 1500.92,63.5442 1500.93,63.5442 1500.94,63.5442 1500.95,63.5442 1500.95,63.5442 1500.96,63.5442 1500.97,63.5442 1500.98,63.5442 1500.99,63.5442 1501,63.5442 1501.01,63.5442 1501.02,63.5442 1501.03,63.5442 1501.04,63.5442 1501.05,63.5442 1501.06,63.5442 1501.06,63.5442 1501.07,63.5442 1501.08,63.5442 1501.09,63.5442 1501.1,63.5442 1501.11,63.5442 1501.12,63.5442 1501.13,63.5442 1501.14,63.5442 1501.15,63.5442 1501.16,63.5442 1501.17,63.5442 1501.18,63.5442 1501.18,63.5442 1501.19,63.5442 1501.2,63.5442 1501.21,63.5442 1501.22,63.5442 1501.23,63.5442 1501.24,63.5442 1501.25,63.5442 1501.26,63.5442 1501.27,63.5442 1501.28,63.5442 1501.29,63.5442 1501.29,63.5442 1501.3,63.5442 1501.31,63.5442 1501.32,63.5442 1501.33,63.5442 1501.34,63.5442 1501.35,63.5442 1501.36,63.5442 1501.37,63.5442 1501.38,63.5442 1501.39,63.5442 1501.4,63.5442 1501.4,63.5442 1501.41,63.5442 1501.42,63.5442 1501.43,63.5442 1501.44,63.5442 1501.45,63.5442 1501.46,63.5442 1501.47,63.5442 1501.48,63.5442 1501.49,63.5442 1501.5,63.5442 1501.51,63.5442 1501.52,63.5442 1501.52,63.5442 1501.53,63.5442 1501.54,63.5442 1501.55,63.5442 1501.56,63.5442 1501.57,63.5442 1501.58,63.5442 1501.59,63.5442 1501.6,63.5442 1501.61,63.5442 1501.62,63.5442 1501.63,63.5442 1501.63,63.5442 1501.64,63.5442 1501.65,63.5442 1501.66,63.5442 1501.67,63.5442 1501.68,63.5442 1501.69,63.5442 1501.7,63.5442 1501.71,63.5442 1501.72,63.5442 1501.73,63.5442 1501.74,63.5442 1501.74,63.5442 1501.75,63.5442 1501.76,63.5442 1501.77,63.5442 1501.78,63.5442 1501.79,63.5442 1501.8,63.5442 1501.81,63.5442 1501.82,63.5442 1501.83,63.5442 1501.84,63.5442 1501.85,63.5442 1501.86,63.5442 1501.86,63.5442 1501.87,63.5442 1501.88,63.5442 1501.89,63.5442 1501.9,63.5442 1501.91,63.5442 1501.92,63.5442 1501.93,63.5442 1501.94,63.5442 1501.95,63.5442 1501.96,63.5442 1501.97,63.5442 1501.97,63.5442 1501.98,63.5442 1501.99,63.5442 1502,63.5442 1502.01,63.5442 1502.02,63.5442 1502.03,63.5442 1502.04,63.5442 1502.05,63.5442 1502.06,63.5442 1502.07,63.5442 1502.08,63.5442 1502.08,63.5442 1502.09,63.5442 1502.1,63.5442 1502.11,63.5442 1502.12,63.5442 1502.13,63.5442 1502.14,63.5442 1502.15,63.5442 1502.16,63.5442 1502.17,63.5442 1502.18,63.5442 1502.19,63.5442 1502.2,63.5442 1502.2,63.5442 1502.21,63.5442 1502.22,63.5442 1502.23,63.5442 1502.24,63.5442 1502.25,63.5442 1502.26,63.5442 1502.27,63.5442 1502.28,63.5442 1502.29,63.5442 1502.3,63.5442 1502.31,63.5442 1502.31,63.5442 1502.32,63.5442 1502.33,63.5442 1502.34,63.5442 1502.35,63.5442 1502.36,63.5442 1502.37,63.5442 1502.38,63.5442 1502.39,63.5442 1502.4,63.5442 1502.41,63.5442 1502.42,63.5442 1502.42,63.5442 1502.43,63.5442 1502.44,63.5442 1502.45,63.5442 1502.46,63.5442 1502.47,63.5442 1502.48,63.5442 1502.49,63.5442 1502.5,63.5442 1502.51,63.5442 1502.52,63.5442 1502.53,63.5442 1502.54,63.5442 1502.54,63.5442 1502.55,63.5442 1502.56,63.5442 1502.57,63.5442 1502.58,63.5442 1502.59,63.5442 1502.6,63.5442 1502.61,63.5442 1502.62,63.5442 1502.63,63.5442 1502.64,63.5442 1502.65,63.5442 1502.65,63.5442 1502.66,63.5442 1502.67,63.5442 1502.68,63.5442 1502.69,63.5442 1502.7,63.5442 1502.71,63.5442 1502.72,63.5442 1502.73,63.5442 1502.74,63.5442 1502.75,63.5442 1502.76,63.5442 1502.76,63.5442 1502.77,63.5442 1502.78,63.5442 1502.79,63.5442 1502.8,63.5442 1502.81,63.5442 1502.82,63.5442 1502.83,63.5442 1502.84,63.5442 1502.85,63.5442 1502.86,63.5442 1502.87,63.5442 1502.88,63.5442 1502.88,63.5442 1502.89,63.5442 1502.9,63.5442 1502.91,63.5442 1502.92,63.5442 1502.93,63.5442 1502.94,63.5442 1502.95,63.5442 1502.96,63.5442 1502.97,63.5442 1502.98,63.5442 1502.99,63.5442 1502.99,63.5442 1503,63.5442 1503.01,63.5442 1503.02,63.5442 1503.03,63.5442 1503.04,63.5442 1503.05,63.5442 1503.06,63.5442 1503.07,63.5442 1503.08,63.5442 1503.09,63.5442 1503.1,63.5442 1503.1,63.5442 1503.11,63.5442 1503.12,63.5442 1503.13,63.5442 1503.14,63.5442 1503.15,63.5442 1503.16,63.5442 1503.17,63.5442 1503.18,63.5442 1503.19,63.5442 1503.2,63.5442 1503.21,63.5442 1503.22,63.5442 1503.22,63.5442 1503.23,63.5442 1503.24,63.5442 1503.25,63.5442 1503.26,63.5442 1503.27,63.5442 1503.28,63.5442 1503.29,63.5442 1503.3,63.5442 1503.31,63.5442 1503.32,63.5442 1503.33,63.5442 1503.33,63.5442 1503.34,63.5442 1503.35,63.5442 1503.36,63.5442 1503.37,63.5442 1503.38,63.5442 1503.39,63.5442 1503.4,63.5442 1503.41,63.5442 1503.42,63.5442 1503.43,63.5442 1503.44,63.5442 1503.44,63.5442 1503.45,63.5442 1503.46,63.5442 1503.47,63.5442 1503.48,63.5442 1503.49,63.5442 1503.5,63.5442 1503.51,63.5442 1503.52,63.5442 1503.53,63.5442 1503.54,63.5442 1503.55,63.5442 1503.56,63.5442 1503.56,63.5442 1503.57,63.5442 1503.58,63.5442 1503.59,63.5442 1503.6,63.5442 1503.61,63.5442 1503.62,63.5442 1503.63,63.5442 1503.64,63.5442 1503.65,63.5442 1503.66,63.5442 1503.67,63.5442 1503.67,63.5442 1503.68,63.5442 1503.69,63.5442 1503.7,63.5442 1503.71,63.5442 1503.72,63.5442 1503.73,63.5442 1503.74,63.5442 1503.75,63.5442 1503.76,63.5442 1503.77,63.5442 1503.78,63.5442 1503.78,63.5442 1503.79,63.5442 1503.8,63.5442 1503.81,63.5442 1503.82,63.5442 1503.83,63.5442 1503.84,63.5442 1503.85,63.5442 1503.86,63.5442 1503.87,63.5442 1503.88,63.5442 1503.89,63.5442 1503.9,63.5442 1503.9,63.5442 1503.91,63.5442 1503.92,63.5442 1503.93,63.5442 1503.94,63.5442 1503.95,63.5442 1503.96,63.5442 1503.97,63.5442 1503.98,63.5442 1503.99,63.5442 1504,63.5442 1504.01,63.5442 1504.01,63.5442 1504.02,63.5442 1504.03,63.5442 1504.04,63.5442 1504.05,63.5442 1504.06,63.5442 1504.07,63.5442 1504.08,63.5442 1504.09,63.5442 1504.1,63.5442 1504.11,63.5442 1504.12,63.5442 1504.12,63.5442 1504.13,63.5442 1504.14,63.5442 1504.15,63.5442 1504.16,63.5442 1504.17,63.5442 1504.18,63.5442 1504.19,63.5442 1504.2,63.5442 1504.21,63.5442 1504.22,63.5442 1504.23,63.5442 1504.24,63.5442 1504.24,63.5442 1504.25,63.5442 1504.26,63.5442 1504.27,63.5442 1504.28,63.5442 1504.29,63.5442 1504.3,63.5442 1504.31,63.5442 1504.32,63.5442 1504.33,63.5442 1504.34,63.5442 1504.35,63.5442 1504.35,63.5442 1504.36,63.5442 1504.37,63.5442 1504.38,63.5442 1504.39,63.5442 1504.4,63.5442 1504.41,63.5442 1504.42,63.5442 1504.43,63.5442 1504.44,63.5442 1504.45,63.5442 1504.46,63.5442 1504.46,63.5442 1504.47,63.5442 1504.48,63.5442 1504.49,63.5442 1504.5,63.5442 1504.51,63.5442 1504.52,63.5442 1504.53,63.5442 1504.54,63.5442 1504.55,63.5442 1504.56,63.5442 1504.57,63.5442 1504.58,63.5442 1504.58,63.5442 1504.59,63.5442 1504.6,63.5442 1504.61,63.5442 1504.62,63.5442 1504.63,63.5442 1504.64,63.5442 1504.65,63.5442 1504.66,63.5442 1504.67,63.5442 1504.68,63.5442 1504.69,63.5442 1504.69,63.5442 1504.7,63.5442 1504.71,63.5442 1504.72,63.5442 1504.73,63.5442 1504.74,63.5442 1504.75,63.5442 1504.76,63.5442 1504.77,63.5442 1504.78,63.5442 1504.79,63.5442 1504.8,63.5442 1504.8,63.5442 1504.81,63.5442 1504.82,63.5442 1504.83,63.5442 1504.84,63.5442 1504.85,63.5442 1504.86,63.5442 1504.87,63.5442 1504.88,63.5442 1504.89,63.5442 1504.9,63.5442 1504.91,63.5442 1504.92,63.5442 1504.92,63.5442 1504.93,63.5442 1504.94,63.5442 1504.95,63.5442 1504.96,63.5442 1504.97,63.5442 1504.98,63.5442 1504.99,63.5442 1505,63.5442 1505.01,63.5442 1505.02,63.5442 1505.03,63.5442 1505.03,63.5442 1505.04,63.5442 1505.05,63.5442 1505.06,63.5442 1505.07,63.5442 1505.08,63.5442 1505.09,63.5442 1505.1,63.5442 1505.11,63.5442 1505.12,63.5442 1505.13,63.5442 1505.14,63.5442 1505.14,63.5442 1505.15,63.5442 1505.16,63.5442 1505.17,63.5442 1505.18,63.5442 1505.19,63.5442 1505.2,63.5442 1505.21,63.5442 1505.22,63.5442 1505.23,63.5442 1505.24,63.5442 1505.25,63.5442 1505.26,63.5442 1505.26,63.5442 1505.27,63.5442 1505.28,63.5442 1505.29,63.5442 1505.3,63.5442 1505.31,63.5442 1505.32,63.5442 1505.33,63.5442 1505.34,63.5442 1505.35,63.5442 1505.36,63.5442 1505.37,63.5442 1505.37,63.5442 1505.38,63.5442 1505.39,63.5442 1505.4,63.5442 1505.41,63.5442 1505.42,63.5442 1505.43,63.5442 1505.44,63.5442 1505.45,63.5442 1505.46,63.5442 1505.47,63.5442 1505.48,63.5442 1505.48,63.5442 1505.49,63.5442 1505.5,63.5442 1505.51,63.5442 1505.52,63.5442 1505.53,63.5442 1505.54,63.5442 1505.55,63.5442 1505.56,63.5442 1505.57,63.5442 1505.58,63.5442 1505.59,63.5442 1505.6,63.5442 1505.6,63.5442 1505.61,63.5442 1505.62,63.5442 1505.63,63.5442 1505.64,63.5442 1505.65,63.5442 1505.66,63.5442 1505.67,63.5442 1505.68,63.5442 1505.69,63.5442 1505.7,63.5442 1505.71,63.5442 1505.71,63.5442 1505.72,63.5442 1505.73,63.5442 1505.74,63.5442 1505.75,63.5442 1505.76,63.5442 1505.77,63.5442 1505.78,63.5442 1505.79,63.5442 1505.8,63.5442 1505.81,63.5442 1505.82,63.5442 1505.82,63.5442 1505.83,63.5442 1505.84,63.5442 1505.85,63.5442 1505.86,63.5442 1505.87,63.5442 1505.88,63.5442 1505.89,63.5442 1505.9,63.5442 1505.91,63.5442 1505.92,63.5442 1505.93,63.5442 1505.94,63.5442 1505.94,63.5442 1505.95,63.5442 1505.96,63.5442 1505.97,63.5442 1505.98,63.5442 1505.99,63.5442 1506,63.5442 1506.01,63.5442 1506.02,63.5442 1506.03,63.5442 1506.04,63.5442 1506.05,63.5442 1506.05,63.5442 1506.06,63.5442 1506.07,63.5442 1506.08,63.5442 1506.09,63.5442 1506.1,63.5442 1506.11,63.5442 1506.12,63.5442 1506.13,63.5442 1506.14,63.5442 1506.15,63.5442 1506.16,63.5442 1506.16,63.5442 1506.17,63.5442 1506.18,63.5442 1506.19,63.5442 1506.2,63.5442 1506.21,63.5442 1506.22,63.5442 1506.23,63.5442 1506.24,63.5442 1506.25,63.5442 1506.26,63.5442 1506.27,63.5442 1506.28,63.5442 1506.28,63.5442 1506.29,63.5442 1506.3,63.5442 1506.31,63.5442 1506.32,63.5442 1506.33,63.5442 1506.34,63.5442 1506.35,63.5442 1506.36,63.5442 1506.37,63.5442 1506.38,63.5442 1506.39,63.5442 1506.39,63.5442 1506.4,63.5442 1506.41,63.5442 1506.42,63.5442 1506.43,63.5442 1506.44,63.5442 1506.45,63.5442 1506.46,63.5442 1506.47,63.5442 1506.48,63.5442 1506.49,63.5442 1506.5,63.5442 1506.51,63.5442 1506.51,63.5442 1506.52,63.5442 1506.53,63.5442 1506.54,63.5442 1506.55,63.5442 1506.56,63.5442 1506.57,63.5442 1506.58,63.5442 1506.59,63.5442 1506.6,63.5442 1506.61,63.5442 1506.62,63.5442 1506.62,63.5442 1506.63,63.5442 1506.64,63.5442 1506.65,63.5442 1506.66,63.5442 1506.67,63.5442 1506.68,63.5442 1506.69,63.5442 1506.7,63.5442 1506.71,63.5442 1506.72,63.5442 1506.73,63.5442 1506.73,63.5442 1506.74,63.5442 1506.75,63.5442 1506.76,63.5442 1506.77,63.5442 1506.78,63.5442 1506.79,63.5442 1506.8,63.5442 1506.81,63.5442 1506.82,63.5442 1506.83,63.5442 1506.84,63.5442 1506.85,63.5442 1506.85,63.5442 1506.86,63.5442 1506.87,63.5442 1506.88,63.5442 1506.89,63.5442 1506.9,63.5442 1506.91,63.5442 1506.92,63.5442 1506.93,63.5442 1506.94,63.5442 1506.95,63.5442 1506.96,63.5442 1506.96,63.5442 1506.97,63.5442 1506.98,63.5442 1506.99,63.5442 1507,63.5442 1507.01,63.5442 1507.02,63.5442 1507.03,63.5442 1507.04,63.5442 1507.05,63.5442 1507.06,63.5442 1507.07,63.5442 1507.07,63.5442 1507.08,63.5442 1507.09,63.5442 1507.1,63.5442 1507.11,63.5442 1507.12,63.5442 1507.13,63.5442 1507.14,63.5442 1507.15,63.5442 1507.16,63.5442 1507.17,63.5442 1507.18,63.5442 1507.19,63.5442 1507.19,63.5442 1507.2,63.5442 1507.21,63.5442 1507.22,63.5442 1507.23,63.5442 1507.24,63.5442 1507.25,63.5442 1507.26,63.5442 1507.27,63.5442 1507.28,63.5442 1507.29,63.5442 1507.3,63.5442 1507.3,63.5442 1507.31,63.5442 1507.32,63.5442 1507.33,63.5442 1507.34,63.5442 1507.35,63.5442 1507.36,63.5442 1507.37,63.5442 1507.38,63.5442 1507.39,63.5442 1507.4,63.5442 1507.41,63.5442 1507.41,63.5442 1507.42,63.5442 1507.43,63.5442 1507.44,63.5442 1507.45,63.5442 1507.46,63.5442 1507.47,63.5442 1507.48,63.5442 1507.49,63.5442 1507.5,63.5442 1507.51,63.5442 1507.52,63.5442 1507.53,63.5442 1507.53,63.5442 1507.54,63.5442 1507.55,63.5442 1507.56,63.5442 1507.57,63.5442 1507.58,63.5442 1507.59,63.5442 1507.6,63.5442 1507.61,63.5442 1507.62,63.5442 1507.63,63.5442 1507.64,63.5442 1507.64,63.5442 1507.65,63.5442 1507.66,63.5442 1507.67,63.5442 1507.68,63.5442 1507.69,63.5442 1507.7,63.5442 1507.71,63.5442 1507.72,63.5442 1507.73,63.5442 1507.74,63.5442 1507.75,63.5442 1507.75,63.5442 1507.76,63.5442 1507.77,63.5442 1507.78,63.5442 1507.79,63.5442 1507.8,63.5442 1507.81,63.5442 1507.82,63.5442 1507.83,63.5442 1507.84,63.5442 1507.85,63.5442 1507.86,63.5442 1507.87,63.5442 1507.87,63.5442 1507.88,63.5442 1507.89,63.5442 1507.9,63.5442 1507.91,63.5442 1507.92,63.5442 1507.93,63.5442 1507.94,63.5442 1507.95,63.5442 1507.96,63.5442 1507.97,63.5442 1507.98,63.5442 1507.98,63.5442 1507.99,63.5442 1508,63.5442 1508.01,63.5442 1508.02,63.5442 1508.03,63.5442 1508.04,63.5442 1508.05,63.5442 1508.06,63.5442 1508.07,63.5442 1508.08,63.5442 1508.09,63.5442 1508.09,63.5442 1508.1,63.5442 1508.11,63.5442 1508.12,63.5442 1508.13,63.5442 1508.14,63.5442 1508.15,63.5442 1508.16,63.5442 1508.17,63.5442 1508.18,63.5442 1508.19,63.5442 1508.2,63.5442 1508.21,63.5442 1508.21,63.5442 1508.22,63.5442 1508.23,63.5442 1508.24,63.5442 1508.25,63.5442 1508.26,63.5442 1508.27,63.5442 1508.28,63.5442 1508.29,63.5442 1508.3,63.5442 1508.31,63.5442 1508.32,63.5442 1508.32,63.5442 1508.33,63.5442 1508.34,63.5442 1508.35,63.5442 1508.36,63.5442 1508.37,63.5442 1508.38,63.5442 1508.39,63.5442 1508.4,63.5442 1508.41,63.5442 1508.42,63.5442 1508.43,63.5442 1508.43,63.5442 1508.44,63.5442 1508.45,63.5442 1508.46,63.5442 1508.47,63.5442 1508.48,63.5442 1508.49,63.5442 1508.5,63.5442 1508.51,63.5442 1508.52,63.5442 1508.53,63.5442 1508.54,63.5442 1508.55,63.5442 1508.55,63.5442 1508.56,63.5442 1508.57,63.5442 1508.58,63.5442 1508.59,63.5442 1508.6,63.5442 1508.61,63.5442 1508.62,63.5442 1508.63,63.5442 1508.64,63.5442 1508.65,63.5442 1508.66,63.5442 1508.66,63.5442 1508.67,63.5442 1508.68,63.5442 1508.69,63.5442 1508.7,63.5442 1508.71,63.5442 1508.72,63.5442 1508.73,63.5442 1508.74,63.5442 1508.75,63.5442 1508.76,63.5442 1508.77,63.5442 1508.77,63.5442 1508.78,63.5442 1508.79,63.5442 1508.8,63.5442 1508.81,63.5442 1508.82,63.5442 1508.83,63.5442 1508.84,63.5442 1508.85,63.5442 1508.86,63.5442 1508.87,63.5442 1508.88,63.5442 1508.89,63.5442 1508.89,63.5442 1508.9,63.5442 1508.91,63.5442 1508.92,63.5442 1508.93,63.5442 1508.94,63.5442 1508.95,63.5442 1508.96,63.5442 1508.97,63.5442 1508.98,63.5442 1508.99,63.5442 1509,63.5442 1509,63.5442 1509.01,63.5442 1509.02,63.5442 1509.03,63.5442 1509.04,63.5442 1509.05,63.5442 1509.06,63.5442 1509.07,63.5442 1509.08,63.5442 1509.09,63.5442 1509.1,63.5442 1509.11,63.5442 1509.11,63.5442 1509.12,63.5442 1509.13,63.5442 1509.14,63.5442 1509.15,63.5442 1509.16,63.5442 1509.17,63.5442 1509.18,63.5442 1509.19,63.5442 1509.2,63.5442 1509.21,63.5442 1509.22,63.5442 1509.23,63.5442 1509.23,63.5442 1509.24,63.5442 1509.25,63.5442 1509.26,63.5442 1509.27,63.5442 1509.28,63.5442 1509.29,63.5442 1509.3,63.5442 1509.31,63.5442 1509.32,63.5442 1509.33,63.5442 1509.34,63.5442 1509.34,63.5442 1509.35,63.5442 1509.36,63.5442 1509.37,63.5442 1509.38,63.5442 1509.39,63.5442 1509.4,63.5442 1509.41,63.5442 1509.42,63.5442 1509.43,63.5442 1509.44,63.5442 1509.45,63.5442 1509.45,63.5442 1509.46,63.5442 1509.47,63.5442 1509.48,63.5442 1509.49,63.5442 1509.5,63.5442 1509.51,63.5442 1509.52,63.5442 1509.53,63.5442 1509.54,63.5442 1509.55,63.5442 1509.56,63.5442 1509.57,63.5442 1509.57,63.5442 1509.58,63.5442 1509.59,63.5442 1509.6,63.5442 1509.61,63.5442 1509.62,63.5442 1509.63,63.5442 1509.64,63.5442 1509.65,63.5442 1509.66,63.5442 1509.67,63.5442 1509.68,63.5442 1509.68,63.5442 1509.69,63.5442 1509.7,63.5442 1509.71,63.5442 1509.72,63.5442 1509.73,63.5442 1509.74,63.5442 1509.75,63.5442 1509.76,63.5442 1509.77,63.5442 1509.78,63.5442 1509.79,63.5442 1509.79,63.5442 1509.8,63.5442 1509.81,63.5442 1509.82,63.5442 1509.83,63.5442 1509.84,63.5442 1509.85,63.5442 1509.86,63.5442 1509.87,63.5442 1509.88,63.5442 1509.89,63.5442 1509.9,63.5442 1509.91,63.5442 1509.91,63.5442 1509.92,63.5442 1509.93,63.5442 1509.94,63.5442 1509.95,63.5442 1509.96,63.5442 1509.97,63.5442 1509.98,63.5442 1509.99,63.5442 1510,63.5442 1510.01,63.5442 1510.02,63.5442 1510.02,63.5442 1510.03,63.5442 1510.04,63.5442 1510.05,63.5442 1510.06,63.5442 1510.07,63.5442 1510.08,63.5442 1510.09,63.5442 1510.1,63.5442 1510.11,63.5442 1510.12,63.5442 1510.13,63.5442 1510.13,63.5442 1510.14,63.5442 1510.15,63.5442 1510.16,63.5442 1510.17,63.5442 1510.18,63.5442 1510.19,63.5442 1510.2,63.5442 1510.21,63.5442 1510.22,63.5442 1510.23,63.5442 1510.24,63.5442 1510.25,63.5442 1510.25,63.5442 1510.26,63.5442 1510.27,63.5442 1510.28,63.5442 1510.29,63.5442 1510.3,63.5442 1510.31,63.5442 1510.32,63.5442 1510.33,63.5442 1510.34,63.5442 1510.35,63.5442 1510.36,63.5442 1510.36,63.5442 1510.37,63.5442 1510.38,63.5442 1510.39,63.5442 1510.4,63.5442 1510.41,63.5442 1510.42,63.5442 1510.43,63.5442 1510.44,63.5442 1510.45,63.5442 1510.46,63.5442 1510.47,63.5442 1510.47,63.5442 1510.48,63.5442 1510.49,63.5442 1510.5,63.5442 1510.51,63.5442 1510.52,63.5442 1510.53,63.5442 1510.54,63.5442 1510.55,63.5442 1510.56,63.5442 1510.57,63.5442 1510.58,63.5442 1510.59,63.5442 1510.59,63.5442 1510.6,63.5442 1510.61,63.5442 1510.62,63.5442 1510.63,63.5442 1510.64,63.5442 1510.65,63.5442 1510.66,63.5442 1510.67,63.5442 1510.68,63.5442 1510.69,63.5442 1510.7,63.5442 1510.7,63.5442 1510.71,63.5442 1510.72,63.5442 1510.73,63.5442 1510.74,63.5442 1510.75,63.5442 1510.76,63.5442 1510.77,63.5442 1510.78,63.5442 1510.79,63.5442 1510.8,63.5442 1510.81,63.5442 1510.81,63.5442 1510.82,63.5442 1510.83,63.5442 1510.84,63.5442 1510.85,63.5442 1510.86,63.5442 1510.87,63.5442 1510.88,63.5442 1510.89,63.5442 1510.9,63.5442 1510.91,63.5442 1510.92,63.5442 1510.93,63.5442 1510.93,63.5442 1510.94,63.5442 1510.95,63.5442 1510.96,63.5442 1510.97,63.5442 1510.98,63.5442 1510.99,63.5442 1511,63.5442 1511.01,63.5442 1511.02,63.5442 1511.03,63.5442 1511.04,63.5442 1511.04,63.5442 1511.05,63.5442 1511.06,63.5442 1511.07,63.5442 1511.08,63.5442 1511.09,63.5442 1511.1,63.5442 1511.11,63.5442 1511.12,63.5442 1511.13,63.5442 1511.14,63.5442 1511.15,63.5442 1511.15,63.5442 1511.16,63.5442 1511.17,63.5442 1511.18,63.5442 1511.19,63.5442 1511.2,63.5442 1511.21,63.5442 1511.22,63.5442 1511.23,63.5442 1511.24,63.5442 1511.25,63.5442 1511.26,63.5442 1511.27,63.5442 1511.27,63.5442 1511.28,63.5442 1511.29,63.5442 1511.3,63.5442 1511.31,63.5442 1511.32,63.5442 1511.33,63.5442 1511.34,63.5442 1511.35,63.5442 1511.36,63.5442 1511.37,63.5442 1511.38,63.5442 1511.38,63.5442 1511.39,63.5442 1511.4,63.5442 1511.41,63.5442 1511.42,63.5442 1511.43,63.5442 1511.44,63.5442 1511.45,63.5442 1511.46,63.5442 1511.47,63.5442 1511.48,63.5442 1511.49,63.5442 1511.49,63.5442 1511.5,63.5442 1511.51,63.5442 1511.52,63.5442 1511.53,63.5442 1511.54,63.5442 1511.55,63.5442 1511.56,63.5442 1511.57,63.5442 1511.58,63.5442 1511.59,63.5442 1511.6,63.5442 1511.61,63.5442 1511.61,63.5442 1511.62,63.5442 1511.63,63.5442 1511.64,63.5442 1511.65,63.5442 1511.66,63.5442 1511.67,63.5442 1511.68,63.5442 1511.69,63.5442 1511.7,63.5442 1511.71,63.5442 1511.72,63.5442 1511.72,63.5442 1511.73,63.5442 1511.74,63.5442 1511.75,63.5442 1511.76,63.5442 1511.77,63.5442 1511.78,63.5442 1511.79,63.5442 1511.8,63.5442 1511.81,63.5442 1511.82,63.5442 1511.83,63.5442 1511.83,63.5442 1511.84,63.5442 1511.85,63.5442 1511.86,63.5442 1511.87,63.5442 1511.88,63.5442 1511.89,63.5442 1511.9,63.5442 1511.91,63.5442 1511.92,63.5442 1511.93,63.5442 1511.94,63.5442 1511.95,63.5442 1511.95,63.5442 1511.96,63.5442 1511.97,63.5442 1511.98,63.5442 1511.99,63.5442 1512,63.5442 1512.01,63.5442 1512.02,63.5442 1512.03,63.5442 1512.04,63.5442 1512.05,63.5442 1512.06,63.5442 1512.06,63.5442 1512.07,63.5442 1512.08,63.5442 1512.09,63.5442 1512.1,63.5442 1512.11,63.5442 1512.12,63.5442 1512.13,63.5442 1512.14,63.5442 1512.15,63.5442 1512.16,63.5442 1512.17,63.5442 1512.17,63.5442 1512.18,63.5442 1512.19,63.5442 1512.2,63.5442 1512.21,63.5442 1512.22,63.5442 1512.23,63.5442 1512.24,63.5442 1512.25,63.5442 1512.26,63.5442 1512.27,63.5442 1512.28,63.5442 1512.29,63.5442 1512.29,63.5442 1512.3,63.5442 1512.31,63.5442 1512.32,63.5442 1512.33,63.5442 1512.34,63.5442 1512.35,63.5442 1512.36,63.5442 1512.37,63.5442 1512.38,63.5442 1512.39,63.5442 1512.4,63.5442 1512.4,63.5442 1512.41,63.5442 1512.42,63.5442 1512.43,63.5442 1512.44,63.5442 1512.45,63.5442 1512.46,63.5442 1512.47,63.5442 1512.48,63.5442 1512.49,63.5442 1512.5,63.5442 1512.51,63.5442 1512.51,63.5442 1512.52,63.5442 1512.53,63.5442 1512.54,63.5442 1512.55,63.5442 1512.56,63.5442 1512.57,63.5442 1512.58,63.5442 1512.59,63.5442 1512.6,63.5442 1512.61,63.5442 1512.62,63.5442 1512.63,63.5442 1512.63,63.5442 1512.64,63.5442 1512.65,63.5442 1512.66,63.5442 1512.67,63.5442 1512.68,63.5442 1512.69,63.5442 1512.7,63.5442 1512.71,63.5442 1512.72,63.5442 1512.73,63.5442 1512.74,63.5442 1512.74,63.5442 1512.75,63.5442 1512.76,63.5442 1512.77,63.5442 1512.78,63.5442 1512.79,63.5442 1512.8,63.5442 1512.81,63.5442 1512.82,63.5442 1512.83,63.5442 1512.84,63.5442 1512.85,63.5442 1512.85,63.5442 1512.86,63.5442 1512.87,63.5442 1512.88,63.5442 1512.89,63.5442 1512.9,63.5442 1512.91,63.5442 1512.92,63.5442 1512.93,63.5442 1512.94,63.5442 1512.95,63.5442 1512.96,63.5442 1512.97,63.5442 1512.97,63.5442 1512.98,63.5442 1512.99,63.5442 1513,63.5442 1513.01,63.5442 1513.02,63.5442 1513.03,63.5442 1513.04,63.5442 1513.05,63.5442 1513.06,63.5442 1513.07,63.5442 1513.08,63.5442 1513.08,63.5442 1513.09,63.5442 1513.1,63.5442 1513.11,63.5442 1513.12,63.5442 1513.13,63.5442 1513.14,63.5442 1513.15,63.5442 1513.16,63.5442 1513.17,63.5442 1513.18,63.5442 1513.19,63.5442 1513.19,63.5442 1513.2,63.5442 1513.21,63.5442 1513.22,63.5442 1513.23,63.5442 1513.24,63.5442 1513.25,63.5442 1513.26,63.5442 1513.27,63.5442 1513.28,63.5442 1513.29,63.5442 1513.3,63.5442 1513.31,63.5442 1513.31,63.5442 1513.32,63.5442 1513.33,63.5442 1513.34,63.5442 1513.35,63.5442 1513.36,63.5442 1513.37,63.5442 1513.38,63.5442 1513.39,63.5442 1513.4,63.5442 1513.41,63.5442 1513.42,63.5442 1513.42,63.5442 1513.43,63.5442 1513.44,63.5442 1513.45,63.5442 1513.46,63.5442 1513.47,63.5442 1513.48,63.5442 1513.49,63.5442 1513.5,63.5442 1513.51,63.5442 1513.52,63.5442 1513.53,63.5442 1513.53,63.5442 1513.54,63.5442 1513.55,63.5442 1513.56,63.5442 1513.57,63.5442 1513.58,63.5442 1513.59,63.5442 1513.6,63.5442 1513.61,63.5442 1513.62,63.5442 1513.63,63.5442 1513.64,63.5442 1513.65,63.5442 1513.65,63.5442 1513.66,63.5442 1513.67,63.5442 1513.68,63.5442 1513.69,63.5442 1513.7,63.5442 1513.71,63.5442 1513.72,63.5442 1513.73,63.5442 1513.74,63.5442 1513.75,63.5442 1513.76,63.5442 1513.76,63.5442 1513.77,63.5442 1513.78,63.5442 1513.79,63.5442 1513.8,63.5442 1513.81,63.5442 1513.82,63.5442 1513.83,63.5442 1513.84,63.5442 1513.85,63.5442 1513.86,63.5442 1513.87,63.5442 1513.87,63.5442 1513.88,63.5442 1513.89,63.5442 1513.9,63.5442 1513.91,63.5442 1513.92,63.5442 1513.93,63.5442 1513.94,63.5442 1513.95,63.5442 1513.96,63.5442 1513.97,63.5442 1513.98,63.5442 1513.99,63.5442 1513.99,63.5442 1514,63.5442 1514.01,63.5442 1514.02,63.5442 1514.03,63.5442 1514.04,63.5442 1514.05,63.5442 1514.06,63.5442 1514.07,63.5442 1514.08,63.5442 1514.09,63.5442 1514.1,63.5442 1514.1,63.5442 1514.11,63.5442 1514.12,63.5442 1514.13,63.5442 1514.14,63.5442 1514.15,63.5442 1514.16,63.5442 1514.17,63.5442 1514.18,63.5442 1514.19,63.5442 1514.2,63.5442 1514.21,63.5442 1514.21,63.5442 1514.22,63.5442 1514.23,63.5442 1514.24,63.5442 1514.25,63.5442 1514.26,63.5442 1514.27,63.5442 1514.28,63.5442 1514.29,63.5442 1514.3,63.5442 1514.31,63.5442 1514.32,63.5442 1514.33,63.5442 1514.33,63.5442 1514.34,63.5442 1514.35,63.5442 1514.36,63.5442 1514.37,63.5442 1514.38,63.5442 1514.39,63.5442 1514.4,63.5442 1514.41,63.5442 1514.42,63.5442 1514.43,63.5442 1514.44,63.5442 1514.44,63.5442 1514.45,63.5442 1514.46,63.5442 1514.47,63.5442 1514.48,63.5442 1514.49,63.5442 1514.5,63.5442 1514.51,63.5442 1514.52,63.5442 1514.53,63.5442 1514.54,63.5442 1514.55,63.5442 1514.55,63.5442 1514.56,63.5442 1514.57,63.5442 1514.58,63.5442 1514.59,63.5442 1514.6,63.5442 1514.61,63.5442 1514.62,63.5442 1514.63,63.5442 1514.64,63.5442 1514.65,63.5442 1514.66,63.5442 1514.67,63.5442 1514.67,63.5442 1514.68,63.5442 1514.69,63.5442 1514.7,63.5442 1514.71,63.5442 1514.72,63.5442 1514.73,63.5442 1514.74,63.5442 1514.75,63.5442 1514.76,63.5442 1514.77,63.5442 1514.78,63.5442 1514.78,63.5442 1514.79,63.5442 1514.8,63.5442 1514.81,63.5442 1514.82,63.5442 1514.83,63.5442 1514.84,63.5442 1514.85,63.5442 1514.86,63.5442 1514.87,63.5442 1514.88,63.5442 1514.89,63.5442 1514.89,63.5442 1514.9,63.5442 1514.91,63.5442 1514.92,63.5442 1514.93,63.5442 1514.94,63.5442 1514.95,63.5442 1514.96,63.5442 1514.97,63.5442 1514.98,63.5442 1514.99,63.5442 1515,63.5442 1515.01,63.5442 1515.01,63.5442 1515.02,63.5442 1515.03,63.5442 1515.04,63.5442 1515.05,63.5442 1515.06,63.5442 1515.07,63.5442 1515.08,63.5442 1515.09,63.5442 1515.1,63.5442 1515.11,63.5442 1515.12,63.5442 1515.12,63.5442 1515.13,63.5442 1515.14,63.5442 1515.15,63.5442 1515.16,63.5442 1515.17,63.5442 1515.18,63.5442 1515.19,63.5442 1515.2,63.5442 1515.21,63.5442 1515.22,63.5442 1515.23,63.5442 1515.23,63.5442 1515.24,63.5442 1515.25,63.5442 1515.26,63.5442 1515.27,63.5442 1515.28,63.5442 1515.29,63.5442 1515.3,63.5442 1515.31,63.5442 1515.32,63.5442 1515.33,63.5442 1515.34,63.5442 1515.35,63.5442 1515.35,63.5442 1515.36,63.5442 1515.37,63.5442 1515.38,63.5442 1515.39,63.5442 1515.4,63.5442 1515.41,63.5442 1515.42,63.5442 1515.43,63.5442 1515.44,63.5442 1515.45,63.5442 1515.46,63.5442 1515.46,63.5442 1515.47,63.5442 1515.48,63.5442 1515.49,63.5442 1515.5,63.5442 1515.51,63.5442 1515.52,63.5442 1515.53,63.5442 1515.54,63.5442 1515.55,63.5442 1515.56,63.5442 1515.57,63.5442 1515.57,63.5442 1515.58,63.5442 1515.59,63.5442 1515.6,63.5442 1515.61,63.5442 1515.62,63.5442 1515.63,63.5442 1515.64,63.5442 1515.65,63.5442 1515.66,63.5442 1515.67,63.5442 1515.68,63.5442 1515.69,63.5442 1515.69,63.5442 1515.7,63.5442 1515.71,63.5442 1515.72,63.5442 1515.73,63.5442 1515.74,63.5442 1515.75,63.5442 1515.76,63.5442 1515.77,63.5442 1515.78,63.5442 1515.79,63.5442 1515.8,63.5442 1515.8,63.5442 1515.81,63.5442 1515.82,63.5442 1515.83,63.5442 1515.84,63.5442 1515.85,63.5442 1515.86,63.5442 1515.87,63.5442 1515.88,63.5442 1515.89,63.5442 1515.9,63.5442 1515.91,63.5442 1515.91,63.5442 1515.92,63.5442 1515.93,63.5442 1515.94,63.5442 1515.95,63.5442 1515.96,63.5442 1515.97,63.5442 1515.98,63.5442 1515.99,63.5442 1516,63.5442 1516.01,63.5442 1516.02,63.5442 1516.03,63.5442 1516.03,63.5442 1516.04,63.5442 1516.05,63.5442 1516.06,63.5442 1516.07,63.5442 1516.08,63.5442 1516.09,63.5442 1516.1,63.5442 1516.11,63.5442 1516.12,63.5442 1516.13,63.5442 1516.14,63.5442 1516.14,63.5442 1516.15,63.5442 1516.16,63.5442 1516.17,63.5442 1516.18,63.5442 1516.19,63.5442 1516.2,63.5442 1516.21,63.5442 1516.22,63.5442 1516.23,63.5442 1516.24,63.5442 1516.25,63.5442 1516.25,63.5442 1516.26,63.5442 1516.27,63.5442 1516.28,63.5442 1516.29,63.5442 1516.3,63.5442 1516.31,63.5442 1516.32,63.5442 1516.33,63.5442 1516.34,63.5442 1516.35,63.5442 1516.36,63.5442 1516.37,63.5442 1516.37,63.5442 1516.38,63.5442 1516.39,63.5442 1516.4,63.5442 1516.41,63.5442 1516.42,63.5442 1516.43,63.5442 1516.44,63.5442 1516.45,63.5442 1516.46,63.5442 1516.47,63.5442 1516.48,63.5442 1516.48,63.5442 1516.49,63.5442 1516.5,63.5442 1516.51,63.5442 1516.52,63.5442 1516.53,63.5442 1516.54,63.5442 1516.55,63.5442 1516.56,63.5442 1516.57,63.5442 1516.58,63.5442 1516.59,63.5442 1516.59,63.5442 1516.6,63.5442 1516.61,63.5442 1516.62,63.5442 1516.63,63.5442 1516.64,63.5442 1516.65,63.5442 1516.66,63.5442 1516.67,63.5442 1516.68,63.5442 1516.69,63.5442 1516.7,63.5442 1516.71,63.5442 1516.71,63.5442 1516.72,63.5442 1516.73,63.5442 1516.74,63.5442 1516.75,63.5442 1516.76,63.5442 1516.77,63.5442 1516.78,63.5442 1516.79,63.5442 1516.8,63.5442 1516.81,63.5442 1516.82,63.5442 1516.82,63.5442 1516.83,63.5442 1516.84,63.5442 1516.85,63.5442 1516.86,63.5442 1516.87,63.5442 1516.88,63.5442 1516.89,63.5442 1516.9,63.5442 1516.91,63.5442 1516.92,63.5442 1516.93,63.5442 1516.93,63.5442 1516.94,63.5442 1516.95,63.5442 1516.96,63.5442 1516.97,63.5442 1516.98,63.5442 1516.99,63.5442 1517,63.5442 1517.01,63.5442 1517.02,63.5442 1517.03,63.5442 1517.04,63.5442 1517.05,63.5442 1517.05,63.5442 1517.06,63.5442 1517.07,63.5442 1517.08,63.5442 1517.09,63.5442 1517.1,63.5442 1517.11,63.5442 1517.12,63.5442 1517.13,63.5442 1517.14,63.5442 1517.15,63.5442 1517.16,63.5442 1517.16,63.5442 1517.17,63.5442 1517.18,63.5442 1517.19,63.5442 1517.2,63.5442 1517.21,63.5442 1517.22,63.5442 1517.23,63.5442 1517.24,63.5442 1517.25,63.5442 1517.26,63.5442 1517.27,63.5442 1517.27,63.5442 1517.28,63.5442 1517.29,63.5442 1517.3,63.5442 1517.31,63.5442 1517.32,63.5442 1517.33,63.5442 1517.34,63.5442 1517.35,63.5442 1517.36,63.5442 1517.37,63.5442 1517.38,63.5442 1517.39,63.5442 1517.39,63.5442 1517.4,63.5442 1517.41,63.5442 1517.42,63.5442 1517.43,63.5442 1517.44,63.5442 1517.45,63.5442 1517.46,63.5442 1517.47,63.5442 1517.48,63.5442 1517.49,63.5442 1517.5,63.5442 1517.5,63.5442 1517.51,63.5442 1517.52,63.5442 1517.53,63.5442 1517.54,63.5442 1517.55,63.5442 1517.56,63.5442 1517.57,63.5442 1517.58,63.5442 1517.59,63.5442 1517.6,63.5442 1517.61,63.5442 1517.61,63.5442 1517.62,63.5442 1517.63,63.5442 1517.64,63.5442 1517.65,63.5442 1517.66,63.5442 1517.67,63.5442 1517.68,63.5442 1517.69,63.5442 1517.7,63.5442 1517.71,63.5442 1517.72,63.5442 1517.73,63.5442 1517.73,63.5442 1517.74,63.5442 1517.75,63.5442 1517.76,63.5442 1517.77,63.5442 1517.78,63.5442 1517.79,63.5442 1517.8,63.5442 1517.81,63.5442 1517.82,63.5442 1517.83,63.5442 1517.84,63.5442 1517.84,63.5442 1517.85,63.5442 1517.86,63.5442 1517.87,63.5442 1517.88,63.5442 1517.89,63.5442 1517.9,63.5442 1517.91,63.5442 1517.92,63.5442 1517.93,63.5442 1517.94,63.5442 1517.95,63.5442 1517.95,63.5442 1517.96,63.5442 1517.97,63.5442 1517.98,63.5442 1517.99,63.5442 1518,63.5442 1518.01,63.5442 1518.02,63.5442 1518.03,63.5442 1518.04,63.5442 1518.05,63.5442 1518.06,63.5442 1518.07,63.5442 1518.07,63.5442 1518.08,63.5442 1518.09,63.5442 1518.1,63.5442 1518.11,63.5442 1518.12,63.5442 1518.13,63.5442 1518.14,63.5442 1518.15,63.5442 1518.16,63.5442 1518.17,63.5442 1518.18,63.5442 1518.18,63.5442 1518.19,63.5442 1518.2,63.5442 1518.21,63.5442 1518.22,63.5442 1518.23,63.5442 1518.24,63.5442 1518.25,63.5442 1518.26,63.5442 1518.27,63.5442 1518.28,63.5442 1518.29,63.5442 1518.29,63.5442 1518.3,63.5442 1518.31,63.5442 1518.32,63.5442 1518.33,63.5442 1518.34,63.5442 1518.35,63.5442 1518.36,63.5442 1518.37,63.5442 1518.38,63.5442 1518.39,63.5442 1518.4,63.5442 1518.41,63.5442 1518.41,63.5442 1518.42,63.5442 1518.43,63.5442 1518.44,63.5442 1518.45,63.5442 1518.46,63.5442 1518.47,63.5442 1518.48,63.5442 1518.49,63.5442 1518.5,63.5442 1518.51,63.5442 1518.52,63.5442 1518.52,63.5442 1518.53,63.5442 1518.54,63.5442 1518.55,63.5442 1518.56,63.5442 1518.57,63.5442 1518.58,63.5442 1518.59,63.5442 1518.6,63.5442 1518.61,63.5442 1518.62,63.5442 1518.63,63.5442 1518.63,63.5442 1518.64,63.5442 1518.65,63.5442 1518.66,63.5442 1518.67,63.5442 1518.68,63.5442 1518.69,63.5442 1518.7,63.5442 1518.71,63.5442 1518.72,63.5442 1518.73,63.5442 1518.74,63.5442 1518.75,63.5442 1518.75,63.5442 1518.76,63.5442 1518.77,63.5442 1518.78,63.5442 1518.79,63.5442 1518.8,63.5442 1518.81,63.5442 1518.82,63.5442 1518.83,63.5442 1518.84,63.5442 1518.85,63.5442 1518.86,63.5442 1518.86,63.5442 1518.87,63.5442 1518.88,63.5442 1518.89,63.5442 1518.9,63.5442 1518.91,63.5442 1518.92,63.5442 1518.93,63.5442 1518.94,63.5442 1518.95,63.5442 1518.96,63.5442 1518.97,63.5442 1518.97,63.5442 1518.98,63.5442 1518.99,63.5442 1519,63.5442 1519.01,63.5442 1519.02,63.5442 1519.03,63.5442 1519.04,63.5442 1519.05,63.5442 1519.06,63.5442 1519.07,63.5442 1519.08,63.5442 1519.09,63.5442 1519.09,63.5442 1519.1,63.5442 1519.11,63.5442 1519.12,63.5442 1519.13,63.5442 1519.14,63.5442 1519.15,63.5442 1519.16,63.5442 1519.17,63.5442 1519.18,63.5442 1519.19,63.5442 1519.2,63.5442 1519.2,63.5442 1519.21,63.5442 1519.22,63.5442 1519.23,63.5442 1519.24,63.5442 1519.25,63.5442 1519.26,63.5442 1519.27,63.5442 1519.28,63.5442 1519.29,63.5442 1519.3,63.5442 1519.31,63.5442 1519.31,63.5442 1519.32,63.5442 1519.33,63.5442 1519.34,63.5442 1519.35,63.5442 1519.36,63.5442 1519.37,63.5442 1519.38,63.5442 1519.39,63.5442 1519.4,63.5442 1519.41,63.5442 1519.42,63.5442 1519.43,63.5442 1519.43,63.5442 1519.44,63.5442 1519.45,63.5442 1519.46,63.5442 1519.47,63.5442 1519.48,63.5442 1519.49,63.5442 1519.5,63.5442 1519.51,63.5442 1519.52,63.5442 1519.53,63.5442 1519.54,63.5442 1519.54,63.5442 1519.55,63.5442 1519.56,63.5442 1519.57,63.5442 1519.58,63.5442 1519.59,63.5442 1519.6,63.5442 1519.61,63.5442 1519.62,63.5442 1519.63,63.5442 1519.64,63.5442 1519.65,63.5442 1519.65,63.5442 1519.66,63.5442 1519.67,63.5442 1519.68,63.5442 1519.69,63.5442 1519.7,63.5442 1519.71,63.5442 1519.72,63.5442 1519.73,63.5442 1519.74,63.5442 1519.75,63.5442 1519.76,63.5442 1519.77,63.5442 1519.77,63.5442 1519.78,63.5442 1519.79,63.5442 1519.8,63.5442 1519.81,63.5442 1519.82,63.5442 1519.83,63.5442 1519.84,63.5442 1519.85,63.5442 1519.86,63.5442 1519.87,63.5442 1519.88,63.5442 1519.88,63.5442 1519.89,63.5442 1519.9,63.5442 1519.91,63.5442 1519.92,63.5442 1519.93,63.5442 1519.94,63.5442 1519.95,63.5442 1519.96,63.5442 1519.97,63.5442 1519.98,63.5442 1519.99,63.5442 1519.99,63.5442 1520,63.5442 1520.01,63.5442 1520.02,63.5442 1520.03,63.5442 1520.04,63.5442 1520.05,63.5442 1520.06,63.5442 1520.07,63.5442 1520.08,63.5442 1520.09,63.5442 1520.1,63.5442 1520.11,63.5442 1520.11,63.5442 1520.12,63.5442 1520.13,63.5442 1520.14,63.5442 1520.15,63.5442 1520.16,63.5442 1520.17,63.5442 1520.18,63.5442 1520.19,63.5442 1520.2,63.5442 1520.21,63.5442 1520.22,63.5442 1520.22,63.5442 1520.23,63.5442 1520.24,63.5442 1520.25,63.5442 1520.26,63.5442 1520.27,63.5442 1520.28,63.5442 1520.29,63.5442 1520.3,63.5442 1520.31,63.5442 1520.32,63.5442 1520.33,63.5442 1520.33,63.5442 1520.34,63.5442 1520.35,63.5442 1520.36,63.5442 1520.37,63.5442 1520.38,63.5442 1520.39,63.5442 1520.4,63.5442 1520.41,63.5442 1520.42,63.5442 1520.43,63.5442 1520.44,63.5442 1520.45,63.5442 1520.45,63.5442 1520.46,63.5442 1520.47,63.5442 1520.48,63.5442 1520.49,63.5442 1520.5,63.5442 1520.51,63.5442 1520.52,63.5442 1520.53,63.5442 1520.54,63.5442 1520.55,63.5442 1520.56,63.5442 1520.56,63.5442 1520.57,63.5442 1520.58,63.5442 1520.59,63.5442 1520.6,63.5442 1520.61,63.5442 1520.62,63.5442 1520.63,63.5442 1520.64,63.5442 1520.65,63.5442 1520.66,63.5442 1520.67,63.5442 1520.67,63.5442 1520.68,63.5442 1520.69,63.5442 1520.7,63.5442 1520.71,63.5442 1520.72,63.5442 1520.73,63.5442 1520.74,63.5442 1520.75,63.5442 1520.76,63.5442 1520.77,63.5442 1520.78,63.5442 1520.79,63.5442 1520.79,63.5442 1520.8,63.5442 1520.81,63.5442 1520.82,63.5442 1520.83,63.5442 1520.84,63.5442 1520.85,63.5442 1520.86,63.5442 1520.87,63.5442 1520.88,63.5442 1520.89,63.5442 1520.9,63.5442 1520.9,63.5442 1520.91,63.5442 1520.92,63.5442 1520.93,63.5442 1520.94,63.5442 1520.95,63.5442 1520.96,63.5442 1520.97,63.5442 1520.98,63.5442 1520.99,63.5442 1521,63.5442 1521.01,63.5442 1521.01,63.5442 1521.02,63.5442 1521.03,63.5442 1521.04,63.5442 1521.05,63.5442 1521.06,63.5442 1521.07,63.5442 1521.08,63.5442 1521.09,63.5442 1521.1,63.5442 1521.11,63.5442 1521.12,63.5442 1521.13,63.5442 1521.13,63.5442 1521.14,63.5442 1521.15,63.5442 1521.16,63.5442 1521.17,63.5442 1521.18,63.5442 1521.19,63.5442 1521.2,63.5442 1521.21,63.5442 1521.22,63.5442 1521.23,63.5442 1521.24,63.5442 1521.24,63.5442 1521.25,63.5442 1521.26,63.5442 1521.27,63.5442 1521.28,63.5442 1521.29,63.5442 1521.3,63.5442 1521.31,63.5442 1521.32,63.5442 1521.33,63.5442 1521.34,63.5442 1521.35,63.5442 1521.35,63.5442 1521.36,63.5442 1521.37,63.5442 1521.38,63.5442 1521.39,63.5442 1521.4,63.5442 1521.41,63.5442 1521.42,63.5442 1521.43,63.5442 1521.44,63.5442 1521.45,63.5442 1521.46,63.5442 1521.47,63.5442 1521.47,63.5442 1521.48,63.5442 1521.49,63.5442 1521.5,63.5442 1521.51,63.5442 1521.52,63.5442 1521.53,63.5442 1521.54,63.5442 1521.55,63.5442 1521.56,63.5442 1521.57,63.5442 1521.58,63.5442 1521.58,63.5442 1521.59,63.5442 1521.6,63.5442 1521.61,63.5442 1521.62,63.5442 1521.63,63.5442 1521.64,63.5442 1521.65,63.5442 1521.66,63.5442 1521.67,63.5442 1521.68,63.5442 1521.69,63.5442 1521.69,63.5442 1521.7,63.5442 1521.71,63.5442 1521.72,63.5442 1521.73,63.5442 1521.74,63.5442 1521.75,63.5442 1521.76,63.5442 1521.77,63.5442 1521.78,63.5442 1521.79,63.5442 1521.8,63.5442 1521.81,63.5442 1521.81,63.5442 1521.82,63.5442 1521.83,63.5442 1521.84,63.5442 1521.85,63.5442 1521.86,63.5442 1521.87,63.5442 1521.88,63.5442 1521.89,63.5442 1521.9,63.5442 1521.91,63.5442 1521.92,63.5442 1521.92,63.5442 1521.93,63.5442 1521.94,63.5442 1521.95,63.5442 1521.96,63.5442 1521.97,63.5442 1521.98,63.5442 1521.99,63.5442 1522,63.5442 1522.01,63.5442 1522.02,63.5442 1522.03,63.5442 1522.03,63.5442 1522.04,63.5442 1522.05,63.5442 1522.06,63.5442 1522.07,63.5442 1522.08,63.5442 1522.09,63.5442 1522.1,63.5442 1522.11,63.5442 1522.12,63.5442 1522.13,63.5442 1522.14,63.5442 1522.15,63.5442 1522.15,63.5442 1522.16,63.5442 1522.17,63.5442 1522.18,63.5442 1522.19,63.5442 1522.2,63.5442 1522.21,63.5442 1522.22,63.5442 1522.23,63.5442 1522.24,63.5442 1522.25,63.5442 1522.26,63.5442 1522.26,63.5442 1522.27,63.5442 1522.28,63.5442 1522.29,63.5442 1522.3,63.5442 1522.31,63.5442 1522.32,63.5442 1522.33,63.5442 1522.34,63.5442 1522.35,63.5442 1522.36,63.5442 1522.37,63.5442 1522.37,63.5442 1522.38,63.5442 1522.39,63.5442 1522.4,63.5442 1522.41,63.5442 1522.42,63.5442 1522.43,63.5442 1522.44,63.5442 1522.45,63.5442 1522.46,63.5442 1522.47,63.5442 1522.48,63.5442 1522.49,63.5442 1522.49,63.5442 1522.5,63.5442 1522.51,63.5442 1522.52,63.5442 1522.53,63.5442 1522.54,63.5442 1522.55,63.5442 1522.56,63.5442 1522.57,63.5442 1522.58,63.5442 1522.59,63.5442 1522.6,63.5442 1522.6,63.5442 1522.61,63.5442 1522.62,63.5442 1522.63,63.5442 1522.64,63.5442 1522.65,63.5442 1522.66,63.5442 1522.67,63.5442 1522.68,63.5442 1522.69,63.5442 1522.7,63.5442 1522.71,63.5442 1522.71,63.5442 1522.72,63.5442 1522.73,63.5442 1522.74,63.5442 1522.75,63.5442 1522.76,63.5442 1522.77,63.5442 1522.78,63.5442 1522.79,63.5442 1522.8,63.5442 1522.81,63.5442 1522.82,63.5442 1522.83,63.5442 1522.83,63.5442 1522.84,63.5442 1522.85,63.5442 1522.86,63.5442 1522.87,63.5442 1522.88,63.5442 1522.89,63.5442 1522.9,63.5442 1522.91,63.5442 1522.92,63.5442 1522.93,63.5442 1522.94,63.5442 1522.94,63.5442 1522.95,63.5442 1522.96,63.5442 1522.97,63.5442 1522.98,63.5442 1522.99,63.5442 1523,63.5442 1523.01,63.5442 1523.02,63.5442 1523.03,63.5442 1523.04,63.5442 1523.05,63.5442 1523.05,63.5442 1523.06,63.5442 1523.07,63.5442 1523.08,63.5442 1523.09,63.5442 1523.1,63.5442 1523.11,63.5442 1523.12,63.5442 1523.13,63.5442 1523.14,63.5442 1523.15,63.5442 1523.16,63.5442 1523.17,63.5442 1523.17,63.5442 1523.18,63.5442 1523.19,63.5442 1523.2,63.5442 1523.21,63.5442 1523.22,63.5442 1523.23,63.5442 1523.24,63.5442 1523.25,63.5442 1523.26,63.5442 1523.27,63.5442 1523.28,63.5442 1523.28,63.5442 1523.29,63.5442 1523.3,63.5442 1523.31,63.5442 1523.32,63.5442 1523.33,63.5442 1523.34,63.5442 1523.35,63.5442 1523.36,63.5442 1523.37,63.5442 1523.38,63.5442 1523.39,63.5442 1523.39,63.5442 1523.4,63.5442 1523.41,63.5442 1523.42,63.5442 1523.43,63.5442 1523.44,63.5442 1523.45,63.5442 1523.46,63.5442 1523.47,63.5442 1523.48,63.5442 1523.49,63.5442 1523.5,63.5442 1523.51,63.5442 1523.51,63.5442 1523.52,63.5442 1523.53,63.5442 1523.54,63.5442 1523.55,63.5442 1523.56,63.5442 1523.57,63.5442 1523.58,63.5442 1523.59,63.5442 1523.6,63.5442 1523.61,63.5442 1523.62,63.5442 1523.62,63.5442 1523.63,63.5442 1523.64,63.5442 1523.65,63.5442 1523.66,63.5442 1523.67,63.5442 1523.68,63.5442 1523.69,63.5442 1523.7,63.5442 1523.71,63.5442 1523.72,63.5442 1523.73,63.5442 1523.73,63.5442 1523.74,63.5442 1523.75,63.5442 1523.76,63.5442 1523.77,63.5442 1523.78,63.5442 1523.79,63.5442 1523.8,63.5442 1523.81,63.5442 1523.82,63.5442 1523.83,63.5442 1523.84,63.5442 1523.85,63.5442 1523.85,63.5442 1523.86,63.5442 1523.87,63.5442 1523.88,63.5442 1523.89,63.5442 1523.9,63.5442 1523.91,63.5442 1523.92,63.5442 1523.93,63.5442 1523.94,63.5442 1523.95,63.5442 1523.96,63.5442 1523.96,63.5442 1523.97,63.5442 1523.98,63.5442 1523.99,63.5442 1524,63.5442 1524.01,63.5442 1524.02,63.5442 1524.03,63.5442 1524.04,63.5442 1524.05,63.5442 1524.06,63.5442 1524.07,63.5442 1524.07,63.5442 1524.08,63.5442 1524.09,63.5442 1524.1,63.5442 1524.11,63.5442 1524.12,63.5442 1524.13,63.5442 1524.14,63.5442 1524.15,63.5442 1524.16,63.5442 1524.17,63.5442 1524.18,63.5442 1524.19,63.5442 1524.19,63.5442 1524.2,63.5442 1524.21,63.5442 1524.22,63.5442 1524.23,63.5442 1524.24,63.5442 1524.25,63.5442 1524.26,63.5442 1524.27,63.5442 1524.28,63.5442 1524.29,63.5442 1524.3,63.5442 1524.3,63.5442 1524.31,63.5442 1524.32,63.5442 1524.33,63.5442 1524.34,63.5442 1524.35,63.5442 1524.36,63.5442 1524.37,63.5442 1524.38,63.5442 1524.39,63.5442 1524.4,63.5442 1524.41,63.5442 1524.41,63.5442 1524.42,63.5442 1524.43,63.5442 1524.44,63.5442 1524.45,63.5442 1524.46,63.5442 1524.47,63.5442 1524.48,63.5442 1524.49,63.5442 1524.5,63.5442 1524.51,63.5442 1524.52,63.5442 1524.53,63.5442 1524.53,63.5442 1524.54,63.5442 1524.55,63.5442 1524.56,63.5442 1524.57,63.5442 1524.58,63.5442 1524.59,63.5442 1524.6,63.5442 1524.61,63.5442 1524.62,63.5442 1524.63,63.5442 1524.64,63.5442 1524.64,63.5442 1524.65,63.5442 1524.66,63.5442 1524.67,63.5442 1524.68,63.5442 1524.69,63.5442 1524.7,63.5442 1524.71,63.5442 1524.72,63.5442 1524.73,63.5442 1524.74,63.5442 1524.75,63.5442 1524.75,63.5442 1524.76,63.5442 1524.77,63.5442 1524.78,63.5442 1524.79,63.5442 1524.8,63.5442 1524.81,63.5442 1524.82,63.5442 1524.83,63.5442 1524.84,63.5442 1524.85,63.5442 1524.86,63.5442 1524.87,63.5442 1524.87,63.5442 1524.88,63.5442 1524.89,63.5442 1524.9,63.5442 1524.91,63.5442 1524.92,63.5442 1524.93,63.5442 1524.94,63.5442 1524.95,63.5442 1524.96,63.5442 1524.97,63.5442 1524.98,63.5442 1524.98,63.5442 1524.99,63.5442 1525,63.5442 1525.01,63.5442 1525.02,63.5442 1525.03,63.5442 1525.04,63.5442 1525.05,63.5442 1525.06,63.5442 1525.07,63.5442 1525.08,63.5442 1525.09,63.5442 1525.09,63.5442 1525.1,63.5442 1525.11,63.5442 1525.12,63.5442 1525.13,63.5442 1525.14,63.5442 1525.15,63.5442 1525.16,63.5442 1525.17,63.5442 1525.18,63.5442 1525.19,63.5442 1525.2,63.5442 1525.21,63.5442 1525.21,63.5442 1525.22,63.5442 1525.23,63.5442 1525.24,63.5442 1525.25,63.5442 1525.26,63.5442 1525.27,63.5442 1525.28,63.5442 1525.29,63.5442 1525.3,63.5442 1525.31,63.5442 1525.32,63.5442 1525.32,63.5442 1525.33,63.5442 1525.34,63.5442 1525.35,63.5442 1525.36,63.5442 1525.37,63.5442 1525.38,63.5442 1525.39,63.5442 1525.4,63.5442 1525.41,63.5442 1525.42,63.5442 1525.43,63.5442 1525.43,63.5442 1525.44,63.5442 1525.45,63.5442 1525.46,63.5442 1525.47,63.5442 1525.48,63.5442 1525.49,63.5442 1525.5,63.5442 1525.51,63.5442 1525.52,63.5442 1525.53,63.5442 1525.54,63.5442 1525.55,63.5442 1525.55,63.5442 1525.56,63.5442 1525.57,63.5442 1525.58,63.5442 1525.59,63.5442 1525.6,63.5442 1525.61,63.5442 1525.62,63.5442 1525.63,63.5442 1525.64,63.5442 1525.65,63.5442 1525.66,63.5442 1525.66,63.5442 1525.67,63.5442 1525.68,63.5442 1525.69,63.5442 1525.7,63.5442 1525.71,63.5442 1525.72,63.5442 1525.73,63.5442 1525.74,63.5442 1525.75,63.5442 1525.76,63.5442 1525.77,63.5442 1525.77,63.5442 1525.78,63.5442 1525.79,63.5442 1525.8,63.5442 1525.81,63.5442 1525.82,63.5442 1525.83,63.5442 1525.84,63.5442 1525.85,63.5442 1525.86,63.5442 1525.87,63.5442 1525.88,63.5442 1525.89,63.5442 1525.89,63.5442 1525.9,63.5442 1525.91,63.5442 1525.92,63.5442 1525.93,63.5442 1525.94,63.5442 1525.95,63.5442 1525.96,63.5442 1525.97,63.5442 1525.98,63.5442 1525.99,63.5442 1526,63.5442 1526,63.5442 1526.01,63.5442 1526.02,63.5442 1526.03,63.5442 1526.04,63.5442 1526.05,63.5442 1526.06,63.5442 1526.07,63.5442 1526.08,63.5442 1526.09,63.5442 1526.1,63.5442 1526.11,63.5442 1526.11,63.5442 1526.12,63.5442 1526.13,63.5442 1526.14,63.5442 1526.15,63.5442 1526.16,63.5442 1526.17,63.5442 1526.18,63.5442 1526.19,63.5442 1526.2,63.5442 1526.21,63.5442 1526.22,63.5442 1526.23,63.5442 1526.23,63.5442 1526.24,63.5442 1526.25,63.5442 1526.26,63.5442 1526.27,63.5442 1526.28,63.5442 1526.29,63.5442 1526.3,63.5442 1526.31,63.5442 1526.32,63.5442 1526.33,63.5442 1526.34,63.5442 1526.34,63.5442 1526.35,63.5442 1526.36,63.5442 1526.37,63.5442 1526.38,63.5442 1526.39,63.5442 1526.4,63.5442 1526.41,63.5442 1526.42,63.5442 1526.43,63.5442 1526.44,63.5442 1526.45,63.5442 1526.45,63.5442 1526.46,63.5442 1526.47,63.5442 1526.48,63.5442 1526.49,63.5442 1526.5,63.5442 1526.51,63.5442 1526.52,63.5442 1526.53,63.5442 1526.54,63.5442 1526.55,63.5442 1526.56,63.5442 1526.57,63.5442 1526.57,63.5442 1526.58,63.5442 1526.59,63.5442 1526.6,63.5442 1526.61,63.5442 1526.62,63.5442 1526.63,63.5442 1526.64,63.5442 1526.65,63.5442 1526.66,63.5442 1526.67,63.5442 1526.68,63.5442 1526.68,63.5442 1526.69,63.5442 1526.7,63.5442 1526.71,63.5442 1526.72,63.5442 1526.73,63.5442 1526.74,63.5442 1526.75,63.5442 1526.76,63.5442 1526.77,63.5442 1526.78,63.5442 1526.79,63.5442 1526.79,63.5442 1526.8,63.5442 1526.81,63.5442 1526.82,63.5442 1526.83,63.5442 1526.84,63.5442 1526.85,63.5442 1526.86,63.5442 1526.87,63.5442 1526.88,63.5442 1526.89,63.5442 1526.9,63.5442 1526.91,63.5442 1526.91,63.5442 1526.92,63.5442 1526.93,63.5442 1526.94,63.5442 1526.95,63.5442 1526.96,63.5442 1526.97,63.5442 1526.98,63.5442 1526.99,63.5442 1527,63.5442 1527.01,63.5442 1527.02,63.5442 1527.02,63.5442 1527.03,63.5442 1527.04,63.5442 1527.05,63.5442 1527.06,63.5442 1527.07,63.5442 1527.08,63.5442 1527.09,63.5442 1527.1,63.5442 1527.11,63.5442 1527.12,63.5442 1527.13,63.5442 1527.13,63.5442 1527.14,63.5442 1527.15,63.5442 1527.16,63.5442 1527.17,63.5442 1527.18,63.5442 1527.19,63.5442 1527.2,63.5442 1527.21,63.5442 1527.22,63.5442 1527.23,63.5442 1527.24,63.5442 1527.25,63.5442 1527.25,63.5442 1527.26,63.5442 1527.27,63.5442 1527.28,63.5442 1527.29,63.5442 1527.3,63.5442 1527.31,63.5442 1527.32,63.5442 1527.33,63.5442 1527.34,63.5442 1527.35,63.5442 1527.36,63.5442 1527.36,63.5442 1527.37,63.5442 1527.38,63.5442 1527.39,63.5442 1527.4,63.5442 1527.41,63.5442 1527.42,63.5442 1527.43,63.5442 1527.44,63.5442 1527.45,63.5442 1527.46,63.5442 1527.47,63.5442 1527.47,63.5442 1527.48,63.5442 1527.49,63.5442 1527.5,63.5442 1527.51,63.5442 1527.52,63.5442 1527.53,63.5442 1527.54,63.5442 1527.55,63.5442 1527.56,63.5442 1527.57,63.5442 1527.58,63.5442 1527.59,63.5442 1527.59,63.5442 1527.6,63.5442 1527.61,63.5442 1527.62,63.5442 1527.63,63.5442 1527.64,63.5442 1527.65,63.5442 1527.66,63.5442 1527.67,63.5442 1527.68,63.5442 1527.69,63.5442 1527.7,63.5442 1527.7,63.5442 1527.71,63.5442 1527.72,63.5442 1527.73,63.5442 1527.74,63.5442 1527.75,63.5442 1527.76,63.5442 1527.77,63.5442 1527.78,63.5442 1527.79,63.5442 1527.8,63.5442 1527.81,63.5442 1527.81,63.5442 1527.82,63.5442 1527.83,63.5442 1527.84,63.5442 1527.85,63.5442 1527.86,63.5442 1527.87,63.5442 1527.88,63.5442 1527.89,63.5442 1527.9,63.5442 1527.91,63.5442 1527.92,63.5442 1527.93,63.5442 1527.93,63.5442 1527.94,63.5442 1527.95,63.5442 1527.96,63.5442 1527.97,63.5442 1527.98,63.5442 1527.99,63.5442 1528,63.5442 1528.01,63.5442 1528.02,63.5442 1528.03,63.5442 1528.04,63.5442 1528.04,63.5442 1528.05,63.5442 1528.06,63.5442 1528.07,63.5442 1528.08,63.5442 1528.09,63.5442 1528.1,63.5442 1528.11,63.5442 1528.12,63.5442 1528.13,63.5442 1528.14,63.5442 1528.15,63.5442 1528.15,63.5442 1528.16,63.5442 1528.17,63.5442 1528.18,63.5442 1528.19,63.5442 1528.2,63.5442 1528.21,63.5442 1528.22,63.5442 1528.23,63.5442 1528.24,63.5442 1528.25,63.5442 1528.26,63.5442 1528.27,63.5442 1528.27,63.5442 1528.28,63.5442 1528.29,63.5442 1528.3,63.5442 1528.31,63.5442 1528.32,63.5442 1528.33,63.5442 1528.34,63.5442 1528.35,63.5442 1528.36,63.5442 1528.37,63.5442 1528.38,63.5442 1528.38,63.5442 1528.39,63.5442 1528.4,63.5442 1528.41,63.5442 1528.42,63.5442 1528.43,63.5442 1528.44,63.5442 1528.45,63.5442 1528.46,63.5442 1528.47,63.5442 1528.48,63.5442 1528.49,63.5442 1528.49,63.5442 1528.5,63.5442 1528.51,63.5442 1528.52,63.5442 1528.53,63.5442 1528.54,63.5442 1528.55,63.5442 1528.56,63.5442 1528.57,63.5442 1528.58,63.5442 1528.59,63.5442 1528.6,63.5442 1528.61,63.5442 1528.61,63.5442 1528.62,63.5442 1528.63,63.5442 1528.64,63.5442 1528.65,63.5442 1528.66,63.5442 1528.67,63.5442 1528.68,63.5442 1528.69,63.5442 1528.7,63.5442 1528.71,63.5442 1528.72,63.5442 1528.72,63.5442 1528.73,63.5442 1528.74,63.5442 1528.75,63.5442 1528.76,63.5442 1528.77,63.5442 1528.78,63.5442 1528.79,63.5442 1528.8,63.5442 1528.81,63.5442 1528.82,63.5442 1528.83,63.5442 1528.83,63.5442 1528.84,63.5442 1528.85,63.5442 1528.86,63.5442 1528.87,63.5442 1528.88,63.5442 1528.89,63.5442 1528.9,63.5442 1528.91,63.5442 1528.92,63.5442 1528.93,63.5442 1528.94,63.5442 1528.95,63.5442 1528.95,63.5442 1528.96,63.5442 1528.97,63.5442 1528.98,63.5442 1528.99,63.5442 1529,63.5442 1529.01,63.5442 1529.02,63.5442 1529.03,63.5442 1529.04,63.5442 1529.05,63.5442 1529.06,63.5442 1529.06,63.5442 1529.07,63.5442 1529.08,63.5442 1529.09,63.5442 1529.1,63.5442 1529.11,63.5442 1529.12,63.5442 1529.13,63.5442 1529.14,63.5442 1529.15,63.5442 1529.16,63.5442 1529.17,63.5442 1529.17,63.5442 1529.18,63.5442 1529.19,63.5442 1529.2,63.5442 1529.21,63.5442 1529.22,63.5442 1529.23,63.5442 1529.24,63.5442 1529.25,63.5442 1529.26,63.5442 1529.27,63.5442 1529.28,63.5442 1529.29,63.5442 1529.29,63.5442 1529.3,63.5442 1529.31,63.5442 1529.32,63.5442 1529.33,63.5442 1529.34,63.5442 1529.35,63.5442 1529.36,63.5442 1529.37,63.5442 1529.38,63.5442 1529.39,63.5442 1529.4,63.5442 1529.4,63.5442 1529.41,63.5442 1529.42,63.5442 1529.43,63.5442 1529.44,63.5442 1529.45,63.5442 1529.46,63.5442 1529.47,63.5442 1529.48,63.5442 1529.49,63.5442 1529.5,63.5442 1529.51,63.5442 1529.51,63.5442 1529.52,63.5442 1529.53,63.5442 1529.54,63.5443 1529.55,63.5444 1529.56,63.5445 1529.57,63.5446 1529.58,63.5447 1529.59,63.5448 1529.6,63.545 1529.61,63.5451 1529.62,63.5453 1529.63,63.5455 1529.63,63.5457 1529.64,63.546 1529.65,63.5462 1529.66,63.5465 1529.67,63.5467 1529.68,63.547 1529.69,63.5473 1529.7,63.5476 1529.71,63.548 1529.72,63.5483 1529.73,63.5487 1529.74,63.5491 1529.74,63.5495 1529.75,63.5499 1529.76,63.5503 1529.77,63.5508 1529.78,63.5512 1529.79,63.5517 1529.8,63.5522 1529.81,63.5527 1529.82,63.5532 1529.83,63.5537 1529.84,63.5543 1529.85,63.5549 1529.85,63.5554 1529.86,63.556 1529.87,63.5567 1529.88,63.5573 1529.89,63.5579 1529.9,63.5586 1529.91,63.5593 1529.92,63.5599 1529.93,63.5606 1529.94,63.5614 1529.95,63.5621 1529.96,63.5628 1529.97,63.5636 1529.97,63.5644 1529.98,63.5652 1529.99,63.566 1530,63.5668 1530.01,63.5677 1530.02,63.5685 1530.03,63.5694 1530.04,63.5703 1530.05,63.5712 1530.06,63.5721 1530.07,63.573 1530.08,63.574 1530.08,63.5749 1530.09,63.5759 1530.1,63.5769 1530.11,63.5779 1530.12,63.5789 1530.13,63.58 1530.14,63.581 1530.15,63.5821 1530.16,63.5832 1530.17,63.5843 1530.18,63.5854 1530.19,63.5865 1530.19,63.5876 1530.2,63.5888 1530.21,63.59 1530.22,63.5912 1530.23,63.5924 1530.24,63.5936 1530.25,63.5948 1530.26,63.5961 1530.27,63.5973 1530.28,63.5986 1530.29,63.5999 1530.3,63.6012 1530.31,63.6025 1530.31,63.6039 1530.32,63.6052 1530.33,63.6066 1530.34,63.608 1530.35,63.6094 1530.36,63.6108 1530.37,63.6122 1530.38,63.6137 1530.39,63.6151 1530.4,63.6166 1530.41,63.6181 1530.42,63.6196 1530.42,63.6211 1530.43,63.6226 1530.44,63.6242 1530.45,63.6257 1530.46,63.6273 1530.47,63.6289 1530.48,63.6305 1530.49,63.6321 1530.5,63.6338 1530.51,63.6354 1530.52,63.6371 1530.53,63.6388 1530.53,63.6405 1530.54,63.6422 1530.55,63.6439 1530.56,63.6457 1530.57,63.6474 1530.58,63.6492 1530.59,63.651 1530.6,63.6528 1530.61,63.6546 1530.62,63.6564 1530.63,63.6583 1530.64,63.6601 1530.65,63.662 1530.65,63.6639 1530.66,63.6658 1530.67,63.6677 1530.68,63.6696 1530.69,63.6716 1530.7,63.6736 1530.71,63.6755 1530.72,63.6775 1530.73,63.6795 1530.74,63.6816 1530.75,63.6836 1530.76,63.6857 1530.76,63.6877 1530.77,63.6898 1530.78,63.6919 1530.79,63.694 1530.8,63.6961 1530.81,63.6983 1530.82,63.7004 1530.83,63.7026 1530.84,63.7048 1530.85,63.707 1530.86,63.7092 1530.87,63.7114 1530.88,63.7137 1530.88,63.7159 1530.89,63.7182 1530.9,63.7205 1530.91,63.7228 1530.92,63.7251 1530.93,63.7274 1530.94,63.7298 1530.95,63.7321 1530.96,63.7345 1530.97,63.7369 1530.98,63.7393 1530.99,63.7417 1530.99,63.7442 1531,63.7466 1531.01,63.7491 1531.02,63.7515 1531.03,63.754 1531.04,63.7565 1531.05,63.7591 1531.06,63.7616 1531.07,63.7641 1531.08,63.7667 1531.09,63.7693 1531.1,63.7719 1531.1,63.7745 1531.11,63.7771 1531.12,63.7797 1531.13,63.7824 1531.14,63.7851 1531.15,63.7877 1531.16,63.7904 1531.17,63.7931 1531.18,63.7959 1531.19,63.7986 1531.2,63.8014 1531.21,63.8041 1531.22,63.8069 1531.22,63.8097 1531.23,63.8125 1531.24,63.8153 1531.25,63.8182 1531.26,63.821 1531.27,63.8239 1531.28,63.8268 1531.29,63.8297 1531.3,63.8326 1531.31,63.8355 1531.32,63.8385 1531.33,63.8414 1531.33,63.8444 1531.34,63.8474 1531.35,63.8504 1531.36,63.8534 1531.37,63.8564 1531.38,63.8594 1531.39,63.8625 1531.4,63.8656 1531.41,63.8686 1531.42,63.8717 1531.43,63.8749 1531.44,63.878 1531.44,63.8811 1531.45,63.8843 1531.46,63.8875 1531.47,63.8906 1531.48,63.8938 1531.49,63.897 1531.5,63.9003 1531.51,63.9035 1531.52,63.9068 1531.53,63.91 1531.54,63.9133 1531.55,63.9166 1531.56,63.9199 1531.56,63.9233 1531.57,63.9266 1531.58,63.93 1531.59,63.9333 1531.6,63.9367 1531.61,63.9401 1531.62,63.9435 1531.63,63.9469 1531.64,63.9504 1531.65,63.9538 1531.66,63.9573 1531.67,63.9608 1531.67,63.9643 1531.68,63.9678 1531.69,63.9713 1531.7,63.9749 1531.71,63.9784 1531.72,63.982 1531.73,63.9856 1531.74,63.9892 1531.75,63.9928 1531.76,63.9964 1531.77,64 1531.78,64.0037 1531.78,64.0073 1531.79,64.011 1531.8,64.0147 1531.81,64.0184 1531.82,64.0222 1531.83,64.0259 1531.84,64.0296 1531.85,64.0334 1531.86,64.0372 1531.87,64.041 1531.88,64.0448 1531.89,64.0486 1531.9,64.0524 1531.9,64.0563 1531.91,64.0602 1531.92,64.064 1531.93,64.0679 1531.94,64.0718 1531.95,64.0758 1531.96,64.0797 1531.97,64.0836 1531.98,64.0876 1531.99,64.0916 1532,64.0956 1532.01,64.0996 1532.01,64.1036 1532.02,64.1076 1532.03,64.1117 1532.04,64.1157 1532.05,64.1198 1532.06,64.1239 1532.07,64.128 1532.08,64.1321 1532.09,64.1362 1532.1,64.1404 1532.11,64.1445 1532.12,64.1487 1532.12,64.1529 1532.13,64.1571 1532.14,64.1613 1532.15,64.1655 1532.16,64.1698 1532.17,64.174 1532.18,64.1783 1532.19,64.1826 1532.2,64.1869 1532.21,64.1912 1532.22,64.1955 1532.23,64.1998 1532.24,64.2042 1532.24,64.2085 1532.25,64.2129 1532.26,64.2173 1532.27,64.2217 1532.28,64.2261 1532.29,64.2306 1532.3,64.235 1532.31,64.2395 1532.32,64.244 1532.33,64.2484 1532.34,64.2529 1532.35,64.2575 1532.35,64.262 1532.36,64.2665 1532.37,64.2711 1532.38,64.2757 1532.39,64.2803 1532.4,64.2849 1532.41,64.2895 1532.42,64.2941 1532.43,64.2987 1532.44,64.3034 1532.45,64.3081 1532.46,64.3127 1532.46,64.3174 1532.47,64.3221 1532.48,64.3269 1532.49,64.3316 1532.5,64.3363 1532.51,64.3411 1532.52,64.3459 1532.53,64.3507 1532.54,64.3555 1532.55,64.3603 1532.56,64.3651 1532.57,64.37 1532.58,64.3748 1532.58,64.3797 1532.59,64.3846 1532.6,64.3895 1532.61,64.3944 1532.62,64.3993 1532.63,64.4043 1532.64,64.4092 1532.65,64.4142 1532.66,64.4192 1532.67,64.4242 1532.68,64.4292 1532.69,64.4342 1532.69,64.4392 1532.7,64.4443 1532.71,64.4494 1532.72,64.4544 1532.73,64.4595 1532.74,64.4646 1532.75,64.4698 1532.76,64.4749 1532.77,64.48 1532.78,64.4852 1532.79,64.4904 1532.8,64.4955 1532.8,64.5007 1532.81,64.506 1532.82,64.5112 1532.83,64.5164 1532.84,64.5217 1532.85,64.5269 1532.86,64.5322 1532.87,64.5375 1532.88,64.5428 1532.89,64.5481 1532.9,64.5535 1532.91,64.5588 1532.92,64.5642 1532.92,64.5695 1532.93,64.5749 1532.94,64.5803 1532.95,64.5857 1532.96,64.5912 1532.97,64.5966 1532.98,64.6021 1532.99,64.6075 1533,64.613 1533.01,64.6185 1533.02,64.624 1533.03,64.6295 1533.03,64.6351 1533.04,64.6406 1533.05,64.6462 1533.06,64.6518 1533.07,64.6573 1533.08,64.6629 1533.09,64.6686 1533.1,64.6742 1533.11,64.6798 1533.12,64.6855 1533.13,64.6912 1533.14,64.6968 1533.14,64.7025 1533.15,64.7082 1533.16,64.714 1533.17,64.7197 1533.18,64.7254 1533.19,64.7312 1533.2,64.737 1533.21,64.7428 1533.22,64.7486 1533.23,64.7544 1533.24,64.7602 1533.25,64.766 1533.26,64.7719 1533.26,64.7778 1533.27,64.7836 1533.28,64.7895 1533.29,64.7954 1533.3,64.8014 1533.31,64.8073 1533.32,64.8132 1533.33,64.8192 1533.34,64.8252 1533.35,64.8312 1533.36,64.8372 1533.37,64.8432 1533.37,64.8492 1533.38,64.8552 1533.39,64.8613 1533.4,64.8674 1533.41,64.8734 1533.42,64.8795 1533.43,64.8856 1533.44,64.8917 1533.45,64.8979 1533.46,64.904 1533.47,64.9102 1533.48,64.9163 1533.48,64.9225 1533.49,64.9287 1533.5,64.9349 1533.51,64.9412 1533.52,64.9474 1533.53,64.9536 1533.54,64.9599 1533.55,64.9662 1533.56,64.9725 1533.57,64.9788 1533.58,64.9851 1533.59,64.9914 1533.6,64.9977 1533.6,65.0041 1533.61,65.0105 1533.62,65.0168 1533.63,65.0232 1533.64,65.0296 1533.65,65.0361 1533.66,65.0425 1533.67,65.0489 1533.68,65.0554 1533.69,65.0619 1533.7,65.0683 1533.71,65.0748 1533.71,65.0814 1533.72,65.0879 1533.73,65.0944 1533.74,65.101 1533.75,65.1075 1533.76,65.1141 1533.77,65.1207 1533.78,65.1273 1533.79,65.1339 1533.8,65.1405 1533.81,65.1472 1533.82,65.1538 1533.82,65.1605 1533.83,65.1672 1533.84,65.1738 1533.85,65.1805 1533.86,65.1873 1533.87,65.194 1533.88,65.2007 1533.89,65.2075 1533.9,65.2143 1533.91,65.221 1533.92,65.2278 1533.93,65.2346 1533.94,65.2415 1533.94,65.2483 1533.95,65.2551 1533.96,65.262 1533.97,65.2689 1533.98,65.2757 1533.99,65.2826 1534,65.2896 1534.01,65.2965 1534.02,65.3034 1534.03,65.3104 1534.04,65.3173 1534.05,65.3243 1534.05,65.3313 1534.06,65.3383 1534.07,65.3453 1534.08,65.3523 1534.09,65.3593 1534.1,65.3664 1534.11,65.3735 1534.12,65.3805 1534.13,65.3876 1534.14,65.3947 1534.15,65.4018 1534.16,65.409 1534.16,65.4161 1534.17,65.4233 1534.18,65.4304 1534.19,65.4376 1534.2,65.4448 1534.21,65.452 1534.22,65.4592 1534.23,65.4664 1534.24,65.4737 1534.25,65.4809 1534.26,65.4882 1534.27,65.4955 1534.28,65.5028 1534.28,65.5101 1534.29,65.5174 1534.3,65.5247 1534.31,65.5321 1534.32,65.5394 1534.33,65.5468 1534.34,65.5542 1534.35,65.5616 1534.36,65.569 1534.37,65.5764 1534.38,65.5838 1534.39,65.5912 1534.39,65.5987 1534.4,65.6062 1534.41,65.6137 1534.42,65.6211 1534.43,65.6287 1534.44,65.6362 1534.45,65.6437 1534.46,65.6512 1534.47,65.6588 1534.48,65.6664 1534.49,65.674 1534.5,65.6815 1534.5,65.6892 1534.51,65.6968 1534.52,65.7044 1534.53,65.712 1534.54,65.7197 1534.55,65.7274 1534.56,65.7351 1534.57,65.7427 1534.58,65.7505 1534.59,65.7582 1534.6,65.7659 1534.61,65.7736 1534.62,65.7814 1534.62,65.7892 1534.63,65.797 1534.64,65.8048 1534.65,65.8126 1534.66,65.8204 1534.67,65.8282 1534.68,65.8361 1534.69,65.8439 1534.7,65.8518 1534.71,65.8597 1534.72,65.8676 1534.73,65.8755 1534.73,65.8834 1534.74,65.8913 1534.75,65.8992 1534.76,65.9072 1534.77,65.9152 1534.78,65.9232 1534.79,65.9311 1534.8,65.9392 1534.81,65.9472 1534.82,65.9552 1534.83,65.9632 1534.84,65.9713 1534.84,65.9794 1534.85,65.9874 1534.86,65.9955 1534.87,66.0036 1534.88,66.0118 1534.89,66.0199 1534.9,66.028 1534.91,66.0362 1534.92,66.0443 1534.93,66.0525 1534.94,66.0607 1534.95,66.0689 1534.96,66.0771 1534.96,66.0854 1534.97,66.0936 1534.98,66.1018 1534.99,66.1101 1535,66.1184 1535.01,66.1267 1535.02,66.135 1535.03,66.1433 1535.04,66.1516 1535.05,66.16 1535.06,66.1683 1535.07,66.1767 1535.07,66.185 1535.08,66.1934 1535.09,66.2018 1535.1,66.2102 1535.11,66.2187 1535.12,66.2271 1535.13,66.2355 1535.14,66.244 1535.15,66.2525 1535.16,66.261 1535.17,66.2694 1535.18,66.278 1535.18,66.2865 1535.19,66.295 1535.2,66.3036 1535.21,66.3121 1535.22,66.3207 1535.23,66.3293 1535.24,66.3379 1535.25,66.3465 1535.26,66.3551 1535.27,66.3637 1535.28,66.3724 1535.29,66.381 1535.3,66.3897 1535.3,66.3983 1535.31,66.407 1535.32,66.4157 1535.33,66.4245 1535.34,66.4332 1535.35,66.4419 1535.36,66.4507 1535.37,66.4594 1535.38,66.4682 1535.39,66.477 1535.4,66.4858 1535.41,66.4946 1535.41,66.5034 1535.42,66.5123 1535.43,66.5211 1535.44,66.53 1535.45,66.5388 1535.46,66.5477 1535.47,66.5566 1535.48,66.5655 1535.49,66.5744 1535.5,66.5834 1535.51,66.5923 1535.52,66.6013 1535.52,66.6102 1535.53,66.6192 1535.54,66.6282 1535.55,66.6372 1535.56,66.6462 1535.57,66.6553 1535.58,66.6643 1535.59,66.6734 1535.6,66.6824 1535.61,66.6915 1535.62,66.7006 1535.63,66.7097 1535.64,66.7188 1535.64,66.7279 1535.65,66.737 1535.66,66.7462 1535.67,66.7553 1535.68,66.7645 1535.69,66.7737 1535.7,66.7829 1535.71,66.7921 1535.72,66.8013 1535.73,66.8105 1535.74,66.8198 1535.75,66.829 1535.75,66.8383 1535.76,66.8476 1535.77,66.8569 1535.78,66.8662 1535.79,66.8755 1535.8,66.8848 1535.81,66.8941 1535.82,66.9035 1535.83,66.9129 1535.84,66.9222 1535.85,66.9316 1535.86,66.941 1535.86,66.9504 1535.87,66.9598 1535.88,66.9693 1535.89,66.9787 1535.9,66.9882 1535.91,66.9976 1535.92,67.0071 1535.93,67.0166 1535.94,67.0261 1535.95,67.0356 1535.96,67.0451 1535.97,67.0547 1535.98,67.0642 1535.98,67.0738 1535.99,67.0834 1536,67.0929 1536.01,67.1025 1536.02,67.1121 1536.03,67.1218 1536.04,67.1314 1536.05,67.141 1536.06,67.1507 1536.07,67.1604 1536.08,67.17 1536.09,67.1797 1536.09,67.1894 1536.1,67.1991 1536.11,67.2089 1536.12,67.2186 1536.13,67.2283 1536.14,67.2381 1536.15,67.2479 1536.16,67.2577 1536.17,67.2674 1536.18,67.2772 1536.19,67.2871 1536.2,67.2969 1536.2,67.3067 1536.21,67.3166 1536.22,67.3265 1536.23,67.3363 1536.24,67.3462 1536.25,67.3561 1536.26,67.366 1536.27,67.3759 1536.28,67.3859 1536.29,67.3958 1536.3,67.4058 1536.31,67.4157 1536.32,67.4257 1536.32,67.4357 1536.33,67.4457 1536.34,67.4557 1536.35,67.4658 1536.36,67.4758 1536.37,67.4858 1536.38,67.4959 1536.39,67.506 1536.4,67.5161 1536.41,67.5262 1536.42,67.5363 1536.43,67.5464 1536.43,67.5565 1536.44,67.5667 1536.45,67.5768 1536.46,67.587 1536.47,67.5971 1536.48,67.6073 1536.49,67.6175 1536.5,67.6277 1536.51,67.638 1536.52,67.6482 1536.53,67.6584 1536.54,67.6687 1536.54,67.679 1536.55,67.6892 1536.56,67.6995 1536.57,67.7098 1536.58,67.7201 1536.59,67.7305 1536.6,67.7408 1536.61,67.7512 1536.62,67.7615 1536.63,67.7719 1536.64,67.7823 1536.65,67.7927 1536.66,67.8031 1536.66,67.8135 1536.67,67.8239 1536.68,67.8343 1536.69,67.8448 1536.7,67.8553 1536.71,67.8657 1536.72,67.8762 1536.73,67.8867 1536.74,67.8972 1536.75,67.9077 1536.76,67.9183 1536.77,67.9288 1536.77,67.9394 1536.78,67.9499 1536.79,67.9605 1536.8,67.9711 1536.81,67.9817 1536.82,67.9923 1536.83,68.0029 1536.84,68.0135 1536.85,68.0242 1536.86,68.0348 1536.87,68.0455 1536.88,68.0562 1536.88,68.0669 1536.89,68.0776 1536.9,68.0883 1536.91,68.099 1536.92,68.1097 1536.93,68.1205 1536.94,68.1312 1536.95,68.142 1536.96,68.1528 1536.97,68.1636 1536.98,68.1744 1536.99,68.1852 1537,68.196 1537,68.2068 1537.01,68.2177 1537.02,68.2285 1537.03,68.2394 1537.04,68.2503 1537.05,68.2612 1537.06,68.2721 1537.07,68.283 1537.08,68.2939 1537.09,68.3048 1537.1,68.3158 1537.11,68.3267 1537.11,68.3377 1537.12,68.3487 1537.13,68.3597 1537.14,68.3707 1537.15,68.3817 1537.16,68.3927 1537.17,68.4037 1537.18,68.4148 1537.19,68.4258 1537.2,68.4369 1537.21,68.448 1537.22,68.4591 1537.22,68.4702 1537.23,68.4813 1537.24,68.4924 1537.25,68.5035 1537.26,68.5147 1537.27,68.5258 1537.28,68.537 1537.29,68.5482 1537.3,68.5594 1537.31,68.5706 1537.32,68.5818 1537.33,68.593 1537.34,68.6042 1537.34,68.6155 1537.35,68.6268 1537.36,68.638 1537.37,68.6493 1537.38,68.6606 1537.39,68.6719 1537.4,68.6832 1537.41,68.6945 1537.42,68.7059 1537.43,68.7172 1537.44,68.7285 1537.45,68.7399 1537.45,68.7513 1537.46,68.7627 1537.47,68.7741 1537.48,68.7855 1537.49,68.7969 1537.5,68.8083 1537.51,68.8198 1537.52,68.8312 1537.53,68.8427 1537.54,68.8542 1537.55,68.8657 1537.56,68.8772 1537.56,68.8887 1537.57,68.9002 1537.58,68.9117 1537.59,68.9233 1537.6,68.9348 1537.61,68.9464 1537.62,68.958 1537.63,68.9695 1537.64,68.9811 1537.65,68.9927 1537.66,69.0044 1537.67,69.016 1537.68,69.0276 1537.68,69.0393 1537.69,69.0509 1537.7,69.0626 1537.71,69.0743 1537.72,69.086 1537.73,69.0977 1537.74,69.1094 1537.75,69.1211 1537.76,69.1329 1537.77,69.1446 1537.78,69.1564 1537.79,69.1681 1537.79,69.1799 1537.8,69.1917 1537.81,69.2035 1537.82,69.2153 1537.83,69.2271 1537.84,69.239 1537.85,69.2508 1537.86,69.2627 1537.87,69.2745 1537.88,69.2864 1537.89,69.2983 1537.9,69.3102 1537.9,69.3221 1537.91,69.334 1537.92,69.346 1537.93,69.3579 1537.94,69.3699 1537.95,69.3818 1537.96,69.3938 1537.97,69.4058 1537.98,69.4178 1537.99,69.4298 1538,69.4418 1538.01,69.4538 1538.02,69.4659 1538.02,69.4779 1538.03,69.49 1538.04,69.502 1538.05,69.5141 1538.06,69.5262 1538.07,69.5383 1538.08,69.5504 1538.09,69.5626 1538.1,69.5747 1538.11,69.5868 1538.12,69.599 1538.13,69.6112 1538.13,69.6233 1538.14,69.6355 1538.15,69.6477 1538.16,69.6599 1538.17,69.6721 1538.18,69.6844 1538.19,69.6966 1538.2,69.7089 1538.21,69.7211 1538.22,69.7334 1538.23,69.7457 1538.24,69.758 1538.24,69.7703 1538.25,69.7826 1538.26,69.7949 1538.27,69.8073 1538.28,69.8196 1538.29,69.832 1538.3,69.8443 1538.31,69.8567 1538.32,69.8691 1538.33,69.8815 1538.34,69.8939 1538.35,69.9063 1538.36,69.9188 1538.36,69.9312 1538.37,69.9436 1538.38,69.9561 1538.39,69.9686 1538.4,69.9811 1538.41,69.9936 1538.42,70.0061 1538.43,70.0186 1538.44,70.0311 1538.45,70.0436 1538.46,70.0562 1538.47,70.0687 1538.47,70.0813 1538.48,70.0939 1538.49,70.1065 1538.5,70.1191 1538.51,70.1317 1538.52,70.1443 1538.53,70.1569 1538.54,70.1696 1538.55,70.1822 1538.56,70.1949 1538.57,70.2076 1538.58,70.2202 1538.58,70.2329 1538.59,70.2456 1538.6,70.2583 1538.61,70.2711 1538.62,70.2838 1538.63,70.2965 1538.64,70.3093 1538.65,70.3221 1538.66,70.3348 1538.67,70.3476 1538.68,70.3604 1538.69,70.3732 1538.7,70.386 1538.7,70.3989 1538.71,70.4117 1538.72,70.4246 1538.73,70.4374 1538.74,70.4503 1538.75,70.4632 1538.76,70.4761 1538.77,70.489 1538.78,70.5019 1538.79,70.5148 1538.8,70.5277 1538.81,70.5407 1538.81,70.5536 1538.82,70.5666 1538.83,70.5795 1538.84,70.5925 1538.85,70.6055 1538.86,70.6185 1538.87,70.6315 1538.88,70.6446 1538.89,70.6576 1538.9,70.6706 1538.91,70.6837 1538.92,70.6968 1538.92,70.7098 1538.93,70.7229 1538.94,70.736 1538.95,70.7491 1538.96,70.7622 1538.97,70.7754 1538.98,70.7885 1538.99,70.8016 1539,70.8148 1539.01,70.828 1539.02,70.8411 1539.03,70.8543 1539.04,70.8675 1539.04,70.8807 1539.05,70.8939 1539.06,70.9072 1539.07,70.9204 1539.08,70.9337 1539.09,70.9469 1539.1,70.9602 1539.11,70.9735 1539.12,70.9868 1539.13,71.0001 1539.14,71.0134 1539.15,71.0267 1539.15,71.04 1539.16,71.0534 1539.17,71.0667 1539.18,71.0801 1539.19,71.0934 1539.2,71.1068 1539.21,71.1202 1539.22,71.1336 1539.23,71.147 1539.24,71.1604 1539.25,71.1739 1539.26,71.1873 1539.26,71.2008 1539.27,71.2142 1539.28,71.2277 1539.29,71.2412 1539.3,71.2547 1539.31,71.2682 1539.32,71.2817 1539.33,71.2952 1539.34,71.3087 1539.35,71.3223 1539.36,71.3358 1539.37,71.3494 1539.38,71.363 1539.38,71.3765 1539.39,71.3901 1539.4,71.4037 1539.41,71.4173 1539.42,71.431 1539.43,71.4446 1539.44,71.4582 1539.45,71.4719 1539.46,71.4856 1539.47,71.4992 1539.48,71.5129 1539.49,71.5266 1539.49,71.5403 1539.5,71.554 1539.51,71.5677 1539.52,71.5815 1539.53,71.5952 1539.54,71.609 1539.55,71.6227 1539.56,71.6365 1539.57,71.6503 1539.58,71.6641 1539.59,71.6779 1539.6,71.6917 1539.6,71.7055 1539.61,71.7193 1539.62,71.7332 1539.63,71.747 1539.64,71.7609 1539.65,71.7747 1539.66,71.7886 1539.67,71.8025 1539.68,71.8164 1539.69,71.8303 1539.7,71.8443 1539.71,71.8582 1539.72,71.8721 1539.72,71.8861 1539.73,71.9 1539.74,71.914 1539.75,71.928 1539.76,71.942 1539.77,71.956 1539.78,71.97 1539.79,71.984 1539.8,71.998 1539.81,72.0121 1539.82,72.0261 1539.83,72.0402 1539.83,72.0542 1539.84,72.0683 1539.85,72.0824 1539.86,72.0965 1539.87,72.1106 1539.88,72.1247 1539.89,72.1388 1539.9,72.153 1539.91,72.1671 1539.92,72.1813 1539.93,72.1955 1539.94,72.2096 1539.94,72.2238 1539.95,72.238 1539.96,72.2522 1539.97,72.2664 1539.98,72.2807 1539.99,72.2949 1540,72.3091 1540.01,72.3234 1540.02,72.3376 1540.03,72.3519 1540.04,72.3662 1540.05,72.3805 1540.06,72.3948 1540.06,72.4091 1540.07,72.4234 1540.08,72.4378 1540.09,72.4521 1540.1,72.4665 1540.11,72.4808 1540.12,72.4952 1540.13,72.5096 1540.14,72.524 1540.15,72.5384 1540.16,72.5528 1540.17,72.5672 1540.17,72.5816 1540.18,72.596 1540.19,72.6105 1540.2,72.625 1540.21,72.6394 1540.22,72.6539 1540.23,72.6684 1540.24,72.6829 1540.25,72.6974 1540.26,72.7119 1540.27,72.7264 1540.28,72.741 1540.28,72.7555 1540.29,72.7701 1540.3,72.7846 1540.31,72.7992 1540.32,72.8138 1540.33,72.8284 1540.34,72.843 1540.35,72.8576 1540.36,72.8722 1540.37,72.8868 1540.38,72.9015 1540.39,72.9161 1540.4,72.9308 1540.4,72.9454 1540.41,72.9601 1540.42,72.9748 1540.43,72.9895 1540.44,73.0042 1540.45,73.0189 1540.46,73.0336 1540.47,73.0484 1540.48,73.0631 1540.49,73.0779 1540.5,73.0926 1540.51,73.1074 1540.51,73.1222 1540.52,73.137 1540.53,73.1518 1540.54,73.1666 1540.55,73.1814 1540.56,73.1963 1540.57,73.2111 1540.58,73.2259 1540.59,73.2408 1540.6,73.2557 1540.61,73.2705 1540.62,73.2854 1540.62,73.3003 1540.63,73.3152 1540.64,73.3302 1540.65,73.3451 1540.66,73.36 1540.67,73.375 1540.68,73.3899 1540.69,73.4049 1540.7,73.4198 1540.71,73.4348 1540.72,73.4498 1540.73,73.4648 1540.74,73.4798 1540.74,73.4948 1540.75,73.5099 1540.76,73.5249 1540.77,73.54 1540.78,73.555 1540.79,73.5701 1540.8,73.5851 1540.81,73.6002 1540.82,73.6153 1540.83,73.6304 1540.84,73.6455 1540.85,73.6607 1540.85,73.6758 1540.86,73.6909 1540.87,73.7061 1540.88,73.7212 1540.89,73.7364 1540.9,73.7516 1540.91,73.7668 1540.92,73.782 1540.93,73.7972 1540.94,73.8124 1540.95,73.8276 1540.96,73.8429 1540.96,73.8581 1540.97,73.8733 1540.98,73.8886 1540.99,73.9039 1541,73.9192 1541.01,73.9344 1541.02,73.9497 1541.03,73.9651 1541.04,73.9804 1541.05,73.9957 1541.06,74.011 1541.07,74.0264 1541.08,74.0417 1541.08,74.0571 1541.09,74.0725 1541.1,74.0879 1541.11,74.1032 1541.12,74.1186 1541.13,74.1341 1541.14,74.1495 1541.15,74.1649 1541.16,74.1803 1541.17,74.1958 1541.18,74.2112 1541.19,74.2267 1541.19,74.2422 1541.2,74.2577 1541.21,74.2732 1541.22,74.2887 1541.23,74.3042 1541.24,74.3197 1541.25,74.3352 1541.26,74.3508 1541.27,74.3663 1541.28,74.3819 1541.29,74.3974 1541.3,74.413 1541.3,74.4286 1541.31,74.4442 1541.32,74.4598 1541.33,74.4754 1541.34,74.491 1541.35,74.5066 1541.36,74.5223 1541.37,74.5379 1541.38,74.5536 1541.39,74.5692 1541.4,74.5849 1541.41,74.6006 1541.42,74.6163 1541.42,74.632 1541.43,74.6477 1541.44,74.6634 1541.45,74.6792 1541.46,74.6949 1541.47,74.7107 1541.48,74.7264 1541.49,74.7422 1541.5,74.758 1541.51,74.7737 1541.52,74.7895 1541.53,74.8053 1541.53,74.8211 1541.54,74.837 1541.55,74.8528 1541.56,74.8686 1541.57,74.8845 1541.58,74.9003 1541.59,74.9162 1541.6,74.9321 1541.61,74.948 1541.62,74.9638 1541.63,74.9797 1541.64,74.9957 1541.64,75.0116 1541.65,75.0275 1541.66,75.0434 1541.67,75.0594 1541.68,75.0753 1541.69,75.0913 1541.7,75.1073 1541.71,75.1233 1541.72,75.1393 1541.73,75.1553 1541.74,75.1713 1541.75,75.1873 1541.76,75.2033 1541.76,75.2193 1541.77,75.2354 1541.78,75.2514 1541.79,75.2675 1541.8,75.2836 1541.81,75.2997 1541.82,75.3158 1541.83,75.3318 1541.84,75.348 1541.85,75.3641 1541.86,75.3802 1541.87,75.3963 1541.87,75.4125 1541.88,75.4286 1541.89,75.4448 1541.9,75.461 1541.91,75.4771 1541.92,75.4933 1541.93,75.5095 1541.94,75.5257 1541.95,75.5419 1541.96,75.5582 1541.97,75.5744 1541.98,75.5906 1541.98,75.6069 1541.99,75.6231 1542,75.6394 1542.01,75.6557 1542.02,75.672 1542.03,75.6883 1542.04,75.7046 1542.05,75.7209 1542.06,75.7372 1542.07,75.7535 1542.08,75.7699 1542.09,75.7862 1542.1,75.8026 1542.1,75.8189 1542.11,75.8353 1542.12,75.8517 1542.13,75.8681 1542.14,75.8845 1542.15,75.9009 1542.16,75.9173 1542.17,75.9337 1542.18,75.9501 1542.19,75.9666 1542.2,75.983 1542.21,75.9995 1542.21,76.016 1542.22,76.0325 1542.23,76.0489 1542.24,76.0654 1542.25,76.0819 1542.26,76.0984 1542.27,76.115 1542.28,76.1315 1542.29,76.148 1542.3,76.1646 1542.31,76.1811 1542.32,76.1977 1542.32,76.2143 1542.33,76.2309 1542.34,76.2475 1542.35,76.2641 1542.36,76.2807 1542.37,76.2973 1542.38,76.3139 1542.39,76.3305 1542.4,76.3472 1542.41,76.3638 1542.42,76.3805 1542.43,76.3972 1542.44,76.4138 1542.44,76.4305 1542.45,76.4472 1542.46,76.4639 1542.47,76.4806 1542.48,76.4974 1542.49,76.5141 1542.5,76.5308 1542.51,76.5476 1542.52,76.5643 1542.53,76.5811 1542.54,76.5979 1542.55,76.6146 1542.55,76.6314 1542.56,76.6482 1542.57,76.665 1542.58,76.6819 1542.59,76.6987 1542.6,76.7155 1542.61,76.7323 1542.62,76.7492 1542.63,76.7661 1542.64,76.7829 1542.65,76.7998 1542.66,76.8167 1542.66,76.8336 1542.67,76.8505 1542.68,76.8674 1542.69,76.8843 1542.7,76.9012 1542.71,76.9182 1542.72,76.9351 1542.73,76.9521 1542.74,76.969 1542.75,76.986 1542.76,77.003 1542.77,77.02 1542.78,77.0369 1542.78,77.054 1542.79,77.071 1542.8,77.088 1542.81,77.105 1542.82,77.122 1542.83,77.1391 1542.84,77.1561 1542.85,77.1732 1542.86,77.1903 1542.87,77.2074 1542.88,77.2244 1542.89,77.2415 1542.89,77.2586 1542.9,77.2758 1542.91,77.2929 1542.92,77.31 1542.93,77.3272 1542.94,77.3443 1542.95,77.3615 1542.96,77.3786 1542.97,77.3958 1542.98,77.413 1542.99,77.4302 1543,77.4474 1543,77.4646 1543.01,77.4818 1543.02,77.499 1543.03,77.5162 1543.04,77.5335 1543.05,77.5507 1543.06,77.568 1543.07,77.5852 1543.08,77.6025 1543.09,77.6198 1543.1,77.6371 1543.11,77.6544 1543.12,77.6717 1543.12,77.689 1543.13,77.7063 1543.14,77.7237 1543.15,77.741 1543.16,77.7583 1543.17,77.7757 1543.18,77.7931 1543.19,77.8104 1543.2,77.8278 1543.21,77.8452 1543.22,77.8626 1543.23,77.88 1543.23,77.8974 1543.24,77.9149 1543.25,77.9323 1543.26,77.9497 1543.27,77.9672 1543.28,77.9846 1543.29,78.0021 1543.3,78.0196 1543.31,78.037 1543.32,78.0545 1543.33,78.072 1543.34,78.0895 1543.34,78.107 1543.35,78.1246 1543.36,78.1421 1543.37,78.1596 1543.38,78.1772 1543.39,78.1947 1543.4,78.2123 1543.41,78.2299 1543.42,78.2475 1543.43,78.265 1543.44,78.2826 1543.45,78.3002 1543.46,78.3179 1543.46,78.3355 1543.47,78.3531 1543.48,78.3707 1543.49,78.3884 1543.5,78.406 1543.51,78.4237 1543.52,78.4414 1543.53,78.4591 1543.54,78.4767 1543.55,78.4944 1543.56,78.5121 1543.57,78.5298 1543.57,78.5476 1543.58,78.5653 1543.59,78.583 1543.6,78.6008 1543.61,78.6185 1543.62,78.6363 1543.63,78.6541 1543.64,78.6718 1543.65,78.6896 1543.66,78.7074 1543.67,78.7252 1543.68,78.743 1543.68,78.7608 1543.69,78.7787 1543.7,78.7965 1543.71,78.8143 1543.72,78.8322 1543.73,78.85 1543.74,78.8679 1543.75,78.8858 1543.76,78.9037 1543.77,78.9215 1543.78,78.9394 1543.79,78.9573 1543.8,78.9753 1543.8,78.9932 1543.81,79.0111 1543.82,79.0291 1543.83,79.047 1543.84,79.065 1543.85,79.0829 1543.86,79.1009 1543.87,79.1189 1543.88,79.1368 1543.89,79.1548 1543.9,79.1728 1543.91,79.1909 1543.91,79.2089 1543.92,79.2269 1543.93,79.2449 1543.94,79.263 1543.95,79.281 1543.96,79.2991 1543.97,79.3172 1543.98,79.3352 1543.99,79.3533 1544,79.3714 1544.01,79.3895 1544.02,79.4076 1544.02,79.4257 1544.03,79.4438 1544.04,79.462 1544.05,79.4801 1544.06,79.4983 1544.07,79.5164 1544.08,79.5346 1544.09,79.5527 1544.1,79.5709 1544.11,79.5891 1544.12,79.6073 1544.13,79.6255 1544.14,79.6437 1544.14,79.6619 1544.15,79.6802 1544.16,79.6984 1544.17,79.7166 1544.18,79.7349 1544.19,79.7531 1544.2,79.7714 1544.21,79.7897 1544.22,79.808 1544.23,79.8262 1544.24,79.8445 1544.25,79.8628 1544.25,79.8812 1544.26,79.8995 1544.27,79.9178 1544.28,79.9361 1544.29,79.9545 1544.3,79.9728 1544.31,79.9912 1544.32,80.0096 1544.33,80.0279 1544.34,80.0463 1544.35,80.0647 1544.36,80.0831 1544.36,80.1015 1544.37,80.1199 1544.38,80.1384 1544.39,80.1568 1544.4,80.1752 1544.41,80.1937 1544.42,80.2121 1544.43,80.2306 1544.44,80.2491 1544.45,80.2675 1544.46,80.286 1544.47,80.3045 1544.48,80.323 1544.48,80.3415 1544.49,80.36 1544.5,80.3786 1544.51,80.3971 1544.52,80.4156 1544.53,80.4342 1544.54,80.4527 1544.55,80.4713 1544.56,80.4899 1544.57,80.5084 1544.58,80.527 1544.59,80.5456 1544.59,80.5642 1544.6,80.5828 1544.61,80.6014 1544.62,80.6201 1544.63,80.6387 1544.64,80.6573 1544.65,80.676 1544.66,80.6947 1544.67,80.7133 1544.68,80.732 1544.69,80.7507 1544.7,80.7693 1544.7,80.788 1544.71,80.8067 1544.72,80.8255 1544.73,80.8442 1544.74,80.8629 1544.75,80.8816 1544.76,80.9004 1544.77,80.9191 1544.78,80.9379 1544.79,80.9566 1544.8,80.9754 1544.81,80.9942 1544.82,81.013 1544.82,81.0318 1544.83,81.0506 1544.84,81.0694 1544.85,81.0882 1544.86,81.107 1544.87,81.1258 1544.88,81.1447 1544.89,81.1635 1544.9,81.1824 1544.91,81.2013 1544.92,81.2201 1544.93,81.239 1544.93,81.2579 1544.94,81.2768 1544.95,81.2957 1544.96,81.3146 1544.97,81.3335 1544.98,81.3524 1544.99,81.3714 1545,81.3903 1545.01,81.4092 1545.02,81.4282 1545.03,81.4472 1545.04,81.4661 1545.04,81.4851 1545.05,81.5041 1545.06,81.5231 1545.07,81.5421 1545.08,81.5611 1545.09,81.5801 1545.1,81.5991 1545.11,81.6181 1545.12,81.6372 1545.13,81.6562 1545.14,81.6753 1545.15,81.6943 1545.16,81.7134 1545.16,81.7325 1545.17,81.7516 1545.18,81.7707 1545.19,81.7897 1545.2,81.8089 1545.21,81.828 1545.22,81.8471 1545.23,81.8662 1545.24,81.8853 1545.25,81.9045 1545.26,81.9236 1545.27,81.9428 1545.27,81.962 1545.28,81.9811 1545.29,82.0003 1545.3,82.0195 1545.31,82.0387 1545.32,82.0579 1545.33,82.0771 1545.34,82.0963 1545.35,82.1155 1545.36,82.1348 1545.37,82.154 1545.38,82.1733 1545.38,82.1925 1545.39,82.2118 1545.4,82.231 1545.41,82.2503 1545.42,82.2696 1545.43,82.2889 1545.44,82.3082 1545.45,82.3275 1545.46,82.3468 1545.47,82.3661 1545.48,82.3855 1545.49,82.4048 1545.5,82.4241 1545.5,82.4435 1545.51,82.4628 1545.52,82.4822 1545.53,82.5016 1545.54,82.521 1545.55,82.5403 1545.56,82.5597 1545.57,82.5791 1545.58,82.5985 1545.59,82.618 1545.6,82.6374 1545.61,82.6568 1545.61,82.6763 1545.62,82.6957 1545.63,82.7151 1545.64,82.7346 1545.65,82.7541 1545.66,82.7736 1545.67,82.793 1545.68,82.8125 1545.69,82.832 1545.7,82.8515 1545.71,82.871 1545.72,82.8906 1545.72,82.9101 1545.73,82.9296 1545.74,82.9492 1545.75,82.9687 1545.76,82.9883 1545.77,83.0078 1545.78,83.0274 1545.79,83.047 1545.8,83.0665 1545.81,83.0861 1545.82,83.1057 1545.83,83.1253 1545.84,83.145 1545.84,83.1646 1545.85,83.1842 1545.86,83.2038 1545.87,83.2235 1545.88,83.2431 1545.89,83.2628 1545.9,83.2825 1545.91,83.3021 1545.92,83.3218 1545.93,83.3415 1545.94,83.3612 1545.95,83.3809 1545.95,83.4006 1545.96,83.4203 1545.97,83.44 1545.98,83.4598 1545.99,83.4795 1546,83.4992 1546.01,83.519 1546.02,83.5387 1546.03,83.5585 1546.04,83.5783 1546.05,83.5981 1546.06,83.6178 1546.06,83.6376 1546.07,83.6574 1546.08,83.6772 1546.09,83.6971 1546.1,83.7169 1546.11,83.7367 1546.12,83.7565 1546.13,83.7764 1546.14,83.7962 1546.15,83.8161 1546.16,83.836 1546.17,83.8558 1546.18,83.8757 1546.18,83.8956 1546.19,83.9155 1546.2,83.9354 1546.21,83.9553 1546.22,83.9752 1546.23,83.9951 1546.24,84.0151 1546.25,84.035 1546.26,84.0549 1546.27,84.0749 1546.28,84.0949 1546.29,84.1148 1546.29,84.1348 1546.3,84.1548 1546.31,84.1748 1546.32,84.1947 1546.33,84.2147 1546.34,84.2347 1546.35,84.2548 1546.36,84.2748 1546.37,84.2948 1546.38,84.3148 1546.39,84.3349 1546.4,84.3549 1546.4,84.375 1546.41,84.3951 1546.42,84.4151 1546.43,84.4352 1546.44,84.4553 1546.45,84.4754 1546.46,84.4955 1546.47,84.5156 1546.48,84.5357 1546.49,84.5558 1546.5,84.5759 1546.51,84.5961 1546.52,84.6162 1546.52,84.6364 1546.53,84.6565 1546.54,84.6767 1546.55,84.6968 1546.56,84.717 1546.57,84.7372 1546.58,84.7574 1546.59,84.7776 1546.6,84.7978 1546.61,84.818 1546.62,84.8382 1546.63,84.8584 1546.63,84.8787 1546.64,84.8989 1546.65,84.9192 1546.66,84.9394 1546.67,84.9597 1546.68,84.9799 1546.69,85.0002 1546.7,85.0205 1546.71,85.0408 1546.72,85.0611 1546.73,85.0814 1546.74,85.1017 1546.74,85.122 1546.75,85.1423 1546.76,85.1626 1546.77,85.183 1546.78,85.2033 1546.79,85.2237 1546.8,85.244 1546.81,85.2644 1546.82,85.2847 1546.83,85.3051 1546.84,85.3255 1546.85,85.3459 1546.86,85.3663 1546.86,85.3867 1546.87,85.4071 1546.88,85.4275 1546.89,85.4479 1546.9,85.4684 1546.91,85.4888 1546.92,85.5092 1546.93,85.5297 1546.94,85.5502 1546.95,85.5706 1546.96,85.5911 1546.97,85.6116 1546.97,85.6321 1546.98,85.6526 1546.99,85.6731 1547,85.6936 1547.01,85.7141 1547.02,85.7346 1547.03,85.7551 1547.04,85.7756 1547.05,85.7962 1547.06,85.8167 1547.07,85.8373 1547.08,85.8578 1547.08,85.8784 1547.09,85.899 1547.1,85.9196 1547.11,85.9402 1547.12,85.9608 1547.13,85.9814 1547.14,86.002 1547.15,86.0226 1547.16,86.0432 1547.17,86.0638 1547.18,86.0845 1547.19,86.1051 1547.2,86.1257 1547.2,86.1464 1547.21,86.1671 1547.22,86.1877 1547.23,86.2084 1547.24,86.2291 1547.25,86.2498 1547.26,86.2705 1547.27,86.2912 1547.28,86.3119 1547.29,86.3326 1547.3,86.3533 1547.31,86.374 1547.31,86.3948 1547.32,86.4155 1547.33,86.4363 1547.34,86.457 1547.35,86.4778 1547.36,86.4986 1547.37,86.5193 1547.38,86.5401 1547.39,86.5609 1547.4,86.5817 1547.41,86.6025 1547.42,86.6233 1547.42,86.6441 1547.43,86.665 1547.44,86.6858 1547.45,86.7066 1547.46,86.7275 1547.47,86.7483 1547.48,86.7692 1547.49,86.79 1547.5,86.8109 1547.51,86.8318 1547.52,86.8526 1547.53,86.8735 1547.54,86.8944 1547.54,86.9153 1547.55,86.9362 1547.56,86.9572 1547.57,86.9781 1547.58,86.999 1547.59,87.0199 1547.6,87.0409 1547.61,87.0618 1547.62,87.0828 1547.63,87.1037 1547.64,87.1247 1547.65,87.1457 1547.65,87.1667 1547.66,87.1877 1547.67,87.2086 1547.68,87.2296 1547.69,87.2507 1547.7,87.2717 1547.71,87.2927 1547.72,87.3137 1547.73,87.3348 1547.74,87.3558 1547.75,87.3768 1547.76,87.3979 1547.76,87.4189 1547.77,87.44 1547.78,87.4611 1547.79,87.4822 1547.8,87.5033 1547.81,87.5243 1547.82,87.5454 1547.83,87.5665 1547.84,87.5877 1547.85,87.6088 1547.86,87.6299 1547.87,87.651 1547.88,87.6722 1547.88,87.6933 1547.89,87.7145 1547.9,87.7356 1547.91,87.7568 1547.92,87.778 1547.93,87.7991 1547.94,87.8203 1547.95,87.8415 1547.96,87.8627 1547.97,87.8839 1547.98,87.9051 1547.99,87.9263 1547.99,87.9475 1548,87.9688 1548.01,87.99 1548.02,88.0112 1548.03,88.0325 1548.04,88.0537 1548.05,88.075 1548.06,88.0963 1548.07,88.1175 1548.08,88.1388 1548.09,88.1601 1548.1,88.1814 1548.1,88.2027 1548.11,88.224 1548.12,88.2453 1548.13,88.2666 1548.14,88.288 1548.15,88.3093 1548.16,88.3306 1548.17,88.352 1548.18,88.3733 1548.19,88.3947 1548.2,88.416 1548.21,88.4374 1548.22,88.4588 1548.22,88.4802 1548.23,88.5016 1548.24,88.523 1548.25,88.5444 1548.26,88.5658 1548.27,88.5872 1548.28,88.6086 1548.29,88.63 1548.3,88.6515 1548.31,88.6729 1548.32,88.6943 1548.33,88.7158 1548.33,88.7372 1548.34,88.7587 1548.35,88.7802 1548.36,88.8017 1548.37,88.8231 1548.38,88.8446 1548.39,88.8661 1548.4,88.8876 1548.41,88.9091 1548.42,88.9306 1548.43,88.9522 1548.44,88.9737 1548.44,88.9952 1548.45,89.0168 1548.46,89.0383 1548.47,89.0599 1548.48,89.0814 1548.49,89.103 1548.5,89.1246 1548.51,89.1461 1548.52,89.1677 1548.53,89.1893 1548.54,89.2109 1548.55,89.2325 1548.56,89.2541 1548.56,89.2757 1548.57,89.2974 1548.58,89.319 1548.59,89.3406 1548.6,89.3623 1548.61,89.3839 1548.62,89.4056 1548.63,89.4272 1548.64,89.4489 1548.65,89.4705 1548.66,89.4922 1548.67,89.5139 1548.67,89.5356 1548.68,89.5573 1548.69,89.579 1548.7,89.6007 1548.71,89.6224 1548.72,89.6441 1548.73,89.6659 1548.74,89.6876 1548.75,89.7093 1548.76,89.7311 1548.77,89.7528 1548.78,89.7746 1548.78,89.7964 1548.79,89.8181 1548.8,89.8399 1548.81,89.8617 1548.82,89.8835 1548.83,89.9053 1548.84,89.9271 1548.85,89.9489 1548.86,89.9707 1548.87,89.9925 1548.88,90.0143 1548.89,90.0362 1548.9,90.058 1548.9,90.0798 1548.91,90.1017 1548.92,90.1236 1548.93,90.1454 1548.94,90.1673 1548.95,90.1892 1548.96,90.211 1548.97,90.2329 1548.98,90.2548 1548.99,90.2767 1549,90.2986 1549.01,90.3205 1549.01,90.3424 1549.02,90.3644 1549.03,90.3863 1549.04,90.4082 1549.05,90.4302 1549.06,90.4521 1549.07,90.4741 1549.08,90.496 1549.09,90.518 1549.1,90.54 1549.11,90.562 1549.12,90.5839 1549.12,90.6059 1549.13,90.6279 1549.14,90.6499 1549.15,90.6719 1549.16,90.6939 1549.17,90.716 1549.18,90.738 1549.19,90.76 1549.2,90.7821 1549.21,90.8041 1549.22,90.8262 1549.23,90.8482 1549.24,90.8703 1549.24,90.8923 1549.25,90.9144 1549.26,90.9365 1549.27,90.9586 1549.28,90.9807 1549.29,91.0028 1549.3,91.0249 1549.31,91.047 1549.32,91.0691 1549.33,91.0912 1549.34,91.1134 1549.35,91.1355 1549.35,91.1576 1549.36,91.1798 1549.37,91.2019 1549.38,91.2241 1549.39,91.2462 1549.4,91.2684 1549.41,91.2906 1549.42,91.3128 1549.43,91.335 1549.44,91.3572 1549.45,91.3794 1549.46,91.4016 1549.46,91.4238 1549.47,91.446 1549.48,91.4682 1549.49,91.4904 1549.5,91.5127 1549.51,91.5349 1549.52,91.5572 1549.53,91.5794 1549.54,91.6017 1549.55,91.6239 1549.56,91.6462 1549.57,91.6685 1549.58,91.6908 1549.58,91.7131 1549.59,91.7354 1549.6,91.7577 1549.61,91.78 1549.62,91.8023 1549.63,91.8246 1549.64,91.8469 1549.65,91.8692 1549.66,91.8916 1549.67,91.9139 1549.68,91.9363 1549.69,91.9586 1549.69,91.981 1549.7,92.0033 1549.71,92.0257 1549.72,92.0481 1549.73,92.0705 1549.74,92.0929 1549.75,92.1153 1549.76,92.1376 1549.77,92.1601 1549.78,92.1825 1549.79,92.2049 1549.8,92.2273 1549.8,92.2497 1549.81,92.2722 1549.82,92.2946 1549.83,92.3171 1549.84,92.3395 1549.85,92.362 1549.86,92.3844 1549.87,92.4069 1549.88,92.4294 1549.89,92.4519 1549.9,92.4743 1549.91,92.4968 1549.92,92.5193 1549.92,92.5418 1549.93,92.5643 1549.94,92.5869 1549.95,92.6094 1549.96,92.6319 1549.97,92.6544 1549.98,92.677 1549.99,92.6995 1550,92.7221 1550.01,92.7446 1550.02,92.7672 1550.03,92.7898 1550.03,92.8123 1550.04,92.8349 1550.05,92.8575 1550.06,92.8801 1550.07,92.9027 1550.08,92.9253 1550.09,92.9479 1550.1,92.9705 1550.11,92.9931 1550.12,93.0158 1550.13,93.0384 1550.14,93.061 1550.14,93.0837 1550.15,93.1063 1550.16,93.129 1550.17,93.1516 1550.18,93.1743 1550.19,93.197 1550.2,93.2196 1550.21,93.2423 1550.22,93.265 1550.23,93.2877 1550.24,93.3104 1550.25,93.3331 1550.26,93.3558 1550.26,93.3785 1550.27,93.4012 1550.28,93.424 1550.29,93.4467 1550.3,93.4694 1550.31,93.4922 1550.32,93.5149 1550.33,93.5377 1550.34,93.5604 1550.35,93.5832 1550.36,93.606 1550.37,93.6288 1550.37,93.6515 1550.38,93.6743 1550.39,93.6971 1550.4,93.7199 1550.41,93.7427 1550.42,93.7656 1550.43,93.7884 1550.44,93.8112 1550.45,93.834 1550.46,93.8569 1550.47,93.8797 1550.48,93.9025 1550.48,93.9254 1550.49,93.9482 1550.5,93.9711 1550.51,93.994 1550.52,94.0168 1550.53,94.0397 1550.54,94.0626 1550.55,94.0855 1550.56,94.1084 1550.57,94.1313 1550.58,94.1542 1550.59,94.1771 1550.6,94.2 1550.6,94.223 1550.61,94.2459 1550.62,94.2688 1550.63,94.2918 1550.64,94.3147 1550.65,94.3377 1550.66,94.3606 1550.67,94.3836 1550.68,94.4065 1550.69,94.4295 1550.7,94.4525 1550.71,94.4755 1550.71,94.4985 1550.72,94.5215 1550.73,94.5445 1550.74,94.5675 1550.75,94.5905 1550.76,94.6135 1550.77,94.6365 1550.78,94.6595 1550.79,94.6826 1550.8,94.7056 1550.81,94.7287 1550.82,94.7517 1550.82,94.7748 1550.83,94.7978 1550.84,94.8209 1550.85,94.844 1550.86,94.867 1550.87,94.8901 1550.88,94.9132 1550.89,94.9363 1550.9,94.9594 1550.91,94.9825 1550.92,95.0056 1550.93,95.0287 1550.94,95.0519 1550.94,95.075 1550.95,95.0981 1550.96,95.1213 1550.97,95.1444 1550.98,95.1675 1550.99,95.1907 1551,95.2139 1551.01,95.237 1551.02,95.2602 1551.03,95.2834 1551.04,95.3065 1551.05,95.3297 1551.05,95.3529 1551.06,95.3761 1551.07,95.3993 1551.08,95.4225 1551.09,95.4457 1551.1,95.469 1551.11,95.4922 1551.12,95.5154 1551.13,95.5387 1551.14,95.5619 1551.15,95.5851 1551.16,95.6084 1551.16,95.6316 1551.17,95.6549 1551.18,95.6782 1551.19,95.7014 1551.2,95.7247 1551.21,95.748 1551.22,95.7713 1551.23,95.7946 1551.24,95.8179 1551.25,95.8412 1551.26,95.8645 1551.27,95.8878 1551.28,95.9111 1551.28,95.9345 1551.29,95.9578 1551.3,95.9811 1551.31,96.0045 1551.32,96.0278 1551.33,96.0512 1551.34,96.0745 1551.35,96.0979 1551.36,96.1213 1551.37,96.1446 1551.38,96.168 1551.39,96.1914 1551.39,96.2148 1551.4,96.2382 1551.41,96.2616 1551.42,96.285 1551.43,96.3084 1551.44,96.3318 1551.45,96.3552 1551.46,96.3787 1551.47,96.4021 1551.48,96.4255 1551.49,96.449 1551.5,96.4724 1551.5,96.4959 1551.51,96.5193 1551.52,96.5428 1551.53,96.5663 1551.54,96.5897 1551.55,96.6132 1551.56,96.6367 1551.57,96.6602 1551.58,96.6837 1551.59,96.7072 1551.6,96.7307 1551.61,96.7542 1551.62,96.7777 1551.62,96.8012 1551.63,96.8248 1551.64,96.8483 1551.65,96.8718 1551.66,96.8954 1551.67,96.9189 1551.68,96.9425 1551.69,96.966 1551.7,96.9896 1551.71,97.0131 1551.72,97.0367 1551.73,97.0603 1551.73,97.0839 1551.74,97.1075 1551.75,97.1311 1551.76,97.1547 1551.77,97.1783 1551.78,97.2019 1551.79,97.2255 1551.8,97.2491 1551.81,97.2727 1551.82,97.2964 1551.83,97.32 1551.84,97.3436 1551.84,97.3673 1551.85,97.3909 1551.86,97.4146 1551.87,97.4383 1551.88,97.4619 1551.89,97.4856 1551.9,97.5093 1551.91,97.5329 1551.92,97.5566 1551.93,97.5803 1551.94,97.604 1551.95,97.6277 1551.96,97.6514 1551.96,97.6751 1551.97,97.6989 1551.98,97.7226 1551.99,97.7463 1552,97.77 1552.01,97.7938 1552.02,97.8175 1552.03,97.8413 1552.04,97.865 1552.05,97.8888 1552.06,97.9125 1552.07,97.9363 1552.07,97.9601 1552.08,97.9839 1552.09,98.0076 1552.1,98.0314 1552.11,98.0552 1552.12,98.079 1552.13,98.1028 1552.14,98.1266 1552.15,98.1505 1552.16,98.1743 1552.17,98.1981 1552.18,98.2219 1552.18,98.2458 1552.19,98.2696 1552.2,98.2934 1552.21,98.3173 1552.22,98.3411 1552.23,98.365 1552.24,98.3889 1552.25,98.4127 1552.26,98.4366 1552.27,98.4605 1552.28,98.4844 1552.29,98.5083 1552.3,98.5322 1552.3,98.5561 1552.31,98.58 1552.32,98.6039 1552.33,98.6278 1552.34,98.6517 1552.35,98.6756 1552.36,98.6996 1552.37,98.7235 1552.38,98.7474 1552.39,98.7714 1552.4,98.7953 1552.41,98.8193 1552.41,98.8432 1552.42,98.8672 1552.43,98.8912 1552.44,98.9151 1552.45,98.9391 1552.46,98.9631 1552.47,98.9871 1552.48,99.0111 1552.49,99.0351 1552.5,99.0591 1552.51,99.0831 1552.52,99.1071 1552.52,99.1311 1552.53,99.1552 1552.54,99.1792 1552.55,99.2032 1552.56,99.2273 1552.57,99.2513 1552.58,99.2754 1552.59,99.2994 1552.6,99.3235 1552.61,99.3475 1552.62,99.3716 1552.63,99.3957 1552.64,99.4197 1552.64,99.4438 1552.65,99.4679 1552.66,99.492 1552.67,99.5161 1552.68,99.5402 1552.69,99.5643 1552.7,99.5884 1552.71,99.6125 1552.72,99.6367 1552.73,99.6608 1552.74,99.6849 1552.75,99.7091 1552.75,99.7332 1552.76,99.7574 1552.77,99.7815 1552.78,99.8057 1552.79,99.8298 1552.8,99.854 1552.81,99.8782 1552.82,99.9023 1552.83,99.9265 1552.84,99.9507 1552.85,99.9749 1552.86,99.9991 1552.86,100.023 1552.87,100.047 1552.88,100.072 1552.89,100.096 1552.9,100.12 1552.91,100.144 1552.92,100.169 1552.93,100.193 1552.94,100.217 1552.95,100.241 1552.96,100.266 1552.97,100.29 1552.98,100.314 1552.98,100.338 1552.99,100.363 1553,100.387 1553.01,100.411 1553.02,100.435 1553.03,100.46 1553.04,100.484 1553.05,100.508 1553.06,100.533 1553.07,100.557 1553.08,100.581 1553.09,100.606 1553.09,100.63 1553.1,100.654 1553.11,100.678 1553.12,100.703 1553.13,100.727 1553.14,100.752 1553.15,100.776 1553.16,100.8 1553.17,100.825 1553.18,100.849 1553.19,100.873 1553.2,100.898 1553.2,100.922 1553.21,100.946 1553.22,100.971 1553.23,100.995 1553.24,101.02 1553.25,101.044 1553.26,101.068 1553.27,101.093 1553.28,101.117 1553.29,101.142 1553.3,101.166 1553.31,101.19 1553.32,101.215 1553.32,101.239 1553.33,101.264 1553.34,101.288 1553.35,101.313 1553.36,101.337 1553.37,101.362 1553.38,101.386 1553.39,101.411 1553.4,101.435 1553.41,101.46 1553.42,101.484 1553.43,101.508 1553.43,101.533 1553.44,101.557 1553.45,101.582 1553.46,101.607 1553.47,101.631 1553.48,101.656 1553.49,101.68 1553.5,101.705 1553.51,101.729 1553.52,101.754 1553.53,101.778 1553.54,101.803 1553.54,101.827 1553.55,101.852 1553.56,101.876 1553.57,101.901 1553.58,101.926 1553.59,101.95 1553.6,101.975 1553.61,101.999 1553.62,102.024 1553.63,102.048 1553.64,102.073 1553.65,102.098 1553.66,102.122 1553.66,102.147 1553.67,102.171 1553.68,102.196 1553.69,102.221 1553.7,102.245 1553.71,102.27 1553.72,102.295 1553.73,102.319 1553.74,102.344 1553.75,102.369 1553.76,102.393 1553.77,102.418 1553.77,102.443 1553.78,102.467 1553.79,102.492 1553.8,102.517 1553.81,102.541 1553.82,102.566 1553.83,102.591 1553.84,102.615 1553.85,102.64 1553.86,102.665 1553.87,102.689 1553.88,102.714 1553.88,102.739 1553.89,102.764 1553.9,102.788 1553.91,102.813 1553.92,102.838 1553.93,102.863 1553.94,102.887 1553.95,102.912 1553.96,102.937 1553.97,102.962 1553.98,102.986 1553.99,103.011 1554,103.036 1554,103.061 1554.01,103.085 1554.02,103.11 1554.03,103.135 1554.04,103.16 1554.05,103.185 1554.06,103.209 1554.07,103.234 1554.08,103.259 1554.09,103.284 1554.1,103.309 1554.11,103.334 1554.11,103.358 1554.12,103.383 1554.13,103.408 1554.14,103.433 1554.15,103.458 1554.16,103.483 1554.17,103.507 1554.18,103.532 1554.19,103.557 1554.2,103.582 1554.21,103.607 1554.22,103.632 1554.22,103.657 1554.23,103.682 1554.24,103.706 1554.25,103.731 1554.26,103.756 1554.27,103.781 1554.28,103.806 1554.29,103.831 1554.3,103.856 1554.31,103.881 1554.32,103.906 1554.33,103.931 1554.34,103.956 1554.34,103.981 1554.35,104.006 1554.36,104.03 1554.37,104.055 1554.38,104.08 1554.39,104.105 1554.4,104.13 1554.41,104.155 1554.42,104.18 1554.43,104.205 1554.44,104.23 1554.45,104.255 1554.45,104.28 1554.46,104.305 1554.47,104.33 1554.48,104.355 1554.49,104.38 1554.5,104.405 1554.51,104.43 1554.52,104.455 1554.53,104.48 1554.54,104.505 1554.55,104.53 1554.56,104.555 1554.56,104.581 1554.57,104.606 1554.58,104.631 1554.59,104.656 1554.6,104.681 1554.61,104.706 1554.62,104.731 1554.63,104.756 1554.64,104.781 1554.65,104.806 1554.66,104.831 1554.67,104.856 1554.68,104.881 1554.68,104.907 1554.69,104.932 1554.7,104.957 1554.71,104.982 1554.72,105.007 1554.73,105.032 1554.74,105.057 1554.75,105.082 1554.76,105.108 1554.77,105.133 1554.78,105.158 1554.79,105.183 1554.79,105.208 1554.8,105.233 1554.81,105.258 1554.82,105.284 1554.83,105.309 1554.84,105.334 1554.85,105.359 1554.86,105.384 1554.87,105.41 1554.88,105.435 1554.89,105.46 1554.9,105.485 1554.9,105.51 1554.91,105.536 1554.92,105.561 1554.93,105.586 1554.94,105.611 1554.95,105.636 1554.96,105.662 1554.97,105.687 1554.98,105.712 1554.99,105.737 1555,105.763 1555.01,105.788 1555.02,105.813 1555.02,105.838 1555.03,105.864 1555.04,105.889 1555.05,105.914 1555.06,105.94 1555.07,105.965 1555.08,105.99 1555.09,106.015 1555.1,106.041 1555.11,106.066 1555.12,106.091 1555.13,106.117 1555.13,106.142 1555.14,106.167 1555.15,106.193 1555.16,106.218 1555.17,106.243 1555.18,106.269 1555.19,106.294 1555.2,106.319 1555.21,106.345 1555.22,106.37 1555.23,106.395 1555.24,106.421 1555.24,106.446 1555.25,106.471 1555.26,106.497 1555.27,106.522 1555.28,106.547 1555.29,106.573 1555.3,106.598 1555.31,106.624 1555.32,106.649 1555.33,106.674 1555.34,106.7 1555.35,106.725 1555.36,106.751 1555.36,106.776 1555.37,106.801 1555.38,106.827 1555.39,106.852 1555.4,106.878 1555.41,106.903 1555.42,106.929 1555.43,106.954 1555.44,106.98 1555.45,107.005 1555.46,107.03 1555.47,107.056 1555.47,107.081 1555.48,107.107 1555.49,107.132 1555.5,107.158 1555.51,107.183 1555.52,107.209 1555.53,107.234 1555.54,107.26 1555.55,107.285 1555.56,107.311 1555.57,107.336 1555.58,107.362 1555.59,107.387 1555.59,107.413 1555.6,107.438 1555.61,107.464 1555.62,107.489 1555.63,107.515 1555.64,107.54 1555.65,107.566 1555.66,107.592 1555.67,107.617 1555.68,107.643 1555.69,107.668 1555.7,107.694 1555.7,107.719 1555.71,107.745 1555.72,107.77 1555.73,107.796 1555.74,107.822 1555.75,107.847 1555.76,107.873 1555.77,107.898 1555.78,107.924 1555.79,107.95 1555.8,107.975 1555.81,108.001 1555.81,108.026 1555.82,108.052 1555.83,108.078 1555.84,108.103 1555.85,108.129 1555.86,108.155 1555.87,108.18 1555.88,108.206 1555.89,108.231 1555.9,108.257 1555.91,108.283 1555.92,108.308 1555.93,108.334 1555.93,108.36 1555.94,108.385 1555.95,108.411 1555.96,108.437 1555.97,108.462 1555.98,108.488 1555.99,108.514 1556,108.54 1556.01,108.565 1556.02,108.591 1556.03,108.617 1556.04,108.642 1556.04,108.668 1556.05,108.694 1556.06,108.719 1556.07,108.745 1556.08,108.771 1556.09,108.797 1556.1,108.822 1556.11,108.848 1556.12,108.874 1556.13,108.9 1556.14,108.925 1556.15,108.951 1556.15,108.977 1556.16,109.003 1556.17,109.028 1556.18,109.054 1556.19,109.08 1556.2,109.106 1556.21,109.132 1556.22,109.157 1556.23,109.183 1556.24,109.209 1556.25,109.235 1556.26,109.261 1556.27,109.286 1556.27,109.312 1556.28,109.338 1556.29,109.364 1556.3,109.39 1556.31,109.415 1556.32,109.441 1556.33,109.467 1556.34,109.493 1556.35,109.519 1556.36,109.545 1556.37,109.57 1556.38,109.596 1556.38,109.622 1556.39,109.648 1556.4,109.674 1556.41,109.7 1556.42,109.726 1556.43,109.752 1556.44,109.777 1556.45,109.803 1556.46,109.829 1556.47,109.855 1556.48,109.881 1556.49,109.907 1556.49,109.933 1556.5,109.959 1556.51,109.985 1556.52,110.011 1556.53,110.036 1556.54,110.062 1556.55,110.088 1556.56,110.114 1556.57,110.14 1556.58,110.166 1556.59,110.192 1556.6,110.218 1556.61,110.244 1556.61,110.27 1556.62,110.296 1556.63,110.322 1556.64,110.348 1556.65,110.374 1556.66,110.4 1556.67,110.426 1556.68,110.452 1556.69,110.478 1556.7,110.504 1556.71,110.53 1556.72,110.556 1556.72,110.582 1556.73,110.608 1556.74,110.634 1556.75,110.66 1556.76,110.686 1556.77,110.712 1556.78,110.738 1556.79,110.764 1556.8,110.79 1556.81,110.816 1556.82,110.842 1556.83,110.868 1556.83,110.894 1556.84,110.92 1556.85,110.946 1556.86,110.972 1556.87,110.998 1556.88,111.024 1556.89,111.05 1556.9,111.076 1556.91,111.102 1556.92,111.128 1556.93,111.154 1556.94,111.181 1556.95,111.207 1556.95,111.233 1556.96,111.259 1556.97,111.285 1556.98,111.311 1556.99,111.337 1557,111.363 1557.01,111.389 1557.02,111.415 1557.03,111.442 1557.04,111.468 1557.05,111.494 1557.06,111.52 1557.06,111.546 1557.07,111.572 1557.08,111.598 1557.09,111.625 1557.1,111.651 1557.11,111.677 1557.12,111.703 1557.13,111.729 1557.14,111.755 1557.15,111.781 1557.16,111.808 1557.17,111.834 1557.17,111.86 1557.18,111.886 1557.19,111.912 1557.2,111.939 1557.21,111.965 1557.22,111.991 1557.23,112.017 1557.24,112.043 1557.25,112.07 1557.26,112.096 1557.27,112.122 1557.28,112.148 1557.29,112.174 1557.29,112.201 1557.3,112.227 1557.31,112.253 1557.32,112.279 1557.33,112.306 1557.34,112.332 1557.35,112.358 1557.36,112.384 1557.37,112.411 1557.38,112.437 1557.39,112.463 1557.4,112.489 1557.4,112.516 1557.41,112.542 1557.42,112.568 1557.43,112.594 1557.44,112.621 1557.45,112.647 1557.46,112.673 1557.47,112.7 1557.48,112.726 1557.49,112.752 1557.5,112.779 1557.51,112.805 1557.51,112.831 1557.52,112.857 1557.53,112.884 1557.54,112.91 1557.55,112.936 1557.56,112.963 1557.57,112.989 1557.58,113.015 1557.59,113.042 1557.6,113.068 1557.61,113.094 1557.62,113.121 1557.63,113.147 1557.63,113.174 1557.64,113.2 1557.65,113.226 1557.66,113.253 1557.67,113.279 1557.68,113.305 1557.69,113.332 1557.7,113.358 1557.71,113.385 1557.72,113.411 1557.73,113.437 1557.74,113.464 1557.74,113.49 1557.75,113.516 1557.76,113.543 1557.77,113.569 1557.78,113.596 1557.79,113.622 1557.8,113.649 1557.81,113.675 1557.82,113.701 1557.83,113.728 1557.84,113.754 1557.85,113.781 1557.85,113.807 1557.86,113.834 1557.87,113.86 1557.88,113.886 1557.89,113.913 1557.9,113.939 1557.91,113.966 1557.92,113.992 1557.93,114.019 1557.94,114.045 1557.95,114.072 1557.96,114.098 1557.97,114.125 1557.97,114.151 1557.98,114.178 1557.99,114.204 1558,114.231 1558.01,114.257 1558.02,114.284 1558.03,114.31 1558.04,114.337 1558.05,114.363 1558.06,114.39 1558.07,114.416 1558.08,114.443 1558.08,114.469 1558.09,114.496 1558.1,114.522 1558.11,114.549 1558.12,114.575 1558.13,114.602 1558.14,114.629 1558.15,114.655 1558.16,114.682 1558.17,114.708 1558.18,114.735 1558.19,114.761 1558.19,114.788 1558.2,114.814 1558.21,114.841 1558.22,114.868 1558.23,114.894 1558.24,114.921 1558.25,114.947 1558.26,114.974 1558.27,115.001 1558.28,115.027 1558.29,115.054 1558.3,115.08 1558.31,115.107 1558.31,115.134 1558.32,115.16 1558.33,115.187 1558.34,115.213 1558.35,115.24 1558.36,115.267 1558.37,115.293 1558.38,115.32 1558.39,115.347 1558.4,115.373 1558.41,115.4 1558.42,115.426 1558.42,115.453 1558.43,115.48 1558.44,115.506 1558.45,115.533 1558.46,115.56 1558.47,115.586 1558.48,115.613 1558.49,115.64 1558.5,115.666 1558.51,115.693 1558.52,115.72 1558.53,115.747 1558.53,115.773 1558.54,115.8 1558.55,115.827 1558.56,115.853 1558.57,115.88 1558.58,115.907 1558.59,115.933 1558.6,115.96 1558.61,115.987 1558.62,116.014 1558.63,116.04 1558.64,116.067 1558.65,116.094 1558.65,116.12 1558.66,116.147 1558.67,116.174 1558.68,116.201 1558.69,116.227 1558.7,116.254 1558.71,116.281 1558.72,116.308 1558.73,116.334 1558.74,116.361 1558.75,116.388 1558.76,116.415 1558.76,116.442 1558.77,116.468 1558.78,116.495 1558.79,116.522 1558.8,116.549 1558.81,116.575 1558.82,116.602 1558.83,116.629 1558.84,116.656 1558.85,116.683 1558.86,116.709 1558.87,116.736 1558.87,116.763 1558.88,116.79 1558.89,116.817 1558.9,116.843 1558.91,116.87 1558.92,116.897 1558.93,116.924 1558.94,116.951 1558.95,116.978 1558.96,117.004 1558.97,117.031 1558.98,117.058 1558.99,117.085 1558.99,117.112 1559,117.139 1559.01,117.166 1559.02,117.192 1559.03,117.219 1559.04,117.246 1559.05,117.273 1559.06,117.3 1559.07,117.327 1559.08,117.354 1559.09,117.381 1559.1,117.407 1559.1,117.434 1559.11,117.461 1559.12,117.488 1559.13,117.515 1559.14,117.542 1559.15,117.569 1559.16,117.596 1559.17,117.623 1559.18,117.65 1559.19,117.677 1559.2,117.703 1559.21,117.73 1559.21,117.757 1559.22,117.784 1559.23,117.811 1559.24,117.838 1559.25,117.865 1559.26,117.892 1559.27,117.919 1559.28,117.946 1559.29,117.973 1559.3,118 1559.31,118.027 1559.32,118.054 1559.33,118.081 1559.33,118.108 1559.34,118.135 1559.35,118.162 1559.36,118.189 1559.37,118.216 1559.38,118.243 1559.39,118.27 1559.4,118.296 1559.41,118.323 1559.42,118.35 1559.43,118.377 1559.44,118.404 1559.44,118.431 1559.45,118.459 1559.46,118.486 1559.47,118.513 1559.48,118.54 1559.49,118.567 1559.5,118.594 1559.51,118.621 1559.52,118.648 1559.53,118.675 1559.54,118.702 1559.55,118.729 1559.55,118.756 1559.56,118.783 1559.57,118.81 1559.58,118.837 1559.59,118.864 1559.6,118.891 1559.61,118.918 1559.62,118.945 1559.63,118.972 1559.64,118.999 1559.65,119.026 1559.66,119.053 1559.67,119.081 1559.67,119.108 1559.68,119.135 1559.69,119.162 1559.7,119.189 1559.71,119.216 1559.72,119.243 1559.73,119.27 1559.74,119.297 1559.75,119.324 1559.76,119.351 1559.77,119.379 1559.78,119.406 1559.78,119.433 1559.79,119.46 1559.8,119.487 1559.81,119.514 1559.82,119.541 1559.83,119.568 1559.84,119.596 1559.85,119.623 1559.86,119.65 1559.87,119.677 1559.88,119.704 1559.89,119.731 1559.89,119.758 1559.9,119.786 1559.91,119.813 1559.92,119.84 1559.93,119.867 1559.94,119.894 1559.95,119.921 1559.96,119.949 1559.97,119.976 1559.98,120.003 1559.99,120.03 1560,120.057 1560.01,120.085 1560.01,120.112 1560.02,120.139 1560.03,120.166 1560.04,120.193 1560.05,120.221 1560.06,120.248 1560.07,120.275 1560.08,120.302 1560.09,120.329 1560.1,120.357 1560.11,120.384 1560.12,120.411 1560.12,120.438 1560.13,120.466 1560.14,120.493 1560.15,120.52 1560.16,120.547 1560.17,120.574 1560.18,120.602 1560.19,120.629 1560.2,120.656 1560.21,120.683 1560.22,120.711 1560.23,120.738 1560.23,120.765 1560.24,120.792 1560.25,120.82 1560.26,120.847 1560.27,120.874 1560.28,120.902 1560.29,120.929 1560.3,120.956 1560.31,120.983 1560.32,121.011 1560.33,121.038 1560.34,121.065 1560.35,121.093 1560.35,121.12 1560.36,121.147 1560.37,121.175 1560.38,121.202 1560.39,121.229 1560.4,121.256 1560.41,121.284 1560.42,121.311 1560.43,121.338 1560.44,121.366 1560.45,121.393 1560.46,121.42 1560.46,121.448 1560.47,121.475 1560.48,121.502 1560.49,121.53 1560.5,121.557 1560.51,121.584 1560.52,121.612 1560.53,121.639 1560.54,121.666 1560.55,121.694 1560.56,121.721 1560.57,121.749 1560.57,121.776 1560.58,121.803 1560.59,121.831 1560.6,121.858 1560.61,121.885 1560.62,121.913 1560.63,121.94 1560.64,121.968 1560.65,121.995 1560.66,122.022 1560.67,122.05 1560.68,122.077 1560.69,122.105 1560.69,122.132 1560.7,122.159 1560.71,122.187 1560.72,122.214 1560.73,122.242 1560.74,122.269 1560.75,122.296 1560.76,122.324 1560.77,122.351 1560.78,122.379 1560.79,122.406 1560.8,122.434 1560.8,122.461 1560.81,122.488 1560.82,122.516 1560.83,122.543 1560.84,122.571 1560.85,122.598 1560.86,122.626 1560.87,122.653 1560.88,122.681 1560.89,122.708 1560.9,122.736 1560.91,122.763 1560.91,122.79 1560.92,122.818 1560.93,122.845 1560.94,122.873 1560.95,122.9 1560.96,122.928 1560.97,122.955 1560.98,122.983 1560.99,123.01 1561,123.038 1561.01,123.065 1561.02,123.093 1561.03,123.12 1561.03,123.148 1561.04,123.175 1561.05,123.203 1561.06,123.23 1561.07,123.258 1561.08,123.285 1561.09,123.313 1561.1,123.34 1561.11,123.368 1561.12,123.395 1561.13,123.423 1561.14,123.451 1561.14,123.478 1561.15,123.506 1561.16,123.533 1561.17,123.561 1561.18,123.588 1561.19,123.616 1561.2,123.643 1561.21,123.671 1561.22,123.698 1561.23,123.726 1561.24,123.754 1561.25,123.781 1561.25,123.809 1561.26,123.836 1561.27,123.864 1561.28,123.891 1561.29,123.919 1561.3,123.947 1561.31,123.974 1561.32,124.002 1561.33,124.029 1561.34,124.057 1561.35,124.085 1561.36,124.112 1561.37,124.14 1561.37,124.167 1561.38,124.195 1561.39,124.223 1561.4,124.25 1561.41,124.278 1561.42,124.305 1561.43,124.333 1561.44,124.361 1561.45,124.388 1561.46,124.416 1561.47,124.444 1561.48,124.471 1561.48,124.499 1561.49,124.527 1561.5,124.554 1561.51,124.582 1561.52,124.609 1561.53,124.637 1561.54,124.665 1561.55,124.692 1561.56,124.72 1561.57,124.748 1561.58,124.775 1561.59,124.803 1561.59,124.831 1561.6,124.858 1561.61,124.886 1561.62,124.914 1561.63,124.941 1561.64,124.969 1561.65,124.997 1561.66,125.024 1561.67,125.052 1561.68,125.08 1561.69,125.108 1561.7,125.135 1561.71,125.163 1561.71,125.191 1561.72,125.218 1561.73,125.246 1561.74,125.274 1561.75,125.301 1561.76,125.329 1561.77,125.357 1561.78,125.385 1561.79,125.412 1561.8,125.44 1561.81,125.468 1561.82,125.495 1561.82,125.523 1561.83,125.551 1561.84,125.579 1561.85,125.606 1561.86,125.634 1561.87,125.662 1561.88,125.69 1561.89,125.717 1561.9,125.745 1561.91,125.773 1561.92,125.801 1561.93,125.828 1561.93,125.856 1561.94,125.884 1561.95,125.912 1561.96,125.939 1561.97,125.967 1561.98,125.995 1561.99,126.023 1562,126.051 1562.01,126.078 1562.02,126.106 1562.03,126.134 1562.04,126.162 1562.05,126.189 1562.05,126.217 1562.06,126.245 1562.07,126.273 1562.08,126.301 1562.09,126.328 1562.1,126.356 1562.11,126.384 1562.12,126.412 1562.13,126.44 1562.14,126.468 1562.15,126.495 1562.16,126.523 1562.16,126.551 1562.17,126.579 1562.18,126.607 1562.19,126.634 1562.2,126.662 1562.21,126.69 1562.22,126.718 1562.23,126.746 1562.24,126.774 1562.25,126.802 1562.26,126.829 1562.27,126.857 1562.27,126.885 1562.28,126.913 1562.29,126.941 1562.3,126.969 1562.31,126.996 1562.32,127.024 1562.33,127.052 1562.34,127.08 1562.35,127.108 1562.36,127.136 1562.37,127.164 1562.38,127.192 1562.39,127.219 1562.39,127.247 1562.4,127.275 1562.41,127.303 1562.42,127.331 1562.43,127.359 1562.44,127.387 1562.45,127.415 1562.46,127.443 1562.47,127.471 1562.48,127.498 1562.49,127.526 1562.5,127.554 1562.5,127.582 1562.51,127.61 1562.52,127.638 1562.53,127.666 1562.54,127.694 1562.55,127.722 1562.56,127.75 1562.57,127.778 1562.58,127.806 1562.59,127.833 1562.6,127.861 1562.61,127.889 1562.61,127.917 1562.62,127.945 1562.63,127.973 1562.64,128.001 1562.65,128.029 1562.66,128.057 1562.67,128.085 1562.68,128.113 1562.69,128.141 1562.7,128.169 1562.71,128.197 1562.72,128.225 1562.73,128.253 1562.73,128.281 1562.74,128.309 1562.75,128.337 1562.76,128.365 1562.77,128.393 1562.78,128.421 1562.79,128.449 1562.8,128.477 1562.81,128.505 1562.82,128.533 1562.83,128.561 1562.84,128.589 1562.84,128.617 1562.85,128.645 1562.86,128.673 1562.87,128.701 1562.88,128.729 1562.89,128.757 1562.9,128.785 1562.91,128.813 1562.92,128.841 1562.93,128.869 1562.94,128.897 1562.95,128.925 1562.95,128.953 1562.96,128.981 1562.97,129.009 1562.98,129.037 1562.99,129.065 1563,129.093 1563.01,129.121 1563.02,129.149 1563.03,129.177 1563.04,129.205 1563.05,129.233 1563.06,129.261 1563.07,129.289 1563.07,129.317 1563.08,129.345 1563.09,129.373 1563.1,129.402 1563.11,129.43 1563.12,129.458 1563.13,129.486 1563.14,129.514 1563.15,129.542 1563.16,129.57 1563.17,129.598 1563.18,129.626 1563.18,129.654 1563.19,129.682 1563.2,129.71 1563.21,129.739 1563.22,129.767 1563.23,129.795 1563.24,129.823 1563.25,129.851 1563.26,129.879 1563.27,129.907 1563.28,129.935 1563.29,129.963 1563.29,129.991 1563.3,130.02 1563.31,130.048 1563.32,130.076 1563.33,130.104 1563.34,130.132 1563.35,130.16 1563.36,130.188 1563.37,130.216 1563.38,130.245 1563.39,130.273 1563.4,130.301 1563.41,130.329 1563.41,130.357 1563.42,130.385 1563.43,130.413 1563.44,130.442 1563.45,130.47 1563.46,130.498 1563.47,130.526 1563.48,130.554 1563.49,130.582 1563.5,130.61 1563.51,130.639 1563.52,130.667 1563.52,130.695 1563.53,130.723 1563.54,130.751 1563.55,130.779 1563.56,130.808 1563.57,130.836 1563.58,130.864 1563.59,130.892 1563.6,130.92 1563.61,130.949 1563.62,130.977 1563.63,131.005 1563.63,131.033 1563.64,131.061 1563.65,131.089 1563.66,131.118 1563.67,131.146 1563.68,131.174 1563.69,131.202 1563.7,131.231 1563.71,131.259 1563.72,131.287 1563.73,131.315 1563.74,131.343 1563.75,131.372 1563.75,131.4 1563.76,131.428 1563.77,131.456 1563.78,131.484 1563.79,131.513 1563.8,131.541 1563.81,131.569 1563.82,131.597 1563.83,131.626 1563.84,131.654 1563.85,131.682 1563.86,131.71 1563.86,131.739 1563.87,131.767 1563.88,131.795 1563.89,131.823 1563.9,131.852 1563.91,131.88 1563.92,131.908 1563.93,131.936 1563.94,131.965 1563.95,131.993 1563.96,132.021 1563.97,132.049 1563.97,132.078 1563.98,132.106 1563.99,132.134 1564,132.163 1564.01,132.191 1564.02,132.219 1564.03,132.247 1564.04,132.276 1564.05,132.304 1564.06,132.332 1564.07,132.361 1564.08,132.389 1564.09,132.417 1564.09,132.445 1564.1,132.474 1564.11,132.502 1564.12,132.53 1564.13,132.559 1564.14,132.587 1564.15,132.615 1564.16,132.644 1564.17,132.672 1564.18,132.7 1564.19,132.729 1564.2,132.757 1564.2,132.785 1564.21,132.814 1564.22,132.842 1564.23,132.87 1564.24,132.899 1564.25,132.927 1564.26,132.955 1564.27,132.984 1564.28,133.012 1564.29,133.04 1564.3,133.069 1564.31,133.097 1564.31,133.125 1564.32,133.154 1564.33,133.182 1564.34,133.21 1564.35,133.239 1564.36,133.267 1564.37,133.295 1564.38,133.324 1564.39,133.352 1564.4,133.38 1564.41,133.409 1564.42,133.437 1564.43,133.466 1564.43,133.494 1564.44,133.522 1564.45,133.551 1564.46,133.579 1564.47,133.607 1564.48,133.636 1564.49,133.664 1564.5,133.693 1564.51,133.721 1564.52,133.749 1564.53,133.778 1564.54,133.806 1564.54,133.835 1564.55,133.863 1564.56,133.891 1564.57,133.92 1564.58,133.948 1564.59,133.977 1564.6,134.005 1564.61,134.033 1564.62,134.062 1564.63,134.09 1564.64,134.119 1564.65,134.147 1564.65,134.176 1564.66,134.204 1564.67,134.232 1564.68,134.261 1564.69,134.289 1564.7,134.318 1564.71,134.346 1564.72,134.375 1564.73,134.403 1564.74,134.431 1564.75,134.46 1564.76,134.488 1564.77,134.517 1564.77,134.545 1564.78,134.574 1564.79,134.602 1564.8,134.631 1564.81,134.659 1564.82,134.687 1564.83,134.716 1564.84,134.744 1564.85,134.773 1564.86,134.801 1564.87,134.83 1564.88,134.858 1564.88,134.887 1564.89,134.915 1564.9,134.944 1564.91,134.972 1564.92,135.001 1564.93,135.029 1564.94,135.058 1564.95,135.086 1564.96,135.115 1564.97,135.143 1564.98,135.171 1564.99,135.2 1564.99,135.228 1565,135.257 1565.01,135.285 1565.02,135.314 1565.03,135.342 1565.04,135.371 1565.05,135.399 1565.06,135.428 1565.07,135.456 1565.08,135.485 1565.09,135.514 1565.1,135.542 1565.11,135.571 1565.11,135.599 1565.12,135.628 1565.13,135.656 1565.14,135.685 1565.15,135.713 1565.16,135.742 1565.17,135.77 1565.18,135.799 1565.19,135.827 1565.2,135.856 1565.21,135.884 1565.22,135.913 1565.22,135.941 1565.23,135.97 1565.24,135.999 1565.25,136.027 1565.26,136.056 1565.27,136.084 1565.28,136.113 1565.29,136.141 1565.3,136.17 1565.31,136.198 1565.32,136.227 1565.33,136.255 1565.33,136.284 1565.34,136.313 1565.35,136.341 1565.36,136.37 1565.37,136.398 1565.38,136.427 1565.39,136.455 1565.4,136.484 1565.41,136.513 1565.42,136.541 1565.43,136.57 1565.44,136.598 1565.45,136.627 1565.45,136.656 1565.46,136.684 1565.47,136.713 1565.48,136.741 1565.49,136.77 1565.5,136.798 1565.51,136.827 1565.52,136.856 1565.53,136.884 1565.54,136.913 1565.55,136.941 1565.56,136.97 1565.56,136.999 1565.57,137.027 1565.58,137.056 1565.59,137.085 1565.6,137.113 1565.61,137.142 1565.62,137.17 1565.63,137.199 1565.64,137.228 1565.65,137.256 1565.66,137.285 1565.67,137.313 1565.67,137.342 1565.68,137.371 1565.69,137.399 1565.7,137.428 1565.71,137.457 1565.72,137.485 1565.73,137.514 1565.74,137.543 1565.75,137.571 1565.76,137.6 1565.77,137.628 1565.78,137.657 1565.79,137.686 1565.79,137.714 1565.8,137.743 1565.81,137.772 1565.82,137.8 1565.83,137.829 1565.84,137.858 1565.85,137.886 1565.86,137.915 1565.87,137.944 1565.88,137.972 1565.89,138.001 1565.9,138.03 1565.9,138.058 1565.91,138.087 1565.92,138.116 1565.93,138.144 1565.94,138.173 1565.95,138.202 1565.96,138.23 1565.97,138.259 1565.98,138.288 1565.99,138.317 1566,138.345 1566.01,138.374 1566.01,138.403 1566.02,138.431 1566.03,138.46 1566.04,138.489 1566.05,138.517 1566.06,138.546 1566.07,138.575 1566.08,138.603 1566.09,138.632 1566.1,138.661 1566.11,138.69 1566.12,138.718 1566.13,138.747 1566.13,138.776 1566.14,138.804 1566.15,138.833 1566.16,138.862 1566.17,138.891 1566.18,138.919 1566.19,138.948 1566.2,138.977 1566.21,139.006 1566.22,139.034 1566.23,139.063 1566.24,139.092 1566.24,139.12 1566.25,139.149 1566.26,139.178 1566.27,139.207 1566.28,139.235 1566.29,139.264 1566.3,139.293 1566.31,139.322 1566.32,139.35 1566.33,139.379 1566.34,139.408 1566.35,139.437 1566.35,139.465 1566.36,139.494 1566.37,139.523 1566.38,139.552 1566.39,139.58 1566.4,139.609 1566.41,139.638 1566.42,139.667 1566.43,139.696 1566.44,139.724 1566.45,139.753 1566.46,139.782 1566.47,139.811 1566.47,139.839 1566.48,139.868 1566.49,139.897 1566.5,139.926 1566.51,139.954 1566.52,139.983 1566.53,140.012 1566.54,140.041 1566.55,140.07 1566.56,140.098 1566.57,140.127 1566.58,140.156 1566.58,140.185 1566.59,140.214 1566.6,140.242 1566.61,140.271 1566.62,140.3 1566.63,140.329 1566.64,140.358 1566.65,140.386 1566.66,140.415 1566.67,140.444 1566.68,140.473 1566.69,140.502 1566.69,140.53 1566.7,140.559 1566.71,140.588 1566.72,140.617 1566.73,140.646 1566.74,140.675 1566.75,140.703 1566.76,140.732 1566.77,140.761 1566.78,140.79 1566.79,140.819 1566.8,140.848 1566.81,140.876 1566.81,140.905 1566.82,140.934 1566.83,140.963 1566.84,140.992 1566.85,141.021 1566.86,141.049 1566.87,141.078 1566.88,141.107 1566.89,141.136 1566.9,141.165 1566.91,141.194 1566.92,141.223 1566.92,141.251 1566.93,141.28 1566.94,141.309 1566.95,141.338 1566.96,141.367 1566.97,141.396 1566.98,141.425 1566.99,141.453 1567,141.482 1567.01,141.511 1567.02,141.54 1567.03,141.569 1567.03,141.598 1567.04,141.627 1567.05,141.655 1567.06,141.684 1567.07,141.713 1567.08,141.742 1567.09,141.771 1567.1,141.8 1567.11,141.829 1567.12,141.858 1567.13,141.887 1567.14,141.915 1567.15,141.944 1567.15,141.973 1567.16,142.002 1567.17,142.031 1567.18,142.06 1567.19,142.089 1567.2,142.118 1567.21,142.147 1567.22,142.175 1567.23,142.204 1567.24,142.233 1567.25,142.262 1567.26,142.291 1567.26,142.32 1567.27,142.349 1567.28,142.378 1567.29,142.407 1567.3,142.436 1567.31,142.465 1567.32,142.494 1567.33,142.522 1567.34,142.551 1567.35,142.58 1567.36,142.609 1567.37,142.638 1567.37,142.667 1567.38,142.696 1567.39,142.725 1567.4,142.754 1567.41,142.783 1567.42,142.812 1567.43,142.841 1567.44,142.87 1567.45,142.899 1567.46,142.927 1567.47,142.956 1567.48,142.985 1567.49,143.014 1567.49,143.043 1567.5,143.072 1567.51,143.101 1567.52,143.13 1567.53,143.159 1567.54,143.188 1567.55,143.217 1567.56,143.246 1567.57,143.275 1567.58,143.304 1567.59,143.333 1567.6,143.362 1567.6,143.391 1567.61,143.42 1567.62,143.449 1567.63,143.478 1567.64,143.507 1567.65,143.536 1567.66,143.565 1567.67,143.594 1567.68,143.622 1567.69,143.651 1567.7,143.68 1567.71,143.709 1567.71,143.738 1567.72,143.767 1567.73,143.796 1567.74,143.825 1567.75,143.854 1567.76,143.883 1567.77,143.912 1567.78,143.941 1567.79,143.97 1567.8,143.999 1567.81,144.028 1567.82,144.057 1567.83,144.086 1567.83,144.115 1567.84,144.144 1567.85,144.173 1567.86,144.202 1567.87,144.231 1567.88,144.26 1567.89,144.289 1567.9,144.318 1567.91,144.347 1567.92,144.376 1567.93,144.405 1567.94,144.434 1567.94,144.463 1567.95,144.492 1567.96,144.521 1567.97,144.55 1567.98,144.579 1567.99,144.608 1568,144.637 1568.01,144.667 1568.02,144.696 1568.03,144.725 1568.04,144.754 1568.05,144.783 1568.05,144.812 1568.06,144.841 1568.07,144.87 1568.08,144.899 1568.09,144.928 1568.1,144.957 1568.11,144.986 1568.12,145.015 1568.13,145.044 1568.14,145.073 1568.15,145.102 1568.16,145.131 1568.17,145.16 1568.17,145.189 1568.18,145.218 1568.19,145.247 1568.2,145.276 1568.21,145.305 1568.22,145.334 1568.23,145.364 1568.24,145.393 1568.25,145.422 1568.26,145.451 1568.27,145.48 1568.28,145.509 1568.28,145.538 1568.29,145.567 1568.3,145.596 1568.31,145.625 1568.32,145.654 1568.33,145.683 1568.34,145.712 1568.35,145.741 1568.36,145.77 1568.37,145.8 1568.38,145.829 1568.39,145.858 1568.39,145.887 1568.4,145.916 1568.41,145.945 1568.42,145.974 1568.43,146.003 1568.44,146.032 1568.45,146.061 1568.46,146.09 1568.47,146.119 1568.48,146.149 1568.49,146.178 1568.5,146.207 1568.51,146.236 1568.51,146.265 1568.52,146.294 1568.53,146.323 1568.54,146.352 1568.55,146.381 1568.56,146.41 1568.57,146.44 1568.58,146.469 1568.59,146.498 1568.6,146.527 1568.61,146.556 1568.62,146.585 1568.62,146.614 1568.63,146.643 1568.64,146.672 1568.65,146.702 1568.66,146.731 1568.67,146.76 1568.68,146.789 1568.69,146.818 1568.7,146.847 1568.71,146.876 1568.72,146.905 1568.73,146.935 1568.73,146.964 1568.74,146.993 1568.75,147.022 1568.76,147.051 1568.77,147.08 1568.78,147.109 1568.79,147.138 1568.8,147.168 1568.81,147.197 1568.82,147.226 1568.83,147.255 1568.84,147.284 1568.85,147.313 1568.85,147.342 1568.86,147.372 1568.87,147.401 1568.88,147.43 1568.89,147.459 1568.9,147.488 1568.91,147.517 1568.92,147.547 1568.93,147.576 1568.94,147.605 1568.95,147.634 1568.96,147.663 1568.96,147.692 1568.97,147.721 1568.98,147.751 1568.99,147.78 1569,147.809 1569.01,147.838 1569.02,147.867 1569.03,147.896 1569.04,147.926 1569.05,147.955 1569.06,147.984 1569.07,148.013 1569.07,148.042 1569.08,148.071 1569.09,148.101 1569.1,148.13 1569.11,148.159 1569.12,148.188 1569.13,148.217 1569.14,148.247 1569.15,148.276 1569.16,148.305 1569.17,148.334 1569.18,148.363 1569.19,148.392 1569.19,148.422 1569.2,148.451 1569.21,148.48 1569.22,148.509 1569.23,148.538 1569.24,148.568 1569.25,148.597 1569.26,148.626 1569.27,148.655 1569.28,148.684 1569.29,148.714 1569.3,148.743 1569.3,148.772 1569.31,148.801 1569.32,148.83 1569.33,148.86 1569.34,148.889 1569.35,148.918 1569.36,148.947 1569.37,148.976 1569.38,149.006 1569.39,149.035 1569.4,149.064 1569.41,149.093 1569.41,149.123 1569.42,149.152 1569.43,149.181 1569.44,149.21 1569.45,149.239 1569.46,149.269 1569.47,149.298 1569.48,149.327 1569.49,149.356 1569.5,149.386 1569.51,149.415 1569.52,149.444 1569.53,149.473 1569.53,149.502 1569.54,149.532 1569.55,149.561 1569.56,149.59 1569.57,149.619 1569.58,149.649 1569.59,149.678 1569.6,149.707 1569.61,149.736 1569.62,149.766 1569.63,149.795 1569.64,149.824 1569.64,149.853 1569.65,149.883 1569.66,149.912 1569.67,149.941 1569.68,149.97 1569.69,150 1569.7,150.029 1569.71,150.058 1569.72,150.087 1569.73,150.117 1569.74,150.146 1569.75,150.175 1569.75,150.204 1569.76,150.234 1569.77,150.263 1569.78,150.292 1569.79,150.321 1569.8,150.351 1569.81,150.38 1569.82,150.409 1569.83,150.438 1569.84,150.468 1569.85,150.497 1569.86,150.526 1569.87,150.555 1569.87,150.585 1569.88,150.614 1569.89,150.643 1569.9,150.673 1569.91,150.702 1569.92,150.731 1569.93,150.76 1569.94,150.79 1569.95,150.819 1569.96,150.848 1569.97,150.878 1569.98,150.907 1569.98,150.936 1569.99,150.965 1570,150.995 1570.01,151.024 1570.02,151.053 1570.03,151.083 1570.04,151.112 1570.05,151.141 1570.06,151.17 1570.07,151.2 1570.08,151.229 1570.09,151.258 1570.09,151.288 1570.1,151.317 1570.11,151.346 1570.12,151.375 1570.13,151.405 1570.14,151.434 1570.15,151.463 1570.16,151.493 1570.17,151.522 1570.18,151.551 1570.19,151.581 1570.2,151.61 1570.21,151.639 1570.21,151.669 1570.22,151.698 1570.23,151.727 1570.24,151.756 1570.25,151.786 1570.26,151.815 1570.27,151.844 1570.28,151.874 1570.29,151.903 1570.3,151.932 1570.31,151.962 1570.32,151.991 1570.32,152.02 1570.33,152.05 1570.34,152.079 1570.35,152.108 1570.36,152.138 1570.37,152.167 1570.38,152.196 1570.39,152.226 1570.4,152.255 1570.41,152.284 1570.42,152.314 1570.43,152.343 1570.43,152.372 1570.44,152.402 1570.45,152.431 1570.46,152.46 1570.47,152.49 1570.48,152.519 1570.49,152.548 1570.5,152.578 1570.51,152.607 1570.52,152.636 1570.53,152.666 1570.54,152.695 1570.55,152.724 1570.55,152.754 1570.56,152.783 1570.57,152.812 1570.58,152.842 1570.59,152.871 1570.6,152.9 1570.61,152.93 1570.62,152.959 1570.63,152.988 1570.64,153.018 1570.65,153.047 1570.66,153.077 1570.66,153.106 1570.67,153.135 1570.68,153.165 1570.69,153.194 1570.7,153.223 1570.71,153.253 1570.72,153.282 1570.73,153.311 1570.74,153.341 1570.75,153.37 1570.76,153.399 1570.77,153.429 1570.77,153.458 1570.78,153.488 1570.79,153.517 1570.8,153.546 1570.81,153.576 1570.82,153.605 1570.83,153.634 1570.84,153.664 1570.85,153.693 1570.86,153.723 1570.87,153.752 1570.88,153.781 1570.89,153.811 1570.89,153.84 1570.9,153.869 1570.91,153.899 1570.92,153.928 1570.93,153.958 1570.94,153.987 1570.95,154.016 1570.96,154.046 1570.97,154.075 1570.98,154.105 1570.99,154.134 1571,154.163 1571,154.193 1571.01,154.222 1571.02,154.252 1571.03,154.281 1571.04,154.31 1571.05,154.34 1571.06,154.369 1571.07,154.399 1571.08,154.428 1571.09,154.457 1571.1,154.487 1571.11,154.516 1571.11,154.546 1571.12,154.575 1571.13,154.604 1571.14,154.634 1571.15,154.663 1571.16,154.693 1571.17,154.722 1571.18,154.751 1571.19,154.781 1571.2,154.81 1571.21,154.84 1571.22,154.869 1571.23,154.898 1571.23,154.928 1571.24,154.957 1571.25,154.987 1571.26,155.016 1571.27,155.045 1571.28,155.075 1571.29,155.104 1571.3,155.134 1571.31,155.163 1571.32,155.193 1571.33,155.222 1571.34,155.251 1571.34,155.281 1571.35,155.31 1571.36,155.34 1571.37,155.369 1571.38,155.399 1571.39,155.428 1571.4,155.457 1571.41,155.487 1571.42,155.516 1571.43,155.546 1571.44,155.575 1571.45,155.605 1571.45,155.634 1571.46,155.663 1571.47,155.693 1571.48,155.722 1571.49,155.752 1571.5,155.781 1571.51,155.811 1571.52,155.84 1571.53,155.869 1571.54,155.899 1571.55,155.928 1571.56,155.958 1571.57,155.987 1571.57,156.017 1571.58,156.046 1571.59,156.076 1571.6,156.105 1571.61,156.134 1571.62,156.164 1571.63,156.193 1571.64,156.223 1571.65,156.252 1571.66,156.282 1571.67,156.311 1571.68,156.341 1571.68,156.37 1571.69,156.4 1571.7,156.429 1571.71,156.458 1571.72,156.488 1571.73,156.517 1571.74,156.547 1571.75,156.576 1571.76,156.606 1571.77,156.635 1571.78,156.665 1571.79,156.694 1571.79,156.724 1571.8,156.753 1571.81,156.783 1571.82,156.812 1571.83,156.841 1571.84,156.871 1571.85,156.9 1571.86,156.93 1571.87,156.959 1571.88,156.989 1571.89,157.018 1571.9,157.048 1571.91,157.077 1571.91,157.107 1571.92,157.136 1571.93,157.166 1571.94,157.195 1571.95,157.225 1571.96,157.254 1571.97,157.284 1571.98,157.313 1571.99,157.343 1572,157.372 1572.01,157.401 1572.02,157.431 1572.02,157.46 1572.03,157.49 1572.04,157.519 1572.05,157.549 1572.06,157.578 1572.07,157.608 1572.08,157.637 1572.09,157.667 1572.1,157.696 1572.11,157.726 1572.12,157.755 1572.13,157.785 1572.13,157.814 1572.14,157.844 1572.15,157.873 1572.16,157.903 1572.17,157.932 1572.18,157.962 1572.19,157.991 1572.2,158.021 1572.21,158.05 1572.22,158.08 1572.23,158.109 1572.24,158.139 1572.25,158.168 1572.25,158.198 1572.26,158.227 1572.27,158.257 1572.28,158.286 1572.29,158.316 1572.3,158.345 1572.31,158.375 1572.32,158.404 1572.33,158.434 1572.34,158.463 1572.35,158.493 1572.36,158.522 1572.36,158.552 1572.37,158.581 1572.38,158.611 1572.39,158.64 1572.4,158.67 1572.41,158.699 1572.42,158.729 1572.43,158.758 1572.44,158.788 1572.45,158.817 1572.46,158.847 1572.47,158.876 1572.47,158.906 1572.48,158.935 1572.49,158.965 1572.5,158.995 1572.51,159.024 1572.52,159.054 1572.53,159.083 1572.54,159.113 1572.55,159.142 1572.56,159.172 1572.57,159.201 1572.58,159.231 1572.59,159.26 1572.59,159.29 1572.6,159.319 1572.61,159.349 1572.62,159.378 1572.63,159.408 1572.64,159.437 1572.65,159.467 1572.66,159.496 1572.67,159.526 1572.68,159.556 1572.69,159.585 1572.7,159.615 1572.7,159.644 1572.71,159.674 1572.72,159.703 1572.73,159.733 1572.74,159.762 1572.75,159.792 1572.76,159.821 1572.77,159.851 1572.78,159.88 1572.79,159.91 1572.8,159.939 1572.81,159.969 1572.81,159.999 1572.82,160.028 1572.83,160.058 1572.84,160.087 1572.85,160.117 1572.86,160.146 1572.87,160.176 1572.88,160.205 1572.89,160.235 1572.9,160.264 1572.91,160.294 1572.92,160.324 1572.93,160.353 1572.93,160.383 1572.94,160.412 1572.95,160.442 1572.96,160.471 1572.97,160.501 1572.98,160.53 1572.99,160.56 1573,160.59 1573.01,160.619 1573.02,160.649 1573.03,160.678 1573.04,160.708 1573.04,160.737 1573.05,160.767 1573.06,160.796 1573.07,160.826 1573.08,160.856 1573.09,160.885 1573.1,160.915 1573.11,160.944 1573.12,160.974 1573.13,161.003 1573.14,161.033 1573.15,161.063 1573.15,161.092 1573.16,161.122 1573.17,161.151 1573.18,161.181 1573.19,161.21 1573.2,161.24 1573.21,161.269 1573.22,161.299 1573.23,161.329 1573.24,161.358 1573.25,161.388 1573.26,161.417 1573.27,161.447 1573.27,161.476 1573.28,161.506 1573.29,161.536 1573.3,161.565 1573.31,161.595 1573.32,161.624 1573.33,161.654 1573.34,161.684 1573.35,161.713 1573.36,161.743 1573.37,161.772 1573.38,161.802 1573.38,161.831 1573.39,161.861 1573.4,161.891 1573.41,161.92 1573.42,161.95 1573.43,161.979 1573.44,162.009 1573.45,162.038 1573.46,162.068 1573.47,162.098 1573.48,162.127 1573.49,162.157 1573.49,162.186 1573.5,162.216 1573.51,162.246 1573.52,162.275 1573.53,162.305 1573.54,162.334 1573.55,162.364 1573.56,162.394 1573.57,162.423 1573.58,162.453 1573.59,162.482 1573.6,162.512 1573.61,162.541 1573.61,162.571 1573.62,162.601 1573.63,162.63 1573.64,162.66 1573.65,162.689 1573.66,162.719 1573.67,162.749 1573.68,162.778 1573.69,162.808 1573.7,162.837 1573.71,162.867 1573.72,162.897 1573.72,162.926 1573.73,162.956 1573.74,162.985 1573.75,163.015 1573.76,163.045 1573.77,163.074 1573.78,163.104 1573.79,163.133 1573.8,163.163 1573.81,163.193 1573.82,163.222 1573.83,163.252 1573.83,163.281 1573.84,163.311 1573.85,163.341 1573.86,163.37 1573.87,163.4 1573.88,163.429 1573.89,163.459 1573.9,163.489 1573.91,163.518 1573.92,163.548 1573.93,163.578 1573.94,163.607 1573.95,163.637 1573.95,163.666 1573.96,163.696 1573.97,163.726 1573.98,163.755 1573.99,163.785 1574,163.814 1574.01,163.844 1574.02,163.874 1574.03,163.903 1574.04,163.933 1574.05,163.963 1574.06,163.992 1574.06,164.022 1574.07,164.051 1574.08,164.081 1574.09,164.111 1574.1,164.14 1574.11,164.17 1574.12,164.199 1574.13,164.229 1574.14,164.259 1574.15,164.288 1574.16,164.318 1574.17,164.348 1574.17,164.377 1574.18,164.407 1574.19,164.436 1574.2,164.466 1574.21,164.496 1574.22,164.525 1574.23,164.555 1574.24,164.585 1574.25,164.614 1574.26,164.644 1574.27,164.673 1574.28,164.703 1574.29,164.733 1574.29,164.762 1574.3,164.792 1574.31,164.822 1574.32,164.851 1574.33,164.881 1574.34,164.911 1574.35,164.94 1574.36,164.97 1574.37,164.999 1574.38,165.029 1574.39,165.059 1574.4,165.088 1574.4,165.118 1574.41,165.148 1574.42,165.177 1574.43,165.207 1574.44,165.236 1574.45,165.266 1574.46,165.296 1574.47,165.325 1574.48,165.355 1574.49,165.385 1574.5,165.414 1574.51,165.444 1574.51,165.474 1574.52,165.503 1574.53,165.533 1574.54,165.563 1574.55,165.592 1574.56,165.622 1574.57,165.651 1574.58,165.681 1574.59,165.711 1574.6,165.74 1574.61,165.77 1574.62,165.8 1574.63,165.829 1574.63,165.859 1574.64,165.889 1574.65,165.918 1574.66,165.948 1574.67,165.978 1574.68,166.007 1574.69,166.037 1574.7,166.066 1574.71,166.096 1574.72,166.126 1574.73,166.155 1574.74,166.185 1574.74,166.215 1574.75,166.244 1574.76,166.274 1574.77,166.304 1574.78,166.333 1574.79,166.363 1574.8,166.393 1574.81,166.422 1574.82,166.452 1574.83,166.482 1574.84,166.511 1574.85,166.541 1574.85,166.571 1574.86,166.6 1574.87,166.63 1574.88,166.66 1574.89,166.689 1574.9,166.719 1574.91,166.749 1574.92,166.778 1574.93,166.808 1574.94,166.837 1574.95,166.867 1574.96,166.897 1574.97,166.926 1574.97,166.956 1574.98,166.986 1574.99,167.015 1575,167.045 1575.01,167.075 1575.02,167.104 1575.03,167.134 1575.04,167.164 1575.05,167.193 1575.06,167.223 1575.07,167.253 1575.08,167.282 1575.08,167.312 1575.09,167.342 1575.1,167.371 1575.11,167.401 1575.12,167.431 1575.13,167.46 1575.14,167.49 1575.15,167.52 1575.16,167.549 1575.17,167.579 1575.18,167.609 1575.19,167.638 1575.19,167.668 1575.2,167.698 1575.21,167.727 1575.22,167.757 1575.23,167.787 1575.24,167.816 1575.25,167.846 1575.26,167.876 1575.27,167.905 1575.28,167.935 1575.29,167.965 1575.3,167.994 1575.31,168.024 1575.31,168.054 1575.32,168.083 1575.33,168.113 1575.34,168.143 1575.35,168.172 1575.36,168.202 1575.37,168.232 1575.38,168.261 1575.39,168.291 1575.4,168.321 1575.41,168.351 1575.42,168.38 1575.42,168.41 1575.43,168.44 1575.44,168.469 1575.45,168.499 1575.46,168.529 1575.47,168.558 1575.48,168.588 1575.49,168.618 1575.5,168.647 1575.51,168.677 1575.52,168.707 1575.53,168.736 1575.53,168.766 1575.54,168.796 1575.55,168.825 1575.56,168.855 1575.57,168.885 1575.58,168.914 1575.59,168.944 1575.6,168.974 1575.61,169.003 1575.62,169.033 1575.63,169.063 1575.64,169.092 1575.65,169.122 1575.65,169.152 1575.66,169.182 1575.67,169.211 1575.68,169.241 1575.69,169.271 1575.7,169.3 1575.71,169.33 1575.72,169.36 1575.73,169.389 1575.74,169.419 1575.75,169.449 1575.76,169.478 1575.76,169.508 1575.77,169.538 1575.78,169.567 1575.79,169.597 1575.8,169.627 1575.81,169.657 1575.82,169.686 1575.83,169.716 1575.84,169.746 1575.85,169.775 1575.86,169.805 1575.87,169.835 1575.87,169.864 1575.88,169.894 1575.89,169.924 1575.9,169.953 1575.91,169.983 1575.92,170.013 1575.93,170.042 1575.94,170.072 1575.95,170.102 1575.96,170.132 1575.97,170.161 1575.98,170.191 1575.99,170.221 1575.99,170.25 1576,170.28 1576.01,170.31 1576.02,170.339 1576.03,170.369 1576.04,170.399 1576.05,170.429 1576.06,170.458 1576.07,170.488 1576.08,170.518 1576.09,170.547 1576.1,170.577 1576.1,170.607 1576.11,170.636 1576.12,170.666 1576.13,170.696 1576.14,170.725 1576.15,170.755 1576.16,170.785 1576.17,170.815 1576.18,170.844 1576.19,170.874 1576.2,170.904 1576.21,170.933 1576.21,170.963 1576.22,170.993 1576.23,171.022 1576.24,171.052 1576.25,171.082 1576.26,171.112 1576.27,171.141 1576.28,171.171 1576.29,171.201 1576.3,171.23 1576.31,171.26 1576.32,171.29 1576.33,171.319 1576.33,171.349 1576.34,171.379 1576.35,171.409 1576.36,171.438 1576.37,171.468 1576.38,171.498 1576.39,171.527 1576.4,171.557 1576.41,171.587 1576.42,171.616 1576.43,171.646 1576.44,171.676 1576.44,171.706 1576.45,171.735 1576.46,171.765 1576.47,171.795 1576.48,171.824 1576.49,171.854 1576.5,171.884 1576.51,171.914 1576.52,171.943 1576.53,171.973 1576.54,172.003 1576.55,172.032 1576.55,172.062 1576.56,172.092 1576.57,172.121 1576.58,172.151 1576.59,172.181 1576.6,172.211 1576.61,172.24 1576.62,172.27 1576.63,172.3 1576.64,172.329 1576.65,172.359 1576.66,172.389 1576.67,172.419 1576.67,172.448 1576.68,172.478 1576.69,172.508 1576.7,172.537 1576.71,172.567 1576.72,172.597 1576.73,172.626 1576.74,172.656 1576.75,172.686 1576.76,172.716 1576.77,172.745 1576.78,172.775 1576.78,172.805 1576.79,172.834 1576.8,172.864 1576.81,172.894 1576.82,172.924 1576.83,172.953 1576.84,172.983 1576.85,173.013 1576.86,173.042 1576.87,173.072 1576.88,173.102 1576.89,173.132 1576.89,173.161 1576.9,173.191 1576.91,173.221 1576.92,173.25 1576.93,173.28 1576.94,173.31 1576.95,173.34 1576.96,173.369 1576.97,173.399 1576.98,173.429 1576.99,173.458 1577,173.488 1577.01,173.518 1577.01,173.548 1577.02,173.577 1577.03,173.607 1577.04,173.637 1577.05,173.666 1577.06,173.696 1577.07,173.726 1577.08,173.756 1577.09,173.785 1577.1,173.815 1577.11,173.845 1577.12,173.874 1577.12,173.904 1577.13,173.934 1577.14,173.964 1577.15,173.993 1577.16,174.023 1577.17,174.053 1577.18,174.082 1577.19,174.112 1577.2,174.142 1577.21,174.172 1577.22,174.201 1577.23,174.231 1577.23,174.261 1577.24,174.29 1577.25,174.32 1577.26,174.35 1577.27,174.38 1577.28,174.409 1577.29,174.439 1577.3,174.469 1577.31,174.498 1577.32,174.528 1577.33,174.558 1577.34,174.588 1577.35,174.617 1577.35,174.647 1577.36,174.677 1577.37,174.706 1577.38,174.736 1577.39,174.766 1577.4,174.796 1577.41,174.825 1577.42,174.855 1577.43,174.885 1577.44,174.915 1577.45,174.944 1577.46,174.974 1577.46,175.004 1577.47,175.033 1577.48,175.063 1577.49,175.093 1577.5,175.123 1577.51,175.152 1577.52,175.182 1577.53,175.212 1577.54,175.241 1577.55,175.271 1577.56,175.301 1577.57,175.331 1577.57,175.36 1577.58,175.39 1577.59,175.42 1577.6,175.449 1577.61,175.479 1577.62,175.509 1577.63,175.539 1577.64,175.568 1577.65,175.598 1577.66,175.628 1577.67,175.658 1577.68,175.687 1577.69,175.717 1577.69,175.747 1577.7,175.776 1577.71,175.806 1577.72,175.836 1577.73,175.866 1577.74,175.895 1577.75,175.925 1577.76,175.955 1577.77,175.984 1577.78,176.014 1577.79,176.044 1577.8,176.074 1577.8,176.103 1577.81,176.133 1577.82,176.163 1577.83,176.192 1577.84,176.222 1577.85,176.252 1577.86,176.282 1577.87,176.311 1577.88,176.341 1577.89,176.371 1577.9,176.401 1577.91,176.43 1577.91,176.46 1577.92,176.49 1577.93,176.519 1577.94,176.549 1577.95,176.579 1577.96,176.609 1577.97,176.638 1577.98,176.668 1577.99,176.698 1578,176.727 1578.01,176.757 1578.02,176.787 1578.03,176.817 1578.03,176.846 1578.04,176.876 1578.05,176.906 1578.06,176.936 1578.07,176.965 1578.08,176.995 1578.09,177.025 1578.1,177.054 1578.11,177.084 1578.12,177.114 1578.13,177.144 1578.14,177.173 1578.14,177.203 1578.15,177.233 1578.16,177.262 1578.17,177.292 1578.18,177.322 1578.19,177.352 1578.2,177.381 1578.21,177.411 1578.22,177.441 1578.23,177.471 1578.24,177.5 1578.25,177.53 1578.25,177.56 1578.26,177.589 1578.27,177.619 1578.28,177.649 1578.29,177.679 1578.3,177.708 1578.31,177.738 1578.32,177.768 1578.33,177.797 1578.34,177.827 1578.35,177.857 1578.36,177.887 1578.37,177.916 1578.37,177.946 1578.38,177.976 1578.39,178.005 1578.4,178.035 1578.41,178.065 1578.42,178.095 1578.43,178.124 1578.44,178.154 1578.45,178.184 1578.46,178.214 1578.47,178.243 1578.48,178.273 1578.48,178.303 1578.49,178.332 1578.5,178.362 1578.51,178.392 1578.52,178.422 1578.53,178.451 1578.54,178.481 1578.55,178.511 1578.56,178.54 1578.57,178.57 1578.58,178.6 1578.59,178.63 1578.59,178.659 1578.6,178.689 1578.61,178.719 1578.62,178.749 1578.63,178.778 1578.64,178.808 1578.65,178.838 1578.66,178.867 1578.67,178.897 1578.68,178.927 1578.69,178.957 1578.7,178.986 1578.71,179.016 1578.71,179.046 1578.72,179.075 1578.73,179.105 1578.74,179.135 1578.75,179.165 1578.76,179.194 1578.77,179.224 1578.78,179.254 1578.79,179.284 1578.8,179.313 1578.81,179.343 1578.82,179.373 1578.82,179.402 1578.83,179.432 1578.84,179.462 1578.85,179.492 1578.86,179.521 1578.87,179.551 1578.88,179.581 1578.89,179.61 1578.9,179.64 1578.91,179.67 1578.92,179.7 1578.93,179.729 1578.93,179.759 1578.94,179.789 1578.95,179.818 1578.96,179.848 1578.97,179.878 1578.98,179.908 1578.99,179.937 1579,179.967 1579.01,179.997 1579.02,180.026 1579.03,180.056 1579.04,180.086 1579.05,180.116 1579.05,180.145 1579.06,180.175 1579.07,180.205 1579.08,180.235 1579.09,180.264 1579.1,180.294 1579.11,180.324 1579.12,180.353 1579.13,180.383 1579.14,180.413 1579.15,180.443 1579.16,180.472 1579.16,180.502 1579.17,180.532 1579.18,180.561 1579.19,180.591 1579.2,180.621 1579.21,180.651 1579.22,180.68 1579.23,180.71 1579.24,180.74 1579.25,180.769 1579.26,180.799 1579.27,180.829 1579.27,180.859 1579.28,180.888 1579.29,180.918 1579.3,180.948 1579.31,180.977 1579.32,181.007 1579.33,181.037 1579.34,181.067 1579.35,181.096 1579.36,181.126 1579.37,181.156 1579.38,181.185 1579.39,181.215 1579.39,181.245 1579.4,181.275 1579.41,181.304 1579.42,181.334 1579.43,181.364 1579.44,181.393 1579.45,181.423 1579.46,181.453 1579.47,181.483 1579.48,181.512 1579.49,181.542 1579.5,181.572 1579.5,181.601 1579.51,181.631 1579.52,181.661 1579.53,181.691 1579.54,181.72 1579.55,181.75 1579.56,181.78 1579.57,181.809 1579.58,181.839 1579.59,181.869 1579.6,181.899 1579.61,181.928 1579.61,181.958 1579.62,181.988 1579.63,182.017 1579.64,182.047 1579.65,182.077 1579.66,182.106 1579.67,182.136 1579.68,182.166 1579.69,182.196 1579.7,182.225 1579.71,182.255 1579.72,182.285 1579.73,182.314 1579.73,182.344 1579.74,182.374 1579.75,182.404 1579.76,182.433 1579.77,182.463 1579.78,182.493 1579.79,182.522 1579.8,182.552 1579.81,182.582 1579.82,182.612 1579.83,182.641 1579.84,182.671 1579.84,182.701 1579.85,182.73 1579.86,182.76 1579.87,182.79 1579.88,182.819 1579.89,182.849 1579.9,182.879 1579.91,182.909 1579.92,182.938 1579.93,182.968 1579.94,182.998 1579.95,183.027 1579.95,183.057 1579.96,183.087 1579.97,183.117 1579.98,183.146 1579.99,183.176 1580,183.206 1580.01,183.235 1580.02,183.265 1580.03,183.295 1580.04,183.324 1580.05,183.354 1580.06,183.384 1580.07,183.414 1580.07,183.443 1580.08,183.473 1580.09,183.503 1580.1,183.532 1580.11,183.562 1580.12,183.592 1580.13,183.621 1580.14,183.651 1580.15,183.681 1580.16,183.711 1580.17,183.74 1580.18,183.77 1580.18,183.8 1580.19,183.829 1580.2,183.859 1580.21,183.889 1580.22,183.918 1580.23,183.948 1580.24,183.978 1580.25,184.008 1580.26,184.037 1580.27,184.067 1580.28,184.097 1580.29,184.126 1580.3,184.156 1580.3,184.186 1580.31,184.215 1580.32,184.245 1580.33,184.275 1580.34,184.305 1580.35,184.334 1580.36,184.364 1580.37,184.394 1580.38,184.423 1580.39,184.453 1580.4,184.483 1580.41,184.512 1580.41,184.542 1580.42,184.572 1580.43,184.602 1580.44,184.631 1580.45,184.661 1580.46,184.691 1580.47,184.72 1580.48,184.75 1580.49,184.78 1580.5,184.809 1580.51,184.839 1580.52,184.869 1580.52,184.898 1580.53,184.928 1580.54,184.958 1580.55,184.988 1580.56,185.017 1580.57,185.047 1580.58,185.077 1580.59,185.106 1580.6,185.136 1580.61,185.166 1580.62,185.195 1580.63,185.225 1580.64,185.255 1580.64,185.284 1580.65,185.314 1580.66,185.344 1580.67,185.374 1580.68,185.403 1580.69,185.433 1580.7,185.463 1580.71,185.492 1580.72,185.522 1580.73,185.552 1580.74,185.581 1580.75,185.611 1580.75,185.641 1580.76,185.67 1580.77,185.7 1580.78,185.73 1580.79,185.759 1580.8,185.789 1580.81,185.819 1580.82,185.848 1580.83,185.878 1580.84,185.908 1580.85,185.938 1580.86,185.967 1580.86,185.997 1580.87,186.027 1580.88,186.056 1580.89,186.086 1580.9,186.116 1580.91,186.145 1580.92,186.175 1580.93,186.205 1580.94,186.234 1580.95,186.264 1580.96,186.294 1580.97,186.323 1580.98,186.353 1580.98,186.383 1580.99,186.412 1581,186.442 1581.01,186.472 1581.02,186.501 1581.03,186.531 1581.04,186.561 1581.05,186.591 1581.06,186.62 1581.07,186.65 1581.08,186.68 1581.09,186.709 1581.09,186.739 1581.1,186.769 1581.11,186.798 1581.12,186.828 1581.13,186.858 1581.14,186.887 1581.15,186.917 1581.16,186.947 1581.17,186.976 1581.18,187.006 1581.19,187.036 1581.2,187.065 1581.2,187.095 1581.21,187.125 1581.22,187.154 1581.23,187.184 1581.24,187.214 1581.25,187.243 1581.26,187.273 1581.27,187.303 1581.28,187.332 1581.29,187.362 1581.3,187.392 1581.31,187.421 1581.32,187.451 1581.32,187.481 1581.33,187.51 1581.34,187.54 1581.35,187.57 1581.36,187.599 1581.37,187.629 1581.38,187.659 1581.39,187.688 1581.4,187.718 1581.41,187.748 1581.42,187.777 1581.43,187.807 1581.43,187.837 1581.44,187.866 1581.45,187.896 1581.46,187.926 1581.47,187.955 1581.48,187.985 1581.49,188.015 1581.5,188.044 1581.51,188.074 1581.52,188.104 1581.53,188.133 1581.54,188.163 1581.54,188.193 1581.55,188.222 1581.56,188.252 1581.57,188.282 1581.58,188.311 1581.59,188.341 1581.6,188.371 1581.61,188.4 1581.62,188.43 1581.63,188.46 1581.64,188.489 1581.65,188.519 1581.66,188.549 1581.66,188.578 1581.67,188.608 1581.68,188.638 1581.69,188.667 1581.7,188.697 1581.71,188.727 1581.72,188.756 1581.73,188.786 1581.74,188.816 1581.75,188.845 1581.76,188.875 1581.77,188.904 1581.77,188.934 1581.78,188.964 1581.79,188.993 1581.8,189.023 1581.81,189.053 1581.82,189.082 1581.83,189.112 1581.84,189.142 1581.85,189.171 1581.86,189.201 1581.87,189.231 1581.88,189.26 1581.88,189.29 1581.89,189.32 1581.9,189.349 1581.91,189.379 1581.92,189.409 1581.93,189.438 1581.94,189.468 1581.95,189.497 1581.96,189.527 1581.97,189.557 1581.98,189.586 1581.99,189.616 1582,189.646 1582,189.675 1582.01,189.705 1582.02,189.735 1582.03,189.764 1582.04,189.794 1582.05,189.824 1582.06,189.853 1582.07,189.883 1582.08,189.913 1582.09,189.942 1582.1,189.972 1582.11,190.001 1582.11,190.031 1582.12,190.061 1582.13,190.09 1582.14,190.12 1582.15,190.15 1582.16,190.179 1582.17,190.209 1582.18,190.239 1582.19,190.268 1582.2,190.298 1582.21,190.327 1582.22,190.357 1582.22,190.387 1582.23,190.416 1582.24,190.446 1582.25,190.476 1582.26,190.505 1582.27,190.535 1582.28,190.565 1582.29,190.594 1582.3,190.624 1582.31,190.653 1582.32,190.683 1582.33,190.713 1582.34,190.742 1582.34,190.772 1582.35,190.802 1582.36,190.831 1582.37,190.861 1582.38,190.89 1582.39,190.92 1582.4,190.95 1582.41,190.979 1582.42,191.009 1582.43,191.039 1582.44,191.068 1582.45,191.098 1582.45,191.128 1582.46,191.157 1582.47,191.187 1582.48,191.216 1582.49,191.246 1582.5,191.276 1582.51,191.305 1582.52,191.335 1582.53,191.365 1582.54,191.394 1582.55,191.424 1582.56,191.453 1582.56,191.483 1582.57,191.513 1582.58,191.542 1582.59,191.572 1582.6,191.601 1582.61,191.631 1582.62,191.661 1582.63,191.69 1582.64,191.72 1582.65,191.75 1582.66,191.779 1582.67,191.809 1582.68,191.838 1582.68,191.868 1582.69,191.898 1582.7,191.927 1582.71,191.957 1582.72,191.986 1582.73,192.016 1582.74,192.046 1582.75,192.075 1582.76,192.105 1582.77,192.135 1582.78,192.164 1582.79,192.194 1582.79,192.223 1582.8,192.253 1582.81,192.283 1582.82,192.312 1582.83,192.342 1582.84,192.371 1582.85,192.401 1582.86,192.431 1582.87,192.46 1582.88,192.49 1582.89,192.519 1582.9,192.549 1582.9,192.579 1582.91,192.608 1582.92,192.638 1582.93,192.668 1582.94,192.697 1582.95,192.727 1582.96,192.756 1582.97,192.786 1582.98,192.816 1582.99,192.845 1583,192.875 1583.01,192.904 1583.02,192.934 1583.02,192.964 1583.03,192.993 1583.04,193.023 1583.05,193.052 1583.06,193.082 1583.07,193.112 1583.08,193.141 1583.09,193.171 1583.1,193.2 1583.11,193.23 1583.12,193.259 1583.13,193.289 1583.13,193.319 1583.14,193.348 1583.15,193.378 1583.16,193.407 1583.17,193.437 1583.18,193.467 1583.19,193.496 1583.2,193.526 1583.21,193.555 1583.22,193.585 1583.23,193.615 1583.24,193.644 1583.24,193.674 1583.25,193.703 1583.26,193.733 1583.27,193.763 1583.28,193.792 1583.29,193.822 1583.3,193.851 1583.31,193.881 1583.32,193.91 1583.33,193.94 1583.34,193.97 1583.35,193.999 1583.36,194.029 1583.36,194.058 1583.37,194.088 1583.38,194.118 1583.39,194.147 1583.4,194.177 1583.41,194.206 1583.42,194.236 1583.43,194.265 1583.44,194.295 1583.45,194.325 1583.46,194.354 1583.47,194.384 1583.47,194.413 1583.48,194.443 1583.49,194.473 1583.5,194.502 1583.51,194.532 1583.52,194.561 1583.53,194.591 1583.54,194.62 1583.55,194.65 1583.56,194.68 1583.57,194.709 1583.58,194.739 1583.58,194.768 1583.59,194.798 1583.6,194.827 1583.61,194.857 1583.62,194.887 1583.63,194.916 1583.64,194.946 1583.65,194.975 1583.66,195.005 1583.67,195.034 1583.68,195.064 1583.69,195.093 1583.7,195.123 1583.7,195.153 1583.71,195.182 1583.72,195.212 1583.73,195.241 1583.74,195.271 1583.75,195.3 1583.76,195.33 1583.77,195.36 1583.78,195.389 1583.79,195.419 1583.8,195.448 1583.81,195.478 1583.81,195.507 1583.82,195.537 1583.83,195.566 1583.84,195.596 1583.85,195.626 1583.86,195.655 1583.87,195.685 1583.88,195.714 1583.89,195.744 1583.9,195.773 1583.91,195.803 1583.92,195.832 1583.92,195.862 1583.93,195.892 1583.94,195.921 1583.95,195.951 1583.96,195.98 1583.97,196.01 1583.98,196.039 1583.99,196.069 1584,196.098 1584.01,196.128 1584.02,196.158 1584.03,196.187 1584.04,196.217 1584.04,196.246 1584.05,196.276 1584.06,196.305 1584.07,196.335 1584.08,196.364 1584.09,196.394 1584.1,196.423 1584.11,196.453 1584.12,196.483 1584.13,196.512 1584.14,196.542 1584.15,196.571 1584.15,196.601 1584.16,196.63 1584.17,196.66 1584.18,196.689 1584.19,196.719 1584.2,196.748 1584.21,196.778 1584.22,196.807 1584.23,196.837 1584.24,196.867 1584.25,196.896 1584.26,196.926 1584.26,196.955 1584.27,196.985 1584.28,197.014 1584.29,197.044 1584.3,197.073 1584.31,197.103 1584.32,197.132 1584.33,197.162 1584.34,197.191 1584.35,197.221 1584.36,197.25 1584.37,197.28 1584.38,197.309 1584.38,197.339 1584.39,197.369 1584.4,197.398 1584.41,197.428 1584.42,197.457 1584.43,197.487 1584.44,197.516 1584.45,197.546 1584.46,197.575 1584.47,197.605 1584.48,197.634 1584.49,197.664 1584.49,197.693 1584.5,197.723 1584.51,197.752 1584.52,197.782 1584.53,197.811 1584.54,197.841 1584.55,197.87 1584.56,197.9 1584.57,197.929 1584.58,197.959 1584.59,197.988 1584.6,198.018 1584.6,198.047 1584.61,198.077 1584.62,198.106 1584.63,198.136 1584.64,198.165 1584.65,198.195 1584.66,198.225 1584.67,198.254 1584.68,198.284 1584.69,198.313 1584.7,198.343 1584.71,198.372 1584.72,198.402 1584.72,198.431 1584.73,198.461 1584.74,198.49 1584.75,198.52 1584.76,198.549 1584.77,198.579 1584.78,198.608 1584.79,198.638 1584.8,198.667 1584.81,198.697 1584.82,198.726 1584.83,198.756 1584.83,198.785 1584.84,198.815 1584.85,198.844 1584.86,198.874 1584.87,198.903 1584.88,198.933 1584.89,198.962 1584.9,198.992 1584.91,199.021 1584.92,199.051 1584.93,199.08 1584.94,199.109 1584.94,199.139 1584.95,199.168 1584.96,199.198 1584.97,199.227 1584.98,199.257 1584.99,199.286 1585,199.316 1585.01,199.345 1585.02,199.375 1585.03,199.404 1585.04,199.434 1585.05,199.463 1585.06,199.493 1585.06,199.522 1585.07,199.552 1585.08,199.581 1585.09,199.611 1585.1,199.64 1585.11,199.67 1585.12,199.699 1585.13,199.729 1585.14,199.758 1585.15,199.788 1585.16,199.817 1585.17,199.847 1585.17,199.876 1585.18,199.906 1585.19,199.935 1585.2,199.964 1585.21,199.994 1585.22,200.023 1585.23,200.053 1585.24,200.082 1585.25,200.112 1585.26,200.141 1585.27,200.171 1585.28,200.2 1585.28,200.23 1585.29,200.259 1585.3,200.289 1585.31,200.318 1585.32,200.348 1585.33,200.377 1585.34,200.407 1585.35,200.436 1585.36,200.465 1585.37,200.495 1585.38,200.524 1585.39,200.554 1585.4,200.583 1585.4,200.613 1585.41,200.642 1585.42,200.672 1585.43,200.701 1585.44,200.731 1585.45,200.76 1585.46,200.79 1585.47,200.819 1585.48,200.848 1585.49,200.878 1585.5,200.907 1585.51,200.937 1585.51,200.966 1585.52,200.996 1585.53,201.025 1585.54,201.055 1585.55,201.084 1585.56,201.113 1585.57,201.143 1585.58,201.172 1585.59,201.202 1585.6,201.231 1585.61,201.261 1585.62,201.29 1585.62,201.32 1585.63,201.349 1585.64,201.378 1585.65,201.408 1585.66,201.437 1585.67,201.467 1585.68,201.496 1585.69,201.526 1585.7,201.555 1585.71,201.585 1585.72,201.614 1585.73,201.643 1585.74,201.673 1585.74,201.702 1585.75,201.732 1585.76,201.761 1585.77,201.791 1585.78,201.82 1585.79,201.85 1585.8,201.879 1585.81,201.908 1585.82,201.938 1585.83,201.967 1585.84,201.997 1585.85,202.026 1585.85,202.056 1585.86,202.085 1585.87,202.114 1585.88,202.144 1585.89,202.173 1585.9,202.203 1585.91,202.232 1585.92,202.261 1585.93,202.291 1585.94,202.32 1585.95,202.35 1585.96,202.379 1585.96,202.409 1585.97,202.438 1585.98,202.467 1585.99,202.497 1586,202.526 1586.01,202.556 1586.02,202.585 1586.03,202.615 1586.04,202.644 1586.05,202.673 1586.06,202.703 1586.07,202.732 1586.08,202.762 1586.08,202.791 1586.09,202.82 1586.1,202.85 1586.11,202.879 1586.12,202.909 1586.13,202.938 1586.14,202.967 1586.15,202.997 1586.16,203.026 1586.17,203.056 1586.18,203.085 1586.19,203.115 1586.19,203.144 1586.2,203.173 1586.21,203.203 1586.22,203.232 1586.23,203.262 1586.24,203.291 1586.25,203.32 1586.26,203.35 1586.27,203.379 1586.28,203.409 1586.29,203.438 1586.3,203.467 1586.3,203.497 1586.31,203.526 1586.32,203.555 1586.33,203.585 1586.34,203.614 1586.35,203.644 1586.36,203.673 1586.37,203.702 1586.38,203.732 1586.39,203.761 1586.4,203.791 1586.41,203.82 1586.42,203.849 1586.42,203.879 1586.43,203.908 1586.44,203.938 1586.45,203.967 1586.46,203.996 1586.47,204.026 1586.48,204.055 1586.49,204.084 1586.5,204.114 1586.51,204.143 1586.52,204.173 1586.53,204.202 1586.53,204.231 1586.54,204.261 1586.55,204.29 1586.56,204.319 1586.57,204.349 1586.58,204.378 1586.59,204.408 1586.6,204.437 1586.61,204.466 1586.62,204.496 1586.63,204.525 1586.64,204.554 1586.64,204.584 1586.65,204.613 1586.66,204.643 1586.67,204.672 1586.68,204.701 1586.69,204.731 1586.7,204.76 1586.71,204.789 1586.72,204.819 1586.73,204.848 1586.74,204.877 1586.75,204.907 1586.76,204.936 1586.76,204.966 1586.77,204.995 1586.78,205.024 1586.79,205.054 1586.8,205.083 1586.81,205.112 1586.82,205.142 1586.83,205.171 1586.84,205.2 1586.85,205.23 1586.86,205.259 1586.87,205.288 1586.87,205.318 1586.88,205.347 1586.89,205.377 1586.9,205.406 1586.91,205.435 1586.92,205.465 1586.93,205.494 1586.94,205.523 1586.95,205.553 1586.96,205.582 1586.97,205.611 1586.98,205.641 1586.98,205.67 1586.99,205.699 1587,205.729 1587.01,205.758 1587.02,205.787 1587.03,205.817 1587.04,205.846 1587.05,205.875 1587.06,205.905 1587.07,205.934 1587.08,205.963 1587.09,205.993 1587.1,206.022 1587.1,206.051 1587.11,206.081 1587.12,206.11 1587.13,206.139 1587.14,206.169 1587.15,206.198 1587.16,206.227 1587.17,206.257 1587.18,206.286 1587.19,206.315 1587.2,206.345 1587.21,206.374 1587.21,206.403 1587.22,206.433 1587.23,206.462 1587.24,206.491 1587.25,206.521 1587.26,206.55 1587.27,206.579 1587.28,206.609 1587.29,206.638 1587.3,206.667 1587.31,206.697 1587.32,206.726 1587.32,206.755 1587.33,206.784 1587.34,206.814 1587.35,206.843 1587.36,206.872 1587.37,206.902 1587.38,206.931 1587.39,206.96 1587.4,206.99 1587.41,207.019 1587.42,207.048 1587.43,207.078 1587.44,207.107 1587.44,207.136 1587.45,207.165 1587.46,207.195 1587.47,207.224 1587.48,207.253 1587.49,207.283 1587.5,207.312 1587.51,207.341 1587.52,207.371 1587.53,207.4 1587.54,207.429 1587.55,207.458 1587.55,207.488 1587.56,207.517 1587.57,207.546 1587.58,207.576 1587.59,207.605 1587.6,207.634 1587.61,207.664 1587.62,207.693 1587.63,207.722 1587.64,207.751 1587.65,207.781 1587.66,207.81 1587.66,207.839 1587.67,207.869 1587.68,207.898 1587.69,207.927 1587.7,207.956 1587.71,207.986 1587.72,208.015 1587.73,208.044 1587.74,208.074 1587.75,208.103 1587.76,208.132 1587.77,208.161 1587.78,208.191 1587.78,208.22 1587.79,208.249 1587.8,208.278 1587.81,208.308 1587.82,208.337 1587.83,208.366 1587.84,208.396 1587.85,208.425 1587.86,208.454 1587.87,208.483 1587.88,208.513 1587.89,208.542 1587.89,208.571 1587.9,208.6 1587.91,208.63 1587.92,208.659 1587.93,208.688 1587.94,208.717 1587.95,208.747 1587.96,208.776 1587.97,208.805 1587.98,208.835 1587.99,208.864 1588,208.893 1588,208.922 1588.01,208.952 1588.02,208.981 1588.03,209.01 1588.04,209.039 1588.05,209.069 1588.06,209.098 1588.07,209.127 1588.08,209.156 1588.09,209.186 1588.1,209.215 1588.11,209.244 1588.12,209.273 1588.12,209.303 1588.13,209.332 1588.14,209.361 1588.15,209.39 1588.16,209.42 1588.17,209.449 1588.18,209.478 1588.19,209.507 1588.2,209.536 1588.21,209.566 1588.22,209.595 1588.23,209.624 1588.23,209.653 1588.24,209.683 1588.25,209.712 1588.26,209.741 1588.27,209.77 1588.28,209.8 1588.29,209.829 1588.3,209.858 1588.31,209.887 1588.32,209.917 1588.33,209.946 1588.34,209.975 1588.34,210.004 1588.35,210.033 1588.36,210.063 1588.37,210.092 1588.38,210.121 1588.39,210.15 1588.4,210.18 1588.41,210.209 1588.42,210.238 1588.43,210.267 1588.44,210.296 1588.45,210.326 1588.46,210.355 1588.46,210.384 1588.47,210.413 1588.48,210.443 1588.49,210.472 1588.5,210.501 1588.51,210.53 1588.52,210.559 1588.53,210.589 1588.54,210.618 1588.55,210.647 1588.56,210.676 1588.57,210.705 1588.57,210.735 1588.58,210.764 1588.59,210.793 1588.6,210.822 1588.61,210.851 1588.62,210.881 1588.63,210.91 1588.64,210.939 1588.65,210.968 1588.66,210.997 1588.67,211.027 1588.68,211.056 1588.68,211.085 1588.69,211.114 1588.7,211.143 1588.71,211.173 1588.72,211.202 1588.73,211.231 1588.74,211.26 1588.75,211.289 1588.76,211.319 1588.77,211.348 1588.78,211.377 1588.79,211.406 1588.8,211.435 1588.8,211.465 1588.81,211.494 1588.82,211.523 1588.83,211.552 1588.84,211.581 1588.85,211.61 1588.86,211.64 1588.87,211.669 1588.88,211.698 1588.89,211.727 1588.9,211.756 1588.91,211.785 1588.91,211.815 1588.92,211.844 1588.93,211.873 1588.94,211.902 1588.95,211.931 1588.96,211.961 1588.97,211.99 1588.98,212.019 1588.99,212.048 1589,212.077 1589.01,212.106 1589.02,212.136 1589.02,212.165 1589.03,212.194 1589.04,212.223 1589.05,212.252 1589.06,212.281 1589.07,212.311 1589.08,212.34 1589.09,212.369 1589.1,212.398 1589.11,212.427 1589.12,212.456 1589.13,212.485 1589.14,212.515 1589.14,212.544 1589.15,212.573 1589.16,212.602 1589.17,212.631 1589.18,212.66 1589.19,212.69 1589.2,212.719 1589.21,212.748 1589.22,212.777 1589.23,212.806 1589.24,212.835 1589.25,212.864 1589.25,212.894 1589.26,212.923 1589.27,212.952 1589.28,212.981 1589.29,213.01 1589.3,213.039 1589.31,213.068 1589.32,213.097 1589.33,213.127 1589.34,213.156 1589.35,213.185 1589.36,213.214 1589.36,213.243 1589.37,213.272 1589.38,213.301 1589.39,213.331 1589.4,213.36 1589.41,213.389 1589.42,213.418 1589.43,213.447 1589.44,213.476 1589.45,213.505 1589.46,213.534 1589.47,213.564 1589.48,213.593 1589.48,213.622 1589.49,213.651 1589.5,213.68 1589.51,213.709 1589.52,213.738 1589.53,213.767 1589.54,213.797 1589.55,213.826 1589.56,213.855 1589.57,213.884 1589.58,213.913 1589.59,213.942 1589.59,213.971 1589.6,214 1589.61,214.029 1589.62,214.059 1589.63,214.088 1589.64,214.117 1589.65,214.146 1589.66,214.175 1589.67,214.204 1589.68,214.233 1589.69,214.262 1589.7,214.291 1589.7,214.32 1589.71,214.35 1589.72,214.379 1589.73,214.408 1589.74,214.437 1589.75,214.466 1589.76,214.495 1589.77,214.524 1589.78,214.553 1589.79,214.582 1589.8,214.611 1589.81,214.64 1589.82,214.67 1589.82,214.699 1589.83,214.728 1589.84,214.757 1589.85,214.786 1589.86,214.815 1589.87,214.844 1589.88,214.873 1589.89,214.902 1589.9,214.931 1589.91,214.96 1589.92,214.989 1589.93,215.019 1589.93,215.048 1589.94,215.077 1589.95,215.106 1589.96,215.135 1589.97,215.164 1589.98,215.193 1589.99,215.222 1590,215.251 1590.01,215.28 1590.02,215.309 1590.03,215.338 1590.04,215.367 1590.04,215.396 1590.05,215.426 1590.06,215.455 1590.07,215.484 1590.08,215.513 1590.09,215.542 1590.1,215.571 1590.11,215.6 1590.12,215.629 1590.13,215.658 1590.14,215.687 1590.15,215.716 1590.16,215.745 1590.16,215.774 1590.17,215.803 1590.18,215.832 1590.19,215.861 1590.2,215.89 1590.21,215.919 1590.22,215.949 1590.23,215.978 1590.24,216.007 1590.25,216.036 1590.26,216.065 1590.27,216.094 1590.27,216.123 1590.28,216.152 1590.29,216.181 1590.3,216.21 1590.31,216.239 1590.32,216.268 1590.33,216.297 1590.34,216.326 1590.35,216.355 1590.36,216.384 1590.37,216.413 1590.38,216.442 1590.38,216.471 1590.39,216.5 1590.4,216.529 1590.41,216.558 1590.42,216.587 1590.43,216.616 1590.44,216.645 1590.45,216.674 1590.46,216.703 1590.47,216.732 1590.48,216.761 1590.49,216.79 1590.5,216.82 1590.5,216.849 1590.51,216.878 1590.52,216.907 1590.53,216.936 1590.54,216.965 1590.55,216.994 1590.56,217.023 1590.57,217.052 1590.58,217.081 1590.59,217.11 1590.6,217.139 1590.61,217.168 1590.61,217.197 1590.62,217.226 1590.63,217.255 1590.64,217.284 1590.65,217.313 1590.66,217.342 1590.67,217.371 1590.68,217.4 1590.69,217.429 1590.7,217.458 1590.71,217.487 1590.72,217.516 1590.72,217.545 1590.73,217.574 1590.74,217.603 1590.75,217.632 1590.76,217.661 1590.77,217.69 1590.78,217.719 1590.79,217.748 1590.8,217.777 1590.81,217.806 1590.82,217.835 1590.83,217.864 1590.84,217.893 1590.84,217.922 1590.85,217.951 1590.86,217.98 1590.87,218.008 1590.88,218.037 1590.89,218.066 1590.9,218.095 1590.91,218.124 1590.92,218.153 1590.93,218.182 1590.94,218.211 1590.95,218.24 1590.95,218.269 1590.96,218.298 1590.97,218.327 1590.98,218.356 1590.99,218.385 1591,218.414 1591.01,218.443 1591.02,218.472 1591.03,218.501 1591.04,218.53 1591.05,218.559 1591.06,218.588 1591.06,218.617 1591.07,218.646 1591.08,218.675 1591.09,218.704 1591.1,218.733 1591.11,218.762 1591.12,218.791 1591.13,218.82 1591.14,218.848 1591.15,218.877 1591.16,218.906 1591.17,218.935 1591.18,218.964 1591.18,218.993 1591.19,219.022 1591.2,219.051 1591.21,219.08 1591.22,219.109 1591.23,219.138 1591.24,219.167 1591.25,219.196 1591.26,219.225 1591.27,219.254 1591.28,219.283 1591.29,219.312 1591.29,219.341 1591.3,219.369 1591.31,219.398 1591.32,219.427 1591.33,219.456 1591.34,219.485 1591.35,219.514 1591.36,219.543 1591.37,219.572 1591.38,219.601 1591.39,219.63 1591.4,219.659 1591.4,219.688 1591.41,219.717 1591.42,219.746 1591.43,219.774 1591.44,219.803 1591.45,219.832 1591.46,219.861 1591.47,219.89 1591.48,219.919 1591.49,219.948 1591.5,219.977 1591.51,220.006 1591.52,220.035 1591.52,220.064 1591.53,220.092 1591.54,220.121 1591.55,220.15 1591.56,220.179 1591.57,220.208 1591.58,220.237 1591.59,220.266 1591.6,220.295 1591.61,220.324 1591.62,220.353 1591.63,220.382 1591.63,220.41 1591.64,220.439 1591.65,220.468 1591.66,220.497 1591.67,220.526 1591.68,220.555 1591.69,220.584 1591.7,220.613 1591.71,220.642 1591.72,220.67 1591.73,220.699 1591.74,220.728 1591.74,220.757 1591.75,220.786 1591.76,220.815 1591.77,220.844 1591.78,220.873 1591.79,220.902 1591.8,220.93 1591.81,220.959 1591.82,220.988 1591.83,221.017 1591.84,221.046 1591.85,221.075 1591.86,221.104 1591.86,221.133 1591.87,221.161 1591.88,221.19 1591.89,221.219 1591.9,221.248 1591.91,221.277 1591.92,221.306 1591.93,221.335 1591.94,221.364 1591.95,221.392 1591.96,221.421 1591.97,221.45 1591.97,221.479 1591.98,221.508 1591.99,221.537 1592,221.566 1592.01,221.594 1592.02,221.623 1592.03,221.652 1592.04,221.681 1592.05,221.71 1592.06,221.739 1592.07,221.768 1592.08,221.796 1592.08,221.825 1592.09,221.854 1592.1,221.883 1592.11,221.912 1592.12,221.941 1592.13,221.969 1592.14,221.998 1592.15,222.027 1592.16,222.056 1592.17,222.085 1592.18,222.114 1592.19,222.142 1592.2,222.171 1592.2,222.2 1592.21,222.229 1592.22,222.258 1592.23,222.287 1592.24,222.315 1592.25,222.344 1592.26,222.373 1592.27,222.402 1592.28,222.431 1592.29,222.46 1592.3,222.488 1592.31,222.517 1592.31,222.546 1592.32,222.575 1592.33,222.604 1592.34,222.633 1592.35,222.661 1592.36,222.69 1592.37,222.719 1592.38,222.748 1592.39,222.777 1592.4,222.805 1592.41,222.834 1592.42,222.863 1592.42,222.892 1592.43,222.921 1592.44,222.95 1592.45,222.978 1592.46,223.007 1592.47,223.036 1592.48,223.065 1592.49,223.094 1592.5,223.122 1592.51,223.151 1592.52,223.18 1592.53,223.209 1592.54,223.238 1592.54,223.266 1592.55,223.295 1592.56,223.324 1592.57,223.353 1592.58,223.382 1592.59,223.41 1592.6,223.439 1592.61,223.468 1592.62,223.497 1592.63,223.525 1592.64,223.554 1592.65,223.583 1592.65,223.612 1592.66,223.641 1592.67,223.669 1592.68,223.698 1592.69,223.727 1592.7,223.756 1592.71,223.784 1592.72,223.813 1592.73,223.842 1592.74,223.871 1592.75,223.9 1592.76,223.928 1592.76,223.957 1592.77,223.986 1592.78,224.015 1592.79,224.043 1592.8,224.072 1592.81,224.101 1592.82,224.13 1592.83,224.158 1592.84,224.187 1592.85,224.216 1592.86,224.245 1592.87,224.274 1592.88,224.302 1592.88,224.331 1592.89,224.36 1592.9,224.389 1592.91,224.417 1592.92,224.446 1592.93,224.475 1592.94,224.504 1592.95,224.532 1592.96,224.561 1592.97,224.59 1592.98,224.619 1592.99,224.647 1592.99,224.676 1593,224.705 1593.01,224.734 1593.02,224.762 1593.03,224.791 1593.04,224.82 1593.05,224.849 1593.06,224.877 1593.07,224.906 1593.08,224.935 1593.09,224.963 1593.1,224.992 1593.1,225.021 1593.11,225.05 1593.12,225.078 1593.13,225.107 1593.14,225.136 1593.15,225.165 1593.16,225.193 1593.17,225.222 1593.18,225.251 1593.19,225.279 1593.2,225.308 1593.21,225.337 1593.22,225.366 1593.22,225.394 1593.23,225.423 1593.24,225.452 1593.25,225.48 1593.26,225.509 1593.27,225.538 1593.28,225.567 1593.29,225.595 1593.3,225.624 1593.31,225.653 1593.32,225.681 1593.33,225.71 1593.33,225.739 1593.34,225.768 1593.35,225.796 1593.36,225.825 1593.37,225.854 1593.38,225.882 1593.39,225.911 1593.4,225.94 1593.41,225.968 1593.42,225.997 1593.43,226.026 1593.44,226.055 1593.44,226.083 1593.45,226.112 1593.46,226.141 1593.47,226.169 1593.48,226.198 1593.49,226.227 1593.5,226.255 1593.51,226.284 1593.52,226.313 1593.53,226.341 1593.54,226.37 1593.55,226.399 1593.56,226.427 1593.56,226.456 1593.57,226.485 1593.58,226.513 1593.59,226.542 1593.6,226.571 1593.61,226.6 1593.62,226.628 1593.63,226.657 1593.64,226.686 1593.65,226.714 1593.66,226.743 1593.67,226.772 1593.67,226.8 1593.68,226.829 1593.69,226.858 1593.7,226.886 1593.71,226.915 1593.72,226.943 1593.73,226.972 1593.74,227.001 1593.75,227.029 1593.76,227.058 1593.77,227.087 1593.78,227.115 1593.78,227.144 1593.79,227.173 1593.8,227.201 1593.81,227.23 1593.82,227.259 1593.83,227.287 1593.84,227.316 1593.85,227.345 1593.86,227.373 1593.87,227.402 1593.88,227.431 1593.89,227.459 1593.9,227.488 1593.9,227.516 1593.91,227.545 1593.92,227.574 1593.93,227.602 1593.94,227.631 1593.95,227.66 1593.96,227.688 1593.97,227.717 1593.98,227.745 1593.99,227.774 1594,227.803 1594.01,227.831 1594.01,227.86 1594.02,227.889 1594.03,227.917 1594.04,227.946 1594.05,227.974 1594.06,228.003 1594.07,228.032 1594.08,228.06 1594.09,228.089 1594.1,228.118 1594.11,228.146 1594.12,228.175 1594.12,228.203 1594.13,228.232 1594.14,228.261 1594.15,228.289 1594.16,228.318 1594.17,228.346 1594.18,228.375 1594.19,228.404 1594.2,228.432 1594.21,228.461 1594.22,228.489 1594.23,228.518 1594.24,228.547 1594.24,228.575 1594.25,228.604 1594.26,228.632 1594.27,228.661 1594.28,228.69 1594.29,228.718 1594.3,228.747 1594.31,228.775 1594.32,228.804 1594.33,228.833 1594.34,228.861 1594.35,228.89 1594.35,228.918 1594.36,228.947 1594.37,228.975 1594.38,229.004 1594.39,229.033 1594.4,229.061 1594.41,229.09 1594.42,229.118 1594.43,229.147 1594.44,229.175 1594.45,229.204 1594.46,229.233 1594.46,229.261 1594.47,229.29 1594.48,229.318 1594.49,229.347 1594.5,229.375 1594.51,229.404 1594.52,229.433 1594.53,229.461 1594.54,229.49 1594.55,229.518 1594.56,229.547 1594.57,229.575 1594.58,229.604 1594.58,229.632 1594.59,229.661 1594.6,229.69 1594.61,229.718 1594.62,229.747 1594.63,229.775 1594.64,229.804 1594.65,229.832 1594.66,229.861 1594.67,229.889 1594.68,229.918 1594.69,229.946 1594.69,229.975 1594.7,230.004 1594.71,230.032 1594.72,230.061 1594.73,230.089 1594.74,230.118 1594.75,230.146 1594.76,230.175 1594.77,230.203 1594.78,230.232 1594.79,230.26 1594.8,230.289 1594.8,230.317 1594.81,230.346 1594.82,230.374 1594.83,230.403 1594.84,230.431 1594.85,230.46 1594.86,230.489 1594.87,230.517 1594.88,230.546 1594.89,230.574 1594.9,230.603 1594.91,230.631 1594.92,230.66 1594.92,230.688 1594.93,230.717 1594.94,230.745 1594.95,230.774 1594.96,230.802 1594.97,230.831 1594.98,230.859 1594.99,230.888 1595,230.916 1595.01,230.945 1595.02,230.973 1595.03,231.002 1595.03,231.03 1595.04,231.059 1595.05,231.087 1595.06,231.116 1595.07,231.144 1595.08,231.173 1595.09,231.201 1595.1,231.23 1595.11,231.258 1595.12,231.287 1595.13,231.315 1595.14,231.344 1595.14,231.372 1595.15,231.401 1595.16,231.429 1595.17,231.457 1595.18,231.486 1595.19,231.514 1595.2,231.543 1595.21,231.571 1595.22,231.6 1595.23,231.628 1595.24,231.657 1595.25,231.685 1595.26,231.714 1595.26,231.742 1595.27,231.771 1595.28,231.799 1595.29,231.828 1595.3,231.856 1595.31,231.885 1595.32,231.913 1595.33,231.941 1595.34,231.97 1595.35,231.998 1595.36,232.027 1595.37,232.055 1595.37,232.084 1595.38,232.112 1595.39,232.141 1595.4,232.169 1595.41,232.198 1595.42,232.226 1595.43,232.254 1595.44,232.283 1595.45,232.311 1595.46,232.34 1595.47,232.368 1595.48,232.397 1595.48,232.425 1595.49,232.454 1595.5,232.482 1595.51,232.51 1595.52,232.539 1595.53,232.567 1595.54,232.596 1595.55,232.624 1595.56,232.653 1595.57,232.681 1595.58,232.709 1595.59,232.738 1595.6,232.766 1595.6,232.795 1595.61,232.823 1595.62,232.852 1595.63,232.88 1595.64,232.908 1595.65,232.937 1595.66,232.965 1595.67,232.994 1595.68,233.022 1595.69,233.05 1595.7,233.079 1595.71,233.107 1595.71,233.136 1595.72,233.164 1595.73,233.193 1595.74,233.221 1595.75,233.249 1595.76,233.278 1595.77,233.306 1595.78,233.335 1595.79,233.363 1595.8,233.391 1595.81,233.42 1595.82,233.448 1595.82,233.477 1595.83,233.505 1595.84,233.533 1595.85,233.562 1595.86,233.59 1595.87,233.618 1595.88,233.647 1595.89,233.675 1595.9,233.704 1595.91,233.732 1595.92,233.76 1595.93,233.789 1595.94,233.817 1595.94,233.846 1595.95,233.874 1595.96,233.902 1595.97,233.931 1595.98,233.959 1595.99,233.987 1596,234.016 1596.01,234.044 1596.02,234.073 1596.03,234.101 1596.04,234.129 1596.05,234.158 1596.05,234.186 1596.06,234.214 1596.07,234.243 1596.08,234.271 1596.09,234.299 1596.1,234.328 1596.11,234.356 1596.12,234.385 1596.13,234.413 1596.14,234.441 1596.15,234.47 1596.16,234.498 1596.16,234.526 1596.17,234.555 1596.18,234.583 1596.19,234.611 1596.2,234.64 1596.21,234.668 1596.22,234.696 1596.23,234.725 1596.24,234.753 1596.25,234.781 1596.26,234.81 1596.27,234.838 1596.28,234.866 1596.28,234.895 1596.29,234.923 1596.3,234.951 1596.31,234.98 1596.32,235.008 1596.33,235.036 1596.34,235.065 1596.35,235.093 1596.36,235.121 1596.37,235.15 1596.38,235.178 1596.39,235.206 1596.39,235.235 1596.4,235.263 1596.41,235.291 1596.42,235.32 1596.43,235.348 1596.44,235.376 1596.45,235.405 1596.46,235.433 1596.47,235.461 1596.48,235.49 1596.49,235.518 1596.5,235.546 1596.5,235.575 1596.51,235.603 1596.52,235.631 1596.53,235.659 1596.54,235.688 1596.55,235.716 1596.56,235.744 1596.57,235.773 1596.58,235.801 1596.59,235.829 1596.6,235.858 1596.61,235.886 1596.62,235.914 1596.62,235.942 1596.63,235.971 1596.64,235.999 1596.65,236.027 1596.66,236.056 1596.67,236.084 1596.68,236.112 1596.69,236.14 1596.7,236.169 1596.71,236.197 1596.72,236.225 1596.73,236.254 1596.73,236.282 1596.74,236.31 1596.75,236.338 1596.76,236.367 1596.77,236.395 1596.78,236.423 1596.79,236.451 1596.8,236.48 1596.81,236.508 1596.82,236.536 1596.83,236.565 1596.84,236.593 1596.84,236.621 1596.85,236.649 1596.86,236.678 1596.87,236.706 1596.88,236.734 1596.89,236.762 1596.9,236.791 1596.91,236.819 1596.92,236.847 1596.93,236.875 1596.94,236.904 1596.95,236.932 1596.96,236.96 1596.96,236.988 1596.97,237.017 1596.98,237.045 1596.99,237.073 1597,237.101 1597.01,237.13 1597.02,237.158 1597.03,237.186 1597.04,237.214 1597.05,237.242 1597.06,237.271 1597.07,237.299 1597.07,237.327 1597.08,237.355 1597.09,237.384 1597.1,237.412 1597.11,237.44 1597.12,237.468 1597.13,237.497 1597.14,237.525 1597.15,237.553 1597.16,237.581 1597.17,237.609 1597.18,237.638 1597.18,237.666 1597.19,237.694 1597.2,237.722 1597.21,237.751 1597.22,237.779 1597.23,237.807 1597.24,237.835 1597.25,237.863 1597.26,237.892 1597.27,237.92 1597.28,237.948 1597.29,237.976 1597.3,238.004 1597.3,238.033 1597.31,238.061 1597.32,238.089 1597.33,238.117 1597.34,238.145 1597.35,238.174 1597.36,238.202 1597.37,238.23 1597.38,238.258 1597.39,238.286 1597.4,238.314 1597.41,238.343 1597.41,238.371 1597.42,238.399 1597.43,238.427 1597.44,238.455 1597.45,238.484 1597.46,238.512 1597.47,238.54 1597.48,238.568 1597.49,238.596 1597.5,238.624 1597.51,238.653 1597.52,238.681 1597.52,238.709 1597.53,238.737 1597.54,238.765 1597.55,238.794 1597.56,238.822 1597.57,238.85 1597.58,238.878 1597.59,238.906 1597.6,238.934 1597.61,238.962 1597.62,238.991 1597.63,239.019 1597.64,239.047 1597.64,239.075 1597.65,239.103 1597.66,239.131 1597.67,239.16 1597.68,239.188 1597.69,239.216 1597.7,239.244 1597.71,239.272 1597.72,239.3 1597.73,239.328 1597.74,239.357 1597.75,239.385 1597.75,239.413 1597.76,239.441 1597.77,239.469 1597.78,239.497 1597.79,239.525 1597.8,239.554 1597.81,239.582 1597.82,239.61 1597.83,239.638 1597.84,239.666 1597.85,239.694 1597.86,239.722 1597.86,239.75 1597.87,239.779 1597.88,239.807 1597.89,239.835 1597.9,239.863 1597.91,239.891 1597.92,239.919 1597.93,239.947 1597.94,239.975 1597.95,240.003 1597.96,240.032 1597.97,240.06 1597.98,240.088 1597.98,240.116 1597.99,240.144 1598,240.172 1598.01,240.2 1598.02,240.228 1598.03,240.256 1598.04,240.285 1598.05,240.313 1598.06,240.341 1598.07,240.369 1598.08,240.397 1598.09,240.425 1598.09,240.453 1598.1,240.481 1598.11,240.509 1598.12,240.537 1598.13,240.565 1598.14,240.594 1598.15,240.622 1598.16,240.65 1598.17,240.678 1598.18,240.706 1598.19,240.734 1598.2,240.762 1598.2,240.79 1598.21,240.818 1598.22,240.846 1598.23,240.874 1598.24,240.902 1598.25,240.93 1598.26,240.959 1598.27,240.987 1598.28,241.015 1598.29,241.043 1598.3,241.071 1598.31,241.099 1598.32,241.127 1598.32,241.155 1598.33,241.183 1598.34,241.211 1598.35,241.239 1598.36,241.267 1598.37,241.295 1598.38,241.323 1598.39,241.351 1598.4,241.379 1598.41,241.407 1598.42,241.436 1598.43,241.464 1598.43,241.492 1598.44,241.52 1598.45,241.548 1598.46,241.576 1598.47,241.604 1598.48,241.632 1598.49,241.66 1598.5,241.688 1598.51,241.716 1598.52,241.744 1598.53,241.772 1598.54,241.8 1598.54,241.828 1598.55,241.856 1598.56,241.884 1598.57,241.912 1598.58,241.94 1598.59,241.968 1598.6,241.996 1598.61,242.024 1598.62,242.052 1598.63,242.08 1598.64,242.108 1598.65,242.136 1598.66,242.164 1598.66,242.192 1598.67,242.22 1598.68,242.248 1598.69,242.276 1598.7,242.304 1598.71,242.332 1598.72,242.36 1598.73,242.388 1598.74,242.416 1598.75,242.444 1598.76,242.472 1598.77,242.5 1598.77,242.528 1598.78,242.556 1598.79,242.584 1598.8,242.612 1598.81,242.64 1598.82,242.668 1598.83,242.696 1598.84,242.724 1598.85,242.752 1598.86,242.78 1598.87,242.808 1598.88,242.836 1598.88,242.864 1598.89,242.892 1598.9,242.92 1598.91,242.948 1598.92,242.976 1598.93,243.004 1598.94,243.032 1598.95,243.06 1598.96,243.088 1598.97,243.116 1598.98,243.144 1598.99,243.172 1599,243.2 1599,243.228 1599.01,243.256 1599.02,243.284 1599.03,243.312 1599.04,243.34 1599.05,243.368 1599.06,243.396 1599.07,243.424 1599.08,243.452 1599.09,243.48 1599.1,243.508 1599.11,243.535 1599.11,243.563 1599.12,243.591 1599.13,243.619 1599.14,243.647 1599.15,243.675 1599.16,243.703 1599.17,243.731 1599.18,243.759 1599.19,243.787 1599.2,243.815 1599.21,243.843 1599.22,243.871 1599.22,243.899 1599.23,243.927 1599.24,243.955 1599.25,243.982 1599.26,244.01 1599.27,244.038 1599.28,244.066 1599.29,244.094 1599.3,244.122 1599.31,244.15 1599.32,244.178 1599.33,244.206 1599.34,244.234 1599.34,244.262 1599.35,244.29 1599.36,244.318 1599.37,244.345 1599.38,244.373 1599.39,244.401 1599.4,244.429 1599.41,244.457 1599.42,244.485 1599.43,244.513 1599.44,244.541 1599.45,244.569 1599.45,244.597 1599.46,244.625 1599.47,244.652 1599.48,244.68 1599.49,244.708 1599.5,244.736 1599.51,244.764 1599.52,244.792 1599.53,244.82 1599.54,244.848 1599.55,244.876 1599.56,244.903 1599.56,244.931 1599.57,244.959 1599.58,244.987 1599.59,245.015 1599.6,245.043 1599.61,245.071 1599.62,245.099 1599.63,245.127 1599.64,245.154 1599.65,245.182 1599.66,245.21 1599.67,245.238 1599.68,245.266 1599.68,245.294 1599.69,245.322 1599.7,245.349 1599.71,245.377 1599.72,245.405 1599.73,245.433 1599.74,245.461 1599.75,245.489 1599.76,245.517 1599.77,245.544 1599.78,245.572 1599.79,245.6 1599.79,245.628 1599.8,245.656 1599.81,245.684 1599.82,245.712 1599.83,245.739 1599.84,245.767 1599.85,245.795 1599.86,245.823 1599.87,245.851 1599.88,245.879 1599.89,245.907 1599.9,245.934 1599.9,245.962 1599.91,245.99 1599.92,246.018 1599.93,246.046 1599.94,246.074 1599.95,246.101 1599.96,246.129 1599.97,246.157 1599.98,246.185 1599.99,246.213 1600,246.24 1600.01,246.268 1600.02,246.296 1600.02,246.324 1600.03,246.352 1600.04,246.38 1600.05,246.407 1600.06,246.435 1600.07,246.463 1600.08,246.491 1600.09,246.519 1600.1,246.546 1600.11,246.574 1600.12,246.602 1600.13,246.63 1600.13,246.658 1600.14,246.685 1600.15,246.713 1600.16,246.741 1600.17,246.769 1600.18,246.797 1600.19,246.824 1600.2,246.852 1600.21,246.88 1600.22,246.908 1600.23,246.936 1600.24,246.963 1600.24,246.991 1600.25,247.019 1600.26,247.047 1600.27,247.075 1600.28,247.102 1600.29,247.13 1600.3,247.158 1600.31,247.186 1600.32,247.213 1600.33,247.241 1600.34,247.269 1600.35,247.297 1600.36,247.325 1600.36,247.352 1600.37,247.38 1600.38,247.408 1600.39,247.436 1600.4,247.463 1600.41,247.491 1600.42,247.519 1600.43,247.547 1600.44,247.574 1600.45,247.602 1600.46,247.63 1600.47,247.658 1600.47,247.685 1600.48,247.713 1600.49,247.741 1600.5,247.769 1600.51,247.796 1600.52,247.824 1600.53,247.852 1600.54,247.88 1600.55,247.907 1600.56,247.935 1600.57,247.963 1600.58,247.991 1600.58,248.018 1600.59,248.046 1600.6,248.074 1600.61,248.102 1600.62,248.129 1600.63,248.157 1600.64,248.185 1600.65,248.213 1600.66,248.24 1600.67,248.268 1600.68,248.296 1600.69,248.323 1600.7,248.351 1600.7,248.379 1600.71,248.407 1600.72,248.434 1600.73,248.462 1600.74,248.49 1600.75,248.517 1600.76,248.545 1600.77,248.573 1600.78,248.601 1600.79,248.628 1600.8,248.656 1600.81,248.684 1600.81,248.711 1600.82,248.739 1600.83,248.767 1600.84,248.795 1600.85,248.822 1600.86,248.85 1600.87,248.878 1600.88,248.905 1600.89,248.933 1600.9,248.961 1600.91,248.988 1600.92,249.016 1600.92,249.044 1600.93,249.071 1600.94,249.099 1600.95,249.127 1600.96,249.155 1600.97,249.182 1600.98,249.21 1600.99,249.238 1601,249.265 1601.01,249.293 1601.02,249.321 1601.03,249.348 1601.04,249.376 1601.04,249.404 1601.05,249.431 1601.06,249.459 1601.07,249.487 1601.08,249.514 1601.09,249.542 1601.1,249.57 1601.11,249.597 1601.12,249.625 1601.13,249.653 1601.14,249.68 1601.15,249.708 1601.15,249.736 1601.16,249.763 1601.17,249.791 1601.18,249.819 1601.19,249.846 1601.2,249.874 1601.21,249.901 1601.22,249.929 1601.23,249.957 1601.24,249.984 1601.25,250.012 1601.26,250.04 1601.26,250.067 1601.27,250.095 1601.28,250.123 1601.29,250.15 1601.3,250.178 1601.31,250.205 1601.32,250.233 1601.33,250.261 1601.34,250.288 1601.35,250.316 1601.36,250.344 1601.37,250.371 1601.38,250.399 1601.38,250.426 1601.39,250.454 1601.4,250.482 1601.41,250.509 1601.42,250.537 1601.43,250.565 1601.44,250.592 1601.45,250.62 1601.46,250.647 1601.47,250.675 1601.48,250.703 1601.49,250.73 1601.49,250.758 1601.5,250.785 1601.51,250.813 1601.52,250.841 1601.53,250.868 1601.54,250.896 1601.55,250.923 1601.56,250.951 1601.57,250.979 1601.58,251.006 1601.59,251.034 1601.6,251.061 1601.6,251.089 1601.61,251.117 1601.62,251.144 1601.63,251.172 1601.64,251.199 1601.65,251.227 1601.66,251.254 1601.67,251.282 1601.68,251.31 1601.69,251.337 1601.7,251.365 1601.71,251.392 1601.72,251.42 1601.72,251.447 1601.73,251.475 1601.74,251.503 1601.75,251.53 1601.76,251.558 1601.77,251.585 1601.78,251.613 1601.79,251.64 1601.8,251.668 1601.81,251.696 1601.82,251.723 1601.83,251.751 1601.83,251.778 1601.84,251.806 1601.85,251.833 1601.86,251.861 1601.87,251.888 1601.88,251.916 1601.89,251.944 1601.9,251.971 1601.91,251.999 1601.92,252.026 1601.93,252.054 1601.94,252.081 1601.94,252.109 1601.95,252.136 1601.96,252.164 1601.97,252.191 1601.98,252.219 1601.99,252.246 1602,252.274 1602.01,252.301 1602.02,252.329 1602.03,252.357 1602.04,252.384 1602.05,252.412 1602.06,252.439 1602.06,252.467 1602.07,252.494 1602.08,252.522 1602.09,252.549 1602.1,252.577 1602.11,252.604 1602.12,252.632 1602.13,252.659 1602.14,252.687 1602.15,252.714 1602.16,252.742 1602.17,252.769 1602.17,252.797 1602.18,252.824 1602.19,252.852 1602.2,252.879 1602.21,252.907 1602.22,252.934 1602.23,252.962 1602.24,252.989 1602.25,253.017 1602.26,253.044 1602.27,253.072 1602.28,253.099 1602.28,253.127 1602.29,253.154 1602.3,253.182 1602.31,253.209 1602.32,253.237 1602.33,253.264 1602.34,253.292 1602.35,253.319 1602.36,253.346 1602.37,253.374 1602.38,253.401 1602.39,253.429 1602.4,253.456 1602.4,253.484 1602.41,253.511 1602.42,253.539 1602.43,253.566 1602.44,253.594 1602.45,253.621 1602.46,253.649 1602.47,253.676 1602.48,253.704 1602.49,253.731 1602.5,253.758 1602.51,253.786 1602.51,253.813 1602.52,253.841 1602.53,253.868 1602.54,253.896 1602.55,253.923 1602.56,253.951 1602.57,253.978 1602.58,254.005 1602.59,254.033 1602.6,254.06 1602.61,254.088 1602.62,254.115 1602.62,254.143 1602.63,254.17 1602.64,254.198 1602.65,254.225 1602.66,254.252 1602.67,254.28 1602.68,254.307 1602.69,254.335 1602.7,254.362 1602.71,254.39 1602.72,254.417 1602.73,254.444 1602.74,254.472 1602.74,254.499 1602.75,254.527 1602.76,254.554 1602.77,254.581 1602.78,254.609 1602.79,254.636 1602.8,254.664 1602.81,254.691 1602.82,254.718 1602.83,254.746 1602.84,254.773 1602.85,254.801 1602.85,254.828 1602.86,254.855 1602.87,254.883 1602.88,254.91 1602.89,254.938 1602.9,254.965 1602.91,254.992 1602.92,255.02 1602.93,255.047 1602.94,255.075 1602.95,255.102 1602.96,255.129 1602.96,255.157 1602.97,255.184 1602.98,255.212 1602.99,255.239 1603,255.266 1603.01,255.294 1603.02,255.321 1603.03,255.348 1603.04,255.376 1603.05,255.403 1603.06,255.43 1603.07,255.458 1603.08,255.485 1603.08,255.513 1603.09,255.54 1603.1,255.567 1603.11,255.595 1603.12,255.622 1603.13,255.649 1603.14,255.677 1603.15,255.704 1603.16,255.731 1603.17,255.759 1603.18,255.786 1603.19,255.814 1603.19,255.841 1603.2,255.868 1603.21,255.896 1603.22,255.923 1603.23,255.95 1603.24,255.978 1603.25,256.005 1603.26,256.032 1603.27,256.06 1603.28,256.087 1603.29,256.114 1603.3,256.142 1603.3,256.169 1603.31,256.196 1603.32,256.224 1603.33,256.251 1603.34,256.278 1603.35,256.306 1603.36,256.333 1603.37,256.36 1603.38,256.388 1603.39,256.415 1603.4,256.442 1603.41,256.469 1603.42,256.497 1603.42,256.524 1603.43,256.551 1603.44,256.579 1603.45,256.606 1603.46,256.633 1603.47,256.661 1603.48,256.688 1603.49,256.715 1603.5,256.743 1603.51,256.77 1603.52,256.797 1603.53,256.824 1603.53,256.852 1603.54,256.879 1603.55,256.906 1603.56,256.934 1603.57,256.961 1603.58,256.988 1603.59,257.015 1603.6,257.043 1603.61,257.07 1603.62,257.097 1603.63,257.125 1603.64,257.152 1603.64,257.179 1603.65,257.206 1603.66,257.234 1603.67,257.261 1603.68,257.288 1603.69,257.316 1603.7,257.343 1603.71,257.37 1603.72,257.397 1603.73,257.425 1603.74,257.452 1603.75,257.479 1603.76,257.506 1603.76,257.534 1603.77,257.561 1603.78,257.588 1603.79,257.615 1603.8,257.643 1603.81,257.67 1603.82,257.697 1603.83,257.724 1603.84,257.752 1603.85,257.779 1603.86,257.806 1603.87,257.833 1603.87,257.861 1603.88,257.888 1603.89,257.915 1603.9,257.942 1603.91,257.97 1603.92,257.997 1603.93,258.024 1603.94,258.051 1603.95,258.079 1603.96,258.106 1603.97,258.133 1603.98,258.16 1603.98,258.187 1603.99,258.215 1604,258.242 1604.01,258.269 1604.02,258.296 1604.03,258.324 1604.04,258.351 1604.05,258.378 1604.06,258.405 1604.07,258.432 1604.08,258.46 1604.09,258.487 1604.1,258.514 1604.1,258.541 1604.11,258.569 1604.12,258.596 1604.13,258.623 1604.14,258.65 1604.15,258.677 1604.16,258.705 1604.17,258.732 1604.18,258.759 1604.19,258.786 1604.2,258.813 1604.21,258.84 1604.21,258.868 1604.22,258.895 1604.23,258.922 1604.24,258.949 1604.25,258.976 1604.26,259.004 1604.27,259.031 1604.28,259.058 1604.29,259.085 1604.3,259.112 1604.31,259.14 1604.32,259.167 1604.32,259.194 1604.33,259.221 1604.34,259.248 1604.35,259.275 1604.36,259.303 1604.37,259.33 1604.38,259.357 1604.39,259.384 1604.4,259.411 1604.41,259.438 1604.42,259.466 1604.43,259.493 1604.44,259.52 1604.44,259.547 1604.45,259.574 1604.46,259.601 1604.47,259.628 1604.48,259.656 1604.49,259.683 1604.5,259.71 1604.51,259.737 1604.52,259.764 1604.53,259.791 1604.54,259.818 1604.55,259.846 1604.55,259.873 1604.56,259.9 1604.57,259.927 1604.58,259.954 1604.59,259.981 1604.6,260.008 1604.61,260.036 1604.62,260.063 1604.63,260.09 1604.64,260.117 1604.65,260.144 1604.66,260.171 1604.66,260.198 1604.67,260.225 1604.68,260.253 1604.69,260.28 1604.7,260.307 1604.71,260.334 1604.72,260.361 1604.73,260.388 1604.74,260.415 1604.75,260.442 1604.76,260.469 1604.77,260.497 1604.78,260.524 1604.78,260.551 1604.79,260.578 1604.8,260.605 1604.81,260.632 1604.82,260.659 1604.83,260.686 1604.84,260.713 1604.85,260.74 1604.86,260.767 1604.87,260.795 1604.88,260.822 1604.89,260.849 1604.89,260.876 1604.9,260.903 1604.91,260.93 1604.92,260.957 1604.93,260.984 1604.94,261.011 1604.95,261.038 1604.96,261.065 1604.97,261.092 1604.98,261.12 1604.99,261.147 1605,261.174 1605.01,261.201 1605.01,261.228 1605.02,261.255 1605.03,261.282 1605.04,261.309 1605.05,261.336 1605.06,261.363 1605.07,261.39 1605.08,261.417 1605.09,261.444 1605.1,261.471 1605.11,261.498 1605.12,261.525 1605.12,261.552 1605.13,261.58 1605.14,261.607 1605.15,261.634 1605.16,261.661 1605.17,261.688 1605.18,261.715 1605.19,261.742 1605.2,261.769 1605.21,261.796 1605.22,261.823 1605.23,261.85 1605.23,261.877 1605.24,261.904 1605.25,261.931 1605.26,261.958 1605.27,261.985 1605.28,262.012 1605.29,262.039 1605.3,262.066 1605.31,262.093 1605.32,262.12 1605.33,262.147 1605.34,262.174 1605.35,262.201 1605.35,262.228 1605.36,262.255 1605.37,262.282 1605.38,262.309 1605.39,262.336 1605.4,262.363 1605.41,262.39 1605.42,262.417 1605.43,262.444 1605.44,262.471 1605.45,262.498 1605.46,262.525 1605.46,262.552 1605.47,262.579 1605.48,262.606 1605.49,262.633 1605.5,262.66 1605.51,262.687 1605.52,262.714 1605.53,262.741 1605.54,262.768 1605.55,262.795 1605.56,262.822 1605.57,262.849 1605.57,262.876 1605.58,262.903 1605.59,262.93 1605.6,262.957 1605.61,262.984 1605.62,263.011 1605.63,263.038 1605.64,263.065 1605.65,263.092 1605.66,263.119 1605.67,263.146 1605.68,263.173 1605.69,263.2 1605.69,263.227 1605.7,263.254 1605.71,263.281 1605.72,263.308 1605.73,263.334 1605.74,263.361 1605.75,263.388 1605.76,263.415 1605.77,263.442 1605.78,263.469 1605.79,263.496 1605.8,263.523 1605.8,263.55 1605.81,263.577 1605.82,263.604 1605.83,263.631 1605.84,263.658 1605.85,263.685 1605.86,263.712 1605.87,263.739 1605.88,263.766 1605.89,263.792 1605.9,263.819 1605.91,263.846 1605.91,263.873 1605.92,263.9 1605.93,263.927 1605.94,263.954 1605.95,263.981 1605.96,264.008 1605.97,264.035 1605.98,264.062 1605.99,264.089 1606,264.115 1606.01,264.142 1606.02,264.169 1606.03,264.196 1606.03,264.223 1606.04,264.25 1606.05,264.277 1606.06,264.304 1606.07,264.331 1606.08,264.358 1606.09,264.385 1606.1,264.411 1606.11,264.438 1606.12,264.465 1606.13,264.492 1606.14,264.519 1606.14,264.546 1606.15,264.573 1606.16,264.6 1606.17,264.627 1606.18,264.653 1606.19,264.68 1606.2,264.707 1606.21,264.734 1606.22,264.761 1606.23,264.788 1606.24,264.815 1606.25,264.842 1606.25,264.868 1606.26,264.895 1606.27,264.922 1606.28,264.949 1606.29,264.976 1606.3,265.003 1606.31,265.03 1606.32,265.056 1606.33,265.083 1606.34,265.11 1606.35,265.137 1606.36,265.164 1606.37,265.191 1606.37,265.218 1606.38,265.244 1606.39,265.271 1606.4,265.298 1606.41,265.325 1606.42,265.352 1606.43,265.379 1606.44,265.405 1606.45,265.432 1606.46,265.459 1606.47,265.486 1606.48,265.513 1606.48,265.54 1606.49,265.566 1606.5,265.593 1606.51,265.62 1606.52,265.647 1606.53,265.674 1606.54,265.701 1606.55,265.727 1606.56,265.754 1606.57,265.781 1606.58,265.808 1606.59,265.835 1606.59,265.862 1606.6,265.888 1606.61,265.915 1606.62,265.942 1606.63,265.969 1606.64,265.996 1606.65,266.022 1606.66,266.049 1606.67,266.076 1606.68,266.103 1606.69,266.13 1606.7,266.156 1606.71,266.183 1606.71,266.21 1606.72,266.237 1606.73,266.264 1606.74,266.29 1606.75,266.317 1606.76,266.344 1606.77,266.371 1606.78,266.398 1606.79,266.424 1606.8,266.451 1606.81,266.478 1606.82,266.505 1606.82,266.531 1606.83,266.558 1606.84,266.585 1606.85,266.612 1606.86,266.639 1606.87,266.665 1606.88,266.692 1606.89,266.719 1606.9,266.746 1606.91,266.772 1606.92,266.799 1606.93,266.826 1606.93,266.853 1606.94,266.879 1606.95,266.906 1606.96,266.933 1606.97,266.96 1606.98,266.986 1606.99,267.013 1607,267.04 1607.01,267.067 1607.02,267.093 1607.03,267.12 1607.04,267.147 1607.05,267.174 1607.05,267.2 1607.06,267.227 1607.07,267.254 1607.08,267.281 1607.09,267.307 1607.1,267.334 1607.11,267.361 1607.12,267.388 1607.13,267.414 1607.14,267.441 1607.15,267.468 1607.16,267.495 1607.16,267.521 1607.17,267.548 1607.18,267.575 1607.19,267.601 1607.2,267.628 1607.21,267.655 1607.22,267.682 1607.23,267.708 1607.24,267.735 1607.25,267.762 1607.26,267.788 1607.27,267.815 1607.27,267.842 1607.28,267.869 1607.29,267.895 1607.3,267.922 1607.31,267.949 1607.32,267.975 1607.33,268.002 1607.34,268.029 1607.35,268.055 1607.36,268.082 1607.37,268.109 1607.38,268.135 1607.39,268.162 1607.39,268.189 1607.4,268.216 1607.41,268.242 1607.42,268.269 1607.43,268.296 1607.44,268.322 1607.45,268.349 1607.46,268.376 1607.47,268.402 1607.48,268.429 1607.49,268.456 1607.5,268.482 1607.5,268.509 1607.51,268.536 1607.52,268.562 1607.53,268.589 1607.54,268.616 1607.55,268.642 1607.56,268.669 1607.57,268.696 1607.58,268.722 1607.59,268.749 1607.6,268.776 1607.61,268.802 1607.61,268.829 1607.62,268.856 1607.63,268.882 1607.64,268.909 1607.65,268.936 1607.66,268.962 1607.67,268.989 1607.68,269.015 1607.69,269.042 1607.7,269.069 1607.71,269.095 1607.72,269.122 1607.73,269.149 1607.73,269.175 1607.74,269.202 1607.75,269.229 1607.76,269.255 1607.77,269.282 1607.78,269.308 1607.79,269.335 1607.8,269.362 1607.81,269.388 1607.82,269.415 1607.83,269.441 1607.84,269.468 1607.84,269.495 1607.85,269.521 1607.86,269.548 1607.87,269.575 1607.88,269.601 1607.89,269.628 1607.9,269.654 1607.91,269.681 1607.92,269.708 1607.93,269.734 1607.94,269.761 1607.95,269.787 1607.95,269.814 1607.96,269.841 1607.97,269.867 1607.98,269.894 1607.99,269.92 1608,269.947 1608.01,269.974 1608.02,270 1608.03,270.027 1608.04,270.053 1608.05,270.08 1608.06,270.106 1608.07,270.133 1608.07,270.16 1608.08,270.186 1608.09,270.213 1608.1,270.239 1608.11,270.266 1608.12,270.292 1608.13,270.319 1608.14,270.346 1608.15,270.372 1608.16,270.399 1608.17,270.425 1608.18,270.452 1608.18,270.478 1608.19,270.505 1608.2,270.532 1608.21,270.558 1608.22,270.585 1608.23,270.611 1608.24,270.638 1608.25,270.664 1608.26,270.691 1608.27,270.717 1608.28,270.744 1608.29,270.77 1608.29,270.797 1608.3,270.824 1608.31,270.85 1608.32,270.877 1608.33,270.903 1608.34,270.93 1608.35,270.956 1608.36,270.983 1608.37,271.009 1608.38,271.036 1608.39,271.062 1608.4,271.089 1608.41,271.115 1608.41,271.142 1608.42,271.168 1608.43,271.195 1608.44,271.221 1608.45,271.248 1608.46,271.275 1608.47,271.301 1608.48,271.328 1608.49,271.354 1608.5,271.381 1608.51,271.407 1608.52,271.434 1608.52,271.46 1608.53,271.487 1608.54,271.513 1608.55,271.54 1608.56,271.566 1608.57,271.593 1608.58,271.619 1608.59,271.646 1608.6,271.672 1608.61,271.699 1608.62,271.725 1608.63,271.752 1608.63,271.778 1608.64,271.805 1608.65,271.831 1608.66,271.857 1608.67,271.884 1608.68,271.91 1608.69,271.937 1608.7,271.963 1608.71,271.99 1608.72,272.016 1608.73,272.043 1608.74,272.069 1608.75,272.096 1608.75,272.122 1608.76,272.149 1608.77,272.175 1608.78,272.202 1608.79,272.228 1608.8,272.255 1608.81,272.281 1608.82,272.307 1608.83,272.334 1608.84,272.36 1608.85,272.387 1608.86,272.413 1608.86,272.44 1608.87,272.466 1608.88,272.493 1608.89,272.519 1608.9,272.545 1608.91,272.572 1608.92,272.598 1608.93,272.625 1608.94,272.651 1608.95,272.678 1608.96,272.704 1608.97,272.731 1608.97,272.757 1608.98,272.783 1608.99,272.81 1609,272.836 1609.01,272.863 1609.02,272.889 1609.03,272.916 1609.04,272.942 1609.05,272.968 1609.06,272.995 1609.07,273.021 1609.08,273.048 1609.09,273.074 1609.09,273.1 1609.1,273.127 1609.11,273.153 1609.12,273.18 1609.13,273.206 1609.14,273.232 1609.15,273.259 1609.16,273.285 1609.17,273.312 1609.18,273.338 1609.19,273.364 1609.2,273.391 1609.2,273.417 1609.21,273.444 1609.22,273.47 1609.23,273.496 1609.24,273.523 1609.25,273.549 1609.26,273.576 1609.27,273.602 1609.28,273.628 1609.29,273.655 1609.3,273.681 1609.31,273.707 1609.31,273.734 1609.32,273.76 1609.33,273.787 1609.34,273.813 1609.35,273.839 1609.36,273.866 1609.37,273.892 1609.38,273.918 1609.39,273.945 1609.4,273.971 1609.41,273.998 1609.42,274.024 1609.43,274.05 1609.43,274.077 1609.44,274.103 1609.45,274.129 1609.46,274.156 1609.47,274.182 1609.48,274.208 1609.49,274.235 1609.5,274.261 1609.51,274.287 1609.52,274.314 1609.53,274.34 1609.54,274.366 1609.54,274.393 1609.55,274.419 1609.56,274.445 1609.57,274.472 1609.58,274.498 1609.59,274.524 1609.6,274.551 1609.61,274.577 1609.62,274.603 1609.63,274.63 1609.64,274.656 1609.65,274.682 1609.65,274.709 1609.66,274.735 1609.67,274.761 1609.68,274.788 1609.69,274.814 1609.7,274.84 1609.71,274.867 1609.72,274.893 1609.73,274.919 1609.74,274.946 1609.75,274.972 1609.76,274.998 1609.77,275.024 1609.77,275.051 1609.78,275.077 1609.79,275.103 1609.8,275.13 1609.81,275.156 1609.82,275.182 1609.83,275.208 1609.84,275.235 1609.85,275.261 1609.86,275.287 1609.87,275.314 1609.88,275.34 1609.88,275.366 1609.89,275.392 1609.9,275.419 1609.91,275.445 1609.92,275.471 1609.93,275.498 1609.94,275.524 1609.95,275.55 1609.96,275.576 1609.97,275.603 1609.98,275.629 1609.99,275.655 1609.99,275.681 1610,275.708 1610.01,275.734 1610.02,275.76 1610.03,275.786 1610.04,275.813 1610.05,275.839 1610.06,275.865 1610.07,275.892 1610.08,275.918 1610.09,275.944 1610.1,275.97 1610.11,275.997 1610.11,276.023 1610.12,276.049 1610.13,276.075 1610.14,276.101 1610.15,276.128 1610.16,276.154 1610.17,276.18 1610.18,276.206 1610.19,276.233 1610.2,276.259 1610.21,276.285 1610.22,276.311 1610.22,276.338 1610.23,276.364 1610.24,276.39 1610.25,276.416 1610.26,276.442 1610.27,276.469 1610.28,276.495 1610.29,276.521 1610.3,276.547 1610.31,276.574 1610.32,276.6 1610.33,276.626 1610.33,276.652 1610.34,276.678 1610.35,276.705 1610.36,276.731 1610.37,276.757 1610.38,276.783 1610.39,276.809 1610.4,276.836 1610.41,276.862 1610.42,276.888 1610.43,276.914 1610.44,276.94 1610.45,276.967 1610.45,276.993 1610.46,277.019 1610.47,277.045 1610.48,277.071 1610.49,277.097 1610.5,277.124 1610.51,277.15 1610.52,277.176 1610.53,277.202 1610.54,277.228 1610.55,277.255 1610.56,277.281 1610.56,277.307 1610.57,277.333 1610.58,277.359 1610.59,277.385 1610.6,277.412 1610.61,277.438 1610.62,277.464 1610.63,277.49 1610.64,277.516 1610.65,277.542 1610.66,277.568 1610.67,277.595 1610.67,277.621 1610.68,277.647 1610.69,277.673 1610.7,277.699 1610.71,277.725 1610.72,277.752 1610.73,277.778 1610.74,277.804 1610.75,277.83 1610.76,277.856 1610.77,277.882 1610.78,277.908 1610.79,277.934 1610.79,277.961 1610.8,277.987 1610.81,278.013 1610.82,278.039 1610.83,278.065 1610.84,278.091 1610.85,278.117 1610.86,278.143 1610.87,278.17 1610.88,278.196 1610.89,278.222 1610.9,278.248 1610.9,278.274 1610.91,278.3 1610.92,278.326 1610.93,278.352 1610.94,278.379 1610.95,278.405 1610.96,278.431 1610.97,278.457 1610.98,278.483 1610.99,278.509 1611,278.535 1611.01,278.561 1611.01,278.587 1611.02,278.613 1611.03,278.64 1611.04,278.666 1611.05,278.692 1611.06,278.718 1611.07,278.744 1611.08,278.77 1611.09,278.796 1611.1,278.822 1611.11,278.848 1611.12,278.874 1611.13,278.9 1611.13,278.926 1611.14,278.953 1611.15,278.979 1611.16,279.005 1611.17,279.031 1611.18,279.057 1611.19,279.083 1611.2,279.109 1611.21,279.135 1611.22,279.161 1611.23,279.187 1611.24,279.213 1611.24,279.239 1611.25,279.265 1611.26,279.291 1611.27,279.317 1611.28,279.343 1611.29,279.369 1611.3,279.396 1611.31,279.422 1611.32,279.448 1611.33,279.474 1611.34,279.5 1611.35,279.526 1611.35,279.552 1611.36,279.578 1611.37,279.604 1611.38,279.63 1611.39,279.656 1611.4,279.682 1611.41,279.708 1611.42,279.734 1611.43,279.76 1611.44,279.786 1611.45,279.812 1611.46,279.838 1611.47,279.864 1611.47,279.89 1611.48,279.916 1611.49,279.942 1611.5,279.968 1611.51,279.994 1611.52,280.02 1611.53,280.046 1611.54,280.072 1611.55,280.098 1611.56,280.124 1611.57,280.15 1611.58,280.176 1611.58,280.202 1611.59,280.228 1611.6,280.254 1611.61,280.28 1611.62,280.306 1611.63,280.332 1611.64,280.358 1611.65,280.384 1611.66,280.41 1611.67,280.436 1611.68,280.462 1611.69,280.488 1611.69,280.514 1611.7,280.54 1611.71,280.566 1611.72,280.592 1611.73,280.618 1611.74,280.644 1611.75,280.67 1611.76,280.696 1611.77,280.722 1611.78,280.748 1611.79,280.774 1611.8,280.8 1611.81,280.826 1611.81,280.852 1611.82,280.878 1611.83,280.904 1611.84,280.93 1611.85,280.956 1611.86,280.982 1611.87,281.008 1611.88,281.033 1611.89,281.059 1611.9,281.085 1611.91,281.111 1611.92,281.137 1611.92,281.163 1611.93,281.189 1611.94,281.215 1611.95,281.241 1611.96,281.267 1611.97,281.293 1611.98,281.319 1611.99,281.345 1612,281.371 1612.01,281.397 1612.02,281.423 1612.03,281.449 1612.03,281.474 1612.04,281.5 1612.05,281.526 1612.06,281.552 1612.07,281.578 1612.08,281.604 1612.09,281.63 1612.1,281.656 1612.11,281.682 1612.12,281.708 1612.13,281.734 1612.14,281.76 1612.15,281.785 1612.15,281.811 1612.16,281.837 1612.17,281.863 1612.18,281.889 1612.19,281.915 1612.2,281.941 1612.21,281.967 1612.22,281.993 1612.23,282.019 1612.24,282.044 1612.25,282.07 1612.26,282.096 1612.26,282.122 1612.27,282.148 1612.28,282.174 1612.29,282.2 1612.3,282.226 1612.31,282.252 1612.32,282.277 1612.33,282.303 1612.34,282.329 1612.35,282.355 1612.36,282.381 1612.37,282.407 1612.37,282.433 1612.38,282.459 1612.39,282.484 1612.4,282.51 1612.41,282.536 1612.42,282.562 1612.43,282.588 1612.44,282.614 1612.45,282.64 1612.46,282.665 1612.47,282.691 1612.48,282.717 1612.49,282.743 1612.49,282.769 1612.5,282.795 1612.51,282.82 1612.52,282.846 1612.53,282.872 1612.54,282.898 1612.55,282.924 1612.56,282.95 1612.57,282.976 1612.58,283.001 1612.59,283.027 1612.6,283.053 1612.6,283.079 1612.61,283.105 1612.62,283.131 1612.63,283.156 1612.64,283.182 1612.65,283.208 1612.66,283.234 1612.67,283.26 1612.68,283.285 1612.69,283.311 1612.7,283.337 1612.71,283.363 1612.71,283.389 1612.72,283.415 1612.73,283.44 1612.74,283.466 1612.75,283.492 1612.76,283.518 1612.77,283.544 1612.78,283.569 1612.79,283.595 1612.8,283.621 1612.81,283.647 1612.82,283.673 1612.83,283.698 1612.83,283.724 1612.84,283.75 1612.85,283.776 1612.86,283.802 1612.87,283.827 1612.88,283.853 1612.89,283.879 1612.9,283.905 1612.91,283.93 1612.92,283.956 1612.93,283.982 1612.94,284.008 1612.94,284.034 1612.95,284.059 1612.96,284.085 1612.97,284.111 1612.98,284.137 1612.99,284.162 1613,284.188 1613.01,284.214 1613.02,284.24 1613.03,284.265 1613.04,284.291 1613.05,284.317 1613.05,284.343 1613.06,284.368 1613.07,284.394 1613.08,284.42 1613.09,284.446 1613.1,284.471 1613.11,284.497 1613.12,284.523 1613.13,284.549 1613.14,284.574 1613.15,284.6 1613.16,284.626 1613.17,284.652 1613.17,284.677 1613.18,284.703 1613.19,284.729 1613.2,284.755 1613.21,284.78 1613.22,284.806 1613.23,284.832 1613.24,284.858 1613.25,284.883 1613.26,284.909 1613.27,284.935 1613.28,284.96 1613.28,284.986 1613.29,285.012 1613.3,285.038 1613.31,285.063 1613.32,285.089 1613.33,285.115 1613.34,285.14 1613.35,285.166 1613.36,285.192 1613.37,285.217 1613.38,285.243 1613.39,285.269 1613.39,285.295 1613.4,285.32 1613.41,285.346 1613.42,285.372 1613.43,285.397 1613.44,285.423 1613.45,285.449 1613.46,285.474 1613.47,285.5 1613.48,285.526 1613.49,285.551 1613.5,285.577 1613.51,285.603 1613.51,285.629 1613.52,285.654 1613.53,285.68 1613.54,285.706 1613.55,285.731 1613.56,285.757 1613.57,285.783 1613.58,285.808 1613.59,285.834 1613.6,285.86 1613.61,285.885 1613.62,285.911 1613.62,285.937 1613.63,285.962 1613.64,285.988 1613.65,286.014 1613.66,286.039 1613.67,286.065 1613.68,286.09 1613.69,286.116 1613.7,286.142 1613.71,286.167 1613.72,286.193 1613.73,286.219 1613.73,286.244 1613.74,286.27 1613.75,286.296 1613.76,286.321 1613.77,286.347 1613.78,286.373 1613.79,286.398 1613.8,286.424 1613.81,286.449 1613.82,286.475 1613.83,286.501 1613.84,286.526 1613.85,286.552 1613.85,286.578 1613.86,286.603 1613.87,286.629 1613.88,286.654 1613.89,286.68 1613.9,286.706 1613.91,286.731 1613.92,286.757 1613.93,286.782 1613.94,286.808 1613.95,286.834 1613.96,286.859 1613.96,286.885 1613.97,286.911 1613.98,286.936 1613.99,286.962 1614,286.987 1614.01,287.013 1614.02,287.039 1614.03,287.064 1614.04,287.09 1614.05,287.115 1614.06,287.141 1614.07,287.166 1614.07,287.192 1614.08,287.218 1614.09,287.243 1614.1,287.269 1614.11,287.294 1614.12,287.32 1614.13,287.346 1614.14,287.371 1614.15,287.397 1614.16,287.422 1614.17,287.448 1614.18,287.473 1614.19,287.499 1614.19,287.524 1614.2,287.55 1614.21,287.576 1614.22,287.601 1614.23,287.627 1614.24,287.652 1614.25,287.678 1614.26,287.703 1614.27,287.729 1614.28,287.755 1614.29,287.78 1614.3,287.806 1614.3,287.831 1614.31,287.857 1614.32,287.882 1614.33,287.908 1614.34,287.933 1614.35,287.959 1614.36,287.984 1614.37,288.01 1614.38,288.035 1614.39,288.061 1614.4,288.087 1614.41,288.112 1614.41,288.138 1614.42,288.163 1614.43,288.189 1614.44,288.214 1614.45,288.24 1614.46,288.265 1614.47,288.291 1614.48,288.316 1614.49,288.342 1614.5,288.367 1614.51,288.393 1614.52,288.418 1614.53,288.444 1614.53,288.469 1614.54,288.495 1614.55,288.52 1614.56,288.546 1614.57,288.571 1614.58,288.597 1614.59,288.622 1614.6,288.648 1614.61,288.673 1614.62,288.699 1614.63,288.724 1614.64,288.75 1614.64,288.775 1614.65,288.801 1614.66,288.826 1614.67,288.852 1614.68,288.877 1614.69,288.903 1614.7,288.928 1614.71,288.954 1614.72,288.979 1614.73,289.005 1614.74,289.03 1614.75,289.056 1614.75,289.081 1614.76,289.106 1614.77,289.132 1614.78,289.157 1614.79,289.183 1614.8,289.208 1614.81,289.234 1614.82,289.259 1614.83,289.285 1614.84,289.31 1614.85,289.336 1614.86,289.361 1614.87,289.387 1614.87,289.412 1614.88,289.437 1614.89,289.463 1614.9,289.488 1614.91,289.514 1614.92,289.539 1614.93,289.565 1614.94,289.59 1614.95,289.616 1614.96,289.641 1614.97,289.666 1614.98,289.692 1614.98,289.717 1614.99,289.743 1615,289.768 1615.01,289.794 1615.02,289.819 1615.03,289.844 1615.04,289.87 1615.05,289.895 1615.06,289.921 1615.07,289.946 1615.08,289.972 1615.09,289.997 1615.09,290.022 1615.1,290.048 1615.11,290.073 1615.12,290.099 1615.13,290.124 1615.14,290.149 1615.15,290.175 1615.16,290.2 1615.17,290.226 1615.18,290.251 1615.19,290.276 1615.2,290.302 1615.21,290.327 1615.21,290.353 1615.22,290.378 1615.23,290.403 1615.24,290.429 1615.25,290.454 1615.26,290.48 1615.27,290.505 1615.28,290.53 1615.29,290.556 1615.3,290.581 1615.31,290.606 1615.32,290.632 1615.32,290.657 1615.33,290.683 1615.34,290.708 1615.35,290.733 1615.36,290.759 1615.37,290.784 1615.38,290.809 1615.39,290.835 1615.4,290.86 1615.41,290.885 1615.42,290.911 1615.43,290.936 1615.43,290.962 1615.44,290.987 1615.45,291.012 1615.46,291.038 1615.47,291.063 1615.48,291.088 1615.49,291.114 1615.5,291.139 1615.51,291.164 1615.52,291.19 1615.53,291.215 1615.54,291.24 1615.55,291.266 1615.55,291.291 1615.56,291.316 1615.57,291.342 1615.58,291.367 1615.59,291.392 1615.6,291.418 1615.61,291.443 1615.62,291.468 1615.63,291.494 1615.64,291.519 1615.65,291.544 1615.66,291.57 1615.66,291.595 1615.67,291.62 1615.68,291.646 1615.69,291.671 1615.7,291.696 1615.71,291.721 1615.72,291.747 1615.73,291.772 1615.74,291.797 1615.75,291.823 1615.76,291.848 1615.77,291.873 1615.77,291.899 1615.78,291.924 1615.79,291.949 1615.8,291.974 1615.81,292 1615.82,292.025 1615.83,292.05 1615.84,292.076 1615.85,292.101 1615.86,292.126 1615.87,292.152 1615.88,292.177 1615.89,292.202 1615.89,292.227 1615.9,292.253 1615.91,292.278 1615.92,292.303 1615.93,292.328 1615.94,292.354 1615.95,292.379 1615.96,292.404 1615.97,292.43 1615.98,292.455 1615.99,292.48 1616,292.505 1616,292.531 1616.01,292.556 1616.02,292.581 1616.03,292.606 1616.04,292.632 1616.05,292.657 1616.06,292.682 1616.07,292.707 1616.08,292.733 1616.09,292.758 1616.1,292.783 1616.11,292.808 1616.11,292.834 1616.12,292.859 1616.13,292.884 1616.14,292.909 1616.15,292.935 1616.16,292.96 1616.17,292.985 1616.18,293.01 1616.19,293.035 1616.2,293.061 1616.21,293.086 1616.22,293.111 1616.23,293.136 1616.23,293.162 1616.24,293.187 1616.25,293.212 1616.26,293.237 1616.27,293.262 1616.28,293.288 1616.29,293.313 1616.3,293.338 1616.31,293.363 1616.32,293.388 1616.33,293.414 1616.34,293.439 1616.34,293.464 1616.35,293.489 1616.36,293.514 1616.37,293.54 1616.38,293.565 1616.39,293.59 1616.4,293.615 1616.41,293.64 1616.42,293.666 1616.43,293.691 1616.44,293.716 1616.45,293.741 1616.45,293.766 1616.46,293.792 1616.47,293.817 1616.48,293.842 1616.49,293.867 1616.5,293.892 1616.51,293.917 1616.52,293.943 1616.53,293.968 1616.54,293.993 1616.55,294.018 1616.56,294.043 1616.57,294.068 1616.57,294.094 1616.58,294.119 1616.59,294.144 1616.6,294.169 1616.61,294.194 1616.62,294.219 1616.63,294.245 1616.64,294.27 1616.65,294.295 1616.66,294.32 1616.67,294.345 1616.68,294.37 1616.68,294.395 1616.69,294.421 1616.7,294.446 1616.71,294.471 1616.72,294.496 1616.73,294.521 1616.74,294.546 1616.75,294.571 1616.76,294.597 1616.77,294.622 1616.78,294.647 1616.79,294.672 1616.79,294.697 1616.8,294.722 1616.81,294.747 1616.82,294.772 1616.83,294.798 1616.84,294.823 1616.85,294.848 1616.86,294.873 1616.87,294.898 1616.88,294.923 1616.89,294.948 1616.9,294.973 1616.91,294.998 1616.91,295.024 1616.92,295.049 1616.93,295.074 1616.94,295.099 1616.95,295.124 1616.96,295.149 1616.97,295.174 1616.98,295.199 1616.99,295.224 1617,295.249 1617.01,295.275 1617.02,295.3 1617.02,295.325 1617.03,295.35 1617.04,295.375 1617.05,295.4 1617.06,295.425 1617.07,295.45 1617.08,295.475 1617.09,295.5 1617.1,295.525 1617.11,295.55 1617.12,295.576 1617.13,295.601 1617.13,295.626 1617.14,295.651 1617.15,295.676 1617.16,295.701 1617.17,295.726 1617.18,295.751 1617.19,295.776 1617.2,295.801 1617.21,295.826 1617.22,295.851 1617.23,295.876 1617.24,295.901 1617.25,295.926 1617.25,295.951 1617.26,295.976 1617.27,296.002 1617.28,296.027 1617.29,296.052 1617.3,296.077 1617.31,296.102 1617.32,296.127 1617.33,296.152 1617.34,296.177 1617.35,296.202 1617.36,296.227 1617.36,296.252 1617.37,296.277 1617.38,296.302 1617.39,296.327 1617.4,296.352 1617.41,296.377 1617.42,296.402 1617.43,296.427 1617.44,296.452 1617.45,296.477 1617.46,296.502 1617.47,296.527 1617.47,296.552 1617.48,296.577 1617.49,296.602 1617.5,296.627 1617.51,296.652 1617.52,296.677 1617.53,296.702 1617.54,296.727 1617.55,296.752 1617.56,296.777 1617.57,296.802 1617.58,296.827 1617.59,296.852 1617.59,296.877 1617.6,296.902 1617.61,296.927 1617.62,296.952 1617.63,296.977 1617.64,297.002 1617.65,297.027 1617.66,297.052 1617.67,297.077 1617.68,297.102 1617.69,297.127 1617.7,297.152 1617.7,297.177 1617.71,297.202 1617.72,297.227 1617.73,297.252 1617.74,297.277 1617.75,297.302 1617.76,297.327 1617.77,297.352 1617.78,297.377 1617.79,297.402 1617.8,297.427 1617.81,297.451 1617.81,297.476 1617.82,297.501 1617.83,297.526 1617.84,297.551 1617.85,297.576 1617.86,297.601 1617.87,297.626 1617.88,297.651 1617.89,297.676 1617.9,297.701 1617.91,297.726 1617.92,297.751 1617.93,297.776 1617.93,297.801 1617.94,297.826 1617.95,297.851 1617.96,297.875 1617.97,297.9 1617.98,297.925 1617.99,297.95 1618,297.975 1618.01,298 1618.02,298.025 1618.03,298.05 1618.04,298.075 1618.04,298.1 1618.05,298.125 1618.06,298.15 1618.07,298.174 1618.08,298.199 1618.09,298.224 1618.1,298.249 1618.11,298.274 1618.12,298.299 1618.13,298.324 1618.14,298.349 1618.15,298.374 1618.15,298.399 1618.16,298.424 1618.17,298.448 1618.18,298.473 1618.19,298.498 1618.2,298.523 1618.21,298.548 1618.22,298.573 1618.23,298.598 1618.24,298.623 1618.25,298.647 1618.26,298.672 1618.27,298.697 1618.27,298.722 1618.28,298.747 1618.29,298.772 1618.3,298.797 1618.31,298.822 1618.32,298.846 1618.33,298.871 1618.34,298.896 1618.35,298.921 1618.36,298.946 1618.37,298.971 1618.38,298.996 1618.38,299.021 1618.39,299.045 1618.4,299.07 1618.41,299.095 1618.42,299.12 1618.43,299.145 1618.44,299.17 1618.45,299.194 1618.46,299.219 1618.47,299.244 1618.48,299.269 1618.49,299.294 1618.49,299.319 1618.5,299.344 1618.51,299.368 1618.52,299.393 1618.53,299.418 1618.54,299.443 1618.55,299.468 1618.56,299.492 1618.57,299.517 1618.58,299.542 1618.59,299.567 1618.6,299.592 1618.61,299.617 1618.61,299.641 1618.62,299.666 1618.63,299.691 1618.64,299.716 1618.65,299.741 1618.66,299.765 1618.67,299.79 1618.68,299.815 1618.69,299.84 1618.7,299.865 1618.71,299.89 1618.72,299.914 1618.72,299.939 1618.73,299.964 1618.74,299.989 1618.75,300.014 1618.76,300.038 1618.77,300.063 1618.78,300.088 1618.79,300.113 1618.8,300.137 1618.81,300.162 1618.82,300.187 1618.83,300.212 1618.83,300.237 1618.84,300.261 1618.85,300.286 1618.86,300.311 1618.87,300.336 1618.88,300.36 1618.89,300.385 1618.9,300.41 1618.91,300.435 1618.92,300.46 1618.93,300.484 1618.94,300.509 1618.95,300.534 1618.95,300.559 1618.96,300.583 1618.97,300.608 1618.98,300.633 1618.99,300.658 1619,300.682 1619.01,300.707 1619.02,300.732 1619.03,300.757 1619.04,300.781 1619.05,300.806 1619.06,300.831 1619.06,300.856 1619.07,300.88 1619.08,300.905 1619.09,300.93 1619.1,300.955 1619.11,300.979 1619.12,301.004 1619.13,301.029 1619.14,301.053 1619.15,301.078 1619.16,301.103 1619.17,301.128 1619.17,301.152 1619.18,301.177 1619.19,301.202 1619.2,301.227 1619.21,301.251 1619.22,301.276 1619.23,301.301 1619.24,301.325 1619.25,301.35 1619.26,301.375 1619.27,301.4 1619.28,301.424 1619.29,301.449 1619.29,301.474 1619.3,301.498 1619.31,301.523 1619.32,301.548 1619.33,301.572 1619.34,301.597 1619.35,301.622 1619.36,301.647 1619.37,301.671 1619.38,301.696 1619.39,301.721 1619.4,301.745 1619.4,301.77 1619.41,301.795 1619.42,301.819 1619.43,301.844 1619.44,301.869 1619.45,301.893 1619.46,301.918 1619.47,301.943 1619.48,301.967 1619.49,301.992 1619.5,302.017 1619.51,302.041 1619.51,302.066 1619.52,302.091 1619.53,302.115 1619.54,302.14 1619.55,302.165 1619.56,302.189 1619.57,302.214 1619.58,302.239 1619.59,302.263 1619.6,302.288 1619.61,302.313 1619.62,302.337 1619.63,302.362 1619.63,302.387 1619.64,302.411 1619.65,302.436 1619.66,302.46 1619.67,302.485 1619.68,302.51 1619.69,302.534 1619.7,302.559 1619.71,302.584 1619.72,302.608 1619.73,302.633 1619.74,302.658 1619.74,302.682 1619.75,302.707 1619.76,302.731 1619.77,302.756 1619.78,302.781 1619.79,302.805 1619.8,302.83 1619.81,302.855 1619.82,302.879 1619.83,302.904 1619.84,302.928 1619.85,302.953 1619.85,302.978 1619.86,303.002 1619.87,303.027 1619.88,303.051 1619.89,303.076 1619.9,303.101 1619.91,303.125 1619.92,303.15 1619.93,303.174 1619.94,303.199 1619.95,303.224 1619.96,303.248 1619.97,303.273 1619.97,303.297 1619.98,303.322 1619.99,303.346 1620,303.371 1620.01,303.396 1620.02,303.42 1620.03,303.445 1620.04,303.469 1620.05,303.494 1620.06,303.519 1620.07,303.543 1620.08,303.568 1620.08,303.592 1620.09,303.617 1620.1,303.641 1620.11,303.666 1620.12,303.691 1620.13,303.715 1620.14,303.74 1620.15,303.764 1620.16,303.789 1620.17,303.813 1620.18,303.838 1620.19,303.862 1620.19,303.887 1620.2,303.912 1620.21,303.936 1620.22,303.961 1620.23,303.985 1620.24,304.01 1620.25,304.034 1620.26,304.059 1620.27,304.083 1620.28,304.108 1620.29,304.132 1620.3,304.157 1620.31,304.181 1620.31,304.206 1620.32,304.231 1620.33,304.255 1620.34,304.28 1620.35,304.304 1620.36,304.329 1620.37,304.353 1620.38,304.378 1620.39,304.402 1620.4,304.427 1620.41,304.451 1620.42,304.476 1620.42,304.5 1620.43,304.525 1620.44,304.549 1620.45,304.574 1620.46,304.598 1620.47,304.623 1620.48,304.647 1620.49,304.672 1620.5,304.696 1620.51,304.721 1620.52,304.745 1620.53,304.77 1620.53,304.794 1620.54,304.819 1620.55,304.843 1620.56,304.868 1620.57,304.892 1620.58,304.917 1620.59,304.941 1620.6,304.966 1620.61,304.99 1620.62,305.015 1620.63,305.039 1620.64,305.064 1620.65,305.088 1620.65,305.112 1620.66,305.137 1620.67,305.161 1620.68,305.186 1620.69,305.21 1620.7,305.235 1620.71,305.259 1620.72,305.284 1620.73,305.308 1620.74,305.333 1620.75,305.357 1620.76,305.382 1620.76,305.406 1620.77,305.43 1620.78,305.455 1620.79,305.479 1620.8,305.504 1620.81,305.528 1620.82,305.553 1620.83,305.577 1620.84,305.602 1620.85,305.626 1620.86,305.65 1620.87,305.675 1620.87,305.699 1620.88,305.724 1620.89,305.748 1620.9,305.773 1620.91,305.797 1620.92,305.822 1620.93,305.846 1620.94,305.87 1620.95,305.895 1620.96,305.919 1620.97,305.944 1620.98,305.968 1620.99,305.992 1620.99,306.017 1621,306.041 1621.01,306.066 1621.02,306.09 1621.03,306.115 1621.04,306.139 1621.05,306.163 1621.06,306.188 1621.07,306.212 1621.08,306.237 1621.09,306.261 1621.1,306.285 1621.1,306.31 1621.11,306.334 1621.12,306.359 1621.13,306.383 1621.14,306.407 1621.15,306.432 1621.16,306.456 1621.17,306.48 1621.18,306.505 1621.19,306.529 1621.2,306.554 1621.21,306.578 1621.21,306.602 1621.22,306.627 1621.23,306.651 1621.24,306.675 1621.25,306.7 1621.26,306.724 1621.27,306.749 1621.28,306.773 1621.29,306.797 1621.3,306.822 1621.31,306.846 1621.32,306.87 1621.33,306.895 1621.33,306.919 1621.34,306.943 1621.35,306.968 1621.36,306.992 1621.37,307.017 1621.38,307.041 1621.39,307.065 1621.4,307.09 1621.41,307.114 1621.42,307.138 1621.43,307.163 1621.44,307.187 1621.44,307.211 1621.45,307.236 1621.46,307.26 1621.47,307.284 1621.48,307.309 1621.49,307.333 1621.5,307.357 1621.51,307.382 1621.52,307.406 1621.53,307.43 1621.54,307.455 1621.55,307.479 1621.55,307.503 1621.56,307.528 1621.57,307.552 1621.58,307.576 1621.59,307.6 1621.6,307.625 1621.61,307.649 1621.62,307.673 1621.63,307.698 1621.64,307.722 1621.65,307.746 1621.66,307.771 1621.67,307.795 1621.67,307.819 1621.68,307.844 1621.69,307.868 1621.7,307.892 1621.71,307.916 1621.72,307.941 1621.73,307.965 1621.74,307.989 1621.75,308.014 1621.76,308.038 1621.77,308.062 1621.78,308.086 1621.78,308.111 1621.79,308.135 1621.8,308.159 1621.81,308.184 1621.82,308.208 1621.83,308.232 1621.84,308.256 1621.85,308.281 1621.86,308.305 1621.87,308.329 1621.88,308.353 1621.89,308.378 1621.89,308.402 1621.9,308.426 1621.91,308.45 1621.92,308.475 1621.93,308.499 1621.94,308.523 1621.95,308.548 1621.96,308.572 1621.97,308.596 1621.98,308.62 1621.99,308.645 1622,308.669 1622.01,308.693 1622.01,308.717 1622.02,308.741 1622.03,308.766 1622.04,308.79 1622.05,308.814 1622.06,308.838 1622.07,308.863 1622.08,308.887 1622.09,308.911 1622.1,308.935 1622.11,308.96 1622.12,308.984 1622.12,309.008 1622.13,309.032 1622.14,309.056 1622.15,309.081 1622.16,309.105 1622.17,309.129 1622.18,309.153 1622.19,309.178 1622.2,309.202 1622.21,309.226 1622.22,309.25 1622.23,309.274 1622.23,309.299 1622.24,309.323 1622.25,309.347 1622.26,309.371 1622.27,309.395 1622.28,309.42 1622.29,309.444 1622.3,309.468 1622.31,309.492 1622.32,309.516 1622.33,309.541 1622.34,309.565 1622.35,309.589 1622.35,309.613 1622.36,309.637 1622.37,309.661 1622.38,309.686 1622.39,309.71 1622.4,309.734 1622.41,309.758 1622.42,309.782 1622.43,309.807 1622.44,309.831 1622.45,309.855 1622.46,309.879 1622.46,309.903 1622.47,309.927 1622.48,309.952 1622.49,309.976 1622.5,310 1622.51,310.024 1622.52,310.048 1622.53,310.072 1622.54,310.096 1622.55,310.121 1622.56,310.145 1622.57,310.169 1622.57,310.193 1622.58,310.217 1622.59,310.241 1622.6,310.266 1622.61,310.29 1622.62,310.314 1622.63,310.338 1622.64,310.362 1622.65,310.386 1622.66,310.41 1622.67,310.434 1622.68,310.459 1622.69,310.483 1622.69,310.507 1622.7,310.531 1622.71,310.555 1622.72,310.579 1622.73,310.603 1622.74,310.627 1622.75,310.652 1622.76,310.676 1622.77,310.7 1622.78,310.724 1622.79,310.748 1622.8,310.772 1622.8,310.796 1622.81,310.82 1622.82,310.844 1622.83,310.869 1622.84,310.893 1622.85,310.917 1622.86,310.941 1622.87,310.965 1622.88,310.989 1622.89,311.013 1622.9,311.037 1622.91,311.061 1622.91,311.085 1622.92,311.11 1622.93,311.134 1622.94,311.158 1622.95,311.182 1622.96,311.206 1622.97,311.23 1622.98,311.254 1622.99,311.278 1623,311.302 1623.01,311.326 1623.02,311.35 1623.03,311.374 1623.03,311.398 1623.04,311.423 1623.05,311.447 1623.06,311.471 1623.07,311.495 1623.08,311.519 1623.09,311.543 1623.1,311.567 1623.11,311.591 1623.12,311.615 1623.13,311.639 1623.14,311.663 1623.14,311.687 1623.15,311.711 1623.16,311.735 1623.17,311.759 1623.18,311.783 1623.19,311.807 1623.2,311.831 1623.21,311.855 1623.22,311.88 1623.23,311.904 1623.24,311.928 1623.25,311.952 1623.25,311.976 1623.26,312 1623.27,312.024 1623.28,312.048 1623.29,312.072 1623.3,312.096 1623.31,312.12 1623.32,312.144 1623.33,312.168 1623.34,312.192 1623.35,312.216 1623.36,312.24 1623.37,312.264 1623.37,312.288 1623.38,312.312 1623.39,312.336 1623.4,312.36 1623.41,312.384 1623.42,312.408 1623.43,312.432 1623.44,312.456 1623.45,312.48 1623.46,312.504 1623.47,312.528 1623.48,312.552 1623.48,312.576 1623.49,312.6 1623.5,312.624 1623.51,312.648 1623.52,312.672 1623.53,312.696 1623.54,312.72 1623.55,312.744 1623.56,312.768 1623.57,312.792 1623.58,312.816 1623.59,312.84 1623.59,312.864 1623.6,312.888 1623.61,312.912 1623.62,312.936 1623.63,312.96 1623.64,312.984 1623.65,313.008 1623.66,313.032 1623.67,313.056 1623.68,313.079 1623.69,313.103 1623.7,313.127 1623.71,313.151 1623.71,313.175 1623.72,313.199 1623.73,313.223 1623.74,313.247 1623.75,313.271 1623.76,313.295 1623.77,313.319 1623.78,313.343 1623.79,313.367 1623.8,313.391 1623.81,313.415 1623.82,313.439 1623.82,313.463 1623.83,313.487 1623.84,313.511 1623.85,313.534 1623.86,313.558 1623.87,313.582 1623.88,313.606 1623.89,313.63 1623.9,313.654 1623.91,313.678 1623.92,313.702 1623.93,313.726 1623.93,313.75 1623.94,313.774 1623.95,313.798 1623.96,313.821 1623.97,313.845 1623.98,313.869 1623.99,313.893 1624,313.917 1624.01,313.941 1624.02,313.965 1624.03,313.989 1624.04,314.013 1624.05,314.037 1624.05,314.061 1624.06,314.084 1624.07,314.108 1624.08,314.132 1624.09,314.156 1624.1,314.18 1624.11,314.204 1624.12,314.228 1624.13,314.252 1624.14,314.276 1624.15,314.299 1624.16,314.323 1624.16,314.347 1624.17,314.371 1624.18,314.395 1624.19,314.419 1624.2,314.443 1624.21,314.467 1624.22,314.49 1624.23,314.514 1624.24,314.538 1624.25,314.562 1624.26,314.586 1624.27,314.61 1624.27,314.634 1624.28,314.657 1624.29,314.681 1624.3,314.705 1624.31,314.729 1624.32,314.753 1624.33,314.777 1624.34,314.801 1624.35,314.824 1624.36,314.848 1624.37,314.872 1624.38,314.896 1624.39,314.92 1624.39,314.944 1624.4,314.967 1624.41,314.991 1624.42,315.015 1624.43,315.039 1624.44,315.063 1624.45,315.087 1624.46,315.11 1624.47,315.134 1624.48,315.158 1624.49,315.182 1624.5,315.206 1624.5,315.23 1624.51,315.253 1624.52,315.277 1624.53,315.301 1624.54,315.325 1624.55,315.349 1624.56,315.373 1624.57,315.396 1624.58,315.42 1624.59,315.444 1624.6,315.468 1624.61,315.492 1624.61,315.515 1624.62,315.539 1624.63,315.563 1624.64,315.587 1624.65,315.611 1624.66,315.634 1624.67,315.658 1624.68,315.682 1624.69,315.706 1624.7,315.73 1624.71,315.753 1624.72,315.777 1624.73,315.801 1624.73,315.825 1624.74,315.848 1624.75,315.872 1624.76,315.896 1624.77,315.92 1624.78,315.944 1624.79,315.967 1624.8,315.991 1624.81,316.015 1624.82,316.039 1624.83,316.062 1624.84,316.086 1624.84,316.11 1624.85,316.134 1624.86,316.157 1624.87,316.181 1624.88,316.205 1624.89,316.229 1624.9,316.252 1624.91,316.276 1624.92,316.3 1624.93,316.324 1624.94,316.347 1624.95,316.371 1624.95,316.395 1624.96,316.419 1624.97,316.442 1624.98,316.466 1624.99,316.49 1625,316.514 1625.01,316.537 1625.02,316.561 1625.03,316.585 1625.04,316.609 1625.05,316.632 1625.06,316.656 1625.07,316.68 1625.07,316.704 1625.08,316.727 1625.09,316.751 1625.1,316.775 1625.11,316.798 1625.12,316.822 1625.13,316.846 1625.14,316.87 1625.15,316.893 1625.16,316.917 1625.17,316.941 1625.18,316.964 1625.18,316.988 1625.19,317.012 1625.2,317.036 1625.21,317.059 1625.22,317.083 1625.23,317.107 1625.24,317.13 1625.25,317.154 1625.26,317.178 1625.27,317.201 1625.28,317.225 1625.29,317.249 1625.29,317.272 1625.3,317.296 1625.31,317.32 1625.32,317.344 1625.33,317.367 1625.34,317.391 1625.35,317.415 1625.36,317.438 1625.37,317.462 1625.38,317.486 1625.39,317.509 1625.4,317.533 1625.41,317.557 1625.41,317.58 1625.42,317.604 1625.43,317.628 1625.44,317.651 1625.45,317.675 1625.46,317.699 1625.47,317.722 1625.48,317.746 1625.49,317.77 1625.5,317.793 1625.51,317.817 1625.52,317.841 1625.52,317.864 1625.53,317.888 1625.54,317.911 1625.55,317.935 1625.56,317.959 1625.57,317.982 1625.58,318.006 1625.59,318.03 1625.6,318.053 1625.61,318.077 1625.62,318.101 1625.63,318.124 1625.63,318.148 1625.64,318.172 1625.65,318.195 1625.66,318.219 1625.67,318.242 1625.68,318.266 1625.69,318.29 1625.7,318.313 1625.71,318.337 1625.72,318.36 1625.73,318.384 1625.74,318.408 1625.75,318.431 1625.75,318.455 1625.76,318.479 1625.77,318.502 1625.78,318.526 1625.79,318.549 1625.8,318.573 1625.81,318.597 1625.82,318.62 1625.83,318.644 1625.84,318.667 1625.85,318.691 1625.86,318.715 1625.86,318.738 1625.87,318.762 1625.88,318.785 1625.89,318.809 1625.9,318.833 1625.91,318.856 1625.92,318.88 1625.93,318.903 1625.94,318.927 1625.95,318.95 1625.96,318.974 1625.97,318.998 1625.97,319.021 1625.98,319.045 1625.99,319.068 1626,319.092 1626.01,319.115 1626.02,319.139 1626.03,319.163 1626.04,319.186 1626.05,319.21 1626.06,319.233 1626.07,319.257 1626.08,319.28 1626.09,319.304 1626.09,319.327 1626.1,319.351 1626.11,319.375 1626.12,319.398 1626.13,319.422 1626.14,319.445 1626.15,319.469 1626.16,319.492 1626.17,319.516 1626.18,319.539 1626.19,319.563 1626.2,319.586 1626.2,319.61 1626.21,319.634 1626.22,319.657 1626.23,319.681 1626.24,319.704 1626.25,319.728 1626.26,319.751 1626.27,319.775 1626.28,319.798 1626.29,319.822 1626.3,319.845 1626.31,319.869 1626.31,319.892 1626.32,319.916 1626.33,319.939 1626.34,319.963 1626.35,319.986 1626.36,320.01 1626.37,320.033 1626.38,320.057 1626.39,320.08 1626.4,320.104 1626.41,320.127 1626.42,320.151 1626.43,320.174 1626.43,320.198 1626.44,320.221 1626.45,320.245 1626.46,320.268 1626.47,320.292 1626.48,320.315 1626.49,320.339 1626.5,320.362 1626.51,320.386 1626.52,320.409 1626.53,320.433 1626.54,320.456 1626.54,320.48 1626.55,320.503 1626.56,320.527 1626.57,320.55 1626.58,320.574 1626.59,320.597 1626.6,320.621 1626.61,320.644 1626.62,320.668 1626.63,320.691 1626.64,320.714 1626.65,320.738 1626.65,320.761 1626.66,320.785 1626.67,320.808 1626.68,320.832 1626.69,320.855 1626.7,320.879 1626.71,320.902 1626.72,320.926 1626.73,320.949 1626.74,320.972 1626.75,320.996 1626.76,321.019 1626.77,321.043 1626.77,321.066 1626.78,321.09 1626.79,321.113 1626.8,321.137 1626.81,321.16 1626.82,321.183 1626.83,321.207 1626.84,321.23 1626.85,321.254 1626.86,321.277 1626.87,321.301 1626.88,321.324 1626.88,321.347 1626.89,321.371 1626.9,321.394 1626.91,321.418 1626.92,321.441 1626.93,321.464 1626.94,321.488 1626.95,321.511 1626.96,321.535 1626.97,321.558 1626.98,321.582 1626.99,321.605 1626.99,321.628 1627,321.652 1627.01,321.675 1627.02,321.699 1627.03,321.722 1627.04,321.745 1627.05,321.769 1627.06,321.792 1627.07,321.816 1627.08,321.839 1627.09,321.862 1627.1,321.886 1627.11,321.909 1627.11,321.932 1627.12,321.956 1627.13,321.979 1627.14,322.003 1627.15,322.026 1627.16,322.049 1627.17,322.073 1627.18,322.096 1627.19,322.119 1627.2,322.143 1627.21,322.166 1627.22,322.19 1627.22,322.213 1627.23,322.236 1627.24,322.26 1627.25,322.283 1627.26,322.306 1627.27,322.33 1627.28,322.353 1627.29,322.376 1627.3,322.4 1627.31,322.423 1627.32,322.447 1627.33,322.47 1627.33,322.493 1627.34,322.517 1627.35,322.54 1627.36,322.563 1627.37,322.587 1627.38,322.61 1627.39,322.633 1627.4,322.657 1627.41,322.68 1627.42,322.703 1627.43,322.727 1627.44,322.75 1627.45,322.773 1627.45,322.797 1627.46,322.82 1627.47,322.843 1627.48,322.867 1627.49,322.89 1627.5,322.913 1627.51,322.937 1627.52,322.96 1627.53,322.983 1627.54,323.006 1627.55,323.03 1627.56,323.053 1627.56,323.076 1627.57,323.1 1627.58,323.123 1627.59,323.146 1627.6,323.17 1627.61,323.193 1627.62,323.216 1627.63,323.239 1627.64,323.263 1627.65,323.286 1627.66,323.309 1627.67,323.333 1627.67,323.356 1627.68,323.379 1627.69,323.403 1627.7,323.426 1627.71,323.449 1627.72,323.472 1627.73,323.496 1627.74,323.519 1627.75,323.542 1627.76,323.565 1627.77,323.589 1627.78,323.612 1627.79,323.635 1627.79,323.659 1627.8,323.682 1627.81,323.705 1627.82,323.728 1627.83,323.752 1627.84,323.775 1627.85,323.798 1627.86,323.821 1627.87,323.845 1627.88,323.868 1627.89,323.891 1627.9,323.914 1627.9,323.938 1627.91,323.961 1627.92,323.984 1627.93,324.007 1627.94,324.031 1627.95,324.054 1627.96,324.077 1627.97,324.1 1627.98,324.124 1627.99,324.147 1628,324.17 1628.01,324.193 1628.01,324.217 1628.02,324.24 1628.03,324.263 1628.04,324.286 1628.05,324.31 1628.06,324.333 1628.07,324.356 1628.08,324.379 1628.09,324.402 1628.1,324.426 1628.11,324.449 1628.12,324.472 1628.13,324.495 1628.13,324.519 1628.14,324.542 1628.15,324.565 1628.16,324.588 1628.17,324.611 1628.18,324.635 1628.19,324.658 1628.2,324.681 1628.21,324.704 1628.22,324.727 1628.23,324.751 1628.24,324.774 1628.24,324.797 1628.25,324.82 1628.26,324.843 1628.27,324.867 1628.28,324.89 1628.29,324.913 1628.3,324.936 1628.31,324.959 1628.32,324.982 1628.33,325.006 1628.34,325.029 1628.35,325.052 1628.35,325.075 1628.36,325.098 1628.37,325.122 1628.38,325.145 1628.39,325.168 1628.4,325.191 1628.41,325.214 1628.42,325.237 1628.43,325.261 1628.44,325.284 1628.45,325.307 1628.46,325.33 1628.47,325.353 1628.47,325.376 1628.48,325.399 1628.49,325.423 1628.5,325.446 1628.51,325.469 1628.52,325.492 1628.53,325.515 1628.54,325.538 1628.55,325.562 1628.56,325.585 1628.57,325.608 1628.58,325.631 1628.58,325.654 1628.59,325.677 1628.6,325.7 1628.61,325.723 1628.62,325.747 1628.63,325.77 1628.64,325.793 1628.65,325.816 1628.66,325.839 1628.67,325.862 1628.68,325.885 1628.69,325.909 1628.69,325.932 1628.7,325.955 1628.71,325.978 1628.72,326.001 1628.73,326.024 1628.74,326.047 1628.75,326.07 1628.76,326.093 1628.77,326.117 1628.78,326.14 1628.79,326.163 1628.8,326.186 1628.81,326.209 1628.81,326.232 1628.82,326.255 1628.83,326.278 1628.84,326.301 1628.85,326.324 1628.86,326.348 1628.87,326.371 1628.88,326.394 1628.89,326.417 1628.9,326.44 1628.91,326.463 1628.92,326.486 1628.92,326.509 1628.93,326.532 1628.94,326.555 1628.95,326.578 1628.96,326.601 1628.97,326.625 1628.98,326.648 1628.99,326.671 1629,326.694 1629.01,326.717 1629.02,326.74 1629.03,326.763 1629.03,326.786 1629.04,326.809 1629.05,326.832 1629.06,326.855 1629.07,326.878 1629.08,326.901 1629.09,326.924 1629.1,326.947 1629.11,326.97 1629.12,326.994 1629.13,327.017 1629.14,327.04 1629.15,327.063 1629.15,327.086 1629.16,327.109 1629.17,327.132 1629.18,327.155 1629.19,327.178 1629.2,327.201 1629.21,327.224 1629.22,327.247 1629.23,327.27 1629.24,327.293 1629.25,327.316 1629.26,327.339 1629.26,327.362 1629.27,327.385 1629.28,327.408 1629.29,327.431 1629.3,327.454 1629.31,327.477 1629.32,327.5 1629.33,327.523 1629.34,327.546 1629.35,327.569 1629.36,327.592 1629.37,327.615 1629.37,327.638 1629.38,327.661 1629.39,327.684 1629.4,327.707 1629.41,327.73 1629.42,327.753 1629.43,327.776 1629.44,327.799 1629.45,327.822 1629.46,327.845 1629.47,327.868 1629.48,327.891 1629.49,327.914 1629.49,327.937 1629.5,327.96 1629.51,327.983 1629.52,328.006 1629.53,328.029 1629.54,328.052 1629.55,328.075 1629.56,328.098 1629.57,328.121 1629.58,328.144 1629.59,328.167 1629.6,328.19 1629.6,328.213 1629.61,328.236 1629.62,328.259 1629.63,328.282 1629.64,328.305 1629.65,328.328 1629.66,328.351 1629.67,328.374 1629.68,328.397 1629.69,328.42 1629.7,328.443 1629.71,328.466 1629.72,328.488 1629.72,328.511 1629.73,328.534 1629.74,328.557 1629.75,328.58 1629.76,328.603 1629.77,328.626 1629.78,328.649 1629.79,328.672 1629.8,328.695 1629.81,328.718 1629.82,328.741 1629.83,328.764 1629.83,328.787 1629.84,328.81 1629.85,328.833 1629.86,328.855 1629.87,328.878 1629.88,328.901 1629.89,328.924 1629.9,328.947 1629.91,328.97 1629.92,328.993 1629.93,329.016 1629.94,329.039 1629.94,329.062 1629.95,329.085 1629.96,329.108 1629.97,329.13 1629.98,329.153 1629.99,329.176 1630,329.199 1630.01,329.222 1630.02,329.245 1630.03,329.268 1630.04,329.291 1630.05,329.314 1630.06,329.337 1630.06,329.359 1630.07,329.382 1630.08,329.405 1630.09,329.428 1630.1,329.451 1630.11,329.474 1630.12,329.497 1630.13,329.52 1630.14,329.543 1630.15,329.565 1630.16,329.588 1630.17,329.611 1630.17,329.634 1630.18,329.657 1630.19,329.68 1630.2,329.703 1630.21,329.726 1630.22,329.748 1630.23,329.771 1630.24,329.794 1630.25,329.817 1630.26,329.84 1630.27,329.863 1630.28,329.886 1630.28,329.908 1630.29,329.931 1630.3,329.954 1630.31,329.977 1630.32,330 1630.33,330.023 1630.34,330.046 1630.35,330.068 1630.36,330.091 1630.37,330.114 1630.38,330.137 1630.39,330.16 1630.4,330.183 1630.4,330.205 1630.41,330.228 1630.42,330.251 1630.43,330.274 1630.44,330.297 1630.45,330.32 1630.46,330.342 1630.47,330.365 1630.48,330.388 1630.49,330.411 1630.5,330.434 1630.51,330.457 1630.51,330.479 1630.52,330.502 1630.53,330.525 1630.54,330.548 1630.55,330.571 1630.56,330.593 1630.57,330.616 1630.58,330.639 1630.59,330.662 1630.6,330.685 1630.61,330.708 1630.62,330.73 1630.62,330.753 1630.63,330.776 1630.64,330.799 1630.65,330.822 1630.66,330.844 1630.67,330.867 1630.68,330.89 1630.69,330.913 1630.7,330.935 1630.71,330.958 1630.72,330.981 1630.73,331.004 1630.74,331.027 1630.74,331.049 1630.75,331.072 1630.76,331.095 1630.77,331.118 1630.78,331.14 1630.79,331.163 1630.8,331.186 1630.81,331.209 1630.82,331.232 1630.83,331.254 1630.84,331.277 1630.85,331.3 1630.85,331.323 1630.86,331.345 1630.87,331.368 1630.88,331.391 1630.89,331.414 1630.9,331.436 1630.91,331.459 1630.92,331.482 1630.93,331.505 1630.94,331.527 1630.95,331.55 1630.96,331.573 1630.96,331.596 1630.97,331.618 1630.98,331.641 1630.99,331.664 1631,331.687 1631.01,331.709 1631.02,331.732 1631.03,331.755 1631.04,331.778 1631.05,331.8 1631.06,331.823 1631.07,331.846 1631.08,331.868 1631.08,331.891 1631.09,331.914 1631.1,331.937 1631.11,331.959 1631.12,331.982 1631.13,332.005 1631.14,332.028 1631.15,332.05 1631.16,332.073 1631.17,332.096 1631.18,332.118 1631.19,332.141 1631.19,332.164 1631.2,332.187 1631.21,332.209 1631.22,332.232 1631.23,332.255 1631.24,332.277 1631.25,332.3 1631.26,332.323 1631.27,332.345 1631.28,332.368 1631.29,332.391 1631.3,332.413 1631.3,332.436 1631.31,332.459 1631.32,332.482 1631.33,332.504 1631.34,332.527 1631.35,332.55 1631.36,332.572 1631.37,332.595 1631.38,332.618 1631.39,332.64 1631.4,332.663 1631.41,332.686 1631.42,332.708 1631.42,332.731 1631.43,332.754 1631.44,332.776 1631.45,332.799 1631.46,332.822 1631.47,332.844 1631.48,332.867 1631.49,332.89 1631.5,332.912 1631.51,332.935 1631.52,332.958 1631.53,332.98 1631.53,333.003 1631.54,333.026 1631.55,333.048 1631.56,333.071 1631.57,333.093 1631.58,333.116 1631.59,333.139 1631.6,333.161 1631.61,333.184 1631.62,333.207 1631.63,333.229 1631.64,333.252 1631.64,333.275 1631.65,333.297 1631.66,333.32 1631.67,333.342 1631.68,333.365 1631.69,333.388 1631.7,333.41 1631.71,333.433 1631.72,333.456 1631.73,333.478 1631.74,333.501 1631.75,333.523 1631.76,333.546 1631.76,333.569 1631.77,333.591 1631.78,333.614 1631.79,333.637 1631.8,333.659 1631.81,333.682 1631.82,333.704 1631.83,333.727 1631.84,333.75 1631.85,333.772 1631.86,333.795 1631.87,333.817 1631.87,333.84 1631.88,333.863 1631.89,333.885 1631.9,333.908 1631.91,333.93 1631.92,333.953 1631.93,333.975 1631.94,333.998 1631.95,334.021 1631.96,334.043 1631.97,334.066 1631.98,334.088 1631.98,334.111 1631.99,334.134 1632,334.156 1632.01,334.179 1632.02,334.201 1632.03,334.224 1632.04,334.246 1632.05,334.269 1632.06,334.292 1632.07,334.314 1632.08,334.337 1632.09,334.359 1632.1,334.382 1632.1,334.404 1632.11,334.427 1632.12,334.449 1632.13,334.472 1632.14,334.495 1632.15,334.517 1632.16,334.54 1632.17,334.562 1632.18,334.585 1632.19,334.607 1632.2,334.63 1632.21,334.652 1632.21,334.675 1632.22,334.697 1632.23,334.72 1632.24,334.743 1632.25,334.765 1632.26,334.788 1632.27,334.81 1632.28,334.833 1632.29,334.855 1632.3,334.878 1632.31,334.9 1632.32,334.923 1632.32,334.945 1632.33,334.968 1632.34,334.99 1632.35,335.013 1632.36,335.035 1632.37,335.058 1632.38,335.08 1632.39,335.103 1632.4,335.125 1632.41,335.148 1632.42,335.17 1632.43,335.193 1632.44,335.215 1632.44,335.238 1632.45,335.26 1632.46,335.283 1632.47,335.305 1632.48,335.328 1632.49,335.35 1632.5,335.373 1632.51,335.395 1632.52,335.418 1632.53,335.44 1632.54,335.463 1632.55,335.485 1632.55,335.508 1632.56,335.53 1632.57,335.553 1632.58,335.575 1632.59,335.598 1632.6,335.62 1632.61,335.643 1632.62,335.665 1632.63,335.688 1632.64,335.71 1632.65,335.733 1632.66,335.755 1632.66,335.778 1632.67,335.8 1632.68,335.822 1632.69,335.845 1632.7,335.867 1632.71,335.89 1632.72,335.912 1632.73,335.935 1632.74,335.957 1632.75,335.98 1632.76,336.002 1632.77,336.025 1632.78,336.047 1632.78,336.069 1632.79,336.092 1632.8,336.114 1632.81,336.137 1632.82,336.159 1632.83,336.182 1632.84,336.204 1632.85,336.227 1632.86,336.249 1632.87,336.271 1632.88,336.294 1632.89,336.316 1632.89,336.339 1632.9,336.361 1632.91,336.384 1632.92,336.406 1632.93,336.428 1632.94,336.451 1632.95,336.473 1632.96,336.496 1632.97,336.518 1632.98,336.54 1632.99,336.563 1633,336.585 1633,336.608 1633.01,336.63 1633.02,336.653 1633.03,336.675 1633.04,336.697 1633.05,336.72 1633.06,336.742 1633.07,336.765 1633.08,336.787 1633.09,336.809 1633.1,336.832 1633.11,336.854 1633.12,336.877 1633.12,336.899 1633.13,336.921 1633.14,336.944 1633.15,336.966 1633.16,336.988 1633.17,337.011 1633.18,337.033 1633.19,337.056 1633.2,337.078 1633.21,337.1 1633.22,337.123 1633.23,337.145 1633.23,337.167 1633.24,337.19 1633.25,337.212 1633.26,337.235 1633.27,337.257 1633.28,337.279 1633.29,337.302 1633.3,337.324 1633.31,337.346 1633.32,337.369 1633.33,337.391 1633.34,337.413 1633.34,337.436 1633.35,337.458 1633.36,337.481 1633.37,337.503 1633.38,337.525 1633.39,337.548 1633.4,337.57 1633.41,337.592 1633.42,337.615 1633.43,337.637 1633.44,337.659 1633.45,337.682 1633.46,337.704 1633.46,337.726 1633.47,337.749 1633.48,337.771 1633.49,337.793 1633.5,337.816 1633.51,337.838 1633.52,337.86 1633.53,337.883 1633.54,337.905 1633.55,337.927 1633.56,337.95 1633.57,337.972 1633.57,337.994 1633.58,338.017 1633.59,338.039 1633.6,338.061 1633.61,338.083 1633.62,338.106 1633.63,338.128 1633.64,338.15 1633.65,338.173 1633.66,338.195 1633.67,338.217 1633.68,338.24 1633.68,338.262 1633.69,338.284 1633.7,338.307 1633.71,338.329 1633.72,338.351 1633.73,338.373 1633.74,338.396 1633.75,338.418 1633.76,338.44 1633.77,338.463 1633.78,338.485 1633.79,338.507 1633.8,338.529 1633.8,338.552 1633.81,338.574 1633.82,338.596 1633.83,338.619 1633.84,338.641 1633.85,338.663 1633.86,338.685 1633.87,338.708 1633.88,338.73 1633.89,338.752 1633.9,338.774 1633.91,338.797 1633.91,338.819 1633.92,338.841 1633.93,338.863 1633.94,338.886 1633.95,338.908 1633.96,338.93 1633.97,338.953 1633.98,338.975 1633.99,338.997 1634,339.019 1634.01,339.042 1634.02,339.064 1634.02,339.086 1634.03,339.108 1634.04,339.13 1634.05,339.153 1634.06,339.175 1634.07,339.197 1634.08,339.219 1634.09,339.242 1634.1,339.264 1634.11,339.286 1634.12,339.308 1634.13,339.331 1634.14,339.353 1634.14,339.375 1634.15,339.397 1634.16,339.419 1634.17,339.442 1634.18,339.464 1634.19,339.486 1634.2,339.508 1634.21,339.531 1634.22,339.553 1634.23,339.575 1634.24,339.597 1634.25,339.619 1634.25,339.642 1634.26,339.664 1634.27,339.686 1634.28,339.708 1634.29,339.73 1634.3,339.753 1634.31,339.775 1634.32,339.797 1634.33,339.819 1634.34,339.841 1634.35,339.864 1634.36,339.886 1634.36,339.908 1634.37,339.93 1634.38,339.952 1634.39,339.975 1634.4,339.997 1634.41,340.019 1634.42,340.041 1634.43,340.063 1634.44,340.085 1634.45,340.108 1634.46,340.13 1634.47,340.152 1634.48,340.174 1634.48,340.196 1634.49,340.219 1634.5,340.241 1634.51,340.263 1634.52,340.285 1634.53,340.307 1634.54,340.329 1634.55,340.351 1634.56,340.374 1634.57,340.396 1634.58,340.418 1634.59,340.44 1634.59,340.462 1634.6,340.484 1634.61,340.507 1634.62,340.529 1634.63,340.551 1634.64,340.573 1634.65,340.595 1634.66,340.617 1634.67,340.639 1634.68,340.662 1634.69,340.684 1634.7,340.706 1634.7,340.728 1634.71,340.75 1634.72,340.772 1634.73,340.794 1634.74,340.817 1634.75,340.839 1634.76,340.861 1634.77,340.883 1634.78,340.905 1634.79,340.927 1634.8,340.949 1634.81,340.971 1634.82,340.993 1634.82,341.016 1634.83,341.038 1634.84,341.06 1634.85,341.082 1634.86,341.104 1634.87,341.126 1634.88,341.148 1634.89,341.17 1634.9,341.192 1634.91,341.215 1634.92,341.237 1634.93,341.259 1634.93,341.281 1634.94,341.303 1634.95,341.325 1634.96,341.347 1634.97,341.369 1634.98,341.391 1634.99,341.413 1635,341.436 1635.01,341.458 1635.02,341.48 1635.03,341.502 1635.04,341.524 1635.04,341.546 1635.05,341.568 1635.06,341.59 1635.07,341.612 1635.08,341.634 1635.09,341.656 1635.1,341.678 1635.11,341.7 1635.12,341.723 1635.13,341.745 1635.14,341.767 1635.15,341.789 1635.16,341.811 1635.16,341.833 1635.17,341.855 1635.18,341.877 1635.19,341.899 1635.2,341.921 1635.21,341.943 1635.22,341.965 1635.23,341.987 1635.24,342.009 1635.25,342.031 1635.26,342.053 1635.27,342.075 1635.27,342.097 1635.28,342.12 1635.29,342.142 1635.3,342.164 1635.31,342.186 1635.32,342.208 1635.33,342.23 1635.34,342.252 1635.35,342.274 1635.36,342.296 1635.37,342.318 1635.38,342.34 1635.38,342.362 1635.39,342.384 1635.4,342.406 1635.41,342.428 1635.42,342.45 1635.43,342.472 1635.44,342.494 1635.45,342.516 1635.46,342.538 1635.47,342.56 1635.48,342.582 1635.49,342.604 1635.5,342.626 1635.5,342.648 1635.51,342.67 1635.52,342.692 1635.53,342.714 1635.54,342.736 1635.55,342.758 1635.56,342.78 1635.57,342.802 1635.58,342.824 1635.59,342.846 1635.6,342.868 1635.61,342.89 1635.61,342.912 1635.62,342.934 1635.63,342.956 1635.64,342.978 1635.65,343 1635.66,343.022 1635.67,343.044 1635.68,343.066 1635.69,343.088 1635.7,343.11 1635.71,343.132 1635.72,343.154 1635.72,343.176 1635.73,343.198 1635.74,343.22 1635.75,343.242 1635.76,343.264 1635.77,343.286 1635.78,343.308 1635.79,343.33 1635.8,343.351 1635.81,343.373 1635.82,343.395 1635.83,343.417 1635.84,343.439 1635.84,343.461 1635.85,343.483 1635.86,343.505 1635.87,343.527 1635.88,343.549 1635.89,343.571 1635.9,343.593 1635.91,343.615 1635.92,343.637 1635.93,343.659 1635.94,343.681 1635.95,343.703 1635.95,343.725 1635.96,343.747 1635.97,343.768 1635.98,343.79 1635.99,343.812 1636,343.834 1636.01,343.856 1636.02,343.878 1636.03,343.9 1636.04,343.922 1636.05,343.944 1636.06,343.966 1636.06,343.988 1636.07,344.01 1636.08,344.031 1636.09,344.053 1636.1,344.075 1636.11,344.097 1636.12,344.119 1636.13,344.141 1636.14,344.163 1636.15,344.185 1636.16,344.207 1636.17,344.229 1636.18,344.251 1636.18,344.272 1636.19,344.294 1636.2,344.316 1636.21,344.338 1636.22,344.36 1636.23,344.382 1636.24,344.404 1636.25,344.426 1636.26,344.448 1636.27,344.469 1636.28,344.491 1636.29,344.513 1636.29,344.535 1636.3,344.557 1636.31,344.579 1636.32,344.601 1636.33,344.623 1636.34,344.644 1636.35,344.666 1636.36,344.688 1636.37,344.71 1636.38,344.732 1636.39,344.754 1636.4,344.776 1636.4,344.798 1636.41,344.819 1636.42,344.841 1636.43,344.863 1636.44,344.885 1636.45,344.907 1636.46,344.929 1636.47,344.951 1636.48,344.972 1636.49,344.994 1636.5,345.016 1636.51,345.038 1636.52,345.06 1636.52,345.082 1636.53,345.103 1636.54,345.125 1636.55,345.147 1636.56,345.169 1636.57,345.191 1636.58,345.213 1636.59,345.234 1636.6,345.256 1636.61,345.278 1636.62,345.3 1636.63,345.322 1636.63,345.344 1636.64,345.365 1636.65,345.387 1636.66,345.409 1636.67,345.431 1636.68,345.453 1636.69,345.475 1636.7,345.496 1636.71,345.518 1636.72,345.54 1636.73,345.562 1636.74,345.584 1636.74,345.605 1636.75,345.627 1636.76,345.649 1636.77,345.671 1636.78,345.693 1636.79,345.714 1636.8,345.736 1636.81,345.758 1636.82,345.78 1636.83,345.802 1636.84,345.823 1636.85,345.845 1636.86,345.867 1636.86,345.889 1636.87,345.911 1636.88,345.932 1636.89,345.954 1636.9,345.976 1636.91,345.998 1636.92,346.019 1636.93,346.041 1636.94,346.063 1636.95,346.085 1636.96,346.107 1636.97,346.128 1636.97,346.15 1636.98,346.172 1636.99,346.194 1637,346.215 1637.01,346.237 1637.02,346.259 1637.03,346.281 1637.04,346.302 1637.05,346.324 1637.06,346.346 1637.07,346.368 1637.08,346.389 1637.08,346.411 1637.09,346.433 1637.1,346.455 1637.11,346.476 1637.12,346.498 1637.13,346.52 1637.14,346.542 1637.15,346.563 1637.16,346.585 1637.17,346.607 1637.18,346.629 1637.19,346.65 1637.2,346.672 1637.2,346.694 1637.21,346.716 1637.22,346.737 1637.23,346.759 1637.24,346.781 1637.25,346.803 1637.26,346.824 1637.27,346.846 1637.28,346.868 1637.29,346.889 1637.3,346.911 1637.31,346.933 1637.31,346.955 1637.32,346.976 1637.33,346.998 1637.34,347.02 1637.35,347.041 1637.36,347.063 1637.37,347.085 1637.38,347.107 1637.39,347.128 1637.4,347.15 1637.41,347.172 1637.42,347.193 1637.42,347.215 1637.43,347.237 1637.44,347.258 1637.45,347.28 1637.46,347.302 1637.47,347.324 1637.48,347.345 1637.49,347.367 1637.5,347.389 1637.51,347.41 1637.52,347.432 1637.53,347.454 1637.54,347.475 1637.54,347.497 1637.55,347.519 1637.56,347.54 1637.57,347.562 1637.58,347.584 1637.59,347.605 1637.6,347.627 1637.61,347.649 1637.62,347.67 1637.63,347.692 1637.64,347.714 1637.65,347.735 1637.65,347.757 1637.66,347.779 1637.67,347.8 1637.68,347.822 1637.69,347.844 1637.7,347.865 1637.71,347.887 1637.72,347.909 1637.73,347.93 1637.74,347.952 1637.75,347.974 1637.76,347.995 1637.76,348.017 1637.77,348.039 1637.78,348.06 1637.79,348.082 1637.8,348.104 1637.81,348.125 1637.82,348.147 1637.83,348.168 1637.84,348.19 1637.85,348.212 1637.86,348.233 1637.87,348.255 1637.88,348.277 1637.88,348.298 1637.89,348.32 1637.9,348.341 1637.91,348.363 1637.92,348.385 1637.93,348.406 1637.94,348.428 1637.95,348.45 1637.96,348.471 1637.97,348.493 1637.98,348.514 1637.99,348.536 1637.99,348.558 1638,348.579 1638.01,348.601 1638.02,348.622 1638.03,348.644 1638.04,348.666 1638.05,348.687 1638.06,348.709 1638.07,348.73 1638.08,348.752 1638.09,348.774 1638.1,348.795 1638.1,348.817 1638.11,348.838 1638.12,348.86 1638.13,348.882 1638.14,348.903 1638.15,348.925 1638.16,348.946 1638.17,348.968 1638.18,348.99 1638.19,349.011 1638.2,349.033 1638.21,349.054 1638.22,349.076 1638.22,349.097 1638.23,349.119 1638.24,349.141 1638.25,349.162 1638.26,349.184 1638.27,349.205 1638.28,349.227 1638.29,349.248 1638.3,349.27 1638.31,349.291 1638.32,349.313 1638.33,349.335 1638.33,349.356 1638.34,349.378 1638.35,349.399 1638.36,349.421 1638.37,349.442 1638.38,349.464 1638.39,349.485 1638.4,349.507 1638.41,349.529 1638.42,349.55 1638.43,349.572 1638.44,349.593 1638.44,349.615 1638.45,349.636 1638.46,349.658 1638.47,349.679 1638.48,349.701 1638.49,349.722 1638.5,349.744 1638.51,349.765 1638.52,349.787 1638.53,349.808 1638.54,349.83 1638.55,349.852 1638.56,349.873 1638.56,349.895 1638.57,349.916 1638.58,349.938 1638.59,349.959 1638.6,349.981 1638.61,350.002 1638.62,350.024 1638.63,350.045 1638.64,350.067 1638.65,350.088 1638.66,350.11 1638.67,350.131 1638.67,350.153 1638.68,350.174 1638.69,350.196 1638.7,350.217 1638.71,350.239 1638.72,350.26 1638.73,350.282 1638.74,350.303 1638.75,350.325 1638.76,350.346 1638.77,350.368 1638.78,350.389 1638.78,350.411 1638.79,350.432 1638.8,350.454 1638.81,350.475 1638.82,350.497 1638.83,350.518 1638.84,350.539 1638.85,350.561 1638.86,350.582 1638.87,350.604 1638.88,350.625 1638.89,350.647 1638.9,350.668 1638.9,350.69 1638.91,350.711 1638.92,350.733 1638.93,350.754 1638.94,350.776 1638.95,350.797 1638.96,350.819 1638.97,350.84 1638.98,350.861 1638.99,350.883 1639,350.904 1639.01,350.926 1639.01,350.947 1639.02,350.969 1639.03,350.99 1639.04,351.012 1639.05,351.033 1639.06,351.054 1639.07,351.076 1639.08,351.097 1639.09,351.119 1639.1,351.14 1639.11,351.162 1639.12,351.183 1639.12,351.204 1639.13,351.226 1639.14,351.247 1639.15,351.269 1639.16,351.29 1639.17,351.312 1639.18,351.333 1639.19,351.354 1639.2,351.376 1639.21,351.397 1639.22,351.419 1639.23,351.44 1639.24,351.462 1639.24,351.483 1639.25,351.504 1639.26,351.526 1639.27,351.547 1639.28,351.569 1639.29,351.59 1639.3,351.611 1639.31,351.633 1639.32,351.654 1639.33,351.676 1639.34,351.697 1639.35,351.718 1639.35,351.74 1639.36,351.761 1639.37,351.783 1639.38,351.804 1639.39,351.825 1639.4,351.847 1639.41,351.868 1639.42,351.89 1639.43,351.911 1639.44,351.932 1639.45,351.954 1639.46,351.975 1639.46,351.996 1639.47,352.018 1639.48,352.039 1639.49,352.061 1639.5,352.082 1639.51,352.103 1639.52,352.125 1639.53,352.146 1639.54,352.167 1639.55,352.189 1639.56,352.21 1639.57,352.231 1639.58,352.253 1639.58,352.274 1639.59,352.296 1639.6,352.317 1639.61,352.338 1639.62,352.36 1639.63,352.381 1639.64,352.402 1639.65,352.424 1639.66,352.445 1639.67,352.466 1639.68,352.488 1639.69,352.509 1639.69,352.53 1639.7,352.552 1639.71,352.573 1639.72,352.594 1639.73,352.616 1639.74,352.637 1639.75,352.658 1639.76,352.68 1639.77,352.701 1639.78,352.722 1639.79,352.744 1639.8,352.765 1639.8,352.786 1639.81,352.808 1639.82,352.829 1639.83,352.85 1639.84,352.872 1639.85,352.893 1639.86,352.914 1639.87,352.936 1639.88,352.957 1639.89,352.978 1639.9,353 1639.91,353.021 1639.92,353.042 1639.92,353.063 1639.93,353.085 1639.94,353.106 1639.95,353.127 1639.96,353.149 1639.97,353.17 1639.98,353.191 1639.99,353.213 1640,353.234 1640.01,353.255 1640.02,353.276 1640.03,353.298 1640.03,353.319 1640.04,353.34 1640.05,353.362 1640.06,353.383 1640.07,353.404 1640.08,353.425 1640.09,353.447 1640.1,353.468 1640.11,353.489 1640.12,353.511 1640.13,353.532 1640.14,353.553 1640.14,353.574 1640.15,353.596 1640.16,353.617 1640.17,353.638 1640.18,353.659 1640.19,353.681 1640.2,353.702 1640.21,353.723 1640.22,353.745 1640.23,353.766 1640.24,353.787 1640.25,353.808 1640.26,353.83 1640.26,353.851 1640.27,353.872 1640.28,353.893 1640.29,353.915 1640.3,353.936 1640.31,353.957 1640.32,353.978 1640.33,354 1640.34,354.021 1640.35,354.042 1640.36,354.063 1640.37,354.084 1640.37,354.106 1640.38,354.127 1640.39,354.148 1640.4,354.169 1640.41,354.191 1640.42,354.212 1640.43,354.233 1640.44,354.254 1640.45,354.276 1640.46,354.297 1640.47,354.318 1640.48,354.339 1640.48,354.36 1640.49,354.382 1640.5,354.403 1640.51,354.424 1640.52,354.445 1640.53,354.466 1640.54,354.488 1640.55,354.509 1640.56,354.53 1640.57,354.551 1640.58,354.573 1640.59,354.594 1640.6,354.615 1640.6,354.636 1640.61,354.657 1640.62,354.679 1640.63,354.7 1640.64,354.721 1640.65,354.742 1640.66,354.763 1640.67,354.784 1640.68,354.806 1640.69,354.827 1640.7,354.848 1640.71,354.869 1640.71,354.89 1640.72,354.912 1640.73,354.933 1640.74,354.954 1640.75,354.975 1640.76,354.996 1640.77,355.017 1640.78,355.039 1640.79,355.06 1640.8,355.081 1640.81,355.102 1640.82,355.123 1640.82,355.144 1640.83,355.166 1640.84,355.187 1640.85,355.208 1640.86,355.229 1640.87,355.25 1640.88,355.271 1640.89,355.293 1640.9,355.314 1640.91,355.335 1640.92,355.356 1640.93,355.377 1640.94,355.398 1640.94,355.42 1640.95,355.441 1640.96,355.462 1640.97,355.483 1640.98,355.504 1640.99,355.525 1641,355.546 1641.01,355.568 1641.02,355.589 1641.03,355.61 1641.04,355.631 1641.05,355.652 1641.05,355.673 1641.06,355.694 1641.07,355.715 1641.08,355.737 1641.09,355.758 1641.1,355.779 1641.11,355.8 1641.12,355.821 1641.13,355.842 1641.14,355.863 1641.15,355.884 1641.16,355.906 1641.16,355.927 1641.17,355.948 1641.18,355.969 1641.19,355.99 1641.2,356.011 1641.21,356.032 1641.22,356.053 1641.23,356.074 1641.24,356.095 1641.25,356.117 1641.26,356.138 1641.27,356.159 1641.28,356.18 1641.28,356.201 1641.29,356.222 1641.3,356.243 1641.31,356.264 1641.32,356.285 1641.33,356.306 1641.34,356.327 1641.35,356.349 1641.36,356.37 1641.37,356.391 1641.38,356.412 1641.39,356.433 1641.39,356.454 1641.4,356.475 1641.41,356.496 1641.42,356.517 1641.43,356.538 1641.44,356.559 1641.45,356.58 1641.46,356.601 1641.47,356.623 1641.48,356.644 1641.49,356.665 1641.5,356.686 1641.5,356.707 1641.51,356.728 1641.52,356.749 1641.53,356.77 1641.54,356.791 1641.55,356.812 1641.56,356.833 1641.57,356.854 1641.58,356.875 1641.59,356.896 1641.6,356.917 1641.61,356.938 1641.62,356.959 1641.62,356.98 1641.63,357.001 1641.64,357.023 1641.65,357.044 1641.66,357.065 1641.67,357.086 1641.68,357.107 1641.69,357.128 1641.7,357.149 1641.71,357.17 1641.72,357.191 1641.73,357.212 1641.73,357.233 1641.74,357.254 1641.75,357.275 1641.76,357.296 1641.77,357.317 1641.78,357.338 1641.79,357.359 1641.8,357.38 1641.81,357.401 1641.82,357.422 1641.83,357.443 1641.84,357.464 1641.84,357.485 1641.85,357.506 1641.86,357.527 1641.87,357.548 1641.88,357.569 1641.89,357.59 1641.9,357.611 1641.91,357.632 1641.92,357.653 1641.93,357.674 1641.94,357.695 1641.95,357.716 1641.96,357.737 1641.96,357.758 1641.97,357.779 1641.98,357.8 1641.99,357.821 1642,357.842 1642.01,357.863 1642.02,357.884 1642.03,357.905 1642.04,357.926 1642.05,357.947 1642.06,357.968 1642.07,357.989 1642.07,358.01 1642.08,358.031 1642.09,358.052 1642.1,358.073 1642.11,358.094 1642.12,358.115 1642.13,358.136 1642.14,358.157 1642.15,358.178 1642.16,358.198 1642.17,358.219 1642.18,358.24 1642.18,358.261 1642.19,358.282 1642.2,358.303 1642.21,358.324 1642.22,358.345 1642.23,358.366 1642.24,358.387 1642.25,358.408 1642.26,358.429 1642.27,358.45 1642.28,358.471 1642.29,358.492 1642.3,358.513 1642.3,358.534 1642.31,358.555 1642.32,358.575 1642.33,358.596 1642.34,358.617 1642.35,358.638 1642.36,358.659 1642.37,358.68 1642.38,358.701 1642.39,358.722 1642.4,358.743 1642.41,358.764 1642.41,358.785 1642.42,358.806 1642.43,358.827 1642.44,358.848 1642.45,358.868 1642.46,358.889 1642.47,358.91 1642.48,358.931 1642.49,358.952 1642.5,358.973 1642.51,358.994 1642.52,359.015 1642.52,359.036 1642.53,359.057 1642.54,359.077 1642.55,359.098 1642.56,359.119 1642.57,359.14 1642.58,359.161 1642.59,359.182 1642.6,359.203 1642.61,359.224 1642.62,359.245 1642.63,359.266 1642.64,359.286 1642.64,359.307 1642.65,359.328 1642.66,359.349 1642.67,359.37 1642.68,359.391 1642.69,359.412 1642.7,359.433 1642.71,359.453 1642.72,359.474 1642.73,359.495 1642.74,359.516 1642.75,359.537 1642.75,359.558 1642.76,359.579 1642.77,359.6 1642.78,359.62 1642.79,359.641 1642.8,359.662 1642.81,359.683 1642.82,359.704 1642.83,359.725 1642.84,359.746 1642.85,359.766 1642.86,359.787 1642.86,359.808 1642.87,359.829 1642.88,359.85 1642.89,359.871 1642.9,359.892 1642.91,359.912 1642.92,359.933 1642.93,359.954 1642.94,359.975 1642.95,359.996 1642.96,360.017 1642.97,360.037 1642.98,360.058 1642.98,360.079 1642.99,360.1 1643,360.121 1643.01,360.142 1643.02,360.162 1643.03,360.183 1643.04,360.204 1643.05,360.225 1643.06,360.246 1643.07,360.266 1643.08,360.287 1643.09,360.308 1643.09,360.329 1643.1,360.35 1643.11,360.371 1643.12,360.391 1643.13,360.412 1643.14,360.433 1643.15,360.454 1643.16,360.475 1643.17,360.495 1643.18,360.516 1643.19,360.537 1643.2,360.558 1643.2,360.579 1643.21,360.599 1643.22,360.62 1643.23,360.641 1643.24,360.662 1643.25,360.683 1643.26,360.703 1643.27,360.724 1643.28,360.745 1643.29,360.766 1643.3,360.787 1643.31,360.807 1643.32,360.828 1643.32,360.849 1643.33,360.87 1643.34,360.89 1643.35,360.911 1643.36,360.932 1643.37,360.953 1643.38,360.974 1643.39,360.994 1643.4,361.015 1643.41,361.036 1643.42,361.057 1643.43,361.077 1643.43,361.098 1643.44,361.119 1643.45,361.14 1643.46,361.16 1643.47,361.181 1643.48,361.202 1643.49,361.223 1643.5,361.243 1643.51,361.264 1643.52,361.285 1643.53,361.306 1643.54,361.326 1643.54,361.347 1643.55,361.368 1643.56,361.389 1643.57,361.409 1643.58,361.43 1643.59,361.451 1643.6,361.472 1643.61,361.492 1643.62,361.513 1643.63,361.534 1643.64,361.555 1643.65,361.575 1643.66,361.596 1643.66,361.617 1643.67,361.638 1643.68,361.658 1643.69,361.679 1643.7,361.7 1643.71,361.72 1643.72,361.741 1643.73,361.762 1643.74,361.783 1643.75,361.803 1643.76,361.824 1643.77,361.845 1643.77,361.865 1643.78,361.886 1643.79,361.907 1643.8,361.928 1643.81,361.948 1643.82,361.969 1643.83,361.99 1643.84,362.01 1643.85,362.031 1643.86,362.052 1643.87,362.073 1643.88,362.093 1643.88,362.114 1643.89,362.135 1643.9,362.155 1643.91,362.176 1643.92,362.197 1643.93,362.217 1643.94,362.238 1643.95,362.259 1643.96,362.279 1643.97,362.3 1643.98,362.321 1643.99,362.341 1644,362.362 1644,362.383 1644.01,362.403 1644.02,362.424 1644.03,362.445 1644.04,362.466 1644.05,362.486 1644.06,362.507 1644.07,362.528 1644.08,362.548 1644.09,362.569 1644.1,362.59 1644.11,362.61 1644.11,362.631 1644.12,362.652 1644.13,362.672 1644.14,362.693 1644.15,362.713 1644.16,362.734 1644.17,362.755 1644.18,362.775 1644.19,362.796 1644.2,362.817 1644.21,362.837 1644.22,362.858 1644.22,362.879 1644.23,362.899 1644.24,362.92 1644.25,362.941 1644.26,362.961 1644.27,362.982 1644.28,363.003 1644.29,363.023 1644.3,363.044 1644.31,363.064 1644.32,363.085 1644.33,363.106 1644.34,363.126 1644.34,363.147 1644.35,363.168 1644.36,363.188 1644.37,363.209 1644.38,363.229 1644.39,363.25 1644.4,363.271 1644.41,363.291 1644.42,363.312 1644.43,363.332 1644.44,363.353 1644.45,363.374 1644.45,363.394 1644.46,363.415 1644.47,363.436 1644.48,363.456 1644.49,363.477 1644.5,363.497 1644.51,363.518 1644.52,363.539 1644.53,363.559 1644.54,363.58 1644.55,363.6 1644.56,363.621 1644.56,363.642 1644.57,363.662 1644.58,363.683 1644.59,363.703 1644.6,363.724 1644.61,363.744 1644.62,363.765 1644.63,363.786 1644.64,363.806 1644.65,363.827 1644.66,363.847 1644.67,363.868 1644.68,363.889 1644.68,363.909 1644.69,363.93 1644.7,363.95 1644.71,363.971 1644.72,363.991 1644.73,364.012 1644.74,364.033 1644.75,364.053 1644.76,364.074 1644.77,364.094 1644.78,364.115 1644.79,364.135 1644.79,364.156 1644.8,364.176 1644.81,364.197 1644.82,364.218 1644.83,364.238 1644.84,364.259 1644.85,364.279 1644.86,364.3 1644.87,364.32 1644.88,364.341 1644.89,364.361 1644.9,364.382 1644.9,364.402 1644.91,364.423 1644.92,364.444 1644.93,364.464 1644.94,364.485 1644.95,364.505 1644.96,364.526 1644.97,364.546 1644.98,364.567 1644.99,364.587 1645,364.608 1645.01,364.628 1645.02,364.649 1645.02,364.669 1645.03,364.69 1645.04,364.71 1645.05,364.731 1645.06,364.751 1645.07,364.772 1645.08,364.793 1645.09,364.813 1645.1,364.834 1645.11,364.854 1645.12,364.875 1645.13,364.895 1645.13,364.916 1645.14,364.936 1645.15,364.957 1645.16,364.977 1645.17,364.998 1645.18,365.018 1645.19,365.039 1645.2,365.059 1645.21,365.08 1645.22,365.1 1645.23,365.121 1645.24,365.141 1645.24,365.162 1645.25,365.182 1645.26,365.203 1645.27,365.223 1645.28,365.244 1645.29,365.264 1645.3,365.284 1645.31,365.305 1645.32,365.325 1645.33,365.346 1645.34,365.366 1645.35,365.387 1645.36,365.407 1645.36,365.428 1645.37,365.448 1645.38,365.469 1645.39,365.489 1645.4,365.51 1645.41,365.53 1645.42,365.551 1645.43,365.571 1645.44,365.592 1645.45,365.612 1645.46,365.632 1645.47,365.653 1645.47,365.673 1645.48,365.694 1645.49,365.714 1645.5,365.735 1645.51,365.755 1645.52,365.776 1645.53,365.796 1645.54,365.817 1645.55,365.837 1645.56,365.857 1645.57,365.878 1645.58,365.898 1645.58,365.919 1645.59,365.939 1645.6,365.96 1645.61,365.98 1645.62,366 1645.63,366.021 1645.64,366.041 1645.65,366.062 1645.66,366.082 1645.67,366.103 1645.68,366.123 1645.69,366.143 1645.7,366.164 1645.7,366.184 1645.71,366.205 1645.72,366.225 1645.73,366.246 1645.74,366.266 1645.75,366.286 1645.76,366.307 1645.77,366.327 1645.78,366.348 1645.79,366.368 1645.8,366.388 1645.81,366.409 1645.81,366.429 1645.82,366.45 1645.83,366.47 1645.84,366.49 1645.85,366.511 1645.86,366.531 1645.87,366.552 1645.88,366.572 1645.89,366.592 1645.9,366.613 1645.91,366.633 1645.92,366.654 1645.92,366.674 1645.93,366.694 1645.94,366.715 1645.95,366.735 1645.96,366.756 1645.97,366.776 1645.98,366.796 1645.99,366.817 1646,366.837 1646.01,366.857 1646.02,366.878 1646.03,366.898 1646.04,366.919 1646.04,366.939 1646.05,366.959 1646.06,366.98 1646.07,367 1646.08,367.02 1646.09,367.041 1646.1,367.061 1646.11,367.082 1646.12,367.102 1646.13,367.122 1646.14,367.143 1646.15,367.163 1646.15,367.183 1646.16,367.204 1646.17,367.224 1646.18,367.244 1646.19,367.265 1646.2,367.285 1646.21,367.305 1646.22,367.326 1646.23,367.346 1646.24,367.366 1646.25,367.387 1646.26,367.407 1646.26,367.427 1646.27,367.448 1646.28,367.468 1646.29,367.488 1646.3,367.509 1646.31,367.529 1646.32,367.549 1646.33,367.57 1646.34,367.59 1646.35,367.61 1646.36,367.631 1646.37,367.651 1646.38,367.671 1646.38,367.692 1646.39,367.712 1646.4,367.732 1646.41,367.753 1646.42,367.773 1646.43,367.793 1646.44,367.814 1646.45,367.834 1646.46,367.854 1646.47,367.875 1646.48,367.895 1646.49,367.915 1646.49,367.935 1646.5,367.956 1646.51,367.976 1646.52,367.996 1646.53,368.017 1646.54,368.037 1646.55,368.057 1646.56,368.078 1646.57,368.098 1646.58,368.118 1646.59,368.138 1646.6,368.159 1646.6,368.179 1646.61,368.199 1646.62,368.22 1646.63,368.24 1646.64,368.26 1646.65,368.28 1646.66,368.301 1646.67,368.321 1646.68,368.341 1646.69,368.362 1646.7,368.382 1646.71,368.402 1646.72,368.422 1646.72,368.443 1646.73,368.463 1646.74,368.483 1646.75,368.503 1646.76,368.524 1646.77,368.544 1646.78,368.564 1646.79,368.584 1646.8,368.605 1646.81,368.625 1646.82,368.645 1646.83,368.665 1646.83,368.686 1646.84,368.706 1646.85,368.726 1646.86,368.746 1646.87,368.767 1646.88,368.787 1646.89,368.807 1646.9,368.827 1646.91,368.848 1646.92,368.868 1646.93,368.888 1646.94,368.908 1646.94,368.929 1646.95,368.949 1646.96,368.969 1646.97,368.989 1646.98,369.01 1646.99,369.03 1647,369.05 1647.01,369.07 1647.02,369.09 1647.03,369.111 1647.04,369.131 1647.05,369.151 1647.06,369.171 1647.06,369.192 1647.07,369.212 1647.08,369.232 1647.09,369.252 1647.1,369.272 1647.11,369.293 1647.12,369.313 1647.13,369.333 1647.14,369.353 1647.15,369.374 1647.16,369.394 1647.17,369.414 1647.17,369.434 1647.18,369.454 1647.19,369.475 1647.2,369.495 1647.21,369.515 1647.22,369.535 1647.23,369.555 1647.24,369.576 1647.25,369.596 1647.26,369.616 1647.27,369.636 1647.28,369.656 1647.28,369.676 1647.29,369.697 1647.3,369.717 1647.31,369.737 1647.32,369.757 1647.33,369.777 1647.34,369.798 1647.35,369.818 1647.36,369.838 1647.37,369.858 1647.38,369.878 1647.39,369.898 1647.4,369.919 1647.4,369.939 1647.41,369.959 1647.42,369.979 1647.43,369.999 1647.44,370.019 1647.45,370.04 1647.46,370.06 1647.47,370.08 1647.48,370.1 1647.49,370.12 1647.5,370.14 1647.51,370.161 1647.51,370.181 1647.52,370.201 1647.53,370.221 1647.54,370.241 1647.55,370.261 1647.56,370.281 1647.57,370.302 1647.58,370.322 1647.59,370.342 1647.6,370.362 1647.61,370.382 1647.62,370.402 1647.62,370.422 1647.63,370.443 1647.64,370.463 1647.65,370.483 1647.66,370.503 1647.67,370.523 1647.68,370.543 1647.69,370.563 1647.7,370.583 1647.71,370.604 1647.72,370.624 1647.73,370.644 1647.74,370.664 1647.74,370.684 1647.75,370.704 1647.76,370.724 1647.77,370.744 1647.78,370.765 1647.79,370.785 1647.8,370.805 1647.81,370.825 1647.82,370.845 1647.83,370.865 1647.84,370.885 1647.85,370.905 1647.85,370.925 1647.86,370.945 1647.87,370.966 1647.88,370.986 1647.89,371.006 1647.9,371.026 1647.91,371.046 1647.92,371.066 1647.93,371.086 1647.94,371.106 1647.95,371.126 1647.96,371.146 1647.96,371.166 1647.97,371.187 1647.98,371.207 1647.99,371.227 1648,371.247 1648.01,371.267 1648.02,371.287 1648.03,371.307 1648.04,371.327 1648.05,371.347 1648.06,371.367 1648.07,371.387 1648.08,371.407 1648.08,371.427 1648.09,371.448 1648.1,371.468 1648.11,371.488 1648.12,371.508 1648.13,371.528 1648.14,371.548 1648.15,371.568 1648.16,371.588 1648.17,371.608 1648.18,371.628 1648.19,371.648 1648.19,371.668 1648.2,371.688 1648.21,371.708 1648.22,371.728 1648.23,371.748 1648.24,371.768 1648.25,371.788 1648.26,371.809 1648.27,371.829 1648.28,371.849 1648.29,371.869 1648.3,371.889 1648.3,371.909 1648.31,371.929 1648.32,371.949 1648.33,371.969 1648.34,371.989 1648.35,372.009 1648.36,372.029 1648.37,372.049 1648.38,372.069 1648.39,372.089 1648.4,372.109 1648.41,372.129 1648.42,372.149 1648.42,372.169 1648.43,372.189 1648.44,372.209 1648.45,372.229 1648.46,372.249 1648.47,372.269 1648.48,372.289 1648.49,372.309 1648.5,372.329 1648.51,372.349 1648.52,372.369 1648.53,372.389 1648.53,372.409 1648.54,372.429 1648.55,372.449 1648.56,372.469 1648.57,372.489 1648.58,372.509 1648.59,372.529 1648.6,372.549 1648.61,372.569 1648.62,372.589 1648.63,372.609 1648.64,372.629 1648.64,372.649 1648.65,372.669 1648.66,372.689 1648.67,372.709 1648.68,372.729 1648.69,372.749 1648.7,372.769 1648.71,372.789 1648.72,372.809 1648.73,372.829 1648.74,372.849 1648.75,372.869 1648.76,372.889 1648.76,372.909 1648.77,372.929 1648.78,372.949 1648.79,372.969 1648.8,372.989 1648.81,373.009 1648.82,373.029 1648.83,373.049 1648.84,373.069 1648.85,373.088 1648.86,373.108 1648.87,373.128 1648.87,373.148 1648.88,373.168 1648.89,373.188 1648.9,373.208 1648.91,373.228 1648.92,373.248 1648.93,373.268 1648.94,373.288 1648.95,373.308 1648.96,373.328 1648.97,373.348 1648.98,373.368 1648.98,373.388 1648.99,373.408 1649,373.428 1649.01,373.447 1649.02,373.467 1649.03,373.487 1649.04,373.507 1649.05,373.527 1649.06,373.547 1649.07,373.567 1649.08,373.587 1649.09,373.607 1649.1,373.627 1649.1,373.647 1649.11,373.667 1649.12,373.687 1649.13,373.706 1649.14,373.726 1649.15,373.746 1649.16,373.766 1649.17,373.786 1649.18,373.806 1649.19,373.826 1649.2,373.846 1649.21,373.866 1649.21,373.886 1649.22,373.906 1649.23,373.925 1649.24,373.945 1649.25,373.965 1649.26,373.985 1649.27,374.005 1649.28,374.025 1649.29,374.045 1649.3,374.065 1649.31,374.085 1649.32,374.105 1649.32,374.124 1649.33,374.144 1649.34,374.164 1649.35,374.184 1649.36,374.204 1649.37,374.224 1649.38,374.244 1649.39,374.264 1649.4,374.283 1649.41,374.303 1649.42,374.323 1649.43,374.343 1649.44,374.363 1649.44,374.383 1649.45,374.403 1649.46,374.423 1649.47,374.442 1649.48,374.462 1649.49,374.482 1649.5,374.502 1649.51,374.522 1649.52,374.542 1649.53,374.562 1649.54,374.581 1649.55,374.601 1649.55,374.621 1649.56,374.641 1649.57,374.661 1649.58,374.681 1649.59,374.701 1649.6,374.72 1649.61,374.74 1649.62,374.76 1649.63,374.78 1649.64,374.8 1649.65,374.82 1649.66,374.839 1649.66,374.859 1649.67,374.879 1649.68,374.899 1649.69,374.919 1649.7,374.939 1649.71,374.958 1649.72,374.978 1649.73,374.998 1649.74,375.018 1649.75,375.038 1649.76,375.058 1649.77,375.077 1649.78,375.097 1649.78,375.117 1649.79,375.137 1649.8,375.157 1649.81,375.177 1649.82,375.196 1649.83,375.216 1649.84,375.236 1649.85,375.256 1649.86,375.276 1649.87,375.295 1649.88,375.315 1649.89,375.335 1649.89,375.355 1649.9,375.375 1649.91,375.394 1649.92,375.414 1649.93,375.434 1649.94,375.454 1649.95,375.474 1649.96,375.493 1649.97,375.513 1649.98,375.533 1649.99,375.553 1650,375.573 1650,375.592 1650.01,375.612 1650.02,375.632 1650.03,375.652 1650.04,375.672 1650.05,375.691 1650.06,375.711 1650.07,375.731 1650.08,375.751 1650.09,375.77 1650.1,375.79 1650.11,375.81 1650.12,375.83 1650.12,375.85 1650.13,375.869 1650.14,375.889 1650.15,375.909 1650.16,375.929 1650.17,375.948 1650.18,375.968 1650.19,375.988 1650.2,376.008 1650.21,376.027 1650.22,376.047 1650.23,376.067 1650.23,376.087 1650.24,376.106 1650.25,376.126 1650.26,376.146 1650.27,376.166 1650.28,376.185 1650.29,376.205 1650.3,376.225 1650.31,376.245 1650.32,376.264 1650.33,376.284 1650.34,376.304 1650.34,376.324 1650.35,376.343 1650.36,376.363 1650.37,376.383 1650.38,376.403 1650.39,376.422 1650.4,376.442 1650.41,376.462 1650.42,376.481 1650.43,376.501 1650.44,376.521 1650.45,376.541 1650.46,376.56 1650.46,376.58 1650.47,376.6 1650.48,376.62 1650.49,376.639 1650.5,376.659 1650.51,376.679 1650.52,376.698 1650.53,376.718 1650.54,376.738 1650.55,376.758 1650.56,376.777 1650.57,376.797 1650.57,376.817 1650.58,376.836 1650.59,376.856 1650.6,376.876 1650.61,376.895 1650.62,376.915 1650.63,376.935 1650.64,376.955 1650.65,376.974 1650.66,376.994 1650.67,377.014 1650.68,377.033 1650.68,377.053 1650.69,377.073 1650.7,377.092 1650.71,377.112 1650.72,377.132 1650.73,377.151 1650.74,377.171 1650.75,377.191 1650.76,377.211 1650.77,377.23 1650.78,377.25 1650.79,377.27 1650.8,377.289 1650.8,377.309 1650.81,377.329 1650.82,377.348 1650.83,377.368 1650.84,377.388 1650.85,377.407 1650.86,377.427 1650.87,377.447 1650.88,377.466 1650.89,377.486 1650.9,377.506 1650.91,377.525 1650.91,377.545 1650.92,377.565 1650.93,377.584 1650.94,377.604 1650.95,377.624 1650.96,377.643 1650.97,377.663 1650.98,377.682 1650.99,377.702 1651,377.722 1651.01,377.741 1651.02,377.761 1651.02,377.781 1651.03,377.8 1651.04,377.82 1651.05,377.84 1651.06,377.859 1651.07,377.879 1651.08,377.899 1651.09,377.918 1651.1,377.938 1651.11,377.957 1651.12,377.977 1651.13,377.997 1651.14,378.016 1651.14,378.036 1651.15,378.056 1651.16,378.075 1651.17,378.095 1651.18,378.114 1651.19,378.134 1651.2,378.154 1651.21,378.173 1651.22,378.193 1651.23,378.212 1651.24,378.232 1651.25,378.252 1651.25,378.271 1651.26,378.291 1651.27,378.311 1651.28,378.33 1651.29,378.35 1651.3,378.369 1651.31,378.389 1651.32,378.409 1651.33,378.428 1651.34,378.448 1651.35,378.467 1651.36,378.487 1651.36,378.507 1651.37,378.526 1651.38,378.546 1651.39,378.565 1651.4,378.585 1651.41,378.604 1651.42,378.624 1651.43,378.644 1651.44,378.663 1651.45,378.683 1651.46,378.702 1651.47,378.722 1651.48,378.742 1651.48,378.761 1651.49,378.781 1651.5,378.8 1651.51,378.82 1651.52,378.839 1651.53,378.859 1651.54,378.879 1651.55,378.898 1651.56,378.918 1651.57,378.937 1651.58,378.957 1651.59,378.976 1651.59,378.996 1651.6,379.015 1651.61,379.035 1651.62,379.055 1651.63,379.074 1651.64,379.094 1651.65,379.113 1651.66,379.133 1651.67,379.152 1651.68,379.172 1651.69,379.191 1651.7,379.211 1651.7,379.231 1651.71,379.25 1651.72,379.27 1651.73,379.289 1651.74,379.309 1651.75,379.328 1651.76,379.348 1651.77,379.367 1651.78,379.387 1651.79,379.406 1651.8,379.426 1651.81,379.445 1651.82,379.465 1651.82,379.485 1651.83,379.504 1651.84,379.524 1651.85,379.543 1651.86,379.563 1651.87,379.582 1651.88,379.602 1651.89,379.621 1651.9,379.641 1651.91,379.66 1651.92,379.68 1651.93,379.699 1651.93,379.719 1651.94,379.738 1651.95,379.758 1651.96,379.777 1651.97,379.797 1651.98,379.816 1651.99,379.836 1652,379.855 1652.01,379.875 1652.02,379.894 1652.03,379.914 1652.04,379.933 1652.04,379.953 1652.05,379.972 1652.06,379.992 1652.07,380.011 1652.08,380.031 1652.09,380.05 1652.1,380.07 1652.11,380.089 1652.12,380.109 1652.13,380.128 1652.14,380.148 1652.15,380.167 1652.16,380.187 1652.16,380.206 1652.17,380.226 1652.18,380.245 1652.19,380.265 1652.2,380.284 1652.21,380.303 1652.22,380.323 1652.23,380.342 1652.24,380.362 1652.25,380.381 1652.26,380.401 1652.27,380.42 1652.27,380.44 1652.28,380.459 1652.29,380.479 1652.3,380.498 1652.31,380.518 1652.32,380.537 1652.33,380.557 1652.34,380.576 1652.35,380.595 1652.36,380.615 1652.37,380.634 1652.38,380.654 1652.38,380.673 1652.39,380.693 1652.4,380.712 1652.41,380.732 1652.42,380.751 1652.43,380.77 1652.44,380.79 1652.45,380.809 1652.46,380.829 1652.47,380.848 1652.48,380.868 1652.49,380.887 1652.5,380.907 1652.5,380.926 1652.51,380.945 1652.52,380.965 1652.53,380.984 1652.54,381.004 1652.55,381.023 1652.56,381.043 1652.57,381.062 1652.58,381.081 1652.59,381.101 1652.6,381.12 1652.61,381.14 1652.61,381.159 1652.62,381.178 1652.63,381.198 1652.64,381.217 1652.65,381.237 1652.66,381.256 1652.67,381.275 1652.68,381.295 1652.69,381.314 1652.7,381.334 1652.71,381.353 1652.72,381.373 1652.72,381.392 1652.73,381.411 1652.74,381.431 1652.75,381.45 1652.76,381.469 1652.77,381.489 1652.78,381.508 1652.79,381.528 1652.8,381.547 1652.81,381.566 1652.82,381.586 1652.83,381.605 1652.84,381.625 1652.84,381.644 1652.85,381.663 1652.86,381.683 1652.87,381.702 1652.88,381.722 1652.89,381.741 1652.9,381.76 1652.91,381.78 1652.92,381.799 1652.93,381.818 1652.94,381.838 1652.95,381.857 1652.95,381.876 1652.96,381.896 1652.97,381.915 1652.98,381.935 1652.99,381.954 1653,381.973 1653.01,381.993 1653.02,382.012 1653.03,382.031 1653.04,382.051 1653.05,382.07 1653.06,382.089 1653.06,382.109 1653.07,382.128 1653.08,382.147 1653.09,382.167 1653.1,382.186 1653.11,382.206 1653.12,382.225 1653.13,382.244 1653.14,382.264 1653.15,382.283 1653.16,382.302 1653.17,382.322 1653.18,382.341 1653.18,382.36 1653.19,382.38 1653.2,382.399 1653.21,382.418 1653.22,382.438 1653.23,382.457 1653.24,382.476 1653.25,382.496 1653.26,382.515 1653.27,382.534 1653.28,382.554 1653.29,382.573 1653.29,382.592 1653.3,382.612 1653.31,382.631 1653.32,382.65 1653.33,382.669 1653.34,382.689 1653.35,382.708 1653.36,382.727 1653.37,382.747 1653.38,382.766 1653.39,382.785 1653.4,382.805 1653.4,382.824 1653.41,382.843 1653.42,382.863 1653.43,382.882 1653.44,382.901 1653.45,382.92 1653.46,382.94 1653.47,382.959 1653.48,382.978 1653.49,382.998 1653.5,383.017 1653.51,383.036 1653.52,383.055 1653.52,383.075 1653.53,383.094 1653.54,383.113 1653.55,383.133 1653.56,383.152 1653.57,383.171 1653.58,383.19 1653.59,383.21 1653.6,383.229 1653.61,383.248 1653.62,383.268 1653.63,383.287 1653.63,383.306 1653.64,383.325 1653.65,383.345 1653.66,383.364 1653.67,383.383 1653.68,383.402 1653.69,383.422 1653.7,383.441 1653.71,383.46 1653.72,383.48 1653.73,383.499 1653.74,383.518 1653.74,383.537 1653.75,383.557 1653.76,383.576 1653.77,383.595 1653.78,383.614 1653.79,383.634 1653.8,383.653 1653.81,383.672 1653.82,383.691 1653.83,383.711 1653.84,383.73 1653.85,383.749 1653.86,383.768 1653.86,383.787 1653.87,383.807 1653.88,383.826 1653.89,383.845 1653.9,383.864 1653.91,383.884 1653.92,383.903 1653.93,383.922 1653.94,383.941 1653.95,383.961 1653.96,383.98 1653.97,383.999 1653.97,384.018 1653.98,384.037 1653.99,384.057 1654,384.076 1654.01,384.095 1654.02,384.114 1654.03,384.134 1654.04,384.153 1654.05,384.172 1654.06,384.191 1654.07,384.21 1654.08,384.23 1654.09,384.249 1654.09,384.268 1654.1,384.287 1654.11,384.306 1654.12,384.326 1654.13,384.345 1654.14,384.364 1654.15,384.383 1654.16,384.402 1654.17,384.422 1654.18,384.441 1654.19,384.46 1654.2,384.479 1654.2,384.498 1654.21,384.518 1654.22,384.537 1654.23,384.556 1654.24,384.575 1654.25,384.594 1654.26,384.614 1654.27,384.633 1654.28,384.652 1654.29,384.671 1654.3,384.69 1654.31,384.71 1654.31,384.729 1654.32,384.748 1654.33,384.767 1654.34,384.786 1654.35,384.805 1654.36,384.825 1654.37,384.844 1654.38,384.863 1654.39,384.882 1654.4,384.901 1654.41,384.92 1654.42,384.94 1654.43,384.959 1654.43,384.978 1654.44,384.997 1654.45,385.016 1654.46,385.035 1654.47,385.054 1654.48,385.074 1654.49,385.093 1654.5,385.112 1654.51,385.131 1654.52,385.15 1654.53,385.169 1654.54,385.189 1654.54,385.208 1654.55,385.227 1654.56,385.246 1654.57,385.265 1654.58,385.284 1654.59,385.303 1654.6,385.323 1654.61,385.342 1654.62,385.361 1654.63,385.38 1654.64,385.399 1654.65,385.418 1654.65,385.437 1654.66,385.456 1654.67,385.476 1654.68,385.495 1654.69,385.514 1654.7,385.533 1654.71,385.552 1654.72,385.571 1654.73,385.59 1654.74,385.609 1654.75,385.629 1654.76,385.648 1654.77,385.667 1654.77,385.686 1654.78,385.705 1654.79,385.724 1654.8,385.743 1654.81,385.762 1654.82,385.781 1654.83,385.801 1654.84,385.82 1654.85,385.839 1654.86,385.858 1654.87,385.877 1654.88,385.896 1654.88,385.915 1654.89,385.934 1654.9,385.953 1654.91,385.972 1654.92,385.992 1654.93,386.011 1654.94,386.03 1654.95,386.049 1654.96,386.068 1654.97,386.087 1654.98,386.106 1654.99,386.125 1654.99,386.144 1655,386.163 1655.01,386.182 1655.02,386.201 1655.03,386.221 1655.04,386.24 1655.05,386.259 1655.06,386.278 1655.07,386.297 1655.08,386.316 1655.09,386.335 1655.1,386.354 1655.11,386.373 1655.11,386.392 1655.12,386.411 1655.13,386.43 1655.14,386.449 1655.15,386.468 1655.16,386.488 1655.17,386.507 1655.18,386.526 1655.19,386.545 1655.2,386.564 1655.21,386.583 1655.22,386.602 1655.22,386.621 1655.23,386.64 1655.24,386.659 1655.25,386.678 1655.26,386.697 1655.27,386.716 1655.28,386.735 1655.29,386.754 1655.3,386.773 1655.31,386.792 1655.32,386.811 1655.33,386.83 1655.33,386.849 1655.34,386.868 1655.35,386.887 1655.36,386.907 1655.37,386.926 1655.38,386.945 1655.39,386.964 1655.4,386.983 1655.41,387.002 1655.42,387.021 1655.43,387.04 1655.44,387.059 1655.45,387.078 1655.45,387.097 1655.46,387.116 1655.47,387.135 1655.48,387.154 1655.49,387.173 1655.5,387.192 1655.51,387.211 1655.52,387.23 1655.53,387.249 1655.54,387.268 1655.55,387.287 1655.56,387.306 1655.56,387.325 1655.57,387.344 1655.58,387.363 1655.59,387.382 1655.6,387.401 1655.61,387.42 1655.62,387.439 1655.63,387.458 1655.64,387.477 1655.65,387.496 1655.66,387.515 1655.67,387.534 1655.67,387.553 1655.68,387.572 1655.69,387.591 1655.7,387.61 1655.71,387.629 1655.72,387.648 1655.73,387.667 1655.74,387.686 1655.75,387.705 1655.76,387.724 1655.77,387.743 1655.78,387.762 1655.79,387.781 1655.79,387.8 1655.8,387.819 1655.81,387.838 1655.82,387.856 1655.83,387.875 1655.84,387.894 1655.85,387.913 1655.86,387.932 1655.87,387.951 1655.88,387.97 1655.89,387.989 1655.9,388.008 1655.9,388.027 1655.91,388.046 1655.92,388.065 1655.93,388.084 1655.94,388.103 1655.95,388.122 1655.96,388.141 1655.97,388.16 1655.98,388.179 1655.99,388.198 1656,388.217 1656.01,388.236 1656.01,388.255 1656.02,388.273 1656.03,388.292 1656.04,388.311 1656.05,388.33 1656.06,388.349 1656.07,388.368 1656.08,388.387 1656.09,388.406 1656.1,388.425 1656.11,388.444 1656.12,388.463 1656.13,388.482 1656.13,388.501 1656.14,388.52 1656.15,388.539 1656.16,388.557 1656.17,388.576 1656.18,388.595 1656.19,388.614 1656.2,388.633 1656.21,388.652 1656.22,388.671 1656.23,388.69 1656.24,388.709 1656.24,388.728 1656.25,388.747 1656.26,388.765 1656.27,388.784 1656.28,388.803 1656.29,388.822 1656.3,388.841 1656.31,388.86 1656.32,388.879 1656.33,388.898 1656.34,388.917 1656.35,388.936 1656.35,388.955 1656.36,388.973 1656.37,388.992 1656.38,389.011 1656.39,389.03 1656.4,389.049 1656.41,389.068 1656.42,389.087 1656.43,389.106 1656.44,389.125 1656.45,389.143 1656.46,389.162 1656.47,389.181 1656.47,389.2 1656.48,389.219 1656.49,389.238 1656.5,389.257 1656.51,389.276 1656.52,389.294 1656.53,389.313 1656.54,389.332 1656.55,389.351 1656.56,389.37 1656.57,389.389 1656.58,389.408 1656.58,389.426 1656.59,389.445 1656.6,389.464 1656.61,389.483 1656.62,389.502 1656.63,389.521 1656.64,389.54 1656.65,389.559 1656.66,389.577 1656.67,389.596 1656.68,389.615 1656.69,389.634 1656.69,389.653 1656.7,389.672 1656.71,389.69 1656.72,389.709 1656.73,389.728 1656.74,389.747 1656.75,389.766 1656.76,389.785 1656.77,389.804 1656.78,389.822 1656.79,389.841 1656.8,389.86 1656.81,389.879 1656.81,389.898 1656.82,389.917 1656.83,389.935 1656.84,389.954 1656.85,389.973 1656.86,389.992 1656.87,390.011 1656.88,390.029 1656.89,390.048 1656.9,390.067 1656.91,390.086 1656.92,390.105 1656.92,390.124 1656.93,390.142 1656.94,390.161 1656.95,390.18 1656.96,390.199 1656.97,390.218 1656.98,390.236 1656.99,390.255 1657,390.274 1657.01,390.293 1657.02,390.312 1657.03,390.33 1657.03,390.349 1657.04,390.368 1657.05,390.387 1657.06,390.406 1657.07,390.425 1657.08,390.443 1657.09,390.462 1657.1,390.481 1657.11,390.5 1657.12,390.518 1657.13,390.537 1657.14,390.556 1657.15,390.575 1657.15,390.594 1657.16,390.612 1657.17,390.631 1657.18,390.65 1657.19,390.669 1657.2,390.688 1657.21,390.706 1657.22,390.725 1657.23,390.744 1657.24,390.763 1657.25,390.781 1657.26,390.8 1657.26,390.819 1657.27,390.838 1657.28,390.857 1657.29,390.875 1657.3,390.894 1657.31,390.913 1657.32,390.932 1657.33,390.95 1657.34,390.969 1657.35,390.988 1657.36,391.007 1657.37,391.025 1657.37,391.044 1657.38,391.063 1657.39,391.082 1657.4,391.1 1657.41,391.119 1657.42,391.138 1657.43,391.157 1657.44,391.175 1657.45,391.194 1657.46,391.213 1657.47,391.232 1657.48,391.25 1657.49,391.269 1657.49,391.288 1657.5,391.307 1657.51,391.325 1657.52,391.344 1657.53,391.363 1657.54,391.382 1657.55,391.4 1657.56,391.419 1657.57,391.438 1657.58,391.456 1657.59,391.475 1657.6,391.494 1657.6,391.513 1657.61,391.531 1657.62,391.55 1657.63,391.569 1657.64,391.588 1657.65,391.606 1657.66,391.625 1657.67,391.644 1657.68,391.662 1657.69,391.681 1657.7,391.7 1657.71,391.719 1657.71,391.737 1657.72,391.756 1657.73,391.775 1657.74,391.793 1657.75,391.812 1657.76,391.831 1657.77,391.849 1657.78,391.868 1657.79,391.887 1657.8,391.906 1657.81,391.924 1657.82,391.943 1657.83,391.962 1657.83,391.98 1657.84,391.999 1657.85,392.018 1657.86,392.036 1657.87,392.055 1657.88,392.074 1657.89,392.093 1657.9,392.111 1657.91,392.13 1657.92,392.149 1657.93,392.167 1657.94,392.186 1657.94,392.205 1657.95,392.223 1657.96,392.242 1657.97,392.261 1657.98,392.279 1657.99,392.298 1658,392.317 1658.01,392.335 1658.02,392.354 1658.03,392.373 1658.04,392.391 1658.05,392.41 1658.05,392.429 1658.06,392.447 1658.07,392.466 1658.08,392.485 1658.09,392.503 1658.1,392.522 1658.11,392.541 1658.12,392.559 1658.13,392.578 1658.14,392.597 1658.15,392.615 1658.16,392.634 1658.17,392.653 1658.17,392.671 1658.18,392.69 1658.19,392.708 1658.2,392.727 1658.21,392.746 1658.22,392.764 1658.23,392.783 1658.24,392.802 1658.25,392.82 1658.26,392.839 1658.27,392.858 1658.28,392.876 1658.28,392.895 1658.29,392.914 1658.3,392.932 1658.31,392.951 1658.32,392.969 1658.33,392.988 1658.34,393.007 1658.35,393.025 1658.36,393.044 1658.37,393.063 1658.38,393.081 1658.39,393.1 1658.39,393.118 1658.4,393.137 1658.41,393.156 1658.42,393.174 1658.43,393.193 1658.44,393.211 1658.45,393.23 1658.46,393.249 1658.47,393.267 1658.48,393.286 1658.49,393.305 1658.5,393.323 1658.51,393.342 1658.51,393.36 1658.52,393.379 1658.53,393.398 1658.54,393.416 1658.55,393.435 1658.56,393.453 1658.57,393.472 1658.58,393.491 1658.59,393.509 1658.6,393.528 1658.61,393.546 1658.62,393.565 1658.62,393.583 1658.63,393.602 1658.64,393.621 1658.65,393.639 1658.66,393.658 1658.67,393.676 1658.68,393.695 1658.69,393.714 1658.7,393.732 1658.71,393.751 1658.72,393.769 1658.73,393.788 1658.73,393.806 1658.74,393.825 1658.75,393.844 1658.76,393.862 1658.77,393.881 1658.78,393.899 1658.79,393.918 1658.8,393.936 1658.81,393.955 1658.82,393.974 1658.83,393.992 1658.84,394.011 1658.85,394.029 1658.85,394.048 1658.86,394.066 1658.87,394.085 1658.88,394.103 1658.89,394.122 1658.9,394.141 1658.91,394.159 1658.92,394.178 1658.93,394.196 1658.94,394.215 1658.95,394.233 1658.96,394.252 1658.96,394.27 1658.97,394.289 1658.98,394.307 1658.99,394.326 1659,394.345 1659.01,394.363 1659.02,394.382 1659.03,394.4 1659.04,394.419 1659.05,394.437 1659.06,394.456 1659.07,394.474 1659.07,394.493 1659.08,394.511 1659.09,394.53 1659.1,394.548 1659.11,394.567 1659.12,394.585 1659.13,394.604 1659.14,394.622 1659.15,394.641 1659.16,394.659 1659.17,394.678 1659.18,394.697 1659.19,394.715 1659.19,394.734 1659.2,394.752 1659.21,394.771 1659.22,394.789 1659.23,394.808 1659.24,394.826 1659.25,394.845 1659.26,394.863 1659.27,394.882 1659.28,394.9 1659.29,394.919 1659.3,394.937 1659.3,394.956 1659.31,394.974 1659.32,394.993 1659.33,395.011 1659.34,395.03 1659.35,395.048 1659.36,395.067 1659.37,395.085 1659.38,395.104 1659.39,395.122 1659.4,395.141 1659.41,395.159 1659.41,395.177 1659.42,395.196 1659.43,395.214 1659.44,395.233 1659.45,395.251 1659.46,395.27 1659.47,395.288 1659.48,395.307 1659.49,395.325 1659.5,395.344 1659.51,395.362 1659.52,395.381 1659.53,395.399 1659.53,395.418 1659.54,395.436 1659.55,395.455 1659.56,395.473 1659.57,395.491 1659.58,395.51 1659.59,395.528 1659.6,395.547 1659.61,395.565 1659.62,395.584 1659.63,395.602 1659.64,395.621 1659.64,395.639 1659.65,395.658 1659.66,395.676 1659.67,395.694 1659.68,395.713 1659.69,395.731 1659.7,395.75 1659.71,395.768 1659.72,395.787 1659.73,395.805 1659.74,395.824 1659.75,395.842 1659.75,395.86 1659.76,395.879 1659.77,395.897 1659.78,395.916 1659.79,395.934 1659.8,395.953 1659.81,395.971 1659.82,395.99 1659.83,396.008 1659.84,396.026 1659.85,396.045 1659.86,396.063 1659.87,396.082 1659.87,396.1 1659.88,396.118 1659.89,396.137 1659.9,396.155 1659.91,396.174 1659.92,396.192 1659.93,396.211 1659.94,396.229 1659.95,396.247 1659.96,396.266 1659.97,396.284 1659.98,396.303 1659.98,396.321 1659.99,396.339 1660,396.358 1660.01,396.376 1660.02,396.395 1660.03,396.413 1660.04,396.431 1660.05,396.45 1660.06,396.468 1660.07,396.487 1660.08,396.505 1660.09,396.523 1660.09,396.542 1660.1,396.56 1660.11,396.579 1660.12,396.597 1660.13,396.615 1660.14,396.634 1660.15,396.652 1660.16,396.671 1660.17,396.689 1660.18,396.707 1660.19,396.726 1660.2,396.744 1660.21,396.762 1660.21,396.781 1660.22,396.799 1660.23,396.818 1660.24,396.836 1660.25,396.854 1660.26,396.873 1660.27,396.891 1660.28,396.909 1660.29,396.928 1660.3,396.946 1660.31,396.965 1660.32,396.983 1660.32,397.001 1660.33,397.02 1660.34,397.038 1660.35,397.056 1660.36,397.075 1660.37,397.093 1660.38,397.111 1660.39,397.13 1660.4,397.148 1660.41,397.166 1660.42,397.185 1660.43,397.203 1660.43,397.221 1660.44,397.24 1660.45,397.258 1660.46,397.277 1660.47,397.295 1660.48,397.313 1660.49,397.332 1660.5,397.35 1660.51,397.368 1660.52,397.387 1660.53,397.405 1660.54,397.423 1660.55,397.442 1660.55,397.46 1660.56,397.478 1660.57,397.497 1660.58,397.515 1660.59,397.533 1660.6,397.552 1660.61,397.57 1660.62,397.588 1660.63,397.607 1660.64,397.625 1660.65,397.643 1660.66,397.661 1660.66,397.68 1660.67,397.698 1660.68,397.716 1660.69,397.735 1660.7,397.753 1660.71,397.771 1660.72,397.79 1660.73,397.808 1660.74,397.826 1660.75,397.845 1660.76,397.863 1660.77,397.881 1660.77,397.9 1660.78,397.918 1660.79,397.936 1660.8,397.954 1660.81,397.973 1660.82,397.991 1660.83,398.009 1660.84,398.028 1660.85,398.046 1660.86,398.064 1660.87,398.082 1660.88,398.101 1660.89,398.119 1660.89,398.137 1660.9,398.156 1660.91,398.174 1660.92,398.192 1660.93,398.21 1660.94,398.229 1660.95,398.247 1660.96,398.265 1660.97,398.284 1660.98,398.302 1660.99,398.32 1661,398.338 1661,398.357 1661.01,398.375 1661.02,398.393 1661.03,398.412 1661.04,398.43 1661.05,398.448 1661.06,398.466 1661.07,398.485 1661.08,398.503 1661.09,398.521 1661.1,398.539 1661.11,398.558 1661.11,398.576 1661.12,398.594 1661.13,398.612 1661.14,398.631 1661.15,398.649 1661.16,398.667 1661.17,398.685 1661.18,398.704 1661.19,398.722 1661.2,398.74 1661.21,398.758 1661.22,398.777 1661.23,398.795 1661.23,398.813 1661.24,398.831 1661.25,398.85 1661.26,398.868 1661.27,398.886 1661.28,398.904 1661.29,398.923 1661.3,398.941 1661.31,398.959 1661.32,398.977 1661.33,398.995 1661.34,399.014 1661.34,399.032 1661.35,399.05 1661.36,399.068 1661.37,399.087 1661.38,399.105 1661.39,399.123 1661.4,399.141 1661.41,399.16 1661.42,399.178 1661.43,399.196 1661.44,399.214 1661.45,399.232 1661.45,399.251 1661.46,399.269 1661.47,399.287 1661.48,399.305 1661.49,399.323 1661.5,399.342 1661.51,399.36 1661.52,399.378 1661.53,399.396 1661.54,399.414 1661.55,399.433 1661.56,399.451 1661.57,399.469 1661.57,399.487 1661.58,399.505 1661.59,399.524 1661.6,399.542 1661.61,399.56 1661.62,399.578 1661.63,399.596 1661.64,399.615 1661.65,399.633 1661.66,399.651 1661.67,399.669 1661.68,399.687 1661.68,399.706 1661.69,399.724 1661.7,399.742 1661.71,399.76 1661.72,399.778 1661.73,399.796 1661.74,399.815 1661.75,399.833 1661.76,399.851 1661.77,399.869 1661.78,399.887 1661.79,399.905 1661.79,399.924 1661.8,399.942 1661.81,399.96 1661.82,399.978 1661.83,399.996 1661.84,400.014 1661.85,400.033 1661.86,400.051 1661.87,400.069 1661.88,400.087 1661.89,400.105 1661.9,400.123 1661.91,400.142 1661.91,400.16 1661.92,400.178 1661.93,400.196 1661.94,400.214 1661.95,400.232 1661.96,400.251 1661.97,400.269 1661.98,400.287 1661.99,400.305 1662,400.323 1662.01,400.341 1662.02,400.359 1662.02,400.378 1662.03,400.396 1662.04,400.414 1662.05,400.432 1662.06,400.45 1662.07,400.468 1662.08,400.486 1662.09,400.504 1662.1,400.523 1662.11,400.541 1662.12,400.559 1662.13,400.577 1662.13,400.595 1662.14,400.613 1662.15,400.631 1662.16,400.649 1662.17,400.668 1662.18,400.686 1662.19,400.704 1662.2,400.722 1662.21,400.74 1662.22,400.758 1662.23,400.776 1662.24,400.794 1662.25,400.813 1662.25,400.831 1662.26,400.849 1662.27,400.867 1662.28,400.885 1662.29,400.903 1662.3,400.921 1662.31,400.939 1662.32,400.957 1662.33,400.975 1662.34,400.994 1662.35,401.012 1662.36,401.03 1662.36,401.048 1662.37,401.066 1662.38,401.084 1662.39,401.102 1662.4,401.12 1662.41,401.138 1662.42,401.156 1662.43,401.174 1662.44,401.193 1662.45,401.211 1662.46,401.229 1662.47,401.247 1662.47,401.265 1662.48,401.283 1662.49,401.301 1662.5,401.319 1662.51,401.337 1662.52,401.355 1662.53,401.373 1662.54,401.391 1662.55,401.41 1662.56,401.428 1662.57,401.446 1662.58,401.464 1662.59,401.482 1662.59,401.5 1662.6,401.518 1662.61,401.536 1662.62,401.554 1662.63,401.572 1662.64,401.59 1662.65,401.608 1662.66,401.626 1662.67,401.644 1662.68,401.662 1662.69,401.68 1662.7,401.699 1662.7,401.717 1662.71,401.735 1662.72,401.753 1662.73,401.771 1662.74,401.789 1662.75,401.807 1662.76,401.825 1662.77,401.843 1662.78,401.861 1662.79,401.879 1662.8,401.897 1662.81,401.915 1662.81,401.933 1662.82,401.951 1662.83,401.969 1662.84,401.987 1662.85,402.005 1662.86,402.023 1662.87,402.041 1662.88,402.059 1662.89,402.077 1662.9,402.095 1662.91,402.113 1662.92,402.131 1662.93,402.149 1662.93,402.167 1662.94,402.186 1662.95,402.204 1662.96,402.222 1662.97,402.24 1662.98,402.258 1662.99,402.276 1663,402.294 1663.01,402.312 1663.02,402.33 1663.03,402.348 1663.04,402.366 1663.04,402.384 1663.05,402.402 1663.06,402.42 1663.07,402.438 1663.08,402.456 1663.09,402.474 1663.1,402.492 1663.11,402.51 1663.12,402.528 1663.13,402.546 1663.14,402.564 1663.15,402.582 1663.15,402.6 1663.16,402.618 1663.17,402.636 1663.18,402.654 1663.19,402.672 1663.2,402.69 1663.21,402.708 1663.22,402.726 1663.23,402.744 1663.24,402.762 1663.25,402.78 1663.26,402.798 1663.27,402.815 1663.27,402.833 1663.28,402.851 1663.29,402.869 1663.3,402.887 1663.31,402.905 1663.32,402.923 1663.33,402.941 1663.34,402.959 1663.35,402.977 1663.36,402.995 1663.37,403.013 1663.38,403.031 1663.38,403.049 1663.39,403.067 1663.4,403.085 1663.41,403.103 1663.42,403.121 1663.43,403.139 1663.44,403.157 1663.45,403.175 1663.46,403.193 1663.47,403.211 1663.48,403.229 1663.49,403.247 1663.49,403.265 1663.5,403.283 1663.51,403.301 1663.52,403.318 1663.53,403.336 1663.54,403.354 1663.55,403.372 1663.56,403.39 1663.57,403.408 1663.58,403.426 1663.59,403.444 1663.6,403.462 1663.61,403.48 1663.61,403.498 1663.62,403.516 1663.63,403.534 1663.64,403.552 1663.65,403.57 1663.66,403.588 1663.67,403.605 1663.68,403.623 1663.69,403.641 1663.7,403.659 1663.71,403.677 1663.72,403.695 1663.72,403.713 1663.73,403.731 1663.74,403.749 1663.75,403.767 1663.76,403.785 1663.77,403.803 1663.78,403.82 1663.79,403.838 1663.8,403.856 1663.81,403.874 1663.82,403.892 1663.83,403.91 1663.83,403.928 1663.84,403.946 1663.85,403.964 1663.86,403.982 1663.87,404 1663.88,404.017 1663.89,404.035 1663.9,404.053 1663.91,404.071 1663.92,404.089 1663.93,404.107 1663.94,404.125 1663.95,404.143 1663.95,404.161 1663.96,404.179 1663.97,404.196 1663.98,404.214 1663.99,404.232 1664,404.25 1664.01,404.268 1664.02,404.286 1664.03,404.304 1664.04,404.322 1664.05,404.339 1664.06,404.357 1664.06,404.375 1664.07,404.393 1664.08,404.411 1664.09,404.429 1664.1,404.447 1664.11,404.465 1664.12,404.482 1664.13,404.5 1664.14,404.518 1664.15,404.536 1664.16,404.554 1664.17,404.572 1664.17,404.59 1664.18,404.608 1664.19,404.625 1664.2,404.643 1664.21,404.661 1664.22,404.679 1664.23,404.697 1664.24,404.715 1664.25,404.733 1664.26,404.75 1664.27,404.768 1664.28,404.786 1664.29,404.804 1664.29,404.822 1664.3,404.84 1664.31,404.857 1664.32,404.875 1664.33,404.893 1664.34,404.911 1664.35,404.929 1664.36,404.947 1664.37,404.965 1664.38,404.982 1664.39,405 1664.4,405.018 1664.4,405.036 1664.41,405.054 1664.42,405.072 1664.43,405.089 1664.44,405.107 1664.45,405.125 1664.46,405.143 1664.47,405.161 1664.48,405.179 1664.49,405.196 1664.5,405.214 1664.51,405.232 1664.51,405.25 1664.52,405.268 1664.53,405.285 1664.54,405.303 1664.55,405.321 1664.56,405.339 1664.57,405.357 1664.58,405.375 1664.59,405.392 1664.6,405.41 1664.61,405.428 1664.62,405.446 1664.63,405.464 1664.63,405.481 1664.64,405.499 1664.65,405.517 1664.66,405.535 1664.67,405.553 1664.68,405.57 1664.69,405.588 1664.7,405.606 1664.71,405.624 1664.72,405.642 1664.73,405.659 1664.74,405.677 1664.74,405.695 1664.75,405.713 1664.76,405.731 1664.77,405.748 1664.78,405.766 1664.79,405.784 1664.8,405.802 1664.81,405.819 1664.82,405.837 1664.83,405.855 1664.84,405.873 1664.85,405.891 1664.85,405.908 1664.86,405.926 1664.87,405.944 1664.88,405.962 1664.89,405.979 1664.9,405.997 1664.91,406.015 1664.92,406.033 1664.93,406.051 1664.94,406.068 1664.95,406.086 1664.96,406.104 1664.97,406.122 1664.97,406.139 1664.98,406.157 1664.99,406.175 1665,406.193 1665.01,406.21 1665.02,406.228 1665.03,406.246 1665.04,406.264 1665.05,406.281 1665.06,406.299 1665.07,406.317 1665.08,406.335 1665.08,406.352 1665.09,406.37 1665.1,406.388 1665.11,406.406 1665.12,406.423 1665.13,406.441 1665.14,406.459 1665.15,406.477 1665.16,406.494 1665.17,406.512 1665.18,406.53 1665.19,406.548 1665.19,406.565 1665.2,406.583 1665.21,406.601 1665.22,406.618 1665.23,406.636 1665.24,406.654 1665.25,406.672 1665.26,406.689 1665.27,406.707 1665.28,406.725 1665.29,406.743 1665.3,406.76 1665.31,406.778 1665.31,406.796 1665.32,406.813 1665.33,406.831 1665.34,406.849 1665.35,406.867 1665.36,406.884 1665.37,406.902 1665.38,406.92 1665.39,406.937 1665.4,406.955 1665.41,406.973 1665.42,406.991 1665.42,407.008 1665.43,407.026 1665.44,407.044 1665.45,407.061 1665.46,407.079 1665.47,407.097 1665.48,407.114 1665.49,407.132 1665.5,407.15 1665.51,407.168 1665.52,407.185 1665.53,407.203 1665.53,407.221 1665.54,407.238 1665.55,407.256 1665.56,407.274 1665.57,407.291 1665.58,407.309 1665.59,407.327 1665.6,407.344 1665.61,407.362 1665.62,407.38 1665.63,407.398 1665.64,407.415 1665.65,407.433 1665.65,407.451 1665.66,407.468 1665.67,407.486 1665.68,407.504 1665.69,407.521 1665.7,407.539 1665.71,407.557 1665.72,407.574 1665.73,407.592 1665.74,407.61 1665.75,407.627 1665.76,407.645 1665.76,407.663 1665.77,407.68 1665.78,407.698 1665.79,407.716 1665.8,407.733 1665.81,407.751 1665.82,407.769 1665.83,407.786 1665.84,407.804 1665.85,407.821 1665.86,407.839 1665.87,407.857 1665.87,407.874 1665.88,407.892 1665.89,407.91 1665.9,407.927 1665.91,407.945 1665.92,407.963 1665.93,407.98 1665.94,407.998 1665.95,408.016 1665.96,408.033 1665.97,408.051 1665.98,408.068 1665.99,408.086 1665.99,408.104 1666,408.121 1666.01,408.139 1666.02,408.157 1666.03,408.174 1666.04,408.192 1666.05,408.21 1666.06,408.227 1666.07,408.245 1666.08,408.262 1666.09,408.28 1666.1,408.298 1666.1,408.315 1666.11,408.333 1666.12,408.351 1666.13,408.368 1666.14,408.386 1666.15,408.403 1666.16,408.421 1666.17,408.439 1666.18,408.456 1666.19,408.474 1666.2,408.491 1666.21,408.509 1666.21,408.527 1666.22,408.544 1666.23,408.562 1666.24,408.579 1666.25,408.597 1666.26,408.615 1666.27,408.632 1666.28,408.65 1666.29,408.667 1666.3,408.685 1666.31,408.703 1666.32,408.72 1666.33,408.738 1666.33,408.755 1666.34,408.773 1666.35,408.791 1666.36,408.808 1666.37,408.826 1666.38,408.843 1666.39,408.861 1666.4,408.879 1666.41,408.896 1666.42,408.914 1666.43,408.931 1666.44,408.949 1666.44,408.966 1666.45,408.984 1666.46,409.002 1666.47,409.019 1666.48,409.037 1666.49,409.054 1666.5,409.072 1666.51,409.089 1666.52,409.107 1666.53,409.125 1666.54,409.142 1666.55,409.16 1666.55,409.177 1666.56,409.195 1666.57,409.212 1666.58,409.23 1666.59,409.248 1666.6,409.265 1666.61,409.283 1666.62,409.3 1666.63,409.318 1666.64,409.335 1666.65,409.353 1666.66,409.37 1666.67,409.388 1666.67,409.406 1666.68,409.423 1666.69,409.441 1666.7,409.458 1666.71,409.476 1666.72,409.493 1666.73,409.511 1666.74,409.528 1666.75,409.546 1666.76,409.563 1666.77,409.581 1666.78,409.598 1666.78,409.616 1666.79,409.634 1666.8,409.651 1666.81,409.669 1666.82,409.686 1666.83,409.704 1666.84,409.721 1666.85,409.739 1666.86,409.756 1666.87,409.774 1666.88,409.791 1666.89,409.809 1666.89,409.826 1666.9,409.844 1666.91,409.861 1666.92,409.879 1666.93,409.896 1666.94,409.914 1666.95,409.931 1666.96,409.949 1666.97,409.966 1666.98,409.984 1666.99,410.002 1667,410.019 1667.01,410.037 1667.01,410.054 1667.02,410.072 1667.03,410.089 1667.04,410.107 1667.05,410.124 1667.06,410.142 1667.07,410.159 1667.08,410.177 1667.09,410.194 1667.1,410.212 1667.11,410.229 1667.12,410.247 1667.12,410.264 1667.13,410.282 1667.14,410.299 1667.15,410.317 1667.16,410.334 1667.17,410.351 1667.18,410.369 1667.19,410.386 1667.2,410.404 1667.21,410.421 1667.22,410.439 1667.23,410.456 1667.23,410.474 1667.24,410.491 1667.25,410.509 1667.26,410.526 1667.27,410.544 1667.28,410.561 1667.29,410.579 1667.3,410.596 1667.31,410.614 1667.32,410.631 1667.33,410.649 1667.34,410.666 1667.35,410.684 1667.35,410.701 1667.36,410.718 1667.37,410.736 1667.38,410.753 1667.39,410.771 1667.4,410.788 1667.41,410.806 1667.42,410.823 1667.43,410.841 1667.44,410.858 1667.45,410.876 1667.46,410.893 1667.46,410.911 1667.47,410.928 1667.48,410.945 1667.49,410.963 1667.5,410.98 1667.51,410.998 1667.52,411.015 1667.53,411.033 1667.54,411.05 1667.55,411.068 1667.56,411.085 1667.57,411.102 1667.57,411.12 1667.58,411.137 1667.59,411.155 1667.6,411.172 1667.61,411.19 1667.62,411.207 1667.63,411.224 1667.64,411.242 1667.65,411.259 1667.66,411.277 1667.67,411.294 1667.68,411.312 1667.69,411.329 1667.69,411.346 1667.7,411.364 1667.71,411.381 1667.72,411.399 1667.73,411.416 1667.74,411.434 1667.75,411.451 1667.76,411.468 1667.77,411.486 1667.78,411.503 1667.79,411.521 1667.8,411.538 1667.8,411.555 1667.81,411.573 1667.82,411.59 1667.83,411.608 1667.84,411.625 1667.85,411.642 1667.86,411.66 1667.87,411.677 1667.88,411.695 1667.89,411.712 1667.9,411.729 1667.91,411.747 1667.91,411.764 1667.92,411.782 1667.93,411.799 1667.94,411.816 1667.95,411.834 1667.96,411.851 1667.97,411.869 1667.98,411.886 1667.99,411.903 1668,411.921 1668.01,411.938 1668.02,411.956 1668.03,411.973 1668.03,411.99 1668.04,412.008 1668.05,412.025 1668.06,412.042 1668.07,412.06 1668.08,412.077 1668.09,412.095 1668.1,412.112 1668.11,412.129 1668.12,412.147 1668.13,412.164 1668.14,412.181 1668.14,412.199 1668.15,412.216 1668.16,412.234 1668.17,412.251 1668.18,412.268 1668.19,412.286 1668.2,412.303 1668.21,412.32 1668.22,412.338 1668.23,412.355 1668.24,412.372 1668.25,412.39 1668.25,412.407 1668.26,412.424 1668.27,412.442 1668.28,412.459 1668.29,412.477 1668.3,412.494 1668.31,412.511 1668.32,412.529 1668.33,412.546 1668.34,412.563 1668.35,412.581 1668.36,412.598 1668.37,412.615 1668.37,412.633 1668.38,412.65 1668.39,412.667 1668.4,412.685 1668.41,412.702 1668.42,412.719 1668.43,412.737 1668.44,412.754 1668.45,412.771 1668.46,412.789 1668.47,412.806 1668.48,412.823 1668.48,412.841 1668.49,412.858 1668.5,412.875 1668.51,412.893 1668.52,412.91 1668.53,412.927 1668.54,412.945 1668.55,412.962 1668.56,412.979 1668.57,412.997 1668.58,413.014 1668.59,413.031 1668.59,413.048 1668.6,413.066 1668.61,413.083 1668.62,413.1 1668.63,413.118 1668.64,413.135 1668.65,413.152 1668.66,413.17 1668.67,413.187 1668.68,413.204 1668.69,413.222 1668.7,413.239 1668.71,413.256 1668.71,413.273 1668.72,413.291 1668.73,413.308 1668.74,413.325 1668.75,413.343 1668.76,413.36 1668.77,413.377 1668.78,413.394 1668.79,413.412 1668.8,413.429 1668.81,413.446 1668.82,413.464 1668.82,413.481 1668.83,413.498 1668.84,413.515 1668.85,413.533 1668.86,413.55 1668.87,413.567 1668.88,413.585 1668.89,413.602 1668.9,413.619 1668.91,413.636 1668.92,413.654 1668.93,413.671 1668.93,413.688 1668.94,413.706 1668.95,413.723 1668.96,413.74 1668.97,413.757 1668.98,413.775 1668.99,413.792 1669,413.809 1669.01,413.826 1669.02,413.844 1669.03,413.861 1669.04,413.878 1669.05,413.895 1669.05,413.913 1669.06,413.93 1669.07,413.947 1669.08,413.964 1669.09,413.982 1669.1,413.999 1669.11,414.016 1669.12,414.033 1669.13,414.051 1669.14,414.068 1669.15,414.085 1669.16,414.102 1669.16,414.12 1669.17,414.137 1669.18,414.154 1669.19,414.171 1669.2,414.189 1669.21,414.206 1669.22,414.223 1669.23,414.24 1669.24,414.258 1669.25,414.275 1669.26,414.292 1669.27,414.309 1669.27,414.327 1669.28,414.344 1669.29,414.361 1669.3,414.378 1669.31,414.395 1669.32,414.413 1669.33,414.43 1669.34,414.447 1669.35,414.464 1669.36,414.482 1669.37,414.499 1669.38,414.516 1669.39,414.533 1669.39,414.55 1669.4,414.568 1669.41,414.585 1669.42,414.602 1669.43,414.619 1669.44,414.636 1669.45,414.654 1669.46,414.671 1669.47,414.688 1669.48,414.705 1669.49,414.723 1669.5,414.74 1669.5,414.757 1669.51,414.774 1669.52,414.791 1669.53,414.809 1669.54,414.826 1669.55,414.843 1669.56,414.86 1669.57,414.877 1669.58,414.895 1669.59,414.912 1669.6,414.929 1669.61,414.946 1669.61,414.963 1669.62,414.98 1669.63,414.998 1669.64,415.015 1669.65,415.032 1669.66,415.049 1669.67,415.066 1669.68,415.084 1669.69,415.101 1669.7,415.118 1669.71,415.135 1669.72,415.152 1669.73,415.169 1669.73,415.187 1669.74,415.204 1669.75,415.221 1669.76,415.238 1669.77,415.255 1669.78,415.273 1669.79,415.29 1669.8,415.307 1669.81,415.324 1669.82,415.341 1669.83,415.358 1669.84,415.375 1669.84,415.393 1669.85,415.41 1669.86,415.427 1669.87,415.444 1669.88,415.461 1669.89,415.478 1669.9,415.496 1669.91,415.513 1669.92,415.53 1669.93,415.547 1669.94,415.564 1669.95,415.581 1669.95,415.599 1669.96,415.616 1669.97,415.633 1669.98,415.65 1669.99,415.667 1670,415.684 1670.01,415.701 1670.02,415.719 1670.03,415.736 1670.04,415.753 1670.05,415.77 1670.06,415.787 1670.07,415.804 1670.07,415.821 1670.08,415.838 1670.09,415.856 1670.1,415.873 1670.11,415.89 1670.12,415.907 1670.13,415.924 1670.14,415.941 1670.15,415.958 1670.16,415.976 1670.17,415.993 1670.18,416.01 1670.18,416.027 1670.19,416.044 1670.2,416.061 1670.21,416.078 1670.22,416.095 1670.23,416.112 1670.24,416.13 1670.25,416.147 1670.26,416.164 1670.27,416.181 1670.28,416.198 1670.29,416.215 1670.29,416.232 1670.3,416.249 1670.31,416.266 1670.32,416.284 1670.33,416.301 1670.34,416.318 1670.35,416.335 1670.36,416.352 1670.37,416.369 1670.38,416.386 1670.39,416.403 1670.4,416.42 1670.41,416.437 1670.41,416.455 1670.42,416.472 1670.43,416.489 1670.44,416.506 1670.45,416.523 1670.46,416.54 1670.47,416.557 1670.48,416.574 1670.49,416.591 1670.5,416.608 1670.51,416.625 1670.52,416.642 1670.52,416.66 1670.53,416.677 1670.54,416.694 1670.55,416.711 1670.56,416.728 1670.57,416.745 1670.58,416.762 1670.59,416.779 1670.6,416.796 1670.61,416.813 1670.62,416.83 1670.63,416.847 1670.63,416.864 1670.64,416.882 1670.65,416.899 1670.66,416.916 1670.67,416.933 1670.68,416.95 1670.69,416.967 1670.7,416.984 1670.71,417.001 1670.72,417.018 1670.73,417.035 1670.74,417.052 1670.75,417.069 1670.75,417.086 1670.76,417.103 1670.77,417.12 1670.78,417.137 1670.79,417.154 1670.8,417.171 1670.81,417.189 1670.82,417.206 1670.83,417.223 1670.84,417.24 1670.85,417.257 1670.86,417.274 1670.86,417.291 1670.87,417.308 1670.88,417.325 1670.89,417.342 1670.9,417.359 1670.91,417.376 1670.92,417.393 1670.93,417.41 1670.94,417.427 1670.95,417.444 1670.96,417.461 1670.97,417.478 1670.97,417.495 1670.98,417.512 1670.99,417.529 1671,417.546 1671.01,417.563 1671.02,417.58 1671.03,417.597 1671.04,417.614 1671.05,417.631 1671.06,417.648 1671.07,417.665 1671.08,417.682 1671.09,417.699 1671.09,417.716 1671.1,417.733 1671.11,417.75 1671.12,417.767 1671.13,417.784 1671.14,417.801 1671.15,417.818 1671.16,417.835 1671.17,417.852 1671.18,417.869 1671.19,417.886 1671.2,417.903 1671.2,417.92 1671.21,417.937 1671.22,417.954 1671.23,417.971 1671.24,417.988 1671.25,418.005 1671.26,418.022 1671.27,418.039 1671.28,418.056 1671.29,418.073 1671.3,418.09 1671.31,418.107 1671.31,418.124 1671.32,418.141 1671.33,418.158 1671.34,418.175 1671.35,418.192 1671.36,418.209 1671.37,418.226 1671.38,418.243 1671.39,418.26 1671.4,418.277 1671.41,418.294 1671.42,418.311 1671.43,418.328 1671.43,418.345 1671.44,418.362 1671.45,418.379 1671.46,418.396 1671.47,418.413 1671.48,418.43 1671.49,418.447 1671.5,418.464 1671.51,418.481 1671.52,418.498 1671.53,418.515 1671.54,418.532 1671.54,418.549 1671.55,418.566 1671.56,418.583 1671.57,418.6 1671.58,418.616 1671.59,418.633 1671.6,418.65 1671.61,418.667 1671.62,418.684 1671.63,418.701 1671.64,418.718 1671.65,418.735 1671.65,418.752 1671.66,418.769 1671.67,418.786 1671.68,418.803 1671.69,418.82 1671.7,418.837 1671.71,418.854 1671.72,418.871 1671.73,418.888 1671.74,418.905 1671.75,418.921 1671.76,418.938 1671.77,418.955 1671.77,418.972 1671.78,418.989 1671.79,419.006 1671.8,419.023 1671.81,419.04 1671.82,419.057 1671.83,419.074 1671.84,419.091 1671.85,419.108 1671.86,419.125 1671.87,419.142 1671.88,419.158 1671.88,419.175 1671.89,419.192 1671.9,419.209 1671.91,419.226 1671.92,419.243 1671.93,419.26 1671.94,419.277 1671.95,419.294 1671.96,419.311 1671.97,419.328 1671.98,419.344 1671.99,419.361 1671.99,419.378 1672,419.395 1672.01,419.412 1672.02,419.429 1672.03,419.446 1672.04,419.463 1672.05,419.48 1672.06,419.497 1672.07,419.514 1672.08,419.53 1672.09,419.547 1672.1,419.564 1672.11,419.581 1672.11,419.598 1672.12,419.615 1672.13,419.632 1672.14,419.649 1672.15,419.666 1672.16,419.682 1672.17,419.699 1672.18,419.716 1672.19,419.733 1672.2,419.75 1672.21,419.767 1672.22,419.784 1672.22,419.801 1672.23,419.817 1672.24,419.834 1672.25,419.851 1672.26,419.868 1672.27,419.885 1672.28,419.902 1672.29,419.919 1672.3,419.936 1672.31,419.952 1672.32,419.969 1672.33,419.986 1672.33,420.003 1672.34,420.02 1672.35,420.037 1672.36,420.054 1672.37,420.07 1672.38,420.087 1672.39,420.104 1672.4,420.121 1672.41,420.138 1672.42,420.155 1672.43,420.172 1672.44,420.188 1672.45,420.205 1672.45,420.222 1672.46,420.239 1672.47,420.256 1672.48,420.273 1672.49,420.29 1672.5,420.306 1672.51,420.323 1672.52,420.34 1672.53,420.357 1672.54,420.374 1672.55,420.391 1672.56,420.407 1672.56,420.424 1672.57,420.441 1672.58,420.458 1672.59,420.475 1672.6,420.492 1672.61,420.509 1672.62,420.525 1672.63,420.542 1672.64,420.559 1672.65,420.576 1672.66,420.593 1672.67,420.609 1672.67,420.626 1672.68,420.643 1672.69,420.66 1672.7,420.677 1672.71,420.694 1672.72,420.71 1672.73,420.727 1672.74,420.744 1672.75,420.761 1672.76,420.778 1672.77,420.795 1672.78,420.811 1672.79,420.828 1672.79,420.845 1672.8,420.862 1672.81,420.879 1672.82,420.895 1672.83,420.912 1672.84,420.929 1672.85,420.946 1672.86,420.963 1672.87,420.979 1672.88,420.996 1672.89,421.013 1672.9,421.03 1672.9,421.047 1672.91,421.063 1672.92,421.08 1672.93,421.097 1672.94,421.114 1672.95,421.131 1672.96,421.147 1672.97,421.164 1672.98,421.181 1672.99,421.198 1673,421.215 1673.01,421.231 1673.01,421.248 1673.02,421.265 1673.03,421.282 1673.04,421.298 1673.05,421.315 1673.06,421.332 1673.07,421.349 1673.08,421.366 1673.09,421.382 1673.1,421.399 1673.11,421.416 1673.12,421.433 1673.13,421.449 1673.13,421.466 1673.14,421.483 1673.15,421.5 1673.16,421.517 1673.17,421.533 1673.18,421.55 1673.19,421.567 1673.2,421.584 1673.21,421.6 1673.22,421.617 1673.23,421.634 1673.24,421.651 1673.24,421.667 1673.25,421.684 1673.26,421.701 1673.27,421.718 1673.28,421.734 1673.29,421.751 1673.3,421.768 1673.31,421.785 1673.32,421.801 1673.33,421.818 1673.34,421.835 1673.35,421.852 1673.35,421.868 1673.36,421.885 1673.37,421.902 1673.38,421.919 1673.39,421.935 1673.4,421.952 1673.41,421.969 1673.42,421.986 1673.43,422.002 1673.44,422.019 1673.45,422.036 1673.46,422.053 1673.47,422.069 1673.47,422.086 1673.48,422.103 1673.49,422.12 1673.5,422.136 1673.51,422.153 1673.52,422.17 1673.53,422.186 1673.54,422.203 1673.55,422.22 1673.56,422.237 1673.57,422.253 1673.58,422.27 1673.58,422.287 1673.59,422.303 1673.6,422.32 1673.61,422.337 1673.62,422.354 1673.63,422.37 1673.64,422.387 1673.65,422.404 1673.66,422.42 1673.67,422.437 1673.68,422.454 1673.69,422.471 1673.69,422.487 1673.7,422.504 1673.71,422.521 1673.72,422.537 1673.73,422.554 1673.74,422.571 1673.75,422.588 1673.76,422.604 1673.77,422.621 1673.78,422.638 1673.79,422.654 1673.8,422.671 1673.81,422.688 1673.81,422.704 1673.82,422.721 1673.83,422.738 1673.84,422.754 1673.85,422.771 1673.86,422.788 1673.87,422.805 1673.88,422.821 1673.89,422.838 1673.9,422.855 1673.91,422.871 1673.92,422.888 1673.92,422.905 1673.93,422.921 1673.94,422.938 1673.95,422.955 1673.96,422.971 1673.97,422.988 1673.98,423.005 1673.99,423.021 1674,423.038 1674.01,423.055 1674.02,423.071 1674.03,423.088 1674.03,423.105 1674.04,423.121 1674.05,423.138 1674.06,423.155 1674.07,423.171 1674.08,423.188 1674.09,423.205 1674.1,423.221 1674.11,423.238 1674.12,423.255 1674.13,423.271 1674.14,423.288 1674.15,423.305 1674.15,423.321 1674.16,423.338 1674.17,423.355 1674.18,423.371 1674.19,423.388 1674.2,423.405 1674.21,423.421 1674.22,423.438 1674.23,423.454 1674.24,423.471 1674.25,423.488 1674.26,423.504 1674.26,423.521 1674.27,423.538 1674.28,423.554 1674.29,423.571 1674.3,423.588 1674.31,423.604 1674.32,423.621 1674.33,423.637 1674.34,423.654 1674.35,423.671 1674.36,423.687 1674.37,423.704 1674.37,423.721 1674.38,423.737 1674.39,423.754 1674.4,423.771 1674.41,423.787 1674.42,423.804 1674.43,423.82 1674.44,423.837 1674.45,423.854 1674.46,423.87 1674.47,423.887 1674.48,423.903 1674.49,423.92 1674.49,423.937 1674.5,423.953 1674.51,423.97 1674.52,423.987 1674.53,424.003 1674.54,424.02 1674.55,424.036 1674.56,424.053 1674.57,424.07 1674.58,424.086 1674.59,424.103 1674.6,424.119 1674.6,424.136 1674.61,424.153 1674.62,424.169 1674.63,424.186 1674.64,424.202 1674.65,424.219 1674.66,424.236 1674.67,424.252 1674.68,424.269 1674.69,424.285 1674.7,424.302 1674.71,424.319 1674.71,424.335 1674.72,424.352 1674.73,424.368 1674.74,424.385 1674.75,424.401 1674.76,424.418 1674.77,424.435 1674.78,424.451 1674.79,424.468 1674.8,424.484 1674.81,424.501 1674.82,424.518 1674.83,424.534 1674.83,424.551 1674.84,424.567 1674.85,424.584 1674.86,424.6 1674.87,424.617 1674.88,424.634 1674.89,424.65 1674.9,424.667 1674.91,424.683 1674.92,424.7 1674.93,424.716 1674.94,424.733 1674.94,424.75 1674.95,424.766 1674.96,424.783 1674.97,424.799 1674.98,424.816 1674.99,424.832 1675,424.849 1675.01,424.865 1675.02,424.882 1675.03,424.899 1675.04,424.915 1675.05,424.932 1675.05,424.948 1675.06,424.965 1675.07,424.981 1675.08,424.998 1675.09,425.014 1675.1,425.031 1675.11,425.047 1675.12,425.064 1675.13,425.081 1675.14,425.097 1675.15,425.114 1675.16,425.13 1675.17,425.147 1675.17,425.163 1675.18,425.18 1675.19,425.196 1675.2,425.213 1675.21,425.229 1675.22,425.246 1675.23,425.262 1675.24,425.279 1675.25,425.296 1675.26,425.312 1675.27,425.329 1675.28,425.345 1675.28,425.362 1675.29,425.378 1675.3,425.395 1675.31,425.411 1675.32,425.428 1675.33,425.444 1675.34,425.461 1675.35,425.477 1675.36,425.494 1675.37,425.51 1675.38,425.527 1675.39,425.543 1675.39,425.56 1675.4,425.576 1675.41,425.593 1675.42,425.609 1675.43,425.626 1675.44,425.642 1675.45,425.659 1675.46,425.675 1675.47,425.692 1675.48,425.708 1675.49,425.725 1675.5,425.741 1675.51,425.758 1675.51,425.774 1675.52,425.791 1675.53,425.807 1675.54,425.824 1675.55,425.84 1675.56,425.857 1675.57,425.873 1675.58,425.89 1675.59,425.906 1675.6,425.923 1675.61,425.939 1675.62,425.956 1675.62,425.972 1675.63,425.989 1675.64,426.005 1675.65,426.022 1675.66,426.038 1675.67,426.055 1675.68,426.071 1675.69,426.088 1675.7,426.104 1675.71,426.121 1675.72,426.137 1675.73,426.154 1675.73,426.17 1675.74,426.186 1675.75,426.203 1675.76,426.219 1675.77,426.236 1675.78,426.252 1675.79,426.269 1675.8,426.285 1675.81,426.302 1675.82,426.318 1675.83,426.335 1675.84,426.351 1675.85,426.368 1675.85,426.384 1675.86,426.401 1675.87,426.417 1675.88,426.433 1675.89,426.45 1675.9,426.466 1675.91,426.483 1675.92,426.499 1675.93,426.516 1675.94,426.532 1675.95,426.549 1675.96,426.565 1675.96,426.581 1675.97,426.598 1675.98,426.614 1675.99,426.631 1676,426.647 1676.01,426.664 1676.02,426.68 1676.03,426.697 1676.04,426.713 1676.05,426.729 1676.06,426.746 1676.07,426.762 1676.07,426.779 1676.08,426.795 1676.09,426.812 1676.1,426.828 1676.11,426.844 1676.12,426.861 1676.13,426.877 1676.14,426.894 1676.15,426.91 1676.16,426.927 1676.17,426.943 1676.18,426.959 1676.19,426.976 1676.19,426.992 1676.2,427.009 1676.21,427.025 1676.22,427.042 1676.23,427.058 1676.24,427.074 1676.25,427.091 1676.26,427.107 1676.27,427.124 1676.28,427.14 1676.29,427.156 1676.3,427.173 1676.3,427.189 1676.31,427.206 1676.32,427.222 1676.33,427.239 1676.34,427.255 1676.35,427.271 1676.36,427.288 1676.37,427.304 1676.38,427.321 1676.39,427.337 1676.4,427.353 1676.41,427.37 1676.41,427.386 1676.42,427.402 1676.43,427.419 1676.44,427.435 1676.45,427.452 1676.46,427.468 1676.47,427.484 1676.48,427.501 1676.49,427.517 1676.5,427.534 1676.51,427.55 1676.52,427.566 1676.53,427.583 1676.53,427.599 1676.54,427.616 1676.55,427.632 1676.56,427.648 1676.57,427.665 1676.58,427.681 1676.59,427.697 1676.6,427.714 1676.61,427.73 1676.62,427.747 1676.63,427.763 1676.64,427.779 1676.64,427.796 1676.65,427.812 1676.66,427.828 1676.67,427.845 1676.68,427.861 1676.69,427.877 1676.7,427.894 1676.71,427.91 1676.72,427.927 1676.73,427.943 1676.74,427.959 1676.75,427.976 1676.75,427.992 1676.76,428.008 1676.77,428.025 1676.78,428.041 1676.79,428.057 1676.8,428.074 1676.81,428.09 1676.82,428.106 1676.83,428.123 1676.84,428.139 1676.85,428.156 1676.86,428.172 1676.87,428.188 1676.87,428.205 1676.88,428.221 1676.89,428.237 1676.9,428.254 1676.91,428.27 1676.92,428.286 1676.93,428.303 1676.94,428.319 1676.95,428.335 1676.96,428.352 1676.97,428.368 1676.98,428.384 1676.98,428.401 1676.99,428.417 1677,428.433 1677.01,428.45 1677.02,428.466 1677.03,428.482 1677.04,428.499 1677.05,428.515 1677.06,428.531 1677.07,428.548 1677.08,428.564 1677.09,428.58 1677.09,428.597 1677.1,428.613 1677.11,428.629 1677.12,428.645 1677.13,428.662 1677.14,428.678 1677.15,428.694 1677.16,428.711 1677.17,428.727 1677.18,428.743 1677.19,428.76 1677.2,428.776 1677.21,428.792 1677.21,428.809 1677.22,428.825 1677.23,428.841 1677.24,428.857 1677.25,428.874 1677.26,428.89 1677.27,428.906 1677.28,428.923 1677.29,428.939 1677.3,428.955 1677.31,428.972 1677.32,428.988 1677.32,429.004 1677.33,429.02 1677.34,429.037 1677.35,429.053 1677.36,429.069 1677.37,429.086 1677.38,429.102 1677.39,429.118 1677.4,429.134 1677.41,429.151 1677.42,429.167 1677.43,429.183 1677.43,429.2 1677.44,429.216 1677.45,429.232 1677.46,429.248 1677.47,429.265 1677.48,429.281 1677.49,429.297 1677.5,429.314 1677.51,429.33 1677.52,429.346 1677.53,429.362 1677.54,429.379 1677.55,429.395 1677.55,429.411 1677.56,429.427 1677.57,429.444 1677.58,429.46 1677.59,429.476 1677.6,429.492 1677.61,429.509 1677.62,429.525 1677.63,429.541 1677.64,429.558 1677.65,429.574 1677.66,429.59 1677.66,429.606 1677.67,429.623 1677.68,429.639 1677.69,429.655 1677.7,429.671 1677.71,429.688 1677.72,429.704 1677.73,429.72 1677.74,429.736 1677.75,429.753 1677.76,429.769 1677.77,429.785 1677.77,429.801 1677.78,429.818 1677.79,429.834 1677.8,429.85 1677.81,429.866 1677.82,429.882 1677.83,429.899 1677.84,429.915 1677.85,429.931 1677.86,429.947 1677.87,429.964 1677.88,429.98 1677.89,429.996 1677.89,430.012 1677.9,430.029 1677.91,430.045 1677.92,430.061 1677.93,430.077 1677.94,430.093 1677.95,430.11 1677.96,430.126 1677.97,430.142 1677.98,430.158 1677.99,430.175 1678,430.191 1678,430.207 1678.01,430.223 1678.02,430.239 1678.03,430.256 1678.04,430.272 1678.05,430.288 1678.06,430.304 1678.07,430.321 1678.08,430.337 1678.09,430.353 1678.1,430.369 1678.11,430.385 1678.11,430.402 1678.12,430.418 1678.13,430.434 1678.14,430.45 1678.15,430.466 1678.16,430.483 1678.17,430.499 1678.18,430.515 1678.19,430.531 1678.2,430.547 1678.21,430.564 1678.22,430.58 1678.23,430.596 1678.23,430.612 1678.24,430.628 1678.25,430.645 1678.26,430.661 1678.27,430.677 1678.28,430.693 1678.29,430.709 1678.3,430.725 1678.31,430.742 1678.32,430.758 1678.33,430.774 1678.34,430.79 1678.34,430.806 1678.35,430.823 1678.36,430.839 1678.37,430.855 1678.38,430.871 1678.39,430.887 1678.4,430.903 1678.41,430.92 1678.42,430.936 1678.43,430.952 1678.44,430.968 1678.45,430.984 1678.45,431 1678.46,431.017 1678.47,431.033 1678.48,431.049 1678.49,431.065 1678.5,431.081 1678.51,431.097 1678.52,431.114 1678.53,431.13 1678.54,431.146 1678.55,431.162 1678.56,431.178 1678.57,431.194 1678.57,431.211 1678.58,431.227 1678.59,431.243 1678.6,431.259 1678.61,431.275 1678.62,431.291 1678.63,431.307 1678.64,431.324 1678.65,431.34 1678.66,431.356 1678.67,431.372 1678.68,431.388 1678.68,431.404 1678.69,431.42 1678.7,431.437 1678.71,431.453 1678.72,431.469 1678.73,431.485 1678.74,431.501 1678.75,431.517 1678.76,431.533 1678.77,431.55 1678.78,431.566 1678.79,431.582 1678.8,431.598 1678.8,431.614 1678.81,431.63 1678.82,431.646 1678.83,431.662 1678.84,431.679 1678.85,431.695 1678.86,431.711 1678.87,431.727 1678.88,431.743 1678.89,431.759 1678.9,431.775 1678.91,431.791 1678.91,431.808 1678.92,431.824 1678.93,431.84 1678.94,431.856 1678.95,431.872 1678.96,431.888 1678.97,431.904 1678.98,431.92 1678.99,431.936 1679,431.953 1679.01,431.969 1679.02,431.985 1679.02,432.001 1679.03,432.017 1679.04,432.033 1679.05,432.049 1679.06,432.065 1679.07,432.081 1679.08,432.097 1679.09,432.114 1679.1,432.13 1679.11,432.146 1679.12,432.162 1679.13,432.178 1679.14,432.194 1679.14,432.21 1679.15,432.226 1679.16,432.242 1679.17,432.258 1679.18,432.274 1679.19,432.291 1679.2,432.307 1679.21,432.323 1679.22,432.339 1679.23,432.355 1679.24,432.371 1679.25,432.387 1679.25,432.403 1679.26,432.419 1679.27,432.435 1679.28,432.451 1679.29,432.467 1679.3,432.484 1679.31,432.5 1679.32,432.516 1679.33,432.532 1679.34,432.548 1679.35,432.564 1679.36,432.58 1679.36,432.596 1679.37,432.612 1679.38,432.628 1679.39,432.644 1679.4,432.66 1679.41,432.676 1679.42,432.692 1679.43,432.708 1679.44,432.725 1679.45,432.741 1679.46,432.757 1679.47,432.773 1679.48,432.789 1679.48,432.805 1679.49,432.821 1679.5,432.837 1679.51,432.853 1679.52,432.869 1679.53,432.885 1679.54,432.901 1679.55,432.917 1679.56,432.933 1679.57,432.949 1679.58,432.965 1679.59,432.981 1679.59,432.997 1679.6,433.013 1679.61,433.029 1679.62,433.046 1679.63,433.062 1679.64,433.078 1679.65,433.094 1679.66,433.11 1679.67,433.126 1679.68,433.142 1679.69,433.158 1679.7,433.174 1679.7,433.19 1679.71,433.206 1679.72,433.222 1679.73,433.238 1679.74,433.254 1679.75,433.27 1679.76,433.286 1679.77,433.302 1679.78,433.318 1679.79,433.334 1679.8,433.35 1679.81,433.366 1679.82,433.382 1679.82,433.398 1679.83,433.414 1679.84,433.43 1679.85,433.446 1679.86,433.462 1679.87,433.478 1679.88,433.494 1679.89,433.51 1679.9,433.526 1679.91,433.542 1679.92,433.558 1679.93,433.574 1679.93,433.59 1679.94,433.606 1679.95,433.622 1679.96,433.638 1679.97,433.654 1679.98,433.67 1679.99,433.686 1680,433.702 1680.01,433.718 1680.02,433.734 1680.03,433.75 1680.04,433.766 1680.04,433.782 1680.05,433.798 1680.06,433.814 1680.07,433.83 1680.08,433.846 1680.09,433.862 1680.1,433.878 1680.11,433.894 1680.12,433.91 1680.13,433.926 1680.14,433.942 1680.15,433.958 1680.16,433.974 1680.16,433.99 1680.17,434.006 1680.18,434.022 1680.19,434.038 1680.2,434.054 1680.21,434.07 1680.22,434.086 1680.23,434.102 1680.24,434.118 1680.25,434.134 1680.26,434.15 1680.27,434.166 1680.27,434.182 1680.28,434.198 1680.29,434.214 1680.3,434.23 1680.31,434.246 1680.32,434.262 1680.33,434.278 1680.34,434.294 1680.35,434.309 1680.36,434.325 1680.37,434.341 1680.38,434.357 1680.38,434.373 1680.39,434.389 1680.4,434.405 1680.41,434.421 1680.42,434.437 1680.43,434.453 1680.44,434.469 1680.45,434.485 1680.46,434.501 1680.47,434.517 1680.48,434.533 1680.49,434.549 1680.5,434.565 1680.5,434.581 1680.51,434.597 1680.52,434.613 1680.53,434.628 1680.54,434.644 1680.55,434.66 1680.56,434.676 1680.57,434.692 1680.58,434.708 1680.59,434.724 1680.6,434.74 1680.61,434.756 1680.61,434.772 1680.62,434.788 1680.63,434.804 1680.64,434.82 1680.65,434.836 1680.66,434.852 1680.67,434.867 1680.68,434.883 1680.69,434.899 1680.7,434.915 1680.71,434.931 1680.72,434.947 1680.72,434.963 1680.73,434.979 1680.74,434.995 1680.75,435.011 1680.76,435.027 1680.77,435.043 1680.78,435.058 1680.79,435.074 1680.8,435.09 1680.81,435.106 1680.82,435.122 1680.83,435.138 1680.84,435.154 1680.84,435.17 1680.85,435.186 1680.86,435.202 1680.87,435.218 1680.88,435.233 1680.89,435.249 1680.9,435.265 1680.91,435.281 1680.92,435.297 1680.93,435.313 1680.94,435.329 1680.95,435.345 1680.95,435.361 1680.96,435.377 1680.97,435.392 1680.98,435.408 1680.99,435.424 1681,435.44 1681.01,435.456 1681.02,435.472 1681.03,435.488 1681.04,435.504 1681.05,435.52 1681.06,435.535 1681.06,435.551 1681.07,435.567 1681.08,435.583 1681.09,435.599 1681.1,435.615 1681.11,435.631 1681.12,435.647 1681.13,435.662 1681.14,435.678 1681.15,435.694 1681.16,435.71 1681.17,435.726 1681.18,435.742 1681.18,435.758 1681.19,435.774 1681.2,435.789 1681.21,435.805 1681.22,435.821 1681.23,435.837 1681.24,435.853 1681.25,435.869 1681.26,435.885 1681.27,435.9 1681.28,435.916 1681.29,435.932 1681.29,435.948 1681.3,435.964 1681.31,435.98 1681.32,435.996 1681.33,436.011 1681.34,436.027 1681.35,436.043 1681.36,436.059 1681.37,436.075 1681.38,436.091 1681.39,436.107 1681.4,436.122 1681.4,436.138 1681.41,436.154 1681.42,436.17 1681.43,436.186 1681.44,436.202 1681.45,436.218 1681.46,436.233 1681.47,436.249 1681.48,436.265 1681.49,436.281 1681.5,436.297 1681.51,436.313 1681.52,436.328 1681.52,436.344 1681.53,436.36 1681.54,436.376 1681.55,436.392 1681.56,436.408 1681.57,436.423 1681.58,436.439 1681.59,436.455 1681.6,436.471 1681.61,436.487 1681.62,436.502 1681.63,436.518 1681.63,436.534 1681.64,436.55 1681.65,436.566 1681.66,436.582 1681.67,436.597 1681.68,436.613 1681.69,436.629 1681.7,436.645 1681.71,436.661 1681.72,436.676 1681.73,436.692 1681.74,436.708 1681.74,436.724 1681.75,436.74 1681.76,436.756 1681.77,436.771 1681.78,436.787 1681.79,436.803 1681.8,436.819 1681.81,436.835 1681.82,436.85 1681.83,436.866 1681.84,436.882 1681.85,436.898 1681.86,436.914 1681.86,436.929 1681.87,436.945 1681.88,436.961 1681.89,436.977 1681.9,436.993 1681.91,437.008 1681.92,437.024 1681.93,437.04 1681.94,437.056 1681.95,437.071 1681.96,437.087 1681.97,437.103 1681.97,437.119 1681.98,437.135 1681.99,437.15 1682,437.166 1682.01,437.182 1682.02,437.198 1682.03,437.214 1682.04,437.229 1682.05,437.245 1682.06,437.261 1682.07,437.277 1682.08,437.292 1682.08,437.308 1682.09,437.324 1682.1,437.34 1682.11,437.356 1682.12,437.371 1682.13,437.387 1682.14,437.403 1682.15,437.419 1682.16,437.434 1682.17,437.45 1682.18,437.466 1682.19,437.482 1682.2,437.497 1682.2,437.513 1682.21,437.529 1682.22,437.545 1682.23,437.56 1682.24,437.576 1682.25,437.592 1682.26,437.608 1682.27,437.623 1682.28,437.639 1682.29,437.655 1682.3,437.671 1682.31,437.686 1682.31,437.702 1682.32,437.718 1682.33,437.734 1682.34,437.749 1682.35,437.765 1682.36,437.781 1682.37,437.797 1682.38,437.812 1682.39,437.828 1682.4,437.844 1682.41,437.86 1682.42,437.875 1682.42,437.891 1682.43,437.907 1682.44,437.923 1682.45,437.938 1682.46,437.954 1682.47,437.97 1682.48,437.986 1682.49,438.001 1682.5,438.017 1682.51,438.033 1682.52,438.048 1682.53,438.064 1682.54,438.08 1682.54,438.096 1682.55,438.111 1682.56,438.127 1682.57,438.143 1682.58,438.159 1682.59,438.174 1682.6,438.19 1682.61,438.206 1682.62,438.221 1682.63,438.237 1682.64,438.253 1682.65,438.269 1682.65,438.284 1682.66,438.3 1682.67,438.316 1682.68,438.331 1682.69,438.347 1682.7,438.363 1682.71,438.379 1682.72,438.394 1682.73,438.41 1682.74,438.426 1682.75,438.441 1682.76,438.457 1682.76,438.473 1682.77,438.488 1682.78,438.504 1682.79,438.52 1682.8,438.536 1682.81,438.551 1682.82,438.567 1682.83,438.583 1682.84,438.598 1682.85,438.614 1682.86,438.63 1682.87,438.645 1682.88,438.661 1682.88,438.677 1682.89,438.692 1682.9,438.708 1682.91,438.724 1682.92,438.739 1682.93,438.755 1682.94,438.771 1682.95,438.787 1682.96,438.802 1682.97,438.818 1682.98,438.834 1682.99,438.849 1682.99,438.865 1683,438.881 1683.01,438.896 1683.02,438.912 1683.03,438.928 1683.04,438.943 1683.05,438.959 1683.06,438.975 1683.07,438.99 1683.08,439.006 1683.09,439.022 1683.1,439.037 1683.1,439.053 1683.11,439.069 1683.12,439.084 1683.13,439.1 1683.14,439.116 1683.15,439.131 1683.16,439.147 1683.17,439.163 1683.18,439.178 1683.19,439.194 1683.2,439.21 1683.21,439.225 1683.22,439.241 1683.22,439.257 1683.23,439.272 1683.24,439.288 1683.25,439.304 1683.26,439.319 1683.27,439.335 1683.28,439.35 1683.29,439.366 1683.3,439.382 1683.31,439.397 1683.32,439.413 1683.33,439.429 1683.33,439.444 1683.34,439.46 1683.35,439.476 1683.36,439.491 1683.37,439.507 1683.38,439.523 1683.39,439.538 1683.4,439.554 1683.41,439.569 1683.42,439.585 1683.43,439.601 1683.44,439.616 1683.44,439.632 1683.45,439.648 1683.46,439.663 1683.47,439.679 1683.48,439.694 1683.49,439.71 1683.5,439.726 1683.51,439.741 1683.52,439.757 1683.53,439.773 1683.54,439.788 1683.55,439.804 1683.56,439.819 1683.56,439.835 1683.57,439.851 1683.58,439.866 1683.59,439.882 1683.6,439.897 1683.61,439.913 1683.62,439.929 1683.63,439.944 1683.64,439.96 1683.65,439.976 1683.66,439.991 1683.67,440.007 1683.67,440.022 1683.68,440.038 1683.69,440.054 1683.7,440.069 1683.71,440.085 1683.72,440.1 1683.73,440.116 1683.74,440.132 1683.75,440.147 1683.76,440.163 1683.77,440.178 1683.78,440.194 1683.78,440.21 1683.79,440.225 1683.8,440.241 1683.81,440.256 1683.82,440.272 1683.83,440.287 1683.84,440.303 1683.85,440.319 1683.86,440.334 1683.87,440.35 1683.88,440.365 1683.89,440.381 1683.9,440.397 1683.9,440.412 1683.91,440.428 1683.92,440.443 1683.93,440.459 1683.94,440.474 1683.95,440.49 1683.96,440.506 1683.97,440.521 1683.98,440.537 1683.99,440.552 1684,440.568 1684.01,440.584 1684.01,440.599 1684.02,440.615 1684.03,440.63 1684.04,440.646 1684.05,440.661 1684.06,440.677 1684.07,440.692 1684.08,440.708 1684.09,440.724 1684.1,440.739 1684.11,440.755 1684.12,440.77 1684.12,440.786 1684.13,440.801 1684.14,440.817 1684.15,440.833 1684.16,440.848 1684.17,440.864 1684.18,440.879 1684.19,440.895 1684.2,440.91 1684.21,440.926 1684.22,440.941 1684.23,440.957 1684.24,440.972 1684.24,440.988 1684.25,441.004 1684.26,441.019 1684.27,441.035 1684.28,441.05 1684.29,441.066 1684.3,441.081 1684.31,441.097 1684.32,441.112 1684.33,441.128 1684.34,441.143 1684.35,441.159 1684.35,441.174 1684.36,441.19 1684.37,441.206 1684.38,441.221 1684.39,441.237 1684.4,441.252 1684.41,441.268 1684.42,441.283 1684.43,441.299 1684.44,441.314 1684.45,441.33 1684.46,441.345 1684.46,441.361 1684.47,441.376 1684.48,441.392 1684.49,441.407 1684.5,441.423 1684.51,441.438 1684.52,441.454 1684.53,441.469 1684.54,441.485 1684.55,441.5 1684.56,441.516 1684.57,441.532 1684.58,441.547 1684.58,441.563 1684.59,441.578 1684.6,441.594 1684.61,441.609 1684.62,441.625 1684.63,441.64 1684.64,441.656 1684.65,441.671 1684.66,441.687 1684.67,441.702 1684.68,441.718 1684.69,441.733 1684.69,441.749 1684.7,441.764 1684.71,441.78 1684.72,441.795 1684.73,441.811 1684.74,441.826 1684.75,441.842 1684.76,441.857 1684.77,441.873 1684.78,441.888 1684.79,441.904 1684.8,441.919 1684.8,441.934 1684.81,441.95 1684.82,441.965 1684.83,441.981 1684.84,441.996 1684.85,442.012 1684.86,442.027 1684.87,442.043 1684.88,442.058 1684.89,442.074 1684.9,442.089 1684.91,442.105 1684.92,442.12 1684.92,442.136 1684.93,442.151 1684.94,442.167 1684.95,442.182 1684.96,442.198 1684.97,442.213 1684.98,442.229 1684.99,442.244 1685,442.26 1685.01,442.275 1685.02,442.29 1685.03,442.306 1685.03,442.321 1685.04,442.337 1685.05,442.352 1685.06,442.368 1685.07,442.383 1685.08,442.399 1685.09,442.414 1685.1,442.43 1685.11,442.445 1685.12,442.46 1685.13,442.476 1685.14,442.491 1685.14,442.507 1685.15,442.522 1685.16,442.538 1685.17,442.553 1685.18,442.569 1685.19,442.584 1685.2,442.6 1685.21,442.615 1685.22,442.63 1685.23,442.646 1685.24,442.661 1685.25,442.677 1685.26,442.692 1685.26,442.708 1685.27,442.723 1685.28,442.739 1685.29,442.754 1685.3,442.769 1685.31,442.785 1685.32,442.8 1685.33,442.816 1685.34,442.831 1685.35,442.847 1685.36,442.862 1685.37,442.877 1685.37,442.893 1685.38,442.908 1685.39,442.924 1685.4,442.939 1685.41,442.955 1685.42,442.97 1685.43,442.985 1685.44,443.001 1685.45,443.016 1685.46,443.032 1685.47,443.047 1685.48,443.063 1685.48,443.078 1685.49,443.093 1685.5,443.109 1685.51,443.124 1685.52,443.14 1685.53,443.155 1685.54,443.17 1685.55,443.186 1685.56,443.201 1685.57,443.217 1685.58,443.232 1685.59,443.247 1685.6,443.263 1685.6,443.278 1685.61,443.294 1685.62,443.309 1685.63,443.324 1685.64,443.34 1685.65,443.355 1685.66,443.371 1685.67,443.386 1685.68,443.401 1685.69,443.417 1685.7,443.432 1685.71,443.448 1685.71,443.463 1685.72,443.478 1685.73,443.494 1685.74,443.509 1685.75,443.525 1685.76,443.54 1685.77,443.555 1685.78,443.571 1685.79,443.586 1685.8,443.602 1685.81,443.617 1685.82,443.632 1685.82,443.648 1685.83,443.663 1685.84,443.678 1685.85,443.694 1685.86,443.709 1685.87,443.725 1685.88,443.74 1685.89,443.755 1685.9,443.771 1685.91,443.786 1685.92,443.801 1685.93,443.817 1685.94,443.832 1685.94,443.848 1685.95,443.863 1685.96,443.878 1685.97,443.894 1685.98,443.909 1685.99,443.924 1686,443.94 1686.01,443.955 1686.02,443.97 1686.03,443.986 1686.04,444.001 1686.05,444.017 1686.05,444.032 1686.06,444.047 1686.07,444.063 1686.08,444.078 1686.09,444.093 1686.1,444.109 1686.11,444.124 1686.12,444.139 1686.13,444.155 1686.14,444.17 1686.15,444.185 1686.16,444.201 1686.16,444.216 1686.17,444.232 1686.18,444.247 1686.19,444.262 1686.2,444.278 1686.21,444.293 1686.22,444.308 1686.23,444.324 1686.24,444.339 1686.25,444.354 1686.26,444.37 1686.27,444.385 1686.28,444.4 1686.28,444.416 1686.29,444.431 1686.3,444.446 1686.31,444.462 1686.32,444.477 1686.33,444.492 1686.34,444.508 1686.35,444.523 1686.36,444.538 1686.37,444.554 1686.38,444.569 1686.39,444.584 1686.39,444.6 1686.4,444.615 1686.41,444.63 1686.42,444.646 1686.43,444.661 1686.44,444.676 1686.45,444.691 1686.46,444.707 1686.47,444.722 1686.48,444.737 1686.49,444.753 1686.5,444.768 1686.5,444.783 1686.51,444.799 1686.52,444.814 1686.53,444.829 1686.54,444.845 1686.55,444.86 1686.56,444.875 1686.57,444.891 1686.58,444.906 1686.59,444.921 1686.6,444.936 1686.61,444.952 1686.62,444.967 1686.62,444.982 1686.63,444.998 1686.64,445.013 1686.65,445.028 1686.66,445.044 1686.67,445.059 1686.68,445.074 1686.69,445.089 1686.7,445.105 1686.71,445.12 1686.72,445.135 1686.73,445.151 1686.73,445.166 1686.74,445.181 1686.75,445.196 1686.76,445.212 1686.77,445.227 1686.78,445.242 1686.79,445.258 1686.8,445.273 1686.81,445.288 1686.82,445.303 1686.83,445.319 1686.84,445.334 1686.84,445.349 1686.85,445.365 1686.86,445.38 1686.87,445.395 1686.88,445.41 1686.89,445.426 1686.9,445.441 1686.91,445.456 1686.92,445.471 1686.93,445.487 1686.94,445.502 1686.95,445.517 1686.96,445.533 1686.96,445.548 1686.97,445.563 1686.98,445.578 1686.99,445.594 1687,445.609 1687.01,445.624 1687.02,445.639 1687.03,445.655 1687.04,445.67 1687.05,445.685 1687.06,445.7 1687.07,445.716 1687.07,445.731 1687.08,445.746 1687.09,445.761 1687.1,445.777 1687.11,445.792 1687.12,445.807 1687.13,445.822 1687.14,445.838 1687.15,445.853 1687.16,445.868 1687.17,445.883 1687.18,445.899 1687.18,445.914 1687.19,445.929 1687.2,445.944 1687.21,445.96 1687.22,445.975 1687.23,445.99 1687.24,446.005 1687.25,446.021 1687.26,446.036 1687.27,446.051 1687.28,446.066 1687.29,446.081 1687.3,446.097 1687.3,446.112 1687.31,446.127 1687.32,446.142 1687.33,446.158 1687.34,446.173 1687.35,446.188 1687.36,446.203 1687.37,446.219 1687.38,446.234 1687.39,446.249 1687.4,446.264 1687.41,446.279 1687.41,446.295 1687.42,446.31 1687.43,446.325 1687.44,446.34 1687.45,446.356 1687.46,446.371 1687.47,446.386 1687.48,446.401 1687.49,446.416 1687.5,446.432 1687.51,446.447 1687.52,446.462 1687.52,446.477 1687.53,446.492 1687.54,446.508 1687.55,446.523 1687.56,446.538 1687.57,446.553 1687.58,446.568 1687.59,446.584 1687.6,446.599 1687.61,446.614 1687.62,446.629 1687.63,446.644 1687.64,446.66 1687.64,446.675 1687.65,446.69 1687.66,446.705 1687.67,446.72 1687.68,446.736 1687.69,446.751 1687.7,446.766 1687.71,446.781 1687.72,446.796 1687.73,446.812 1687.74,446.827 1687.75,446.842 1687.75,446.857 1687.76,446.872 1687.77,446.888 1687.78,446.903 1687.79,446.918 1687.8,446.933 1687.81,446.948 1687.82,446.963 1687.83,446.979 1687.84,446.994 1687.85,447.009 1687.86,447.024 1687.86,447.039 1687.87,447.054 1687.88,447.07 1687.89,447.085 1687.9,447.1 1687.91,447.115 1687.92,447.13 1687.93,447.146 1687.94,447.161 1687.95,447.176 1687.96,447.191 1687.97,447.206 1687.98,447.221 1687.98,447.236 1687.99,447.252 1688,447.267 1688.01,447.282 1688.02,447.297 1688.03,447.312 1688.04,447.327 1688.05,447.343 1688.06,447.358 1688.07,447.373 1688.08,447.388 1688.09,447.403 1688.09,447.418 1688.1,447.434 1688.11,447.449 1688.12,447.464 1688.13,447.479 1688.14,447.494 1688.15,447.509 1688.16,447.524 1688.17,447.54 1688.18,447.555 1688.19,447.57 1688.2,447.585 1688.2,447.6 1688.21,447.615 1688.22,447.63 1688.23,447.646 1688.24,447.661 1688.25,447.676 1688.26,447.691 1688.27,447.706 1688.28,447.721 1688.29,447.736 1688.3,447.751 1688.31,447.767 1688.32,447.782 1688.32,447.797 1688.33,447.812 1688.34,447.827 1688.35,447.842 1688.36,447.857 1688.37,447.872 1688.38,447.888 1688.39,447.903 1688.4,447.918 1688.41,447.933 1688.42,447.948 1688.43,447.963 1688.43,447.978 1688.44,447.993 1688.45,448.009 1688.46,448.024 1688.47,448.039 1688.48,448.054 1688.49,448.069 1688.5,448.084 1688.51,448.099 1688.52,448.114 1688.53,448.129 1688.54,448.145 1688.54,448.16 1688.55,448.175 1688.56,448.19 1688.57,448.205 1688.58,448.22 1688.59,448.235 1688.6,448.25 1688.61,448.265 1688.62,448.28 1688.63,448.296 1688.64,448.311 1688.65,448.326 1688.66,448.341 1688.66,448.356 1688.67,448.371 1688.68,448.386 1688.69,448.401 1688.7,448.416 1688.71,448.431 1688.72,448.447 1688.73,448.462 1688.74,448.477 1688.75,448.492 1688.76,448.507 1688.77,448.522 1688.77,448.537 1688.78,448.552 1688.79,448.567 1688.8,448.582 1688.81,448.597 1688.82,448.612 1688.83,448.628 1688.84,448.643 1688.85,448.658 1688.86,448.673 1688.87,448.688 1688.88,448.703 1688.88,448.718 1688.89,448.733 1688.9,448.748 1688.91,448.763 1688.92,448.778 1688.93,448.793 1688.94,448.808 1688.95,448.823 1688.96,448.839 1688.97,448.854 1688.98,448.869 1688.99,448.884 1689,448.899 1689,448.914 1689.01,448.929 1689.02,448.944 1689.03,448.959 1689.04,448.974 1689.05,448.989 1689.06,449.004 1689.07,449.019 1689.08,449.034 1689.09,449.049 1689.1,449.064 1689.11,449.079 1689.11,449.094 1689.12,449.11 1689.13,449.125 1689.14,449.14 1689.15,449.155 1689.16,449.17 1689.17,449.185 1689.18,449.2 1689.19,449.215 1689.2,449.23 1689.21,449.245 1689.22,449.26 1689.22,449.275 1689.23,449.29 1689.24,449.305 1689.25,449.32 1689.26,449.335 1689.27,449.35 1689.28,449.365 1689.29,449.38 1689.3,449.395 1689.31,449.41 1689.32,449.425 1689.33,449.44 1689.34,449.455 1689.34,449.47 1689.35,449.485 1689.36,449.5 1689.37,449.516 1689.38,449.531 1689.39,449.546 1689.4,449.561 1689.41,449.576 1689.42,449.591 1689.43,449.606 1689.44,449.621 1689.45,449.636 1689.45,449.651 1689.46,449.666 1689.47,449.681 1689.48,449.696 1689.49,449.711 1689.5,449.726 1689.51,449.741 1689.52,449.756 1689.53,449.771 1689.54,449.786 1689.55,449.801 1689.56,449.816 1689.56,449.831 1689.57,449.846 1689.58,449.861 1689.59,449.876 1689.6,449.891 1689.61,449.906 1689.62,449.921 1689.63,449.936 1689.64,449.951 1689.65,449.966 1689.66,449.981 1689.67,449.996 1689.68,450.011 1689.68,450.026 1689.69,450.041 1689.7,450.056 1689.71,450.071 1689.72,450.086 1689.73,450.101 1689.74,450.116 1689.75,450.131 1689.76,450.146 1689.77,450.161 1689.78,450.176 1689.79,450.191 1689.79,450.206 1689.8,450.221 1689.81,450.236 1689.82,450.251 1689.83,450.266 1689.84,450.281 1689.85,450.296 1689.86,450.31 1689.87,450.325 1689.88,450.34 1689.89,450.355 1689.9,450.37 1689.9,450.385 1689.91,450.4 1689.92,450.415 1689.93,450.43 1689.94,450.445 1689.95,450.46 1689.96,450.475 1689.97,450.49 1689.98,450.505 1689.99,450.52 1690,450.535 1690.01,450.55 1690.02,450.565 1690.02,450.58 1690.03,450.595 1690.04,450.61 1690.05,450.625 1690.06,450.64 1690.07,450.655 1690.08,450.67 1690.09,450.685 1690.1,450.7 1690.11,450.715 1690.12,450.729 1690.13,450.744 1690.13,450.759 1690.14,450.774 1690.15,450.789 1690.16,450.804 1690.17,450.819 1690.18,450.834 1690.19,450.849 1690.2,450.864 1690.21,450.879 1690.22,450.894 1690.23,450.909 1690.24,450.924 1690.24,450.939 1690.25,450.954 1690.26,450.969 1690.27,450.983 1690.28,450.998 1690.29,451.013 1690.3,451.028 1690.31,451.043 1690.32,451.058 1690.33,451.073 1690.34,451.088 1690.35,451.103 1690.36,451.118 1690.36,451.133 1690.37,451.148 1690.38,451.163 1690.39,451.178 1690.4,451.192 1690.41,451.207 1690.42,451.222 1690.43,451.237 1690.44,451.252 1690.45,451.267 1690.46,451.282 1690.47,451.297 1690.47,451.312 1690.48,451.327 1690.49,451.342 1690.5,451.357 1690.51,451.371 1690.52,451.386 1690.53,451.401 1690.54,451.416 1690.55,451.431 1690.56,451.446 1690.57,451.461 1690.58,451.476 1690.58,451.491 1690.59,451.506 1690.6,451.521 1690.61,451.535 1690.62,451.55 1690.63,451.565 1690.64,451.58 1690.65,451.595 1690.66,451.61 1690.67,451.625 1690.68,451.64 1690.69,451.655 1690.7,451.67 1690.7,451.684 1690.71,451.699 1690.72,451.714 1690.73,451.729 1690.74,451.744 1690.75,451.759 1690.76,451.774 1690.77,451.789 1690.78,451.804 1690.79,451.818 1690.8,451.833 1690.81,451.848 1690.81,451.863 1690.82,451.878 1690.83,451.893 1690.84,451.908 1690.85,451.923 1690.86,451.937 1690.87,451.952 1690.88,451.967 1690.89,451.982 1690.9,451.997 1690.91,452.012 1690.92,452.027 1690.92,452.042 1690.93,452.056 1690.94,452.071 1690.95,452.086 1690.96,452.101 1690.97,452.116 1690.98,452.131 1690.99,452.146 1691,452.161 1691.01,452.175 1691.02,452.19 1691.03,452.205 1691.04,452.22 1691.04,452.235 1691.05,452.25 1691.06,452.265 1691.07,452.279 1691.08,452.294 1691.09,452.309 1691.1,452.324 1691.11,452.339 1691.12,452.354 1691.13,452.369 1691.14,452.383 1691.15,452.398 1691.15,452.413 1691.16,452.428 1691.17,452.443 1691.18,452.458 1691.19,452.472 1691.2,452.487 1691.21,452.502 1691.22,452.517 1691.23,452.532 1691.24,452.547 1691.25,452.562 1691.26,452.576 1691.26,452.591 1691.27,452.606 1691.28,452.621 1691.29,452.636 1691.3,452.651 1691.31,452.665 1691.32,452.68 1691.33,452.695 1691.34,452.71 1691.35,452.725 1691.36,452.74 1691.37,452.754 1691.38,452.769 1691.38,452.784 1691.39,452.799 1691.4,452.814 1691.41,452.828 1691.42,452.843 1691.43,452.858 1691.44,452.873 1691.45,452.888 1691.46,452.903 1691.47,452.917 1691.48,452.932 1691.49,452.947 1691.49,452.962 1691.5,452.977 1691.51,452.991 1691.52,453.006 1691.53,453.021 1691.54,453.036 1691.55,453.051 1691.56,453.066 1691.57,453.08 1691.58,453.095 1691.59,453.11 1691.6,453.125 1691.6,453.14 1691.61,453.154 1691.62,453.169 1691.63,453.184 1691.64,453.199 1691.65,453.214 1691.66,453.228 1691.67,453.243 1691.68,453.258 1691.69,453.273 1691.7,453.288 1691.71,453.302 1691.72,453.317 1691.72,453.332 1691.73,453.347 1691.74,453.362 1691.75,453.376 1691.76,453.391 1691.77,453.406 1691.78,453.421 1691.79,453.436 1691.8,453.45 1691.81,453.465 1691.82,453.48 1691.83,453.495 1691.83,453.509 1691.84,453.524 1691.85,453.539 1691.86,453.554 1691.87,453.569 1691.88,453.583 1691.89,453.598 1691.9,453.613 1691.91,453.628 1691.92,453.642 1691.93,453.657 1691.94,453.672 1691.94,453.687 1691.95,453.702 1691.96,453.716 1691.97,453.731 1691.98,453.746 1691.99,453.761 1692,453.775 1692.01,453.79 1692.02,453.805 1692.03,453.82 1692.04,453.834 1692.05,453.849 1692.06,453.864 1692.06,453.879 1692.07,453.893 1692.08,453.908 1692.09,453.923 1692.1,453.938 1692.11,453.953 1692.12,453.967 1692.13,453.982 1692.14,453.997 1692.15,454.012 1692.16,454.026 1692.17,454.041 1692.17,454.056 1692.18,454.071 1692.19,454.085 1692.2,454.1 1692.21,454.115 1692.22,454.13 1692.23,454.144 1692.24,454.159 1692.25,454.174 1692.26,454.188 1692.27,454.203 1692.28,454.218 1692.28,454.233 1692.29,454.247 1692.3,454.262 1692.31,454.277 1692.32,454.292 1692.33,454.306 1692.34,454.321 1692.35,454.336 1692.36,454.351 1692.37,454.365 1692.38,454.38 1692.39,454.395 1692.4,454.41 1692.4,454.424 1692.41,454.439 1692.42,454.454 1692.43,454.468 1692.44,454.483 1692.45,454.498 1692.46,454.513 1692.47,454.527 1692.48,454.542 1692.49,454.557 1692.5,454.571 1692.51,454.586 1692.51,454.601 1692.52,454.616 1692.53,454.63 1692.54,454.645 1692.55,454.66 1692.56,454.674 1692.57,454.689 1692.58,454.704 1692.59,454.719 1692.6,454.733 1692.61,454.748 1692.62,454.763 1692.62,454.777 1692.63,454.792 1692.64,454.807 1692.65,454.822 1692.66,454.836 1692.67,454.851 1692.68,454.866 1692.69,454.88 1692.7,454.895 1692.71,454.91 1692.72,454.924 1692.73,454.939 1692.74,454.954 1692.74,454.969 1692.75,454.983 1692.76,454.998 1692.77,455.013 1692.78,455.027 1692.79,455.042 1692.8,455.057 1692.81,455.071 1692.82,455.086 1692.83,455.101 1692.84,455.115 1692.85,455.13 1692.85,455.145 1692.86,455.16 1692.87,455.174 1692.88,455.189 1692.89,455.204 1692.9,455.218 1692.91,455.233 1692.92,455.248 1692.93,455.262 1692.94,455.277 1692.95,455.292 1692.96,455.306 1692.96,455.321 1692.97,455.336 1692.98,455.35 1692.99,455.365 1693,455.38 1693.01,455.394 1693.02,455.409 1693.03,455.424 1693.04,455.438 1693.05,455.453 1693.06,455.468 1693.07,455.482 1693.08,455.497 1693.08,455.512 1693.09,455.526 1693.1,455.541 1693.11,455.556 1693.12,455.57 1693.13,455.585 1693.14,455.6 1693.15,455.614 1693.16,455.629 1693.17,455.644 1693.18,455.658 1693.19,455.673 1693.19,455.688 1693.2,455.702 1693.21,455.717 1693.22,455.732 1693.23,455.746 1693.24,455.761 1693.25,455.775 1693.26,455.79 1693.27,455.805 1693.28,455.819 1693.29,455.834 1693.3,455.849 1693.3,455.863 1693.31,455.878 1693.32,455.893 1693.33,455.907 1693.34,455.922 1693.35,455.937 1693.36,455.951 1693.37,455.966 1693.38,455.98 1693.39,455.995 1693.4,456.01 1693.41,456.024 1693.42,456.039 1693.42,456.054 1693.43,456.068 1693.44,456.083 1693.45,456.097 1693.46,456.112 1693.47,456.127 1693.48,456.141 1693.49,456.156 1693.5,456.171 1693.51,456.185 1693.52,456.2 1693.53,456.214 1693.53,456.229 1693.54,456.244 1693.55,456.258 1693.56,456.273 1693.57,456.288 1693.58,456.302 1693.59,456.317 1693.6,456.331 1693.61,456.346 1693.62,456.361 1693.63,456.375 1693.64,456.39 1693.64,456.404 1693.65,456.419 1693.66,456.434 1693.67,456.448 1693.68,456.463 1693.69,456.477 1693.7,456.492 1693.71,456.507 1693.72,456.521 1693.73,456.536 1693.74,456.551 1693.75,456.565 1693.76,456.58 1693.76,456.594 1693.77,456.609 1693.78,456.623 1693.79,456.638 1693.8,456.653 1693.81,456.667 1693.82,456.682 1693.83,456.696 1693.84,456.711 1693.85,456.726 1693.86,456.74 1693.87,456.755 1693.87,456.769 1693.88,456.784 1693.89,456.799 1693.9,456.813 1693.91,456.828 1693.92,456.842 1693.93,456.857 1693.94,456.872 1693.95,456.886 1693.96,456.901 1693.97,456.915 1693.98,456.93 1693.98,456.944 1693.99,456.959 1694,456.974 1694.01,456.988 1694.02,457.003 1694.03,457.017 1694.04,457.032 1694.05,457.046 1694.06,457.061 1694.07,457.076 1694.08,457.09 1694.09,457.105 1694.1,457.119 1694.1,457.134 1694.11,457.148 1694.12,457.163 1694.13,457.178 1694.14,457.192 1694.15,457.207 1694.16,457.221 1694.17,457.236 1694.18,457.25 1694.19,457.265 1694.2,457.279 1694.21,457.294 1694.21,457.309 1694.22,457.323 1694.23,457.338 1694.24,457.352 1694.25,457.367 1694.26,457.381 1694.27,457.396 1694.28,457.41 1694.29,457.425 1694.3,457.44 1694.31,457.454 1694.32,457.469 1694.32,457.483 1694.33,457.498 1694.34,457.512 1694.35,457.527 1694.36,457.541 1694.37,457.556 1694.38,457.57 1694.39,457.585 1694.4,457.599 1694.41,457.614 1694.42,457.629 1694.43,457.643 1694.44,457.658 1694.44,457.672 1694.45,457.687 1694.46,457.701 1694.47,457.716 1694.48,457.73 1694.49,457.745 1694.5,457.759 1694.51,457.774 1694.52,457.788 1694.53,457.803 1694.54,457.817 1694.55,457.832 1694.55,457.846 1694.56,457.861 1694.57,457.876 1694.58,457.89 1694.59,457.905 1694.6,457.919 1694.61,457.934 1694.62,457.948 1694.63,457.963 1694.64,457.977 1694.65,457.992 1694.66,458.006 1694.66,458.021 1694.67,458.035 1694.68,458.05 1694.69,458.064 1694.7,458.079 1694.71,458.093 1694.72,458.108 1694.73,458.122 1694.74,458.137 1694.75,458.151 1694.76,458.166 1694.77,458.18 1694.78,458.195 1694.78,458.209 1694.79,458.224 1694.8,458.238 1694.81,458.253 1694.82,458.267 1694.83,458.282 1694.84,458.296 1694.85,458.311 1694.86,458.325 1694.87,458.34 1694.88,458.354 1694.89,458.369 1694.89,458.383 1694.9,458.398 1694.91,458.412 1694.92,458.427 1694.93,458.441 1694.94,458.456 1694.95,458.47 1694.96,458.485 1694.97,458.499 1694.98,458.514 1694.99,458.528 1695,458.543 1695,458.557 1695.01,458.572 1695.02,458.586 1695.03,458.601 1695.04,458.615 1695.05,458.629 1695.06,458.644 1695.07,458.658 1695.08,458.673 1695.09,458.687 1695.1,458.702 1695.11,458.716 1695.12,458.731 1695.12,458.745 1695.13,458.76 1695.14,458.774 1695.15,458.789 1695.16,458.803 1695.17,458.818 1695.18,458.832 1695.19,458.847 1695.2,458.861 1695.21,458.875 1695.22,458.89 1695.23,458.904 1695.23,458.919 1695.24,458.933 1695.25,458.948 1695.26,458.962 1695.27,458.977 1695.28,458.991 1695.29,459.006 1695.3,459.02 1695.31,459.034 1695.32,459.049 1695.33,459.063 1695.34,459.078 1695.34,459.092 1695.35,459.107 1695.36,459.121 1695.37,459.136 1695.38,459.15 1695.39,459.165 1695.4,459.179 1695.41,459.193 1695.42,459.208 1695.43,459.222 1695.44,459.237 1695.45,459.251 1695.46,459.266 1695.46,459.28 1695.47,459.294 1695.48,459.309 1695.49,459.323 1695.5,459.338 1695.51,459.352 1695.52,459.367 1695.53,459.381 1695.54,459.396 1695.55,459.41 1695.56,459.424 1695.57,459.439 1695.57,459.453 1695.58,459.468 1695.59,459.482 1695.6,459.497 1695.61,459.511 1695.62,459.525 1695.63,459.54 1695.64,459.554 1695.65,459.569 1695.66,459.583 1695.67,459.597 1695.68,459.612 1695.68,459.626 1695.69,459.641 1695.7,459.655 1695.71,459.67 1695.72,459.684 1695.73,459.698 1695.74,459.713 1695.75,459.727 1695.76,459.742 1695.77,459.756 1695.78,459.77 1695.79,459.785 1695.8,459.799 1695.8,459.814 1695.81,459.828 1695.82,459.842 1695.83,459.857 1695.84,459.871 1695.85,459.886 1695.86,459.9 1695.87,459.914 1695.88,459.929 1695.89,459.943 1695.9,459.958 1695.91,459.972 1695.91,459.986 1695.92,460.001 1695.93,460.015 1695.94,460.03 1695.95,460.044 1695.96,460.058 1695.97,460.073 1695.98,460.087 1695.99,460.102 1696,460.116 1696.01,460.13 1696.02,460.145 1696.02,460.159 1696.03,460.174 1696.04,460.188 1696.05,460.202 1696.06,460.217 1696.07,460.231 1696.08,460.245 1696.09,460.26 1696.1,460.274 1696.11,460.289 1696.12,460.303 1696.13,460.317 1696.14,460.332 1696.14,460.346 1696.15,460.36 1696.16,460.375 1696.17,460.389 1696.18,460.404 1696.19,460.418 1696.2,460.432 1696.21,460.447 1696.22,460.461 1696.23,460.475 1696.24,460.49 1696.25,460.504 1696.25,460.519 1696.26,460.533 1696.27,460.547 1696.28,460.562 1696.29,460.576 1696.3,460.59 1696.31,460.605 1696.32,460.619 1696.33,460.633 1696.34,460.648 1696.35,460.662 1696.36,460.677 1696.36,460.691 1696.37,460.705 1696.38,460.72 1696.39,460.734 1696.4,460.748 1696.41,460.763 1696.42,460.777 1696.43,460.791 1696.44,460.806 1696.45,460.82 1696.46,460.834 1696.47,460.849 1696.48,460.863 1696.48,460.877 1696.49,460.892 1696.5,460.906 1696.51,460.92 1696.52,460.935 1696.53,460.949 1696.54,460.963 1696.55,460.978 1696.56,460.992 1696.57,461.006 1696.58,461.021 1696.59,461.035 1696.59,461.049 1696.6,461.064 1696.61,461.078 1696.62,461.092 1696.63,461.107 1696.64,461.121 1696.65,461.135 1696.66,461.15 1696.67,461.164 1696.68,461.178 1696.69,461.193 1696.7,461.207 1696.7,461.221 1696.71,461.236 1696.72,461.25 1696.73,461.264 1696.74,461.279 1696.75,461.293 1696.76,461.307 1696.77,461.322 1696.78,461.336 1696.79,461.35 1696.8,461.365 1696.81,461.379 1696.82,461.393 1696.82,461.408 1696.83,461.422 1696.84,461.436 1696.85,461.45 1696.86,461.465 1696.87,461.479 1696.88,461.493 1696.89,461.508 1696.9,461.522 1696.91,461.536 1696.92,461.551 1696.93,461.565 1696.93,461.579 1696.94,461.593 1696.95,461.608 1696.96,461.622 1696.97,461.636 1696.98,461.651 1696.99,461.665 1697,461.679 1697.01,461.694 1697.02,461.708 1697.03,461.722 1697.04,461.736 1697.04,461.751 1697.05,461.765 1697.06,461.779 1697.07,461.794 1697.08,461.808 1697.09,461.822 1697.1,461.836 1697.11,461.851 1697.12,461.865 1697.13,461.879 1697.14,461.894 1697.15,461.908 1697.16,461.922 1697.16,461.936 1697.17,461.951 1697.18,461.965 1697.19,461.979 1697.2,461.994 1697.21,462.008 1697.22,462.022 1697.23,462.036 1697.24,462.051 1697.25,462.065 1697.26,462.079 1697.27,462.094 1697.27,462.108 1697.28,462.122 1697.29,462.136 1697.3,462.151 1697.31,462.165 1697.32,462.179 1697.33,462.193 1697.34,462.208 1697.35,462.222 1697.36,462.236 1697.37,462.25 1697.38,462.265 1697.38,462.279 1697.39,462.293 1697.4,462.307 1697.41,462.322 1697.42,462.336 1697.43,462.35 1697.44,462.365 1697.45,462.379 1697.46,462.393 1697.47,462.407 1697.48,462.422 1697.49,462.436 1697.5,462.45 1697.5,462.464 1697.51,462.479 1697.52,462.493 1697.53,462.507 1697.54,462.521 1697.55,462.536 1697.56,462.55 1697.57,462.564 1697.58,462.578 1697.59,462.592 1697.6,462.607 1697.61,462.621 1697.61,462.635 1697.62,462.649 1697.63,462.664 1697.64,462.678 1697.65,462.692 1697.66,462.706 1697.67,462.721 1697.68,462.735 1697.69,462.749 1697.7,462.763 1697.71,462.778 1697.72,462.792 1697.72,462.806 1697.73,462.82 1697.74,462.834 1697.75,462.849 1697.76,462.863 1697.77,462.877 1697.78,462.891 1697.79,462.906 1697.8,462.92 1697.81,462.934 1697.82,462.948 1697.83,462.962 1697.84,462.977 1697.84,462.991 1697.85,463.005 1697.86,463.019 1697.87,463.034 1697.88,463.048 1697.89,463.062 1697.9,463.076 1697.91,463.09 1697.92,463.105 1697.93,463.119 1697.94,463.133 1697.95,463.147 1697.95,463.161 1697.96,463.176 1697.97,463.19 1697.98,463.204 1697.99,463.218 1698,463.233 1698.01,463.247 1698.02,463.261 1698.03,463.275 1698.04,463.289 1698.05,463.304 1698.06,463.318 1698.06,463.332 1698.07,463.346 1698.08,463.36 1698.09,463.375 1698.1,463.389 1698.11,463.403 1698.12,463.417 1698.13,463.431 1698.14,463.445 1698.15,463.46 1698.16,463.474 1698.17,463.488 1698.18,463.502 1698.18,463.516 1698.19,463.531 1698.2,463.545 1698.21,463.559 1698.22,463.573 1698.23,463.587 1698.24,463.602 1698.25,463.616 1698.26,463.63 1698.27,463.644 1698.28,463.658 1698.29,463.672 1698.29,463.687 1698.3,463.701 1698.31,463.715 1698.32,463.729 1698.33,463.743 1698.34,463.758 1698.35,463.772 1698.36,463.786 1698.37,463.8 1698.38,463.814 1698.39,463.828 1698.4,463.843 1698.4,463.857 1698.41,463.871 1698.42,463.885 1698.43,463.899 1698.44,463.913 1698.45,463.928 1698.46,463.942 1698.47,463.956 1698.48,463.97 1698.49,463.984 1698.5,463.998 1698.51,464.012 1698.52,464.027 1698.52,464.041 1698.53,464.055 1698.54,464.069 1698.55,464.083 1698.56,464.097 1698.57,464.112 1698.58,464.126 1698.59,464.14 1698.6,464.154 1698.61,464.168 1698.62,464.182 1698.63,464.196 1698.63,464.211 1698.64,464.225 1698.65,464.239 1698.66,464.253 1698.67,464.267 1698.68,464.281 1698.69,464.295 1698.7,464.31 1698.71,464.324 1698.72,464.338 1698.73,464.352 1698.74,464.366 1698.74,464.38 1698.75,464.394 1698.76,464.409 1698.77,464.423 1698.78,464.437 1698.79,464.451 1698.8,464.465 1698.81,464.479 1698.82,464.493 1698.83,464.508 1698.84,464.522 1698.85,464.536 1698.86,464.55 1698.86,464.564 1698.87,464.578 1698.88,464.592 1698.89,464.606 1698.9,464.621 1698.91,464.635 1698.92,464.649 1698.93,464.663 1698.94,464.677 1698.95,464.691 1698.96,464.705 1698.97,464.719 1698.97,464.733 1698.98,464.748 1698.99,464.762 1699,464.776 1699.01,464.79 1699.02,464.804 1699.03,464.818 1699.04,464.832 1699.05,464.846 1699.06,464.861 1699.07,464.875 1699.08,464.889 1699.08,464.903 1699.09,464.917 1699.1,464.931 1699.11,464.945 1699.12,464.959 1699.13,464.973 1699.14,464.987 1699.15,465.002 1699.16,465.016 1699.17,465.03 1699.18,465.044 1699.19,465.058 1699.2,465.072 1699.2,465.086 1699.21,465.1 1699.22,465.114 1699.23,465.128 1699.24,465.143 1699.25,465.157 1699.26,465.171 1699.27,465.185 1699.28,465.199 1699.29,465.213 1699.3,465.227 1699.31,465.241 1699.31,465.255 1699.32,465.269 1699.33,465.283 1699.34,465.297 1699.35,465.312 1699.36,465.326 1699.37,465.34 1699.38,465.354 1699.39,465.368 1699.4,465.382 1699.41,465.396 1699.42,465.41 1699.42,465.424 1699.43,465.438 1699.44,465.452 1699.45,465.466 1699.46,465.48 1699.47,465.495 1699.48,465.509 1699.49,465.523 1699.5,465.537 1699.51,465.551 1699.52,465.565 1699.53,465.579 1699.54,465.593 1699.54,465.607 1699.55,465.621 1699.56,465.635 1699.57,465.649 1699.58,465.663 1699.59,465.677 1699.6,465.691 1699.61,465.706 1699.62,465.72 1699.63,465.734 1699.64,465.748 1699.65,465.762 1699.65,465.776 1699.66,465.79 1699.67,465.804 1699.68,465.818 1699.69,465.832 1699.7,465.846 1699.71,465.86 1699.72,465.874 1699.73,465.888 1699.74,465.902 1699.75,465.916 1699.76,465.93 1699.76,465.944 1699.77,465.958 1699.78,465.973 1699.79,465.987 1699.8,466.001 1699.81,466.015 1699.82,466.029 1699.83,466.043 1699.84,466.057 1699.85,466.071 1699.86,466.085 1699.87,466.099 1699.88,466.113 1699.88,466.127 1699.89,466.141 1699.9,466.155 1699.91,466.169 1699.92,466.183 1699.93,466.197 1699.94,466.211 1699.95,466.225 1699.96,466.239 1699.97,466.253 1699.98,466.267 1699.99,466.281 1699.99,466.295 1700,466.309 1700.01,466.323 1700.02,466.337 1700.03,466.351 1700.04,466.365 1700.05,466.379 1700.06,466.393 1700.07,466.407 1700.08,466.421 1700.09,466.436 1700.1,466.45 1700.1,466.464 1700.11,466.478 1700.12,466.492 1700.13,466.506 1700.14,466.52 1700.15,466.534 1700.16,466.548 1700.17,466.562 1700.18,466.576 1700.19,466.59 1700.2,466.604 1700.21,466.618 1700.22,466.632 1700.22,466.646 1700.23,466.66 1700.24,466.674 1700.25,466.688 1700.26,466.702 1700.27,466.716 1700.28,466.73 1700.29,466.744 1700.3,466.758 1700.31,466.772 1700.32,466.786 1700.33,466.8 1700.33,466.814 1700.34,466.828 1700.35,466.842 1700.36,466.856 1700.37,466.87 1700.38,466.884 1700.39,466.898 1700.4,466.912 1700.41,466.926 1700.42,466.94 1700.43,466.954 1700.44,466.968 1700.44,466.982 1700.45,466.996 1700.46,467.009 1700.47,467.023 1700.48,467.037 1700.49,467.051 1700.5,467.065 1700.51,467.079 1700.52,467.093 1700.53,467.107 1700.54,467.121 1700.55,467.135 1700.56,467.149 1700.56,467.163 1700.57,467.177 1700.58,467.191 1700.59,467.205 1700.6,467.219 1700.61,467.233 1700.62,467.247 1700.63,467.261 1700.64,467.275 1700.65,467.289 1700.66,467.303 1700.67,467.317 1700.67,467.331 1700.68,467.345 1700.69,467.359 1700.7,467.373 1700.71,467.387 1700.72,467.401 1700.73,467.415 1700.74,467.429 1700.75,467.443 1700.76,467.457 1700.77,467.47 1700.78,467.484 1700.78,467.498 1700.79,467.512 1700.8,467.526 1700.81,467.54 1700.82,467.554 1700.83,467.568 1700.84,467.582 1700.85,467.596 1700.86,467.61 1700.87,467.624 1700.88,467.638 1700.89,467.652 1700.9,467.666 1700.9,467.68 1700.91,467.694 1700.92,467.708 1700.93,467.722 1700.94,467.736 1700.95,467.749 1700.96,467.763 1700.97,467.777 1700.98,467.791 1700.99,467.805 1701,467.819 1701.01,467.833 1701.01,467.847 1701.02,467.861 1701.03,467.875 1701.04,467.889 1701.05,467.903 1701.06,467.917 1701.07,467.931 1701.08,467.945 1701.09,467.958 1701.1,467.972 1701.11,467.986 1701.12,468 1701.12,468.014 1701.13,468.028 1701.14,468.042 1701.15,468.056 1701.16,468.07 1701.17,468.084 1701.18,468.098 1701.19,468.112 1701.2,468.126 1701.21,468.139 1701.22,468.153 1701.23,468.167 1701.24,468.181 1701.24,468.195 1701.25,468.209 1701.26,468.223 1701.27,468.237 1701.28,468.251 1701.29,468.265 1701.3,468.279 1701.31,468.292 1701.32,468.306 1701.33,468.32 1701.34,468.334 1701.35,468.348 1701.35,468.362 1701.36,468.376 1701.37,468.39 1701.38,468.404 1701.39,468.418 1701.4,468.432 1701.41,468.445 1701.42,468.459 1701.43,468.473 1701.44,468.487 1701.45,468.501 1701.46,468.515 1701.46,468.529 1701.47,468.543 1701.48,468.557 1701.49,468.57 1701.5,468.584 1701.51,468.598 1701.52,468.612 1701.53,468.626 1701.54,468.64 1701.55,468.654 1701.56,468.668 1701.57,468.682 1701.58,468.695 1701.58,468.709 1701.59,468.723 1701.6,468.737 1701.61,468.751 1701.62,468.765 1701.63,468.779 1701.64,468.793 1701.65,468.807 1701.66,468.82 1701.67,468.834 1701.68,468.848 1701.69,468.862 1701.69,468.876 1701.7,468.89 1701.71,468.904 1701.72,468.918 1701.73,468.931 1701.74,468.945 1701.75,468.959 1701.76,468.973 1701.77,468.987 1701.78,469.001 1701.79,469.015 1701.8,469.028 1701.8,469.042 1701.81,469.056 1701.82,469.07 1701.83,469.084 1701.84,469.098 1701.85,469.112 1701.86,469.126 1701.87,469.139 1701.88,469.153 1701.89,469.167 1701.9,469.181 1701.91,469.195 1701.92,469.209 1701.92,469.223 1701.93,469.236 1701.94,469.25 1701.95,469.264 1701.96,469.278 1701.97,469.292 1701.98,469.306 1701.99,469.319 1702,469.333 1702.01,469.347 1702.02,469.361 1702.03,469.375 1702.03,469.389 1702.04,469.403 1702.05,469.416 1702.06,469.43 1702.07,469.444 1702.08,469.458 1702.09,469.472 1702.1,469.486 1702.11,469.499 1702.12,469.513 1702.13,469.527 1702.14,469.541 1702.14,469.555 1702.15,469.569 1702.16,469.582 1702.17,469.596 1702.18,469.61 1702.19,469.624 1702.2,469.638 1702.21,469.652 1702.22,469.665 1702.23,469.679 1702.24,469.693 1702.25,469.707 1702.26,469.721 1702.26,469.735 1702.27,469.748 1702.28,469.762 1702.29,469.776 1702.3,469.79 1702.31,469.804 1702.32,469.818 1702.33,469.831 1702.34,469.845 1702.35,469.859 1702.36,469.873 1702.37,469.887 1702.37,469.9 1702.38,469.914 1702.39,469.928 1702.4,469.942 1702.41,469.956 1702.42,469.969 1702.43,469.983 1702.44,469.997 1702.45,470.011 1702.46,470.025 1702.47,470.039 1702.48,470.052 1702.48,470.066 1702.49,470.08 1702.5,470.094 1702.51,470.108 1702.52,470.121 1702.53,470.135 1702.54,470.149 1702.55,470.163 1702.56,470.177 1702.57,470.19 1702.58,470.204 1702.59,470.218 1702.6,470.232 1702.6,470.246 1702.61,470.259 1702.62,470.273 1702.63,470.287 1702.64,470.301 1702.65,470.315 1702.66,470.328 1702.67,470.342 1702.68,470.356 1702.69,470.37 1702.7,470.383 1702.71,470.397 1702.71,470.411 1702.72,470.425 1702.73,470.439 1702.74,470.452 1702.75,470.466 1702.76,470.48 1702.77,470.494 1702.78,470.508 1702.79,470.521 1702.8,470.535 1702.81,470.549 1702.82,470.563 1702.82,470.576 1702.83,470.59 1702.84,470.604 1702.85,470.618 1702.86,470.632 1702.87,470.645 1702.88,470.659 1702.89,470.673 1702.9,470.687 1702.91,470.7 1702.92,470.714 1702.93,470.728 1702.94,470.742 1702.94,470.755 1702.95,470.769 1702.96,470.783 1702.97,470.797 1702.98,470.81 1702.99,470.824 1703,470.838 1703.01,470.852 1703.02,470.866 1703.03,470.879 1703.04,470.893 1703.05,470.907 1703.05,470.921 1703.06,470.934 1703.07,470.948 1703.08,470.962 1703.09,470.976 1703.1,470.989 1703.11,471.003 1703.12,471.017 1703.13,471.031 1703.14,471.044 1703.15,471.058 1703.16,471.072 1703.16,471.086 1703.17,471.099 1703.18,471.113 1703.19,471.127 1703.2,471.141 1703.21,471.154 1703.22,471.168 1703.23,471.182 1703.24,471.196 1703.25,471.209 1703.26,471.223 1703.27,471.237 1703.28,471.25 1703.28,471.264 1703.29,471.278 1703.3,471.292 1703.31,471.305 1703.32,471.319 1703.33,471.333 1703.34,471.347 1703.35,471.36 1703.36,471.374 1703.37,471.388 1703.38,471.402 1703.39,471.415 1703.39,471.429 1703.4,471.443 1703.41,471.456 1703.42,471.47 1703.43,471.484 1703.44,471.498 1703.45,471.511 1703.46,471.525 1703.47,471.539 1703.48,471.552 1703.49,471.566 1703.5,471.58 1703.51,471.594 1703.51,471.607 1703.52,471.621 1703.53,471.635 1703.54,471.649 1703.55,471.662 1703.56,471.676 1703.57,471.69 1703.58,471.703 1703.59,471.717 1703.6,471.731 1703.61,471.744 1703.62,471.758 1703.62,471.772 1703.63,471.786 1703.64,471.799 1703.65,471.813 1703.66,471.827 1703.67,471.84 1703.68,471.854 1703.69,471.868 1703.7,471.882 1703.71,471.895 1703.72,471.909 1703.73,471.923 1703.73,471.936 1703.74,471.95 1703.75,471.964 1703.76,471.977 1703.77,471.991 1703.78,472.005 1703.79,472.018 1703.8,472.032 1703.81,472.046 1703.82,472.06 1703.83,472.073 1703.84,472.087 1703.85,472.101 1703.85,472.114 1703.86,472.128 1703.87,472.142 1703.88,472.155 1703.89,472.169 1703.9,472.183 1703.91,472.196 1703.92,472.21 1703.93,472.224 1703.94,472.237 1703.95,472.251 1703.96,472.265 1703.96,472.279 1703.97,472.292 1703.98,472.306 1703.99,472.32 1704,472.333 1704.01,472.347 1704.02,472.361 1704.03,472.374 1704.04,472.388 1704.05,472.402 1704.06,472.415 1704.07,472.429 1704.07,472.443 1704.08,472.456 1704.09,472.47 1704.1,472.484 1704.11,472.497 1704.12,472.511 1704.13,472.525 1704.14,472.538 1704.15,472.552 1704.16,472.566 1704.17,472.579 1704.18,472.593 1704.19,472.607 1704.19,472.62 1704.2,472.634 1704.21,472.648 1704.22,472.661 1704.23,472.675 1704.24,472.688 1704.25,472.702 1704.26,472.716 1704.27,472.729 1704.28,472.743 1704.29,472.757 1704.3,472.77 1704.3,472.784 1704.31,472.798 1704.32,472.811 1704.33,472.825 1704.34,472.839 1704.35,472.852 1704.36,472.866 1704.37,472.88 1704.38,472.893 1704.39,472.907 1704.4,472.92 1704.41,472.934 1704.41,472.948 1704.42,472.961 1704.43,472.975 1704.44,472.989 1704.45,473.002 1704.46,473.016 1704.47,473.03 1704.48,473.043 1704.49,473.057 1704.5,473.07 1704.51,473.084 1704.52,473.098 1704.53,473.111 1704.53,473.125 1704.54,473.139 1704.55,473.152 1704.56,473.166 1704.57,473.18 1704.58,473.193 1704.59,473.207 1704.6,473.22 1704.61,473.234 1704.62,473.248 1704.63,473.261 1704.64,473.275 1704.64,473.288 1704.65,473.302 1704.66,473.316 1704.67,473.329 1704.68,473.343 1704.69,473.357 1704.7,473.37 1704.71,473.384 1704.72,473.397 1704.73,473.411 1704.74,473.425 1704.75,473.438 1704.75,473.452 1704.76,473.465 1704.77,473.479 1704.78,473.493 1704.79,473.506 1704.8,473.52 1704.81,473.534 1704.82,473.547 1704.83,473.561 1704.84,473.574 1704.85,473.588 1704.86,473.602 1704.87,473.615 1704.87,473.629 1704.88,473.642 1704.89,473.656 1704.9,473.67 1704.91,473.683 1704.92,473.697 1704.93,473.71 1704.94,473.724 1704.95,473.738 1704.96,473.751 1704.97,473.765 1704.98,473.778 1704.98,473.792 1704.99,473.805 1705,473.819 1705.01,473.833 1705.02,473.846 1705.03,473.86 1705.04,473.873 1705.05,473.887 1705.06,473.901 1705.07,473.914 1705.08,473.928 1705.09,473.941 1705.09,473.955 1705.1,473.968 1705.11,473.982 1705.12,473.996 1705.13,474.009 1705.14,474.023 1705.15,474.036 1705.16,474.05 1705.17,474.064 1705.18,474.077 1705.19,474.091 1705.2,474.104 1705.21,474.118 1705.21,474.131 1705.22,474.145 1705.23,474.159 1705.24,474.172 1705.25,474.186 1705.26,474.199 1705.27,474.213 1705.28,474.226 1705.29,474.24 1705.3,474.254 1705.31,474.267 1705.32,474.281 1705.32,474.294 1705.33,474.308 1705.34,474.321 1705.35,474.335 1705.36,474.348 1705.37,474.362 1705.38,474.376 1705.39,474.389 1705.4,474.403 1705.41,474.416 1705.42,474.43 1705.43,474.443 1705.43,474.457 1705.44,474.47 1705.45,474.484 1705.46,474.498 1705.47,474.511 1705.48,474.525 1705.49,474.538 1705.5,474.552 1705.51,474.565 1705.52,474.579 1705.53,474.592 1705.54,474.606 1705.55,474.619 1705.55,474.633 1705.56,474.647 1705.57,474.66 1705.58,474.674 1705.59,474.687 1705.6,474.701 1705.61,474.714 1705.62,474.728 1705.63,474.741 1705.64,474.755 1705.65,474.768 1705.66,474.782 1705.66,474.795 1705.67,474.809 1705.68,474.823 1705.69,474.836 1705.7,474.85 1705.71,474.863 1705.72,474.877 1705.73,474.89 1705.74,474.904 1705.75,474.917 1705.76,474.931 1705.77,474.944 1705.77,474.958 1705.78,474.971 1705.79,474.985 1705.8,474.998 1705.81,475.012 1705.82,475.025 1705.83,475.039 1705.84,475.052 1705.85,475.066 1705.86,475.079 1705.87,475.093 1705.88,475.107 1705.89,475.12 1705.89,475.134 1705.9,475.147 1705.91,475.161 1705.92,475.174 1705.93,475.188 1705.94,475.201 1705.95,475.215 1705.96,475.228 1705.97,475.242 1705.98,475.255 1705.99,475.269 1706,475.282 1706,475.296 1706.01,475.309 1706.02,475.323 1706.03,475.336 1706.04,475.35 1706.05,475.363 1706.06,475.377 1706.07,475.39 1706.08,475.404 1706.09,475.417 1706.1,475.431 1706.11,475.444 1706.11,475.458 1706.12,475.471 1706.13,475.485 1706.14,475.498 1706.15,475.512 1706.16,475.525 1706.17,475.539 1706.18,475.552 1706.19,475.566 1706.2,475.579 1706.21,475.593 1706.22,475.606 1706.23,475.62 1706.23,475.633 1706.24,475.647 1706.25,475.66 1706.26,475.673 1706.27,475.687 1706.28,475.7 1706.29,475.714 1706.3,475.727 1706.31,475.741 1706.32,475.754 1706.33,475.768 1706.34,475.781 1706.34,475.795 1706.35,475.808 1706.36,475.822 1706.37,475.835 1706.38,475.849 1706.39,475.862 1706.4,475.876 1706.41,475.889 1706.42,475.903 1706.43,475.916 1706.44,475.93 1706.45,475.943 1706.45,475.956 1706.46,475.97 1706.47,475.983 1706.48,475.997 1706.49,476.01 1706.5,476.024 1706.51,476.037 1706.52,476.051 1706.53,476.064 1706.54,476.078 1706.55,476.091 1706.56,476.105 1706.57,476.118 1706.57,476.131 1706.58,476.145 1706.59,476.158 1706.6,476.172 1706.61,476.185 1706.62,476.199 1706.63,476.212 1706.64,476.226 1706.65,476.239 1706.66,476.253 1706.67,476.266 1706.68,476.279 1706.68,476.293 1706.69,476.306 1706.7,476.32 1706.71,476.333 1706.72,476.347 1706.73,476.36 1706.74,476.374 1706.75,476.387 1706.76,476.4 1706.77,476.414 1706.78,476.427 1706.79,476.441 1706.79,476.454 1706.8,476.468 1706.81,476.481 1706.82,476.494 1706.83,476.508 1706.84,476.521 1706.85,476.535 1706.86,476.548 1706.87,476.562 1706.88,476.575 1706.89,476.589 1706.9,476.602 1706.91,476.615 1706.91,476.629 1706.92,476.642 1706.93,476.656 1706.94,476.669 1706.95,476.683 1706.96,476.696 1706.97,476.709 1706.98,476.723 1706.99,476.736 1707,476.75 1707.01,476.763 1707.02,476.776 1707.02,476.79 1707.03,476.803 1707.04,476.817 1707.05,476.83 1707.06,476.844 1707.07,476.857 1707.08,476.87 1707.09,476.884 1707.1,476.897 1707.11,476.911 1707.12,476.924 1707.13,476.937 1707.13,476.951 1707.14,476.964 1707.15,476.978 1707.16,476.991 1707.17,477.005 1707.18,477.018 1707.19,477.031 1707.2,477.045 1707.21,477.058 1707.22,477.072 1707.23,477.085 1707.24,477.098 1707.25,477.112 1707.25,477.125 1707.26,477.139 1707.27,477.152 1707.28,477.165 1707.29,477.179 1707.3,477.192 1707.31,477.206 1707.32,477.219 1707.33,477.232 1707.34,477.246 1707.35,477.259 1707.36,477.272 1707.36,477.286 1707.37,477.299 1707.38,477.313 1707.39,477.326 1707.4,477.339 1707.41,477.353 1707.42,477.366 1707.43,477.38 1707.44,477.393 1707.45,477.406 1707.46,477.42 1707.47,477.433 1707.47,477.447 1707.48,477.46 1707.49,477.473 1707.5,477.487 1707.51,477.5 1707.52,477.513 1707.53,477.527 1707.54,477.54 1707.55,477.554 1707.56,477.567 1707.57,477.58 1707.58,477.594 1707.59,477.607 1707.59,477.62 1707.6,477.634 1707.61,477.647 1707.62,477.661 1707.63,477.674 1707.64,477.687 1707.65,477.701 1707.66,477.714 1707.67,477.727 1707.68,477.741 1707.69,477.754 1707.7,477.767 1707.7,477.781 1707.71,477.794 1707.72,477.808 1707.73,477.821 1707.74,477.834 1707.75,477.848 1707.76,477.861 1707.77,477.874 1707.78,477.888 1707.79,477.901 1707.8,477.914 1707.81,477.928 1707.81,477.941 1707.82,477.954 1707.83,477.968 1707.84,477.981 1707.85,477.995 1707.86,478.008 1707.87,478.021 1707.88,478.035 1707.89,478.048 1707.9,478.061 1707.91,478.075 1707.92,478.088 1707.93,478.101 1707.93,478.115 1707.94,478.128 1707.95,478.141 1707.96,478.155 1707.97,478.168 1707.98,478.181 1707.99,478.195 1708,478.208 1708.01,478.221 1708.02,478.235 1708.03,478.248 1708.04,478.261 1708.04,478.275 1708.05,478.288 1708.06,478.301 1708.07,478.315 1708.08,478.328 1708.09,478.341 1708.1,478.355 1708.11,478.368 1708.12,478.381 1708.13,478.395 1708.14,478.408 1708.15,478.421 1708.15,478.435 1708.16,478.448 1708.17,478.461 1708.18,478.475 1708.19,478.488 1708.2,478.501 1708.21,478.515 1708.22,478.528 1708.23,478.541 1708.24,478.555 1708.25,478.568 1708.26,478.581 1708.27,478.595 1708.27,478.608 1708.28,478.621 1708.29,478.634 1708.3,478.648 1708.31,478.661 1708.32,478.674 1708.33,478.688 1708.34,478.701 1708.35,478.714 1708.36,478.728 1708.37,478.741 1708.38,478.754 1708.38,478.768 1708.39,478.781 1708.4,478.794 1708.41,478.808 1708.42,478.821 1708.43,478.834 1708.44,478.847 1708.45,478.861 1708.46,478.874 1708.47,478.887 1708.48,478.901 1708.49,478.914 1708.49,478.927 1708.5,478.941 1708.51,478.954 1708.52,478.967 1708.53,478.98 1708.54,478.994 1708.55,479.007 1708.56,479.02 1708.57,479.034 1708.58,479.047 1708.59,479.06 1708.6,479.073 1708.61,479.087 1708.61,479.1 1708.62,479.113 1708.63,479.127 1708.64,479.14 1708.65,479.153 1708.66,479.166 1708.67,479.18 1708.68,479.193 1708.69,479.206 1708.7,479.22 1708.71,479.233 1708.72,479.246 1708.72,479.259 1708.73,479.273 1708.74,479.286 1708.75,479.299 1708.76,479.313 1708.77,479.326 1708.78,479.339 1708.79,479.352 1708.8,479.366 1708.81,479.379 1708.82,479.392 1708.83,479.405 1708.83,479.419 1708.84,479.432 1708.85,479.445 1708.86,479.459 1708.87,479.472 1708.88,479.485 1708.89,479.498 1708.9,479.512 1708.91,479.525 1708.92,479.538 1708.93,479.551 1708.94,479.565 1708.95,479.578 1708.95,479.591 1708.96,479.604 1708.97,479.618 1708.98,479.631 1708.99,479.644 1709,479.657 1709.01,479.671 1709.02,479.684 1709.03,479.697 1709.04,479.71 1709.05,479.724 1709.06,479.737 1709.06,479.75 1709.07,479.763 1709.08,479.777 1709.09,479.79 1709.1,479.803 1709.11,479.816 1709.12,479.83 1709.13,479.843 1709.14,479.856 1709.15,479.869 1709.16,479.883 1709.17,479.896 1709.17,479.909 1709.18,479.922 1709.19,479.936 1709.2,479.949 1709.21,479.962 1709.22,479.975 1709.23,479.989 1709.24,480.002 1709.25,480.015 1709.26,480.028 1709.27,480.042 1709.28,480.055 1709.29,480.068 1709.29,480.081 1709.3,480.095 1709.31,480.108 1709.32,480.121 1709.33,480.134 1709.34,480.147 1709.35,480.161 1709.36,480.174 1709.37,480.187 1709.38,480.2 1709.39,480.214 1709.4,480.227 1709.4,480.24 1709.41,480.253 1709.42,480.266 1709.43,480.28 1709.44,480.293 1709.45,480.306 1709.46,480.319 1709.47,480.333 1709.48,480.346 1709.49,480.359 1709.5,480.372 1709.51,480.385 1709.51,480.399 1709.52,480.412 1709.53,480.425 1709.54,480.438 1709.55,480.451 1709.56,480.465 1709.57,480.478 1709.58,480.491 1709.59,480.504 1709.6,480.518 1709.61,480.531 1709.62,480.544 1709.63,480.557 1709.63,480.57 1709.64,480.584 1709.65,480.597 1709.66,480.61 1709.67,480.623 1709.68,480.636 1709.69,480.65 1709.7,480.663 1709.71,480.676 1709.72,480.689 1709.73,480.702 1709.74,480.716 1709.74,480.729 1709.75,480.742 1709.76,480.755 1709.77,480.768 1709.78,480.782 1709.79,480.795 1709.8,480.808 1709.81,480.821 1709.82,480.834 1709.83,480.847 1709.84,480.861 1709.85,480.874 1709.85,480.887 1709.86,480.9 1709.87,480.913 1709.88,480.927 1709.89,480.94 1709.9,480.953 1709.91,480.966 1709.92,480.979 1709.93,480.993 1709.94,481.006 1709.95,481.019 1709.96,481.032 1709.97,481.045 1709.97,481.058 1709.98,481.072 1709.99,481.085 1710,481.098 1710.01,481.111 1710.02,481.124 1710.03,481.137 1710.04,481.151 1710.05,481.164 1710.06,481.177 1710.07,481.19 1710.08,481.203 1710.08,481.216 1710.09,481.23 1710.1,481.243 1710.11,481.256 1710.12,481.269 1710.13,481.282 1710.14,481.295 1710.15,481.309 1710.16,481.322 1710.17,481.335 1710.18,481.348 1710.19,481.361 1710.19,481.374 1710.2,481.388 1710.21,481.401 1710.22,481.414 1710.23,481.427 1710.24,481.44 1710.25,481.453 1710.26,481.467 1710.27,481.48 1710.28,481.493 1710.29,481.506 1710.3,481.519 1710.31,481.532 1710.31,481.545 1710.32,481.559 1710.33,481.572 1710.34,481.585 1710.35,481.598 1710.36,481.611 1710.37,481.624 1710.38,481.638 1710.39,481.651 1710.4,481.664 1710.41,481.677 1710.42,481.69 1710.42,481.703 1710.43,481.716 1710.44,481.729 1710.45,481.743 1710.46,481.756 1710.47,481.769 1710.48,481.782 1710.49,481.795 1710.5,481.808 1710.51,481.821 1710.52,481.835 1710.53,481.848 1710.53,481.861 1710.54,481.874 1710.55,481.887 1710.56,481.9 1710.57,481.913 1710.58,481.927 1710.59,481.94 1710.6,481.953 1710.61,481.966 1710.62,481.979 1710.63,481.992 1710.64,482.005 1710.65,482.018 1710.65,482.032 1710.66,482.045 1710.67,482.058 1710.68,482.071 1710.69,482.084 1710.7,482.097 1710.71,482.11 1710.72,482.123 1710.73,482.136 1710.74,482.15 1710.75,482.163 1710.76,482.176 1710.76,482.189 1710.77,482.202 1710.78,482.215 1710.79,482.228 1710.8,482.241 1710.81,482.254 1710.82,482.268 1710.83,482.281 1710.84,482.294 1710.85,482.307 1710.86,482.32 1710.87,482.333 1710.87,482.346 1710.88,482.359 1710.89,482.372 1710.9,482.386 1710.91,482.399 1710.92,482.412 1710.93,482.425 1710.94,482.438 1710.95,482.451 1710.96,482.464 1710.97,482.477 1710.98,482.49 1710.99,482.503 1710.99,482.517 1711,482.53 1711.01,482.543 1711.02,482.556 1711.03,482.569 1711.04,482.582 1711.05,482.595 1711.06,482.608 1711.07,482.621 1711.08,482.634 1711.09,482.647 1711.1,482.661 1711.1,482.674 1711.11,482.687 1711.12,482.7 1711.13,482.713 1711.14,482.726 1711.15,482.739 1711.16,482.752 1711.17,482.765 1711.18,482.778 1711.19,482.791 1711.2,482.804 1711.21,482.818 1711.21,482.831 1711.22,482.844 1711.23,482.857 1711.24,482.87 1711.25,482.883 1711.26,482.896 1711.27,482.909 1711.28,482.922 1711.29,482.935 1711.3,482.948 1711.31,482.961 1711.32,482.974 1711.33,482.987 1711.33,483.001 1711.34,483.014 1711.35,483.027 1711.36,483.04 1711.37,483.053 1711.38,483.066 1711.39,483.079 1711.4,483.092 1711.41,483.105 1711.42,483.118 1711.43,483.131 1711.44,483.144 1711.44,483.157 1711.45,483.17 1711.46,483.183 1711.47,483.196 1711.48,483.21 1711.49,483.223 1711.5,483.236 1711.51,483.249 1711.52,483.262 1711.53,483.275 1711.54,483.288 1711.55,483.301 1711.55,483.314 1711.56,483.327 1711.57,483.34 1711.58,483.353 1711.59,483.366 1711.6,483.379 1711.61,483.392 1711.62,483.405 1711.63,483.418 1711.64,483.431 1711.65,483.444 1711.66,483.457 1711.67,483.471 1711.67,483.484 1711.68,483.497 1711.69,483.51 1711.7,483.523 1711.71,483.536 1711.72,483.549 1711.73,483.562 1711.74,483.575 1711.75,483.588 1711.76,483.601 1711.77,483.614 1711.78,483.627 1711.78,483.64 1711.79,483.653 1711.8,483.666 1711.81,483.679 1711.82,483.692 1711.83,483.705 1711.84,483.718 1711.85,483.731 1711.86,483.744 1711.87,483.757 1711.88,483.77 1711.89,483.783 1711.89,483.796 1711.9,483.809 1711.91,483.822 1711.92,483.835 1711.93,483.848 1711.94,483.861 1711.95,483.874 1711.96,483.887 1711.97,483.9 1711.98,483.914 1711.99,483.927 1712,483.94 1712.01,483.953 1712.01,483.966 1712.02,483.979 1712.03,483.992 1712.04,484.005 1712.05,484.018 1712.06,484.031 1712.07,484.044 1712.08,484.057 1712.09,484.07 1712.1,484.083 1712.11,484.096 1712.12,484.109 1712.12,484.122 1712.13,484.135 1712.14,484.148 1712.15,484.161 1712.16,484.174 1712.17,484.187 1712.18,484.2 1712.19,484.213 1712.2,484.226 1712.21,484.239 1712.22,484.252 1712.23,484.265 1712.23,484.278 1712.24,484.291 1712.25,484.304 1712.26,484.317 1712.27,484.33 1712.28,484.343 1712.29,484.356 1712.3,484.369 1712.31,484.382 1712.32,484.395 1712.33,484.408 1712.34,484.421 1712.35,484.434 1712.35,484.447 1712.36,484.46 1712.37,484.473 1712.38,484.486 1712.39,484.499 1712.4,484.512 1712.41,484.525 1712.42,484.537 1712.43,484.55 1712.44,484.563 1712.45,484.576 1712.46,484.589 1712.46,484.602 1712.47,484.615 1712.48,484.628 1712.49,484.641 1712.5,484.654 1712.51,484.667 1712.52,484.68 1712.53,484.693 1712.54,484.706 1712.55,484.719 1712.56,484.732 1712.57,484.745 1712.57,484.758 1712.58,484.771 1712.59,484.784 1712.6,484.797 1712.61,484.81 1712.62,484.823 1712.63,484.836 1712.64,484.849 1712.65,484.862 1712.66,484.875 1712.67,484.888 1712.68,484.901 1712.69,484.914 1712.69,484.927 1712.7,484.94 1712.71,484.953 1712.72,484.965 1712.73,484.978 1712.74,484.991 1712.75,485.004 1712.76,485.017 1712.77,485.03 1712.78,485.043 1712.79,485.056 1712.8,485.069 1712.8,485.082 1712.81,485.095 1712.82,485.108 1712.83,485.121 1712.84,485.134 1712.85,485.147 1712.86,485.16 1712.87,485.173 1712.88,485.186 1712.89,485.199 1712.9,485.212 1712.91,485.225 1712.91,485.237 1712.92,485.25 1712.93,485.263 1712.94,485.276 1712.95,485.289 1712.96,485.302 1712.97,485.315 1712.98,485.328 1712.99,485.341 1713,485.354 1713.01,485.367 1713.02,485.38 1713.03,485.393 1713.03,485.406 1713.04,485.419 1713.05,485.432 1713.06,485.444 1713.07,485.457 1713.08,485.47 1713.09,485.483 1713.1,485.496 1713.11,485.509 1713.12,485.522 1713.13,485.535 1713.14,485.548 1713.14,485.561 1713.15,485.574 1713.16,485.587 1713.17,485.6 1713.18,485.612 1713.19,485.625 1713.2,485.638 1713.21,485.651 1713.22,485.664 1713.23,485.677 1713.24,485.69 1713.25,485.703 1713.25,485.716 1713.26,485.729 1713.27,485.742 1713.28,485.755 1713.29,485.767 1713.3,485.78 1713.31,485.793 1713.32,485.806 1713.33,485.819 1713.34,485.832 1713.35,485.845 1713.36,485.858 1713.37,485.871 1713.37,485.884 1713.38,485.897 1713.39,485.909 1713.4,485.922 1713.41,485.935 1713.42,485.948 1713.43,485.961 1713.44,485.974 1713.45,485.987 1713.46,486 1713.47,486.013 1713.48,486.026 1713.48,486.039 1713.49,486.051 1713.5,486.064 1713.51,486.077 1713.52,486.09 1713.53,486.103 1713.54,486.116 1713.55,486.129 1713.56,486.142 1713.57,486.155 1713.58,486.167 1713.59,486.18 1713.59,486.193 1713.6,486.206 1713.61,486.219 1713.62,486.232 1713.63,486.245 1713.64,486.258 1713.65,486.271 1713.66,486.283 1713.67,486.296 1713.68,486.309 1713.69,486.322 1713.7,486.335 1713.71,486.348 1713.71,486.361 1713.72,486.374 1713.73,486.387 1713.74,486.399 1713.75,486.412 1713.76,486.425 1713.77,486.438 1713.78,486.451 1713.79,486.464 1713.8,486.477 1713.81,486.49 1713.82,486.502 1713.82,486.515 1713.83,486.528 1713.84,486.541 1713.85,486.554 1713.86,486.567 1713.87,486.58 1713.88,486.592 1713.89,486.605 1713.9,486.618 1713.91,486.631 1713.92,486.644 1713.93,486.657 1713.93,486.67 1713.94,486.683 1713.95,486.695 1713.96,486.708 1713.97,486.721 1713.98,486.734 1713.99,486.747 1714,486.76 1714.01,486.773 1714.02,486.785 1714.03,486.798 1714.04,486.811 1714.05,486.824 1714.05,486.837 1714.06,486.85 1714.07,486.863 1714.08,486.875 1714.09,486.888 1714.1,486.901 1714.11,486.914 1714.12,486.927 1714.13,486.94 1714.14,486.952 1714.15,486.965 1714.16,486.978 1714.16,486.991 1714.17,487.004 1714.18,487.017 1714.19,487.03 1714.2,487.042 1714.21,487.055 1714.22,487.068 1714.23,487.081 1714.24,487.094 1714.25,487.107 1714.26,487.119 1714.27,487.132 1714.27,487.145 1714.28,487.158 1714.29,487.171 1714.3,487.184 1714.31,487.196 1714.32,487.209 1714.33,487.222 1714.34,487.235 1714.35,487.248 1714.36,487.261 1714.37,487.273 1714.38,487.286 1714.39,487.299 1714.39,487.312 1714.4,487.325 1714.41,487.338 1714.42,487.35 1714.43,487.363 1714.44,487.376 1714.45,487.389 1714.46,487.402 1714.47,487.415 1714.48,487.427 1714.49,487.44 1714.5,487.453 1714.5,487.466 1714.51,487.479 1714.52,487.491 1714.53,487.504 1714.54,487.517 1714.55,487.53 1714.56,487.543 1714.57,487.556 1714.58,487.568 1714.59,487.581 1714.6,487.594 1714.61,487.607 1714.61,487.62 1714.62,487.632 1714.63,487.645 1714.64,487.658 1714.65,487.671 1714.66,487.684 1714.67,487.696 1714.68,487.709 1714.69,487.722 1714.7,487.735 1714.71,487.748 1714.72,487.76 1714.73,487.773 1714.73,487.786 1714.74,487.799 1714.75,487.812 1714.76,487.824 1714.77,487.837 1714.78,487.85 1714.79,487.863 1714.8,487.876 1714.81,487.888 1714.82,487.901 1714.83,487.914 1714.84,487.927 1714.84,487.94 1714.85,487.952 1714.86,487.965 1714.87,487.978 1714.88,487.991 1714.89,488.004 1714.9,488.016 1714.91,488.029 1714.92,488.042 1714.93,488.055 1714.94,488.067 1714.95,488.08 1714.95,488.093 1714.96,488.106 1714.97,488.119 1714.98,488.131 1714.99,488.144 1715,488.157 1715.01,488.17 1715.02,488.183 1715.03,488.195 1715.04,488.208 1715.05,488.221 1715.06,488.234 1715.07,488.246 1715.07,488.259 1715.08,488.272 1715.09,488.285 1715.1,488.298 1715.11,488.31 1715.12,488.323 1715.13,488.336 1715.14,488.349 1715.15,488.361 1715.16,488.374 1715.17,488.387 1715.18,488.4 1715.18,488.412 1715.19,488.425 1715.2,488.438 1715.21,488.451 1715.22,488.464 1715.23,488.476 1715.24,488.489 1715.25,488.502 1715.26,488.515 1715.27,488.527 1715.28,488.54 1715.29,488.553 1715.29,488.566 1715.3,488.578 1715.31,488.591 1715.32,488.604 1715.33,488.617 1715.34,488.629 1715.35,488.642 1715.36,488.655 1715.37,488.668 1715.38,488.68 1715.39,488.693 1715.4,488.706 1715.41,488.719 1715.41,488.731 1715.42,488.744 1715.43,488.757 1715.44,488.77 1715.45,488.782 1715.46,488.795 1715.47,488.808 1715.48,488.821 1715.49,488.833 1715.5,488.846 1715.51,488.859 1715.52,488.872 1715.52,488.884 1715.53,488.897 1715.54,488.91 1715.55,488.923 1715.56,488.935 1715.57,488.948 1715.58,488.961 1715.59,488.973 1715.6,488.986 1715.61,488.999 1715.62,489.012 1715.63,489.024 1715.63,489.037 1715.64,489.05 1715.65,489.063 1715.66,489.075 1715.67,489.088 1715.68,489.101 1715.69,489.114 1715.7,489.126 1715.71,489.139 1715.72,489.152 1715.73,489.164 1715.74,489.177 1715.75,489.19 1715.75,489.203 1715.76,489.215 1715.77,489.228 1715.78,489.241 1715.79,489.253 1715.8,489.266 1715.81,489.279 1715.82,489.292 1715.83,489.304 1715.84,489.317 1715.85,489.33 1715.86,489.343 1715.86,489.355 1715.87,489.368 1715.88,489.381 1715.89,489.393 1715.9,489.406 1715.91,489.419 1715.92,489.431 1715.93,489.444 1715.94,489.457 1715.95,489.47 1715.96,489.482 1715.97,489.495 1715.97,489.508 1715.98,489.52 1715.99,489.533 1716,489.546 1716.01,489.559 1716.02,489.571 1716.03,489.584 1716.04,489.597 1716.05,489.609 1716.06,489.622 1716.07,489.635 1716.08,489.647 1716.09,489.66 1716.09,489.673 1716.1,489.686 1716.11,489.698 1716.12,489.711 1716.13,489.724 1716.14,489.736 1716.15,489.749 1716.16,489.762 1716.17,489.774 1716.18,489.787 1716.19,489.8 1716.2,489.812 1716.2,489.825 1716.21,489.838 1716.22,489.851 1716.23,489.863 1716.24,489.876 1716.25,489.889 1716.26,489.901 1716.27,489.914 1716.28,489.927 1716.29,489.939 1716.3,489.952 1716.31,489.965 1716.31,489.977 1716.32,489.99 1716.33,490.003 1716.34,490.015 1716.35,490.028 1716.36,490.041 1716.37,490.053 1716.38,490.066 1716.39,490.079 1716.4,490.091 1716.41,490.104 1716.42,490.117 1716.43,490.129 1716.43,490.142 1716.44,490.155 1716.45,490.168 1716.46,490.18 1716.47,490.193 1716.48,490.206 1716.49,490.218 1716.5,490.231 1716.51,490.244 1716.52,490.256 1716.53,490.269 1716.54,490.281 1716.54,490.294 1716.55,490.307 1716.56,490.319 1716.57,490.332 1716.58,490.345 1716.59,490.357 1716.6,490.37 1716.61,490.383 1716.62,490.395 1716.63,490.408 1716.64,490.421 1716.65,490.433 1716.65,490.446 1716.66,490.459 1716.67,490.471 1716.68,490.484 1716.69,490.497 1716.7,490.509 1716.71,490.522 1716.72,490.535 1716.73,490.547 1716.74,490.56 1716.75,490.573 1716.76,490.585 1716.77,490.598 1716.77,490.611 1716.78,490.623 1716.79,490.636 1716.8,490.648 1716.81,490.661 1716.82,490.674 1716.83,490.686 1716.84,490.699 1716.85,490.712 1716.86,490.724 1716.87,490.737 1716.88,490.75 1716.88,490.762 1716.89,490.775 1716.9,490.787 1716.91,490.8 1716.92,490.813 1716.93,490.825 1716.94,490.838 1716.95,490.851 1716.96,490.863 1716.97,490.876 1716.98,490.889 1716.99,490.901 1716.99,490.914 1717,490.926 1717.01,490.939 1717.02,490.952 1717.03,490.964 1717.04,490.977 1717.05,490.99 1717.06,491.002 1717.07,491.015 1717.08,491.027 1717.09,491.04 1717.1,491.053 1717.11,491.065 1717.11,491.078 1717.12,491.091 1717.13,491.103 1717.14,491.116 1717.15,491.128 1717.16,491.141 1717.17,491.154 1717.18,491.166 1717.19,491.179 1717.2,491.191 1717.21,491.204 1717.22,491.217 1717.22,491.229 1717.23,491.242 1717.24,491.254 1717.25,491.267 1717.26,491.28 1717.27,491.292 1717.28,491.305 1717.29,491.318 1717.3,491.33 1717.31,491.343 1717.32,491.355 1717.33,491.368 1717.33,491.381 1717.34,491.393 1717.35,491.406 1717.36,491.418 1717.37,491.431 1717.38,491.444 1717.39,491.456 1717.4,491.469 1717.41,491.481 1717.42,491.494 1717.43,491.507 1717.44,491.519 1717.45,491.532 1717.45,491.544 1717.46,491.557 1717.47,491.57 1717.48,491.582 1717.49,491.595 1717.5,491.607 1717.51,491.62 1717.52,491.632 1717.53,491.645 1717.54,491.658 1717.55,491.67 1717.56,491.683 1717.56,491.695 1717.57,491.708 1717.58,491.721 1717.59,491.733 1717.6,491.746 1717.61,491.758 1717.62,491.771 1717.63,491.783 1717.64,491.796 1717.65,491.809 1717.66,491.821 1717.67,491.834 1717.67,491.846 1717.68,491.859 1717.69,491.872 1717.7,491.884 1717.71,491.897 1717.72,491.909 1717.73,491.922 1717.74,491.934 1717.75,491.947 1717.76,491.96 1717.77,491.972 1717.78,491.985 1717.79,491.997 1717.79,492.01 1717.8,492.022 1717.81,492.035 1717.82,492.048 1717.83,492.06 1717.84,492.073 1717.85,492.085 1717.86,492.098 1717.87,492.11 1717.88,492.123 1717.89,492.135 1717.9,492.148 1717.9,492.161 1717.91,492.173 1717.92,492.186 1717.93,492.198 1717.94,492.211 1717.95,492.223 1717.96,492.236 1717.97,492.248 1717.98,492.261 1717.99,492.274 1718,492.286 1718.01,492.299 1718.01,492.311 1718.02,492.324 1718.03,492.336 1718.04,492.349 1718.05,492.361 1718.06,492.374 1718.07,492.387 1718.08,492.399 1718.09,492.412 1718.1,492.424 1718.11,492.437 1718.12,492.449 1718.13,492.462 1718.13,492.474 1718.14,492.487 1718.15,492.499 1718.16,492.512 1718.17,492.525 1718.18,492.537 1718.19,492.55 1718.2,492.562 1718.21,492.575 1718.22,492.587 1718.23,492.6 1718.24,492.612 1718.24,492.625 1718.25,492.637 1718.26,492.65 1718.27,492.662 1718.28,492.675 1718.29,492.687 1718.3,492.7 1718.31,492.713 1718.32,492.725 1718.33,492.738 1718.34,492.75 1718.35,492.763 1718.35,492.775 1718.36,492.788 1718.37,492.8 1718.38,492.813 1718.39,492.825 1718.4,492.838 1718.41,492.85 1718.42,492.863 1718.43,492.875 1718.44,492.888 1718.45,492.9 1718.46,492.913 1718.47,492.925 1718.47,492.938 1718.48,492.95 1718.49,492.963 1718.5,492.976 1718.51,492.988 1718.52,493.001 1718.53,493.013 1718.54,493.026 1718.55,493.038 1718.56,493.051 1718.57,493.063 1718.58,493.076 1718.58,493.088 1718.59,493.101 1718.6,493.113 1718.61,493.126 1718.62,493.138 1718.63,493.151 1718.64,493.163 1718.65,493.176 1718.66,493.188 1718.67,493.201 1718.68,493.213 1718.69,493.226 1718.69,493.238 1718.7,493.251 1718.71,493.263 1718.72,493.276 1718.73,493.288 1718.74,493.301 1718.75,493.313 1718.76,493.326 1718.77,493.338 1718.78,493.351 1718.79,493.363 1718.8,493.376 1718.81,493.388 1718.81,493.401 1718.82,493.413 1718.83,493.426 1718.84,493.438 1718.85,493.451 1718.86,493.463 1718.87,493.476 1718.88,493.488 1718.89,493.501 1718.9,493.513 1718.91,493.526 1718.92,493.538 1718.92,493.551 1718.93,493.563 1718.94,493.575 1718.95,493.588 1718.96,493.6 1718.97,493.613 1718.98,493.625 1718.99,493.638 1719,493.65 1719.01,493.663 1719.02,493.675 1719.03,493.688 1719.03,493.7 1719.04,493.713 1719.05,493.725 1719.06,493.738 1719.07,493.75 1719.08,493.763 1719.09,493.775 1719.1,493.788 1719.11,493.8 1719.12,493.813 1719.13,493.825 1719.14,493.837 1719.15,493.85 1719.15,493.862 1719.16,493.875 1719.17,493.887 1719.18,493.9 1719.19,493.912 1719.2,493.925 1719.21,493.937 1719.22,493.95 1719.23,493.962 1719.24,493.975 1719.25,493.987 1719.26,493.999 1719.26,494.012 1719.27,494.024 1719.28,494.037 1719.29,494.049 1719.3,494.062 1719.31,494.074 1719.32,494.087 1719.33,494.099 1719.34,494.112 1719.35,494.124 1719.36,494.136 1719.37,494.149 1719.37,494.161 1719.38,494.174 1719.39,494.186 1719.4,494.199 1719.41,494.211 1719.42,494.224 1719.43,494.236 1719.44,494.249 1719.45,494.261 1719.46,494.273 1719.47,494.286 1719.48,494.298 1719.49,494.311 1719.49,494.323 1719.5,494.336 1719.51,494.348 1719.52,494.361 1719.53,494.373 1719.54,494.385 1719.55,494.398 1719.56,494.41 1719.57,494.423 1719.58,494.435 1719.59,494.448 1719.6,494.46 1719.6,494.472 1719.61,494.485 1719.62,494.497 1719.63,494.51 1719.64,494.522 1719.65,494.535 1719.66,494.547 1719.67,494.559 1719.68,494.572 1719.69,494.584 1719.7,494.597 1719.71,494.609 1719.71,494.622 1719.72,494.634 1719.73,494.646 1719.74,494.659 1719.75,494.671 1719.76,494.684 1719.77,494.696 1719.78,494.709 1719.79,494.721 1719.8,494.733 1719.81,494.746 1719.82,494.758 1719.83,494.771 1719.83,494.783 1719.84,494.795 1719.85,494.808 1719.86,494.82 1719.87,494.833 1719.88,494.845 1719.89,494.858 1719.9,494.87 1719.91,494.882 1719.92,494.895 1719.93,494.907 1719.94,494.92 1719.94,494.932 1719.95,494.944 1719.96,494.957 1719.97,494.969 1719.98,494.982 1719.99,494.994 1720,495.006 1720.01,495.019 1720.02,495.031 1720.03,495.044 1720.04,495.056 1720.05,495.068 1720.05,495.081 1720.06,495.093 1720.07,495.106 1720.08,495.118 1720.09,495.13 1720.1,495.143 1720.11,495.155 1720.12,495.168 1720.13,495.18 1720.14,495.192 1720.15,495.205 1720.16,495.217 1720.17,495.23 1720.17,495.242 1720.18,495.254 1720.19,495.267 1720.2,495.279 1720.21,495.292 1720.22,495.304 1720.23,495.316 1720.24,495.329 1720.25,495.341 1720.26,495.354 1720.27,495.366 1720.28,495.378 1720.28,495.391 1720.29,495.403 1720.3,495.415 1720.31,495.428 1720.32,495.44 1720.33,495.453 1720.34,495.465 1720.35,495.477 1720.36,495.49 1720.37,495.502 1720.38,495.514 1720.39,495.527 1720.39,495.539 1720.4,495.552 1720.41,495.564 1720.42,495.576 1720.43,495.589 1720.44,495.601 1720.45,495.613 1720.46,495.626 1720.47,495.638 1720.48,495.651 1720.49,495.663 1720.5,495.675 1720.51,495.688 1720.51,495.7 1720.52,495.712 1720.53,495.725 1720.54,495.737 1720.55,495.75 1720.56,495.762 1720.57,495.774 1720.58,495.787 1720.59,495.799 1720.6,495.811 1720.61,495.824 1720.62,495.836 1720.62,495.848 1720.63,495.861 1720.64,495.873 1720.65,495.885 1720.66,495.898 1720.67,495.91 1720.68,495.923 1720.69,495.935 1720.7,495.947 1720.71,495.96 1720.72,495.972 1720.73,495.984 1720.73,495.997 1720.74,496.009 1720.75,496.021 1720.76,496.034 1720.77,496.046 1720.78,496.058 1720.79,496.071 1720.8,496.083 1720.81,496.095 1720.82,496.108 1720.83,496.12 1720.84,496.132 1720.85,496.145 1720.85,496.157 1720.86,496.169 1720.87,496.182 1720.88,496.194 1720.89,496.207 1720.9,496.219 1720.91,496.231 1720.92,496.244 1720.93,496.256 1720.94,496.268 1720.95,496.281 1720.96,496.293 1720.96,496.305 1720.97,496.318 1720.98,496.33 1720.99,496.342 1721,496.355 1721.01,496.367 1721.02,496.379 1721.03,496.392 1721.04,496.404 1721.05,496.416 1721.06,496.429 1721.07,496.441 1721.07,496.453 1721.08,496.465 1721.09,496.478 1721.1,496.49 1721.11,496.502 1721.12,496.515 1721.13,496.527 1721.14,496.539 1721.15,496.552 1721.16,496.564 1721.17,496.576 1721.18,496.589 1721.19,496.601 1721.19,496.613 1721.2,496.626 1721.21,496.638 1721.22,496.65 1721.23,496.663 1721.24,496.675 1721.25,496.687 1721.26,496.7 1721.27,496.712 1721.28,496.724 1721.29,496.736 1721.3,496.749 1721.3,496.761 1721.31,496.773 1721.32,496.786 1721.33,496.798 1721.34,496.81 1721.35,496.823 1721.36,496.835 1721.37,496.847 1721.38,496.86 1721.39,496.872 1721.4,496.884 1721.41,496.896 1721.41,496.909 1721.42,496.921 1721.43,496.933 1721.44,496.946 1721.45,496.958 1721.46,496.97 1721.47,496.983 1721.48,496.995 1721.49,497.007 1721.5,497.019 1721.51,497.032 1721.52,497.044 1721.53,497.056 1721.53,497.069 1721.54,497.081 1721.55,497.093 1721.56,497.105 1721.57,497.118 1721.58,497.13 1721.59,497.142 1721.6,497.155 1721.61,497.167 1721.62,497.179 1721.63,497.192 1721.64,497.204 1721.64,497.216 1721.65,497.228 1721.66,497.241 1721.67,497.253 1721.68,497.265 1721.69,497.277 1721.7,497.29 1721.71,497.302 1721.72,497.314 1721.73,497.327 1721.74,497.339 1721.75,497.351 1721.75,497.363 1721.76,497.376 1721.77,497.388 1721.78,497.4 1721.79,497.413 1721.8,497.425 1721.81,497.437 1721.82,497.449 1721.83,497.462 1721.84,497.474 1721.85,497.486 1721.86,497.498 1721.87,497.511 1721.87,497.523 1721.88,497.535 1721.89,497.548 1721.9,497.56 1721.91,497.572 1721.92,497.584 1721.93,497.597 1721.94,497.609 1721.95,497.621 1721.96,497.633 1721.97,497.646 1721.98,497.658 1721.98,497.67 1721.99,497.682 1722,497.695 1722.01,497.707 1722.02,497.719 1722.03,497.731 1722.04,497.744 1722.05,497.756 1722.06,497.768 1722.07,497.78 1722.08,497.793 1722.09,497.805 1722.09,497.817 1722.1,497.829 1722.11,497.842 1722.12,497.854 1722.13,497.866 1722.14,497.878 1722.15,497.891 1722.16,497.903 1722.17,497.915 1722.18,497.927 1722.19,497.94 1722.2,497.952 1722.21,497.964 1722.21,497.976 1722.22,497.989 1722.23,498.001 1722.24,498.013 1722.25,498.025 1722.26,498.038 1722.27,498.05 1722.28,498.062 1722.29,498.074 1722.3,498.087 1722.31,498.099 1722.32,498.111 1722.32,498.123 1722.33,498.136 1722.34,498.148 1722.35,498.16 1722.36,498.172 1722.37,498.184 1722.38,498.197 1722.39,498.209 1722.4,498.221 1722.41,498.233 1722.42,498.246 1722.43,498.258 1722.43,498.27 1722.44,498.282 1722.45,498.295 1722.46,498.307 1722.47,498.319 1722.48,498.331 1722.49,498.343 1722.5,498.356 1722.51,498.368 1722.52,498.38 1722.53,498.392 1722.54,498.405 1722.55,498.417 1722.55,498.429 1722.56,498.441 1722.57,498.453 1722.58,498.466 1722.59,498.478 1722.6,498.49 1722.61,498.502 1722.62,498.514 1722.63,498.527 1722.64,498.539 1722.65,498.551 1722.66,498.563 1722.66,498.576 1722.67,498.588 1722.68,498.6 1722.69,498.612 1722.7,498.624 1722.71,498.637 1722.72,498.649 1722.73,498.661 1722.74,498.673 1722.75,498.685 1722.76,498.698 1722.77,498.71 1722.77,498.722 1722.78,498.734 1722.79,498.746 1722.8,498.759 1722.81,498.771 1722.82,498.783 1722.83,498.795 1722.84,498.807 1722.85,498.82 1722.86,498.832 1722.87,498.844 1722.88,498.856 1722.89,498.868 1722.89,498.881 1722.9,498.893 1722.91,498.905 1722.92,498.917 1722.93,498.929 1722.94,498.942 1722.95,498.954 1722.96,498.966 1722.97,498.978 1722.98,498.99 1722.99,499.003 1723,499.015 1723,499.027 1723.01,499.039 1723.02,499.051 1723.03,499.063 1723.04,499.076 1723.05,499.088 1723.06,499.1 1723.07,499.112 1723.08,499.124 1723.09,499.137 1723.1,499.149 1723.11,499.161 1723.11,499.173 1723.12,499.185 1723.13,499.197 1723.14,499.21 1723.15,499.222 1723.16,499.234 1723.17,499.246 1723.18,499.258 1723.19,499.271 1723.2,499.283 1723.21,499.295 1723.22,499.307 1723.23,499.319 1723.23,499.331 1723.24,499.344 1723.25,499.356 1723.26,499.368 1723.27,499.38 1723.28,499.392 1723.29,499.404 1723.3,499.417 1723.31,499.429 1723.32,499.441 1723.33,499.453 1723.34,499.465 1723.34,499.477 1723.35,499.49 1723.36,499.502 1723.37,499.514 1723.38,499.526 1723.39,499.538 1723.4,499.55 1723.41,499.562 1723.42,499.575 1723.43,499.587 1723.44,499.599 1723.45,499.611 1723.45,499.623 1723.46,499.635 1723.47,499.648 1723.48,499.66 1723.49,499.672 1723.5,499.684 1723.51,499.696 1723.52,499.708 1723.53,499.72 1723.54,499.733 1723.55,499.745 1723.56,499.757 1723.57,499.769 1723.57,499.781 1723.58,499.793 1723.59,499.806 1723.6,499.818 1723.61,499.83 1723.62,499.842 1723.63,499.854 1723.64,499.866 1723.65,499.878 1723.66,499.891 1723.67,499.903 1723.68,499.915 1723.68,499.927 1723.69,499.939 1723.7,499.951 1723.71,499.963 1723.72,499.975 1723.73,499.988 1723.74,500 1723.75,500.012 1723.76,500.024 1723.77,500.036 1723.78,500.048 1723.79,500.06 1723.79,500.073 1723.8,500.085 1723.81,500.097 1723.82,500.109 1723.83,500.121 1723.84,500.133 1723.85,500.145 1723.86,500.157 1723.87,500.17 1723.88,500.182 1723.89,500.194 1723.9,500.206 1723.91,500.218 1723.91,500.23 1723.92,500.242 1723.93,500.254 1723.94,500.267 1723.95,500.279 1723.96,500.291 1723.97,500.303 1723.98,500.315 1723.99,500.327 1724,500.339 1724.01,500.351 1724.02,500.363 1724.02,500.376 1724.03,500.388 1724.04,500.4 1724.05,500.412 1724.06,500.424 1724.07,500.436 1724.08,500.448 1724.09,500.46 1724.1,500.472 1724.11,500.485 1724.12,500.497 1724.13,500.509 1724.13,500.521 1724.14,500.533 1724.15,500.545 1724.16,500.557 1724.17,500.569 1724.18,500.581 1724.19,500.594 1724.2,500.606 1724.21,500.618 1724.22,500.63 1724.23,500.642 1724.24,500.654 1724.25,500.666 1724.25,500.678 1724.26,500.69 1724.27,500.702 1724.28,500.715 1724.29,500.727 1724.3,500.739 1724.31,500.751 1724.32,500.763 1724.33,500.775 1724.34,500.787 1724.35,500.799 1724.36,500.811 1724.36,500.823 1724.37,500.835 1724.38,500.848 1724.39,500.86 1724.4,500.872 1724.41,500.884 1724.42,500.896 1724.43,500.908 1724.44,500.92 1724.45,500.932 1724.46,500.944 1724.47,500.956 1724.47,500.968 1724.48,500.98 1724.49,500.993 1724.5,501.005 1724.51,501.017 1724.52,501.029 1724.53,501.041 1724.54,501.053 1724.55,501.065 1724.56,501.077 1724.57,501.089 1724.58,501.101 1724.59,501.113 1724.59,501.125 1724.6,501.137 1724.61,501.15 1724.62,501.162 1724.63,501.174 1724.64,501.186 1724.65,501.198 1724.66,501.21 1724.67,501.222 1724.68,501.234 1724.69,501.246 1724.7,501.258 1724.7,501.27 1724.71,501.282 1724.72,501.294 1724.73,501.306 1724.74,501.319 1724.75,501.331 1724.76,501.343 1724.77,501.355 1724.78,501.367 1724.79,501.379 1724.8,501.391 1724.81,501.403 1724.81,501.415 1724.82,501.427 1724.83,501.439 1724.84,501.451 1724.85,501.463 1724.86,501.475 1724.87,501.487 1724.88,501.499 1724.89,501.511 1724.9,501.523 1724.91,501.536 1724.92,501.548 1724.93,501.56 1724.93,501.572 1724.94,501.584 1724.95,501.596 1724.96,501.608 1724.97,501.62 1724.98,501.632 1724.99,501.644 1725,501.656 1725.01,501.668 1725.02,501.68 1725.03,501.692 1725.04,501.704 1725.04,501.716 1725.05,501.728 1725.06,501.74 1725.07,501.752 1725.08,501.764 1725.09,501.776 1725.1,501.788 1725.11,501.801 1725.12,501.813 1725.13,501.825 1725.14,501.837 1725.15,501.849 1725.15,501.861 1725.16,501.873 1725.17,501.885 1725.18,501.897 1725.19,501.909 1725.2,501.921 1725.21,501.933 1725.22,501.945 1725.23,501.957 1725.24,501.969 1725.25,501.981 1725.26,501.993 1725.27,502.005 1725.27,502.017 1725.28,502.029 1725.29,502.041 1725.3,502.053 1725.31,502.065 1725.32,502.077 1725.33,502.089 1725.34,502.101 1725.35,502.113 1725.36,502.125 1725.37,502.137 1725.38,502.149 1725.38,502.161 1725.39,502.173 1725.4,502.185 1725.41,502.197 1725.42,502.209 1725.43,502.221 1725.44,502.233 1725.45,502.245 1725.46,502.258 1725.47,502.27 1725.48,502.282 1725.49,502.294 1725.49,502.306 1725.5,502.318 1725.51,502.33 1725.52,502.342 1725.53,502.354 1725.54,502.366 1725.55,502.378 1725.56,502.39 1725.57,502.402 1725.58,502.414 1725.59,502.426 1725.6,502.438 1725.61,502.45 1725.61,502.462 1725.62,502.474 1725.63,502.486 1725.64,502.498 1725.65,502.51 1725.66,502.522 1725.67,502.534 1725.68,502.546 1725.69,502.558 1725.7,502.57 1725.71,502.582 1725.72,502.594 1725.72,502.606 1725.73,502.618 1725.74,502.63 1725.75,502.642 1725.76,502.654 1725.77,502.666 1725.78,502.678 1725.79,502.69 1725.8,502.702 1725.81,502.714 1725.82,502.726 1725.83,502.738 1725.83,502.75 1725.84,502.761 1725.85,502.773 1725.86,502.785 1725.87,502.797 1725.88,502.809 1725.89,502.821 1725.9,502.833 1725.91,502.845 1725.92,502.857 1725.93,502.869 1725.94,502.881 1725.95,502.893 1725.95,502.905 1725.96,502.917 1725.97,502.929 1725.98,502.941 1725.99,502.953 1726,502.965 1726.01,502.977 1726.02,502.989 1726.03,503.001 1726.04,503.013 1726.05,503.025 1726.06,503.037 1726.06,503.049 1726.07,503.061 1726.08,503.073 1726.09,503.085 1726.1,503.097 1726.11,503.109 1726.12,503.121 1726.13,503.133 1726.14,503.145 1726.15,503.157 1726.16,503.169 1726.17,503.181 1726.17,503.193 1726.18,503.205 1726.19,503.217 1726.2,503.228 1726.21,503.24 1726.22,503.252 1726.23,503.264 1726.24,503.276 1726.25,503.288 1726.26,503.3 1726.27,503.312 1726.28,503.324 1726.29,503.336 1726.29,503.348 1726.3,503.36 1726.31,503.372 1726.32,503.384 1726.33,503.396 1726.34,503.408 1726.35,503.42 1726.36,503.432 1726.37,503.444 1726.38,503.456 1726.39,503.468 1726.4,503.48 1726.4,503.491 1726.41,503.503 1726.42,503.515 1726.43,503.527 1726.44,503.539 1726.45,503.551 1726.46,503.563 1726.47,503.575 1726.48,503.587 1726.49,503.599 1726.5,503.611 1726.51,503.623 1726.51,503.635 1726.52,503.647 1726.53,503.659 1726.54,503.671 1726.55,503.683 1726.56,503.694 1726.57,503.706 1726.58,503.718 1726.59,503.73 1726.6,503.742 1726.61,503.754 1726.62,503.766 1726.63,503.778 1726.63,503.79 1726.64,503.802 1726.65,503.814 1726.66,503.826 1726.67,503.838 1726.68,503.85 1726.69,503.862 1726.7,503.873 1726.71,503.885 1726.72,503.897 1726.73,503.909 1726.74,503.921 1726.74,503.933 1726.75,503.945 1726.76,503.957 1726.77,503.969 1726.78,503.981 1726.79,503.993 1726.8,504.005 1726.81,504.017 1726.82,504.028 1726.83,504.04 1726.84,504.052 1726.85,504.064 1726.85,504.076 1726.86,504.088 1726.87,504.1 1726.88,504.112 1726.89,504.124 1726.9,504.136 1726.91,504.148 1726.92,504.16 1726.93,504.171 1726.94,504.183 1726.95,504.195 1726.96,504.207 1726.97,504.219 1726.97,504.231 1726.98,504.243 1726.99,504.255 1727,504.267 1727.01,504.279 1727.02,504.291 1727.03,504.302 1727.04,504.314 1727.05,504.326 1727.06,504.338 1727.07,504.35 1727.08,504.362 1727.08,504.374 1727.09,504.386 1727.1,504.398 1727.11,504.41 1727.12,504.421 1727.13,504.433 1727.14,504.445 1727.15,504.457 1727.16,504.469 1727.17,504.481 1727.18,504.493 1727.19,504.505 1727.19,504.517 1727.2,504.528 1727.21,504.54 1727.22,504.552 1727.23,504.564 1727.24,504.576 1727.25,504.588 1727.26,504.6 1727.27,504.612 1727.28,504.624 1727.29,504.635 1727.3,504.647 1727.31,504.659 1727.31,504.671 1727.32,504.683 1727.33,504.695 1727.34,504.707 1727.35,504.719 1727.36,504.731 1727.37,504.742 1727.38,504.754 1727.39,504.766 1727.4,504.778 1727.41,504.79 1727.42,504.802 1727.42,504.814 1727.43,504.826 1727.44,504.837 1727.45,504.849 1727.46,504.861 1727.47,504.873 1727.48,504.885 1727.49,504.897 1727.5,504.909 1727.51,504.921 1727.52,504.932 1727.53,504.944 1727.53,504.956 1727.54,504.968 1727.55,504.98 1727.56,504.992 1727.57,505.004 1727.58,505.016 1727.59,505.027 1727.6,505.039 1727.61,505.051 1727.62,505.063 1727.63,505.075 1727.64,505.087 1727.65,505.099 1727.65,505.11 1727.66,505.122 1727.67,505.134 1727.68,505.146 1727.69,505.158 1727.7,505.17 1727.71,505.182 1727.72,505.193 1727.73,505.205 1727.74,505.217 1727.75,505.229 1727.76,505.241 1727.76,505.253 1727.77,505.265 1727.78,505.276 1727.79,505.288 1727.8,505.3 1727.81,505.312 1727.82,505.324 1727.83,505.336 1727.84,505.348 1727.85,505.359 1727.86,505.371 1727.87,505.383 1727.87,505.395 1727.88,505.407 1727.89,505.419 1727.9,505.43 1727.91,505.442 1727.92,505.454 1727.93,505.466 1727.94,505.478 1727.95,505.49 1727.96,505.502 1727.97,505.513 1727.98,505.525 1727.99,505.537 1727.99,505.549 1728,505.561 1728.01,505.573 1728.02,505.584 1728.03,505.596 1728.04,505.608 1728.05,505.62 1728.06,505.632 1728.07,505.644 1728.08,505.655 1728.09,505.667 1728.1,505.679 1728.1,505.691 1728.11,505.703 1728.12,505.715 1728.13,505.726 1728.14,505.738 1728.15,505.75 1728.16,505.762 1728.17,505.774 1728.18,505.786 1728.19,505.797 1728.2,505.809 1728.21,505.821 1728.22,505.833 1728.22,505.845 1728.23,505.856 1728.24,505.868 1728.25,505.88 1728.26,505.892 1728.27,505.904 1728.28,505.916 1728.29,505.927 1728.3,505.939 1728.31,505.951 1728.32,505.963 1728.33,505.975 1728.33,505.986 1728.34,505.998 1728.35,506.01 1728.36,506.022 1728.37,506.034 1728.38,506.046 1728.39,506.057 1728.4,506.069 1728.41,506.081 1728.42,506.093 1728.43,506.105 1728.44,506.116 1728.44,506.128 1728.45,506.14 1728.46,506.152 1728.47,506.164 1728.48,506.175 1728.49,506.187 1728.5,506.199 1728.51,506.211 1728.52,506.223 1728.53,506.234 1728.54,506.246 1728.55,506.258 1728.56,506.27 1728.56,506.282 1728.57,506.293 1728.58,506.305 1728.59,506.317 1728.6,506.329 1728.61,506.341 1728.62,506.352 1728.63,506.364 1728.64,506.376 1728.65,506.388 1728.66,506.4 1728.67,506.411 1728.67,506.423 1728.68,506.435 1728.69,506.447 1728.7,506.459 1728.71,506.47 1728.72,506.482 1728.73,506.494 1728.74,506.506 1728.75,506.517 1728.76,506.529 1728.77,506.541 1728.78,506.553 1728.78,506.565 1728.79,506.576 1728.8,506.588 1728.81,506.6 1728.82,506.612 1728.83,506.624 1728.84,506.635 1728.85,506.647 1728.86,506.659 1728.87,506.671 1728.88,506.682 1728.89,506.694 1728.9,506.706 1728.9,506.718 1728.91,506.73 1728.92,506.741 1728.93,506.753 1728.94,506.765 1728.95,506.777 1728.96,506.788 1728.97,506.8 1728.98,506.812 1728.99,506.824 1729,506.836 1729.01,506.847 1729.01,506.859 1729.02,506.871 1729.03,506.883 1729.04,506.894 1729.05,506.906 1729.06,506.918 1729.07,506.93 1729.08,506.941 1729.09,506.953 1729.1,506.965 1729.11,506.977 1729.12,506.988 1729.12,507 1729.13,507.012 1729.14,507.024 1729.15,507.036 1729.16,507.047 1729.17,507.059 1729.18,507.071 1729.19,507.083 1729.2,507.094 1729.21,507.106 1729.22,507.118 1729.23,507.13 1729.24,507.141 1729.24,507.153 1729.25,507.165 1729.26,507.177 1729.27,507.188 1729.28,507.2 1729.29,507.212 1729.3,507.224 1729.31,507.235 1729.32,507.247 1729.33,507.259 1729.34,507.271 1729.35,507.282 1729.35,507.294 1729.36,507.306 1729.37,507.318 1729.38,507.329 1729.39,507.341 1729.4,507.353 1729.41,507.365 1729.42,507.376 1729.43,507.388 1729.44,507.4 1729.45,507.411 1729.46,507.423 1729.46,507.435 1729.47,507.447 1729.48,507.458 1729.49,507.47 1729.5,507.482 1729.51,507.494 1729.52,507.505 1729.53,507.517 1729.54,507.529 1729.55,507.541 1729.56,507.552 1729.57,507.564 1729.58,507.576 1729.58,507.588 1729.59,507.599 1729.6,507.611 1729.61,507.623 1729.62,507.634 1729.63,507.646 1729.64,507.658 1729.65,507.67 1729.66,507.681 1729.67,507.693 1729.68,507.705 1729.69,507.717 1729.69,507.728 1729.7,507.74 1729.71,507.752 1729.72,507.763 1729.73,507.775 1729.74,507.787 1729.75,507.799 1729.76,507.81 1729.77,507.822 1729.78,507.834 1729.79,507.845 1729.8,507.857 1729.8,507.869 1729.81,507.881 1729.82,507.892 1729.83,507.904 1729.84,507.916 1729.85,507.927 1729.86,507.939 1729.87,507.951 1729.88,507.963 1729.89,507.974 1729.9,507.986 1729.91,507.998 1729.92,508.009 1729.92,508.021 1729.93,508.033 1729.94,508.045 1729.95,508.056 1729.96,508.068 1729.97,508.08 1729.98,508.091 1729.99,508.103 1730,508.115 1730.01,508.126 1730.02,508.138 1730.03,508.15 1730.03,508.162 1730.04,508.173 1730.05,508.185 1730.06,508.197 1730.07,508.208 1730.08,508.22 1730.09,508.232 1730.1,508.243 1730.11,508.255 1730.12,508.267 1730.13,508.279 1730.14,508.29 1730.14,508.302 1730.15,508.314 1730.16,508.325 1730.17,508.337 1730.18,508.349 1730.19,508.36 1730.2,508.372 1730.21,508.384 1730.22,508.395 1730.23,508.407 1730.24,508.419 1730.25,508.43 1730.26,508.442 1730.26,508.454 1730.27,508.466 1730.28,508.477 1730.29,508.489 1730.3,508.501 1730.31,508.512 1730.32,508.524 1730.33,508.536 1730.34,508.547 1730.35,508.559 1730.36,508.571 1730.37,508.582 1730.37,508.594 1730.38,508.606 1730.39,508.617 1730.4,508.629 1730.41,508.641 1730.42,508.652 1730.43,508.664 1730.44,508.676 1730.45,508.687 1730.46,508.699 1730.47,508.711 1730.48,508.722 1730.48,508.734 1730.49,508.746 1730.5,508.757 1730.51,508.769 1730.52,508.781 1730.53,508.792 1730.54,508.804 1730.55,508.816 1730.56,508.827 1730.57,508.839 1730.58,508.851 1730.59,508.862 1730.6,508.874 1730.6,508.886 1730.61,508.897 1730.62,508.909 1730.63,508.921 1730.64,508.932 1730.65,508.944 1730.66,508.956 1730.67,508.967 1730.68,508.979 1730.69,508.991 1730.7,509.002 1730.71,509.014 1730.71,509.026 1730.72,509.037 1730.73,509.049 1730.74,509.061 1730.75,509.072 1730.76,509.084 1730.77,509.096 1730.78,509.107 1730.79,509.119 1730.8,509.131 1730.81,509.142 1730.82,509.154 1730.82,509.165 1730.83,509.177 1730.84,509.189 1730.85,509.2 1730.86,509.212 1730.87,509.224 1730.88,509.235 1730.89,509.247 1730.9,509.259 1730.91,509.27 1730.92,509.282 1730.93,509.294 1730.94,509.305 1730.94,509.317 1730.95,509.328 1730.96,509.34 1730.97,509.352 1730.98,509.363 1730.99,509.375 1731,509.387 1731.01,509.398 1731.02,509.41 1731.03,509.422 1731.04,509.433 1731.05,509.445 1731.05,509.456 1731.06,509.468 1731.07,509.48 1731.08,509.491 1731.09,509.503 1731.1,509.515 1731.11,509.526 1731.12,509.538 1731.13,509.55 1731.14,509.561 1731.15,509.573 1731.16,509.584 1731.16,509.596 1731.17,509.608 1731.18,509.619 1731.19,509.631 1731.2,509.643 1731.21,509.654 1731.22,509.666 1731.23,509.677 1731.24,509.689 1731.25,509.701 1731.26,509.712 1731.27,509.724 1731.28,509.735 1731.28,509.747 1731.29,509.759 1731.3,509.77 1731.31,509.782 1731.32,509.794 1731.33,509.805 1731.34,509.817 1731.35,509.828 1731.36,509.84 1731.37,509.852 1731.38,509.863 1731.39,509.875 1731.39,509.886 1731.4,509.898 1731.41,509.91 1731.42,509.921 1731.43,509.933 1731.44,509.944 1731.45,509.956 1731.46,509.968 1731.47,509.979 1731.48,509.991 1731.49,510.002 1731.5,510.014 1731.5,510.026 1731.51,510.037 1731.52,510.049 1731.53,510.061 1731.54,510.072 1731.55,510.084 1731.56,510.095 1731.57,510.107 1731.58,510.118 1731.59,510.13 1731.6,510.142 1731.61,510.153 1731.62,510.165 1731.62,510.176 1731.63,510.188 1731.64,510.2 1731.65,510.211 1731.66,510.223 1731.67,510.234 1731.68,510.246 1731.69,510.258 1731.7,510.269 1731.71,510.281 1731.72,510.292 1731.73,510.304 1731.73,510.316 1731.74,510.327 1731.75,510.339 1731.76,510.35 1731.77,510.362 1731.78,510.373 1731.79,510.385 1731.8,510.397 1731.81,510.408 1731.82,510.42 1731.83,510.431 1731.84,510.443 1731.84,510.455 1731.85,510.466 1731.86,510.478 1731.87,510.489 1731.88,510.501 1731.89,510.512 1731.9,510.524 1731.91,510.536 1731.92,510.547 1731.93,510.559 1731.94,510.57 1731.95,510.582 1731.96,510.593 1731.96,510.605 1731.97,510.617 1731.98,510.628 1731.99,510.64 1732,510.651 1732.01,510.663 1732.02,510.674 1732.03,510.686 1732.04,510.698 1732.05,510.709 1732.06,510.721 1732.07,510.732 1732.07,510.744 1732.08,510.755 1732.09,510.767 1732.1,510.779 1732.11,510.79 1732.12,510.802 1732.13,510.813 1732.14,510.825 1732.15,510.836 1732.16,510.848 1732.17,510.859 1732.18,510.871 1732.18,510.883 1732.19,510.894 1732.2,510.906 1732.21,510.917 1732.22,510.929 1732.23,510.94 1732.24,510.952 1732.25,510.963 1732.26,510.975 1732.27,510.987 1732.28,510.998 1732.29,511.01 1732.3,511.021 1732.3,511.033 1732.31,511.044 1732.32,511.056 1732.33,511.067 1732.34,511.079 1732.35,511.091 1732.36,511.102 1732.37,511.114 1732.38,511.125 1732.39,511.137 1732.4,511.148 1732.41,511.16 1732.41,511.171 1732.42,511.183 1732.43,511.194 1732.44,511.206 1732.45,511.217 1732.46,511.229 1732.47,511.241 1732.48,511.252 1732.49,511.264 1732.5,511.275 1732.51,511.287 1732.52,511.298 1732.52,511.31 1732.53,511.321 1732.54,511.333 1732.55,511.344 1732.56,511.356 1732.57,511.367 1732.58,511.379 1732.59,511.391 1732.6,511.402 1732.61,511.414 1732.62,511.425 1732.63,511.437 1732.64,511.448 1732.64,511.46 1732.65,511.471 1732.66,511.483 1732.67,511.494 1732.68,511.506 1732.69,511.517 1732.7,511.529 1732.71,511.54 1732.72,511.552 1732.73,511.563 1732.74,511.575 1732.75,511.586 1732.75,511.598 1732.76,511.609 1732.77,511.621 1732.78,511.633 1732.79,511.644 1732.8,511.656 1732.81,511.667 1732.82,511.679 1732.83,511.69 1732.84,511.702 1732.85,511.713 1732.86,511.725 1732.86,511.736 1732.87,511.748 1732.88,511.759 1732.89,511.771 1732.9,511.782 1732.91,511.794 1732.92,511.805 1732.93,511.817 1732.94,511.828 1732.95,511.84 1732.96,511.851 1732.97,511.863 1732.98,511.874 1732.98,511.886 1732.99,511.897 1733,511.909 1733.01,511.92 1733.02,511.932 1733.03,511.943 1733.04,511.955 1733.05,511.966 1733.06,511.978 1733.07,511.989 1733.08,512.001 1733.09,512.012 1733.09,512.024 1733.1,512.035 1733.11,512.047 1733.12,512.058 1733.13,512.07 1733.14,512.081 1733.15,512.093 1733.16,512.104 1733.17,512.116 1733.18,512.127 1733.19,512.139 1733.2,512.15 1733.2,512.162 1733.21,512.173 1733.22,512.185 1733.23,512.196 1733.24,512.208 1733.25,512.219 1733.26,512.231 1733.27,512.242 1733.28,512.254 1733.29,512.265 1733.3,512.277 1733.31,512.288 1733.32,512.3 1733.32,512.311 1733.33,512.323 1733.34,512.334 1733.35,512.345 1733.36,512.357 1733.37,512.368 1733.38,512.38 1733.39,512.391 1733.4,512.403 1733.41,512.414 1733.42,512.426 1733.43,512.437 1733.43,512.449 1733.44,512.46 1733.45,512.472 1733.46,512.483 1733.47,512.495 1733.48,512.506 1733.49,512.518 1733.5,512.529 1733.51,512.541 1733.52,512.552 1733.53,512.564 1733.54,512.575 1733.54,512.586 1733.55,512.598 1733.56,512.609 1733.57,512.621 1733.58,512.632 1733.59,512.644 1733.6,512.655 1733.61,512.667 1733.62,512.678 1733.63,512.69 1733.64,512.701 1733.65,512.713 1733.66,512.724 1733.66,512.735 1733.67,512.747 1733.68,512.758 1733.69,512.77 1733.7,512.781 1733.71,512.793 1733.72,512.804 1733.73,512.816 1733.74,512.827 1733.75,512.839 1733.76,512.85 1733.77,512.862 1733.77,512.873 1733.78,512.884 1733.79,512.896 1733.8,512.907 1733.81,512.919 1733.82,512.93 1733.83,512.942 1733.84,512.953 1733.85,512.965 1733.86,512.976 1733.87,512.987 1733.88,512.999 1733.88,513.01 1733.89,513.022 1733.9,513.033 1733.91,513.045 1733.92,513.056 1733.93,513.068 1733.94,513.079 1733.95,513.09 1733.96,513.102 1733.97,513.113 1733.98,513.125 1733.99,513.136 1734,513.148 1734,513.159 1734.01,513.171 1734.02,513.182 1734.03,513.193 1734.04,513.205 1734.05,513.216 1734.06,513.228 1734.07,513.239 1734.08,513.251 1734.09,513.262 1734.1,513.273 1734.11,513.285 1734.11,513.296 1734.12,513.308 1734.13,513.319 1734.14,513.331 1734.15,513.342 1734.16,513.353 1734.17,513.365 1734.18,513.376 1734.19,513.388 1734.2,513.399 1734.21,513.411 1734.22,513.422 1734.22,513.433 1734.23,513.445 1734.24,513.456 1734.25,513.468 1734.26,513.479 1734.27,513.491 1734.28,513.502 1734.29,513.513 1734.3,513.525 1734.31,513.536 1734.32,513.548 1734.33,513.559 1734.34,513.571 1734.34,513.582 1734.35,513.593 1734.36,513.605 1734.37,513.616 1734.38,513.628 1734.39,513.639 1734.4,513.65 1734.41,513.662 1734.42,513.673 1734.43,513.685 1734.44,513.696 1734.45,513.707 1734.45,513.719 1734.46,513.73 1734.47,513.742 1734.48,513.753 1734.49,513.765 1734.5,513.776 1734.51,513.787 1734.52,513.799 1734.53,513.81 1734.54,513.822 1734.55,513.833 1734.56,513.844 1734.56,513.856 1734.57,513.867 1734.58,513.879 1734.59,513.89 1734.6,513.901 1734.61,513.913 1734.62,513.924 1734.63,513.936 1734.64,513.947 1734.65,513.958 1734.66,513.97 1734.67,513.981 1734.68,513.993 1734.68,514.004 1734.69,514.015 1734.7,514.027 1734.71,514.038 1734.72,514.049 1734.73,514.061 1734.74,514.072 1734.75,514.084 1734.76,514.095 1734.77,514.106 1734.78,514.118 1734.79,514.129 1734.79,514.141 1734.8,514.152 1734.81,514.163 1734.82,514.175 1734.83,514.186 1734.84,514.198 1734.85,514.209 1734.86,514.22 1734.87,514.232 1734.88,514.243 1734.89,514.254 1734.9,514.266 1734.9,514.277 1734.91,514.289 1734.92,514.3 1734.93,514.311 1734.94,514.323 1734.95,514.334 1734.96,514.345 1734.97,514.357 1734.98,514.368 1734.99,514.38 1735,514.391 1735.01,514.402 1735.02,514.414 1735.02,514.425 1735.03,514.436 1735.04,514.448 1735.05,514.459 1735.06,514.471 1735.07,514.482 1735.08,514.493 1735.09,514.505 1735.1,514.516 1735.11,514.527 1735.12,514.539 1735.13,514.55 1735.13,514.562 1735.14,514.573 1735.15,514.584 1735.16,514.596 1735.17,514.607 1735.18,514.618 1735.19,514.63 1735.2,514.641 1735.21,514.652 1735.22,514.664 1735.23,514.675 1735.24,514.687 1735.24,514.698 1735.25,514.709 1735.26,514.721 1735.27,514.732 1735.28,514.743 1735.29,514.755 1735.3,514.766 1735.31,514.777 1735.32,514.789 1735.33,514.8 1735.34,514.811 1735.35,514.823 1735.36,514.834 1735.36,514.845 1735.37,514.857 1735.38,514.868 1735.39,514.88 1735.4,514.891 1735.41,514.902 1735.42,514.914 1735.43,514.925 1735.44,514.936 1735.45,514.948 1735.46,514.959 1735.47,514.97 1735.47,514.982 1735.48,514.993 1735.49,515.004 1735.5,515.016 1735.51,515.027 1735.52,515.038 1735.53,515.05 1735.54,515.061 1735.55,515.072 1735.56,515.084 1735.57,515.095 1735.58,515.106 1735.58,515.118 1735.59,515.129 1735.6,515.14 1735.61,515.152 1735.62,515.163 1735.63,515.174 1735.64,515.186 1735.65,515.197 1735.66,515.208 1735.67,515.22 1735.68,515.231 1735.69,515.242 1735.7,515.254 1735.7,515.265 1735.71,515.276 1735.72,515.288 1735.73,515.299 1735.74,515.31 1735.75,515.322 1735.76,515.333 1735.77,515.344 1735.78,515.356 1735.79,515.367 1735.8,515.378 1735.81,515.39 1735.81,515.401 1735.82,515.412 1735.83,515.424 1735.84,515.435 1735.85,515.446 1735.86,515.458 1735.87,515.469 1735.88,515.48 1735.89,515.492 1735.9,515.503 1735.91,515.514 1735.92,515.525 1735.92,515.537 1735.93,515.548 1735.94,515.559 1735.95,515.571 1735.96,515.582 1735.97,515.593 1735.98,515.605 1735.99,515.616 1736,515.627 1736.01,515.639 1736.02,515.65 1736.03,515.661 1736.04,515.673 1736.04,515.684 1736.05,515.695 1736.06,515.706 1736.07,515.718 1736.08,515.729 1736.09,515.74 1736.1,515.752 1736.11,515.763 1736.12,515.774 1736.13,515.786 1736.14,515.797 1736.15,515.808 1736.15,515.819 1736.16,515.831 1736.17,515.842 1736.18,515.853 1736.19,515.865 1736.2,515.876 1736.21,515.887 1736.22,515.899 1736.23,515.91 1736.24,515.921 1736.25,515.932 1736.26,515.944 1736.26,515.955 1736.27,515.966 1736.28,515.978 1736.29,515.989 1736.3,516 1736.31,516.012 1736.32,516.023 1736.33,516.034 1736.34,516.045 1736.35,516.057 1736.36,516.068 1736.37,516.079 1736.38,516.091 1736.38,516.102 1736.39,516.113 1736.4,516.124 1736.41,516.136 1736.42,516.147 1736.43,516.158 1736.44,516.17 1736.45,516.181 1736.46,516.192 1736.47,516.203 1736.48,516.215 1736.49,516.226 1736.49,516.237 1736.5,516.248 1736.51,516.26 1736.52,516.271 1736.53,516.282 1736.54,516.294 1736.55,516.305 1736.56,516.316 1736.57,516.327 1736.58,516.339 1736.59,516.35 1736.6,516.361 1736.6,516.372 1736.61,516.384 1736.62,516.395 1736.63,516.406 1736.64,516.418 1736.65,516.429 1736.66,516.44 1736.67,516.451 1736.68,516.463 1736.69,516.474 1736.7,516.485 1736.71,516.496 1736.72,516.508 1736.72,516.519 1736.73,516.53 1736.74,516.542 1736.75,516.553 1736.76,516.564 1736.77,516.575 1736.78,516.587 1736.79,516.598 1736.8,516.609 1736.81,516.62 1736.82,516.632 1736.83,516.643 1736.83,516.654 1736.84,516.665 1736.85,516.677 1736.86,516.688 1736.87,516.699 1736.88,516.71 1736.89,516.722 1736.9,516.733 1736.91,516.744 1736.92,516.755 1736.93,516.767 1736.94,516.778 1736.94,516.789 1736.95,516.8 1736.96,516.812 1736.97,516.823 1736.98,516.834 1736.99,516.845 1737,516.857 1737.01,516.868 1737.02,516.879 1737.03,516.89 1737.04,516.902 1737.05,516.913 1737.06,516.924 1737.06,516.935 1737.07,516.947 1737.08,516.958 1737.09,516.969 1737.1,516.98 1737.11,516.992 1737.12,517.003 1737.13,517.014 1737.14,517.025 1737.15,517.037 1737.16,517.048 1737.17,517.059 1737.17,517.07 1737.18,517.081 1737.19,517.093 1737.2,517.104 1737.21,517.115 1737.22,517.126 1737.23,517.138 1737.24,517.149 1737.25,517.16 1737.26,517.171 1737.27,517.183 1737.28,517.194 1737.28,517.205 1737.29,517.216 1737.3,517.227 1737.31,517.239 1737.32,517.25 1737.33,517.261 1737.34,517.272 1737.35,517.284 1737.36,517.295 1737.37,517.306 1737.38,517.317 1737.39,517.328 1737.4,517.34 1737.4,517.351 1737.41,517.362 1737.42,517.373 1737.43,517.385 1737.44,517.396 1737.45,517.407 1737.46,517.418 1737.47,517.429 1737.48,517.441 1737.49,517.452 1737.5,517.463 1737.51,517.474 1737.51,517.486 1737.52,517.497 1737.53,517.508 1737.54,517.519 1737.55,517.53 1737.56,517.542 1737.57,517.553 1737.58,517.564 1737.59,517.575 1737.6,517.586 1737.61,517.598 1737.62,517.609 1737.62,517.62 1737.63,517.631 1737.64,517.642 1737.65,517.654 1737.66,517.665 1737.67,517.676 1737.68,517.687 1737.69,517.699 1737.7,517.71 1737.71,517.721 1737.72,517.732 1737.73,517.743 1737.74,517.755 1737.74,517.766 1737.75,517.777 1737.76,517.788 1737.77,517.799 1737.78,517.811 1737.79,517.822 1737.8,517.833 1737.81,517.844 1737.82,517.855 1737.83,517.867 1737.84,517.878 1737.85,517.889 1737.85,517.9 1737.86,517.911 1737.87,517.922 1737.88,517.934 1737.89,517.945 1737.9,517.956 1737.91,517.967 1737.92,517.978 1737.93,517.99 1737.94,518.001 1737.95,518.012 1737.96,518.023 1737.96,518.034 1737.97,518.046 1737.98,518.057 1737.99,518.068 1738,518.079 1738.01,518.09 1738.02,518.101 1738.03,518.113 1738.04,518.124 1738.05,518.135 1738.06,518.146 1738.07,518.157 1738.08,518.169 1738.08,518.18 1738.09,518.191 1738.1,518.202 1738.11,518.213 1738.12,518.224 1738.13,518.236 1738.14,518.247 1738.15,518.258 1738.16,518.269 1738.17,518.28 1738.18,518.291 1738.19,518.303 1738.19,518.314 1738.2,518.325 1738.21,518.336 1738.22,518.347 1738.23,518.359 1738.24,518.37 1738.25,518.381 1738.26,518.392 1738.27,518.403 1738.28,518.414 1738.29,518.426 1738.3,518.437 1738.3,518.448 1738.31,518.459 1738.32,518.47 1738.33,518.481 1738.34,518.493 1738.35,518.504 1738.36,518.515 1738.37,518.526 1738.38,518.537 1738.39,518.548 1738.4,518.559 1738.41,518.571 1738.42,518.582 1738.42,518.593 1738.43,518.604 1738.44,518.615 1738.45,518.626 1738.46,518.638 1738.47,518.649 1738.48,518.66 1738.49,518.671 1738.5,518.682 1738.51,518.693 1738.52,518.704 1738.53,518.716 1738.53,518.727 1738.54,518.738 1738.55,518.749 1738.56,518.76 1738.57,518.771 1738.58,518.783 1738.59,518.794 1738.6,518.805 1738.61,518.816 1738.62,518.827 1738.63,518.838 1738.64,518.849 1738.64,518.861 1738.65,518.872 1738.66,518.883 1738.67,518.894 1738.68,518.905 1738.69,518.916 1738.7,518.927 1738.71,518.939 1738.72,518.95 1738.73,518.961 1738.74,518.972 1738.75,518.983 1738.76,518.994 1738.76,519.005 1738.77,519.017 1738.78,519.028 1738.79,519.039 1738.8,519.05 1738.81,519.061 1738.82,519.072 1738.83,519.083 1738.84,519.094 1738.85,519.106 1738.86,519.117 1738.87,519.128 1738.87,519.139 1738.88,519.15 1738.89,519.161 1738.9,519.172 1738.91,519.183 1738.92,519.195 1738.93,519.206 1738.94,519.217 1738.95,519.228 1738.96,519.239 1738.97,519.25 1738.98,519.261 1738.98,519.272 1738.99,519.284 1739,519.295 1739.01,519.306 1739.02,519.317 1739.03,519.328 1739.04,519.339 1739.05,519.35 1739.06,519.361 1739.07,519.373 1739.08,519.384 1739.09,519.395 1739.1,519.406 1739.1,519.417 1739.11,519.428 1739.12,519.439 1739.13,519.45 1739.14,519.461 1739.15,519.473 1739.16,519.484 1739.17,519.495 1739.18,519.506 1739.19,519.517 1739.2,519.528 1739.21,519.539 1739.21,519.55 1739.22,519.561 1739.23,519.573 1739.24,519.584 1739.25,519.595 1739.26,519.606 1739.27,519.617 1739.28,519.628 1739.29,519.639 1739.3,519.65 1739.31,519.661 1739.32,519.673 1739.32,519.684 1739.33,519.695 1739.34,519.706 1739.35,519.717 1739.36,519.728 1739.37,519.739 1739.38,519.75 1739.39,519.761 1739.4,519.772 1739.41,519.784 1739.42,519.795 1739.43,519.806 1739.44,519.817 1739.44,519.828 1739.45,519.839 1739.46,519.85 1739.47,519.861 1739.48,519.872 1739.49,519.883 1739.5,519.894 1739.51,519.906 1739.52,519.917 1739.53,519.928 1739.54,519.939 1739.55,519.95 1739.55,519.961 1739.56,519.972 1739.57,519.983 1739.58,519.994 1739.59,520.005 1739.6,520.016 1739.61,520.027 1739.62,520.039 1739.63,520.05 1739.64,520.061 1739.65,520.072 1739.66,520.083 1739.66,520.094 1739.67,520.105 1739.68,520.116 1739.69,520.127 1739.7,520.138 1739.71,520.149 1739.72,520.16 1739.73,520.172 1739.74,520.183 1739.75,520.194 1739.76,520.205 1739.77,520.216 1739.78,520.227 1739.78,520.238 1739.79,520.249 1739.8,520.26 1739.81,520.271 1739.82,520.282 1739.83,520.293 1739.84,520.304 1739.85,520.315 1739.86,520.327 1739.87,520.338 1739.88,520.349 1739.89,520.36 1739.89,520.371 1739.9,520.382 1739.91,520.393 1739.92,520.404 1739.93,520.415 1739.94,520.426 1739.95,520.437 1739.96,520.448 1739.97,520.459 1739.98,520.47 1739.99,520.481 1740,520.492 1740,520.504 1740.01,520.515 1740.02,520.526 1740.03,520.537 1740.04,520.548 1740.05,520.559 1740.06,520.57 1740.07,520.581 1740.08,520.592 1740.09,520.603 1740.1,520.614 1740.11,520.625 1740.12,520.636 1740.12,520.647 1740.13,520.658 1740.14,520.669 1740.15,520.68 1740.16,520.691 1740.17,520.703 1740.18,520.714 1740.19,520.725 1740.2,520.736 1740.21,520.747 1740.22,520.758 1740.23,520.769 1740.23,520.78 1740.24,520.791 1740.25,520.802 1740.26,520.813 1740.27,520.824 1740.28,520.835 1740.29,520.846 1740.3,520.857 1740.31,520.868 1740.32,520.879 1740.33,520.89 1740.34,520.901 1740.34,520.912 1740.35,520.923 1740.36,520.934 1740.37,520.945 1740.38,520.957 1740.39,520.968 1740.4,520.979 1740.41,520.99 1740.42,521.001 1740.43,521.012 1740.44,521.023 1740.45,521.034 1740.46,521.045 1740.46,521.056 1740.47,521.067 1740.48,521.078 1740.49,521.089 1740.5,521.1 1740.51,521.111 1740.52,521.122 1740.53,521.133 1740.54,521.144 1740.55,521.155 1740.56,521.166 1740.57,521.177 1740.57,521.188 1740.58,521.199 1740.59,521.21 1740.6,521.221 1740.61,521.232 1740.62,521.243 1740.63,521.254 1740.64,521.265 1740.65,521.276 1740.66,521.287 1740.67,521.298 1740.68,521.309 1740.68,521.32 1740.69,521.331 1740.7,521.342 1740.71,521.353 1740.72,521.364 1740.73,521.375 1740.74,521.386 1740.75,521.398 1740.76,521.409 1740.77,521.42 1740.78,521.431 1740.79,521.442 1740.8,521.453 1740.8,521.464 1740.81,521.475 1740.82,521.486 1740.83,521.497 1740.84,521.508 1740.85,521.519 1740.86,521.53 1740.87,521.541 1740.88,521.552 1740.89,521.563 1740.9,521.574 1740.91,521.585 1740.91,521.596 1740.92,521.607 1740.93,521.618 1740.94,521.629 1740.95,521.64 1740.96,521.651 1740.97,521.662 1740.98,521.673 1740.99,521.684 1741,521.695 1741.01,521.706 1741.02,521.717 1741.02,521.728 1741.03,521.739 1741.04,521.75 1741.05,521.761 1741.06,521.772 1741.07,521.783 1741.08,521.794 1741.09,521.805 1741.1,521.816 1741.11,521.827 1741.12,521.838 1741.13,521.849 1741.14,521.86 1741.14,521.871 1741.15,521.882 1741.16,521.893 1741.17,521.904 1741.18,521.915 1741.19,521.926 1741.2,521.936 1741.21,521.947 1741.22,521.958 1741.23,521.969 1741.24,521.98 1741.25,521.991 1741.25,522.002 1741.26,522.013 1741.27,522.024 1741.28,522.035 1741.29,522.046 1741.3,522.057 1741.31,522.068 1741.32,522.079 1741.33,522.09 1741.34,522.101 1741.35,522.112 1741.36,522.123 1741.36,522.134 1741.37,522.145 1741.38,522.156 1741.39,522.167 1741.4,522.178 1741.41,522.189 1741.42,522.2 1741.43,522.211 1741.44,522.222 1741.45,522.233 1741.46,522.244 1741.47,522.255 1741.48,522.266 1741.48,522.277 1741.49,522.288 1741.5,522.299 1741.51,522.31 1741.52,522.321 1741.53,522.332 1741.54,522.343 1741.55,522.354 1741.56,522.365 1741.57,522.375 1741.58,522.386 1741.59,522.397 1741.59,522.408 1741.6,522.419 1741.61,522.43 1741.62,522.441 1741.63,522.452 1741.64,522.463 1741.65,522.474 1741.66,522.485 1741.67,522.496 1741.68,522.507 1741.69,522.518 1741.7,522.529 1741.7,522.54 1741.71,522.551 1741.72,522.562 1741.73,522.573 1741.74,522.584 1741.75,522.595 1741.76,522.606 1741.77,522.617 1741.78,522.628 1741.79,522.638 1741.8,522.649 1741.81,522.66 1741.82,522.671 1741.82,522.682 1741.83,522.693 1741.84,522.704 1741.85,522.715 1741.86,522.726 1741.87,522.737 1741.88,522.748 1741.89,522.759 1741.9,522.77 1741.91,522.781 1741.92,522.792 1741.93,522.803 1741.93,522.814 1741.94,522.825 1741.95,522.835 1741.96,522.846 1741.97,522.857 1741.98,522.868 1741.99,522.879 1742,522.89 1742.01,522.901 1742.02,522.912 1742.03,522.923 1742.04,522.934 1742.04,522.945 1742.05,522.956 1742.06,522.967 1742.07,522.978 1742.08,522.989 1742.09,523 1742.1,523.01 1742.11,523.021 1742.12,523.032 1742.13,523.043 1742.14,523.054 1742.15,523.065 1742.16,523.076 1742.16,523.087 1742.17,523.098 1742.18,523.109 1742.19,523.12 1742.2,523.131 1742.21,523.142 1742.22,523.153 1742.23,523.163 1742.24,523.174 1742.25,523.185 1742.26,523.196 1742.27,523.207 1742.27,523.218 1742.28,523.229 1742.29,523.24 1742.3,523.251 1742.31,523.262 1742.32,523.273 1742.33,523.284 1742.34,523.294 1742.35,523.305 1742.36,523.316 1742.37,523.327 1742.38,523.338 1742.38,523.349 1742.39,523.36 1742.4,523.371 1742.41,523.382 1742.42,523.393 1742.43,523.404 1742.44,523.415 1742.45,523.425 1742.46,523.436 1742.47,523.447 1742.48,523.458 1742.49,523.469 1742.5,523.48 1742.5,523.491 1742.51,523.502 1742.52,523.513 1742.53,523.524 1742.54,523.535 1742.55,523.545 1742.56,523.556 1742.57,523.567 1742.58,523.578 1742.59,523.589 1742.6,523.6 1742.61,523.611 1742.61,523.622 1742.62,523.633 1742.63,523.644 1742.64,523.654 1742.65,523.665 1742.66,523.676 1742.67,523.687 1742.68,523.698 1742.69,523.709 1742.7,523.72 1742.71,523.731 1742.72,523.742 1742.72,523.752 1742.73,523.763 1742.74,523.774 1742.75,523.785 1742.76,523.796 1742.77,523.807 1742.78,523.818 1742.79,523.829 1742.8,523.84 1742.81,523.851 1742.82,523.861 1742.83,523.872 1742.84,523.883 1742.84,523.894 1742.85,523.905 1742.86,523.916 1742.87,523.927 1742.88,523.938 1742.89,523.948 1742.9,523.959 1742.91,523.97 1742.92,523.981 1742.93,523.992 1742.94,524.003 1742.95,524.014 1742.95,524.025 1742.96,524.036 1742.97,524.046 1742.98,524.057 1742.99,524.068 1743,524.079 1743.01,524.09 1743.02,524.101 1743.03,524.112 1743.04,524.123 1743.05,524.133 1743.06,524.144 1743.06,524.155 1743.07,524.166 1743.08,524.177 1743.09,524.188 1743.1,524.199 1743.11,524.21 1743.12,524.22 1743.13,524.231 1743.14,524.242 1743.15,524.253 1743.16,524.264 1743.17,524.275 1743.18,524.286 1743.18,524.296 1743.19,524.307 1743.2,524.318 1743.21,524.329 1743.22,524.34 1743.23,524.351 1743.24,524.362 1743.25,524.373 1743.26,524.383 1743.27,524.394 1743.28,524.405 1743.29,524.416 1743.29,524.427 1743.3,524.438 1743.31,524.449 1743.32,524.459 1743.33,524.47 1743.34,524.481 1743.35,524.492 1743.36,524.503 1743.37,524.514 1743.38,524.525 1743.39,524.535 1743.4,524.546 1743.4,524.557 1743.41,524.568 1743.42,524.579 1743.43,524.59 1743.44,524.6 1743.45,524.611 1743.46,524.622 1743.47,524.633 1743.48,524.644 1743.49,524.655 1743.5,524.666 1743.51,524.676 1743.52,524.687 1743.52,524.698 1743.53,524.709 1743.54,524.72 1743.55,524.731 1743.56,524.742 1743.57,524.752 1743.58,524.763 1743.59,524.774 1743.6,524.785 1743.61,524.796 1743.62,524.807 1743.63,524.817 1743.63,524.828 1743.64,524.839 1743.65,524.85 1743.66,524.861 1743.67,524.872 1743.68,524.882 1743.69,524.893 1743.7,524.904 1743.71,524.915 1743.72,524.926 1743.73,524.937 1743.74,524.947 1743.74,524.958 1743.75,524.969 1743.76,524.98 1743.77,524.991 1743.78,525.002 1743.79,525.012 1743.8,525.023 1743.81,525.034 1743.82,525.045 1743.83,525.056 1743.84,525.067 1743.85,525.077 1743.86,525.088 1743.86,525.099 1743.87,525.11 1743.88,525.121 1743.89,525.132 1743.9,525.142 1743.91,525.153 1743.92,525.164 1743.93,525.175 1743.94,525.186 1743.95,525.196 1743.96,525.207 1743.97,525.218 1743.97,525.229 1743.98,525.24 1743.99,525.251 1744,525.261 1744.01,525.272 1744.02,525.283 1744.03,525.294 1744.04,525.305 1744.05,525.315 1744.06,525.326 1744.07,525.337 1744.08,525.348 1744.08,525.359 1744.09,525.369 1744.1,525.38 1744.11,525.391 1744.12,525.402 1744.13,525.413 1744.14,525.424 1744.15,525.434 1744.16,525.445 1744.17,525.456 1744.18,525.467 1744.19,525.478 1744.2,525.488 1744.2,525.499 1744.21,525.51 1744.22,525.521 1744.23,525.532 1744.24,525.542 1744.25,525.553 1744.26,525.564 1744.27,525.575 1744.28,525.586 1744.29,525.596 1744.3,525.607 1744.31,525.618 1744.31,525.629 1744.32,525.64 1744.33,525.65 1744.34,525.661 1744.35,525.672 1744.36,525.683 1744.37,525.694 1744.38,525.704 1744.39,525.715 1744.4,525.726 1744.41,525.737 1744.42,525.748 1744.42,525.758 1744.43,525.769 1744.44,525.78 1744.45,525.791 1744.46,525.802 1744.47,525.812 1744.48,525.823 1744.49,525.834 1744.5,525.845 1744.51,525.855 1744.52,525.866 1744.53,525.877 1744.54,525.888 1744.54,525.899 1744.55,525.909 1744.56,525.92 1744.57,525.931 1744.58,525.942 1744.59,525.953 1744.6,525.963 1744.61,525.974 1744.62,525.985 1744.63,525.996 1744.64,526.006 1744.65,526.017 1744.65,526.028 1744.66,526.039 1744.67,526.05 1744.68,526.06 1744.69,526.071 1744.7,526.082 1744.71,526.093 1744.72,526.103 1744.73,526.114 1744.74,526.125 1744.75,526.136 1744.76,526.146 1744.76,526.157 1744.77,526.168 1744.78,526.179 1744.79,526.19 1744.8,526.2 1744.81,526.211 1744.82,526.222 1744.83,526.233 1744.84,526.243 1744.85,526.254 1744.86,526.265 1744.87,526.276 1744.88,526.286 1744.88,526.297 1744.89,526.308 1744.9,526.319 1744.91,526.33 1744.92,526.34 1744.93,526.351 1744.94,526.362 1744.95,526.373 1744.96,526.383 1744.97,526.394 1744.98,526.405 1744.99,526.416 1744.99,526.426 1745,526.437 1745.01,526.448 1745.02,526.459 1745.03,526.469 1745.04,526.48 1745.05,526.491 1745.06,526.502 1745.07,526.512 1745.08,526.523 1745.09,526.534 1745.1,526.545 1745.1,526.555 1745.11,526.566 1745.12,526.577 1745.13,526.588 1745.14,526.598 1745.15,526.609 1745.16,526.62 1745.17,526.631 1745.18,526.641 1745.19,526.652 1745.2,526.663 1745.21,526.674 1745.22,526.684 1745.22,526.695 1745.23,526.706 1745.24,526.717 1745.25,526.727 1745.26,526.738 1745.27,526.749 1745.28,526.76 1745.29,526.77 1745.3,526.781 1745.31,526.792 1745.32,526.803 1745.33,526.813 1745.33,526.824 1745.34,526.835 1745.35,526.846 1745.36,526.856 1745.37,526.867 1745.38,526.878 1745.39,526.888 1745.4,526.899 1745.41,526.91 1745.42,526.921 1745.43,526.931 1745.44,526.942 1745.44,526.953 1745.45,526.964 1745.46,526.974 1745.47,526.985 1745.48,526.996 1745.49,527.007 1745.5,527.017 1745.51,527.028 1745.52,527.039 1745.53,527.049 1745.54,527.06 1745.55,527.071 1745.56,527.082 1745.56,527.092 1745.57,527.103 1745.58,527.114 1745.59,527.124 1745.6,527.135 1745.61,527.146 1745.62,527.157 1745.63,527.167 1745.64,527.178 1745.65,527.189 1745.66,527.2 1745.67,527.21 1745.67,527.221 1745.68,527.232 1745.69,527.242 1745.7,527.253 1745.71,527.264 1745.72,527.275 1745.73,527.285 1745.74,527.296 1745.75,527.307 1745.76,527.317 1745.77,527.328 1745.78,527.339 1745.78,527.35 1745.79,527.36 1745.8,527.371 1745.81,527.382 1745.82,527.392 1745.83,527.403 1745.84,527.414 1745.85,527.424 1745.86,527.435 1745.87,527.446 1745.88,527.457 1745.89,527.467 1745.9,527.478 1745.9,527.489 1745.91,527.499 1745.92,527.51 1745.93,527.521 1745.94,527.532 1745.95,527.542 1745.96,527.553 1745.97,527.564 1745.98,527.574 1745.99,527.585 1746,527.596 1746.01,527.606 1746.01,527.617 1746.02,527.628 1746.03,527.639 1746.04,527.649 1746.05,527.66 1746.06,527.671 1746.07,527.681 1746.08,527.692 1746.09,527.703 1746.1,527.713 1746.11,527.724 1746.12,527.735 1746.12,527.745 1746.13,527.756 1746.14,527.767 1746.15,527.778 1746.16,527.788 1746.17,527.799 1746.18,527.81 1746.19,527.82 1746.2,527.831 1746.21,527.842 1746.22,527.852 1746.23,527.863 1746.24,527.874 1746.24,527.884 1746.25,527.895 1746.26,527.906 1746.27,527.916 1746.28,527.927 1746.29,527.938 1746.3,527.949 1746.31,527.959 1746.32,527.97 1746.33,527.981 1746.34,527.991 1746.35,528.002 1746.35,528.013 1746.36,528.023 1746.37,528.034 1746.38,528.045 1746.39,528.055 1746.4,528.066 1746.41,528.077 1746.42,528.087 1746.43,528.098 1746.44,528.109 1746.45,528.119 1746.46,528.13 1746.46,528.141 1746.47,528.151 1746.48,528.162 1746.49,528.173 1746.5,528.183 1746.51,528.194 1746.52,528.205 1746.53,528.215 1746.54,528.226 1746.55,528.237 1746.56,528.247 1746.57,528.258 1746.58,528.269 1746.58,528.279 1746.59,528.29 1746.6,528.301 1746.61,528.311 1746.62,528.322 1746.63,528.333 1746.64,528.343 1746.65,528.354 1746.66,528.365 1746.67,528.375 1746.68,528.386 1746.69,528.397 1746.69,528.407 1746.7,528.418 1746.71,528.429 1746.72,528.439 1746.73,528.45 1746.74,528.461 1746.75,528.471 1746.76,528.482 1746.77,528.493 1746.78,528.503 1746.79,528.514 1746.8,528.524 1746.8,528.535 1746.81,528.546 1746.82,528.556 1746.83,528.567 1746.84,528.578 1746.85,528.588 1746.86,528.599 1746.87,528.61 1746.88,528.62 1746.89,528.631 1746.9,528.642 1746.91,528.652 1746.92,528.663 1746.92,528.674 1746.93,528.684 1746.94,528.695 1746.95,528.705 1746.96,528.716 1746.97,528.727 1746.98,528.737 1746.99,528.748 1747,528.759 1747.01,528.769 1747.02,528.78 1747.03,528.791 1747.03,528.801 1747.04,528.812 1747.05,528.823 1747.06,528.833 1747.07,528.844 1747.08,528.854 1747.09,528.865 1747.1,528.876 1747.11,528.886 1747.12,528.897 1747.13,528.908 1747.14,528.918 1747.14,528.929 1747.15,528.94 1747.16,528.95 1747.17,528.961 1747.18,528.971 1747.19,528.982 1747.2,528.993 1747.21,529.003 1747.22,529.014 1747.23,529.025 1747.24,529.035 1747.25,529.046 1747.26,529.056 1747.26,529.067 1747.27,529.078 1747.28,529.088 1747.29,529.099 1747.3,529.11 1747.31,529.12 1747.32,529.131 1747.33,529.141 1747.34,529.152 1747.35,529.163 1747.36,529.173 1747.37,529.184 1747.37,529.194 1747.38,529.205 1747.39,529.216 1747.4,529.226 1747.41,529.237 1747.42,529.248 1747.43,529.258 1747.44,529.269 1747.45,529.279 1747.46,529.29 1747.47,529.301 1747.48,529.311 1747.48,529.322 1747.49,529.332 1747.5,529.343 1747.51,529.354 1747.52,529.364 1747.53,529.375 1747.54,529.386 1747.55,529.396 1747.56,529.407 1747.57,529.417 1747.58,529.428 1747.59,529.439 1747.6,529.449 1747.6,529.46 1747.61,529.47 1747.62,529.481 1747.63,529.492 1747.64,529.502 1747.65,529.513 1747.66,529.523 1747.67,529.534 1747.68,529.545 1747.69,529.555 1747.7,529.566 1747.71,529.576 1747.71,529.587 1747.72,529.598 1747.73,529.608 1747.74,529.619 1747.75,529.629 1747.76,529.64 1747.77,529.651 1747.78,529.661 1747.79,529.672 1747.8,529.682 1747.81,529.693 1747.82,529.704 1747.82,529.714 1747.83,529.725 1747.84,529.735 1747.85,529.746 1747.86,529.756 1747.87,529.767 1747.88,529.778 1747.89,529.788 1747.9,529.799 1747.91,529.809 1747.92,529.82 1747.93,529.831 1747.94,529.841 1747.94,529.852 1747.95,529.862 1747.96,529.873 1747.97,529.884 1747.98,529.894 1747.99,529.905 1748,529.915 1748.01,529.926 1748.02,529.936 1748.03,529.947 1748.04,529.958 1748.05,529.968 1748.05,529.979 1748.06,529.989 1748.07,530 1748.08,530.01 1748.09,530.021 1748.1,530.032 1748.11,530.042 1748.12,530.053 1748.13,530.063 1748.14,530.074 1748.15,530.085 1748.16,530.095 1748.16,530.106 1748.17,530.116 1748.18,530.127 1748.19,530.137 1748.2,530.148 1748.21,530.159 1748.22,530.169 1748.23,530.18 1748.24,530.19 1748.25,530.201 1748.26,530.211 1748.27,530.222 1748.28,530.232 1748.28,530.243 1748.29,530.254 1748.3,530.264 1748.31,530.275 1748.32,530.285 1748.33,530.296 1748.34,530.306 1748.35,530.317 1748.36,530.328 1748.37,530.338 1748.38,530.349 1748.39,530.359 1748.39,530.37 1748.4,530.38 1748.41,530.391 1748.42,530.401 1748.43,530.412 1748.44,530.423 1748.45,530.433 1748.46,530.444 1748.47,530.454 1748.48,530.465 1748.49,530.475 1748.5,530.486 1748.5,530.496 1748.51,530.507 1748.52,530.518 1748.53,530.528 1748.54,530.539 1748.55,530.549 1748.56,530.56 1748.57,530.57 1748.58,530.581 1748.59,530.591 1748.6,530.602 1748.61,530.613 1748.62,530.623 1748.62,530.634 1748.63,530.644 1748.64,530.655 1748.65,530.665 1748.66,530.676 1748.67,530.686 1748.68,530.697 1748.69,530.707 1748.7,530.718 1748.71,530.728 1748.72,530.739 1748.73,530.75 1748.73,530.76 1748.74,530.771 1748.75,530.781 1748.76,530.792 1748.77,530.802 1748.78,530.813 1748.79,530.823 1748.8,530.834 1748.81,530.844 1748.82,530.855 1748.83,530.865 1748.84,530.876 1748.84,530.887 1748.85,530.897 1748.86,530.908 1748.87,530.918 1748.88,530.929 1748.89,530.939 1748.9,530.95 1748.91,530.96 1748.92,530.971 1748.93,530.981 1748.94,530.992 1748.95,531.002 1748.96,531.013 1748.96,531.023 1748.97,531.034 1748.98,531.044 1748.99,531.055 1749,531.066 1749.01,531.076 1749.02,531.087 1749.03,531.097 1749.04,531.108 1749.05,531.118 1749.06,531.129 1749.07,531.139 1749.07,531.15 1749.08,531.16 1749.09,531.171 1749.1,531.181 1749.11,531.192 1749.12,531.202 1749.13,531.213 1749.14,531.223 1749.15,531.234 1749.16,531.244 1749.17,531.255 1749.18,531.265 1749.18,531.276 1749.19,531.286 1749.2,531.297 1749.21,531.307 1749.22,531.318 1749.23,531.328 1749.24,531.339 1749.25,531.349 1749.26,531.36 1749.27,531.37 1749.28,531.381 1749.29,531.392 1749.3,531.402 1749.3,531.413 1749.31,531.423 1749.32,531.434 1749.33,531.444 1749.34,531.455 1749.35,531.465 1749.36,531.476 1749.37,531.486 1749.38,531.497 1749.39,531.507 1749.4,531.518 1749.41,531.528 1749.41,531.539 1749.42,531.549 1749.43,531.56 1749.44,531.57 1749.45,531.581 1749.46,531.591 1749.47,531.602 1749.48,531.612 1749.49,531.623 1749.5,531.633 1749.51,531.644 1749.52,531.654 1749.52,531.665 1749.53,531.675 1749.54,531.686 1749.55,531.696 1749.56,531.706 1749.57,531.717 1749.58,531.727 1749.59,531.738 1749.6,531.748 1749.61,531.759 1749.62,531.769 1749.63,531.78 1749.64,531.79 1749.64,531.801 1749.65,531.811 1749.66,531.822 1749.67,531.832 1749.68,531.843 1749.69,531.853 1749.7,531.864 1749.71,531.874 1749.72,531.885 1749.73,531.895 1749.74,531.906 1749.75,531.916 1749.75,531.927 1749.76,531.937 1749.77,531.948 1749.78,531.958 1749.79,531.969 1749.8,531.979 1749.81,531.99 1749.82,532 1749.83,532.011 1749.84,532.021 1749.85,532.031 1749.86,532.042 1749.86,532.052 1749.87,532.063 1749.88,532.073 1749.89,532.084 1749.9,532.094 1749.91,532.105 1749.92,532.115 1749.93,532.126 1749.94,532.136 1749.95,532.147 1749.96,532.157 1749.97,532.168 1749.98,532.178 1749.98,532.189 1749.99,532.199 1750,532.209 1750.01,532.22 1750.02,532.23 1750.03,532.241 1750.04,532.251 1750.05,532.262 1750.06,532.272 1750.07,532.283 1750.08,532.293 1750.09,532.304 1750.09,532.314 1750.1,532.325 1750.11,532.335 1750.12,532.346 1750.13,532.356 1750.14,532.366 1750.15,532.377 1750.16,532.387 1750.17,532.398 1750.18,532.408 1750.19,532.419 1750.2,532.429 1750.2,532.44 1750.21,532.45 1750.22,532.461 1750.23,532.471 1750.24,532.481 1750.25,532.492 1750.26,532.502 1750.27,532.513 1750.28,532.523 1750.29,532.534 1750.3,532.544 1750.31,532.555 1750.32,532.565 1750.32,532.575 1750.33,532.586 1750.34,532.596 1750.35,532.607 1750.36,532.617 1750.37,532.628 1750.38,532.638 1750.39,532.649 1750.4,532.659 1750.41,532.669 1750.42,532.68 1750.43,532.69 1750.43,532.701 1750.44,532.711 1750.45,532.722 1750.46,532.732 1750.47,532.743 1750.48,532.753 1750.49,532.763 1750.5,532.774 1750.51,532.784 1750.52,532.795 1750.53,532.805 1750.54,532.816 1750.54,532.826 1750.55,532.837 1750.56,532.847 1750.57,532.857 1750.58,532.868 1750.59,532.878 1750.6,532.889 1750.61,532.899 1750.62,532.91 1750.63,532.92 1750.64,532.93 1750.65,532.941 1750.66,532.951 1750.66,532.962 1750.67,532.972 1750.68,532.983 1750.69,532.993 1750.7,533.003 1750.71,533.014 1750.72,533.024 1750.73,533.035 1750.74,533.045 1750.75,533.056 1750.76,533.066 1750.77,533.076 1750.77,533.087 1750.78,533.097 1750.79,533.108 1750.8,533.118 1750.81,533.128 1750.82,533.139 1750.83,533.149 1750.84,533.16 1750.85,533.17 1750.86,533.181 1750.87,533.191 1750.88,533.201 1750.88,533.212 1750.89,533.222 1750.9,533.233 1750.91,533.243 1750.92,533.254 1750.93,533.264 1750.94,533.274 1750.95,533.285 1750.96,533.295 1750.97,533.306 1750.98,533.316 1750.99,533.326 1751,533.337 1751,533.347 1751.01,533.358 1751.02,533.368 1751.03,533.378 1751.04,533.389 1751.05,533.399 1751.06,533.41 1751.07,533.42 1751.08,533.43 1751.09,533.441 1751.1,533.451 1751.11,533.462 1751.11,533.472 1751.12,533.482 1751.13,533.493 1751.14,533.503 1751.15,533.514 1751.16,533.524 1751.17,533.534 1751.18,533.545 1751.19,533.555 1751.2,533.566 1751.21,533.576 1751.22,533.586 1751.22,533.597 1751.23,533.607 1751.24,533.618 1751.25,533.628 1751.26,533.638 1751.27,533.649 1751.28,533.659 1751.29,533.67 1751.3,533.68 1751.31,533.69 1751.32,533.701 1751.33,533.711 1751.34,533.722 1751.34,533.732 1751.35,533.742 1751.36,533.753 1751.37,533.763 1751.38,533.774 1751.39,533.784 1751.4,533.794 1751.41,533.805 1751.42,533.815 1751.43,533.825 1751.44,533.836 1751.45,533.846 1751.45,533.857 1751.46,533.867 1751.47,533.877 1751.48,533.888 1751.49,533.898 1751.5,533.909 1751.51,533.919 1751.52,533.929 1751.53,533.94 1751.54,533.95 1751.55,533.96 1751.56,533.971 1751.56,533.981 1751.57,533.992 1751.58,534.002 1751.59,534.012 1751.6,534.023 1751.61,534.033 1751.62,534.043 1751.63,534.054 1751.64,534.064 1751.65,534.075 1751.66,534.085 1751.67,534.095 1751.68,534.106 1751.68,534.116 1751.69,534.126 1751.7,534.137 1751.71,534.147 1751.72,534.158 1751.73,534.168 1751.74,534.178 1751.75,534.189 1751.76,534.199 1751.77,534.209 1751.78,534.22 1751.79,534.23 1751.79,534.24 1751.8,534.251 1751.81,534.261 1751.82,534.272 1751.83,534.282 1751.84,534.292 1751.85,534.303 1751.86,534.313 1751.87,534.323 1751.88,534.334 1751.89,534.344 1751.9,534.354 1751.9,534.365 1751.91,534.375 1751.92,534.386 1751.93,534.396 1751.94,534.406 1751.95,534.417 1751.96,534.427 1751.97,534.437 1751.98,534.448 1751.99,534.458 1752,534.468 1752.01,534.479 1752.02,534.489 1752.02,534.499 1752.03,534.51 1752.04,534.52 1752.05,534.53 1752.06,534.541 1752.07,534.551 1752.08,534.562 1752.09,534.572 1752.1,534.582 1752.11,534.593 1752.12,534.603 1752.13,534.613 1752.13,534.624 1752.14,534.634 1752.15,534.644 1752.16,534.655 1752.17,534.665 1752.18,534.675 1752.19,534.686 1752.2,534.696 1752.21,534.706 1752.22,534.717 1752.23,534.727 1752.24,534.737 1752.24,534.748 1752.25,534.758 1752.26,534.768 1752.27,534.779 1752.28,534.789 1752.29,534.799 1752.3,534.81 1752.31,534.82 1752.32,534.83 1752.33,534.841 1752.34,534.851 1752.35,534.861 1752.36,534.872 1752.36,534.882 1752.37,534.892 1752.38,534.903 1752.39,534.913 1752.4,534.923 1752.41,534.934 1752.42,534.944 1752.43,534.954 1752.44,534.965 1752.45,534.975 1752.46,534.985 1752.47,534.996 1752.47,535.006 1752.48,535.016 1752.49,535.027 1752.5,535.037 1752.51,535.047 1752.52,535.058 1752.53,535.068 1752.54,535.078 1752.55,535.089 1752.56,535.099 1752.57,535.109 1752.58,535.12 1752.58,535.13 1752.59,535.14 1752.6,535.151 1752.61,535.161 1752.62,535.171 1752.63,535.182 1752.64,535.192 1752.65,535.202 1752.66,535.212 1752.67,535.223 1752.68,535.233 1752.69,535.243 1752.7,535.254 1752.7,535.264 1752.71,535.274 1752.72,535.285 1752.73,535.295 1752.74,535.305 1752.75,535.316 1752.76,535.326 1752.77,535.336 1752.78,535.347 1752.79,535.357 1752.8,535.367 1752.81,535.377 1752.81,535.388 1752.82,535.398 1752.83,535.408 1752.84,535.419 1752.85,535.429 1752.86,535.439 1752.87,535.45 1752.88,535.46 1752.89,535.47 1752.9,535.48 1752.91,535.491 1752.92,535.501 1752.93,535.511 1752.93,535.522 1752.94,535.532 1752.95,535.542 1752.96,535.553 1752.97,535.563 1752.98,535.573 1752.99,535.583 1753,535.594 1753.01,535.604 1753.02,535.614 1753.03,535.625 1753.04,535.635 1753.04,535.645 1753.05,535.656 1753.06,535.666 1753.07,535.676 1753.08,535.686 1753.09,535.697 1753.1,535.707 1753.11,535.717 1753.12,535.728 1753.13,535.738 1753.14,535.748 1753.15,535.758 1753.15,535.769 1753.16,535.779 1753.17,535.789 1753.18,535.8 1753.19,535.81 1753.2,535.82 1753.21,535.83 1753.22,535.841 1753.23,535.851 1753.24,535.861 1753.25,535.872 1753.26,535.882 1753.27,535.892 1753.27,535.902 1753.28,535.913 1753.29,535.923 1753.3,535.933 1753.31,535.944 1753.32,535.954 1753.33,535.964 1753.34,535.974 1753.35,535.985 1753.36,535.995 1753.37,536.005 1753.38,536.016 1753.38,536.026 1753.39,536.036 1753.4,536.046 1753.41,536.057 1753.42,536.067 1753.43,536.077 1753.44,536.087 1753.45,536.098 1753.46,536.108 1753.47,536.118 1753.48,536.129 1753.49,536.139 1753.49,536.149 1753.5,536.159 1753.51,536.17 1753.52,536.18 1753.53,536.19 1753.54,536.2 1753.55,536.211 1753.56,536.221 1753.57,536.231 1753.58,536.241 1753.59,536.252 1753.6,536.262 1753.61,536.272 1753.61,536.283 1753.62,536.293 1753.63,536.303 1753.64,536.313 1753.65,536.324 1753.66,536.334 1753.67,536.344 1753.68,536.354 1753.69,536.365 1753.7,536.375 1753.71,536.385 1753.72,536.395 1753.72,536.406 1753.73,536.416 1753.74,536.426 1753.75,536.436 1753.76,536.447 1753.77,536.457 1753.78,536.467 1753.79,536.477 1753.8,536.488 1753.81,536.498 1753.82,536.508 1753.83,536.518 1753.83,536.529 1753.84,536.539 1753.85,536.549 1753.86,536.559 1753.87,536.57 1753.88,536.58 1753.89,536.59 1753.9,536.6 1753.91,536.611 1753.92,536.621 1753.93,536.631 1753.94,536.641 1753.95,536.652 1753.95,536.662 1753.96,536.672 1753.97,536.682 1753.98,536.693 1753.99,536.703 1754,536.713 1754.01,536.723 1754.02,536.734 1754.03,536.744 1754.04,536.754 1754.05,536.764 1754.06,536.775 1754.06,536.785 1754.07,536.795 1754.08,536.805 1754.09,536.815 1754.1,536.826 1754.11,536.836 1754.12,536.846 1754.13,536.856 1754.14,536.867 1754.15,536.877 1754.16,536.887 1754.17,536.897 1754.17,536.908 1754.18,536.918 1754.19,536.928 1754.2,536.938 1754.21,536.948 1754.22,536.959 1754.23,536.969 1754.24,536.979 1754.25,536.989 1754.26,537 1754.27,537.01 1754.28,537.02 1754.29,537.03 1754.29,537.041 1754.3,537.051 1754.31,537.061 1754.32,537.071 1754.33,537.081 1754.34,537.092 1754.35,537.102 1754.36,537.112 1754.37,537.122 1754.38,537.133 1754.39,537.143 1754.4,537.153 1754.4,537.163 1754.41,537.173 1754.42,537.184 1754.43,537.194 1754.44,537.204 1754.45,537.214 1754.46,537.224 1754.47,537.235 1754.48,537.245 1754.49,537.255 1754.5,537.265 1754.51,537.276 1754.51,537.286 1754.52,537.296 1754.53,537.306 1754.54,537.316 1754.55,537.327 1754.56,537.337 1754.57,537.347 1754.58,537.357 1754.59,537.367 1754.6,537.378 1754.61,537.388 1754.62,537.398 1754.63,537.408 1754.63,537.418 1754.64,537.429 1754.65,537.439 1754.66,537.449 1754.67,537.459 1754.68,537.469 1754.69,537.48 1754.7,537.49 1754.71,537.5 1754.72,537.51 1754.73,537.521 1754.74,537.531 1754.74,537.541 1754.75,537.551 1754.76,537.561 1754.77,537.571 1754.78,537.582 1754.79,537.592 1754.8,537.602 1754.81,537.612 1754.82,537.622 1754.83,537.633 1754.84,537.643 1754.85,537.653 1754.85,537.663 1754.86,537.673 1754.87,537.684 1754.88,537.694 1754.89,537.704 1754.9,537.714 1754.91,537.724 1754.92,537.735 1754.93,537.745 1754.94,537.755 1754.95,537.765 1754.96,537.775 1754.97,537.786 1754.97,537.796 1754.98,537.806 1754.99,537.816 1755,537.826 1755.01,537.836 1755.02,537.847 1755.03,537.857 1755.04,537.867 1755.05,537.877 1755.06,537.887 1755.07,537.898 1755.08,537.908 1755.08,537.918 1755.09,537.928 1755.1,537.938 1755.11,537.948 1755.12,537.959 1755.13,537.969 1755.14,537.979 1755.15,537.989 1755.16,537.999 1755.17,538.01 1755.18,538.02 1755.19,538.03 1755.19,538.04 1755.2,538.05 1755.21,538.06 1755.22,538.071 1755.23,538.081 1755.24,538.091 1755.25,538.101 1755.26,538.111 1755.27,538.121 1755.28,538.132 1755.29,538.142 1755.3,538.152 1755.31,538.162 1755.31,538.172 1755.32,538.182 1755.33,538.193 1755.34,538.203 1755.35,538.213 1755.36,538.223 1755.37,538.233 1755.38,538.243 1755.39,538.254 1755.4,538.264 1755.41,538.274 1755.42,538.284 1755.42,538.294 1755.43,538.304 1755.44,538.315 1755.45,538.325 1755.46,538.335 1755.47,538.345 1755.48,538.355 1755.49,538.365 1755.5,538.376 1755.51,538.386 1755.52,538.396 1755.53,538.406 1755.53,538.416 1755.54,538.426 1755.55,538.436 1755.56,538.447 1755.57,538.457 1755.58,538.467 1755.59,538.477 1755.6,538.487 1755.61,538.497 1755.62,538.508 1755.63,538.518 1755.64,538.528 1755.65,538.538 1755.65,538.548 1755.66,538.558 1755.67,538.568 1755.68,538.579 1755.69,538.589 1755.7,538.599 1755.71,538.609 1755.72,538.619 1755.73,538.629 1755.74,538.639 1755.75,538.65 1755.76,538.66 1755.76,538.67 1755.77,538.68 1755.78,538.69 1755.79,538.7 1755.8,538.71 1755.81,538.721 1755.82,538.731 1755.83,538.741 1755.84,538.751 1755.85,538.761 1755.86,538.771 1755.87,538.781 1755.87,538.792 1755.88,538.802 1755.89,538.812 1755.9,538.822 1755.91,538.832 1755.92,538.842 1755.93,538.852 1755.94,538.863 1755.95,538.873 1755.96,538.883 1755.97,538.893 1755.98,538.903 1755.99,538.913 1755.99,538.923 1756,538.933 1756.01,538.944 1756.02,538.954 1756.03,538.964 1756.04,538.974 1756.05,538.984 1756.06,538.994 1756.07,539.004 1756.08,539.014 1756.09,539.025 1756.1,539.035 1756.1,539.045 1756.11,539.055 1756.12,539.065 1756.13,539.075 1756.14,539.085 1756.15,539.095 1756.16,539.106 1756.17,539.116 1756.18,539.126 1756.19,539.136 1756.2,539.146 1756.21,539.156 1756.21,539.166 1756.22,539.176 1756.23,539.187 1756.24,539.197 1756.25,539.207 1756.26,539.217 1756.27,539.227 1756.28,539.237 1756.29,539.247 1756.3,539.257 1756.31,539.267 1756.32,539.278 1756.33,539.288 1756.33,539.298 1756.34,539.308 1756.35,539.318 1756.36,539.328 1756.37,539.338 1756.38,539.348 1756.39,539.358 1756.4,539.369 1756.41,539.379 1756.42,539.389 1756.43,539.399 1756.44,539.409 1756.44,539.419 1756.45,539.429 1756.46,539.439 1756.47,539.449 1756.48,539.46 1756.49,539.47 1756.5,539.48 1756.51,539.49 1756.52,539.5 1756.53,539.51 1756.54,539.52 1756.55,539.53 1756.55,539.54 1756.56,539.55 1756.57,539.561 1756.58,539.571 1756.59,539.581 1756.6,539.591 1756.61,539.601 1756.62,539.611 1756.63,539.621 1756.64,539.631 1756.65,539.641 1756.66,539.651 1756.67,539.661 1756.67,539.672 1756.68,539.682 1756.69,539.692 1756.7,539.702 1756.71,539.712 1756.72,539.722 1756.73,539.732 1756.74,539.742 1756.75,539.752 1756.76,539.762 1756.77,539.772 1756.78,539.783 1756.78,539.793 1756.79,539.803 1756.8,539.813 1756.81,539.823 1756.82,539.833 1756.83,539.843 1756.84,539.853 1756.85,539.863 1756.86,539.873 1756.87,539.883 1756.88,539.893 1756.89,539.904 1756.89,539.914 1756.9,539.924 1756.91,539.934 1756.92,539.944 1756.93,539.954 1756.94,539.964 1756.95,539.974 1756.96,539.984 1756.97,539.994 1756.98,540.004 1756.99,540.014 1757,540.025 1757.01,540.035 1757.01,540.045 1757.02,540.055 1757.03,540.065 1757.04,540.075 1757.05,540.085 1757.06,540.095 1757.07,540.105 1757.08,540.115 1757.09,540.125 1757.1,540.135 1757.11,540.145 1757.12,540.155 1757.12,540.166 1757.13,540.176 1757.14,540.186 1757.15,540.196 1757.16,540.206 1757.17,540.216 1757.18,540.226 1757.19,540.236 1757.2,540.246 1757.21,540.256 1757.22,540.266 1757.23,540.276 1757.23,540.286 1757.24,540.296 1757.25,540.306 1757.26,540.316 1757.27,540.327 1757.28,540.337 1757.29,540.347 1757.3,540.357 1757.31,540.367 1757.32,540.377 1757.33,540.387 1757.34,540.397 1757.35,540.407 1757.35,540.417 1757.36,540.427 1757.37,540.437 1757.38,540.447 1757.39,540.457 1757.4,540.467 1757.41,540.477 1757.42,540.487 1757.43,540.497 1757.44,540.508 1757.45,540.518 1757.46,540.528 1757.46,540.538 1757.47,540.548 1757.48,540.558 1757.49,540.568 1757.5,540.578 1757.51,540.588 1757.52,540.598 1757.53,540.608 1757.54,540.618 1757.55,540.628 1757.56,540.638 1757.57,540.648 1757.57,540.658 1757.58,540.668 1757.59,540.678 1757.6,540.688 1757.61,540.698 1757.62,540.708 1757.63,540.719 1757.64,540.729 1757.65,540.739 1757.66,540.749 1757.67,540.759 1757.68,540.769 1757.69,540.779 1757.69,540.789 1757.7,540.799 1757.71,540.809 1757.72,540.819 1757.73,540.829 1757.74,540.839 1757.75,540.849 1757.76,540.859 1757.77,540.869 1757.78,540.879 1757.79,540.889 1757.8,540.899 1757.8,540.909 1757.81,540.919 1757.82,540.929 1757.83,540.939 1757.84,540.949 1757.85,540.959 1757.86,540.969 1757.87,540.979 1757.88,540.989 1757.89,540.999 1757.9,541.009 1757.91,541.02 1757.91,541.03 1757.92,541.04 1757.93,541.05 1757.94,541.06 1757.95,541.07 1757.96,541.08 1757.97,541.09 1757.98,541.1 1757.99,541.11 1758,541.12 1758.01,541.13 1758.02,541.14 1758.03,541.15 1758.03,541.16 1758.04,541.17 1758.05,541.18 1758.06,541.19 1758.07,541.2 1758.08,541.21 1758.09,541.22 1758.1,541.23 1758.11,541.24 1758.12,541.25 1758.13,541.26 1758.14,541.27 1758.14,541.28 1758.15,541.29 1758.16,541.3 1758.17,541.31 1758.18,541.32 1758.19,541.33 1758.2,541.34 1758.21,541.35 1758.22,541.36 1758.23,541.37 1758.24,541.38 1758.25,541.39 1758.25,541.4 1758.26,541.41 1758.27,541.42 1758.28,541.43 1758.29,541.44 1758.3,541.45 1758.31,541.46 1758.32,541.47 1758.33,541.48 1758.34,541.49 1758.35,541.5 1758.36,541.51 1758.37,541.52 1758.37,541.53 1758.38,541.54 1758.39,541.55 1758.4,541.56 1758.41,541.57 1758.42,541.58 1758.43,541.59 1758.44,541.6 1758.45,541.61 1758.46,541.62 1758.47,541.63 1758.48,541.64 1758.48,541.65 1758.49,541.66 1758.5,541.67 1758.51,541.68 1758.52,541.69 1758.53,541.7 1758.54,541.71 1758.55,541.72 1758.56,541.73 1758.57,541.74 1758.58,541.75 1758.59,541.76 1758.59,541.77 1758.6,541.78 1758.61,541.79 1758.62,541.8 1758.63,541.81 1758.64,541.82 1758.65,541.83 1758.66,541.84 1758.67,541.85 1758.68,541.86 1758.69,541.87 1758.7,541.88 1758.71,541.89 1758.71,541.9 1758.72,541.91 1758.73,541.92 1758.74,541.93 1758.75,541.94 1758.76,541.95 1758.77,541.96 1758.78,541.97 1758.79,541.98 1758.8,541.99 1758.81,542 1758.82,542.01 1758.82,542.02 1758.83,542.03 1758.84,542.04 1758.85,542.049 1758.86,542.059 1758.87,542.069 1758.88,542.079 1758.89,542.089 1758.9,542.099 1758.91,542.109 1758.92,542.119 1758.93,542.129 1758.93,542.139 1758.94,542.149 1758.95,542.159 1758.96,542.169 1758.97,542.179 1758.98,542.189 1758.99,542.199 1759,542.209 1759.01,542.219 1759.02,542.229 1759.03,542.239 1759.04,542.249 1759.05,542.259 1759.05,542.269 1759.06,542.279 1759.07,542.289 1759.08,542.299 1759.09,542.309 1759.1,542.319 1759.11,542.329 1759.12,542.339 1759.13,542.348 1759.14,542.358 1759.15,542.368 1759.16,542.378 1759.16,542.388 1759.17,542.398 1759.18,542.408 1759.19,542.418 1759.2,542.428 1759.21,542.438 1759.22,542.448 1759.23,542.458 1759.24,542.468 1759.25,542.478 1759.26,542.488 1759.27,542.498 1759.27,542.508 1759.28,542.518 1759.29,542.528 1759.3,542.538 1759.31,542.548 1759.32,542.558 1759.33,542.567 1759.34,542.577 1759.35,542.587 1759.36,542.597 1759.37,542.607 1759.38,542.617 1759.39,542.627 1759.39,542.637 1759.4,542.647 1759.41,542.657 1759.42,542.667 1759.43,542.677 1759.44,542.687 1759.45,542.697 1759.46,542.707 1759.47,542.717 1759.48,542.727 1759.49,542.737 1759.5,542.746 1759.5,542.756 1759.51,542.766 1759.52,542.776 1759.53,542.786 1759.54,542.796 1759.55,542.806 1759.56,542.816 1759.57,542.826 1759.58,542.836 1759.59,542.846 1759.6,542.856 1759.61,542.866 1759.61,542.876 1759.62,542.886 1759.63,542.895 1759.64,542.905 1759.65,542.915 1759.66,542.925 1759.67,542.935 1759.68,542.945 1759.69,542.955 1759.7,542.965 1759.71,542.975 1759.72,542.985 1759.73,542.995 1759.73,543.005 1759.74,543.015 1759.75,543.025 1759.76,543.034 1759.77,543.044 1759.78,543.054 1759.79,543.064 1759.8,543.074 1759.81,543.084 1759.82,543.094 1759.83,543.104 1759.84,543.114 1759.84,543.124 1759.85,543.134 1759.86,543.144 1759.87,543.154 1759.88,543.163 1759.89,543.173 1759.9,543.183 1759.91,543.193 1759.92,543.203 1759.93,543.213 1759.94,543.223 1759.95,543.233 1759.95,543.243 1759.96,543.253 1759.97,543.263 1759.98,543.273 1759.99,543.282 1760,543.292 1760.01,543.302 1760.02,543.312 1760.03,543.322 1760.04,543.332 1760.05,543.342 1760.06,543.352 1760.07,543.362 1760.07,543.372 1760.08,543.382 1760.09,543.391 1760.1,543.401 1760.11,543.411 1760.12,543.421 1760.13,543.431 1760.14,543.441 1760.15,543.451 1760.16,543.461 1760.17,543.471 1760.18,543.481 1760.18,543.49 1760.19,543.5 1760.2,543.51 1760.21,543.52 1760.22,543.53 1760.23,543.54 1760.24,543.55 1760.25,543.56 1760.26,543.57 1760.27,543.58 1760.28,543.589 1760.29,543.599 1760.29,543.609 1760.3,543.619 1760.31,543.629 1760.32,543.639 1760.33,543.649 1760.34,543.659 1760.35,543.669 1760.36,543.679 1760.37,543.688 1760.38,543.698 1760.39,543.708 1760.4,543.718 1760.41,543.728 1760.41,543.738 1760.42,543.748 1760.43,543.758 1760.44,543.768 1760.45,543.777 1760.46,543.787 1760.47,543.797 1760.48,543.807 1760.49,543.817 1760.5,543.827 1760.51,543.837 1760.52,543.847 1760.52,543.857 1760.53,543.866 1760.54,543.876 1760.55,543.886 1760.56,543.896 1760.57,543.906 1760.58,543.916 1760.59,543.926 1760.6,543.936 1760.61,543.945 1760.62,543.955 1760.63,543.965 1760.63,543.975 1760.64,543.985 1760.65,543.995 1760.66,544.005 1760.67,544.015 1760.68,544.024 1760.69,544.034 1760.7,544.044 1760.71,544.054 1760.72,544.064 1760.73,544.074 1760.74,544.084 1760.75,544.094 1760.75,544.103 1760.76,544.113 1760.77,544.123 1760.78,544.133 1760.79,544.143 1760.8,544.153 1760.81,544.163 1760.82,544.173 1760.83,544.182 1760.84,544.192 1760.85,544.202 1760.86,544.212 1760.86,544.222 1760.87,544.232 1760.88,544.242 1760.89,544.251 1760.9,544.261 1760.91,544.271 1760.92,544.281 1760.93,544.291 1760.94,544.301 1760.95,544.311 1760.96,544.321 1760.97,544.33 1760.97,544.34 1760.98,544.35 1760.99,544.36 1761,544.37 1761.01,544.38 1761.02,544.39 1761.03,544.399 1761.04,544.409 1761.05,544.419 1761.06,544.429 1761.07,544.439 1761.08,544.449 1761.09,544.459 1761.09,544.468 1761.1,544.478 1761.11,544.488 1761.12,544.498 1761.13,544.508 1761.14,544.518 1761.15,544.527 1761.16,544.537 1761.17,544.547 1761.18,544.557 1761.19,544.567 1761.2,544.577 1761.2,544.587 1761.21,544.596 1761.22,544.606 1761.23,544.616 1761.24,544.626 1761.25,544.636 1761.26,544.646 1761.27,544.655 1761.28,544.665 1761.29,544.675 1761.3,544.685 1761.31,544.695 1761.31,544.705 1761.32,544.715 1761.33,544.724 1761.34,544.734 1761.35,544.744 1761.36,544.754 1761.37,544.764 1761.38,544.774 1761.39,544.783 1761.4,544.793 1761.41,544.803 1761.42,544.813 1761.43,544.823 1761.43,544.833 1761.44,544.842 1761.45,544.852 1761.46,544.862 1761.47,544.872 1761.48,544.882 1761.49,544.892 1761.5,544.901 1761.51,544.911 1761.52,544.921 1761.53,544.931 1761.54,544.941 1761.54,544.951 1761.55,544.96 1761.56,544.97 1761.57,544.98 1761.58,544.99 1761.59,545 1761.6,545.01 1761.61,545.019 1761.62,545.029 1761.63,545.039 1761.64,545.049 1761.65,545.059 1761.65,545.068 1761.66,545.078 1761.67,545.088 1761.68,545.098 1761.69,545.108 1761.7,545.118 1761.71,545.127 1761.72,545.137 1761.73,545.147 1761.74,545.157 1761.75,545.167 1761.76,545.177 1761.77,545.186 1761.77,545.196 1761.78,545.206 1761.79,545.216 1761.8,545.226 1761.81,545.235 1761.82,545.245 1761.83,545.255 1761.84,545.265 1761.85,545.275 1761.86,545.284 1761.87,545.294 1761.88,545.304 1761.88,545.314 1761.89,545.324 1761.9,545.334 1761.91,545.343 1761.92,545.353 1761.93,545.363 1761.94,545.373 1761.95,545.383 1761.96,545.392 1761.97,545.402 1761.98,545.412 1761.99,545.422 1761.99,545.432 1762,545.441 1762.01,545.451 1762.02,545.461 1762.03,545.471 1762.04,545.481 1762.05,545.49 1762.06,545.5 1762.07,545.51 1762.08,545.52 1762.09,545.53 1762.1,545.539 1762.11,545.549 1762.11,545.559 1762.12,545.569 1762.13,545.579 1762.14,545.588 1762.15,545.598 1762.16,545.608 1762.17,545.618 1762.18,545.628 1762.19,545.637 1762.2,545.647 1762.21,545.657 1762.22,545.667 1762.22,545.677 1762.23,545.686 1762.24,545.696 1762.25,545.706 1762.26,545.716 1762.27,545.726 1762.28,545.735 1762.29,545.745 1762.3,545.755 1762.31,545.765 1762.32,545.774 1762.33,545.784 1762.33,545.794 1762.34,545.804 1762.35,545.814 1762.36,545.823 1762.37,545.833 1762.38,545.843 1762.39,545.853 1762.4,545.863 1762.41,545.872 1762.42,545.882 1762.43,545.892 1762.44,545.902 1762.45,545.911 1762.45,545.921 1762.46,545.931 1762.47,545.941 1762.48,545.951 1762.49,545.96 1762.5,545.97 1762.51,545.98 1762.52,545.99 1762.53,545.999 1762.54,546.009 1762.55,546.019 1762.56,546.029 1762.56,546.039 1762.57,546.048 1762.58,546.058 1762.59,546.068 1762.6,546.078 1762.61,546.087 1762.62,546.097 1762.63,546.107 1762.64,546.117 1762.65,546.127 1762.66,546.136 1762.67,546.146 1762.67,546.156 1762.68,546.166 1762.69,546.175 1762.7,546.185 1762.71,546.195 1762.72,546.205 1762.73,546.214 1762.74,546.224 1762.75,546.234 1762.76,546.244 1762.77,546.253 1762.78,546.263 1762.79,546.273 1762.79,546.283 1762.8,546.293 1762.81,546.302 1762.82,546.312 1762.83,546.322 1762.84,546.332 1762.85,546.341 1762.86,546.351 1762.87,546.361 1762.88,546.371 1762.89,546.38 1762.9,546.39 1762.9,546.4 1762.91,546.41 1762.92,546.419 1762.93,546.429 1762.94,546.439 1762.95,546.449 1762.96,546.458 1762.97,546.468 1762.98,546.478 1762.99,546.488 1763,546.497 1763.01,546.507 1763.01,546.517 1763.02,546.527 1763.03,546.536 1763.04,546.546 1763.05,546.556 1763.06,546.566 1763.07,546.575 1763.08,546.585 1763.09,546.595 1763.1,546.605 1763.11,546.614 1763.12,546.624 1763.13,546.634 1763.13,546.644 1763.14,546.653 1763.15,546.663 1763.16,546.673 1763.17,546.683 1763.18,546.692 1763.19,546.702 1763.2,546.712 1763.21,546.722 1763.22,546.731 1763.23,546.741 1763.24,546.751 1763.24,546.761 1763.25,546.77 1763.26,546.78 1763.27,546.79 1763.28,546.799 1763.29,546.809 1763.3,546.819 1763.31,546.829 1763.32,546.838 1763.33,546.848 1763.34,546.858 1763.35,546.868 1763.35,546.877 1763.36,546.887 1763.37,546.897 1763.38,546.907 1763.39,546.916 1763.4,546.926 1763.41,546.936 1763.42,546.945 1763.43,546.955 1763.44,546.965 1763.45,546.975 1763.46,546.984 1763.47,546.994 1763.47,547.004 1763.48,547.014 1763.49,547.023 1763.5,547.033 1763.51,547.043 1763.52,547.052 1763.53,547.062 1763.54,547.072 1763.55,547.082 1763.56,547.091 1763.57,547.101 1763.58,547.111 1763.58,547.12 1763.59,547.13 1763.6,547.14 1763.61,547.15 1763.62,547.159 1763.63,547.169 1763.64,547.179 1763.65,547.189 1763.66,547.198 1763.67,547.208 1763.68,547.218 1763.69,547.227 1763.69,547.237 1763.7,547.247 1763.71,547.257 1763.72,547.266 1763.73,547.276 1763.74,547.286 1763.75,547.295 1763.76,547.305 1763.77,547.315 1763.78,547.325 1763.79,547.334 1763.8,547.344 1763.81,547.354 1763.81,547.363 1763.82,547.373 1763.83,547.383 1763.84,547.392 1763.85,547.402 1763.86,547.412 1763.87,547.422 1763.88,547.431 1763.89,547.441 1763.9,547.451 1763.91,547.46 1763.92,547.47 1763.92,547.48 1763.93,547.489 1763.94,547.499 1763.95,547.509 1763.96,547.519 1763.97,547.528 1763.98,547.538 1763.99,547.548 1764,547.557 1764.01,547.567 1764.02,547.577 1764.03,547.586 1764.03,547.596 1764.04,547.606 1764.05,547.616 1764.06,547.625 1764.07,547.635 1764.08,547.645 1764.09,547.654 1764.1,547.664 1764.11,547.674 1764.12,547.683 1764.13,547.693 1764.14,547.703 1764.15,547.713 1764.15,547.722 1764.16,547.732 1764.17,547.742 1764.18,547.751 1764.19,547.761 1764.2,547.771 1764.21,547.78 1764.22,547.79 1764.23,547.8 1764.24,547.809 1764.25,547.819 1764.26,547.829 1764.26,547.838 1764.27,547.848 1764.28,547.858 1764.29,547.867 1764.3,547.877 1764.31,547.887 1764.32,547.897 1764.33,547.906 1764.34,547.916 1764.35,547.926 1764.36,547.935 1764.37,547.945 1764.37,547.955 1764.38,547.964 1764.39,547.974 1764.4,547.984 1764.41,547.993 1764.42,548.003 1764.43,548.013 1764.44,548.022 1764.45,548.032 1764.46,548.042 1764.47,548.051 1764.48,548.061 1764.49,548.071 1764.49,548.08 1764.5,548.09 1764.51,548.1 1764.52,548.109 1764.53,548.119 1764.54,548.129 1764.55,548.138 1764.56,548.148 1764.57,548.158 1764.58,548.167 1764.59,548.177 1764.6,548.187 1764.6,548.196 1764.61,548.206 1764.62,548.216 1764.63,548.225 1764.64,548.235 1764.65,548.245 1764.66,548.254 1764.67,548.264 1764.68,548.274 1764.69,548.283 1764.7,548.293 1764.71,548.303 1764.71,548.312 1764.72,548.322 1764.73,548.332 1764.74,548.341 1764.75,548.351 1764.76,548.361 1764.77,548.37 1764.78,548.38 1764.79,548.39 1764.8,548.399 1764.81,548.409 1764.82,548.419 1764.83,548.428 1764.83,548.438 1764.84,548.448 1764.85,548.457 1764.86,548.467 1764.87,548.477 1764.88,548.486 1764.89,548.496 1764.9,548.505 1764.91,548.515 1764.92,548.525 1764.93,548.534 1764.94,548.544 1764.94,548.554 1764.95,548.563 1764.96,548.573 1764.97,548.583 1764.98,548.592 1764.99,548.602 1765,548.612 1765.01,548.621 1765.02,548.631 1765.03,548.641 1765.04,548.65 1765.05,548.66 1765.05,548.669 1765.06,548.679 1765.07,548.689 1765.08,548.698 1765.09,548.708 1765.1,548.718 1765.11,548.727 1765.12,548.737 1765.13,548.747 1765.14,548.756 1765.15,548.766 1765.16,548.775 1765.17,548.785 1765.17,548.795 1765.18,548.804 1765.19,548.814 1765.2,548.824 1765.21,548.833 1765.22,548.843 1765.23,548.853 1765.24,548.862 1765.25,548.872 1765.26,548.881 1765.27,548.891 1765.28,548.901 1765.28,548.91 1765.29,548.92 1765.3,548.93 1765.31,548.939 1765.32,548.949 1765.33,548.958 1765.34,548.968 1765.35,548.978 1765.36,548.987 1765.37,548.997 1765.38,549.007 1765.39,549.016 1765.39,549.026 1765.4,549.035 1765.41,549.045 1765.42,549.055 1765.43,549.064 1765.44,549.074 1765.45,549.084 1765.46,549.093 1765.47,549.103 1765.48,549.112 1765.49,549.122 1765.5,549.132 1765.51,549.141 1765.51,549.151 1765.52,549.161 1765.53,549.17 1765.54,549.18 1765.55,549.189 1765.56,549.199 1765.57,549.209 1765.58,549.218 1765.59,549.228 1765.6,549.237 1765.61,549.247 1765.62,549.257 1765.62,549.266 1765.63,549.276 1765.64,549.286 1765.65,549.295 1765.66,549.305 1765.67,549.314 1765.68,549.324 1765.69,549.334 1765.7,549.343 1765.71,549.353 1765.72,549.362 1765.73,549.372 1765.73,549.382 1765.74,549.391 1765.75,549.401 1765.76,549.41 1765.77,549.42 1765.78,549.43 1765.79,549.439 1765.8,549.449 1765.81,549.458 1765.82,549.468 1765.83,549.478 1765.84,549.487 1765.85,549.497 1765.85,549.506 1765.86,549.516 1765.87,549.526 1765.88,549.535 1765.89,549.545 1765.9,549.554 1765.91,549.564 1765.92,549.574 1765.93,549.583 1765.94,549.593 1765.95,549.602 1765.96,549.612 1765.96,549.622 1765.97,549.631 1765.98,549.641 1765.99,549.65 1766,549.66 1766.01,549.67 1766.02,549.679 1766.03,549.689 1766.04,549.698 1766.05,549.708 1766.06,549.718 1766.07,549.727 1766.07,549.737 1766.08,549.746 1766.09,549.756 1766.1,549.765 1766.11,549.775 1766.12,549.785 1766.13,549.794 1766.14,549.804 1766.15,549.813 1766.16,549.823 1766.17,549.833 1766.18,549.842 1766.19,549.852 1766.19,549.861 1766.2,549.871 1766.21,549.88 1766.22,549.89 1766.23,549.9 1766.24,549.909 1766.25,549.919 1766.26,549.928 1766.27,549.938 1766.28,549.948 1766.29,549.957 1766.3,549.967 1766.3,549.976 1766.31,549.986 1766.32,549.995 1766.33,550.005 1766.34,550.015 1766.35,550.024 1766.36,550.034 1766.37,550.043 1766.38,550.053 1766.39,550.062 1766.4,550.072 1766.41,550.082 1766.41,550.091 1766.42,550.101 1766.43,550.11 1766.44,550.12 1766.45,550.129 1766.46,550.139 1766.47,550.149 1766.48,550.158 1766.49,550.168 1766.5,550.177 1766.51,550.187 1766.52,550.196 1766.53,550.206 1766.53,550.216 1766.54,550.225 1766.55,550.235 1766.56,550.244 1766.57,550.254 1766.58,550.263 1766.59,550.273 1766.6,550.282 1766.61,550.292 1766.62,550.302 1766.63,550.311 1766.64,550.321 1766.64,550.33 1766.65,550.34 1766.66,550.349 1766.67,550.359 1766.68,550.368 1766.69,550.378 1766.7,550.388 1766.71,550.397 1766.72,550.407 1766.73,550.416 1766.74,550.426 1766.75,550.435 1766.75,550.445 1766.76,550.454 1766.77,550.464 1766.78,550.474 1766.79,550.483 1766.8,550.493 1766.81,550.502 1766.82,550.512 1766.83,550.521 1766.84,550.531 1766.85,550.54 1766.86,550.55 1766.87,550.559 1766.87,550.569 1766.88,550.579 1766.89,550.588 1766.9,550.598 1766.91,550.607 1766.92,550.617 1766.93,550.626 1766.94,550.636 1766.95,550.645 1766.96,550.655 1766.97,550.664 1766.98,550.674 1766.98,550.684 1766.99,550.693 1767,550.703 1767.01,550.712 1767.02,550.722 1767.03,550.731 1767.04,550.741 1767.05,550.75 1767.06,550.76 1767.07,550.769 1767.08,550.779 1767.09,550.788 1767.09,550.798 1767.1,550.808 1767.11,550.817 1767.12,550.827 1767.13,550.836 1767.14,550.846 1767.15,550.855 1767.16,550.865 1767.17,550.874 1767.18,550.884 1767.19,550.893 1767.2,550.903 1767.21,550.912 1767.21,550.922 1767.22,550.931 1767.23,550.941 1767.24,550.95 1767.25,550.96 1767.26,550.97 1767.27,550.979 1767.28,550.989 1767.29,550.998 1767.3,551.008 1767.31,551.017 1767.32,551.027 1767.32,551.036 1767.33,551.046 1767.34,551.055 1767.35,551.065 1767.36,551.074 1767.37,551.084 1767.38,551.093 1767.39,551.103 1767.4,551.112 1767.41,551.122 1767.42,551.131 1767.43,551.141 1767.43,551.15 1767.44,551.16 1767.45,551.169 1767.46,551.179 1767.47,551.189 1767.48,551.198 1767.49,551.208 1767.5,551.217 1767.51,551.227 1767.52,551.236 1767.53,551.246 1767.54,551.255 1767.55,551.265 1767.55,551.274 1767.56,551.284 1767.57,551.293 1767.58,551.303 1767.59,551.312 1767.6,551.322 1767.61,551.331 1767.62,551.341 1767.63,551.35 1767.64,551.36 1767.65,551.369 1767.66,551.379 1767.66,551.388 1767.67,551.398 1767.68,551.407 1767.69,551.417 1767.7,551.426 1767.71,551.436 1767.72,551.445 1767.73,551.455 1767.74,551.464 1767.75,551.474 1767.76,551.483 1767.77,551.493 1767.77,551.502 1767.78,551.512 1767.79,551.521 1767.8,551.531 1767.81,551.54 1767.82,551.55 1767.83,551.559 1767.84,551.569 1767.85,551.578 1767.86,551.588 1767.87,551.597 1767.88,551.607 1767.89,551.616 1767.89,551.626 1767.9,551.635 1767.91,551.645 1767.92,551.654 1767.93,551.664 1767.94,551.673 1767.95,551.683 1767.96,551.692 1767.97,551.702 1767.98,551.711 1767.99,551.721 1768,551.73 1768,551.74 1768.01,551.749 1768.02,551.758 1768.03,551.768 1768.04,551.777 1768.05,551.787 1768.06,551.796 1768.07,551.806 1768.08,551.815 1768.09,551.825 1768.1,551.834 1768.11,551.844 1768.11,551.853 1768.12,551.863 1768.13,551.872 1768.14,551.882 1768.15,551.891 1768.16,551.901 1768.17,551.91 1768.18,551.92 1768.19,551.929 1768.2,551.939 1768.21,551.948 1768.22,551.958 1768.23,551.967 1768.23,551.977 1768.24,551.986 1768.25,551.995 1768.26,552.005 1768.27,552.014 1768.28,552.024 1768.29,552.033 1768.3,552.043 1768.31,552.052 1768.32,552.062 1768.33,552.071 1768.34,552.081 1768.34,552.09 1768.35,552.1 1768.36,552.109 1768.37,552.119 1768.38,552.128 1768.39,552.138 1768.4,552.147 1768.41,552.156 1768.42,552.166 1768.43,552.175 1768.44,552.185 1768.45,552.194 1768.45,552.204 1768.46,552.213 1768.47,552.223 1768.48,552.232 1768.49,552.242 1768.5,552.251 1768.51,552.261 1768.52,552.27 1768.53,552.279 1768.54,552.289 1768.55,552.298 1768.56,552.308 1768.57,552.317 1768.57,552.327 1768.58,552.336 1768.59,552.346 1768.6,552.355 1768.61,552.365 1768.62,552.374 1768.63,552.383 1768.64,552.393 1768.65,552.402 1768.66,552.412 1768.67,552.421 1768.68,552.431 1768.68,552.44 1768.69,552.45 1768.7,552.459 1768.71,552.469 1768.72,552.478 1768.73,552.487 1768.74,552.497 1768.75,552.506 1768.76,552.516 1768.77,552.525 1768.78,552.535 1768.79,552.544 1768.79,552.554 1768.8,552.563 1768.81,552.572 1768.82,552.582 1768.83,552.591 1768.84,552.601 1768.85,552.61 1768.86,552.62 1768.87,552.629 1768.88,552.639 1768.89,552.648 1768.9,552.657 1768.91,552.667 1768.91,552.676 1768.92,552.686 1768.93,552.695 1768.94,552.705 1768.95,552.714 1768.96,552.724 1768.97,552.733 1768.98,552.742 1768.99,552.752 1769,552.761 1769.01,552.771 1769.02,552.78 1769.02,552.79 1769.03,552.799 1769.04,552.808 1769.05,552.818 1769.06,552.827 1769.07,552.837 1769.08,552.846 1769.09,552.856 1769.1,552.865 1769.11,552.874 1769.12,552.884 1769.13,552.893 1769.13,552.903 1769.14,552.912 1769.15,552.922 1769.16,552.931 1769.17,552.94 1769.18,552.95 1769.19,552.959 1769.2,552.969 1769.21,552.978 1769.22,552.988 1769.23,552.997 1769.24,553.006 1769.25,553.016 1769.25,553.025 1769.26,553.035 1769.27,553.044 1769.28,553.053 1769.29,553.063 1769.3,553.072 1769.31,553.082 1769.32,553.091 1769.33,553.101 1769.34,553.11 1769.35,553.119 1769.36,553.129 1769.36,553.138 1769.37,553.148 1769.38,553.157 1769.39,553.166 1769.4,553.176 1769.41,553.185 1769.42,553.195 1769.43,553.204 1769.44,553.214 1769.45,553.223 1769.46,553.232 1769.47,553.242 1769.47,553.251 1769.48,553.261 1769.49,553.27 1769.5,553.279 1769.51,553.289 1769.52,553.298 1769.53,553.308 1769.54,553.317 1769.55,553.326 1769.56,553.336 1769.57,553.345 1769.58,553.355 1769.59,553.364 1769.59,553.373 1769.6,553.383 1769.61,553.392 1769.62,553.402 1769.63,553.411 1769.64,553.42 1769.65,553.43 1769.66,553.439 1769.67,553.449 1769.68,553.458 1769.69,553.467 1769.7,553.477 1769.7,553.486 1769.71,553.496 1769.72,553.505 1769.73,553.514 1769.74,553.524 1769.75,553.533 1769.76,553.543 1769.77,553.552 1769.78,553.561 1769.79,553.571 1769.8,553.58 1769.81,553.59 1769.81,553.599 1769.82,553.608 1769.83,553.618 1769.84,553.627 1769.85,553.637 1769.86,553.646 1769.87,553.655 1769.88,553.665 1769.89,553.674 1769.9,553.683 1769.91,553.693 1769.92,553.702 1769.93,553.712 1769.93,553.721 1769.94,553.73 1769.95,553.74 1769.96,553.749 1769.97,553.759 1769.98,553.768 1769.99,553.777 1770,553.787 1770.01,553.796 1770.02,553.805 1770.03,553.815 1770.04,553.824 1770.04,553.834 1770.05,553.843 1770.06,553.852 1770.07,553.862 1770.08,553.871 1770.09,553.881 1770.1,553.89 1770.11,553.899 1770.12,553.909 1770.13,553.918 1770.14,553.927 1770.15,553.937 1770.15,553.946 1770.16,553.956 1770.17,553.965 1770.18,553.974 1770.19,553.984 1770.2,553.993 1770.21,554.002 1770.22,554.012 1770.23,554.021 1770.24,554.03 1770.25,554.04 1770.26,554.049 1770.27,554.059 1770.27,554.068 1770.28,554.077 1770.29,554.087 1770.3,554.096 1770.31,554.105 1770.32,554.115 1770.33,554.124 1770.34,554.134 1770.35,554.143 1770.36,554.152 1770.37,554.162 1770.38,554.171 1770.38,554.18 1770.39,554.19 1770.4,554.199 1770.41,554.208 1770.42,554.218 1770.43,554.227 1770.44,554.237 1770.45,554.246 1770.46,554.255 1770.47,554.265 1770.48,554.274 1770.49,554.283 1770.49,554.293 1770.5,554.302 1770.51,554.311 1770.52,554.321 1770.53,554.33 1770.54,554.339 1770.55,554.349 1770.56,554.358 1770.57,554.367 1770.58,554.377 1770.59,554.386 1770.6,554.396 1770.61,554.405 1770.61,554.414 1770.62,554.424 1770.63,554.433 1770.64,554.442 1770.65,554.452 1770.66,554.461 1770.67,554.47 1770.68,554.48 1770.69,554.489 1770.7,554.498 1770.71,554.508 1770.72,554.517 1770.72,554.526 1770.73,554.536 1770.74,554.545 1770.75,554.554 1770.76,554.564 1770.77,554.573 1770.78,554.582 1770.79,554.592 1770.8,554.601 1770.81,554.61 1770.82,554.62 1770.83,554.629 1770.83,554.638 1770.84,554.648 1770.85,554.657 1770.86,554.666 1770.87,554.676 1770.88,554.685 1770.89,554.694 1770.9,554.704 1770.91,554.713 1770.92,554.723 1770.93,554.732 1770.94,554.741 1770.95,554.751 1770.95,554.76 1770.96,554.769 1770.97,554.778 1770.98,554.788 1770.99,554.797 1771,554.806 1771.01,554.816 1771.02,554.825 1771.03,554.834 1771.04,554.844 1771.05,554.853 1771.06,554.862 1771.06,554.872 1771.07,554.881 1771.08,554.89 1771.09,554.9 1771.1,554.909 1771.11,554.918 1771.12,554.928 1771.13,554.937 1771.14,554.946 1771.15,554.956 1771.16,554.965 1771.17,554.974 1771.17,554.984 1771.18,554.993 1771.19,555.002 1771.2,555.012 1771.21,555.021 1771.22,555.03 1771.23,555.04 1771.24,555.049 1771.25,555.058 1771.26,555.068 1771.27,555.077 1771.28,555.086 1771.29,555.095 1771.29,555.105 1771.3,555.114 1771.31,555.123 1771.32,555.133 1771.33,555.142 1771.34,555.151 1771.35,555.161 1771.36,555.17 1771.37,555.179 1771.38,555.189 1771.39,555.198 1771.4,555.207 1771.4,555.217 1771.41,555.226 1771.42,555.235 1771.43,555.244 1771.44,555.254 1771.45,555.263 1771.46,555.272 1771.47,555.282 1771.48,555.291 1771.49,555.3 1771.5,555.31 1771.51,555.319 1771.51,555.328 1771.52,555.337 1771.53,555.347 1771.54,555.356 1771.55,555.365 1771.56,555.375 1771.57,555.384 1771.58,555.393 1771.59,555.403 1771.6,555.412 1771.61,555.421 1771.62,555.43 1771.63,555.44 1771.63,555.449 1771.64,555.458 1771.65,555.468 1771.66,555.477 1771.67,555.486 1771.68,555.496 1771.69,555.505 1771.7,555.514 1771.71,555.523 1771.72,555.533 1771.73,555.542 1771.74,555.551 1771.74,555.561 1771.75,555.57 1771.76,555.579 1771.77,555.588 1771.78,555.598 1771.79,555.607 1771.8,555.616 1771.81,555.626 1771.82,555.635 1771.83,555.644 1771.84,555.653 1771.85,555.663 1771.85,555.672 1771.86,555.681 1771.87,555.691 1771.88,555.7 1771.89,555.709 1771.9,555.718 1771.91,555.728 1771.92,555.737 1771.93,555.746 1771.94,555.756 1771.95,555.765 1771.96,555.774 1771.97,555.783 1771.97,555.793 1771.98,555.802 1771.99,555.811 1772,555.821 1772.01,555.83 1772.02,555.839 1772.03,555.848 1772.04,555.858 1772.05,555.867 1772.06,555.876 1772.07,555.885 1772.08,555.895 1772.08,555.904 1772.09,555.913 1772.1,555.923 1772.11,555.932 1772.12,555.941 1772.13,555.95 1772.14,555.96 1772.15,555.969 1772.16,555.978 1772.17,555.987 1772.18,555.997 1772.19,556.006 1772.19,556.015 1772.2,556.025 1772.21,556.034 1772.22,556.043 1772.23,556.052 1772.24,556.062 1772.25,556.071 1772.26,556.08 1772.27,556.089 1772.28,556.099 1772.29,556.108 1772.3,556.117 1772.31,556.126 1772.31,556.136 1772.32,556.145 1772.33,556.154 1772.34,556.163 1772.35,556.173 1772.36,556.182 1772.37,556.191 1772.38,556.2 1772.39,556.21 1772.4,556.219 1772.41,556.228 1772.42,556.237 1772.42,556.247 1772.43,556.256 1772.44,556.265 1772.45,556.275 1772.46,556.284 1772.47,556.293 1772.48,556.302 1772.49,556.312 1772.5,556.321 1772.51,556.33 1772.52,556.339 1772.53,556.349 1772.53,556.358 1772.54,556.367 1772.55,556.376 1772.56,556.386 1772.57,556.395 1772.58,556.404 1772.59,556.413 1772.6,556.423 1772.61,556.432 1772.62,556.441 1772.63,556.45 1772.64,556.459 1772.65,556.469 1772.65,556.478 1772.66,556.487 1772.67,556.496 1772.68,556.506 1772.69,556.515 1772.7,556.524 1772.71,556.533 1772.72,556.543 1772.73,556.552 1772.74,556.561 1772.75,556.57 1772.76,556.58 1772.76,556.589 1772.77,556.598 1772.78,556.607 1772.79,556.617 1772.8,556.626 1772.81,556.635 1772.82,556.644 1772.83,556.653 1772.84,556.663 1772.85,556.672 1772.86,556.681 1772.87,556.69 1772.87,556.7 1772.88,556.709 1772.89,556.718 1772.9,556.727 1772.91,556.737 1772.92,556.746 1772.93,556.755 1772.94,556.764 1772.95,556.773 1772.96,556.783 1772.97,556.792 1772.98,556.801 1772.99,556.81 1772.99,556.82 1773,556.829 1773.01,556.838 1773.02,556.847 1773.03,556.857 1773.04,556.866 1773.05,556.875 1773.06,556.884 1773.07,556.893 1773.08,556.903 1773.09,556.912 1773.1,556.921 1773.1,556.93 1773.11,556.94 1773.12,556.949 1773.13,556.958 1773.14,556.967 1773.15,556.976 1773.16,556.986 1773.17,556.995 1773.18,557.004 1773.19,557.013 1773.2,557.022 1773.21,557.032 1773.21,557.041 1773.22,557.05 1773.23,557.059 1773.24,557.069 1773.25,557.078 1773.26,557.087 1773.27,557.096 1773.28,557.105 1773.29,557.115 1773.3,557.124 1773.31,557.133 1773.32,557.142 1773.33,557.151 1773.33,557.161 1773.34,557.17 1773.35,557.179 1773.36,557.188 1773.37,557.197 1773.38,557.207 1773.39,557.216 1773.4,557.225 1773.41,557.234 1773.42,557.243 1773.43,557.253 1773.44,557.262 1773.44,557.271 1773.45,557.28 1773.46,557.289 1773.47,557.299 1773.48,557.308 1773.49,557.317 1773.5,557.326 1773.51,557.335 1773.52,557.345 1773.53,557.354 1773.54,557.363 1773.55,557.372 1773.55,557.381 1773.56,557.391 1773.57,557.4 1773.58,557.409 1773.59,557.418 1773.6,557.427 1773.61,557.437 1773.62,557.446 1773.63,557.455 1773.64,557.464 1773.65,557.473 1773.66,557.483 1773.67,557.492 1773.67,557.501 1773.68,557.51 1773.69,557.519 1773.7,557.529 1773.71,557.538 1773.72,557.547 1773.73,557.556 1773.74,557.565 1773.75,557.574 1773.76,557.584 1773.77,557.593 1773.78,557.602 1773.78,557.611 1773.79,557.62 1773.8,557.63 1773.81,557.639 1773.82,557.648 1773.83,557.657 1773.84,557.666 1773.85,557.675 1773.86,557.685 1773.87,557.694 1773.88,557.703 1773.89,557.712 1773.89,557.721 1773.9,557.731 1773.91,557.74 1773.92,557.749 1773.93,557.758 1773.94,557.767 1773.95,557.776 1773.96,557.786 1773.97,557.795 1773.98,557.804 1773.99,557.813 1774,557.822 1774.01,557.831 1774.01,557.841 1774.02,557.85 1774.03,557.859 1774.04,557.868 1774.05,557.877 1774.06,557.886 1774.07,557.896 1774.08,557.905 1774.09,557.914 1774.1,557.923 1774.11,557.932 1774.12,557.941 1774.12,557.951 1774.13,557.96 1774.14,557.969 1774.15,557.978 1774.16,557.987 1774.17,557.996 1774.18,558.006 1774.19,558.015 1774.2,558.024 1774.21,558.033 1774.22,558.042 1774.23,558.051 1774.23,558.061 1774.24,558.07 1774.25,558.079 1774.26,558.088 1774.27,558.097 1774.28,558.106 1774.29,558.116 1774.3,558.125 1774.31,558.134 1774.32,558.143 1774.33,558.152 1774.34,558.161 1774.35,558.17 1774.35,558.18 1774.36,558.189 1774.37,558.198 1774.38,558.207 1774.39,558.216 1774.4,558.225 1774.41,558.235 1774.42,558.244 1774.43,558.253 1774.44,558.262 1774.45,558.271 1774.46,558.28 1774.46,558.289 1774.47,558.299 1774.48,558.308 1774.49,558.317 1774.5,558.326 1774.51,558.335 1774.52,558.344 1774.53,558.353 1774.54,558.363 1774.55,558.372 1774.56,558.381 1774.57,558.39 1774.57,558.399 1774.58,558.408 1774.59,558.417 1774.6,558.427 1774.61,558.436 1774.62,558.445 1774.63,558.454 1774.64,558.463 1774.65,558.472 1774.66,558.481 1774.67,558.491 1774.68,558.5 1774.69,558.509 1774.69,558.518 1774.7,558.527 1774.71,558.536 1774.72,558.545 1774.73,558.555 1774.74,558.564 1774.75,558.573 1774.76,558.582 1774.77,558.591 1774.78,558.6 1774.79,558.609 1774.8,558.618 1774.8,558.628 1774.81,558.637 1774.82,558.646 1774.83,558.655 1774.84,558.664 1774.85,558.673 1774.86,558.682 1774.87,558.691 1774.88,558.701 1774.89,558.71 1774.9,558.719 1774.91,558.728 1774.91,558.737 1774.92,558.746 1774.93,558.755 1774.94,558.764 1774.95,558.774 1774.96,558.783 1774.97,558.792 1774.98,558.801 1774.99,558.81 1775,558.819 1775.01,558.828 1775.02,558.837 1775.03,558.847 1775.03,558.856 1775.04,558.865 1775.05,558.874 1775.06,558.883 1775.07,558.892 1775.08,558.901 1775.09,558.91 1775.1,558.92 1775.11,558.929 1775.12,558.938 1775.13,558.947 1775.14,558.956 1775.14,558.965 1775.15,558.974 1775.16,558.983 1775.17,558.992 1775.18,559.002 1775.19,559.011 1775.2,559.02 1775.21,559.029 1775.22,559.038 1775.23,559.047 1775.24,559.056 1775.25,559.065 1775.25,559.074 1775.26,559.083 1775.27,559.093 1775.28,559.102 1775.29,559.111 1775.3,559.12 1775.31,559.129 1775.32,559.138 1775.33,559.147 1775.34,559.156 1775.35,559.165 1775.36,559.175 1775.37,559.184 1775.37,559.193 1775.38,559.202 1775.39,559.211 1775.4,559.22 1775.41,559.229 1775.42,559.238 1775.43,559.247 1775.44,559.256 1775.45,559.266 1775.46,559.275 1775.47,559.284 1775.48,559.293 1775.48,559.302 1775.49,559.311 1775.5,559.32 1775.51,559.329 1775.52,559.338 1775.53,559.347 1775.54,559.356 1775.55,559.366 1775.56,559.375 1775.57,559.384 1775.58,559.393 1775.59,559.402 1775.59,559.411 1775.6,559.42 1775.61,559.429 1775.62,559.438 1775.63,559.447 1775.64,559.456 1775.65,559.466 1775.66,559.475 1775.67,559.484 1775.68,559.493 1775.69,559.502 1775.7,559.511 1775.71,559.52 1775.71,559.529 1775.72,559.538 1775.73,559.547 1775.74,559.556 1775.75,559.565 1775.76,559.575 1775.77,559.584 1775.78,559.593 1775.79,559.602 1775.8,559.611 1775.81,559.62 1775.82,559.629 1775.82,559.638 1775.83,559.647 1775.84,559.656 1775.85,559.665 1775.86,559.674 1775.87,559.683 1775.88,559.693 1775.89,559.702 1775.9,559.711 1775.91,559.72 1775.92,559.729 1775.93,559.738 1775.93,559.747 1775.94,559.756 1775.95,559.765 1775.96,559.774 1775.97,559.783 1775.98,559.792 1775.99,559.801 1776,559.81 1776.01,559.819 1776.02,559.829 1776.03,559.838 1776.04,559.847 1776.05,559.856 1776.05,559.865 1776.06,559.874 1776.07,559.883 1776.08,559.892 1776.09,559.901 1776.1,559.91 1776.11,559.919 1776.12,559.928 1776.13,559.937 1776.14,559.946 1776.15,559.955 1776.16,559.965 1776.16,559.974 1776.17,559.983 1776.18,559.992 1776.19,560.001 1776.2,560.01 1776.21,560.019 1776.22,560.028 1776.23,560.037 1776.24,560.046 1776.25,560.055 1776.26,560.064 1776.27,560.073 1776.27,560.082 1776.28,560.091 1776.29,560.1 1776.3,560.109 1776.31,560.118 1776.32,560.127 1776.33,560.137 1776.34,560.146 1776.35,560.155 1776.36,560.164 1776.37,560.173 1776.38,560.182 1776.39,560.191 1776.39,560.2 1776.4,560.209 1776.41,560.218 1776.42,560.227 1776.43,560.236 1776.44,560.245 1776.45,560.254 1776.46,560.263 1776.47,560.272 1776.48,560.281 1776.49,560.29 1776.5,560.299 1776.5,560.308 1776.51,560.317 1776.52,560.326 1776.53,560.336 1776.54,560.345 1776.55,560.354 1776.56,560.363 1776.57,560.372 1776.58,560.381 1776.59,560.39 1776.6,560.399 1776.61,560.408 1776.61,560.417 1776.62,560.426 1776.63,560.435 1776.64,560.444 1776.65,560.453 1776.66,560.462 1776.67,560.471 1776.68,560.48 1776.69,560.489 1776.7,560.498 1776.71,560.507 1776.72,560.516 1776.73,560.525 1776.73,560.534 1776.74,560.543 1776.75,560.552 1776.76,560.561 1776.77,560.57 1776.78,560.579 1776.79,560.588 1776.8,560.597 1776.81,560.606 1776.82,560.616 1776.83,560.625 1776.84,560.634 1776.84,560.643 1776.85,560.652 1776.86,560.661 1776.87,560.67 1776.88,560.679 1776.89,560.688 1776.9,560.697 1776.91,560.706 1776.92,560.715 1776.93,560.724 1776.94,560.733 1776.95,560.742 1776.95,560.751 1776.96,560.76 1776.97,560.769 1776.98,560.778 1776.99,560.787 1777,560.796 1777.01,560.805 1777.02,560.814 1777.03,560.823 1777.04,560.832 1777.05,560.841 1777.06,560.85 1777.07,560.859 1777.07,560.868 1777.08,560.877 1777.09,560.886 1777.1,560.895 1777.11,560.904 1777.12,560.913 1777.13,560.922 1777.14,560.931 1777.15,560.94 1777.16,560.949 1777.17,560.958 1777.18,560.967 1777.18,560.976 1777.19,560.985 1777.2,560.994 1777.21,561.003 1777.22,561.012 1777.23,561.021 1777.24,561.03 1777.25,561.039 1777.26,561.048 1777.27,561.057 1777.28,561.066 1777.29,561.075 1777.3,561.084 1777.3,561.093 1777.31,561.102 1777.32,561.111 1777.33,561.12 1777.34,561.129 1777.35,561.138 1777.36,561.147 1777.37,561.156 1777.38,561.165 1777.39,561.174 1777.4,561.183 1777.41,561.192 1777.41,561.201 1777.42,561.21 1777.43,561.219 1777.44,561.228 1777.45,561.237 1777.46,561.246 1777.47,561.255 1777.48,561.264 1777.49,561.273 1777.5,561.282 1777.51,561.291 1777.52,561.3 1777.52,561.309 1777.53,561.318 1777.54,561.327 1777.55,561.336 1777.56,561.345 1777.57,561.354 1777.58,561.363 1777.59,561.372 1777.6,561.381 1777.61,561.39 1777.62,561.399 1777.63,561.408 1777.64,561.417 1777.64,561.426 1777.65,561.435 1777.66,561.444 1777.67,561.453 1777.68,561.462 1777.69,561.471 1777.7,561.48 1777.71,561.489 1777.72,561.498 1777.73,561.507 1777.74,561.516 1777.75,561.524 1777.75,561.533 1777.76,561.542 1777.77,561.551 1777.78,561.56 1777.79,561.569 1777.8,561.578 1777.81,561.587 1777.82,561.596 1777.83,561.605 1777.84,561.614 1777.85,561.623 1777.86,561.632 1777.86,561.641 1777.87,561.65 1777.88,561.659 1777.89,561.668 1777.9,561.677 1777.91,561.686 1777.92,561.695 1777.93,561.704 1777.94,561.713 1777.95,561.722 1777.96,561.731 1777.97,561.74 1777.98,561.749 1777.98,561.758 1777.99,561.767 1778,561.776 1778.01,561.785 1778.02,561.794 1778.03,561.802 1778.04,561.811 1778.05,561.82 1778.06,561.829 1778.07,561.838 1778.08,561.847 1778.09,561.856 1778.09,561.865 1778.1,561.874 1778.11,561.883 1778.12,561.892 1778.13,561.901 1778.14,561.91 1778.15,561.919 1778.16,561.928 1778.17,561.937 1778.18,561.946 1778.19,561.955 1778.2,561.964 1778.2,561.973 1778.21,561.982 1778.22,561.991 1778.23,562 1778.24,562.008 1778.25,562.017 1778.26,562.026 1778.27,562.035 1778.28,562.044 1778.29,562.053 1778.3,562.062 1778.31,562.071 1778.32,562.08 1778.32,562.089 1778.33,562.098 1778.34,562.107 1778.35,562.116 1778.36,562.125 1778.37,562.134 1778.38,562.143 1778.39,562.152 1778.4,562.161 1778.41,562.169 1778.42,562.178 1778.43,562.187 1778.43,562.196 1778.44,562.205 1778.45,562.214 1778.46,562.223 1778.47,562.232 1778.48,562.241 1778.49,562.25 1778.5,562.259 1778.51,562.268 1778.52,562.277 1778.53,562.286 1778.54,562.295 1778.54,562.304 1778.55,562.312 1778.56,562.321 1778.57,562.33 1778.58,562.339 1778.59,562.348 1778.6,562.357 1778.61,562.366 1778.62,562.375 1778.63,562.384 1778.64,562.393 1778.65,562.402 1778.66,562.411 1778.66,562.42 1778.67,562.429 1778.68,562.437 1778.69,562.446 1778.7,562.455 1778.71,562.464 1778.72,562.473 1778.73,562.482 1778.74,562.491 1778.75,562.5 1778.76,562.509 1778.77,562.518 1778.77,562.527 1778.78,562.536 1778.79,562.545 1778.8,562.553 1778.81,562.562 1778.82,562.571 1778.83,562.58 1778.84,562.589 1778.85,562.598 1778.86,562.607 1778.87,562.616 1778.88,562.625 1778.88,562.634 1778.89,562.643 1778.9,562.652 1778.91,562.66 1778.92,562.669 1778.93,562.678 1778.94,562.687 1778.95,562.696 1778.96,562.705 1778.97,562.714 1778.98,562.723 1778.99,562.732 1779,562.741 1779,562.75 1779.01,562.758 1779.02,562.767 1779.03,562.776 1779.04,562.785 1779.05,562.794 1779.06,562.803 1779.07,562.812 1779.08,562.821 1779.09,562.83 1779.1,562.839 1779.11,562.848 1779.11,562.856 1779.12,562.865 1779.13,562.874 1779.14,562.883 1779.15,562.892 1779.16,562.901 1779.17,562.91 1779.18,562.919 1779.19,562.928 1779.2,562.937 1779.21,562.945 1779.22,562.954 1779.22,562.963 1779.23,562.972 1779.24,562.981 1779.25,562.99 1779.26,562.999 1779.27,563.008 1779.28,563.017 1779.29,563.025 1779.3,563.034 1779.31,563.043 1779.32,563.052 1779.33,563.061 1779.34,563.07 1779.34,563.079 1779.35,563.088 1779.36,563.097 1779.37,563.106 1779.38,563.114 1779.39,563.123 1779.4,563.132 1779.41,563.141 1779.42,563.15 1779.43,563.159 1779.44,563.168 1779.45,563.177 1779.45,563.185 1779.46,563.194 1779.47,563.203 1779.48,563.212 1779.49,563.221 1779.5,563.23 1779.51,563.239 1779.52,563.248 1779.53,563.257 1779.54,563.265 1779.55,563.274 1779.56,563.283 1779.56,563.292 1779.57,563.301 1779.58,563.31 1779.59,563.319 1779.6,563.328 1779.61,563.336 1779.62,563.345 1779.63,563.354 1779.64,563.363 1779.65,563.372 1779.66,563.381 1779.67,563.39 1779.68,563.399 1779.68,563.407 1779.69,563.416 1779.7,563.425 1779.71,563.434 1779.72,563.443 1779.73,563.452 1779.74,563.461 1779.75,563.47 1779.76,563.478 1779.77,563.487 1779.78,563.496 1779.79,563.505 1779.79,563.514 1779.8,563.523 1779.81,563.532 1779.82,563.541 1779.83,563.549 1779.84,563.558 1779.85,563.567 1779.86,563.576 1779.87,563.585 1779.88,563.594 1779.89,563.603 1779.9,563.611 1779.9,563.62 1779.91,563.629 1779.92,563.638 1779.93,563.647 1779.94,563.656 1779.95,563.665 1779.96,563.673 1779.97,563.682 1779.98,563.691 1779.99,563.7 1780,563.709 1780.01,563.718 1780.02,563.727 1780.02,563.735 1780.03,563.744 1780.04,563.753 1780.05,563.762 1780.06,563.771 1780.07,563.78 1780.08,563.789 1780.09,563.797 1780.1,563.806 1780.11,563.815 1780.12,563.824 1780.13,563.833 1780.13,563.842 1780.14,563.85 1780.15,563.859 1780.16,563.868 1780.17,563.877 1780.18,563.886 1780.19,563.895 1780.2,563.904 1780.21,563.912 1780.22,563.921 1780.23,563.93 1780.24,563.939 1780.24,563.948 1780.25,563.957 1780.26,563.965 1780.27,563.974 1780.28,563.983 1780.29,563.992 1780.3,564.001 1780.31,564.01 1780.32,564.019 1780.33,564.027 1780.34,564.036 1780.35,564.045 1780.36,564.054 1780.36,564.063 1780.37,564.072 1780.38,564.08 1780.39,564.089 1780.4,564.098 1780.41,564.107 1780.42,564.116 1780.43,564.125 1780.44,564.133 1780.45,564.142 1780.46,564.151 1780.47,564.16 1780.47,564.169 1780.48,564.178 1780.49,564.186 1780.5,564.195 1780.51,564.204 1780.52,564.213 1780.53,564.222 1780.54,564.231 1780.55,564.239 1780.56,564.248 1780.57,564.257 1780.58,564.266 1780.58,564.275 1780.59,564.283 1780.6,564.292 1780.61,564.301 1780.62,564.31 1780.63,564.319 1780.64,564.328 1780.65,564.336 1780.66,564.345 1780.67,564.354 1780.68,564.363 1780.69,564.372 1780.7,564.38 1780.7,564.389 1780.71,564.398 1780.72,564.407 1780.73,564.416 1780.74,564.425 1780.75,564.433 1780.76,564.442 1780.77,564.451 1780.78,564.46 1780.79,564.469 1780.8,564.477 1780.81,564.486 1780.81,564.495 1780.82,564.504 1780.83,564.513 1780.84,564.522 1780.85,564.53 1780.86,564.539 1780.87,564.548 1780.88,564.557 1780.89,564.566 1780.9,564.574 1780.91,564.583 1780.92,564.592 1780.92,564.601 1780.93,564.61 1780.94,564.618 1780.95,564.627 1780.96,564.636 1780.97,564.645 1780.98,564.654 1780.99,564.662 1781,564.671 1781.01,564.68 1781.02,564.689 1781.03,564.698 1781.04,564.706 1781.04,564.715 1781.05,564.724 1781.06,564.733 1781.07,564.742 1781.08,564.75 1781.09,564.759 1781.1,564.768 1781.11,564.777 1781.12,564.786 1781.13,564.794 1781.14,564.803 1781.15,564.812 1781.15,564.821 1781.16,564.83 1781.17,564.838 1781.18,564.847 1781.19,564.856 1781.2,564.865 1781.21,564.874 1781.22,564.882 1781.23,564.891 1781.24,564.9 1781.25,564.909 1781.26,564.918 1781.26,564.926 1781.27,564.935 1781.28,564.944 1781.29,564.953 1781.3,564.961 1781.31,564.97 1781.32,564.979 1781.33,564.988 1781.34,564.997 1781.35,565.005 1781.36,565.014 1781.37,565.023 1781.38,565.032 1781.38,565.041 1781.39,565.049 1781.4,565.058 1781.41,565.067 1781.42,565.076 1781.43,565.084 1781.44,565.093 1781.45,565.102 1781.46,565.111 1781.47,565.12 1781.48,565.128 1781.49,565.137 1781.49,565.146 1781.5,565.155 1781.51,565.163 1781.52,565.172 1781.53,565.181 1781.54,565.19 1781.55,565.199 1781.56,565.207 1781.57,565.216 1781.58,565.225 1781.59,565.234 1781.6,565.242 1781.6,565.251 1781.61,565.26 1781.62,565.269 1781.63,565.277 1781.64,565.286 1781.65,565.295 1781.66,565.304 1781.67,565.313 1781.68,565.321 1781.69,565.33 1781.7,565.339 1781.71,565.348 1781.72,565.356 1781.72,565.365 1781.73,565.374 1781.74,565.383 1781.75,565.391 1781.76,565.4 1781.77,565.409 1781.78,565.418 1781.79,565.426 1781.8,565.435 1781.81,565.444 1781.82,565.453 1781.83,565.461 1781.83,565.47 1781.84,565.479 1781.85,565.488 1781.86,565.496 1781.87,565.505 1781.88,565.514 1781.89,565.523 1781.9,565.532 1781.91,565.54 1781.92,565.549 1781.93,565.558 1781.94,565.567 1781.94,565.575 1781.95,565.584 1781.96,565.593 1781.97,565.602 1781.98,565.61 1781.99,565.619 1782,565.628 1782.01,565.637 1782.02,565.645 1782.03,565.654 1782.04,565.663 1782.05,565.672 1782.06,565.68 1782.06,565.689 1782.07,565.698 1782.08,565.707 1782.09,565.715 1782.1,565.724 1782.11,565.733 1782.12,565.741 1782.13,565.75 1782.14,565.759 1782.15,565.768 1782.16,565.776 1782.17,565.785 1782.17,565.794 1782.18,565.803 1782.19,565.811 1782.2,565.82 1782.21,565.829 1782.22,565.838 1782.23,565.846 1782.24,565.855 1782.25,565.864 1782.26,565.873 1782.27,565.881 1782.28,565.89 1782.28,565.899 1782.29,565.907 1782.3,565.916 1782.31,565.925 1782.32,565.934 1782.33,565.942 1782.34,565.951 1782.35,565.96 1782.36,565.969 1782.37,565.977 1782.38,565.986 1782.39,565.995 1782.4,566.004 1782.4,566.012 1782.41,566.021 1782.42,566.03 1782.43,566.038 1782.44,566.047 1782.45,566.056 1782.46,566.065 1782.47,566.073 1782.48,566.082 1782.49,566.091 1782.5,566.099 1782.51,566.108 1782.51,566.117 1782.52,566.126 1782.53,566.134 1782.54,566.143 1782.55,566.152 1782.56,566.161 1782.57,566.169 1782.58,566.178 1782.59,566.187 1782.6,566.195 1782.61,566.204 1782.62,566.213 1782.62,566.222 1782.63,566.23 1782.64,566.239 1782.65,566.248 1782.66,566.256 1782.67,566.265 1782.68,566.274 1782.69,566.283 1782.7,566.291 1782.71,566.3 1782.72,566.309 1782.73,566.317 1782.74,566.326 1782.74,566.335 1782.75,566.344 1782.76,566.352 1782.77,566.361 1782.78,566.37 1782.79,566.378 1782.8,566.387 1782.81,566.396 1782.82,566.404 1782.83,566.413 1782.84,566.422 1782.85,566.431 1782.85,566.439 1782.86,566.448 1782.87,566.457 1782.88,566.465 1782.89,566.474 1782.9,566.483 1782.91,566.491 1782.92,566.5 1782.93,566.509 1782.94,566.518 1782.95,566.526 1782.96,566.535 1782.96,566.544 1782.97,566.552 1782.98,566.561 1782.99,566.57 1783,566.578 1783.01,566.587 1783.02,566.596 1783.03,566.605 1783.04,566.613 1783.05,566.622 1783.06,566.631 1783.07,566.639 1783.08,566.648 1783.08,566.657 1783.09,566.665 1783.1,566.674 1783.11,566.683 1783.12,566.691 1783.13,566.7 1783.14,566.709 1783.15,566.717 1783.16,566.726 1783.17,566.735 1783.18,566.744 1783.19,566.752 1783.19,566.761 1783.2,566.77 1783.21,566.778 1783.22,566.787 1783.23,566.796 1783.24,566.804 1783.25,566.813 1783.26,566.822 1783.27,566.83 1783.28,566.839 1783.29,566.848 1783.3,566.856 1783.3,566.865 1783.31,566.874 1783.32,566.882 1783.33,566.891 1783.34,566.9 1783.35,566.908 1783.36,566.917 1783.37,566.926 1783.38,566.935 1783.39,566.943 1783.4,566.952 1783.41,566.961 1783.42,566.969 1783.42,566.978 1783.43,566.987 1783.44,566.995 1783.45,567.004 1783.46,567.013 1783.47,567.021 1783.48,567.03 1783.49,567.039 1783.5,567.047 1783.51,567.056 1783.52,567.065 1783.53,567.073 1783.53,567.082 1783.54,567.091 1783.55,567.099 1783.56,567.108 1783.57,567.117 1783.58,567.125 1783.59,567.134 1783.6,567.143 1783.61,567.151 1783.62,567.16 1783.63,567.169 1783.64,567.177 1783.64,567.186 1783.65,567.195 1783.66,567.203 1783.67,567.212 1783.68,567.22 1783.69,567.229 1783.7,567.238 1783.71,567.246 1783.72,567.255 1783.73,567.264 1783.74,567.272 1783.75,567.281 1783.76,567.29 1783.76,567.298 1783.77,567.307 1783.78,567.316 1783.79,567.324 1783.8,567.333 1783.81,567.342 1783.82,567.35 1783.83,567.359 1783.84,567.368 1783.85,567.376 1783.86,567.385 1783.87,567.394 1783.87,567.402 1783.88,567.411 1783.89,567.419 1783.9,567.428 1783.91,567.437 1783.92,567.445 1783.93,567.454 1783.94,567.463 1783.95,567.471 1783.96,567.48 1783.97,567.489 1783.98,567.497 1783.98,567.506 1783.99,567.515 1784,567.523 1784.01,567.532 1784.02,567.54 1784.03,567.549 1784.04,567.558 1784.05,567.566 1784.06,567.575 1784.07,567.584 1784.08,567.592 1784.09,567.601 1784.1,567.61 1784.1,567.618 1784.11,567.627 1784.12,567.635 1784.13,567.644 1784.14,567.653 1784.15,567.661 1784.16,567.67 1784.17,567.679 1784.18,567.687 1784.19,567.696 1784.2,567.705 1784.21,567.713 1784.21,567.722 1784.22,567.73 1784.23,567.739 1784.24,567.748 1784.25,567.756 1784.26,567.765 1784.27,567.774 1784.28,567.782 1784.29,567.791 1784.3,567.799 1784.31,567.808 1784.32,567.817 1784.32,567.825 1784.33,567.834 1784.34,567.843 1784.35,567.851 1784.36,567.86 1784.37,567.868 1784.38,567.877 1784.39,567.886 1784.4,567.894 1784.41,567.903 1784.42,567.911 1784.43,567.92 1784.44,567.929 1784.44,567.937 1784.45,567.946 1784.46,567.955 1784.47,567.963 1784.48,567.972 1784.49,567.98 1784.5,567.989 1784.51,567.998 1784.52,568.006 1784.53,568.015 1784.54,568.023 1784.55,568.032 1784.55,568.041 1784.56,568.049 1784.57,568.058 1784.58,568.067 1784.59,568.075 1784.6,568.084 1784.61,568.092 1784.62,568.101 1784.63,568.11 1784.64,568.118 1784.65,568.127 1784.66,568.135 1784.66,568.144 1784.67,568.153 1784.68,568.161 1784.69,568.17 1784.7,568.178 1784.71,568.187 1784.72,568.196 1784.73,568.204 1784.74,568.213 1784.75,568.221 1784.76,568.23 1784.77,568.239 1784.78,568.247 1784.78,568.256 1784.79,568.264 1784.8,568.273 1784.81,568.282 1784.82,568.29 1784.83,568.299 1784.84,568.307 1784.85,568.316 1784.86,568.325 1784.87,568.333 1784.88,568.342 1784.89,568.35 1784.89,568.359 1784.9,568.368 1784.91,568.376 1784.92,568.385 1784.93,568.393 1784.94,568.402 1784.95,568.41 1784.96,568.419 1784.97,568.428 1784.98,568.436 1784.99,568.445 1785,568.453 1785,568.462 1785.01,568.471 1785.02,568.479 1785.03,568.488 1785.04,568.496 1785.05,568.505 1785.06,568.513 1785.07,568.522 1785.08,568.531 1785.09,568.539 1785.1,568.548 1785.11,568.556 1785.12,568.565 1785.12,568.574 1785.13,568.582 1785.14,568.591 1785.15,568.599 1785.16,568.608 1785.17,568.616 1785.18,568.625 1785.19,568.634 1785.2,568.642 1785.21,568.651 1785.22,568.659 1785.23,568.668 1785.23,568.676 1785.24,568.685 1785.25,568.694 1785.26,568.702 1785.27,568.711 1785.28,568.719 1785.29,568.728 1785.3,568.736 1785.31,568.745 1785.32,568.754 1785.33,568.762 1785.34,568.771 1785.34,568.779 1785.35,568.788 1785.36,568.796 1785.37,568.805 1785.38,568.814 1785.39,568.822 1785.4,568.831 1785.41,568.839 1785.42,568.848 1785.43,568.856 1785.44,568.865 1785.45,568.873 1785.46,568.882 1785.46,568.891 1785.47,568.899 1785.48,568.908 1785.49,568.916 1785.5,568.925 1785.51,568.933 1785.52,568.942 1785.53,568.951 1785.54,568.959 1785.55,568.968 1785.56,568.976 1785.57,568.985 1785.57,568.993 1785.58,569.002 1785.59,569.01 1785.6,569.019 1785.61,569.028 1785.62,569.036 1785.63,569.045 1785.64,569.053 1785.65,569.062 1785.66,569.07 1785.67,569.079 1785.68,569.087 1785.68,569.096 1785.69,569.104 1785.7,569.113 1785.71,569.122 1785.72,569.13 1785.73,569.139 1785.74,569.147 1785.75,569.156 1785.76,569.164 1785.77,569.173 1785.78,569.181 1785.79,569.19 1785.8,569.198 1785.8,569.207 1785.81,569.216 1785.82,569.224 1785.83,569.233 1785.84,569.241 1785.85,569.25 1785.86,569.258 1785.87,569.267 1785.88,569.275 1785.89,569.284 1785.9,569.292 1785.91,569.301 1785.91,569.309 1785.92,569.318 1785.93,569.327 1785.94,569.335 1785.95,569.344 1785.96,569.352 1785.97,569.361 1785.98,569.369 1785.99,569.378 1786,569.386 1786.01,569.395 1786.02,569.403 1786.02,569.412 1786.03,569.42 1786.04,569.429 1786.05,569.437 1786.06,569.446 1786.07,569.454 1786.08,569.463 1786.09,569.472 1786.1,569.48 1786.11,569.489 1786.12,569.497 1786.13,569.506 1786.14,569.514 1786.14,569.523 1786.15,569.531 1786.16,569.54 1786.17,569.548 1786.18,569.557 1786.19,569.565 1786.2,569.574 1786.21,569.582 1786.22,569.591 1786.23,569.599 1786.24,569.608 1786.25,569.616 1786.25,569.625 1786.26,569.633 1786.27,569.642 1786.28,569.65 1786.29,569.659 1786.3,569.667 1786.31,569.676 1786.32,569.684 1786.33,569.693 1786.34,569.702 1786.35,569.71 1786.36,569.719 1786.36,569.727 1786.37,569.736 1786.38,569.744 1786.39,569.753 1786.4,569.761 1786.41,569.77 1786.42,569.778 1786.43,569.787 1786.44,569.795 1786.45,569.804 1786.46,569.812 1786.47,569.821 1786.48,569.829 1786.48,569.838 1786.49,569.846 1786.5,569.855 1786.51,569.863 1786.52,569.872 1786.53,569.88 1786.54,569.889 1786.55,569.897 1786.56,569.906 1786.57,569.914 1786.58,569.923 1786.59,569.931 1786.59,569.94 1786.6,569.948 1786.61,569.957 1786.62,569.965 1786.63,569.974 1786.64,569.982 1786.65,569.991 1786.66,569.999 1786.67,570.008 1786.68,570.016 1786.69,570.025 1786.7,570.033 1786.7,570.042 1786.71,570.05 1786.72,570.059 1786.73,570.067 1786.74,570.076 1786.75,570.084 1786.76,570.093 1786.77,570.101 1786.78,570.109 1786.79,570.118 1786.8,570.126 1786.81,570.135 1786.82,570.143 1786.82,570.152 1786.83,570.16 1786.84,570.169 1786.85,570.177 1786.86,570.186 1786.87,570.194 1786.88,570.203 1786.89,570.211 1786.9,570.22 1786.91,570.228 1786.92,570.237 1786.93,570.245 1786.93,570.254 1786.94,570.262 1786.95,570.271 1786.96,570.279 1786.97,570.288 1786.98,570.296 1786.99,570.305 1787,570.313 1787.01,570.321 1787.02,570.33 1787.03,570.338 1787.04,570.347 1787.04,570.355 1787.05,570.364 1787.06,570.372 1787.07,570.381 1787.08,570.389 1787.09,570.398 1787.1,570.406 1787.11,570.415 1787.12,570.423 1787.13,570.432 1787.14,570.44 1787.15,570.449 1787.16,570.457 1787.16,570.465 1787.17,570.474 1787.18,570.482 1787.19,570.491 1787.2,570.499 1787.21,570.508 1787.22,570.516 1787.23,570.525 1787.24,570.533 1787.25,570.542 1787.26,570.55 1787.27,570.559 1787.27,570.567 1787.28,570.575 1787.29,570.584 1787.3,570.592 1787.31,570.601 1787.32,570.609 1787.33,570.618 1787.34,570.626 1787.35,570.635 1787.36,570.643 1787.37,570.652 1787.38,570.66 1787.38,570.668 1787.39,570.677 1787.4,570.685 1787.41,570.694 1787.42,570.702 1787.43,570.711 1787.44,570.719 1787.45,570.728 1787.46,570.736 1787.47,570.745 1787.48,570.753 1787.49,570.761 1787.5,570.77 1787.5,570.778 1787.51,570.787 1787.52,570.795 1787.53,570.804 1787.54,570.812 1787.55,570.821 1787.56,570.829 1787.57,570.837 1787.58,570.846 1787.59,570.854 1787.6,570.863 1787.61,570.871 1787.61,570.88 1787.62,570.888 1787.63,570.897 1787.64,570.905 1787.65,570.913 1787.66,570.922 1787.67,570.93 1787.68,570.939 1787.69,570.947 1787.7,570.956 1787.71,570.964 1787.72,570.972 1787.72,570.981 1787.73,570.989 1787.74,570.998 1787.75,571.006 1787.76,571.015 1787.77,571.023 1787.78,571.031 1787.79,571.04 1787.8,571.048 1787.81,571.057 1787.82,571.065 1787.83,571.074 1787.84,571.082 1787.84,571.091 1787.85,571.099 1787.86,571.107 1787.87,571.116 1787.88,571.124 1787.89,571.133 1787.9,571.141 1787.91,571.149 1787.92,571.158 1787.93,571.166 1787.94,571.175 1787.95,571.183 1787.95,571.192 1787.96,571.2 1787.97,571.208 1787.98,571.217 1787.99,571.225 1788,571.234 1788.01,571.242 1788.02,571.251 1788.03,571.259 1788.04,571.267 1788.05,571.276 1788.06,571.284 1788.06,571.293 1788.07,571.301 1788.08,571.309 1788.09,571.318 1788.1,571.326 1788.11,571.335 1788.12,571.343 1788.13,571.351 1788.14,571.36 1788.15,571.368 1788.16,571.377 1788.17,571.385 1788.18,571.394 1788.18,571.402 1788.19,571.41 1788.2,571.419 1788.21,571.427 1788.22,571.436 1788.23,571.444 1788.24,571.452 1788.25,571.461 1788.26,571.469 1788.27,571.478 1788.28,571.486 1788.29,571.494 1788.29,571.503 1788.3,571.511 1788.31,571.52 1788.32,571.528 1788.33,571.536 1788.34,571.545 1788.35,571.553 1788.36,571.562 1788.37,571.57 1788.38,571.578 1788.39,571.587 1788.4,571.595 1788.4,571.604 1788.41,571.612 1788.42,571.62 1788.43,571.629 1788.44,571.637 1788.45,571.646 1788.46,571.654 1788.47,571.662 1788.48,571.671 1788.49,571.679 1788.5,571.688 1788.51,571.696 1788.52,571.704 1788.52,571.713 1788.53,571.721 1788.54,571.729 1788.55,571.738 1788.56,571.746 1788.57,571.755 1788.58,571.763 1788.59,571.771 1788.6,571.78 1788.61,571.788 1788.62,571.797 1788.63,571.805 1788.63,571.813 1788.64,571.822 1788.65,571.83 1788.66,571.838 1788.67,571.847 1788.68,571.855 1788.69,571.864 1788.7,571.872 1788.71,571.88 1788.72,571.889 1788.73,571.897 1788.74,571.905 1788.74,571.914 1788.75,571.922 1788.76,571.931 1788.77,571.939 1788.78,571.947 1788.79,571.956 1788.8,571.964 1788.81,571.972 1788.82,571.981 1788.83,571.989 1788.84,571.998 1788.85,572.006 1788.86,572.014 1788.86,572.023 1788.87,572.031 1788.88,572.039 1788.89,572.048 1788.9,572.056 1788.91,572.065 1788.92,572.073 1788.93,572.081 1788.94,572.09 1788.95,572.098 1788.96,572.106 1788.97,572.115 1788.97,572.123 1788.98,572.131 1788.99,572.14 1789,572.148 1789.01,572.157 1789.02,572.165 1789.03,572.173 1789.04,572.182 1789.05,572.19 1789.06,572.198 1789.07,572.207 1789.08,572.215 1789.08,572.223 1789.09,572.232 1789.1,572.24 1789.11,572.248 1789.12,572.257 1789.13,572.265 1789.14,572.274 1789.15,572.282 1789.16,572.29 1789.17,572.299 1789.18,572.307 1789.19,572.315 1789.2,572.324 1789.2,572.332 1789.21,572.34 1789.22,572.349 1789.23,572.357 1789.24,572.365 1789.25,572.374 1789.26,572.382 1789.27,572.39 1789.28,572.399 1789.29,572.407 1789.3,572.415 1789.31,572.424 1789.31,572.432 1789.32,572.44 1789.33,572.449 1789.34,572.457 1789.35,572.466 1789.36,572.474 1789.37,572.482 1789.38,572.491 1789.39,572.499 1789.4,572.507 1789.41,572.516 1789.42,572.524 1789.42,572.532 1789.43,572.541 1789.44,572.549 1789.45,572.557 1789.46,572.566 1789.47,572.574 1789.48,572.582 1789.49,572.591 1789.5,572.599 1789.51,572.607 1789.52,572.616 1789.53,572.624 1789.54,572.632 1789.54,572.641 1789.55,572.649 1789.56,572.657 1789.57,572.666 1789.58,572.674 1789.59,572.682 1789.6,572.691 1789.61,572.699 1789.62,572.707 1789.63,572.716 1789.64,572.724 1789.65,572.732 1789.65,572.74 1789.66,572.749 1789.67,572.757 1789.68,572.765 1789.69,572.774 1789.7,572.782 1789.71,572.79 1789.72,572.799 1789.73,572.807 1789.74,572.815 1789.75,572.824 1789.76,572.832 1789.76,572.84 1789.77,572.849 1789.78,572.857 1789.79,572.865 1789.8,572.874 1789.81,572.882 1789.82,572.89 1789.83,572.899 1789.84,572.907 1789.85,572.915 1789.86,572.923 1789.87,572.932 1789.88,572.94 1789.88,572.948 1789.89,572.957 1789.9,572.965 1789.91,572.973 1789.92,572.982 1789.93,572.99 1789.94,572.998 1789.95,573.007 1789.96,573.015 1789.97,573.023 1789.98,573.032 1789.99,573.04 1789.99,573.048 1790,573.056 1790.01,573.065 1790.02,573.073 1790.03,573.081 1790.04,573.09 1790.05,573.098 1790.06,573.106 1790.07,573.115 1790.08,573.123 1790.09,573.131 1790.1,573.139 1790.1,573.148 1790.11,573.156 1790.12,573.164 1790.13,573.173 1790.14,573.181 1790.15,573.189 1790.16,573.198 1790.17,573.206 1790.18,573.214 1790.19,573.222 1790.2,573.231 1790.21,573.239 1790.22,573.247 1790.22,573.256 1790.23,573.264 1790.24,573.272 1790.25,573.28 1790.26,573.289 1790.27,573.297 1790.28,573.305 1790.29,573.314 1790.3,573.322 1790.31,573.33 1790.32,573.338 1790.33,573.347 1790.33,573.355 1790.34,573.363 1790.35,573.372 1790.36,573.38 1790.37,573.388 1790.38,573.396 1790.39,573.405 1790.4,573.413 1790.41,573.421 1790.42,573.43 1790.43,573.438 1790.44,573.446 1790.44,573.454 1790.45,573.463 1790.46,573.471 1790.47,573.479 1790.48,573.487 1790.49,573.496 1790.5,573.504 1790.51,573.512 1790.52,573.521 1790.53,573.529 1790.54,573.537 1790.55,573.545 1790.56,573.554 1790.56,573.562 1790.57,573.57 1790.58,573.578 1790.59,573.587 1790.6,573.595 1790.61,573.603 1790.62,573.612 1790.63,573.62 1790.64,573.628 1790.65,573.636 1790.66,573.645 1790.67,573.653 1790.67,573.661 1790.68,573.669 1790.69,573.678 1790.7,573.686 1790.71,573.694 1790.72,573.702 1790.73,573.711 1790.74,573.719 1790.75,573.727 1790.76,573.736 1790.77,573.744 1790.78,573.752 1790.78,573.76 1790.79,573.769 1790.8,573.777 1790.81,573.785 1790.82,573.793 1790.83,573.802 1790.84,573.81 1790.85,573.818 1790.86,573.826 1790.87,573.835 1790.88,573.843 1790.89,573.851 1790.9,573.859 1790.9,573.868 1790.91,573.876 1790.92,573.884 1790.93,573.892 1790.94,573.901 1790.95,573.909 1790.96,573.917 1790.97,573.925 1790.98,573.934 1790.99,573.942 1791,573.95 1791.01,573.958 1791.01,573.967 1791.02,573.975 1791.03,573.983 1791.04,573.991 1791.05,574 1791.06,574.008 1791.07,574.016 1791.08,574.024 1791.09,574.033 1791.1,574.041 1791.11,574.049 1791.12,574.057 1791.12,574.065 1791.13,574.074 1791.14,574.082 1791.15,574.09 1791.16,574.098 1791.17,574.107 1791.18,574.115 1791.19,574.123 1791.2,574.131 1791.21,574.14 1791.22,574.148 1791.23,574.156 1791.24,574.164 1791.24,574.173 1791.25,574.181 1791.26,574.189 1791.27,574.197 1791.28,574.205 1791.29,574.214 1791.3,574.222 1791.31,574.23 1791.32,574.238 1791.33,574.247 1791.34,574.255 1791.35,574.263 1791.35,574.271 1791.36,574.279 1791.37,574.288 1791.38,574.296 1791.39,574.304 1791.4,574.312 1791.41,574.321 1791.42,574.329 1791.43,574.337 1791.44,574.345 1791.45,574.353 1791.46,574.362 1791.46,574.37 1791.47,574.378 1791.48,574.386 1791.49,574.395 1791.5,574.403 1791.51,574.411 1791.52,574.419 1791.53,574.427 1791.54,574.436 1791.55,574.444 1791.56,574.452 1791.57,574.46 1791.58,574.469 1791.58,574.477 1791.59,574.485 1791.6,574.493 1791.61,574.501 1791.62,574.51 1791.63,574.518 1791.64,574.526 1791.65,574.534 1791.66,574.542 1791.67,574.551 1791.68,574.559 1791.69,574.567 1791.69,574.575 1791.7,574.583 1791.71,574.592 1791.72,574.6 1791.73,574.608 1791.74,574.616 1791.75,574.624 1791.76,574.633 1791.77,574.641 1791.78,574.649 1791.79,574.657 1791.8,574.665 1791.8,574.674 1791.81,574.682 1791.82,574.69 1791.83,574.698 1791.84,574.706 1791.85,574.715 1791.86,574.723 1791.87,574.731 1791.88,574.739 1791.89,574.747 1791.9,574.756 1791.91,574.764 1791.92,574.772 1791.92,574.78 1791.93,574.788 1791.94,574.797 1791.95,574.805 1791.96,574.813 1791.97,574.821 1791.98,574.829 1791.99,574.837 1792,574.846 1792.01,574.854 1792.02,574.862 1792.03,574.87 1792.03,574.878 1792.04,574.887 1792.05,574.895 1792.06,574.903 1792.07,574.911 1792.08,574.919 1792.09,574.928 1792.1,574.936 1792.11,574.944 1792.12,574.952 1792.13,574.96 1792.14,574.968 1792.14,574.977 1792.15,574.985 1792.16,574.993 1792.17,575.001 1792.18,575.009 1792.19,575.017 1792.2,575.026 1792.21,575.034 1792.22,575.042 1792.23,575.05 1792.24,575.058 1792.25,575.067 1792.26,575.075 1792.26,575.083 1792.27,575.091 1792.28,575.099 1792.29,575.107 1792.3,575.116 1792.31,575.124 1792.32,575.132 1792.33,575.14 1792.34,575.148 1792.35,575.156 1792.36,575.165 1792.37,575.173 1792.37,575.181 1792.38,575.189 1792.39,575.197 1792.4,575.205 1792.41,575.214 1792.42,575.222 1792.43,575.23 1792.44,575.238 1792.45,575.246 1792.46,575.254 1792.47,575.262 1792.48,575.271 1792.48,575.279 1792.49,575.287 1792.5,575.295 1792.51,575.303 1792.52,575.311 1792.53,575.32 1792.54,575.328 1792.55,575.336 1792.56,575.344 1792.57,575.352 1792.58,575.36 1792.59,575.369 1792.6,575.377 1792.6,575.385 1792.61,575.393 1792.62,575.401 1792.63,575.409 1792.64,575.417 1792.65,575.426 1792.66,575.434 1792.67,575.442 1792.68,575.45 1792.69,575.458 1792.7,575.466 1792.71,575.474 1792.71,575.483 1792.72,575.491 1792.73,575.499 1792.74,575.507 1792.75,575.515 1792.76,575.523 1792.77,575.531 1792.78,575.54 1792.79,575.548 1792.8,575.556 1792.81,575.564 1792.82,575.572 1792.82,575.58 1792.83,575.588 1792.84,575.597 1792.85,575.605 1792.86,575.613 1792.87,575.621 1792.88,575.629 1792.89,575.637 1792.9,575.645 1792.91,575.653 1792.92,575.662 1792.93,575.67 1792.94,575.678 1792.94,575.686 1792.95,575.694 1792.96,575.702 1792.97,575.71 1792.98,575.719 1792.99,575.727 1793,575.735 1793.01,575.743 1793.02,575.751 1793.03,575.759 1793.04,575.767 1793.05,575.775 1793.05,575.784 1793.06,575.792 1793.07,575.8 1793.08,575.808 1793.09,575.816 1793.1,575.824 1793.11,575.832 1793.12,575.84 1793.13,575.848 1793.14,575.857 1793.15,575.865 1793.16,575.873 1793.16,575.881 1793.17,575.889 1793.18,575.897 1793.19,575.905 1793.2,575.913 1793.21,575.922 1793.22,575.93 1793.23,575.938 1793.24,575.946 1793.25,575.954 1793.26,575.962 1793.27,575.97 1793.28,575.978 1793.28,575.986 1793.29,575.995 1793.3,576.003 1793.31,576.011 1793.32,576.019 1793.33,576.027 1793.34,576.035 1793.35,576.043 1793.36,576.051 1793.37,576.059 1793.38,576.067 1793.39,576.076 1793.39,576.084 1793.4,576.092 1793.41,576.1 1793.42,576.108 1793.43,576.116 1793.44,576.124 1793.45,576.132 1793.46,576.14 1793.47,576.149 1793.48,576.157 1793.49,576.165 1793.5,576.173 1793.5,576.181 1793.51,576.189 1793.52,576.197 1793.53,576.205 1793.54,576.213 1793.55,576.221 1793.56,576.229 1793.57,576.238 1793.58,576.246 1793.59,576.254 1793.6,576.262 1793.61,576.27 1793.62,576.278 1793.62,576.286 1793.63,576.294 1793.64,576.302 1793.65,576.31 1793.66,576.318 1793.67,576.327 1793.68,576.335 1793.69,576.343 1793.7,576.351 1793.71,576.359 1793.72,576.367 1793.73,576.375 1793.73,576.383 1793.74,576.391 1793.75,576.399 1793.76,576.407 1793.77,576.415 1793.78,576.424 1793.79,576.432 1793.8,576.44 1793.81,576.448 1793.82,576.456 1793.83,576.464 1793.84,576.472 1793.84,576.48 1793.85,576.488 1793.86,576.496 1793.87,576.504 1793.88,576.512 1793.89,576.52 1793.9,576.529 1793.91,576.537 1793.92,576.545 1793.93,576.553 1793.94,576.561 1793.95,576.569 1793.96,576.577 1793.96,576.585 1793.97,576.593 1793.98,576.601 1793.99,576.609 1794,576.617 1794.01,576.625 1794.02,576.633 1794.03,576.641 1794.04,576.65 1794.05,576.658 1794.06,576.666 1794.07,576.674 1794.07,576.682 1794.08,576.69 1794.09,576.698 1794.1,576.706 1794.11,576.714 1794.12,576.722 1794.13,576.73 1794.14,576.738 1794.15,576.746 1794.16,576.754 1794.17,576.762 1794.18,576.77 1794.18,576.778 1794.19,576.787 1794.2,576.795 1794.21,576.803 1794.22,576.811 1794.23,576.819 1794.24,576.827 1794.25,576.835 1794.26,576.843 1794.27,576.851 1794.28,576.859 1794.29,576.867 1794.3,576.875 1794.3,576.883 1794.31,576.891 1794.32,576.899 1794.33,576.907 1794.34,576.915 1794.35,576.923 1794.36,576.931 1794.37,576.939 1794.38,576.947 1794.39,576.956 1794.4,576.964 1794.41,576.972 1794.41,576.98 1794.42,576.988 1794.43,576.996 1794.44,577.004 1794.45,577.012 1794.46,577.02 1794.47,577.028 1794.48,577.036 1794.49,577.044 1794.5,577.052 1794.51,577.06 1794.52,577.068 1794.52,577.076 1794.53,577.084 1794.54,577.092 1794.55,577.1 1794.56,577.108 1794.57,577.116 1794.58,577.124 1794.59,577.132 1794.6,577.14 1794.61,577.148 1794.62,577.156 1794.63,577.164 1794.64,577.172 1794.64,577.181 1794.65,577.189 1794.66,577.197 1794.67,577.205 1794.68,577.213 1794.69,577.221 1794.7,577.229 1794.71,577.237 1794.72,577.245 1794.73,577.253 1794.74,577.261 1794.75,577.269 1794.75,577.277 1794.76,577.285 1794.77,577.293 1794.78,577.301 1794.79,577.309 1794.8,577.317 1794.81,577.325 1794.82,577.333 1794.83,577.341 1794.84,577.349 1794.85,577.357 1794.86,577.365 1794.86,577.373 1794.87,577.381 1794.88,577.389 1794.89,577.397 1794.9,577.405 1794.91,577.413 1794.92,577.421 1794.93,577.429 1794.94,577.437 1794.95,577.445 1794.96,577.453 1794.97,577.461 1794.98,577.469 1794.98,577.477 1794.99,577.485 1795,577.493 1795.01,577.501 1795.02,577.509 1795.03,577.517 1795.04,577.525 1795.05,577.533 1795.06,577.541 1795.07,577.549 1795.08,577.557 1795.09,577.565 1795.09,577.573 1795.1,577.581 1795.11,577.589 1795.12,577.597 1795.13,577.605 1795.14,577.613 1795.15,577.621 1795.16,577.629 1795.17,577.637 1795.18,577.645 1795.19,577.653 1795.2,577.661 1795.2,577.669 1795.21,577.677 1795.22,577.685 1795.23,577.693 1795.24,577.701 1795.25,577.709 1795.26,577.717 1795.27,577.725 1795.28,577.733 1795.29,577.741 1795.3,577.749 1795.31,577.757 1795.32,577.765 1795.32,577.773 1795.33,577.781 1795.34,577.789 1795.35,577.797 1795.36,577.805 1795.37,577.813 1795.38,577.821 1795.39,577.829 1795.4,577.837 1795.41,577.845 1795.42,577.853 1795.43,577.861 1795.43,577.869 1795.44,577.877 1795.45,577.885 1795.46,577.893 1795.47,577.901 1795.48,577.909 1795.49,577.917 1795.5,577.924 1795.51,577.932 1795.52,577.94 1795.53,577.948 1795.54,577.956 1795.54,577.964 1795.55,577.972 1795.56,577.98 1795.57,577.988 1795.58,577.996 1795.59,578.004 1795.6,578.012 1795.61,578.02 1795.62,578.028 1795.63,578.036 1795.64,578.044 1795.65,578.052 1795.66,578.06 1795.66,578.068 1795.67,578.076 1795.68,578.084 1795.69,578.092 1795.7,578.1 1795.71,578.108 1795.72,578.116 1795.73,578.124 1795.74,578.132 1795.75,578.14 1795.76,578.147 1795.77,578.155 1795.77,578.163 1795.78,578.171 1795.79,578.179 1795.8,578.187 1795.81,578.195 1795.82,578.203 1795.83,578.211 1795.84,578.219 1795.85,578.227 1795.86,578.235 1795.87,578.243 1795.88,578.251 1795.88,578.259 1795.89,578.267 1795.9,578.275 1795.91,578.283 1795.92,578.291 1795.93,578.299 1795.94,578.307 1795.95,578.314 1795.96,578.322 1795.97,578.33 1795.98,578.338 1795.99,578.346 1796,578.354 1796,578.362 1796.01,578.37 1796.02,578.378 1796.03,578.386 1796.04,578.394 1796.05,578.402 1796.06,578.41 1796.07,578.418 1796.08,578.426 1796.09,578.434 1796.1,578.442 1796.11,578.449 1796.11,578.457 1796.12,578.465 1796.13,578.473 1796.14,578.481 1796.15,578.489 1796.16,578.497 1796.17,578.505 1796.18,578.513 1796.19,578.521 1796.2,578.529 1796.21,578.537 1796.22,578.545 1796.22,578.553 1796.23,578.56 1796.24,578.568 1796.25,578.576 1796.26,578.584 1796.27,578.592 1796.28,578.6 1796.29,578.608 1796.3,578.616 1796.31,578.624 1796.32,578.632 1796.33,578.64 1796.34,578.648 1796.34,578.656 1796.35,578.663 1796.36,578.671 1796.37,578.679 1796.38,578.687 1796.39,578.695 1796.4,578.703 1796.41,578.711 1796.42,578.719 1796.43,578.727 1796.44,578.735 1796.45,578.743 1796.45,578.751 1796.46,578.758 1796.47,578.766 1796.48,578.774 1796.49,578.782 1796.5,578.79 1796.51,578.798 1796.52,578.806 1796.53,578.814 1796.54,578.822 1796.55,578.83 1796.56,578.838 1796.56,578.845 1796.57,578.853 1796.58,578.861 1796.59,578.869 1796.6,578.877 1796.61,578.885 1796.62,578.893 1796.63,578.901 1796.64,578.909 1796.65,578.917 1796.66,578.924 1796.67,578.932 1796.68,578.94 1796.68,578.948 1796.69,578.956 1796.7,578.964 1796.71,578.972 1796.72,578.98 1796.73,578.988 1796.74,578.996 1796.75,579.003 1796.76,579.011 1796.77,579.019 1796.78,579.027 1796.79,579.035 1796.79,579.043 1796.8,579.051 1796.81,579.059 1796.82,579.067 1796.83,579.074 1796.84,579.082 1796.85,579.09 1796.86,579.098 1796.87,579.106 1796.88,579.114 1796.89,579.122 1796.9,579.13 1796.9,579.138 1796.91,579.145 1796.92,579.153 1796.93,579.161 1796.94,579.169 1796.95,579.177 1796.96,579.185 1796.97,579.193 1796.98,579.201 1796.99,579.208 1797,579.216 1797.01,579.224 1797.02,579.232 1797.02,579.24 1797.03,579.248 1797.04,579.256 1797.05,579.264 1797.06,579.271 1797.07,579.279 1797.08,579.287 1797.09,579.295 1797.1,579.303 1797.11,579.311 1797.12,579.319 1797.13,579.327 1797.13,579.334 1797.14,579.342 1797.15,579.35 1797.16,579.358 1797.17,579.366 1797.18,579.374 1797.19,579.382 1797.2,579.39 1797.21,579.397 1797.22,579.405 1797.23,579.413 1797.24,579.421 1797.24,579.429 1797.25,579.437 1797.26,579.445 1797.27,579.452 1797.28,579.46 1797.29,579.468 1797.3,579.476 1797.31,579.484 1797.32,579.492 1797.33,579.5 1797.34,579.507 1797.35,579.515 1797.36,579.523 1797.36,579.531 1797.37,579.539 1797.38,579.547 1797.39,579.555 1797.4,579.562 1797.41,579.57 1797.42,579.578 1797.43,579.586 1797.44,579.594 1797.45,579.602 1797.46,579.61 1797.47,579.617 1797.47,579.625 1797.48,579.633 1797.49,579.641 1797.5,579.649 1797.51,579.657 1797.52,579.664 1797.53,579.672 1797.54,579.68 1797.55,579.688 1797.56,579.696 1797.57,579.704 1797.58,579.711 1797.58,579.719 1797.59,579.727 1797.6,579.735 1797.61,579.743 1797.62,579.751 1797.63,579.759 1797.64,579.766 1797.65,579.774 1797.66,579.782 1797.67,579.79 1797.68,579.798 1797.69,579.806 1797.7,579.813 1797.7,579.821 1797.71,579.829 1797.72,579.837 1797.73,579.845 1797.74,579.853 1797.75,579.86 1797.76,579.868 1797.77,579.876 1797.78,579.884 1797.79,579.892 1797.8,579.899 1797.81,579.907 1797.81,579.915 1797.82,579.923 1797.83,579.931 1797.84,579.939 1797.85,579.946 1797.86,579.954 1797.87,579.962 1797.88,579.97 1797.89,579.978 1797.9,579.986 1797.91,579.993 1797.92,580.001 1797.92,580.009 1797.93,580.017 1797.94,580.025 1797.95,580.032 1797.96,580.04 1797.97,580.048 1797.98,580.056 1797.99,580.064 1798,580.071 1798.01,580.079 1798.02,580.087 1798.03,580.095 1798.04,580.103 1798.04,580.111 1798.05,580.118 1798.06,580.126 1798.07,580.134 1798.08,580.142 1798.09,580.15 1798.1,580.157 1798.11,580.165 1798.12,580.173 1798.13,580.181 1798.14,580.189 1798.15,580.196 1798.15,580.204 1798.16,580.212 1798.17,580.22 1798.18,580.228 1798.19,580.235 1798.2,580.243 1798.21,580.251 1798.22,580.259 1798.23,580.267 1798.24,580.274 1798.25,580.282 1798.26,580.29 1798.26,580.298 1798.27,580.306 1798.28,580.313 1798.29,580.321 1798.3,580.329 1798.31,580.337 1798.32,580.345 1798.33,580.352 1798.34,580.36 1798.35,580.368 1798.36,580.376 1798.37,580.384 1798.38,580.391 1798.38,580.399 1798.39,580.407 1798.4,580.415 1798.41,580.422 1798.42,580.43 1798.43,580.438 1798.44,580.446 1798.45,580.454 1798.46,580.461 1798.47,580.469 1798.48,580.477 1798.49,580.485 1798.49,580.492 1798.5,580.5 1798.51,580.508 1798.52,580.516 1798.53,580.524 1798.54,580.531 1798.55,580.539 1798.56,580.547 1798.57,580.555 1798.58,580.562 1798.59,580.57 1798.6,580.578 1798.6,580.586 1798.61,580.594 1798.62,580.601 1798.63,580.609 1798.64,580.617 1798.65,580.625 1798.66,580.632 1798.67,580.64 1798.68,580.648 1798.69,580.656 1798.7,580.664 1798.71,580.671 1798.72,580.679 1798.72,580.687 1798.73,580.695 1798.74,580.702 1798.75,580.71 1798.76,580.718 1798.77,580.726 1798.78,580.733 1798.79,580.741 1798.8,580.749 1798.81,580.757 1798.82,580.764 1798.83,580.772 1798.83,580.78 1798.84,580.788 1798.85,580.795 1798.86,580.803 1798.87,580.811 1798.88,580.819 1798.89,580.826 1798.9,580.834 1798.91,580.842 1798.92,580.85 1798.93,580.857 1798.94,580.865 1798.94,580.873 1798.95,580.881 1798.96,580.888 1798.97,580.896 1798.98,580.904 1798.99,580.912 1799,580.919 1799.01,580.927 1799.02,580.935 1799.03,580.943 1799.04,580.95 1799.05,580.958 1799.06,580.966 1799.06,580.974 1799.07,580.981 1799.08,580.989 1799.09,580.997 1799.1,581.005 1799.11,581.012 1799.12,581.02 1799.13,581.028 1799.14,581.036 1799.15,581.043 1799.16,581.051 1799.17,581.059 1799.17,581.067 1799.18,581.074 1799.19,581.082 1799.2,581.09 1799.21,581.097 1799.22,581.105 1799.23,581.113 1799.24,581.121 1799.25,581.128 1799.26,581.136 1799.27,581.144 1799.28,581.152 1799.28,581.159 1799.29,581.167 1799.3,581.175 1799.31,581.182 1799.32,581.19 1799.33,581.198 1799.34,581.206 1799.35,581.213 1799.36,581.221 1799.37,581.229 1799.38,581.237 1799.39,581.244 1799.4,581.252 1799.4,581.26 1799.41,581.267 1799.42,581.275 1799.43,581.283 1799.44,581.291 1799.45,581.298 1799.46,581.306 1799.47,581.314 1799.48,581.321 1799.49,581.329 1799.5,581.337 1799.51,581.345 1799.51,581.352 1799.52,581.36 1799.53,581.368 1799.54,581.375 1799.55,581.383 1799.56,581.391 1799.57,581.399 1799.58,581.406 1799.59,581.414 1799.6,581.422 1799.61,581.429 1799.62,581.437 1799.62,581.445 1799.63,581.452 1799.64,581.46 1799.65,581.468 1799.66,581.476 1799.67,581.483 1799.68,581.491 1799.69,581.499 1799.7,581.506 1799.71,581.514 1799.72,581.522 1799.73,581.529 1799.74,581.537 1799.74,581.545 1799.75,581.553 1799.76,581.56 1799.77,581.568 1799.78,581.576 1799.79,581.583 1799.8,581.591 1799.81,581.599 1799.82,581.606 1799.83,581.614 1799.84,581.622 1799.85,581.629 1799.85,581.637 1799.86,581.645 1799.87,581.653 1799.88,581.66 1799.89,581.668 1799.9,581.676 1799.91,581.683 1799.92,581.691 1799.93,581.699 1799.94,581.706 1799.95,581.714 1799.96,581.722 1799.96,581.729 1799.97,581.737 1799.98,581.745 1799.99,581.752 1800,581.76 1800.01,581.768 1800.02,581.775 1800.03,581.783 1800.04,581.791 1800.05,581.798 1800.06,581.806 1800.07,581.814 1800.08,581.822 1800.08,581.829 1800.09,581.837 1800.1,581.845 1800.11,581.852 1800.12,581.86 1800.13,581.868 1800.14,581.875 1800.15,581.883 1800.16,581.891 1800.17,581.898 1800.18,581.906 1800.19,581.914 1800.19,581.921 1800.2,581.929 1800.21,581.937 1800.22,581.944 1800.23,581.952 1800.24,581.96 1800.25,581.967 1800.26,581.975 1800.27,581.983 1800.28,581.99 1800.29,581.998 1800.3,582.005 1800.3,582.013 1800.31,582.021 1800.32,582.028 1800.33,582.036 1800.34,582.044 1800.35,582.051 1800.36,582.059 1800.37,582.067 1800.38,582.074 1800.39,582.082 1800.4,582.09 1800.41,582.097 1800.42,582.105 1800.42,582.113 1800.43,582.12 1800.44,582.128 1800.45,582.136 1800.46,582.143 1800.47,582.151 1800.48,582.159 1800.49,582.166 1800.5,582.174 1800.51,582.181 1800.52,582.189 1800.53,582.197 1800.53,582.204 1800.54,582.212 1800.55,582.22 1800.56,582.227 1800.57,582.235 1800.58,582.243 1800.59,582.25 1800.6,582.258 1800.61,582.266 1800.62,582.273 1800.63,582.281 1800.64,582.288 1800.64,582.296 1800.65,582.304 1800.66,582.311 1800.67,582.319 1800.68,582.327 1800.69,582.334 1800.7,582.342 1800.71,582.349 1800.72,582.357 1800.73,582.365 1800.74,582.372 1800.75,582.38 1800.76,582.388 1800.76,582.395 1800.77,582.403 1800.78,582.41 1800.79,582.418 1800.8,582.426 1800.81,582.433 1800.82,582.441 1800.83,582.449 1800.84,582.456 1800.85,582.464 1800.86,582.471 1800.87,582.479 1800.87,582.487 1800.88,582.494 1800.89,582.502 1800.9,582.51 1800.91,582.517 1800.92,582.525 1800.93,582.532 1800.94,582.54 1800.95,582.548 1800.96,582.555 1800.97,582.563 1800.98,582.57 1800.98,582.578 1800.99,582.586 1801,582.593 1801.01,582.601 1801.02,582.609 1801.03,582.616 1801.04,582.624 1801.05,582.631 1801.06,582.639 1801.07,582.647 1801.08,582.654 1801.09,582.662 1801.1,582.669 1801.1,582.677 1801.11,582.685 1801.12,582.692 1801.13,582.7 1801.14,582.707 1801.15,582.715 1801.16,582.723 1801.17,582.73 1801.18,582.738 1801.19,582.745 1801.2,582.753 1801.21,582.761 1801.21,582.768 1801.22,582.776 1801.23,582.783 1801.24,582.791 1801.25,582.799 1801.26,582.806 1801.27,582.814 1801.28,582.821 1801.29,582.829 1801.3,582.836 1801.31,582.844 1801.32,582.852 1801.32,582.859 1801.33,582.867 1801.34,582.874 1801.35,582.882 1801.36,582.89 1801.37,582.897 1801.38,582.905 1801.39,582.912 1801.4,582.92 1801.41,582.927 1801.42,582.935 1801.43,582.943 1801.44,582.95 1801.44,582.958 1801.45,582.965 1801.46,582.973 1801.47,582.981 1801.48,582.988 1801.49,582.996 1801.5,583.003 1801.51,583.011 1801.52,583.018 1801.53,583.026 1801.54,583.034 1801.55,583.041 1801.55,583.049 1801.56,583.056 1801.57,583.064 1801.58,583.071 1801.59,583.079 1801.6,583.087 1801.61,583.094 1801.62,583.102 1801.63,583.109 1801.64,583.117 1801.65,583.124 1801.66,583.132 1801.66,583.139 1801.67,583.147 1801.68,583.155 1801.69,583.162 1801.7,583.17 1801.71,583.177 1801.72,583.185 1801.73,583.192 1801.74,583.2 1801.75,583.208 1801.76,583.215 1801.77,583.223 1801.78,583.23 1801.78,583.238 1801.79,583.245 1801.8,583.253 1801.81,583.26 1801.82,583.268 1801.83,583.275 1801.84,583.283 1801.85,583.291 1801.86,583.298 1801.87,583.306 1801.88,583.313 1801.89,583.321 1801.89,583.328 1801.9,583.336 1801.91,583.343 1801.92,583.351 1801.93,583.359 1801.94,583.366 1801.95,583.374 1801.96,583.381 1801.97,583.389 1801.98,583.396 1801.99,583.404 1802,583.411 1802.01,583.419 1802.01,583.426 1802.02,583.434 1802.03,583.441 1802.04,583.449 1802.05,583.457 1802.06,583.464 1802.07,583.472 1802.08,583.479 1802.09,583.487 1802.1,583.494 1802.11,583.502 1802.12,583.509 1802.12,583.517 1802.13,583.524 1802.14,583.532 1802.15,583.539 1802.16,583.547 1802.17,583.554 1802.18,583.562 1802.19,583.569 1802.2,583.577 1802.21,583.585 1802.22,583.592 1802.23,583.6 1802.23,583.607 1802.24,583.615 1802.25,583.622 1802.26,583.63 1802.27,583.637 1802.28,583.645 1802.29,583.652 1802.3,583.66 1802.31,583.667 1802.32,583.675 1802.33,583.682 1802.34,583.69 1802.35,583.697 1802.35,583.705 1802.36,583.712 1802.37,583.72 1802.38,583.727 1802.39,583.735 1802.4,583.742 1802.41,583.75 1802.42,583.757 1802.43,583.765 1802.44,583.772 1802.45,583.78 1802.46,583.787 1802.46,583.795 1802.47,583.802 1802.48,583.81 1802.49,583.817 1802.5,583.825 1802.51,583.832 1802.52,583.84 1802.53,583.847 1802.54,583.855 1802.55,583.862 1802.56,583.87 1802.57,583.877 1802.57,583.885 1802.58,583.892 1802.59,583.9 1802.6,583.907 1802.61,583.915 1802.62,583.922 1802.63,583.93 1802.64,583.937 1802.65,583.945 1802.66,583.952 1802.67,583.96 1802.68,583.967 1802.69,583.975 1802.69,583.982 1802.7,583.99 1802.71,583.997 1802.72,584.005 1802.73,584.012 1802.74,584.02 1802.75,584.027 1802.76,584.035 1802.77,584.042 1802.78,584.05 1802.79,584.057 1802.8,584.065 1802.8,584.072 1802.81,584.08 1802.82,584.087 1802.83,584.095 1802.84,584.102 1802.85,584.11 1802.86,584.117 1802.87,584.125 1802.88,584.132 1802.89,584.139 1802.9,584.147 1802.91,584.154 1802.91,584.162 1802.92,584.169 1802.93,584.177 1802.94,584.184 1802.95,584.192 1802.96,584.199 1802.97,584.207 1802.98,584.214 1802.99,584.222 1803,584.229 1803.01,584.237 1803.02,584.244 1803.03,584.252 1803.03,584.259 1803.04,584.266 1803.05,584.274 1803.06,584.281 1803.07,584.289 1803.08,584.296 1803.09,584.304 1803.1,584.311 1803.11,584.319 1803.12,584.326 1803.13,584.334 1803.14,584.341 1803.14,584.349 1803.15,584.356 1803.16,584.363 1803.17,584.371 1803.18,584.378 1803.19,584.386 1803.2,584.393 1803.21,584.401 1803.22,584.408 1803.23,584.416 1803.24,584.423 1803.25,584.43 1803.25,584.438 1803.26,584.445 1803.27,584.453 1803.28,584.46 1803.29,584.468 1803.3,584.475 1803.31,584.483 1803.32,584.49 1803.33,584.497 1803.34,584.505 1803.35,584.512 1803.36,584.52 1803.37,584.527 1803.37,584.535 1803.38,584.542 1803.39,584.55 1803.4,584.557 1803.41,584.564 1803.42,584.572 1803.43,584.579 1803.44,584.587 1803.45,584.594 1803.46,584.602 1803.47,584.609 1803.48,584.616 1803.48,584.624 1803.49,584.631 1803.5,584.639 1803.51,584.646 1803.52,584.654 1803.53,584.661 1803.54,584.668 1803.55,584.676 1803.56,584.683 1803.57,584.691 1803.58,584.698 1803.59,584.706 1803.59,584.713 1803.6,584.72 1803.61,584.728 1803.62,584.735 1803.63,584.743 1803.64,584.75 1803.65,584.758 1803.66,584.765 1803.67,584.772 1803.68,584.78 1803.69,584.787 1803.7,584.795 1803.71,584.802 1803.71,584.809 1803.72,584.817 1803.73,584.824 1803.74,584.832 1803.75,584.839 1803.76,584.847 1803.77,584.854 1803.78,584.861 1803.79,584.869 1803.8,584.876 1803.81,584.884 1803.82,584.891 1803.82,584.898 1803.83,584.906 1803.84,584.913 1803.85,584.921 1803.86,584.928 1803.87,584.935 1803.88,584.943 1803.89,584.95 1803.9,584.958 1803.91,584.965 1803.92,584.972 1803.93,584.98 1803.93,584.987 1803.94,584.995 1803.95,585.002 1803.96,585.009 1803.97,585.017 1803.98,585.024 1803.99,585.032 1804,585.039 1804.01,585.046 1804.02,585.054 1804.03,585.061 1804.04,585.069 1804.05,585.076 1804.05,585.083 1804.06,585.091 1804.07,585.098 1804.08,585.105 1804.09,585.113 1804.1,585.12 1804.11,585.128 1804.12,585.135 1804.13,585.142 1804.14,585.15 1804.15,585.157 1804.16,585.165 1804.16,585.172 1804.17,585.179 1804.18,585.187 1804.19,585.194 1804.2,585.201 1804.21,585.209 1804.22,585.216 1804.23,585.224 1804.24,585.231 1804.25,585.238 1804.26,585.246 1804.27,585.253 1804.27,585.26 1804.28,585.268 1804.29,585.275 1804.3,585.283 1804.31,585.29 1804.32,585.297 1804.33,585.305 1804.34,585.312 1804.35,585.319 1804.36,585.327 1804.37,585.334 1804.38,585.341 1804.39,585.349 1804.39,585.356 1804.4,585.364 1804.41,585.371 1804.42,585.378 1804.43,585.386 1804.44,585.393 1804.45,585.4 1804.46,585.408 1804.47,585.415 1804.48,585.422 1804.49,585.43 1804.5,585.437 1804.5,585.444 1804.51,585.452 1804.52,585.459 1804.53,585.467 1804.54,585.474 1804.55,585.481 1804.56,585.489 1804.57,585.496 1804.58,585.503 1804.59,585.511 1804.6,585.518 1804.61,585.525 1804.61,585.533 1804.62,585.54 1804.63,585.547 1804.64,585.555 1804.65,585.562 1804.66,585.569 1804.67,585.577 1804.68,585.584 1804.69,585.591 1804.7,585.599 1804.71,585.606 1804.72,585.613 1804.73,585.621 1804.73,585.628 1804.74,585.635 1804.75,585.643 1804.76,585.65 1804.77,585.657 1804.78,585.665 1804.79,585.672 1804.8,585.679 1804.81,585.687 1804.82,585.694 1804.83,585.701 1804.84,585.709 1804.84,585.716 1804.85,585.723 1804.86,585.731 1804.87,585.738 1804.88,585.745 1804.89,585.753 1804.9,585.76 1804.91,585.767 1804.92,585.775 1804.93,585.782 1804.94,585.789 1804.95,585.797 1804.95,585.804 1804.96,585.811 1804.97,585.819 1804.98,585.826 1804.99,585.833 1805,585.841 1805.01,585.848 1805.02,585.855 1805.03,585.863 1805.04,585.87 1805.05,585.877 1805.06,585.884 1805.07,585.892 1805.07,585.899 1805.08,585.906 1805.09,585.914 1805.1,585.921 1805.11,585.928 1805.12,585.936 1805.13,585.943 1805.14,585.95 1805.15,585.958 1805.16,585.965 1805.17,585.972 1805.18,585.979 1805.18,585.987 1805.19,585.994 1805.2,586.001 1805.21,586.009 1805.22,586.016 1805.23,586.023 1805.24,586.031 1805.25,586.038 1805.26,586.045 1805.27,586.052 1805.28,586.06 1805.29,586.067 1805.29,586.074 1805.3,586.082 1805.31,586.089 1805.32,586.096 1805.33,586.104 1805.34,586.111 1805.35,586.118 1805.36,586.125 1805.37,586.133 1805.38,586.14 1805.39,586.147 1805.4,586.155 1805.41,586.162 1805.41,586.169 1805.42,586.176 1805.43,586.184 1805.44,586.191 1805.45,586.198 1805.46,586.206 1805.47,586.213 1805.48,586.22 1805.49,586.227 1805.5,586.235 1805.51,586.242 1805.52,586.249 1805.52,586.256 1805.53,586.264 1805.54,586.271 1805.55,586.278 1805.56,586.286 1805.57,586.293 1805.58,586.3 1805.59,586.307 1805.6,586.315 1805.61,586.322 1805.62,586.329 1805.63,586.336 1805.63,586.344 1805.64,586.351 1805.65,586.358 1805.66,586.366 1805.67,586.373 1805.68,586.38 1805.69,586.387 1805.7,586.395 1805.71,586.402 1805.72,586.409 1805.73,586.416 1805.74,586.424 1805.75,586.431 1805.75,586.438 1805.76,586.445 1805.77,586.453 1805.78,586.46 1805.79,586.467 1805.8,586.474 1805.81,586.482 1805.82,586.489 1805.83,586.496 1805.84,586.503 1805.85,586.511 1805.86,586.518 1805.86,586.525 1805.87,586.532 1805.88,586.54 1805.89,586.547 1805.9,586.554 1805.91,586.561 1805.92,586.569 1805.93,586.576 1805.94,586.583 1805.95,586.59 1805.96,586.598 1805.97,586.605 1805.97,586.612 1805.98,586.619 1805.99,586.627 1806,586.634 1806.01,586.641 1806.02,586.648 1806.03,586.656 1806.04,586.663 1806.05,586.67 1806.06,586.677 1806.07,586.684 1806.08,586.692 1806.09,586.699 1806.09,586.706 1806.1,586.713 1806.11,586.721 1806.12,586.728 1806.13,586.735 1806.14,586.742 1806.15,586.75 1806.16,586.757 1806.17,586.764 1806.18,586.771 1806.19,586.778 1806.2,586.786 1806.2,586.793 1806.21,586.8 1806.22,586.807 1806.23,586.815 1806.24,586.822 1806.25,586.829 1806.26,586.836 1806.27,586.843 1806.28,586.851 1806.29,586.858 1806.3,586.865 1806.31,586.872 1806.31,586.88 1806.32,586.887 1806.33,586.894 1806.34,586.901 1806.35,586.908 1806.36,586.916 1806.37,586.923 1806.38,586.93 1806.39,586.937 1806.4,586.944 1806.41,586.952 1806.42,586.959 1806.43,586.966 1806.43,586.973 1806.44,586.98 1806.45,586.988 1806.46,586.995 1806.47,587.002 1806.48,587.009 1806.49,587.016 1806.5,587.024 1806.51,587.031 1806.52,587.038 1806.53,587.045 1806.54,587.052 1806.54,587.06 1806.55,587.067 1806.56,587.074 1806.57,587.081 1806.58,587.088 1806.59,587.096 1806.6,587.103 1806.61,587.11 1806.62,587.117 1806.63,587.124 1806.64,587.132 1806.65,587.139 1806.65,587.146 1806.66,587.153 1806.67,587.16 1806.68,587.167 1806.69,587.175 1806.7,587.182 1806.71,587.189 1806.72,587.196 1806.73,587.203 1806.74,587.211 1806.75,587.218 1806.76,587.225 1806.77,587.232 1806.77,587.239 1806.78,587.246 1806.79,587.254 1806.8,587.261 1806.81,587.268 1806.82,587.275 1806.83,587.282 1806.84,587.289 1806.85,587.297 1806.86,587.304 1806.87,587.311 1806.88,587.318 1806.88,587.325 1806.89,587.333 1806.9,587.34 1806.91,587.347 1806.92,587.354 1806.93,587.361 1806.94,587.368 1806.95,587.376 1806.96,587.383 1806.97,587.39 1806.98,587.397 1806.99,587.404 1806.99,587.411 1807,587.418 1807.01,587.426 1807.02,587.433 1807.03,587.44 1807.04,587.447 1807.05,587.454 1807.06,587.461 1807.07,587.469 1807.08,587.476 1807.09,587.483 1807.1,587.49 1807.11,587.497 1807.11,587.504 1807.12,587.511 1807.13,587.519 1807.14,587.526 1807.15,587.533 1807.16,587.54 1807.17,587.547 1807.18,587.554 1807.19,587.561 1807.2,587.569 1807.21,587.576 1807.22,587.583 1807.22,587.59 1807.23,587.597 1807.24,587.604 1807.25,587.611 1807.26,587.619 1807.27,587.626 1807.28,587.633 1807.29,587.64 1807.3,587.647 1807.31,587.654 1807.32,587.661 1807.33,587.669 1807.33,587.676 1807.34,587.683 1807.35,587.69 1807.36,587.697 1807.37,587.704 1807.38,587.711 1807.39,587.718 1807.4,587.726 1807.41,587.733 1807.42,587.74 1807.43,587.747 1807.44,587.754 1807.45,587.761 1807.45,587.768 1807.46,587.775 1807.47,587.783 1807.48,587.79 1807.49,587.797 1807.5,587.804 1807.51,587.811 1807.52,587.818 1807.53,587.825 1807.54,587.832 1807.55,587.839 1807.56,587.847 1807.56,587.854 1807.57,587.861 1807.58,587.868 1807.59,587.875 1807.6,587.882 1807.61,587.889 1807.62,587.896 1807.63,587.903 1807.64,587.911 1807.65,587.918 1807.66,587.925 1807.67,587.932 1807.67,587.939 1807.68,587.946 1807.69,587.953 1807.7,587.96 1807.71,587.967 1807.72,587.975 1807.73,587.982 1807.74,587.989 1807.75,587.996 1807.76,588.003 1807.77,588.01 1807.78,588.017 1807.79,588.024 1807.79,588.031 1807.8,588.038 1807.81,588.045 1807.82,588.053 1807.83,588.06 1807.84,588.067 1807.85,588.074 1807.86,588.081 1807.87,588.088 1807.88,588.095 1807.89,588.102 1807.9,588.109 1807.9,588.116 1807.91,588.123 1807.92,588.131 1807.93,588.138 1807.94,588.145 1807.95,588.152 1807.96,588.159 1807.97,588.166 1807.98,588.173 1807.99,588.18 1808,588.187 1808.01,588.194 1808.01,588.201 1808.02,588.208 1808.03,588.215 1808.04,588.223 1808.05,588.23 1808.06,588.237 1808.07,588.244 1808.08,588.251 1808.09,588.258 1808.1,588.265 1808.11,588.272 1808.12,588.279 1808.13,588.286 1808.13,588.293 1808.14,588.3 1808.15,588.307 1808.16,588.314 1808.17,588.321 1808.18,588.329 1808.19,588.336 1808.2,588.343 1808.21,588.35 1808.22,588.357 1808.23,588.364 1808.24,588.371 1808.24,588.378 1808.25,588.385 1808.26,588.392 1808.27,588.399 1808.28,588.406 1808.29,588.413 1808.3,588.42 1808.31,588.427 1808.32,588.434 1808.33,588.441 1808.34,588.448 1808.35,588.456 1808.35,588.463 1808.36,588.47 1808.37,588.477 1808.38,588.484 1808.39,588.491 1808.4,588.498 1808.41,588.505 1808.42,588.512 1808.43,588.519 1808.44,588.526 1808.45,588.533 1808.46,588.54 1808.47,588.547 1808.47,588.554 1808.48,588.561 1808.49,588.568 1808.5,588.575 1808.51,588.582 1808.52,588.589 1808.53,588.596 1808.54,588.603 1808.55,588.61 1808.56,588.617 1808.57,588.624 1808.58,588.631 1808.58,588.639 1808.59,588.646 1808.6,588.653 1808.61,588.66 1808.62,588.667 1808.63,588.674 1808.64,588.681 1808.65,588.688 1808.66,588.695 1808.67,588.702 1808.68,588.709 1808.69,588.716 1808.69,588.723 1808.7,588.73 1808.71,588.737 1808.72,588.744 1808.73,588.751 1808.74,588.758 1808.75,588.765 1808.76,588.772 1808.77,588.779 1808.78,588.786 1808.79,588.793 1808.8,588.8 1808.81,588.807 1808.81,588.814 1808.82,588.821 1808.83,588.828 1808.84,588.835 1808.85,588.842 1808.86,588.849 1808.87,588.856 1808.88,588.863 1808.89,588.87 1808.9,588.877 1808.91,588.884 1808.92,588.891 1808.92,588.898 1808.93,588.905 1808.94,588.912 1808.95,588.919 1808.96,588.926 1808.97,588.933 1808.98,588.94 1808.99,588.947 1809,588.954 1809.01,588.961 1809.02,588.968 1809.03,588.975 1809.03,588.982 1809.04,588.989 1809.05,588.996 1809.06,589.003 1809.07,589.01 1809.08,589.017 1809.09,589.024 1809.1,589.031 1809.11,589.038 1809.12,589.045 1809.13,589.052 1809.14,589.059 1809.15,589.066 1809.15,589.073 1809.16,589.08 1809.17,589.087 1809.18,589.094 1809.19,589.101 1809.2,589.108 1809.21,589.115 1809.22,589.122 1809.23,589.128 1809.24,589.135 1809.25,589.142 1809.26,589.149 1809.26,589.156 1809.27,589.163 1809.28,589.17 1809.29,589.177 1809.3,589.184 1809.31,589.191 1809.32,589.198 1809.33,589.205 1809.34,589.212 1809.35,589.219 1809.36,589.226 1809.37,589.233 1809.37,589.24 1809.38,589.247 1809.39,589.254 1809.4,589.261 1809.41,589.268 1809.42,589.275 1809.43,589.282 1809.44,589.289 1809.45,589.296 1809.46,589.303 1809.47,589.31 1809.48,589.316 1809.49,589.323 1809.49,589.33 1809.5,589.337 1809.51,589.344 1809.52,589.351 1809.53,589.358 1809.54,589.365 1809.55,589.372 1809.56,589.379 1809.57,589.386 1809.58,589.393 1809.59,589.4 1809.6,589.407 1809.6,589.414 1809.61,589.421 1809.62,589.428 1809.63,589.435 1809.64,589.441 1809.65,589.448 1809.66,589.455 1809.67,589.462 1809.68,589.469 1809.69,589.476 1809.7,589.483 1809.71,589.49 1809.71,589.497 1809.72,589.504 1809.73,589.511 1809.74,589.518 1809.75,589.525 1809.76,589.532 1809.77,589.538 1809.78,589.545 1809.79,589.552 1809.8,589.559 1809.81,589.566 1809.82,589.573 1809.83,589.58 1809.83,589.587 1809.84,589.594 1809.85,589.601 1809.86,589.608 1809.87,589.615 1809.88,589.622 1809.89,589.628 1809.9,589.635 1809.91,589.642 1809.92,589.649 1809.93,589.656 1809.94,589.663 1809.94,589.67 1809.95,589.677 1809.96,589.684 1809.97,589.691 1809.98,589.698 1809.99,589.704 1810,589.711 1810.01,589.718 1810.02,589.725 1810.03,589.732 1810.04,589.739 1810.05,589.746 1810.05,589.753 1810.06,589.76 1810.07,589.767 1810.08,589.773 1810.09,589.78 1810.1,589.787 1810.11,589.794 1810.12,589.801 1810.13,589.808 1810.14,589.815 1810.15,589.822 1810.16,589.829 1810.17,589.836 1810.17,589.842 1810.18,589.849 1810.19,589.856 1810.2,589.863 1810.21,589.87 1810.22,589.877 1810.23,589.884 1810.24,589.891 1810.25,589.897 1810.26,589.904 1810.27,589.911 1810.28,589.918 1810.28,589.925 1810.29,589.932 1810.3,589.939 1810.31,589.946 1810.32,589.953 1810.33,589.959 1810.34,589.966 1810.35,589.973 1810.36,589.98 1810.37,589.987 1810.38,589.994 1810.39,590.001 1810.39,590.008 1810.4,590.014 1810.41,590.021 1810.42,590.028 1810.43,590.035 1810.44,590.042 1810.45,590.049 1810.46,590.056 1810.47,590.062 1810.48,590.069 1810.49,590.076 1810.5,590.083 1810.51,590.09 1810.51,590.097 1810.52,590.104 1810.53,590.11 1810.54,590.117 1810.55,590.124 1810.56,590.131 1810.57,590.138 1810.58,590.145 1810.59,590.152 1810.6,590.158 1810.61,590.165 1810.62,590.172 1810.62,590.179 1810.63,590.186 1810.64,590.193 1810.65,590.2 1810.66,590.206 1810.67,590.213 1810.68,590.22 1810.69,590.227 1810.7,590.234 1810.71,590.241 1810.72,590.247 1810.73,590.254 1810.73,590.261 1810.74,590.268 1810.75,590.275 1810.76,590.282 1810.77,590.288 1810.78,590.295 1810.79,590.302 1810.8,590.309 1810.81,590.316 1810.82,590.323 1810.83,590.329 1810.84,590.336 1810.85,590.343 1810.85,590.35 1810.86,590.357 1810.87,590.364 1810.88,590.37 1810.89,590.377 1810.9,590.384 1810.91,590.391 1810.92,590.398 1810.93,590.405 1810.94,590.411 1810.95,590.418 1810.96,590.425 1810.96,590.432 1810.97,590.439 1810.98,590.446 1810.99,590.452 1811,590.459 1811.01,590.466 1811.02,590.473 1811.03,590.48 1811.04,590.486 1811.05,590.493 1811.06,590.5 1811.07,590.507 1811.07,590.514 1811.08,590.52 1811.09,590.527 1811.1,590.534 1811.11,590.541 1811.12,590.548 1811.13,590.554 1811.14,590.561 1811.15,590.568 1811.16,590.575 1811.17,590.582 1811.18,590.588 1811.19,590.595 1811.19,590.602 1811.2,590.609 1811.21,590.616 1811.22,590.622 1811.23,590.629 1811.24,590.636 1811.25,590.643 1811.26,590.65 1811.27,590.656 1811.28,590.663 1811.29,590.67 1811.3,590.677 1811.3,590.684 1811.31,590.69 1811.32,590.697 1811.33,590.704 1811.34,590.711 1811.35,590.718 1811.36,590.724 1811.37,590.731 1811.38,590.738 1811.39,590.745 1811.4,590.751 1811.41,590.758 1811.41,590.765 1811.42,590.772 1811.43,590.779 1811.44,590.785 1811.45,590.792 1811.46,590.799 1811.47,590.806 1811.48,590.812 1811.49,590.819 1811.5,590.826 1811.51,590.833 1811.52,590.839 1811.53,590.846 1811.53,590.853 1811.54,590.86 1811.55,590.867 1811.56,590.873 1811.57,590.88 1811.58,590.887 1811.59,590.894 1811.6,590.9 1811.61,590.907 1811.62,590.914 1811.63,590.921 1811.64,590.927 1811.64,590.934 1811.65,590.941 1811.66,590.948 1811.67,590.954 1811.68,590.961 1811.69,590.968 1811.7,590.975 1811.71,590.981 1811.72,590.988 1811.73,590.995 1811.74,591.002 1811.75,591.008 1811.75,591.015 1811.76,591.022 1811.77,591.029 1811.78,591.035 1811.79,591.042 1811.8,591.049 1811.81,591.056 1811.82,591.062 1811.83,591.069 1811.84,591.076 1811.85,591.083 1811.86,591.089 1811.87,591.096 1811.87,591.103 1811.88,591.11 1811.89,591.116 1811.9,591.123 1811.91,591.13 1811.92,591.136 1811.93,591.143 1811.94,591.15 1811.95,591.157 1811.96,591.163 1811.97,591.17 1811.98,591.177 1811.98,591.184 1811.99,591.19 1812,591.197 1812.01,591.204 1812.02,591.21 1812.03,591.217 1812.04,591.224 1812.05,591.231 1812.06,591.237 1812.07,591.244 1812.08,591.251 1812.09,591.257 1812.09,591.264 1812.1,591.271 1812.11,591.278 1812.12,591.284 1812.13,591.291 1812.14,591.298 1812.15,591.304 1812.16,591.311 1812.17,591.318 1812.18,591.325 1812.19,591.331 1812.2,591.338 1812.21,591.345 1812.21,591.351 1812.22,591.358 1812.23,591.365 1812.24,591.371 1812.25,591.378 1812.26,591.385 1812.27,591.392 1812.28,591.398 1812.29,591.405 1812.3,591.412 1812.31,591.418 1812.32,591.425 1812.32,591.432 1812.33,591.438 1812.34,591.445 1812.35,591.452 1812.36,591.459 1812.37,591.465 1812.38,591.472 1812.39,591.479 1812.4,591.485 1812.41,591.492 1812.42,591.499 1812.43,591.505 1812.43,591.512 1812.44,591.519 1812.45,591.525 1812.46,591.532 1812.47,591.539 1812.48,591.545 1812.49,591.552 1812.5,591.559 1812.51,591.565 1812.52,591.572 1812.53,591.579 1812.54,591.585 1812.55,591.592 1812.55,591.599 1812.56,591.605 1812.57,591.612 1812.58,591.619 1812.59,591.625 1812.6,591.632 1812.61,591.639 1812.62,591.645 1812.63,591.652 1812.64,591.659 1812.65,591.665 1812.66,591.672 1812.66,591.679 1812.67,591.685 1812.68,591.692 1812.69,591.699 1812.7,591.705 1812.71,591.712 1812.72,591.719 1812.73,591.725 1812.74,591.732 1812.75,591.739 1812.76,591.745 1812.77,591.752 1812.77,591.759 1812.78,591.765 1812.79,591.772 1812.8,591.779 1812.81,591.785 1812.82,591.792 1812.83,591.799 1812.84,591.805 1812.85,591.812 1812.86,591.818 1812.87,591.825 1812.88,591.832 1812.89,591.838 1812.89,591.845 1812.9,591.852 1812.91,591.858 1812.92,591.865 1812.93,591.872 1812.94,591.878 1812.95,591.885 1812.96,591.891 1812.97,591.898 1812.98,591.905 1812.99,591.911 1813,591.918 1813,591.925 1813.01,591.931 1813.02,591.938 1813.03,591.944 1813.04,591.951 1813.05,591.958 1813.06,591.964 1813.07,591.971 1813.08,591.978 1813.09,591.984 1813.1,591.991 1813.11,591.997 1813.11,592.004 1813.12,592.011 1813.13,592.017 1813.14,592.024 1813.15,592.031 1813.16,592.037 1813.17,592.044 1813.18,592.05 1813.19,592.057 1813.2,592.064 1813.21,592.07 1813.22,592.077 1813.23,592.083 1813.23,592.09 1813.24,592.097 1813.25,592.103 1813.26,592.11 1813.27,592.116 1813.28,592.123 1813.29,592.13 1813.3,592.136 1813.31,592.143 1813.32,592.149 1813.33,592.156 1813.34,592.163 1813.34,592.169 1813.35,592.176 1813.36,592.182 1813.37,592.189 1813.38,592.196 1813.39,592.202 1813.4,592.209 1813.41,592.215 1813.42,592.222 1813.43,592.229 1813.44,592.235 1813.45,592.242 1813.45,592.248 1813.46,592.255 1813.47,592.261 1813.48,592.268 1813.49,592.275 1813.5,592.281 1813.51,592.288 1813.52,592.294 1813.53,592.301 1813.54,592.308 1813.55,592.314 1813.56,592.321 1813.57,592.327 1813.57,592.334 1813.58,592.34 1813.59,592.347 1813.6,592.354 1813.61,592.36 1813.62,592.367 1813.63,592.373 1813.64,592.38 1813.65,592.386 1813.66,592.393 1813.67,592.399 1813.68,592.406 1813.68,592.413 1813.69,592.419 1813.7,592.426 1813.71,592.432 1813.72,592.439 1813.73,592.445 1813.74,592.452 1813.75,592.459 1813.76,592.465 1813.77,592.472 1813.78,592.478 1813.79,592.485 1813.79,592.491 1813.8,592.498 1813.81,592.504 1813.82,592.511 1813.83,592.517 1813.84,592.524 1813.85,592.531 1813.86,592.537 1813.87,592.544 1813.88,592.55 1813.89,592.557 1813.9,592.563 1813.91,592.57 1813.91,592.576 1813.92,592.583 1813.93,592.589 1813.94,592.596 1813.95,592.602 1813.96,592.609 1813.97,592.616 1813.98,592.622 1813.99,592.629 1814,592.635 1814.01,592.642 1814.02,592.648 1814.02,592.655 1814.03,592.661 1814.04,592.668 1814.05,592.674 1814.06,592.681 1814.07,592.687 1814.08,592.694 1814.09,592.7 1814.1,592.707 1814.11,592.713 1814.12,592.72 1814.13,592.726 1814.13,592.733 1814.14,592.74 1814.15,592.746 1814.16,592.753 1814.17,592.759 1814.18,592.766 1814.19,592.772 1814.2,592.779 1814.21,592.785 1814.22,592.792 1814.23,592.798 1814.24,592.805 1814.25,592.811 1814.25,592.818 1814.26,592.824 1814.27,592.831 1814.28,592.837 1814.29,592.844 1814.3,592.85 1814.31,592.857 1814.32,592.863 1814.33,592.87 1814.34,592.876 1814.35,592.883 1814.36,592.889 1814.36,592.896 1814.37,592.902 1814.38,592.909 1814.39,592.915 1814.4,592.922 1814.41,592.928 1814.42,592.935 1814.43,592.941 1814.44,592.948 1814.45,592.954 1814.46,592.96 1814.47,592.967 1814.47,592.973 1814.48,592.98 1814.49,592.986 1814.5,592.993 1814.51,592.999 1814.52,593.006 1814.53,593.012 1814.54,593.019 1814.55,593.025 1814.56,593.032 1814.57,593.038 1814.58,593.045 1814.59,593.051 1814.59,593.058 1814.6,593.064 1814.61,593.071 1814.62,593.077 1814.63,593.084 1814.64,593.09 1814.65,593.096 1814.66,593.103 1814.67,593.109 1814.68,593.116 1814.69,593.122 1814.7,593.129 1814.7,593.135 1814.71,593.142 1814.72,593.148 1814.73,593.155 1814.74,593.161 1814.75,593.168 1814.76,593.174 1814.77,593.18 1814.78,593.187 1814.79,593.193 1814.8,593.2 1814.81,593.206 1814.81,593.213 1814.82,593.219 1814.83,593.226 1814.84,593.232 1814.85,593.238 1814.86,593.245 1814.87,593.251 1814.88,593.258 1814.89,593.264 1814.9,593.271 1814.91,593.277 1814.92,593.284 1814.93,593.29 1814.93,593.296 1814.94,593.303 1814.95,593.309 1814.96,593.316 1814.97,593.322 1814.98,593.329 1814.99,593.335 1815,593.341 1815.01,593.348 1815.02,593.354 1815.03,593.361 1815.04,593.367 1815.04,593.374 1815.05,593.38 1815.06,593.386 1815.07,593.393 1815.08,593.399 1815.09,593.406 1815.1,593.412 1815.11,593.418 1815.12,593.425 1815.13,593.431 1815.14,593.438 1815.15,593.444 1815.15,593.451 1815.16,593.457 1815.17,593.463 1815.18,593.47 1815.19,593.476 1815.2,593.483 1815.21,593.489 1815.22,593.495 1815.23,593.502 1815.24,593.508 1815.25,593.515 1815.26,593.521 1815.27,593.527 1815.27,593.534 1815.28,593.54 1815.29,593.547 1815.3,593.553 1815.31,593.559 1815.32,593.566 1815.33,593.572 1815.34,593.579 1815.35,593.585 1815.36,593.591 1815.37,593.598 1815.38,593.604 1815.38,593.611 1815.39,593.617 1815.4,593.623 1815.41,593.63 1815.42,593.636 1815.43,593.642 1815.44,593.649 1815.45,593.655 1815.46,593.662 1815.47,593.668 1815.48,593.674 1815.49,593.681 1815.49,593.687 1815.5,593.694 1815.51,593.7 1815.52,593.706 1815.53,593.713 1815.54,593.719 1815.55,593.725 1815.56,593.732 1815.57,593.738 1815.58,593.745 1815.59,593.751 1815.6,593.757 1815.61,593.764 1815.61,593.77 1815.62,593.776 1815.63,593.783 1815.64,593.789 1815.65,593.795 1815.66,593.802 1815.67,593.808 1815.68,593.815 1815.69,593.821 1815.7,593.827 1815.71,593.834 1815.72,593.84 1815.72,593.846 1815.73,593.853 1815.74,593.859 1815.75,593.865 1815.76,593.872 1815.77,593.878 1815.78,593.884 1815.79,593.891 1815.8,593.897 1815.81,593.903 1815.82,593.91 1815.83,593.916 1815.83,593.922 1815.84,593.929 1815.85,593.935 1815.86,593.941 1815.87,593.948 1815.88,593.954 1815.89,593.96 1815.9,593.967 1815.91,593.973 1815.92,593.979 1815.93,593.986 1815.94,593.992 1815.95,593.998 1815.95,594.005 1815.96,594.011 1815.97,594.017 1815.98,594.024 1815.99,594.03 1816,594.036 1816.01,594.043 1816.02,594.049 1816.03,594.055 1816.04,594.062 1816.05,594.068 1816.06,594.074 1816.06,594.081 1816.07,594.087 1816.08,594.093 1816.09,594.1 1816.1,594.106 1816.11,594.112 1816.12,594.119 1816.13,594.125 1816.14,594.131 1816.15,594.137 1816.16,594.144 1816.17,594.15 1816.17,594.156 1816.18,594.163 1816.19,594.169 1816.2,594.175 1816.21,594.182 1816.22,594.188 1816.23,594.194 1816.24,594.2 1816.25,594.207 1816.26,594.213 1816.27,594.219 1816.28,594.226 1816.29,594.232 1816.29,594.238 1816.3,594.245 1816.31,594.251 1816.32,594.257 1816.33,594.263 1816.34,594.27 1816.35,594.276 1816.36,594.282 1816.37,594.289 1816.38,594.295 1816.39,594.301 1816.4,594.307 1816.4,594.314 1816.41,594.32 1816.42,594.326 1816.43,594.333 1816.44,594.339 1816.45,594.345 1816.46,594.351 1816.47,594.358 1816.48,594.364 1816.49,594.37 1816.5,594.376 1816.51,594.383 1816.51,594.389 1816.52,594.395 1816.53,594.402 1816.54,594.408 1816.55,594.414 1816.56,594.42 1816.57,594.427 1816.58,594.433 1816.59,594.439 1816.6,594.445 1816.61,594.452 1816.62,594.458 1816.63,594.464 1816.63,594.47 1816.64,594.477 1816.65,594.483 1816.66,594.489 1816.67,594.495 1816.68,594.502 1816.69,594.508 1816.7,594.514 1816.71,594.52 1816.72,594.527 1816.73,594.533 1816.74,594.539 1816.74,594.545 1816.75,594.552 1816.76,594.558 1816.77,594.564 1816.78,594.57 1816.79,594.577 1816.8,594.583 1816.81,594.589 1816.82,594.595 1816.83,594.602 1816.84,594.608 1816.85,594.614 1816.85,594.62 1816.86,594.626 1816.87,594.633 1816.88,594.639 1816.89,594.645 1816.9,594.651 1816.91,594.658 1816.92,594.664 1816.93,594.67 1816.94,594.676 1816.95,594.682 1816.96,594.689 1816.97,594.695 1816.97,594.701 1816.98,594.707 1816.99,594.714 1817,594.72 1817.01,594.726 1817.02,594.732 1817.03,594.738 1817.04,594.745 1817.05,594.751 1817.06,594.757 1817.07,594.763 1817.08,594.769 1817.08,594.776 1817.09,594.782 1817.1,594.788 1817.11,594.794 1817.12,594.8 1817.13,594.807 1817.14,594.813 1817.15,594.819 1817.16,594.825 1817.17,594.831 1817.18,594.838 1817.19,594.844 1817.19,594.85 1817.2,594.856 1817.21,594.862 1817.22,594.869 1817.23,594.875 1817.24,594.881 1817.25,594.887 1817.26,594.893 1817.27,594.9 1817.28,594.906 1817.29,594.912 1817.3,594.918 1817.31,594.924 1817.31,594.93 1817.32,594.937 1817.33,594.943 1817.34,594.949 1817.35,594.955 1817.36,594.961 1817.37,594.968 1817.38,594.974 1817.39,594.98 1817.4,594.986 1817.41,594.992 1817.42,594.998 1817.42,595.005 1817.43,595.011 1817.44,595.017 1817.45,595.023 1817.46,595.029 1817.47,595.035 1817.48,595.042 1817.49,595.048 1817.5,595.054 1817.51,595.06 1817.52,595.066 1817.53,595.072 1817.53,595.079 1817.54,595.085 1817.55,595.091 1817.56,595.097 1817.57,595.103 1817.58,595.109 1817.59,595.115 1817.6,595.122 1817.61,595.128 1817.62,595.134 1817.63,595.14 1817.64,595.146 1817.65,595.152 1817.65,595.158 1817.66,595.165 1817.67,595.171 1817.68,595.177 1817.69,595.183 1817.7,595.189 1817.71,595.195 1817.72,595.201 1817.73,595.208 1817.74,595.214 1817.75,595.22 1817.76,595.226 1817.76,595.232 1817.77,595.238 1817.78,595.244 1817.79,595.25 1817.8,595.257 1817.81,595.263 1817.82,595.269 1817.83,595.275 1817.84,595.281 1817.85,595.287 1817.86,595.293 1817.87,595.299 1817.87,595.306 1817.88,595.312 1817.89,595.318 1817.9,595.324 1817.91,595.33 1817.92,595.336 1817.93,595.342 1817.94,595.348 1817.95,595.354 1817.96,595.361 1817.97,595.367 1817.98,595.373 1817.99,595.379 1817.99,595.385 1818,595.391 1818.01,595.397 1818.02,595.403 1818.03,595.409 1818.04,595.415 1818.05,595.422 1818.06,595.428 1818.07,595.434 1818.08,595.44 1818.09,595.446 1818.1,595.452 1818.1,595.458 1818.11,595.464 1818.12,595.47 1818.13,595.476 1818.14,595.483 1818.15,595.489 1818.16,595.495 1818.17,595.501 1818.18,595.507 1818.19,595.513 1818.2,595.519 1818.21,595.525 1818.21,595.531 1818.22,595.537 1818.23,595.543 1818.24,595.549 1818.25,595.555 1818.26,595.562 1818.27,595.568 1818.28,595.574 1818.29,595.58 1818.3,595.586 1818.31,595.592 1818.32,595.598 1818.33,595.604 1818.33,595.61 1818.34,595.616 1818.35,595.622 1818.36,595.628 1818.37,595.634 1818.38,595.64 1818.39,595.646 1818.4,595.653 1818.41,595.659 1818.42,595.665 1818.43,595.671 1818.44,595.677 1818.44,595.683 1818.45,595.689 1818.46,595.695 1818.47,595.701 1818.48,595.707 1818.49,595.713 1818.5,595.719 1818.51,595.725 1818.52,595.731 1818.53,595.737 1818.54,595.743 1818.55,595.749 1818.55,595.755 1818.56,595.761 1818.57,595.767 1818.58,595.773 1818.59,595.779 1818.6,595.786 1818.61,595.792 1818.62,595.798 1818.63,595.804 1818.64,595.81 1818.65,595.816 1818.66,595.822 1818.67,595.828 1818.67,595.834 1818.68,595.84 1818.69,595.846 1818.7,595.852 1818.71,595.858 1818.72,595.864 1818.73,595.87 1818.74,595.876 1818.75,595.882 1818.76,595.888 1818.77,595.894 1818.78,595.9 1818.78,595.906 1818.79,595.912 1818.8,595.918 1818.81,595.924 1818.82,595.93 1818.83,595.936 1818.84,595.942 1818.85,595.948 1818.86,595.954 1818.87,595.96 1818.88,595.966 1818.89,595.972 1818.89,595.978 1818.9,595.984 1818.91,595.99 1818.92,595.996 1818.93,596.002 1818.94,596.008 1818.95,596.014 1818.96,596.02 1818.97,596.026 1818.98,596.032 1818.99,596.038 1819,596.044 1819.01,596.05 1819.01,596.056 1819.02,596.062 1819.03,596.068 1819.04,596.074 1819.05,596.08 1819.06,596.086 1819.07,596.092 1819.08,596.098 1819.09,596.104 1819.1,596.11 1819.11,596.116 1819.12,596.122 1819.12,596.128 1819.13,596.134 1819.14,596.14 1819.15,596.146 1819.16,596.152 1819.17,596.158 1819.18,596.163 1819.19,596.169 1819.2,596.175 1819.21,596.181 1819.22,596.187 1819.23,596.193 1819.23,596.199 1819.24,596.205 1819.25,596.211 1819.26,596.217 1819.27,596.223 1819.28,596.229 1819.29,596.235 1819.3,596.241 1819.31,596.247 1819.32,596.253 1819.33,596.259 1819.34,596.265 1819.35,596.271 1819.35,596.277 1819.36,596.283 1819.37,596.289 1819.38,596.294 1819.39,596.3 1819.4,596.306 1819.41,596.312 1819.42,596.318 1819.43,596.324 1819.44,596.33 1819.45,596.336 1819.46,596.342 1819.46,596.348 1819.47,596.354 1819.48,596.36 1819.49,596.366 1819.5,596.372 1819.51,596.378 1819.52,596.383 1819.53,596.389 1819.54,596.395 1819.55,596.401 1819.56,596.407 1819.57,596.413 1819.57,596.419 1819.58,596.425 1819.59,596.431 1819.6,596.437 1819.61,596.443 1819.62,596.449 1819.63,596.454 1819.64,596.46 1819.65,596.466 1819.66,596.472 1819.67,596.478 1819.68,596.484 1819.69,596.49 1819.69,596.496 1819.7,596.502 1819.71,596.508 1819.72,596.514 1819.73,596.519 1819.74,596.525 1819.75,596.531 1819.76,596.537 1819.77,596.543 1819.78,596.549 1819.79,596.555 1819.8,596.561 1819.8,596.567 1819.81,596.572 1819.82,596.578 1819.83,596.584 1819.84,596.59 1819.85,596.596 1819.86,596.602 1819.87,596.608 1819.88,596.614 1819.89,596.62 1819.9,596.625 1819.91,596.631 1819.91,596.637 1819.92,596.643 1819.93,596.649 1819.94,596.655 1819.95,596.661 1819.96,596.667 1819.97,596.672 1819.98,596.678 1819.99,596.684 1820,596.69 1820.01,596.696 1820.02,596.702 1820.03,596.708 1820.03,596.713 1820.04,596.719 1820.05,596.725 1820.06,596.731 1820.07,596.737 1820.08,596.743 1820.09,596.749 1820.1,596.755 1820.11,596.76 1820.12,596.766 1820.13,596.772 1820.14,596.778 1820.14,596.784 1820.15,596.79 1820.16,596.795 1820.17,596.801 1820.18,596.807 1820.19,596.813 1820.2,596.819 1820.21,596.825 1820.22,596.831 1820.23,596.836 1820.24,596.842 1820.25,596.848 1820.25,596.854 1820.26,596.86 1820.27,596.866 1820.28,596.871 1820.29,596.877 1820.3,596.883 1820.31,596.889 1820.32,596.895 1820.33,596.901 1820.34,596.906 1820.35,596.912 1820.36,596.918 1820.37,596.924 1820.37,596.93 1820.38,596.935 1820.39,596.941 1820.4,596.947 1820.41,596.953 1820.42,596.959 1820.43,596.965 1820.44,596.97 1820.45,596.976 1820.46,596.982 1820.47,596.988 1820.48,596.994 1820.48,596.999 1820.49,597.005 1820.5,597.011 1820.51,597.017 1820.52,597.023 1820.53,597.028 1820.54,597.034 1820.55,597.04 1820.56,597.046 1820.57,597.052 1820.58,597.057 1820.59,597.063 1820.59,597.069 1820.6,597.075 1820.61,597.081 1820.62,597.086 1820.63,597.092 1820.64,597.098 1820.65,597.104 1820.66,597.109 1820.67,597.115 1820.68,597.121 1820.69,597.127 1820.7,597.133 1820.71,597.138 1820.71,597.144 1820.72,597.15 1820.73,597.156 1820.74,597.162 1820.75,597.167 1820.76,597.173 1820.77,597.179 1820.78,597.185 1820.79,597.19 1820.8,597.196 1820.81,597.202 1820.82,597.208 1820.82,597.213 1820.83,597.219 1820.84,597.225 1820.85,597.231 1820.86,597.236 1820.87,597.242 1820.88,597.248 1820.89,597.254 1820.9,597.26 1820.91,597.265 1820.92,597.271 1820.93,597.277 1820.93,597.283 1820.94,597.288 1820.95,597.294 1820.96,597.3 1820.97,597.306 1820.98,597.311 1820.99,597.317 1821,597.323 1821.01,597.328 1821.02,597.334 1821.03,597.34 1821.04,597.346 1821.05,597.351 1821.05,597.357 1821.06,597.363 1821.07,597.369 1821.08,597.374 1821.09,597.38 1821.1,597.386 1821.11,597.392 1821.12,597.397 1821.13,597.403 1821.14,597.409 1821.15,597.414 1821.16,597.42 1821.16,597.426 1821.17,597.432 1821.18,597.437 1821.19,597.443 1821.2,597.449 1821.21,597.454 1821.22,597.46 1821.23,597.466 1821.24,597.472 1821.25,597.477 1821.26,597.483 1821.27,597.489 1821.27,597.494 1821.28,597.5 1821.29,597.506 1821.3,597.512 1821.31,597.517 1821.32,597.523 1821.33,597.529 1821.34,597.534 1821.35,597.54 1821.36,597.546 1821.37,597.551 1821.38,597.557 1821.39,597.563 1821.39,597.569 1821.4,597.574 1821.41,597.58 1821.42,597.586 1821.43,597.591 1821.44,597.597 1821.45,597.603 1821.46,597.608 1821.47,597.614 1821.48,597.62 1821.49,597.625 1821.5,597.631 1821.5,597.637 1821.51,597.642 1821.52,597.648 1821.53,597.654 1821.54,597.659 1821.55,597.665 1821.56,597.671 1821.57,597.676 1821.58,597.682 1821.59,597.688 1821.6,597.693 1821.61,597.699 1821.61,597.705 1821.62,597.71 1821.63,597.716 1821.64,597.722 1821.65,597.727 1821.66,597.733 1821.67,597.739 1821.68,597.744 1821.69,597.75 1821.7,597.756 1821.71,597.761 1821.72,597.767 1821.73,597.773 1821.73,597.778 1821.74,597.784 1821.75,597.79 1821.76,597.795 1821.77,597.801 1821.78,597.807 1821.79,597.812 1821.8,597.818 1821.81,597.823 1821.82,597.829 1821.83,597.835 1821.84,597.84 1821.84,597.846 1821.85,597.852 1821.86,597.857 1821.87,597.863 1821.88,597.869 1821.89,597.874 1821.9,597.88 1821.91,597.885 1821.92,597.891 1821.93,597.897 1821.94,597.902 1821.95,597.908 1821.95,597.914 1821.96,597.919 1821.97,597.925 1821.98,597.93 1821.99,597.936 1822,597.942 1822.01,597.947 1822.02,597.953 1822.03,597.958 1822.04,597.964 1822.05,597.97 1822.06,597.975 1822.07,597.981 1822.07,597.986 1822.08,597.992 1822.09,597.998 1822.1,598.003 1822.11,598.009 1822.12,598.014 1822.13,598.02 1822.14,598.026 1822.15,598.031 1822.16,598.037 1822.17,598.042 1822.18,598.048 1822.18,598.054 1822.19,598.059 1822.2,598.065 1822.21,598.07 1822.22,598.076 1822.23,598.082 1822.24,598.087 1822.25,598.093 1822.26,598.098 1822.27,598.104 1822.28,598.109 1822.29,598.115 1822.29,598.121 1822.3,598.126 1822.31,598.132 1822.32,598.137 1822.33,598.143 1822.34,598.148 1822.35,598.154 1822.36,598.16 1822.37,598.165 1822.38,598.171 1822.39,598.176 1822.4,598.182 1822.41,598.187 1822.41,598.193 1822.42,598.198 1822.43,598.204 1822.44,598.21 1822.45,598.215 1822.46,598.221 1822.47,598.226 1822.48,598.232 1822.49,598.237 1822.5,598.243 1822.51,598.248 1822.52,598.254 1822.52,598.26 1822.53,598.265 1822.54,598.271 1822.55,598.276 1822.56,598.282 1822.57,598.287 1822.58,598.293 1822.59,598.298 1822.6,598.304 1822.61,598.309 1822.62,598.315 1822.63,598.32 1822.63,598.326 1822.64,598.331 1822.65,598.337 1822.66,598.343 1822.67,598.348 1822.68,598.354 1822.69,598.359 1822.7,598.365 1822.71,598.37 1822.72,598.376 1822.73,598.381 1822.74,598.387 1822.75,598.392 1822.75,598.398 1822.76,598.403 1822.77,598.409 1822.78,598.414 1822.79,598.42 1822.8,598.425 1822.81,598.431 1822.82,598.436 1822.83,598.442 1822.84,598.447 1822.85,598.453 1822.86,598.458 1822.86,598.464 1822.87,598.469 1822.88,598.475 1822.89,598.48 1822.9,598.486 1822.91,598.491 1822.92,598.497 1822.93,598.502 1822.94,598.508 1822.95,598.513 1822.96,598.519 1822.97,598.524 1822.97,598.53 1822.98,598.535 1822.99,598.541 1823,598.546 1823.01,598.552 1823.02,598.557 1823.03,598.562 1823.04,598.568 1823.05,598.573 1823.06,598.579 1823.07,598.584 1823.08,598.59 1823.09,598.595 1823.09,598.601 1823.1,598.606 1823.11,598.612 1823.12,598.617 1823.13,598.623 1823.14,598.628 1823.15,598.634 1823.16,598.639 1823.17,598.644 1823.18,598.65 1823.19,598.655 1823.2,598.661 1823.2,598.666 1823.21,598.672 1823.22,598.677 1823.23,598.683 1823.24,598.688 1823.25,598.694 1823.26,598.699 1823.27,598.704 1823.28,598.71 1823.29,598.715 1823.3,598.721 1823.31,598.726 1823.31,598.732 1823.32,598.737 1823.33,598.742 1823.34,598.748 1823.35,598.753 1823.36,598.759 1823.37,598.764 1823.38,598.77 1823.39,598.775 1823.4,598.78 1823.41,598.786 1823.42,598.791 1823.43,598.797 1823.43,598.802 1823.44,598.808 1823.45,598.813 1823.46,598.818 1823.47,598.824 1823.48,598.829 1823.49,598.835 1823.5,598.84 1823.51,598.845 1823.52,598.851 1823.53,598.856 1823.54,598.862 1823.54,598.867 1823.55,598.872 1823.56,598.878 1823.57,598.883 1823.58,598.889 1823.59,598.894 1823.6,598.899 1823.61,598.905 1823.62,598.91 1823.63,598.916 1823.64,598.921 1823.65,598.926 1823.65,598.932 1823.66,598.937 1823.67,598.943 1823.68,598.948 1823.69,598.953 1823.7,598.959 1823.71,598.964 1823.72,598.969 1823.73,598.975 1823.74,598.98 1823.75,598.986 1823.76,598.991 1823.77,598.996 1823.77,599.002 1823.78,599.007 1823.79,599.012 1823.8,599.018 1823.81,599.023 1823.82,599.029 1823.83,599.034 1823.84,599.039 1823.85,599.045 1823.86,599.05 1823.87,599.055 1823.88,599.061 1823.88,599.066 1823.89,599.071 1823.9,599.077 1823.91,599.082 1823.92,599.088 1823.93,599.093 1823.94,599.098 1823.95,599.104 1823.96,599.109 1823.97,599.114 1823.98,599.12 1823.99,599.125 1823.99,599.13 1824,599.136 1824.01,599.141 1824.02,599.146 1824.03,599.152 1824.04,599.157 1824.05,599.162 1824.06,599.168 1824.07,599.173 1824.08,599.178 1824.09,599.184 1824.1,599.189 1824.11,599.194 1824.11,599.2 1824.12,599.205 1824.13,599.21 1824.14,599.216 1824.15,599.221 1824.16,599.226 1824.17,599.232 1824.18,599.237 1824.19,599.242 1824.2,599.247 1824.21,599.253 1824.22,599.258 1824.22,599.263 1824.23,599.269 1824.24,599.274 1824.25,599.279 1824.26,599.285 1824.27,599.29 1824.28,599.295 1824.29,599.3 1824.3,599.306 1824.31,599.311 1824.32,599.316 1824.33,599.322 1824.33,599.327 1824.34,599.332 1824.35,599.338 1824.36,599.343 1824.37,599.348 1824.38,599.353 1824.39,599.359 1824.4,599.364 1824.41,599.369 1824.42,599.375 1824.43,599.38 1824.44,599.385 1824.45,599.39 1824.45,599.396 1824.46,599.401 1824.47,599.406 1824.48,599.411 1824.49,599.417 1824.5,599.422 1824.51,599.427 1824.52,599.433 1824.53,599.438 1824.54,599.443 1824.55,599.448 1824.56,599.454 1824.56,599.459 1824.57,599.464 1824.58,599.469 1824.59,599.475 1824.6,599.48 1824.61,599.485 1824.62,599.49 1824.63,599.496 1824.64,599.501 1824.65,599.506 1824.66,599.511 1824.67,599.517 1824.67,599.522 1824.68,599.527 1824.69,599.532 1824.7,599.538 1824.71,599.543 1824.72,599.548 1824.73,599.553 1824.74,599.559 1824.75,599.564 1824.76,599.569 1824.77,599.574 1824.78,599.579 1824.79,599.585 1824.79,599.59 1824.8,599.595 1824.81,599.6 1824.82,599.606 1824.83,599.611 1824.84,599.616 1824.85,599.621 1824.86,599.626 1824.87,599.632 1824.88,599.637 1824.89,599.642 1824.9,599.647 1824.9,599.652 1824.91,599.658 1824.92,599.663 1824.93,599.668 1824.94,599.673 1824.95,599.679 1824.96,599.684 1824.97,599.689 1824.98,599.694 1824.99,599.699 1825,599.705 1825.01,599.71 1825.01,599.715 1825.02,599.72 1825.03,599.725 1825.04,599.73 1825.05,599.736 1825.06,599.741 1825.07,599.746 1825.08,599.751 1825.09,599.756 1825.1,599.762 1825.11,599.767 1825.12,599.772 1825.13,599.777 1825.13,599.782 1825.14,599.787 1825.15,599.793 1825.16,599.798 1825.17,599.803 1825.18,599.808 1825.19,599.813 1825.2,599.818 1825.21,599.824 1825.22,599.829 1825.23,599.834 1825.24,599.839 1825.24,599.844 1825.25,599.849 1825.26,599.855 1825.27,599.86 1825.28,599.865 1825.29,599.87 1825.3,599.875 1825.31,599.88 1825.32,599.886 1825.33,599.891 1825.34,599.896 1825.35,599.901 1825.35,599.906 1825.36,599.911 1825.37,599.916 1825.38,599.922 1825.39,599.927 1825.4,599.932 1825.41,599.937 1825.42,599.942 1825.43,599.947 1825.44,599.952 1825.45,599.957 1825.46,599.963 1825.47,599.968 1825.47,599.973 1825.48,599.978 1825.49,599.983 1825.5,599.988 1825.51,599.993 1825.52,599.998 1825.53,600.004 1825.54,600.009 1825.55,600.014 1825.56,600.019 1825.57,600.024 1825.58,600.029 1825.58,600.034 1825.59,600.039 1825.6,600.044 1825.61,600.05 1825.62,600.055 1825.63,600.06 1825.64,600.065 1825.65,600.07 1825.66,600.075 1825.67,600.08 1825.68,600.085 1825.69,600.09 1825.69,600.095 1825.7,600.101 1825.71,600.106 1825.72,600.111 1825.73,600.116 1825.74,600.121 1825.75,600.126 1825.76,600.131 1825.77,600.136 1825.78,600.141 1825.79,600.146 1825.8,600.151 1825.81,600.156 1825.81,600.161 1825.82,600.167 1825.83,600.172 1825.84,600.177 1825.85,600.182 1825.86,600.187 1825.87,600.192 1825.88,600.197 1825.89,600.202 1825.9,600.207 1825.91,600.212 1825.92,600.217 1825.92,600.222 1825.93,600.227 1825.94,600.232 1825.95,600.237 1825.96,600.242 1825.97,600.248 1825.98,600.253 1825.99,600.258 1826,600.263 1826.01,600.268 1826.02,600.273 1826.03,600.278 1826.03,600.283 1826.04,600.288 1826.05,600.293 1826.06,600.298 1826.07,600.303 1826.08,600.308 1826.09,600.313 1826.1,600.318 1826.11,600.323 1826.12,600.328 1826.13,600.333 1826.14,600.338 1826.15,600.343 1826.15,600.348 1826.16,600.353 1826.17,600.358 1826.18,600.363 1826.19,600.368 1826.2,600.373 1826.21,600.378 1826.22,600.383 1826.23,600.388 1826.24,600.393 1826.25,600.398 1826.26,600.403 1826.26,600.408 1826.27,600.413 1826.28,600.418 1826.29,600.423 1826.3,600.428 1826.31,600.433 1826.32,600.438 1826.33,600.443 1826.34,600.448 1826.35,600.453 1826.36,600.458 1826.37,600.463 1826.37,600.468 1826.38,600.473 1826.39,600.478 1826.4,600.483 1826.41,600.488 1826.42,600.493 1826.43,600.498 1826.44,600.503 1826.45,600.508 1826.46,600.513 1826.47,600.518 1826.48,600.523 1826.49,600.528 1826.49,600.533 1826.5,600.538 1826.51,600.543 1826.52,600.548 1826.53,600.553 1826.54,600.558 1826.55,600.563 1826.56,600.568 1826.57,600.573 1826.58,600.578 1826.59,600.583 1826.6,600.588 1826.6,600.593 1826.61,600.598 1826.62,600.602 1826.63,600.607 1826.64,600.612 1826.65,600.617 1826.66,600.622 1826.67,600.627 1826.68,600.632 1826.69,600.637 1826.7,600.642 1826.71,600.647 1826.72,600.652 1826.72,600.657 1826.73,600.662 1826.74,600.667 1826.75,600.672 1826.76,600.677 1826.77,600.681 1826.78,600.686 1826.79,600.691 1826.8,600.696 1826.81,600.701 1826.82,600.706 1826.83,600.711 1826.83,600.716 1826.84,600.721 1826.85,600.726 1826.86,600.731 1826.87,600.736 1826.88,600.74 1826.89,600.745 1826.9,600.75 1826.91,600.755 1826.92,600.76 1826.93,600.765 1826.94,600.77 1826.94,600.775 1826.95,600.78 1826.96,600.785 1826.97,600.789 1826.98,600.794 1826.99,600.799 1827,600.804 1827.01,600.809 1827.02,600.814 1827.03,600.819 1827.04,600.824 1827.05,600.829 1827.06,600.833 1827.06,600.838 1827.07,600.843 1827.08,600.848 1827.09,600.853 1827.1,600.858 1827.11,600.863 1827.12,600.868 1827.13,600.872 1827.14,600.877 1827.15,600.882 1827.16,600.887 1827.17,600.892 1827.17,600.897 1827.18,600.902 1827.19,600.907 1827.2,600.911 1827.21,600.916 1827.22,600.921 1827.23,600.926 1827.24,600.931 1827.25,600.936 1827.26,600.94 1827.27,600.945 1827.28,600.95 1827.28,600.955 1827.29,600.96 1827.3,600.965 1827.31,600.97 1827.32,600.974 1827.33,600.979 1827.34,600.984 1827.35,600.989 1827.36,600.994 1827.37,600.999 1827.38,601.003 1827.39,601.008 1827.4,601.013 1827.4,601.018 1827.41,601.023 1827.42,601.028 1827.43,601.032 1827.44,601.037 1827.45,601.042 1827.46,601.047 1827.47,601.052 1827.48,601.056 1827.49,601.061 1827.5,601.066 1827.51,601.071 1827.51,601.076 1827.52,601.08 1827.53,601.085 1827.54,601.09 1827.55,601.095 1827.56,601.1 1827.57,601.104 1827.58,601.109 1827.59,601.114 1827.6,601.119 1827.61,601.124 1827.62,601.128 1827.62,601.133 1827.63,601.138 1827.64,601.143 1827.65,601.148 1827.66,601.152 1827.67,601.157 1827.68,601.162 1827.69,601.167 1827.7,601.171 1827.71,601.176 1827.72,601.181 1827.73,601.186 1827.74,601.191 1827.74,601.195 1827.75,601.2 1827.76,601.205 1827.77,601.21 1827.78,601.214 1827.79,601.219 1827.8,601.224 1827.81,601.229 1827.82,601.233 1827.83,601.238 1827.84,601.243 1827.85,601.248 1827.85,601.252 1827.86,601.257 1827.87,601.262 1827.88,601.267 1827.89,601.271 1827.9,601.276 1827.91,601.281 1827.92,601.286 1827.93,601.29 1827.94,601.295 1827.95,601.3 1827.96,601.305 1827.96,601.309 1827.97,601.314 1827.98,601.319 1827.99,601.324 1828,601.328 1828.01,601.333 1828.02,601.338 1828.03,601.342 1828.04,601.347 1828.05,601.352 1828.06,601.357 1828.07,601.361 1828.08,601.366 1828.08,601.371 1828.09,601.376 1828.1,601.38 1828.11,601.385 1828.12,601.39 1828.13,601.394 1828.14,601.399 1828.15,601.404 1828.16,601.408 1828.17,601.413 1828.18,601.418 1828.19,601.423 1828.19,601.427 1828.2,601.432 1828.21,601.437 1828.22,601.441 1828.23,601.446 1828.24,601.451 1828.25,601.455 1828.26,601.46 1828.27,601.465 1828.28,601.469 1828.29,601.474 1828.3,601.479 1828.3,601.483 1828.31,601.488 1828.32,601.493 1828.33,601.498 1828.34,601.502 1828.35,601.507 1828.36,601.512 1828.37,601.516 1828.38,601.521 1828.39,601.526 1828.4,601.53 1828.41,601.535 1828.42,601.539 1828.42,601.544 1828.43,601.549 1828.44,601.553 1828.45,601.558 1828.46,601.563 1828.47,601.567 1828.48,601.572 1828.49,601.577 1828.5,601.581 1828.51,601.586 1828.52,601.591 1828.53,601.595 1828.53,601.6 1828.54,601.605 1828.55,601.609 1828.56,601.614 1828.57,601.618 1828.58,601.623 1828.59,601.628 1828.6,601.632 1828.61,601.637 1828.62,601.642 1828.63,601.646 1828.64,601.651 1828.64,601.655 1828.65,601.66 1828.66,601.665 1828.67,601.669 1828.68,601.674 1828.69,601.679 1828.7,601.683 1828.71,601.688 1828.72,601.692 1828.73,601.697 1828.74,601.702 1828.75,601.706 1828.76,601.711 1828.76,601.715 1828.77,601.72 1828.78,601.725 1828.79,601.729 1828.8,601.734 1828.81,601.738 1828.82,601.743 1828.83,601.748 1828.84,601.752 1828.85,601.757 1828.86,601.761 1828.87,601.766 1828.87,601.77 1828.88,601.775 1828.89,601.78 1828.9,601.784 1828.91,601.789 1828.92,601.793 1828.93,601.798 1828.94,601.803 1828.95,601.807 1828.96,601.812 1828.97,601.816 1828.98,601.821 1828.98,601.825 1828.99,601.83 1829,601.834 1829.01,601.839 1829.02,601.844 1829.03,601.848 1829.04,601.853 1829.05,601.857 1829.06,601.862 1829.07,601.866 1829.08,601.871 1829.09,601.875 1829.1,601.88 1829.1,601.885 1829.11,601.889 1829.12,601.894 1829.13,601.898 1829.14,601.903 1829.15,601.907 1829.16,601.912 1829.17,601.916 1829.18,601.921 1829.19,601.925 1829.2,601.93 1829.21,601.934 1829.21,601.939 1829.22,601.943 1829.23,601.948 1829.24,601.952 1829.25,601.957 1829.26,601.961 1829.27,601.966 1829.28,601.971 1829.29,601.975 1829.3,601.98 1829.31,601.984 1829.32,601.989 1829.32,601.993 1829.33,601.998 1829.34,602.002 1829.35,602.007 1829.36,602.011 1829.37,602.016 1829.38,602.02 1829.39,602.025 1829.4,602.029 1829.41,602.034 1829.42,602.038 1829.43,602.042 1829.44,602.047 1829.44,602.051 1829.45,602.056 1829.46,602.06 1829.47,602.065 1829.48,602.069 1829.49,602.074 1829.5,602.078 1829.51,602.083 1829.52,602.087 1829.53,602.092 1829.54,602.096 1829.55,602.101 1829.55,602.105 1829.56,602.11 1829.57,602.114 1829.58,602.119 1829.59,602.123 1829.6,602.127 1829.61,602.132 1829.62,602.136 1829.63,602.141 1829.64,602.145 1829.65,602.15 1829.66,602.154 1829.66,602.159 1829.67,602.163 1829.68,602.167 1829.69,602.172 1829.7,602.176 1829.71,602.181 1829.72,602.185 1829.73,602.19 1829.74,602.194 1829.75,602.198 1829.76,602.203 1829.77,602.207 1829.78,602.212 1829.78,602.216 1829.79,602.221 1829.8,602.225 1829.81,602.229 1829.82,602.234 1829.83,602.238 1829.84,602.243 1829.85,602.247 1829.86,602.252 1829.87,602.256 1829.88,602.26 1829.89,602.265 1829.89,602.269 1829.9,602.274 1829.91,602.278 1829.92,602.282 1829.93,602.287 1829.94,602.291 1829.95,602.296 1829.96,602.3 1829.97,602.304 1829.98,602.309 1829.99,602.313 1830,602.317 1830,602.322 1830.01,602.326 1830.02,602.331 1830.03,602.335 1830.04,602.339 1830.05,602.344 1830.06,602.348 1830.07,602.353 1830.08,602.357 1830.09,602.361 1830.1,602.366 1830.11,602.37 1830.12,602.374 1830.12,602.379 1830.13,602.383 1830.14,602.387 1830.15,602.392 1830.16,602.396 1830.17,602.401 1830.18,602.405 1830.19,602.409 1830.2,602.414 1830.21,602.418 1830.22,602.422 1830.23,602.427 1830.23,602.431 1830.24,602.435 1830.25,602.44 1830.26,602.444 1830.27,602.448 1830.28,602.453 1830.29,602.457 1830.3,602.461 1830.31,602.466 1830.32,602.47 1830.33,602.474 1830.34,602.479 1830.34,602.483 1830.35,602.487 1830.36,602.492 1830.37,602.496 1830.38,602.5 1830.39,602.505 1830.4,602.509 1830.41,602.513 1830.42,602.517 1830.43,602.522 1830.44,602.526 1830.45,602.53 1830.46,602.535 1830.46,602.539 1830.47,602.543 1830.48,602.548 1830.49,602.552 1830.5,602.556 1830.51,602.56 1830.52,602.565 1830.53,602.569 1830.54,602.573 1830.55,602.578 1830.56,602.582 1830.57,602.586 1830.57,602.59 1830.58,602.595 1830.59,602.599 1830.6,602.603 1830.61,602.608 1830.62,602.612 1830.63,602.616 1830.64,602.62 1830.65,602.625 1830.66,602.629 1830.67,602.633 1830.68,602.637 1830.68,602.642 1830.69,602.646 1830.7,602.65 1830.71,602.655 1830.72,602.659 1830.73,602.663 1830.74,602.667 1830.75,602.672 1830.76,602.676 1830.77,602.68 1830.78,602.684 1830.79,602.688 1830.8,602.693 1830.8,602.697 1830.81,602.701 1830.82,602.705 1830.83,602.71 1830.84,602.714 1830.85,602.718 1830.86,602.722 1830.87,602.727 1830.88,602.731 1830.89,602.735 1830.9,602.739 1830.91,602.743 1830.91,602.748 1830.92,602.752 1830.93,602.756 1830.94,602.76 1830.95,602.765 1830.96,602.769 1830.97,602.773 1830.98,602.777 1830.99,602.781 1831,602.786 1831.01,602.79 1831.02,602.794 1831.02,602.798 1831.03,602.802 1831.04,602.807 1831.05,602.811 1831.06,602.815 1831.07,602.819 1831.08,602.823 1831.09,602.828 1831.1,602.832 1831.11,602.836 1831.12,602.84 1831.13,602.844 1831.14,602.848 1831.14,602.853 1831.15,602.857 1831.16,602.861 1831.17,602.865 1831.18,602.869 1831.19,602.874 1831.2,602.878 1831.21,602.882 1831.22,602.886 1831.23,602.89 1831.24,602.894 1831.25,602.898 1831.25,602.903 1831.26,602.907 1831.27,602.911 1831.28,602.915 1831.29,602.919 1831.3,602.923 1831.31,602.928 1831.32,602.932 1831.33,602.936 1831.34,602.94 1831.35,602.944 1831.36,602.948 1831.36,602.952 1831.37,602.957 1831.38,602.961 1831.39,602.965 1831.4,602.969 1831.41,602.973 1831.42,602.977 1831.43,602.981 1831.44,602.985 1831.45,602.99 1831.46,602.994 1831.47,602.998 1831.48,603.002 1831.48,603.006 1831.49,603.01 1831.5,603.014 1831.51,603.018 1831.52,603.022 1831.53,603.027 1831.54,603.031 1831.55,603.035 1831.56,603.039 1831.57,603.043 1831.58,603.047 1831.59,603.051 1831.59,603.055 1831.6,603.059 1831.61,603.063 1831.62,603.067 1831.63,603.072 1831.64,603.076 1831.65,603.08 1831.66,603.084 1831.67,603.088 1831.68,603.092 1831.69,603.096 1831.7,603.1 1831.7,603.104 1831.71,603.108 1831.72,603.112 1831.73,603.116 1831.74,603.12 1831.75,603.124 1831.76,603.129 1831.77,603.133 1831.78,603.137 1831.79,603.141 1831.8,603.145 1831.81,603.149 1831.82,603.153 1831.82,603.157 1831.83,603.161 1831.84,603.165 1831.85,603.169 1831.86,603.173 1831.87,603.177 1831.88,603.181 1831.89,603.185 1831.9,603.189 1831.91,603.193 1831.92,603.197 1831.93,603.201 1831.93,603.205 1831.94,603.209 1831.95,603.213 1831.96,603.217 1831.97,603.221 1831.98,603.225 1831.99,603.229 1832,603.234 1832.01,603.238 1832.02,603.242 1832.03,603.246 1832.04,603.25 1832.04,603.254 1832.05,603.258 1832.06,603.262 1832.07,603.266 1832.08,603.27 1832.09,603.274 1832.1,603.278 1832.11,603.282 1832.12,603.286 1832.13,603.29 1832.14,603.294 1832.15,603.297 1832.16,603.301 1832.16,603.305 1832.17,603.309 1832.18,603.313 1832.19,603.317 1832.2,603.321 1832.21,603.325 1832.22,603.329 1832.23,603.333 1832.24,603.337 1832.25,603.341 1832.26,603.345 1832.27,603.349 1832.27,603.353 1832.28,603.357 1832.29,603.361 1832.3,603.365 1832.31,603.369 1832.32,603.373 1832.33,603.377 1832.34,603.381 1832.35,603.385 1832.36,603.389 1832.37,603.393 1832.38,603.397 1832.38,603.401 1832.39,603.404 1832.4,603.408 1832.41,603.412 1832.42,603.416 1832.43,603.42 1832.44,603.424 1832.45,603.428 1832.46,603.432 1832.47,603.436 1832.48,603.44 1832.49,603.444 1832.5,603.448 1832.5,603.452 1832.51,603.455 1832.52,603.459 1832.53,603.463 1832.54,603.467 1832.55,603.471 1832.56,603.475 1832.57,603.479 1832.58,603.483 1832.59,603.487 1832.6,603.491 1832.61,603.495 1832.61,603.498 1832.62,603.502 1832.63,603.506 1832.64,603.51 1832.65,603.514 1832.66,603.518 1832.67,603.522 1832.68,603.526 1832.69,603.53 1832.7,603.533 1832.71,603.537 1832.72,603.541 1832.72,603.545 1832.73,603.549 1832.74,603.553 1832.75,603.557 1832.76,603.56 1832.77,603.564 1832.78,603.568 1832.79,603.572 1832.8,603.576 1832.81,603.58 1832.82,603.584 1832.83,603.587 1832.84,603.591 1832.84,603.595 1832.85,603.599 1832.86,603.603 1832.87,603.607 1832.88,603.611 1832.89,603.614 1832.9,603.618 1832.91,603.622 1832.92,603.626 1832.93,603.63 1832.94,603.634 1832.95,603.637 1832.95,603.641 1832.96,603.645 1832.97,603.649 1832.98,603.653 1832.99,603.657 1833,603.66 1833.01,603.664 1833.02,603.668 1833.03,603.672 1833.04,603.676 1833.05,603.679 1833.06,603.683 1833.06,603.687 1833.07,603.691 1833.08,603.695 1833.09,603.698 1833.1,603.702 1833.11,603.706 1833.12,603.71 1833.13,603.714 1833.14,603.717 1833.15,603.721 1833.16,603.725 1833.17,603.729 1833.18,603.733 1833.18,603.736 1833.19,603.74 1833.2,603.744 1833.21,603.748 1833.22,603.751 1833.23,603.755 1833.24,603.759 1833.25,603.763 1833.26,603.766 1833.27,603.77 1833.28,603.774 1833.29,603.778 1833.29,603.782 1833.3,603.785 1833.31,603.789 1833.32,603.793 1833.33,603.797 1833.34,603.8 1833.35,603.804 1833.36,603.808 1833.37,603.812 1833.38,603.815 1833.39,603.819 1833.4,603.823 1833.4,603.826 1833.41,603.83 1833.42,603.834 1833.43,603.838 1833.44,603.841 1833.45,603.845 1833.46,603.849 1833.47,603.853 1833.48,603.856 1833.49,603.86 1833.5,603.864 1833.51,603.867 1833.52,603.871 1833.52,603.875 1833.53,603.879 1833.54,603.882 1833.55,603.886 1833.56,603.89 1833.57,603.893 1833.58,603.897 1833.59,603.901 1833.6,603.905 1833.61,603.908 1833.62,603.912 1833.63,603.916 1833.63,603.919 1833.64,603.923 1833.65,603.927 1833.66,603.93 1833.67,603.934 1833.68,603.938 1833.69,603.941 1833.7,603.945 1833.71,603.949 1833.72,603.952 1833.73,603.956 1833.74,603.96 1833.74,603.963 1833.75,603.967 1833.76,603.971 1833.77,603.974 1833.78,603.978 1833.79,603.982 1833.8,603.985 1833.81,603.989 1833.82,603.993 1833.83,603.996 1833.84,604 1833.85,604.004 1833.86,604.007 1833.86,604.011 1833.87,604.015 1833.88,604.018 1833.89,604.022 1833.9,604.025 1833.91,604.029 1833.92,604.033 1833.93,604.036 1833.94,604.04 1833.95,604.044 1833.96,604.047 1833.97,604.051 1833.97,604.054 1833.98,604.058 1833.99,604.062 1834,604.065 1834.01,604.069 1834.02,604.073 1834.03,604.076 1834.04,604.08 1834.05,604.083 1834.06,604.087 1834.07,604.091 1834.08,604.094 1834.08,604.098 1834.09,604.101 1834.1,604.105 1834.11,604.108 1834.12,604.112 1834.13,604.116 1834.14,604.119 1834.15,604.123 1834.16,604.126 1834.17,604.13 1834.18,604.134 1834.19,604.137 1834.2,604.141 1834.2,604.144 1834.21,604.148 1834.22,604.151 1834.23,604.155 1834.24,604.159 1834.25,604.162 1834.26,604.166 1834.27,604.169 1834.28,604.173 1834.29,604.176 1834.3,604.18 1834.31,604.183 1834.31,604.187 1834.32,604.191 1834.33,604.194 1834.34,604.198 1834.35,604.201 1834.36,604.205 1834.37,604.208 1834.38,604.212 1834.39,604.215 1834.4,604.219 1834.41,604.222 1834.42,604.226 1834.42,604.229 1834.43,604.233 1834.44,604.236 1834.45,604.24 1834.46,604.243 1834.47,604.247 1834.48,604.25 1834.49,604.254 1834.5,604.258 1834.51,604.261 1834.52,604.265 1834.53,604.268 1834.54,604.272 1834.54,604.275 1834.55,604.279 1834.56,604.282 1834.57,604.286 1834.58,604.289 1834.59,604.292 1834.6,604.296 1834.61,604.299 1834.62,604.303 1834.63,604.306 1834.64,604.31 1834.65,604.313 1834.65,604.317 1834.66,604.32 1834.67,604.324 1834.68,604.327 1834.69,604.331 1834.7,604.334 1834.71,604.338 1834.72,604.341 1834.73,604.345 1834.74,604.348 1834.75,604.351 1834.76,604.355 1834.76,604.358 1834.77,604.362 1834.78,604.365 1834.79,604.369 1834.8,604.372 1834.81,604.376 1834.82,604.379 1834.83,604.383 1834.84,604.386 1834.85,604.389 1834.86,604.393 1834.87,604.396 1834.88,604.4 1834.88,604.403 1834.89,604.407 1834.9,604.41 1834.91,604.413 1834.92,604.417 1834.93,604.42 1834.94,604.424 1834.95,604.427 1834.96,604.43 1834.97,604.434 1834.98,604.437 1834.99,604.441 1834.99,604.444 1835,604.447 1835.01,604.451 1835.02,604.454 1835.03,604.458 1835.04,604.461 1835.05,604.464 1835.06,604.468 1835.07,604.471 1835.08,604.475 1835.09,604.478 1835.1,604.481 1835.1,604.485 1835.11,604.488 1835.12,604.491 1835.13,604.495 1835.14,604.498 1835.15,604.502 1835.16,604.505 1835.17,604.508 1835.18,604.512 1835.19,604.515 1835.2,604.518 1835.21,604.522 1835.22,604.525 1835.22,604.528 1835.23,604.532 1835.24,604.535 1835.25,604.538 1835.26,604.542 1835.27,604.545 1835.28,604.548 1835.29,604.552 1835.3,604.555 1835.31,604.559 1835.32,604.562 1835.33,604.565 1835.33,604.568 1835.34,604.572 1835.35,604.575 1835.36,604.578 1835.37,604.582 1835.38,604.585 1835.39,604.588 1835.4,604.592 1835.41,604.595 1835.42,604.598 1835.43,604.602 1835.44,604.605 1835.44,604.608 1835.45,604.612 1835.46,604.615 1835.47,604.618 1835.48,604.621 1835.49,604.625 1835.5,604.628 1835.51,604.631 1835.52,604.635 1835.53,604.638 1835.54,604.641 1835.55,604.644 1835.56,604.648 1835.56,604.651 1835.57,604.654 1835.58,604.658 1835.59,604.661 1835.6,604.664 1835.61,604.667 1835.62,604.671 1835.63,604.674 1835.64,604.677 1835.65,604.68 1835.66,604.684 1835.67,604.687 1835.67,604.69 1835.68,604.693 1835.69,604.697 1835.7,604.7 1835.71,604.703 1835.72,604.706 1835.73,604.71 1835.74,604.713 1835.75,604.716 1835.76,604.719 1835.77,604.723 1835.78,604.726 1835.78,604.729 1835.79,604.732 1835.8,604.735 1835.81,604.739 1835.82,604.742 1835.83,604.745 1835.84,604.748 1835.85,604.752 1835.86,604.755 1835.87,604.758 1835.88,604.761 1835.89,604.764 1835.9,604.768 1835.9,604.771 1835.91,604.774 1835.92,604.777 1835.93,604.78 1835.94,604.784 1835.95,604.787 1835.96,604.79 1835.97,604.793 1835.98,604.796 1835.99,604.8 1836,604.803 1836.01,604.806 1836.01,604.809 1836.02,604.812 1836.03,604.815 1836.04,604.819 1836.05,604.822 1836.06,604.825 1836.07,604.828 1836.08,604.831 1836.09,604.834 1836.1,604.838 1836.11,604.841 1836.12,604.844 1836.12,604.847 1836.13,604.85 1836.14,604.853 1836.15,604.856 1836.16,604.86 1836.17,604.863 1836.18,604.866 1836.19,604.869 1836.2,604.872 1836.21,604.875 1836.22,604.878 1836.23,604.882 1836.24,604.885 1836.24,604.888 1836.25,604.891 1836.26,604.894 1836.27,604.897 1836.28,604.9 1836.29,604.903 1836.3,604.906 1836.31,604.91 1836.32,604.913 1836.33,604.916 1836.34,604.919 1836.35,604.922 1836.35,604.925 1836.36,604.928 1836.37,604.931 1836.38,604.934 1836.39,604.937 1836.4,604.941 1836.41,604.944 1836.42,604.947 1836.43,604.95 1836.44,604.953 1836.45,604.956 1836.46,604.959 1836.46,604.962 1836.47,604.965 1836.48,604.968 1836.49,604.971 1836.5,604.974 1836.51,604.977 1836.52,604.981 1836.53,604.984 1836.54,604.987 1836.55,604.99 1836.56,604.993 1836.57,604.996 1836.58,604.999 1836.58,605.002 1836.59,605.005 1836.6,605.008 1836.61,605.011 1836.62,605.014 1836.63,605.017 1836.64,605.02 1836.65,605.023 1836.66,605.026 1836.67,605.029 1836.68,605.032 1836.69,605.035 1836.69,605.038 1836.7,605.041 1836.71,605.044 1836.72,605.047 1836.73,605.05 1836.74,605.053 1836.75,605.056 1836.76,605.059 1836.77,605.062 1836.78,605.065 1836.79,605.068 1836.8,605.071 1836.8,605.074 1836.81,605.077 1836.82,605.08 1836.83,605.083 1836.84,605.086 1836.85,605.089 1836.86,605.092 1836.87,605.095 1836.88,605.098 1836.89,605.101 1836.9,605.104 1836.91,605.107 1836.92,605.11 1836.92,605.113 1836.93,605.116 1836.94,605.119 1836.95,605.122 1836.96,605.125 1836.97,605.128 1836.98,605.131 1836.99,605.134 1837,605.137 1837.01,605.14 1837.02,605.143 1837.03,605.146 1837.03,605.148 1837.04,605.151 1837.05,605.154 1837.06,605.157 1837.07,605.16 1837.08,605.163 1837.09,605.166 1837.1,605.169 1837.11,605.172 1837.12,605.175 1837.13,605.178 1837.14,605.181 1837.14,605.184 1837.15,605.187 1837.16,605.189 1837.17,605.192 1837.18,605.195 1837.19,605.198 1837.2,605.201 1837.21,605.204 1837.22,605.207 1837.23,605.21 1837.24,605.213 1837.25,605.216 1837.26,605.218 1837.26,605.221 1837.27,605.224 1837.28,605.227 1837.29,605.23 1837.3,605.233 1837.31,605.236 1837.32,605.239 1837.33,605.241 1837.34,605.244 1837.35,605.247 1837.36,605.25 1837.37,605.253 1837.37,605.256 1837.38,605.259 1837.39,605.261 1837.4,605.264 1837.41,605.267 1837.42,605.27 1837.43,605.273 1837.44,605.276 1837.45,605.279 1837.46,605.281 1837.47,605.284 1837.48,605.287 1837.48,605.29 1837.49,605.293 1837.5,605.296 1837.51,605.298 1837.52,605.301 1837.53,605.304 1837.54,605.307 1837.55,605.31 1837.56,605.313 1837.57,605.315 1837.58,605.318 1837.59,605.321 1837.6,605.324 1837.6,605.327 1837.61,605.329 1837.62,605.332 1837.63,605.335 1837.64,605.338 1837.65,605.341 1837.66,605.343 1837.67,605.346 1837.68,605.349 1837.69,605.352 1837.7,605.354 1837.71,605.357 1837.71,605.36 1837.72,605.363 1837.73,605.366 1837.74,605.368 1837.75,605.371 1837.76,605.374 1837.77,605.377 1837.78,605.379 1837.79,605.382 1837.8,605.385 1837.81,605.388 1837.82,605.39 1837.82,605.393 1837.83,605.396 1837.84,605.399 1837.85,605.401 1837.86,605.404 1837.87,605.407 1837.88,605.41 1837.89,605.412 1837.9,605.415 1837.91,605.418 1837.92,605.421 1837.93,605.423 1837.94,605.426 1837.94,605.429 1837.95,605.432 1837.96,605.434 1837.97,605.437 1837.98,605.44 1837.99,605.442 1838,605.445 1838.01,605.448 1838.02,605.45 1838.03,605.453 1838.04,605.456 1838.05,605.459 1838.05,605.461 1838.06,605.464 1838.07,605.467 1838.08,605.469 1838.09,605.472 1838.1,605.475 1838.11,605.477 1838.12,605.48 1838.13,605.483 1838.14,605.485 1838.15,605.488 1838.16,605.491 1838.16,605.493 1838.17,605.496 1838.18,605.499 1838.19,605.501 1838.2,605.504 1838.21,605.507 1838.22,605.509 1838.23,605.512 1838.24,605.515 1838.25,605.517 1838.26,605.52 1838.27,605.523 1838.28,605.525 1838.28,605.528 1838.29,605.531 1838.3,605.533 1838.31,605.536 1838.32,605.538 1838.33,605.541 1838.34,605.544 1838.35,605.546 1838.36,605.549 1838.37,605.552 1838.38,605.554 1838.39,605.557 1838.39,605.559 1838.4,605.562 1838.41,605.565 1838.42,605.567 1838.43,605.57 1838.44,605.572 1838.45,605.575 1838.46,605.578 1838.47,605.58 1838.48,605.583 1838.49,605.585 1838.5,605.588 1838.5,605.591 1838.51,605.593 1838.52,605.596 1838.53,605.598 1838.54,605.601 1838.55,605.603 1838.56,605.606 1838.57,605.609 1838.58,605.611 1838.59,605.614 1838.6,605.616 1838.61,605.619 1838.62,605.621 1838.62,605.624 1838.63,605.627 1838.64,605.629 1838.65,605.632 1838.66,605.634 1838.67,605.637 1838.68,605.639 1838.69,605.642 1838.7,605.644 1838.71,605.647 1838.72,605.649 1838.73,605.652 1838.73,605.654 1838.74,605.657 1838.75,605.66 1838.76,605.662 1838.77,605.665 1838.78,605.667 1838.79,605.67 1838.8,605.672 1838.81,605.675 1838.82,605.677 1838.83,605.68 1838.84,605.682 1838.84,605.685 1838.85,605.687 1838.86,605.69 1838.87,605.692 1838.88,605.695 1838.89,605.697 1838.9,605.7 1838.91,605.702 1838.92,605.705 1838.93,605.707 1838.94,605.709 1838.95,605.712 1838.96,605.714 1838.96,605.717 1838.97,605.719 1838.98,605.722 1838.99,605.724 1839,605.727 1839.01,605.729 1839.02,605.732 1839.03,605.734 1839.04,605.737 1839.05,605.739 1839.06,605.741 1839.07,605.744 1839.07,605.746 1839.08,605.749 1839.09,605.751 1839.1,605.754 1839.11,605.756 1839.12,605.758 1839.13,605.761 1839.14,605.763 1839.15,605.766 1839.16,605.768 1839.17,605.771 1839.18,605.773 1839.18,605.775 1839.19,605.778 1839.2,605.78 1839.21,605.783 1839.22,605.785 1839.23,605.787 1839.24,605.79 1839.25,605.792 1839.26,605.795 1839.27,605.797 1839.28,605.799 1839.29,605.802 1839.3,605.804 1839.3,605.807 1839.31,605.809 1839.32,605.811 1839.33,605.814 1839.34,605.816 1839.35,605.818 1839.36,605.821 1839.37,605.823 1839.38,605.826 1839.39,605.828 1839.4,605.83 1839.41,605.833 1839.41,605.835 1839.42,605.837 1839.43,605.84 1839.44,605.842 1839.45,605.844 1839.46,605.847 1839.47,605.849 1839.48,605.851 1839.49,605.854 1839.5,605.856 1839.51,605.858 1839.52,605.861 1839.52,605.863 1839.53,605.865 1839.54,605.868 1839.55,605.87 1839.56,605.872 1839.57,605.875 1839.58,605.877 1839.59,605.879 1839.6,605.882 1839.61,605.884 1839.62,605.886 1839.63,605.888 1839.64,605.891 1839.64,605.893 1839.65,605.895 1839.66,605.898 1839.67,605.9 1839.68,605.902 1839.69,605.904 1839.7,605.907 1839.71,605.909 1839.72,605.911 1839.73,605.914 1839.74,605.916 1839.75,605.918 1839.75,605.92 1839.76,605.923 1839.77,605.925 1839.78,605.927 1839.79,605.929 1839.8,605.932 1839.81,605.934 1839.82,605.936 1839.83,605.938 1839.84,605.941 1839.85,605.943 1839.86,605.945 1839.86,605.947 1839.87,605.95 1839.88,605.952 1839.89,605.954 1839.9,605.956 1839.91,605.958 1839.92,605.961 1839.93,605.963 1839.94,605.965 1839.95,605.967 1839.96,605.97 1839.97,605.972 1839.98,605.974 1839.98,605.976 1839.99,605.978 1840,605.981 1840.01,605.983 1840.02,605.985 1840.03,605.987 1840.04,605.989 1840.05,605.992 1840.06,605.994 1840.07,605.996 1840.08,605.998 1840.09,606 1840.09,606.002 1840.1,606.005 1840.11,606.007 1840.12,606.009 1840.13,606.011 1840.14,606.013 1840.15,606.015 1840.16,606.018 1840.17,606.02 1840.18,606.022 1840.19,606.024 1840.2,606.026 1840.2,606.028 1840.21,606.03 1840.22,606.033 1840.23,606.035 1840.24,606.037 1840.25,606.039 1840.26,606.041 1840.27,606.043 1840.28,606.045 1840.29,606.048 1840.3,606.05 1840.31,606.052 1840.32,606.054 1840.32,606.056 1840.33,606.058 1840.34,606.06 1840.35,606.062 1840.36,606.064 1840.37,606.067 1840.38,606.069 1840.39,606.071 1840.4,606.073 1840.41,606.075 1840.42,606.077 1840.43,606.079 1840.43,606.081 1840.44,606.083 1840.45,606.085 1840.46,606.087 1840.47,606.09 1840.48,606.092 1840.49,606.094 1840.5,606.096 1840.51,606.098 1840.52,606.1 1840.53,606.102 1840.54,606.104 1840.54,606.106 1840.55,606.108 1840.56,606.11 1840.57,606.112 1840.58,606.114 1840.59,606.116 1840.6,606.118 1840.61,606.12 1840.62,606.122 1840.63,606.124 1840.64,606.126 1840.65,606.128 1840.66,606.13 1840.66,606.132 1840.67,606.135 1840.68,606.137 1840.69,606.139 1840.7,606.141 1840.71,606.143 1840.72,606.145 1840.73,606.147 1840.74,606.149 1840.75,606.151 1840.76,606.153 1840.77,606.155 1840.77,606.157 1840.78,606.159 1840.79,606.161 1840.8,606.163 1840.81,606.165 1840.82,606.166 1840.83,606.168 1840.84,606.17 1840.85,606.172 1840.86,606.174 1840.87,606.176 1840.88,606.178 1840.88,606.18 1840.89,606.182 1840.9,606.184 1840.91,606.186 1840.92,606.188 1840.93,606.19 1840.94,606.192 1840.95,606.194 1840.96,606.196 1840.97,606.198 1840.98,606.2 1840.99,606.202 1841,606.204 1841,606.206 1841.01,606.207 1841.02,606.209 1841.03,606.211 1841.04,606.213 1841.05,606.215 1841.06,606.217 1841.07,606.219 1841.08,606.221 1841.09,606.223 1841.1,606.225 1841.11,606.227 1841.11,606.228 1841.12,606.23 1841.13,606.232 1841.14,606.234 1841.15,606.236 1841.16,606.238 1841.17,606.24 1841.18,606.242 1841.19,606.244 1841.2,606.245 1841.21,606.247 1841.22,606.249 1841.22,606.251 1841.23,606.253 1841.24,606.255 1841.25,606.257 1841.26,606.259 1841.27,606.26 1841.28,606.262 1841.29,606.264 1841.3,606.266 1841.31,606.268 1841.32,606.27 1841.33,606.271 1841.34,606.273 1841.34,606.275 1841.35,606.277 1841.36,606.279 1841.37,606.281 1841.38,606.282 1841.39,606.284 1841.4,606.286 1841.41,606.288 1841.42,606.29 1841.43,606.292 1841.44,606.293 1841.45,606.295 1841.45,606.297 1841.46,606.299 1841.47,606.301 1841.48,606.302 1841.49,606.304 1841.5,606.306 1841.51,606.308 1841.52,606.309 1841.53,606.311 1841.54,606.313 1841.55,606.315 1841.56,606.317 1841.56,606.318 1841.57,606.32 1841.58,606.322 1841.59,606.324 1841.6,606.325 1841.61,606.327 1841.62,606.329 1841.63,606.331 1841.64,606.332 1841.65,606.334 1841.66,606.336 1841.67,606.338 1841.68,606.339 1841.68,606.341 1841.69,606.343 1841.7,606.345 1841.71,606.346 1841.72,606.348 1841.73,606.35 1841.74,606.352 1841.75,606.353 1841.76,606.355 1841.77,606.357 1841.78,606.358 1841.79,606.36 1841.79,606.362 1841.8,606.364 1841.81,606.365 1841.82,606.367 1841.83,606.369 1841.84,606.37 1841.85,606.372 1841.86,606.374 1841.87,606.375 1841.88,606.377 1841.89,606.379 1841.9,606.38 1841.9,606.382 1841.91,606.384 1841.92,606.385 1841.93,606.387 1841.94,606.389 1841.95,606.39 1841.96,606.392 1841.97,606.394 1841.98,606.395 1841.99,606.397 1842,606.399 1842.01,606.4 1842.02,606.402 1842.02,606.404 1842.03,606.405 1842.04,606.407 1842.05,606.409 1842.06,606.41 1842.07,606.412 1842.08,606.413 1842.09,606.415 1842.1,606.417 1842.11,606.418 1842.12,606.42 1842.13,606.422 1842.13,606.423 1842.14,606.425 1842.15,606.426 1842.16,606.428 1842.17,606.43 1842.18,606.431 1842.19,606.433 1842.2,606.434 1842.21,606.436 1842.22,606.438 1842.23,606.439 1842.24,606.441 1842.24,606.442 1842.25,606.444 1842.26,606.445 1842.27,606.447 1842.28,606.449 1842.29,606.45 1842.3,606.452 1842.31,606.453 1842.32,606.455 1842.33,606.456 1842.34,606.458 1842.35,606.459 1842.36,606.461 1842.36,606.463 1842.37,606.464 1842.38,606.466 1842.39,606.467 1842.4,606.469 1842.41,606.47 1842.42,606.472 1842.43,606.473 1842.44,606.475 1842.45,606.476 1842.46,606.478 1842.47,606.479 1842.47,606.481 1842.48,606.482 1842.49,606.484 1842.5,606.485 1842.51,606.487 1842.52,606.488 1842.53,606.49 1842.54,606.491 1842.55,606.493 1842.56,606.494 1842.57,606.496 1842.58,606.497 1842.58,606.499 1842.59,606.5 1842.6,606.502 1842.61,606.503 1842.62,606.505 1842.63,606.506 1842.64,606.508 1842.65,606.509 1842.66,606.511 1842.67,606.512 1842.68,606.513 1842.69,606.515 1842.7,606.516 1842.7,606.518 1842.71,606.519 1842.72,606.521 1842.73,606.522 1842.74,606.524 1842.75,606.525 1842.76,606.526 1842.77,606.528 1842.78,606.529 1842.79,606.531 1842.8,606.532 1842.81,606.534 1842.81,606.535 1842.82,606.536 1842.83,606.538 1842.84,606.539 1842.85,606.541 1842.86,606.542 1842.87,606.543 1842.88,606.545 1842.89,606.546 1842.9,606.548 1842.91,606.549 1842.92,606.55 1842.92,606.552 1842.93,606.553 1842.94,606.554 1842.95,606.556 1842.96,606.557 1842.97,606.559 1842.98,606.56 1842.99,606.561 1843,606.563 1843.01,606.564 1843.02,606.565 1843.03,606.567 1843.04,606.568 1843.04,606.569 1843.05,606.571 1843.06,606.572 1843.07,606.573 1843.08,606.575 1843.09,606.576 1843.1,606.577 1843.11,606.579 1843.12,606.58 1843.13,606.581 1843.14,606.583 1843.15,606.584 1843.15,606.585 1843.16,606.587 1843.17,606.588 1843.18,606.589 1843.19,606.59 1843.2,606.592 1843.21,606.593 1843.22,606.594 1843.23,606.596 1843.24,606.597 1843.25,606.598 1843.26,606.599 1843.26,606.601 1843.27,606.602 1843.28,606.603 1843.29,606.605 1843.3,606.606 1843.31,606.607 1843.32,606.608 1843.33,606.61 1843.34,606.611 1843.35,606.612 1843.36,606.613 1843.37,606.615 1843.38,606.616 1843.38,606.617 1843.39,606.618 1843.4,606.62 1843.41,606.621 1843.42,606.622 1843.43,606.623 1843.44,606.625 1843.45,606.626 1843.46,606.627 1843.47,606.628 1843.48,606.629 1843.49,606.631 1843.49,606.632 1843.5,606.633 1843.51,606.634 1843.52,606.635 1843.53,606.637 1843.54,606.638 1843.55,606.639 1843.56,606.64 1843.57,606.641 1843.58,606.643 1843.59,606.644 1843.6,606.645 1843.6,606.646 1843.61,606.647 1843.62,606.648 1843.63,606.65 1843.64,606.651 1843.65,606.652 1843.66,606.653 1843.67,606.654 1843.68,606.655 1843.69,606.657 1843.7,606.658 1843.71,606.659 1843.72,606.66 1843.72,606.661 1843.73,606.662 1843.74,606.663 1843.75,606.664 1843.76,606.666 1843.77,606.667 1843.78,606.668 1843.79,606.669 1843.8,606.67 1843.81,606.671 1843.82,606.672 1843.83,606.673 1843.83,606.675 1843.84,606.676 1843.85,606.677 1843.86,606.678 1843.87,606.679 1843.88,606.68 1843.89,606.681 1843.9,606.682 1843.91,606.683 1843.92,606.684 1843.93,606.685 1843.94,606.686 1843.94,606.688 1843.95,606.689 1843.96,606.69 1843.97,606.691 1843.98,606.692 1843.99,606.693 1844,606.694 1844.01,606.695 1844.02,606.696 1844.03,606.697 1844.04,606.698 1844.05,606.699 1844.06,606.7 1844.06,606.701 1844.07,606.702 1844.08,606.703 1844.09,606.704 1844.1,606.705 1844.11,606.706 1844.12,606.707 1844.13,606.708 1844.14,606.709 1844.15,606.71 1844.16,606.711 1844.17,606.712 1844.17,606.713 1844.18,606.714 1844.19,606.715 1844.2,606.716 1844.21,606.717 1844.22,606.718 1844.23,606.719 1844.24,606.72 1844.25,606.721 1844.26,606.722 1844.27,606.723 1844.28,606.724 1844.28,606.725 1844.29,606.726 1844.3,606.727 1844.31,606.728 1844.32,606.729 1844.33,606.73 1844.34,606.731 1844.35,606.732 1844.36,606.733 1844.37,606.734 1844.38,606.735 1844.39,606.736 1844.4,606.736 1844.4,606.737 1844.41,606.738 1844.42,606.739 1844.43,606.74 1844.44,606.741 1844.45,606.742 1844.46,606.743 1844.47,606.744 1844.48,606.745 1844.49,606.746 1844.5,606.746 1844.51,606.747 1844.51,606.748 1844.52,606.749 1844.53,606.75 1844.54,606.751 1844.55,606.752 1844.56,606.753 1844.57,606.754 1844.58,606.754 1844.59,606.755 1844.6,606.756 1844.61,606.757 1844.62,606.758 1844.62,606.759 1844.63,606.76 1844.64,606.76 1844.65,606.761 1844.66,606.762 1844.67,606.763 1844.68,606.764 1844.69,606.765 1844.7,606.765 1844.71,606.766 1844.72,606.767 1844.73,606.768 1844.74,606.769 1844.74,606.77 1844.75,606.77 1844.76,606.771 1844.77,606.772 1844.78,606.773 1844.79,606.774 1844.8,606.774 1844.81,606.775 1844.82,606.776 1844.83,606.777 1844.84,606.778 1844.85,606.778 1844.85,606.779 1844.86,606.78 1844.87,606.781 1844.88,606.782 1844.89,606.782 1844.9,606.783 1844.91,606.784 1844.92,606.785 1844.93,606.785 1844.94,606.786 1844.95,606.787 1844.96,606.788 1844.96,606.788 1844.97,606.789 1844.98,606.79 1844.99,606.791 1845,606.791 1845.01,606.792 1845.02,606.793 1845.03,606.794 1845.04,606.794 1845.05,606.795 1845.06,606.796 1845.07,606.796 1845.08,606.797 1845.08,606.798 1845.09,606.799 1845.1,606.799 1845.11,606.8 1845.12,606.801 1845.13,606.801 1845.14,606.802 1845.15,606.803 1845.16,606.803 1845.17,606.804 1845.18,606.805 1845.19,606.805 1845.19,606.806 1845.2,606.807 1845.21,606.807 1845.22,606.808 1845.23,606.809 1845.24,606.809 1845.25,606.81 1845.26,606.811 1845.27,606.811 1845.28,606.812 1845.29,606.813 1845.3,606.813 1845.3,606.814 1845.31,606.815 1845.32,606.815 1845.33,606.816 1845.34,606.816 1845.35,606.817 1845.36,606.818 1845.37,606.818 1845.38,606.819 1845.39,606.82 1845.4,606.82 1845.41,606.821 1845.42,606.821 1845.42,606.822 1845.43,606.823 1845.44,606.823 1845.45,606.824 1845.46,606.824 1845.47,606.825 1845.48,606.826 1845.49,606.826 1845.5,606.827 1845.51,606.827 1845.52,606.828 1845.53,606.828 1845.53,606.829 1845.54,606.829 1845.55,606.83 1845.56,606.831 1845.57,606.831 1845.58,606.832 1845.59,606.832 1845.6,606.833 1845.61,606.833 1845.62,606.834 1845.63,606.834 1845.64,606.835 1845.64,606.835 1845.65,606.836 1845.66,606.836 1845.67,606.837 1845.68,606.838 1845.69,606.838 1845.7,606.839 1845.71,606.839 1845.72,606.84 1845.73,606.84 1845.74,606.841 1845.75,606.841 1845.76,606.842 1845.76,606.842 1845.77,606.842 1845.78,606.843 1845.79,606.843 1845.8,606.844 1845.81,606.844 1845.82,606.845 1845.83,606.845 1845.84,606.846 1845.85,606.846 1845.86,606.847 1845.87,606.847 1845.87,606.848 1845.88,606.848 1845.89,606.848 1845.9,606.849 1845.91,606.849 1845.92,606.85 1845.93,606.85 1845.94,606.851 1845.95,606.851 1845.96,606.852 1845.97,606.852 1845.98,606.852 1845.98,606.853 1845.99,606.853 1846,606.854 1846.01,606.854 1846.02,606.854 1846.03,606.855 1846.04,606.855 1846.05,606.856 1846.06,606.856 1846.07,606.856 1846.08,606.857 1846.09,606.857 1846.1,606.857 1846.1,606.858 1846.11,606.858 1846.12,606.859 1846.13,606.859 1846.14,606.859 1846.15,606.86 1846.16,606.86 1846.17,606.86 1846.18,606.861 1846.19,606.861 1846.2,606.861 1846.21,606.862 1846.21,606.862 1846.22,606.862 1846.23,606.863 1846.24,606.863 1846.25,606.863 1846.26,606.864 1846.27,606.864 1846.28,606.864 1846.29,606.865 1846.3,606.865 1846.31,606.865 1846.32,606.866 1846.32,606.866 1846.33,606.866 1846.34,606.866 1846.35,606.867 1846.36,606.867 1846.37,606.867 1846.38,606.868 1846.39,606.868 1846.4,606.868 1846.41,606.868 1846.42,606.869 1846.43,606.869 1846.44,606.869 1846.44,606.869 1846.45,606.87 1846.46,606.87 1846.47,606.87 1846.48,606.87 1846.49,606.871 1846.5,606.871 1846.51,606.871 1846.52,606.871 1846.53,606.872 1846.54,606.872 1846.55,606.872 1846.55,606.872 1846.56,606.872 1846.57,606.873 1846.58,606.873 1846.59,606.873 1846.6,606.873 1846.61,606.874 1846.62,606.874 1846.63,606.874 1846.64,606.874 1846.65,606.874 1846.66,606.874 1846.66,606.875 1846.67,606.875 1846.68,606.875 1846.69,606.875 1846.7,606.875 1846.71,606.876 1846.72,606.876 1846.73,606.876 1846.74,606.876 1846.75,606.876 1846.76,606.876 1846.77,606.876 1846.78,606.877 1846.78,606.877 1846.79,606.877 1846.8,606.877 1846.81,606.877 1846.82,606.877 1846.83,606.877 1846.84,606.878 1846.85,606.878 1846.86,606.878 1846.87,606.878 1846.88,606.878 1846.89,606.878 1846.89,606.878 1846.9,606.878 1846.91,606.878 1846.92,606.878 1846.93,606.879 1846.94,606.879 1846.95,606.879 1846.96,606.879 1846.97,606.879 1846.98,606.879 1846.99,606.879 1847,606.879 1847,606.879 1847.01,606.879 1847.02,606.879 1847.03,606.879 1847.04,606.879 1847.05,606.879 1847.06,606.879 1847.07,606.88 1847.08,606.88 1847.09,606.88 1847.1,606.88 1847.11,606.88 1847.12,606.88 1847.12,606.88 1847.13,606.88 1847.14,606.88 1847.15,606.88 1847.16,606.88 1847.17,606.88 1847.18,606.88 1847.19,606.88 1847.2,606.88 1847.21,606.88 1847.22,606.88 1847.23,606.88 1847.23,606.88 1847.24,606.88 1847.25,606.88 1847.26,606.88 1847.27,606.88 1847.28,606.88 1847.29,606.88 1847.3,606.88 1847.31,606.88 1847.32,606.88 1847.33,606.88 1847.34,606.88 1847.34,606.88 1847.35,606.88 1847.36,606.88 1847.37,606.88 1847.38,606.88 1847.39,606.88 1847.4,606.88 1847.41,606.88 1847.42,606.88 1847.43,606.88 1847.44,606.88 1847.45,606.88 1847.46,606.88 1847.46,606.88 1847.47,606.88 1847.48,606.88 1847.49,606.88 1847.5,606.88 1847.51,606.88 1847.52,606.88 1847.53,606.88 1847.54,606.88 1847.55,606.88 1847.56,606.88 1847.57,606.88 1847.57,606.88 1847.58,606.88 1847.59,606.88 1847.6,606.88 1847.61,606.88 1847.62,606.88 1847.63,606.88 1847.64,606.88 1847.65,606.88 1847.66,606.88 1847.67,606.88 1847.68,606.88 1847.68,606.88 1847.69,606.88 1847.7,606.88 1847.71,606.88 1847.72,606.88 1847.73,606.88 1847.74,606.88 1847.75,606.88 1847.76,606.88 1847.77,606.88 1847.78,606.88 1847.79,606.88 1847.8,606.88 1847.8,606.88 1847.81,606.88 1847.82,606.88 1847.83,606.88 1847.84,606.88 1847.85,606.88 1847.86,606.88 1847.87,606.88 1847.88,606.88 1847.89,606.88 1847.9,606.88 1847.91,606.88 1847.91,606.88 1847.92,606.88 1847.93,606.88 1847.94,606.88 1847.95,606.88 1847.96,606.88 1847.97,606.88 1847.98,606.88 1847.99,606.88 1848,606.88 1848.01,606.88 1848.02,606.88 1848.02,606.88 1848.03,606.88 1848.04,606.88 1848.05,606.88 1848.06,606.88 1848.07,606.88 1848.08,606.88 1848.09,606.88 1848.1,606.88 1848.11,606.88 1848.12,606.88 1848.13,606.88 1848.14,606.88 1848.14,606.88 1848.15,606.88 1848.16,606.88 1848.17,606.88 1848.18,606.88 1848.19,606.88 1848.2,606.88 1848.21,606.88 1848.22,606.88 1848.23,606.88 1848.24,606.88 1848.25,606.88 1848.25,606.88 1848.26,606.88 1848.27,606.88 1848.28,606.88 1848.29,606.88 1848.3,606.88 1848.31,606.88 1848.32,606.88 1848.33,606.88 1848.34,606.88 1848.35,606.88 1848.36,606.88 1848.36,606.88 1848.37,606.88 1848.38,606.88 1848.39,606.88 1848.4,606.88 1848.41,606.88 1848.42,606.88 1848.43,606.88 1848.44,606.88 1848.45,606.88 1848.46,606.88 1848.47,606.88 1848.48,606.88 1848.48,606.88 1848.49,606.88 1848.5,606.88 1848.51,606.88 1848.52,606.88 1848.53,606.88 1848.54,606.88 1848.55,606.88 1848.56,606.88 1848.57,606.88 1848.58,606.88 1848.59,606.88 1848.59,606.88 1848.6,606.88 1848.61,606.88 1848.62,606.88 1848.63,606.88 1848.64,606.88 1848.65,606.88 1848.66,606.88 1848.67,606.88 1848.68,606.88 1848.69,606.88 1848.7,606.88 1848.7,606.88 1848.71,606.88 1848.72,606.88 1848.73,606.88 1848.74,606.88 1848.75,606.88 1848.76,606.88 1848.77,606.88 1848.78,606.88 1848.79,606.88 1848.8,606.88 1848.81,606.88 1848.82,606.88 1848.82,606.88 1848.83,606.88 1848.84,606.88 1848.85,606.88 1848.86,606.88 1848.87,606.88 1848.88,606.88 1848.89,606.88 1848.9,606.88 1848.91,606.88 1848.92,606.88 1848.93,606.88 1848.93,606.88 1848.94,606.88 1848.95,606.88 1848.96,606.88 1848.97,606.88 1848.98,606.88 1848.99,606.88 1849,606.88 1849.01,606.88 1849.02,606.88 1849.03,606.88 1849.04,606.88 1849.04,606.88 1849.05,606.88 1849.06,606.88 1849.07,606.88 1849.08,606.88 1849.09,606.88 1849.1,606.88 1849.11,606.88 1849.12,606.88 1849.13,606.88 1849.14,606.88 1849.15,606.88 1849.16,606.88 1849.16,606.88 1849.17,606.88 1849.18,606.88 1849.19,606.88 1849.2,606.88 1849.21,606.88 1849.22,606.88 1849.23,606.88 1849.24,606.88 1849.25,606.88 1849.26,606.88 1849.27,606.88 1849.27,606.88 1849.28,606.88 1849.29,606.88 1849.3,606.88 1849.31,606.88 1849.32,606.88 1849.33,606.88 1849.34,606.88 1849.35,606.88 1849.36,606.88 1849.37,606.88 1849.38,606.88 1849.38,606.88 1849.39,606.88 1849.4,606.88 1849.41,606.88 1849.42,606.88 1849.43,606.88 1849.44,606.88 1849.45,606.88 1849.46,606.88 1849.47,606.88 1849.48,606.88 1849.49,606.88 1849.5,606.88 1849.5,606.88 1849.51,606.88 1849.52,606.88 1849.53,606.88 1849.54,606.88 1849.55,606.88 1849.56,606.88 1849.57,606.88 1849.58,606.88 1849.59,606.88 1849.6,606.88 1849.61,606.88 1849.61,606.88 1849.62,606.88 1849.63,606.88 1849.64,606.88 1849.65,606.88 1849.66,606.88 1849.67,606.88 1849.68,606.88 1849.69,606.88 1849.7,606.88 1849.71,606.88 1849.72,606.88 1849.72,606.88 1849.73,606.88 1849.74,606.88 1849.75,606.88 1849.76,606.88 1849.77,606.88 1849.78,606.88 1849.79,606.88 1849.8,606.88 1849.81,606.88 1849.82,606.88 1849.83,606.88 1849.84,606.88 1849.84,606.88 1849.85,606.88 1849.86,606.88 1849.87,606.88 1849.88,606.88 1849.89,606.88 1849.9,606.88 1849.91,606.88 1849.92,606.88 1849.93,606.88 1849.94,606.88 1849.95,606.88 1849.95,606.88 1849.96,606.88 1849.97,606.88 1849.98,606.88 1849.99,606.88 1850,606.88 1850.01,606.88 1850.02,606.88 1850.03,606.88 1850.04,606.88 1850.05,606.88 1850.06,606.88 1850.06,606.88 1850.07,606.88 1850.08,606.88 1850.09,606.88 1850.1,606.88 1850.11,606.88 1850.12,606.88 1850.13,606.88 1850.14,606.88 1850.15,606.88 1850.16,606.88 1850.17,606.88 1850.18,606.88 1850.18,606.88 1850.19,606.88 1850.2,606.88 1850.21,606.88 1850.22,606.88 1850.23,606.88 1850.24,606.88 1850.25,606.88 1850.26,606.88 1850.27,606.88 1850.28,606.88 1850.29,606.88 1850.29,606.88 1850.3,606.88 1850.31,606.88 1850.32,606.88 1850.33,606.88 1850.34,606.88 1850.35,606.88 1850.36,606.88 1850.37,606.88 1850.38,606.88 1850.39,606.88 1850.4,606.88 1850.4,606.88 1850.41,606.88 1850.42,606.88 1850.43,606.88 1850.44,606.88 1850.45,606.88 1850.46,606.88 1850.47,606.88 1850.48,606.88 1850.49,606.88 1850.5,606.88 1850.51,606.88 1850.52,606.88 1850.52,606.88 1850.53,606.88 1850.54,606.88 1850.55,606.88 1850.56,606.88 1850.57,606.88 1850.58,606.88 1850.59,606.88 1850.6,606.88 1850.61,606.88 1850.62,606.88 1850.63,606.88 1850.63,606.88 1850.64,606.88 1850.65,606.88 1850.66,606.88 1850.67,606.88 1850.68,606.88 1850.69,606.88 1850.7,606.88 1850.71,606.88 1850.72,606.88 1850.73,606.88 1850.74,606.88 1850.74,606.88 1850.75,606.88 1850.76,606.88 1850.77,606.88 1850.78,606.88 1850.79,606.88 1850.8,606.88 1850.81,606.88 1850.82,606.88 1850.83,606.88 1850.84,606.88 1850.85,606.88 1850.86,606.88 1850.86,606.88 1850.87,606.88 1850.88,606.88 1850.89,606.88 1850.9,606.88 1850.91,606.88 1850.92,606.88 1850.93,606.88 1850.94,606.88 1850.95,606.88 1850.96,606.88 1850.97,606.88 1850.97,606.88 1850.98,606.88 1850.99,606.88 1851,606.88 1851.01,606.88 1851.02,606.88 1851.03,606.88 1851.04,606.88 1851.05,606.88 1851.06,606.88 1851.07,606.88 1851.08,606.88 1851.08,606.88 1851.09,606.88 1851.1,606.88 1851.11,606.88 1851.12,606.88 1851.13,606.88 1851.14,606.88 1851.15,606.88 1851.16,606.88 1851.17,606.88 1851.18,606.88 1851.19,606.88 1851.2,606.88 1851.2,606.88 1851.21,606.88 1851.22,606.88 1851.23,606.88 1851.24,606.88 1851.25,606.88 1851.26,606.88 1851.27,606.88 1851.28,606.88 1851.29,606.88 1851.3,606.88 1851.31,606.88 1851.31,606.88 1851.32,606.88 1851.33,606.88 1851.34,606.88 1851.35,606.88 1851.36,606.88 1851.37,606.88 1851.38,606.88 1851.39,606.88 1851.4,606.88 1851.41,606.88 1851.42,606.88 1851.43,606.88 1851.43,606.88 1851.44,606.88 1851.45,606.88 1851.46,606.88 1851.47,606.88 1851.48,606.88 1851.49,606.88 1851.5,606.88 1851.51,606.88 1851.52,606.88 1851.53,606.88 1851.54,606.88 1851.54,606.88 1851.55,606.88 1851.56,606.88 1851.57,606.88 1851.58,606.88 1851.59,606.88 1851.6,606.88 1851.61,606.88 1851.62,606.88 1851.63,606.88 1851.64,606.88 1851.65,606.88 1851.65,606.88 1851.66,606.88 1851.67,606.88 1851.68,606.88 1851.69,606.88 1851.7,606.88 1851.71,606.88 1851.72,606.88 1851.73,606.88 1851.74,606.88 1851.75,606.88 1851.76,606.88 1851.77,606.88 1851.77,606.88 1851.78,606.88 1851.79,606.88 1851.8,606.88 1851.81,606.88 1851.82,606.88 1851.83,606.88 1851.84,606.88 1851.85,606.88 1851.86,606.88 1851.87,606.88 1851.88,606.88 1851.88,606.88 1851.89,606.88 1851.9,606.88 1851.91,606.88 1851.92,606.88 1851.93,606.88 1851.94,606.88 1851.95,606.88 1851.96,606.88 1851.97,606.88 1851.98,606.88 1851.99,606.88 1851.99,606.88 1852,606.88 1852.01,606.88 1852.02,606.88 1852.03,606.88 1852.04,606.88 1852.05,606.88 1852.06,606.88 1852.07,606.88 1852.08,606.88 1852.09,606.88 1852.1,606.88 1852.11,606.88 1852.11,606.88 1852.12,606.88 1852.13,606.88 1852.14,606.88 1852.15,606.88 1852.16,606.88 1852.17,606.88 1852.18,606.88 1852.19,606.88 1852.2,606.88 1852.21,606.88 1852.22,606.88 1852.22,606.88 1852.23,606.88 1852.24,606.88 1852.25,606.88 1852.26,606.88 1852.27,606.88 1852.28,606.88 1852.29,606.88 1852.3,606.88 1852.31,606.88 1852.32,606.88 1852.33,606.88 1852.33,606.88 1852.34,606.88 1852.35,606.88 1852.36,606.88 1852.37,606.88 1852.38,606.88 1852.39,606.88 1852.4,606.88 1852.41,606.88 1852.42,606.88 1852.43,606.88 1852.44,606.88 1852.45,606.88 1852.45,606.88 1852.46,606.88 1852.47,606.88 1852.48,606.88 1852.49,606.88 1852.5,606.88 1852.51,606.88 1852.52,606.88 1852.53,606.88 1852.54,606.88 1852.55,606.88 1852.56,606.88 1852.56,606.88 1852.57,606.88 1852.58,606.88 1852.59,606.88 1852.6,606.88 1852.61,606.88 1852.62,606.88 1852.63,606.88 1852.64,606.88 1852.65,606.88 1852.66,606.88 1852.67,606.88 1852.67,606.88 1852.68,606.88 1852.69,606.88 1852.7,606.88 1852.71,606.88 1852.72,606.88 1852.73,606.88 1852.74,606.88 1852.75,606.88 1852.76,606.88 1852.77,606.88 1852.78,606.88 1852.79,606.88 1852.79,606.88 1852.8,606.88 1852.81,606.88 1852.82,606.88 1852.83,606.88 1852.84,606.88 1852.85,606.88 1852.86,606.88 1852.87,606.88 1852.88,606.88 1852.89,606.88 1852.9,606.88 1852.9,606.88 1852.91,606.88 1852.92,606.88 1852.93,606.88 1852.94,606.88 1852.95,606.88 1852.96,606.88 1852.97,606.88 1852.98,606.88 1852.99,606.88 1853,606.88 1853.01,606.88 1853.01,606.88 1853.02,606.88 1853.03,606.88 1853.04,606.88 1853.05,606.88 1853.06,606.88 1853.07,606.88 1853.08,606.88 1853.09,606.88 1853.1,606.88 1853.11,606.88 1853.12,606.88 1853.13,606.88 1853.13,606.88 1853.14,606.88 1853.15,606.88 1853.16,606.88 1853.17,606.88 1853.18,606.88 1853.19,606.88 1853.2,606.88 1853.21,606.88 1853.22,606.88 1853.23,606.88 1853.24,606.88 1853.24,606.88 1853.25,606.88 1853.26,606.88 1853.27,606.88 1853.28,606.88 1853.29,606.88 1853.3,606.88 1853.31,606.88 1853.32,606.88 1853.33,606.88 1853.34,606.88 1853.35,606.88 1853.35,606.88 1853.36,606.88 1853.37,606.88 1853.38,606.88 1853.39,606.88 1853.4,606.88 1853.41,606.88 1853.42,606.88 1853.43,606.88 1853.44,606.88 1853.45,606.88 1853.46,606.88 1853.47,606.88 1853.47,606.88 1853.48,606.88 1853.49,606.88 1853.5,606.88 1853.51,606.88 1853.52,606.88 1853.53,606.88 1853.54,606.88 1853.55,606.88 1853.56,606.88 1853.57,606.88 1853.58,606.88 1853.58,606.88 1853.59,606.88 1853.6,606.88 1853.61,606.88 1853.62,606.88 1853.63,606.88 1853.64,606.88 1853.65,606.88 1853.66,606.88 1853.67,606.88 1853.68,606.88 1853.69,606.88 1853.69,606.88 1853.7,606.88 1853.71,606.88 1853.72,606.88 1853.73,606.88 1853.74,606.88 1853.75,606.88 1853.76,606.88 1853.77,606.88 1853.78,606.88 1853.79,606.88 1853.8,606.88 1853.81,606.88 1853.81,606.88 1853.82,606.88 1853.83,606.88 1853.84,606.88 1853.85,606.88 1853.86,606.88 1853.87,606.88 1853.88,606.88 1853.89,606.88 1853.9,606.88 1853.91,606.88 1853.92,606.88 1853.92,606.88 1853.93,606.88 1853.94,606.88 1853.95,606.88 1853.96,606.88 1853.97,606.88 1853.98,606.88 1853.99,606.88 1854,606.88 1854.01,606.88 1854.02,606.88 1854.03,606.88 1854.03,606.88 1854.04,606.88 1854.05,606.88 1854.06,606.88 1854.07,606.88 1854.08,606.88 1854.09,606.88 1854.1,606.88 1854.11,606.88 1854.12,606.88 1854.13,606.88 1854.14,606.88 1854.15,606.88 1854.15,606.88 1854.16,606.88 1854.17,606.88 1854.18,606.88 1854.19,606.88 1854.2,606.88 1854.21,606.88 1854.22,606.88 1854.23,606.88 1854.24,606.88 1854.25,606.88 1854.26,606.88 1854.26,606.88 1854.27,606.88 1854.28,606.88 1854.29,606.88 1854.3,606.88 1854.31,606.88 1854.32,606.88 1854.33,606.88 1854.34,606.88 1854.35,606.88 1854.36,606.88 1854.37,606.88 1854.37,606.88 1854.38,606.88 1854.39,606.88 1854.4,606.88 1854.41,606.88 1854.42,606.88 1854.43,606.88 1854.44,606.88 1854.45,606.88 1854.46,606.88 1854.47,606.88 1854.48,606.88 1854.49,606.88 1854.49,606.88 1854.5,606.88 1854.51,606.88 1854.52,606.88 1854.53,606.88 1854.54,606.88 1854.55,606.88 1854.56,606.88 1854.57,606.88 1854.58,606.88 1854.59,606.88 1854.6,606.88 1854.6,606.88 1854.61,606.88 1854.62,606.88 1854.63,606.88 1854.64,606.88 1854.65,606.88 1854.66,606.88 1854.67,606.88 1854.68,606.88 1854.69,606.88 1854.7,606.88 1854.71,606.88 1854.71,606.88 1854.72,606.88 1854.73,606.88 1854.74,606.88 1854.75,606.88 1854.76,606.88 1854.77,606.88 1854.78,606.88 1854.79,606.88 1854.8,606.88 1854.81,606.88 1854.82,606.88 1854.83,606.88 1854.83,606.88 1854.84,606.88 1854.85,606.88 1854.86,606.88 1854.87,606.88 1854.88,606.88 1854.89,606.88 1854.9,606.88 1854.91,606.88 1854.92,606.88 1854.93,606.88 1854.94,606.88 1854.94,606.88 1854.95,606.88 1854.96,606.88 1854.97,606.88 1854.98,606.88 1854.99,606.88 1855,606.88 1855.01,606.88 1855.02,606.88 1855.03,606.88 1855.04,606.88 1855.05,606.88 1855.05,606.88 1855.06,606.88 1855.07,606.88 1855.08,606.88 1855.09,606.88 1855.1,606.88 1855.11,606.88 1855.12,606.88 1855.13,606.88 1855.14,606.88 1855.15,606.88 1855.16,606.88 1855.17,606.88 1855.17,606.88 1855.18,606.88 1855.19,606.88 1855.2,606.88 1855.21,606.88 1855.22,606.88 1855.23,606.88 1855.24,606.88 1855.25,606.88 1855.26,606.88 1855.27,606.88 1855.28,606.88 1855.28,606.88 1855.29,606.88 1855.3,606.88 1855.31,606.88 1855.32,606.88 1855.33,606.88 1855.34,606.88 1855.35,606.88 1855.36,606.88 1855.37,606.88 1855.38,606.88 1855.39,606.88 1855.39,606.88 1855.4,606.88 1855.41,606.88 1855.42,606.88 1855.43,606.88 1855.44,606.88 1855.45,606.88 1855.46,606.88 1855.47,606.88 1855.48,606.88 1855.49,606.88 1855.5,606.88 1855.51,606.88 1855.51,606.88 1855.52,606.88 1855.53,606.88 1855.54,606.88 1855.55,606.88 1855.56,606.88 1855.57,606.88 1855.58,606.88 1855.59,606.88 1855.6,606.88 1855.61,606.88 1855.62,606.88 1855.62,606.88 1855.63,606.88 1855.64,606.88 1855.65,606.88 1855.66,606.88 1855.67,606.88 1855.68,606.88 1855.69,606.88 1855.7,606.88 1855.71,606.88 1855.72,606.88 1855.73,606.88 1855.73,606.88 1855.74,606.88 1855.75,606.88 1855.76,606.88 1855.77,606.88 1855.78,606.88 1855.79,606.88 1855.8,606.88 1855.81,606.88 1855.82,606.88 1855.83,606.88 1855.84,606.88 1855.85,606.88 1855.85,606.88 1855.86,606.88 1855.87,606.88 1855.88,606.88 1855.89,606.88 1855.9,606.88 1855.91,606.88 1855.92,606.88 1855.93,606.88 1855.94,606.88 1855.95,606.88 1855.96,606.88 1855.96,606.88 1855.97,606.88 1855.98,606.88 1855.99,606.88 1856,606.88 1856.01,606.88 1856.02,606.88 1856.03,606.88 1856.04,606.88 1856.05,606.88 1856.06,606.88 1856.07,606.88 1856.07,606.88 1856.08,606.88 1856.09,606.88 1856.1,606.88 1856.11,606.88 1856.12,606.88 1856.13,606.88 1856.14,606.88 1856.15,606.88 1856.16,606.88 1856.17,606.88 1856.18,606.88 1856.19,606.88 1856.19,606.88 1856.2,606.88 1856.21,606.88 1856.22,606.88 1856.23,606.88 1856.24,606.88 1856.25,606.88 1856.26,606.88 1856.27,606.88 1856.28,606.88 1856.29,606.88 1856.3,606.88 1856.3,606.88 1856.31,606.88 1856.32,606.88 1856.33,606.88 1856.34,606.88 1856.35,606.88 1856.36,606.88 1856.37,606.88 1856.38,606.88 1856.39,606.88 1856.4,606.88 1856.41,606.88 1856.41,606.88 1856.42,606.88 1856.43,606.88 1856.44,606.88 1856.45,606.88 1856.46,606.88 1856.47,606.88 1856.48,606.88 1856.49,606.88 1856.5,606.88 1856.51,606.88 1856.52,606.88 1856.53,606.88 1856.53,606.88 1856.54,606.88 1856.55,606.88 1856.56,606.88 1856.57,606.88 1856.58,606.88 1856.59,606.88 1856.6,606.88 1856.61,606.88 1856.62,606.88 1856.63,606.88 1856.64,606.88 1856.64,606.88 1856.65,606.88 1856.66,606.88 1856.67,606.88 1856.68,606.88 1856.69,606.88 1856.7,606.88 1856.71,606.88 1856.72,606.88 1856.73,606.88 1856.74,606.88 1856.75,606.88 1856.75,606.88 1856.76,606.88 1856.77,606.88 1856.78,606.88 1856.79,606.88 1856.8,606.88 1856.81,606.88 1856.82,606.88 1856.83,606.88 1856.84,606.88 1856.85,606.88 1856.86,606.88 1856.87,606.88 1856.87,606.88 1856.88,606.88 1856.89,606.88 1856.9,606.88 1856.91,606.88 1856.92,606.88 1856.93,606.88 1856.94,606.88 1856.95,606.88 1856.96,606.88 1856.97,606.88 1856.98,606.88 1856.98,606.88 1856.99,606.88 1857,606.88 1857.01,606.88 1857.02,606.88 1857.03,606.88 1857.04,606.88 1857.05,606.88 1857.06,606.88 1857.07,606.88 1857.08,606.88 1857.09,606.88 1857.09,606.88 1857.1,606.88 1857.11,606.88 1857.12,606.88 1857.13,606.88 1857.14,606.88 1857.15,606.88 1857.16,606.88 1857.17,606.88 1857.18,606.88 1857.19,606.88 1857.2,606.88 1857.21,606.88 1857.21,606.88 1857.22,606.88 1857.23,606.88 1857.24,606.88 1857.25,606.88 1857.26,606.88 1857.27,606.88 1857.28,606.88 1857.29,606.88 1857.3,606.88 1857.31,606.88 1857.32,606.88 1857.32,606.88 1857.33,606.88 1857.34,606.88 1857.35,606.88 1857.36,606.88 1857.37,606.88 1857.38,606.88 1857.39,606.88 1857.4,606.88 1857.41,606.88 1857.42,606.88 1857.43,606.88 1857.43,606.88 1857.44,606.88 1857.45,606.88 1857.46,606.88 1857.47,606.88 1857.48,606.88 1857.49,606.88 1857.5,606.88 1857.51,606.88 1857.52,606.88 1857.53,606.88 1857.54,606.88 1857.55,606.88 1857.55,606.88 1857.56,606.88 1857.57,606.88 1857.58,606.88 1857.59,606.88 1857.6,606.88 1857.61,606.88 1857.62,606.88 1857.63,606.88 1857.64,606.88 1857.65,606.88 1857.66,606.88 1857.66,606.88 1857.67,606.88 1857.68,606.88 1857.69,606.88 1857.7,606.88 1857.71,606.88 1857.72,606.88 1857.73,606.88 1857.74,606.88 1857.75,606.88 1857.76,606.88 1857.77,606.88 1857.77,606.88 1857.78,606.88 1857.79,606.88 1857.8,606.88 1857.81,606.88 1857.82,606.88 1857.83,606.88 1857.84,606.88 1857.85,606.88 1857.86,606.88 1857.87,606.88 1857.88,606.88 1857.89,606.88 1857.89,606.88 1857.9,606.88 1857.91,606.88 1857.92,606.88 1857.93,606.88 1857.94,606.88 1857.95,606.88 1857.96,606.88 1857.97,606.88 1857.98,606.88 1857.99,606.88 1858,606.88 1858,606.88 1858.01,606.88 1858.02,606.88 1858.03,606.88 1858.04,606.88 1858.05,606.88 1858.06,606.88 1858.07,606.88 1858.08,606.88 1858.09,606.88 1858.1,606.88 1858.11,606.88 1858.11,606.88 1858.12,606.88 1858.13,606.88 1858.14,606.88 1858.15,606.88 1858.16,606.88 1858.17,606.88 1858.18,606.88 1858.19,606.88 1858.2,606.88 1858.21,606.88 1858.22,606.88 1858.23,606.88 1858.23,606.88 1858.24,606.88 1858.25,606.88 1858.26,606.88 1858.27,606.88 1858.28,606.88 1858.29,606.88 1858.3,606.88 1858.31,606.88 1858.32,606.88 1858.33,606.88 1858.34,606.88 1858.34,606.88 1858.35,606.88 1858.36,606.88 1858.37,606.88 1858.38,606.88 1858.39,606.88 1858.4,606.88 1858.41,606.88 1858.42,606.88 1858.43,606.88 1858.44,606.88 1858.45,606.88 1858.45,606.88 1858.46,606.88 1858.47,606.88 1858.48,606.88 1858.49,606.88 1858.5,606.88 1858.51,606.88 1858.52,606.88 1858.53,606.88 1858.54,606.88 1858.55,606.88 1858.56,606.88 1858.57,606.88 1858.57,606.88 1858.58,606.88 1858.59,606.88 1858.6,606.88 1858.61,606.88 1858.62,606.88 1858.63,606.88 1858.64,606.88 1858.65,606.88 1858.66,606.88 1858.67,606.88 1858.68,606.88 1858.68,606.88 1858.69,606.88 1858.7,606.88 1858.71,606.88 1858.72,606.88 1858.73,606.88 1858.74,606.88 1858.75,606.88 1858.76,606.88 1858.77,606.88 1858.78,606.88 1858.79,606.88 1858.79,606.88 1858.8,606.88 1858.81,606.88 1858.82,606.88 1858.83,606.88 1858.84,606.88 1858.85,606.88 1858.86,606.88 1858.87,606.88 1858.88,606.88 1858.89,606.88 1858.9,606.88 1858.91,606.88 1858.91,606.88 1858.92,606.88 1858.93,606.88 1858.94,606.88 1858.95,606.88 1858.96,606.88 1858.97,606.88 1858.98,606.88 1858.99,606.88 1859,606.88 1859.01,606.88 1859.02,606.88 1859.02,606.88 1859.03,606.88 1859.04,606.88 1859.05,606.88 1859.06,606.88 1859.07,606.88 1859.08,606.88 1859.09,606.88 1859.1,606.88 1859.11,606.88 1859.12,606.88 1859.13,606.88 1859.13,606.88 1859.14,606.88 1859.15,606.88 1859.16,606.88 1859.17,606.88 1859.18,606.88 1859.19,606.88 1859.2,606.88 1859.21,606.88 1859.22,606.88 1859.23,606.88 1859.24,606.88 1859.25,606.88 1859.25,606.88 1859.26,606.88 1859.27,606.88 1859.28,606.88 1859.29,606.88 1859.3,606.88 1859.31,606.88 1859.32,606.88 1859.33,606.88 1859.34,606.88 1859.35,606.88 1859.36,606.88 1859.36,606.88 1859.37,606.88 1859.38,606.88 1859.39,606.88 1859.4,606.88 1859.41,606.88 1859.42,606.88 1859.43,606.88 1859.44,606.88 1859.45,606.88 1859.46,606.88 1859.47,606.88 1859.47,606.88 1859.48,606.88 1859.49,606.88 1859.5,606.88 1859.51,606.88 1859.52,606.88 1859.53,606.88 1859.54,606.88 1859.55,606.88 1859.56,606.88 1859.57,606.88 1859.58,606.88 1859.59,606.88 1859.59,606.88 1859.6,606.88 1859.61,606.88 1859.62,606.88 1859.63,606.88 1859.64,606.88 1859.65,606.88 1859.66,606.88 1859.67,606.88 1859.68,606.88 1859.69,606.88 1859.7,606.88 1859.7,606.88 1859.71,606.88 1859.72,606.88 1859.73,606.88 1859.74,606.88 1859.75,606.88 1859.76,606.88 1859.77,606.88 1859.78,606.88 1859.79,606.88 1859.8,606.88 1859.81,606.88 1859.81,606.88 1859.82,606.88 1859.83,606.88 1859.84,606.88 1859.85,606.88 1859.86,606.88 1859.87,606.88 1859.88,606.88 1859.89,606.88 1859.9,606.88 1859.91,606.88 1859.92,606.88 1859.93,606.88 1859.93,606.88 1859.94,606.88 1859.95,606.88 1859.96,606.88 1859.97,606.88 1859.98,606.88 1859.99,606.88 1860,606.88 1860.01,606.88 1860.02,606.88 1860.03,606.88 1860.04,606.88 1860.04,606.88 1860.05,606.88 1860.06,606.88 1860.07,606.88 1860.08,606.88 1860.09,606.88 1860.1,606.88 1860.11,606.88 1860.12,606.88 1860.13,606.88 1860.14,606.88 1860.15,606.88 1860.15,606.88 1860.16,606.88 1860.17,606.88 1860.18,606.88 1860.19,606.88 1860.2,606.88 1860.21,606.88 1860.22,606.88 1860.23,606.88 1860.24,606.88 1860.25,606.88 1860.26,606.88 1860.27,606.88 1860.27,606.88 1860.28,606.88 1860.29,606.88 1860.3,606.88 1860.31,606.88 1860.32,606.88 1860.33,606.88 1860.34,606.88 1860.35,606.88 1860.36,606.88 1860.37,606.88 1860.38,606.88 1860.38,606.88 1860.39,606.88 1860.4,606.88 1860.41,606.88 1860.42,606.88 1860.43,606.88 1860.44,606.88 1860.45,606.88 1860.46,606.88 1860.47,606.88 1860.48,606.88 1860.49,606.88 1860.49,606.88 1860.5,606.88 1860.51,606.88 1860.52,606.88 1860.53,606.88 1860.54,606.88 1860.55,606.88 1860.56,606.88 1860.57,606.88 1860.58,606.88 1860.59,606.88 1860.6,606.88 1860.61,606.88 1860.61,606.88 1860.62,606.88 1860.63,606.88 1860.64,606.88 1860.65,606.88 1860.66,606.88 1860.67,606.88 1860.68,606.88 1860.69,606.88 1860.7,606.88 1860.71,606.88 1860.72,606.88 1860.72,606.88 1860.73,606.88 1860.74,606.88 1860.75,606.88 1860.76,606.88 1860.77,606.88 1860.78,606.88 1860.79,606.88 1860.8,606.88 1860.81,606.88 1860.82,606.88 1860.83,606.88 1860.83,606.88 1860.84,606.88 1860.85,606.88 1860.86,606.88 1860.87,606.88 1860.88,606.88 1860.89,606.88 1860.9,606.88 1860.91,606.88 1860.92,606.88 1860.93,606.88 1860.94,606.88 1860.95,606.88 1860.95,606.88 1860.96,606.88 1860.97,606.88 1860.98,606.88 1860.99,606.88 1861,606.88 1861.01,606.88 1861.02,606.88 1861.03,606.88 1861.04,606.88 1861.05,606.88 1861.06,606.88 1861.06,606.88 1861.07,606.88 1861.08,606.88 1861.09,606.88 1861.1,606.88 1861.11,606.88 1861.12,606.88 1861.13,606.88 1861.14,606.88 1861.15,606.88 1861.16,606.88 1861.17,606.88 1861.17,606.88 1861.18,606.88 1861.19,606.88 1861.2,606.88 1861.21,606.88 1861.22,606.88 1861.23,606.88 1861.24,606.88 1861.25,606.88 1861.26,606.88 1861.27,606.88 1861.28,606.88 1861.29,606.88 1861.29,606.88 1861.3,606.88 1861.31,606.88 1861.32,606.88 1861.33,606.88 1861.34,606.88 1861.35,606.88 1861.36,606.88 1861.37,606.88 1861.38,606.88 1861.39,606.88 1861.4,606.88 1861.4,606.88 1861.41,606.88 1861.42,606.88 1861.43,606.88 1861.44,606.88 1861.45,606.88 1861.46,606.88 1861.47,606.88 1861.48,606.88 1861.49,606.88 1861.5,606.88 1861.51,606.88 1861.51,606.88 1861.52,606.88 1861.53,606.88 1861.54,606.88 1861.55,606.88 1861.56,606.88 1861.57,606.88 1861.58,606.88 1861.59,606.88 1861.6,606.88 1861.61,606.88 1861.62,606.88 1861.63,606.88 1861.63,606.88 1861.64,606.88 1861.65,606.88 1861.66,606.88 1861.67,606.88 1861.68,606.88 1861.69,606.88 1861.7,606.88 1861.71,606.88 1861.72,606.88 1861.73,606.88 1861.74,606.88 1861.74,606.88 1861.75,606.88 1861.76,606.88 1861.77,606.88 1861.78,606.88 1861.79,606.88 1861.8,606.88 1861.81,606.88 1861.82,606.88 1861.83,606.88 1861.84,606.88 1861.85,606.88 1861.85,606.88 1861.86,606.88 1861.87,606.88 1861.88,606.88 1861.89,606.88 1861.9,606.88 1861.91,606.88 1861.92,606.88 1861.93,606.88 1861.94,606.88 1861.95,606.88 1861.96,606.88 1861.97,606.88 1861.97,606.88 1861.98,606.88 1861.99,606.88 1862,606.88 1862.01,606.88 1862.02,606.88 1862.03,606.88 1862.04,606.88 1862.05,606.88 1862.06,606.88 1862.07,606.88 1862.08,606.88 1862.08,606.88 1862.09,606.88 1862.1,606.88 1862.11,606.88 1862.12,606.88 1862.13,606.88 1862.14,606.88 1862.15,606.88 1862.16,606.88 1862.17,606.88 1862.18,606.88 1862.19,606.88 1862.19,606.88 1862.2,606.88 1862.21,606.88 1862.22,606.88 1862.23,606.88 1862.24,606.88 1862.25,606.88 1862.26,606.88 1862.27,606.88 1862.28,606.88 1862.29,606.88 1862.3,606.88 1862.31,606.88 1862.31,606.88 1862.32,606.88 1862.33,606.88 1862.34,606.88 1862.35,606.88 1862.36,606.88 1862.37,606.88 1862.38,606.88 1862.39,606.88 1862.4,606.88 1862.41,606.88 1862.42,606.88 1862.42,606.88 1862.43,606.88 1862.44,606.88 1862.45,606.88 1862.46,606.88 1862.47,606.88 1862.48,606.88 1862.49,606.88 1862.5,606.88 1862.51,606.88 1862.52,606.88 1862.53,606.88 1862.53,606.88 1862.54,606.88 1862.55,606.88 1862.56,606.88 1862.57,606.88 1862.58,606.88 1862.59,606.88 1862.6,606.88 1862.61,606.88 1862.62,606.88 1862.63,606.88 1862.64,606.88 1862.65,606.88 1862.65,606.88 1862.66,606.88 1862.67,606.88 1862.68,606.88 1862.69,606.88 1862.7,606.88 1862.71,606.88 1862.72,606.88 1862.73,606.88 1862.74,606.88 1862.75,606.88 1862.76,606.88 1862.76,606.88 1862.77,606.88 1862.78,606.88 1862.79,606.88 1862.8,606.88 1862.81,606.88 1862.82,606.88 1862.83,606.88 1862.84,606.88 1862.85,606.88 1862.86,606.88 1862.87,606.88 1862.87,606.88 1862.88,606.88 1862.89,606.88 1862.9,606.88 1862.91,606.88 1862.92,606.88 1862.93,606.88 1862.94,606.88 1862.95,606.88 1862.96,606.88 1862.97,606.88 1862.98,606.88 1862.99,606.88 1862.99,606.88 1863,606.88 1863.01,606.88 1863.02,606.88 1863.03,606.88 1863.04,606.88 1863.05,606.88 1863.06,606.88 1863.07,606.88 1863.08,606.88 1863.09,606.88 1863.1,606.88 1863.1,606.88 1863.11,606.88 1863.12,606.88 1863.13,606.88 1863.14,606.88 1863.15,606.88 1863.16,606.88 1863.17,606.88 1863.18,606.88 1863.19,606.88 1863.2,606.88 1863.21,606.88 1863.21,606.88 1863.22,606.88 1863.23,606.88 1863.24,606.88 1863.25,606.88 1863.26,606.88 1863.27,606.88 1863.28,606.88 1863.29,606.88 1863.3,606.88 1863.31,606.88 1863.32,606.88 1863.33,606.88 1863.33,606.88 1863.34,606.88 1863.35,606.88 1863.36,606.88 1863.37,606.88 1863.38,606.88 1863.39,606.88 1863.4,606.88 1863.41,606.88 1863.42,606.88 1863.43,606.88 1863.44,606.88 1863.44,606.88 1863.45,606.88 1863.46,606.88 1863.47,606.88 1863.48,606.88 1863.49,606.88 1863.5,606.88 1863.51,606.88 1863.52,606.88 1863.53,606.88 1863.54,606.88 1863.55,606.88 1863.55,606.88 1863.56,606.88 1863.57,606.88 1863.58,606.88 1863.59,606.88 1863.6,606.88 1863.61,606.88 1863.62,606.88 1863.63,606.88 1863.64,606.88 1863.65,606.88 1863.66,606.88 1863.67,606.88 1863.67,606.88 1863.68,606.88 1863.69,606.88 1863.7,606.88 1863.71,606.88 1863.72,606.88 1863.73,606.88 1863.74,606.88 1863.75,606.88 1863.76,606.88 1863.77,606.88 1863.78,606.88 1863.78,606.88 1863.79,606.88 1863.8,606.88 1863.81,606.88 1863.82,606.88 1863.83,606.88 1863.84,606.88 1863.85,606.88 1863.86,606.88 1863.87,606.88 1863.88,606.88 1863.89,606.88 1863.89,606.88 1863.9,606.88 1863.91,606.88 1863.92,606.88 1863.93,606.88 1863.94,606.88 1863.95,606.88 1863.96,606.88 1863.97,606.88 1863.98,606.88 1863.99,606.88 1864,606.88 1864.01,606.88 1864.01,606.88 1864.02,606.88 1864.03,606.88 1864.04,606.88 1864.05,606.88 1864.06,606.88 1864.07,606.88 1864.08,606.88 1864.09,606.88 1864.1,606.88 1864.11,606.88 1864.12,606.88 1864.12,606.88 1864.13,606.88 1864.14,606.88 1864.15,606.88 1864.16,606.88 1864.17,606.88 1864.18,606.88 1864.19,606.88 1864.2,606.88 1864.21,606.88 1864.22,606.88 1864.23,606.88 1864.23,606.88 1864.24,606.88 1864.25,606.88 1864.26,606.88 1864.27,606.88 1864.28,606.88 1864.29,606.88 1864.3,606.88 1864.31,606.88 1864.32,606.88 1864.33,606.88 1864.34,606.88 1864.35,606.88 1864.35,606.88 1864.36,606.88 1864.37,606.88 1864.38,606.88 1864.39,606.88 1864.4,606.88 1864.41,606.88 1864.42,606.88 1864.43,606.88 1864.44,606.88 1864.45,606.88 1864.46,606.88 1864.46,606.88 1864.47,606.88 1864.48,606.88 1864.49,606.88 1864.5,606.88 1864.51,606.88 1864.52,606.88 1864.53,606.88 1864.54,606.88 1864.55,606.88 1864.56,606.88 1864.57,606.88 1864.57,606.88 1864.58,606.88 1864.59,606.88 1864.6,606.88 1864.61,606.88 1864.62,606.88 1864.63,606.88 1864.64,606.88 1864.65,606.88 1864.66,606.88 1864.67,606.88 1864.68,606.88 1864.69,606.88 1864.69,606.88 1864.7,606.88 1864.71,606.88 1864.72,606.88 1864.73,606.88 1864.74,606.88 1864.75,606.88 1864.76,606.88 1864.77,606.88 1864.78,606.88 1864.79,606.88 1864.8,606.88 1864.8,606.88 1864.81,606.88 1864.82,606.88 1864.83,606.88 1864.84,606.88 1864.85,606.88 1864.86,606.88 1864.87,606.88 1864.88,606.88 1864.89,606.88 1864.9,606.88 1864.91,606.88 1864.91,606.88 1864.92,606.88 1864.93,606.88 1864.94,606.88 1864.95,606.88 1864.96,606.88 1864.97,606.88 1864.98,606.88 1864.99,606.88 1865,606.88 1865.01,606.88 1865.02,606.88 1865.03,606.88 1865.03,606.88 1865.04,606.88 1865.05,606.88 1865.06,606.88 1865.07,606.88 1865.08,606.88 1865.09,606.88 1865.1,606.88 1865.11,606.88 1865.12,606.88 1865.13,606.88 1865.14,606.88 1865.14,606.88 1865.15,606.88 1865.16,606.88 1865.17,606.88 1865.18,606.88 1865.19,606.88 1865.2,606.88 1865.21,606.88 1865.22,606.88 1865.23,606.88 1865.24,606.88 1865.25,606.88 1865.25,606.88 1865.26,606.88 1865.27,606.88 1865.28,606.88 1865.29,606.88 1865.3,606.88 1865.31,606.88 1865.32,606.88 1865.33,606.88 1865.34,606.88 1865.35,606.88 1865.36,606.88 1865.37,606.88 1865.37,606.88 1865.38,606.88 1865.39,606.88 1865.4,606.88 1865.41,606.88 1865.42,606.88 1865.43,606.88 1865.44,606.88 1865.45,606.88 1865.46,606.88 1865.47,606.88 1865.48,606.88 1865.48,606.88 1865.49,606.88 1865.5,606.88 1865.51,606.88 1865.52,606.88 1865.53,606.88 1865.54,606.88 1865.55,606.88 1865.56,606.88 1865.57,606.88 1865.58,606.88 1865.59,606.88 1865.59,606.88 1865.6,606.88 1865.61,606.88 1865.62,606.88 1865.63,606.88 1865.64,606.88 1865.65,606.88 1865.66,606.88 1865.67,606.88 1865.68,606.88 1865.69,606.88 1865.7,606.88 1865.71,606.88 1865.71,606.88 1865.72,606.88 1865.73,606.88 1865.74,606.88 1865.75,606.88 1865.76,606.88 1865.77,606.88 1865.78,606.88 1865.79,606.88 1865.8,606.88 1865.81,606.88 1865.82,606.88 1865.82,606.88 1865.83,606.88 1865.84,606.88 1865.85,606.88 1865.86,606.88 1865.87,606.88 1865.88,606.88 1865.89,606.88 1865.9,606.88 1865.91,606.88 1865.92,606.88 1865.93,606.88 1865.93,606.88 1865.94,606.88 1865.95,606.88 1865.96,606.88 1865.97,606.88 1865.98,606.88 1865.99,606.88 1866,606.88 1866.01,606.88 1866.02,606.88 1866.03,606.88 1866.04,606.88 1866.05,606.88 1866.05,606.88 1866.06,606.88 1866.07,606.88 1866.08,606.88 1866.09,606.88 1866.1,606.88 1866.11,606.88 1866.12,606.88 1866.13,606.88 1866.14,606.88 1866.15,606.88 1866.16,606.88 1866.16,606.88 1866.17,606.88 1866.18,606.88 1866.19,606.88 1866.2,606.88 1866.21,606.88 1866.22,606.88 1866.23,606.88 1866.24,606.88 1866.25,606.88 1866.26,606.88 1866.27,606.88 1866.27,606.88 1866.28,606.88 1866.29,606.88 1866.3,606.88 1866.31,606.88 1866.32,606.88 1866.33,606.88 1866.34,606.88 1866.35,606.88 1866.36,606.88 1866.37,606.88 1866.38,606.88 1866.39,606.88 1866.39,606.88 1866.4,606.88 1866.41,606.88 1866.42,606.88 1866.43,606.88 1866.44,606.88 1866.45,606.88 1866.46,606.88 1866.47,606.88 1866.48,606.88 1866.49,606.88 1866.5,606.88 1866.5,606.88 1866.51,606.88 1866.52,606.88 1866.53,606.88 1866.54,606.88 1866.55,606.88 1866.56,606.88 1866.57,606.88 1866.58,606.88 1866.59,606.88 1866.6,606.88 1866.61,606.88 1866.61,606.88 1866.62,606.88 1866.63,606.88 1866.64,606.88 1866.65,606.88 1866.66,606.88 1866.67,606.88 1866.68,606.88 1866.69,606.88 1866.7,606.88 1866.71,606.88 1866.72,606.88 1866.73,606.88 1866.73,606.88 1866.74,606.88 1866.75,606.88 1866.76,606.88 1866.77,606.88 1866.78,606.88 1866.79,606.88 1866.8,606.88 1866.81,606.88 1866.82,606.88 1866.83,606.88 1866.84,606.88 1866.84,606.88 1866.85,606.88 1866.86,606.88 1866.87,606.88 1866.88,606.88 1866.89,606.88 1866.9,606.88 1866.91,606.88 1866.92,606.88 1866.93,606.88 1866.94,606.88 1866.95,606.88 1866.95,606.88 1866.96,606.88 1866.97,606.88 1866.98,606.88 1866.99,606.88 1867,606.88 1867.01,606.88 1867.02,606.88 1867.03,606.88 1867.04,606.88 1867.05,606.88 1867.06,606.88 1867.07,606.88 1867.07,606.88 1867.08,606.88 1867.09,606.88 1867.1,606.88 1867.11,606.88 1867.12,606.88 1867.13,606.88 1867.14,606.88 1867.15,606.88 1867.16,606.88 1867.17,606.88 1867.18,606.88 1867.18,606.88 1867.19,606.88 1867.2,606.88 1867.21,606.88 1867.22,606.88 1867.23,606.88 1867.24,606.88 1867.25,606.88 1867.26,606.88 1867.27,606.88 1867.28,606.88 1867.29,606.88 1867.29,606.88 1867.3,606.88 1867.31,606.88 1867.32,606.88 1867.33,606.88 1867.34,606.88 1867.35,606.88 1867.36,606.88 1867.37,606.88 1867.38,606.88 1867.39,606.88 1867.4,606.88 1867.41,606.88 1867.41,606.88 1867.42,606.88 1867.43,606.88 1867.44,606.88 1867.45,606.88 1867.46,606.88 1867.47,606.88 1867.48,606.88 1867.49,606.88 1867.5,606.88 1867.51,606.88 1867.52,606.88 1867.52,606.88 1867.53,606.88 1867.54,606.88 1867.55,606.88 1867.56,606.88 1867.57,606.88 1867.58,606.88 1867.59,606.88 1867.6,606.88 1867.61,606.88 1867.62,606.88 1867.63,606.88 1867.63,606.88 1867.64,606.88 1867.65,606.88 1867.66,606.88 1867.67,606.88 1867.68,606.88 1867.69,606.88 1867.7,606.88 1867.71,606.88 1867.72,606.88 1867.73,606.88 1867.74,606.88 1867.75,606.88 1867.75,606.88 1867.76,606.88 1867.77,606.88 1867.78,606.88 1867.79,606.88 1867.8,606.88 1867.81,606.88 1867.82,606.88 1867.83,606.88 1867.84,606.88 1867.85,606.88 1867.86,606.88 1867.86,606.88 1867.87,606.88 1867.88,606.88 1867.89,606.88 1867.9,606.88 1867.91,606.88 1867.92,606.88 1867.93,606.88 1867.94,606.88 1867.95,606.88 1867.96,606.88 1867.97,606.88 1867.97,606.88 1867.98,606.88 1867.99,606.88 1868,606.88 1868.01,606.88 1868.02,606.88 1868.03,606.88 1868.04,606.88 1868.05,606.88 1868.06,606.88 1868.07,606.88 1868.08,606.88 1868.09,606.88 1868.09,606.88 1868.1,606.88 1868.11,606.88 1868.12,606.88 1868.13,606.88 1868.14,606.88 1868.15,606.88 1868.16,606.88 1868.17,606.88 1868.18,606.88 1868.19,606.88 1868.2,606.88 1868.2,606.88 1868.21,606.88 1868.22,606.88 1868.23,606.88 1868.24,606.88 1868.25,606.88 1868.26,606.88 1868.27,606.88 1868.28,606.88 1868.29,606.88 1868.3,606.88 1868.31,606.88 1868.31,606.88 1868.32,606.88 1868.33,606.88 1868.34,606.88 1868.35,606.88 1868.36,606.88 1868.37,606.88 1868.38,606.88 1868.39,606.88 1868.4,606.88 1868.41,606.88 1868.42,606.88 1868.43,606.88 1868.43,606.88 1868.44,606.88 1868.45,606.88 1868.46,606.88 1868.47,606.88 1868.48,606.88 1868.49,606.88 1868.5,606.88 1868.51,606.88 1868.52,606.88 1868.53,606.88 1868.54,606.88 1868.54,606.88 1868.55,606.88 1868.56,606.88 1868.57,606.88 1868.58,606.88 1868.59,606.88 1868.6,606.88 1868.61,606.88 1868.62,606.88 1868.63,606.88 1868.64,606.88 1868.65,606.88 1868.65,606.88 1868.66,606.88 1868.67,606.88 1868.68,606.88 1868.69,606.88 1868.7,606.88 1868.71,606.88 1868.72,606.88 1868.73,606.88 1868.74,606.88 1868.75,606.88 1868.76,606.88 1868.77,606.88 1868.77,606.88 1868.78,606.88 1868.79,606.88 1868.8,606.88 1868.81,606.88 1868.82,606.88 1868.83,606.88 1868.84,606.88 1868.85,606.88 1868.86,606.88 1868.87,606.88 1868.88,606.88 1868.88,606.88 1868.89,606.88 1868.9,606.88 1868.91,606.88 1868.92,606.88 1868.93,606.88 1868.94,606.88 1868.95,606.88 1868.96,606.88 1868.97,606.88 1868.98,606.88 1868.99,606.88 1868.99,606.88 1869,606.88 1869.01,606.88 1869.02,606.88 1869.03,606.88 1869.04,606.88 1869.05,606.88 1869.06,606.88 1869.07,606.88 1869.08,606.88 1869.09,606.88 1869.1,606.88 1869.11,606.88 1869.11,606.88 1869.12,606.88 1869.13,606.88 1869.14,606.88 1869.15,606.88 1869.16,606.88 1869.17,606.88 1869.18,606.88 1869.19,606.88 1869.2,606.88 1869.21,606.88 1869.22,606.88 1869.22,606.88 1869.23,606.88 1869.24,606.88 1869.25,606.88 1869.26,606.88 1869.27,606.88 1869.28,606.88 1869.29,606.88 1869.3,606.88 1869.31,606.88 1869.32,606.88 1869.33,606.88 1869.33,606.88 1869.34,606.88 1869.35,606.88 1869.36,606.88 1869.37,606.88 1869.38,606.88 1869.39,606.88 1869.4,606.88 1869.41,606.88 1869.42,606.88 1869.43,606.88 1869.44,606.88 1869.45,606.88 1869.45,606.88 1869.46,606.88 1869.47,606.88 1869.48,606.88 1869.49,606.88 1869.5,606.88 1869.51,606.88 1869.52,606.88 1869.53,606.88 1869.54,606.88 1869.55,606.88 1869.56,606.88 1869.56,606.88 1869.57,606.88 1869.58,606.88 1869.59,606.88 1869.6,606.88 1869.61,606.88 1869.62,606.88 1869.63,606.88 1869.64,606.88 1869.65,606.88 1869.66,606.88 1869.67,606.88 1869.67,606.88 1869.68,606.88 1869.69,606.88 1869.7,606.88 1869.71,606.88 1869.72,606.88 1869.73,606.88 1869.74,606.88 1869.75,606.88 1869.76,606.88 1869.77,606.88 1869.78,606.88 1869.79,606.88 1869.79,606.88 1869.8,606.88 1869.81,606.88 1869.82,606.88 1869.83,606.88 1869.84,606.88 1869.85,606.88 1869.86,606.88 1869.87,606.88 1869.88,606.88 1869.89,606.88 1869.9,606.88 1869.9,606.88 1869.91,606.88 1869.92,606.88 1869.93,606.88 1869.94,606.88 1869.95,606.88 1869.96,606.88 1869.97,606.88 1869.98,606.88 1869.99,606.88 1870,606.88 1870.01,606.88 1870.01,606.88 1870.02,606.88 1870.03,606.88 1870.04,606.88 1870.05,606.88 1870.06,606.88 1870.07,606.88 1870.08,606.88 1870.09,606.88 1870.1,606.88 1870.11,606.88 1870.12,606.88 1870.13,606.88 1870.13,606.88 1870.14,606.88 1870.15,606.88 1870.16,606.88 1870.17,606.88 1870.18,606.88 1870.19,606.88 1870.2,606.88 1870.21,606.88 1870.22,606.88 1870.23,606.88 1870.24,606.88 1870.24,606.88 1870.25,606.88 1870.26,606.88 1870.27,606.88 1870.28,606.88 1870.29,606.88 1870.3,606.88 1870.31,606.88 1870.32,606.88 1870.33,606.88 1870.34,606.88 1870.35,606.88 1870.35,606.88 1870.36,606.88 1870.37,606.88 1870.38,606.88 1870.39,606.88 1870.4,606.88 1870.41,606.88 1870.42,606.88 1870.43,606.88 1870.44,606.88 1870.45,606.88 1870.46,606.88 1870.47,606.88 1870.47,606.88 1870.48,606.88 1870.49,606.88 1870.5,606.88 1870.51,606.88 1870.52,606.88 1870.53,606.88 1870.54,606.88 1870.55,606.88 1870.56,606.88 1870.57,606.88 1870.58,606.88 1870.58,606.88 1870.59,606.88 1870.6,606.88 1870.61,606.88 1870.62,606.88 1870.63,606.88 1870.64,606.88 1870.65,606.88 1870.66,606.88 1870.67,606.88 1870.68,606.88 1870.69,606.88 1870.69,606.88 1870.7,606.88 1870.71,606.88 1870.72,606.88 1870.73,606.88 1870.74,606.88 1870.75,606.88 1870.76,606.88 1870.77,606.88 1870.78,606.88 1870.79,606.88 1870.8,606.88 1870.81,606.88 1870.81,606.88 1870.82,606.88 1870.83,606.88 1870.84,606.88 1870.85,606.88 1870.86,606.88 1870.87,606.88 1870.88,606.88 1870.89,606.88 1870.9,606.88 1870.91,606.88 1870.92,606.88 1870.92,606.88 1870.93,606.88 1870.94,606.88 1870.95,606.88 1870.96,606.88 1870.97,606.88 1870.98,606.88 1870.99,606.88 1871,606.88 1871.01,606.88 1871.02,606.88 1871.03,606.88 1871.03,606.88 1871.04,606.88 1871.05,606.88 1871.06,606.88 1871.07,606.88 1871.08,606.88 1871.09,606.88 1871.1,606.88 1871.11,606.88 1871.12,606.88 1871.13,606.88 1871.14,606.88 1871.15,606.88 1871.15,606.88 1871.16,606.88 1871.17,606.88 1871.18,606.88 1871.19,606.88 1871.2,606.88 1871.21,606.88 1871.22,606.88 1871.23,606.88 1871.24,606.88 1871.25,606.88 1871.26,606.88 1871.26,606.88 1871.27,606.88 1871.28,606.88 1871.29,606.88 1871.3,606.88 1871.31,606.88 1871.32,606.88 1871.33,606.88 1871.34,606.88 1871.35,606.88 1871.36,606.88 1871.37,606.88 1871.37,606.88 1871.38,606.88 1871.39,606.88 1871.4,606.88 1871.41,606.88 1871.42,606.88 1871.43,606.88 1871.44,606.88 1871.45,606.88 1871.46,606.88 1871.47,606.88 1871.48,606.88 1871.49,606.88 1871.49,606.88 1871.5,606.88 1871.51,606.88 1871.52,606.88 1871.53,606.88 1871.54,606.88 1871.55,606.88 1871.56,606.88 1871.57,606.88 1871.58,606.88 1871.59,606.88 1871.6,606.88 1871.6,606.88 1871.61,606.88 1871.62,606.88 1871.63,606.88 1871.64,606.88 1871.65,606.88 1871.66,606.88 1871.67,606.88 1871.68,606.88 1871.69,606.88 1871.7,606.88 1871.71,606.88 1871.71,606.88 1871.72,606.88 1871.73,606.88 1871.74,606.88 1871.75,606.88 1871.76,606.88 1871.77,606.88 1871.78,606.88 1871.79,606.88 1871.8,606.88 1871.81,606.88 1871.82,606.88 1871.83,606.88 1871.83,606.88 1871.84,606.88 1871.85,606.88 1871.86,606.88 1871.87,606.88 1871.88,606.88 1871.89,606.88 1871.9,606.88 1871.91,606.88 1871.92,606.88 1871.93,606.88 1871.94,606.88 1871.94,606.88 1871.95,606.88 1871.96,606.88 1871.97,606.88 1871.98,606.88 1871.99,606.88 1872,606.88 1872.01,606.88 1872.02,606.88 1872.03,606.88 1872.04,606.88 1872.05,606.88 1872.05,606.88 1872.06,606.88 1872.07,606.88 1872.08,606.88 1872.09,606.88 1872.1,606.88 1872.11,606.88 1872.12,606.88 1872.13,606.88 1872.14,606.88 1872.15,606.88 1872.16,606.88 1872.17,606.88 1872.17,606.88 1872.18,606.88 1872.19,606.88 1872.2,606.88 1872.21,606.88 1872.22,606.88 1872.23,606.88 1872.24,606.88 1872.25,606.88 1872.26,606.88 1872.27,606.88 1872.28,606.88 1872.28,606.88 1872.29,606.88 1872.3,606.88 1872.31,606.88 1872.32,606.88 1872.33,606.88 1872.34,606.88 1872.35,606.88 1872.36,606.88 1872.37,606.88 1872.38,606.88 1872.39,606.88 1872.39,606.88 1872.4,606.88 1872.41,606.88 1872.42,606.88 1872.43,606.88 1872.44,606.88 1872.45,606.88 1872.46,606.88 1872.47,606.88 1872.48,606.88 1872.49,606.88 1872.5,606.88 1872.51,606.88 1872.51,606.88 1872.52,606.88 1872.53,606.88 1872.54,606.88 1872.55,606.88 1872.56,606.88 1872.57,606.88 1872.58,606.88 1872.59,606.88 1872.6,606.88 1872.61,606.88 1872.62,606.88 1872.62,606.88 1872.63,606.88 1872.64,606.88 1872.65,606.88 1872.66,606.88 1872.67,606.88 1872.68,606.88 1872.69,606.88 1872.7,606.88 1872.71,606.88 1872.72,606.88 1872.73,606.88 1872.73,606.88 1872.74,606.88 1872.75,606.88 1872.76,606.88 1872.77,606.88 1872.78,606.88 1872.79,606.88 1872.8,606.88 1872.81,606.88 1872.82,606.88 1872.83,606.88 1872.84,606.88 1872.85,606.88 1872.85,606.88 1872.86,606.88 1872.87,606.88 1872.88,606.88 1872.89,606.88 1872.9,606.88 1872.91,606.88 1872.92,606.88 1872.93,606.88 1872.94,606.88 1872.95,606.88 1872.96,606.88 1872.96,606.88 1872.97,606.88 1872.98,606.88 1872.99,606.88 1873,606.88 1873.01,606.88 1873.02,606.88 1873.03,606.88 1873.04,606.88 1873.05,606.88 1873.06,606.88 1873.07,606.88 1873.07,606.88 1873.08,606.88 1873.09,606.88 1873.1,606.88 1873.11,606.88 1873.12,606.88 1873.13,606.88 1873.14,606.88 1873.15,606.88 1873.16,606.88 1873.17,606.88 1873.18,606.88 1873.19,606.88 1873.19,606.88 1873.2,606.88 1873.21,606.88 1873.22,606.88 1873.23,606.88 1873.24,606.88 1873.25,606.88 1873.26,606.88 1873.27,606.88 1873.28,606.88 1873.29,606.88 1873.3,606.88 1873.3,606.88 1873.31,606.88 1873.32,606.88 1873.33,606.88 1873.34,606.88 1873.35,606.88 1873.36,606.88 1873.37,606.88 1873.38,606.88 1873.39,606.88 1873.4,606.88 1873.41,606.88 1873.41,606.88 1873.42,606.88 1873.43,606.88 1873.44,606.88 1873.45,606.88 1873.46,606.88 1873.47,606.88 1873.48,606.88 1873.49,606.88 1873.5,606.88 1873.51,606.88 1873.52,606.88 1873.53,606.88 1873.53,606.88 1873.54,606.88 1873.55,606.88 1873.56,606.88 1873.57,606.88 1873.58,606.88 1873.59,606.88 1873.6,606.88 1873.61,606.88 1873.62,606.88 1873.63,606.88 1873.64,606.88 1873.64,606.88 1873.65,606.88 1873.66,606.88 1873.67,606.88 1873.68,606.88 1873.69,606.88 1873.7,606.88 1873.71,606.88 1873.72,606.88 1873.73,606.88 1873.74,606.88 1873.75,606.88 1873.75,606.88 1873.76,606.88 1873.77,606.88 1873.78,606.88 1873.79,606.88 1873.8,606.88 1873.81,606.88 1873.82,606.88 1873.83,606.88 1873.84,606.88 1873.85,606.88 1873.86,606.88 1873.87,606.88 1873.87,606.88 1873.88,606.88 1873.89,606.88 1873.9,606.88 1873.91,606.88 1873.92,606.88 1873.93,606.88 1873.94,606.88 1873.95,606.88 1873.96,606.88 1873.97,606.88 1873.98,606.88 1873.98,606.88 1873.99,606.88 1874,606.88 1874.01,606.88 1874.02,606.88 1874.03,606.88 1874.04,606.88 1874.05,606.88 1874.06,606.88 1874.07,606.88 1874.08,606.88 1874.09,606.88 1874.09,606.88 1874.1,606.88 1874.11,606.88 1874.12,606.88 1874.13,606.88 1874.14,606.88 1874.15,606.88 1874.16,606.88 1874.17,606.88 1874.18,606.88 1874.19,606.88 1874.2,606.88 1874.21,606.88 1874.21,606.88 1874.22,606.88 1874.23,606.88 1874.24,606.88 1874.25,606.88 1874.26,606.88 1874.27,606.88 1874.28,606.88 1874.29,606.88 1874.3,606.88 1874.31,606.88 1874.32,606.88 1874.32,606.88 1874.33,606.88 1874.34,606.88 1874.35,606.88 1874.36,606.88 1874.37,606.88 1874.38,606.88 1874.39,606.88 1874.4,606.88 1874.41,606.88 1874.42,606.88 1874.43,606.88 1874.43,606.88 1874.44,606.88 1874.45,606.88 1874.46,606.88 1874.47,606.88 1874.48,606.88 1874.49,606.88 1874.5,606.88 1874.51,606.88 1874.52,606.88 1874.53,606.88 1874.54,606.88 1874.55,606.88 1874.55,606.88 1874.56,606.88 1874.57,606.88 1874.58,606.88 1874.59,606.88 1874.6,606.88 1874.61,606.88 1874.62,606.88 1874.63,606.88 1874.64,606.88 1874.65,606.88 1874.66,606.88 1874.66,606.88 1874.67,606.88 1874.68,606.88 1874.69,606.88 1874.7,606.88 1874.71,606.88 1874.72,606.88 1874.73,606.88 1874.74,606.88 1874.75,606.88 1874.76,606.88 1874.77,606.88 1874.77,606.88 1874.78,606.88 1874.79,606.88 1874.8,606.88 1874.81,606.88 1874.82,606.88 1874.83,606.88 1874.84,606.88 1874.85,606.88 1874.86,606.88 1874.87,606.88 1874.88,606.88 1874.89,606.88 1874.89,606.88 1874.9,606.88 1874.91,606.88 1874.92,606.88 1874.93,606.88 1874.94,606.88 1874.95,606.88 1874.96,606.88 1874.97,606.88 1874.98,606.88 1874.99,606.88 1875,606.88 1875,606.88 1875.01,606.88 1875.02,606.88 1875.03,606.88 1875.04,606.88 1875.05,606.88 1875.06,606.88 1875.07,606.88 1875.08,606.88 1875.09,606.88 1875.1,606.88 1875.11,606.88 1875.11,606.88 1875.12,606.88 1875.13,606.88 1875.14,606.88 1875.15,606.88 1875.16,606.88 1875.17,606.88 1875.18,606.88 1875.19,606.88 1875.2,606.88 1875.21,606.88 1875.22,606.88 1875.23,606.88 1875.23,606.88 1875.24,606.88 1875.25,606.88 1875.26,606.88 1875.27,606.88 1875.28,606.88 1875.29,606.88 1875.3,606.88 1875.31,606.88 1875.32,606.88 1875.33,606.88 1875.34,606.88 1875.34,606.88 1875.35,606.88 1875.36,606.88 1875.37,606.88 1875.38,606.88 1875.39,606.88 1875.4,606.88 1875.41,606.88 1875.42,606.88 1875.43,606.88 1875.44,606.88 1875.45,606.88 1875.45,606.88 1875.46,606.88 1875.47,606.88 1875.48,606.88 1875.49,606.88 1875.5,606.88 1875.51,606.88 1875.52,606.88 1875.53,606.88 1875.54,606.88 1875.55,606.88 1875.56,606.88 1875.57,606.88 1875.57,606.88 1875.58,606.88 1875.59,606.88 1875.6,606.88 1875.61,606.88 1875.62,606.88 1875.63,606.88 1875.64,606.88 1875.65,606.88 1875.66,606.88 1875.67,606.88 1875.68,606.88 1875.68,606.88 1875.69,606.88 1875.7,606.88 1875.71,606.88 1875.72,606.88 1875.73,606.88 1875.74,606.88 1875.75,606.88 1875.76,606.88 1875.77,606.88 1875.78,606.88 1875.79,606.88 1875.79,606.88 1875.8,606.88 1875.81,606.88 1875.82,606.88 1875.83,606.88 1875.84,606.88 1875.85,606.88 1875.86,606.88 1875.87,606.88 1875.88,606.88 1875.89,606.88 1875.9,606.88 1875.91,606.88 1875.91,606.88 1875.92,606.88 1875.93,606.88 1875.94,606.88 1875.95,606.88 1875.96,606.88 1875.97,606.88 1875.98,606.88 1875.99,606.88 1876,606.88 1876.01,606.88 1876.02,606.88 1876.02,606.88 1876.03,606.88 1876.04,606.88 1876.05,606.88 1876.06,606.88 1876.07,606.88 1876.08,606.88 1876.09,606.88 1876.1,606.88 1876.11,606.88 1876.12,606.88 1876.13,606.88 1876.14,606.88 1876.14,606.88 1876.15,606.88 1876.16,606.88 1876.17,606.88 1876.18,606.88 1876.19,606.88 1876.2,606.88 1876.21,606.88 1876.22,606.88 1876.23,606.88 1876.24,606.88 1876.25,606.88 1876.25,606.88 1876.26,606.88 1876.27,606.88 1876.28,606.88 1876.29,606.88 1876.3,606.88 1876.31,606.88 1876.32,606.88 1876.33,606.88 1876.34,606.88 1876.35,606.88 1876.36,606.88 1876.36,606.88 1876.37,606.88 1876.38,606.88 1876.39,606.88 1876.4,606.88 1876.41,606.88 1876.42,606.88 1876.43,606.88 1876.44,606.88 1876.45,606.88 1876.46,606.88 1876.47,606.88 1876.48,606.88 1876.48,606.88 1876.49,606.88 1876.5,606.88 1876.51,606.88 1876.52,606.88 1876.53,606.88 1876.54,606.88 1876.55,606.88 1876.56,606.88 1876.57,606.88 1876.58,606.88 1876.59,606.88 1876.59,606.88 1876.6,606.88 1876.61,606.88 1876.62,606.88 1876.63,606.88 1876.64,606.88 1876.65,606.88 1876.66,606.88 1876.67,606.88 1876.68,606.88 1876.69,606.88 1876.7,606.88 1876.7,606.88 1876.71,606.88 1876.72,606.88 1876.73,606.88 1876.74,606.88 1876.75,606.88 1876.76,606.88 1876.77,606.88 1876.78,606.88 1876.79,606.88 1876.8,606.88 1876.81,606.88 1876.82,606.88 1876.82,606.88 1876.83,606.88 1876.84,606.88 1876.85,606.88 1876.86,606.88 1876.87,606.88 1876.88,606.88 1876.89,606.88 1876.9,606.88 1876.91,606.88 1876.92,606.88 1876.93,606.88 1876.93,606.88 1876.94,606.88 1876.95,606.88 1876.96,606.88 1876.97,606.88 1876.98,606.88 1876.99,606.88 1877,606.88 1877.01,606.88 1877.02,606.88 1877.03,606.88 1877.04,606.88 1877.04,606.88 1877.05,606.88 1877.06,606.88 1877.07,606.88 1877.08,606.88 1877.09,606.88 1877.1,606.88 1877.11,606.88 1877.12,606.88 1877.13,606.88 1877.14,606.88 1877.15,606.88 1877.16,606.88 1877.16,606.88 1877.17,606.88 1877.18,606.88 1877.19,606.88 1877.2,606.88 1877.21,606.88 1877.22,606.88 1877.23,606.88 1877.24,606.88 1877.25,606.88 1877.26,606.88 1877.27,606.88 1877.27,606.88 1877.28,606.88 1877.29,606.88 1877.3,606.88 1877.31,606.88 1877.32,606.88 1877.33,606.88 1877.34,606.88 1877.35,606.88 1877.36,606.88 1877.37,606.88 1877.38,606.88 1877.38,606.88 1877.39,606.88 1877.4,606.88 1877.41,606.88 1877.42,606.88 1877.43,606.88 1877.44,606.88 1877.45,606.88 1877.46,606.88 1877.47,606.88 1877.48,606.88 1877.49,606.88 1877.5,606.88 1877.5,606.88 1877.51,606.88 1877.52,606.88 1877.53,606.88 1877.54,606.88 1877.55,606.88 1877.56,606.88 1877.57,606.88 1877.58,606.88 1877.59,606.88 1877.6,606.88 1877.61,606.88 1877.61,606.88 1877.62,606.88 1877.63,606.88 1877.64,606.88 1877.65,606.88 1877.66,606.88 1877.67,606.88 1877.68,606.88 1877.69,606.88 1877.7,606.88 1877.71,606.88 1877.72,606.88 1877.72,606.88 1877.73,606.88 1877.74,606.88 1877.75,606.88 1877.76,606.88 1877.77,606.88 1877.78,606.88 1877.79,606.88 1877.8,606.88 1877.81,606.88 1877.82,606.88 1877.83,606.88 1877.84,606.88 1877.84,606.88 1877.85,606.88 1877.86,606.88 1877.87,606.88 1877.88,606.88 1877.89,606.88 1877.9,606.88 1877.91,606.88 1877.92,606.88 1877.93,606.88 1877.94,606.88 1877.95,606.88 1877.95,606.88 1877.96,606.88 1877.97,606.88 1877.98,606.88 1877.99,606.88 1878,606.88 1878.01,606.88 1878.02,606.88 1878.03,606.88 1878.04,606.88 1878.05,606.88 1878.06,606.88 1878.06,606.88 1878.07,606.88 1878.08,606.88 1878.09,606.88 1878.1,606.88 1878.11,606.88 1878.12,606.88 1878.13,606.88 1878.14,606.88 1878.15,606.88 1878.16,606.88 1878.17,606.88 1878.18,606.88 1878.18,606.88 1878.19,606.88 1878.2,606.88 1878.21,606.88 1878.22,606.88 1878.23,606.88 1878.24,606.88 1878.25,606.88 1878.26,606.88 1878.27,606.88 1878.28,606.88 1878.29,606.88 1878.29,606.88 1878.3,606.88 1878.31,606.88 1878.32,606.88 1878.33,606.88 1878.34,606.88 1878.35,606.88 1878.36,606.88 1878.37,606.88 1878.38,606.88 1878.39,606.88 1878.4,606.88 1878.4,606.88 1878.41,606.88 1878.42,606.88 1878.43,606.88 1878.44,606.88 1878.45,606.88 1878.46,606.88 1878.47,606.88 1878.48,606.88 1878.49,606.88 1878.5,606.88 1878.51,606.88 1878.52,606.88 1878.52,606.88 1878.53,606.88 1878.54,606.88 1878.55,606.88 1878.56,606.88 1878.57,606.88 1878.58,606.88 1878.59,606.88 1878.6,606.88 1878.61,606.88 1878.62,606.88 1878.63,606.88 1878.63,606.88 1878.64,606.88 1878.65,606.88 1878.66,606.88 1878.67,606.88 1878.68,606.88 1878.69,606.88 1878.7,606.88 1878.71,606.88 1878.72,606.88 1878.73,606.88 1878.74,606.88 1878.74,606.88 1878.75,606.88 1878.76,606.88 1878.77,606.88 1878.78,606.88 1878.79,606.88 1878.8,606.88 1878.81,606.88 1878.82,606.88 1878.83,606.88 1878.84,606.88 1878.85,606.88 1878.86,606.88 1878.86,606.88 1878.87,606.88 1878.88,606.88 1878.89,606.88 1878.9,606.88 1878.91,606.88 1878.92,606.88 1878.93,606.88 1878.94,606.88 1878.95,606.88 1878.96,606.88 1878.97,606.88 1878.97,606.88 1878.98,606.88 1878.99,606.88 1879,606.88 1879.01,606.88 1879.02,606.88 1879.03,606.88 1879.04,606.88 1879.05,606.88 1879.06,606.88 1879.07,606.88 1879.08,606.88 1879.08,606.88 1879.09,606.88 1879.1,606.88 1879.11,606.88 1879.12,606.88 1879.13,606.88 1879.14,606.88 1879.15,606.88 1879.16,606.88 1879.17,606.88 1879.18,606.88 1879.19,606.88 1879.2,606.88 1879.2,606.88 1879.21,606.88 1879.22,606.88 1879.23,606.88 1879.24,606.88 1879.25,606.88 1879.26,606.88 1879.27,606.88 1879.28,606.88 1879.29,606.88 1879.3,606.88 1879.31,606.88 1879.31,606.88 1879.32,606.88 1879.33,606.88 1879.34,606.88 1879.35,606.88 1879.36,606.88 1879.37,606.88 1879.38,606.88 1879.39,606.88 1879.4,606.88 1879.41,606.88 1879.42,606.88 1879.42,606.88 1879.43,606.88 1879.44,606.88 1879.45,606.88 1879.46,606.88 1879.47,606.88 1879.48,606.88 1879.49,606.88 1879.5,606.88 1879.51,606.88 1879.52,606.88 1879.53,606.88 1879.54,606.88 1879.54,606.88 1879.55,606.88 1879.56,606.88 1879.57,606.88 1879.58,606.88 1879.59,606.88 1879.6,606.88 1879.61,606.88 1879.62,606.88 1879.63,606.88 1879.64,606.88 1879.65,606.88 1879.65,606.88 1879.66,606.88 1879.67,606.88 1879.68,606.88 1879.69,606.88 1879.7,606.88 1879.71,606.88 1879.72,606.88 1879.73,606.88 1879.74,606.88 1879.75,606.88 1879.76,606.88 1879.76,606.88 1879.77,606.88 1879.78,606.88 1879.79,606.88 1879.8,606.88 1879.81,606.88 1879.82,606.88 1879.83,606.88 1879.84,606.88 1879.85,606.88 1879.86,606.88 1879.87,606.88 1879.88,606.88 1879.88,606.88 1879.89,606.88 1879.9,606.88 1879.91,606.88 1879.92,606.88 1879.93,606.88 1879.94,606.88 1879.95,606.88 1879.96,606.88 1879.97,606.88 1879.98,606.88 1879.99,606.88 1879.99,606.88 1880,606.88 1880.01,606.88 1880.02,606.88 1880.03,606.88 1880.04,606.88 1880.05,606.88 1880.06,606.88 1880.07,606.88 1880.08,606.88 1880.09,606.88 1880.1,606.88 1880.1,606.88 1880.11,606.88 1880.12,606.88 1880.13,606.88 1880.14,606.88 1880.15,606.88 1880.16,606.88 1880.17,606.88 1880.18,606.88 1880.19,606.88 1880.2,606.88 1880.21,606.88 1880.22,606.88 1880.22,606.88 1880.23,606.88 1880.24,606.88 1880.25,606.88 1880.26,606.88 1880.27,606.88 1880.28,606.88 1880.29,606.88 1880.3,606.88 1880.31,606.88 1880.32,606.88 1880.33,606.88 1880.33,606.88 1880.34,606.88 1880.35,606.88 1880.36,606.88 1880.37,606.88 1880.38,606.88 1880.39,606.88 1880.4,606.88 1880.41,606.88 1880.42,606.88 1880.43,606.88 1880.44,606.88 1880.44,606.88 1880.45,606.88 1880.46,606.88 1880.47,606.88 1880.48,606.88 1880.49,606.88 1880.5,606.88 1880.51,606.88 1880.52,606.88 1880.53,606.88 1880.54,606.88 1880.55,606.88 1880.56,606.88 1880.56,606.88 1880.57,606.88 1880.58,606.88 1880.59,606.88 1880.6,606.88 1880.61,606.88 1880.62,606.88 1880.63,606.88 1880.64,606.88 1880.65,606.88 1880.66,606.88 1880.67,606.88 1880.67,606.88 1880.68,606.88 1880.69,606.88 1880.7,606.88 1880.71,606.88 1880.72,606.88 1880.73,606.88 1880.74,606.88 1880.75,606.88 1880.76,606.88 1880.77,606.88 1880.78,606.88 1880.78,606.88 1880.79,606.88 1880.8,606.88 1880.81,606.88 1880.82,606.88 1880.83,606.88 1880.84,606.88 1880.85,606.88 1880.86,606.88 1880.87,606.88 1880.88,606.88 1880.89,606.88 1880.9,606.88 1880.9,606.88 1880.91,606.88 1880.92,606.88 1880.93,606.88 1880.94,606.88 1880.95,606.88 1880.96,606.88 1880.97,606.88 1880.98,606.88 1880.99,606.88 1881,606.88 1881.01,606.88 1881.01,606.88 1881.02,606.88 1881.03,606.88 1881.04,606.88 1881.05,606.88 1881.06,606.88 1881.07,606.88 1881.08,606.88 1881.09,606.88 1881.1,606.88 1881.11,606.88 1881.12,606.88 1881.12,606.88 1881.13,606.88 1881.14,606.88 1881.15,606.88 1881.16,606.88 1881.17,606.88 1881.18,606.88 1881.19,606.88 1881.2,606.88 1881.21,606.88 1881.22,606.88 1881.23,606.88 1881.24,606.88 1881.24,606.88 1881.25,606.88 1881.26,606.88 1881.27,606.88 1881.28,606.88 1881.29,606.88 1881.3,606.88 1881.31,606.88 1881.32,606.88 1881.33,606.88 1881.34,606.88 1881.35,606.88 1881.35,606.88 1881.36,606.88 1881.37,606.88 1881.38,606.88 1881.39,606.88 1881.4,606.88 1881.41,606.88 1881.42,606.88 1881.43,606.88 1881.44,606.88 1881.45,606.88 1881.46,606.88 1881.46,606.88 1881.47,606.88 1881.48,606.88 1881.49,606.88 1881.5,606.88 1881.51,606.88 1881.52,606.88 1881.53,606.88 1881.54,606.88 1881.55,606.88 1881.56,606.88 1881.57,606.88 1881.58,606.88 1881.58,606.88 1881.59,606.88 1881.6,606.88 1881.61,606.88 1881.62,606.88 1881.63,606.88 1881.64,606.88 1881.65,606.88 1881.66,606.88 1881.67,606.88 1881.68,606.88 1881.69,606.88 1881.69,606.88 1881.7,606.88 1881.71,606.88 1881.72,606.88 1881.73,606.88 1881.74,606.88 1881.75,606.88 1881.76,606.88 1881.77,606.88 1881.78,606.88 1881.79,606.88 1881.8,606.88 1881.8,606.88 1881.81,606.88 1881.82,606.88 1881.83,606.88 1881.84,606.88 1881.85,606.88 1881.86,606.88 1881.87,606.88 1881.88,606.88 1881.89,606.88 1881.9,606.88 1881.91,606.88 1881.92,606.88 1881.92,606.88 1881.93,606.88 1881.94,606.88 1881.95,606.88 1881.96,606.88 1881.97,606.88 1881.98,606.88 1881.99,606.88 1882,606.88 1882.01,606.88 1882.02,606.88 1882.03,606.88 1882.03,606.88 1882.04,606.88 1882.05,606.88 1882.06,606.88 1882.07,606.88 1882.08,606.88 1882.09,606.88 1882.1,606.88 1882.11,606.88 1882.12,606.88 1882.13,606.88 1882.14,606.88 1882.14,606.88 1882.15,606.88 1882.16,606.88 1882.17,606.88 1882.18,606.88 1882.19,606.88 1882.2,606.88 1882.21,606.88 1882.22,606.88 1882.23,606.88 1882.24,606.88 1882.25,606.88 1882.26,606.88 1882.26,606.88 1882.27,606.88 1882.28,606.88 1882.29,606.88 1882.3,606.88 1882.31,606.88 1882.32,606.88 1882.33,606.88 1882.34,606.88 1882.35,606.88 1882.36,606.88 1882.37,606.88 1882.37,606.88 1882.38,606.88 1882.39,606.88 1882.4,606.88 1882.41,606.88 1882.42,606.88 1882.43,606.88 1882.44,606.88 1882.45,606.88 1882.46,606.88 1882.47,606.88 1882.48,606.88 1882.48,606.88 1882.49,606.88 1882.5,606.88 1882.51,606.88 1882.52,606.88 1882.53,606.88 1882.54,606.88 1882.55,606.88 1882.56,606.88 1882.57,606.88 1882.58,606.88 1882.59,606.88 1882.6,606.88 1882.6,606.88 1882.61,606.88 1882.62,606.88 1882.63,606.88 1882.64,606.88 1882.65,606.88 1882.66,606.88 1882.67,606.88 1882.68,606.88 1882.69,606.88 1882.7,606.88 1882.71,606.88 1882.71,606.88 1882.72,606.88 1882.73,606.88 1882.74,606.88 1882.75,606.88 1882.76,606.88 1882.77,606.88 1882.78,606.88 1882.79,606.88 1882.8,606.88 1882.81,606.88 1882.82,606.88 1882.82,606.88 1882.83,606.88 1882.84,606.88 1882.85,606.88 1882.86,606.88 1882.87,606.88 1882.88,606.88 1882.89,606.88 1882.9,606.88 1882.91,606.88 1882.92,606.88 1882.93,606.88 1882.94,606.88 1882.94,606.88 1882.95,606.88 1882.96,606.88 1882.97,606.88 1882.98,606.88 1882.99,606.88 1883,606.88 1883.01,606.88 1883.02,606.88 1883.03,606.88 1883.04,606.88 1883.05,606.88 1883.05,606.88 1883.06,606.88 1883.07,606.88 1883.08,606.88 1883.09,606.88 1883.1,606.88 1883.11,606.88 1883.12,606.88 1883.13,606.88 1883.14,606.88 1883.15,606.88 1883.16,606.88 1883.16,606.88 1883.17,606.88 1883.18,606.88 1883.19,606.88 1883.2,606.88 1883.21,606.88 1883.22,606.88 1883.23,606.88 1883.24,606.88 1883.25,606.88 1883.26,606.88 1883.27,606.88 1883.28,606.88 1883.28,606.88 1883.29,606.88 1883.3,606.88 1883.31,606.88 1883.32,606.88 1883.33,606.88 1883.34,606.88 1883.35,606.88 1883.36,606.88 1883.37,606.88 1883.38,606.88 1883.39,606.88 1883.39,606.88 1883.4,606.88 1883.41,606.88 1883.42,606.88 1883.43,606.88 1883.44,606.88 1883.45,606.88 1883.46,606.88 1883.47,606.88 1883.48,606.88 1883.49,606.88 1883.5,606.88 1883.5,606.88 1883.51,606.88 1883.52,606.88 1883.53,606.88 1883.54,606.88 1883.55,606.88 1883.56,606.88 1883.57,606.88 1883.58,606.88 1883.59,606.88 1883.6,606.88 1883.61,606.88 1883.62,606.88 1883.62,606.88 1883.63,606.88 1883.64,606.88 1883.65,606.88 1883.66,606.88 1883.67,606.88 1883.68,606.88 1883.69,606.88 1883.7,606.88 1883.71,606.88 1883.72,606.88 1883.73,606.88 1883.73,606.88 1883.74,606.88 1883.75,606.88 1883.76,606.88 1883.77,606.88 1883.78,606.88 1883.79,606.88 1883.8,606.88 1883.81,606.88 1883.82,606.88 1883.83,606.88 1883.84,606.88 1883.84,606.88 1883.85,606.88 1883.86,606.88 1883.87,606.88 1883.88,606.88 1883.89,606.88 1883.9,606.88 1883.91,606.88 1883.92,606.88 1883.93,606.88 1883.94,606.88 1883.95,606.88 1883.96,606.88 1883.96,606.88 1883.97,606.88 1883.98,606.88 1883.99,606.88 1884,606.88 1884.01,606.88 1884.02,606.88 1884.03,606.88 1884.04,606.88 1884.05,606.88 1884.06,606.88 1884.07,606.88 1884.07,606.88 1884.08,606.88 1884.09,606.88 1884.1,606.88 1884.11,606.88 1884.12,606.88 1884.13,606.88 1884.14,606.88 1884.15,606.88 1884.16,606.88 1884.17,606.88 1884.18,606.88 1884.18,606.88 1884.19,606.88 1884.2,606.88 1884.21,606.88 1884.22,606.88 1884.23,606.88 1884.24,606.88 1884.25,606.88 1884.26,606.88 1884.27,606.88 1884.28,606.88 1884.29,606.88 1884.3,606.88 1884.3,606.88 1884.31,606.88 1884.32,606.88 1884.33,606.88 1884.34,606.88 1884.35,606.88 1884.36,606.88 1884.37,606.88 1884.38,606.88 1884.39,606.88 1884.4,606.88 1884.41,606.88 1884.41,606.88 1884.42,606.88 1884.43,606.88 1884.44,606.88 1884.45,606.88 1884.46,606.88 1884.47,606.88 1884.48,606.88 1884.49,606.88 1884.5,606.88 1884.51,606.88 1884.52,606.88 1884.52,606.88 1884.53,606.88 1884.54,606.88 1884.55,606.88 1884.56,606.88 1884.57,606.88 1884.58,606.88 1884.59,606.88 1884.6,606.88 1884.61,606.88 1884.62,606.88 1884.63,606.88 1884.64,606.88 1884.64,606.88 1884.65,606.88 1884.66,606.88 1884.67,606.88 1884.68,606.88 1884.69,606.88 1884.7,606.88 1884.71,606.88 1884.72,606.88 1884.73,606.88 1884.74,606.88 1884.75,606.88 1884.75,606.88 1884.76,606.88 1884.77,606.88 1884.78,606.88 1884.79,606.88 1884.8,606.88 1884.81,606.88 1884.82,606.88 1884.83,606.88 1884.84,606.88 1884.85,606.88 1884.86,606.88 1884.86,606.88 1884.87,606.88 1884.88,606.88 1884.89,606.88 1884.9,606.88 1884.91,606.88 1884.92,606.88 1884.93,606.88 1884.94,606.88 1884.95,606.88 1884.96,606.88 1884.97,606.88 1884.98,606.88 1884.98,606.88 1884.99,606.88 1885,606.88 1885.01,606.88 1885.02,606.88 1885.03,606.88 1885.04,606.88 1885.05,606.88 1885.06,606.88 1885.07,606.88 1885.08,606.88 1885.09,606.88 1885.09,606.88 1885.1,606.88 1885.11,606.88 1885.12,606.88 1885.13,606.88 1885.14,606.88 1885.15,606.88 1885.16,606.88 1885.17,606.88 1885.18,606.88 1885.19,606.88 1885.2,606.88 1885.2,606.88 1885.21,606.88 1885.22,606.88 1885.23,606.88 1885.24,606.88 1885.25,606.88 1885.26,606.88 1885.27,606.88 1885.28,606.88 1885.29,606.88 1885.3,606.88 1885.31,606.88 1885.32,606.88 1885.32,606.88 1885.33,606.88 1885.34,606.88 1885.35,606.88 1885.36,606.88 1885.37,606.88 1885.38,606.88 1885.39,606.88 1885.4,606.88 1885.41,606.88 1885.42,606.88 1885.43,606.88 1885.43,606.88 1885.44,606.88 1885.45,606.88 1885.46,606.88 1885.47,606.88 1885.48,606.88 1885.49,606.88 1885.5,606.88 1885.51,606.88 1885.52,606.88 1885.53,606.88 1885.54,606.88 1885.54,606.88 1885.55,606.88 1885.56,606.88 1885.57,606.88 1885.58,606.88 1885.59,606.88 1885.6,606.88 1885.61,606.88 1885.62,606.88 1885.63,606.88 1885.64,606.88 1885.65,606.88 1885.66,606.88 1885.66,606.88 1885.67,606.88 1885.68,606.88 1885.69,606.88 1885.7,606.88 1885.71,606.88 1885.72,606.88 1885.73,606.88 1885.74,606.88 1885.75,606.88 1885.76,606.88 1885.77,606.88 1885.77,606.88 1885.78,606.88 1885.79,606.88 1885.8,606.88 1885.81,606.88 1885.82,606.88 1885.83,606.88 1885.84,606.88 1885.85,606.88 1885.86,606.88 1885.87,606.88 1885.88,606.88 1885.88,606.88 1885.89,606.88 1885.9,606.88 1885.91,606.88 1885.92,606.88 1885.93,606.88 1885.94,606.88 1885.95,606.88 1885.96,606.88 1885.97,606.88 1885.98,606.88 1885.99,606.88 1886,606.88 1886,606.88 1886.01,606.88 1886.02,606.88 1886.03,606.88 1886.04,606.88 1886.05,606.88 1886.06,606.88 1886.07,606.88 1886.08,606.88 1886.09,606.88 1886.1,606.88 1886.11,606.88 1886.11,606.88 1886.12,606.88 1886.13,606.88 1886.14,606.88 1886.15,606.88 1886.16,606.88 1886.17,606.88 1886.18,606.88 1886.19,606.88 1886.2,606.88 1886.21,606.88 1886.22,606.88 1886.22,606.88 1886.23,606.88 1886.24,606.88 1886.25,606.88 1886.26,606.88 1886.27,606.88 1886.28,606.88 1886.29,606.88 1886.3,606.88 1886.31,606.88 1886.32,606.88 1886.33,606.88 1886.34,606.88 1886.34,606.88 1886.35,606.88 1886.36,606.88 1886.37,606.88 1886.38,606.88 1886.39,606.88 1886.4,606.88 1886.41,606.88 1886.42,606.88 1886.43,606.88 1886.44,606.88 1886.45,606.88 1886.45,606.88 1886.46,606.88 1886.47,606.88 1886.48,606.88 1886.49,606.88 1886.5,606.88 1886.51,606.88 1886.52,606.88 1886.53,606.88 1886.54,606.88 1886.55,606.88 1886.56,606.88 1886.56,606.88 1886.57,606.88 1886.58,606.88 1886.59,606.88 1886.6,606.88 1886.61,606.88 1886.62,606.88 1886.63,606.88 1886.64,606.88 1886.65,606.88 1886.66,606.88 1886.67,606.88 1886.68,606.88 1886.68,606.88 1886.69,606.88 1886.7,606.88 1886.71,606.88 1886.72,606.88 1886.73,606.88 1886.74,606.88 1886.75,606.88 1886.76,606.88 1886.77,606.88 1886.78,606.88 1886.79,606.88 1886.79,606.88 1886.8,606.88 1886.81,606.88 1886.82,606.88 1886.83,606.88 1886.84,606.88 1886.85,606.88 1886.86,606.88 1886.87,606.88 1886.88,606.88 1886.89,606.88 1886.9,606.88 1886.9,606.88 1886.91,606.88 1886.92,606.88 1886.93,606.88 1886.94,606.88 1886.95,606.88 1886.96,606.88 1886.97,606.88 1886.98,606.88 1886.99,606.88 1887,606.88 1887.01,606.88 1887.02,606.88 1887.02,606.88 1887.03,606.88 1887.04,606.88 1887.05,606.88 1887.06,606.88 1887.07,606.88 1887.08,606.88 1887.09,606.88 1887.1,606.88 1887.11,606.88 1887.12,606.88 1887.13,606.88 1887.13,606.88 1887.14,606.88 1887.15,606.88 1887.16,606.88 1887.17,606.88 1887.18,606.88 1887.19,606.88 1887.2,606.88 1887.21,606.88 1887.22,606.88 1887.23,606.88 1887.24,606.88 1887.24,606.88 1887.25,606.88 1887.26,606.88 1887.27,606.88 1887.28,606.88 1887.29,606.88 1887.3,606.88 1887.31,606.88 1887.32,606.88 1887.33,606.88 1887.34,606.88 1887.35,606.88 1887.36,606.88 1887.36,606.88 1887.37,606.88 1887.38,606.88 1887.39,606.88 1887.4,606.88 1887.41,606.88 1887.42,606.88 1887.43,606.88 1887.44,606.88 1887.45,606.88 1887.46,606.88 1887.47,606.88 1887.47,606.88 1887.48,606.88 1887.49,606.88 1887.5,606.88 1887.51,606.88 1887.52,606.88 1887.53,606.88 1887.54,606.88 1887.55,606.88 1887.56,606.88 1887.57,606.88 1887.58,606.88 1887.58,606.88 1887.59,606.88 1887.6,606.88 1887.61,606.88 1887.62,606.88 1887.63,606.88 1887.64,606.88 1887.65,606.88 1887.66,606.88 1887.67,606.88 1887.68,606.88 1887.69,606.88 1887.7,606.88 1887.7,606.88 1887.71,606.88 1887.72,606.88 1887.73,606.88 1887.74,606.88 1887.75,606.88 1887.76,606.88 1887.77,606.88 1887.78,606.88 1887.79,606.88 1887.8,606.88 1887.81,606.88 1887.81,606.88 1887.82,606.88 1887.83,606.88 1887.84,606.88 1887.85,606.88 1887.86,606.88 1887.87,606.88 1887.88,606.88 1887.89,606.88 1887.9,606.88 1887.91,606.88 1887.92,606.88 1887.92,606.88 1887.93,606.88 1887.94,606.88 1887.95,606.88 1887.96,606.88 1887.97,606.88 1887.98,606.88 1887.99,606.88 1888,606.88 1888.01,606.88 1888.02,606.88 1888.03,606.88 1888.04,606.88 1888.04,606.88 1888.05,606.88 1888.06,606.88 1888.07,606.88 1888.08,606.88 1888.09,606.88 1888.1,606.88 1888.11,606.88 1888.12,606.88 1888.13,606.88 1888.14,606.88 1888.15,606.88 1888.15,606.88 1888.16,606.88 1888.17,606.88 1888.18,606.88 1888.19,606.88 1888.2,606.88 1888.21,606.88 1888.22,606.88 1888.23,606.88 1888.24,606.88 1888.25,606.88 1888.26,606.88 1888.26,606.88 1888.27,606.88 1888.28,606.88 1888.29,606.88 1888.3,606.88 1888.31,606.88 1888.32,606.88 1888.33,606.88 1888.34,606.88 1888.35,606.88 1888.36,606.88 1888.37,606.88 1888.38,606.88 1888.38,606.88 1888.39,606.88 1888.4,606.88 1888.41,606.88 1888.42,606.88 1888.43,606.88 1888.44,606.88 1888.45,606.88 1888.46,606.88 1888.47,606.88 1888.48,606.88 1888.49,606.88 1888.49,606.88 1888.5,606.88 1888.51,606.88 1888.52,606.88 1888.53,606.88 1888.54,606.88 1888.55,606.88 1888.56,606.88 1888.57,606.88 1888.58,606.88 1888.59,606.88 1888.6,606.88 1888.6,606.88 1888.61,606.88 1888.62,606.88 1888.63,606.88 1888.64,606.88 1888.65,606.88 1888.66,606.88 1888.67,606.88 1888.68,606.88 1888.69,606.88 1888.7,606.88 1888.71,606.88 1888.72,606.88 1888.72,606.88 1888.73,606.88 1888.74,606.88 1888.75,606.88 1888.76,606.88 1888.77,606.88 1888.78,606.88 1888.79,606.88 1888.8,606.88 1888.81,606.88 1888.82,606.88 1888.83,606.88 1888.83,606.88 1888.84,606.88 1888.85,606.88 1888.86,606.88 1888.87,606.88 1888.88,606.88 1888.89,606.88 1888.9,606.88 1888.91,606.88 1888.92,606.88 1888.93,606.88 1888.94,606.88 1888.94,606.88 1888.95,606.88 1888.96,606.88 1888.97,606.88 1888.98,606.88 1888.99,606.88 1889,606.88 1889.01,606.88 1889.02,606.88 1889.03,606.88 1889.04,606.88 1889.05,606.88 1889.06,606.88 1889.06,606.88 1889.07,606.88 1889.08,606.88 1889.09,606.88 1889.1,606.88 1889.11,606.88 1889.12,606.88 1889.13,606.88 1889.14,606.88 1889.15,606.88 1889.16,606.88 1889.17,606.88 1889.17,606.88 1889.18,606.88 1889.19,606.88 1889.2,606.88 1889.21,606.88 1889.22,606.88 1889.23,606.88 1889.24,606.88 1889.25,606.88 1889.26,606.88 1889.27,606.88 1889.28,606.88 1889.28,606.88 1889.29,606.88 1889.3,606.88 1889.31,606.88 1889.32,606.88 1889.33,606.88 1889.34,606.88 1889.35,606.88 1889.36,606.88 1889.37,606.88 1889.38,606.88 1889.39,606.88 1889.4,606.88 1889.4,606.88 1889.41,606.88 1889.42,606.88 1889.43,606.88 1889.44,606.88 1889.45,606.88 1889.46,606.88 1889.47,606.88 1889.48,606.88 1889.49,606.88 1889.5,606.88 1889.51,606.88 1889.51,606.88 1889.52,606.88 1889.53,606.88 1889.54,606.88 1889.55,606.88 1889.56,606.88 1889.57,606.88 1889.58,606.88 1889.59,606.88 1889.6,606.88 1889.61,606.88 1889.62,606.88 1889.62,606.88 1889.63,606.88 1889.64,606.88 1889.65,606.88 1889.66,606.88 1889.67,606.88 1889.68,606.88 1889.69,606.88 1889.7,606.88 1889.71,606.88 1889.72,606.88 1889.73,606.88 1889.74,606.88 1889.74,606.88 1889.75,606.88 1889.76,606.88 1889.77,606.88 1889.78,606.88 1889.79,606.88 1889.8,606.88 1889.81,606.88 1889.82,606.88 1889.83,606.88 1889.84,606.88 1889.85,606.88 1889.85,606.88 1889.86,606.88 1889.87,606.88 1889.88,606.88 1889.89,606.88 1889.9,606.88 1889.91,606.88 1889.92,606.88 1889.93,606.88 1889.94,606.88 1889.95,606.88 1889.96,606.88 1889.96,606.88 1889.97,606.88 1889.98,606.88 1889.99,606.88 1890,606.88 1890.01,606.88 1890.02,606.88 1890.03,606.88 1890.04,606.88 1890.05,606.88 1890.06,606.88 1890.07,606.88 1890.08,606.88 1890.08,606.88 1890.09,606.88 1890.1,606.88 1890.11,606.88 1890.12,606.88 1890.13,606.88 1890.14,606.88 1890.15,606.88 1890.16,606.88 1890.17,606.88 1890.18,606.88 1890.19,606.88 1890.19,606.88 1890.2,606.88 1890.21,606.88 1890.22,606.88 1890.23,606.88 1890.24,606.88 1890.25,606.88 1890.26,606.88 1890.27,606.88 1890.28,606.88 1890.29,606.88 1890.3,606.88 1890.3,606.88 1890.31,606.88 1890.32,606.88 1890.33,606.88 1890.34,606.88 1890.35,606.88 1890.36,606.88 1890.37,606.88 1890.38,606.88 1890.39,606.88 1890.4,606.88 1890.41,606.88 1890.42,606.88 1890.42,606.88 1890.43,606.88 1890.44,606.88 1890.45,606.88 1890.46,606.88 1890.47,606.88 1890.48,606.88 1890.49,606.88 1890.5,606.88 1890.51,606.88 1890.52,606.88 1890.53,606.88 1890.53,606.88 1890.54,606.88 1890.55,606.88 1890.56,606.88 1890.57,606.88 1890.58,606.88 1890.59,606.88 1890.6,606.88 1890.61,606.88 1890.62,606.88 1890.63,606.88 1890.64,606.88 1890.64,606.88 1890.65,606.88 1890.66,606.88 1890.67,606.88 1890.68,606.88 1890.69,606.88 1890.7,606.88 1890.71,606.88 1890.72,606.88 1890.73,606.88 1890.74,606.88 1890.75,606.88 1890.76,606.88 1890.76,606.88 1890.77,606.88 1890.78,606.88 1890.79,606.88 1890.8,606.88 1890.81,606.88 1890.82,606.88 1890.83,606.88 1890.84,606.88 1890.85,606.88 1890.86,606.88 1890.87,606.88 1890.87,606.88 1890.88,606.88 1890.89,606.88 1890.9,606.88 1890.91,606.88 1890.92,606.88 1890.93,606.88 1890.94,606.88 1890.95,606.88 1890.96,606.88 1890.97,606.88 1890.98,606.88 1890.98,606.88 1890.99,606.88 1891,606.88 1891.01,606.88 1891.02,606.88 1891.03,606.88 1891.04,606.88 1891.05,606.88 1891.06,606.88 1891.07,606.88 1891.08,606.88 1891.09,606.88 1891.1,606.88 1891.1,606.88 1891.11,606.88 1891.12,606.88 1891.13,606.88 1891.14,606.88 1891.15,606.88 1891.16,606.88 1891.17,606.88 1891.18,606.88 1891.19,606.88 1891.2,606.88 1891.21,606.88 1891.21,606.88 1891.22,606.88 1891.23,606.88 1891.24,606.88 1891.25,606.88 1891.26,606.88 1891.27,606.88 1891.28,606.88 1891.29,606.88 1891.3,606.88 1891.31,606.88 1891.32,606.88 1891.32,606.88 1891.33,606.88 1891.34,606.88 1891.35,606.88 1891.36,606.88 1891.37,606.88 1891.38,606.88 1891.39,606.88 1891.4,606.88 1891.41,606.88 1891.42,606.88 1891.43,606.88 1891.44,606.88 1891.44,606.88 1891.45,606.88 1891.46,606.88 1891.47,606.88 1891.48,606.88 1891.49,606.88 1891.5,606.88 1891.51,606.88 1891.52,606.88 1891.53,606.88 1891.54,606.88 1891.55,606.88 1891.55,606.88 1891.56,606.88 1891.57,606.88 1891.58,606.88 1891.59,606.88 1891.6,606.88 1891.61,606.88 1891.62,606.88 1891.63,606.88 1891.64,606.88 1891.65,606.88 1891.66,606.88 1891.66,606.88 1891.67,606.88 1891.68,606.88 1891.69,606.88 1891.7,606.88 1891.71,606.88 1891.72,606.88 1891.73,606.88 1891.74,606.88 1891.75,606.88 1891.76,606.88 1891.77,606.88 1891.78,606.88 1891.78,606.88 1891.79,606.88 1891.8,606.88 1891.81,606.88 1891.82,606.88 1891.83,606.88 1891.84,606.88 1891.85,606.88 1891.86,606.88 1891.87,606.88 1891.88,606.88 1891.89,606.88 1891.89,606.88 1891.9,606.88 1891.91,606.88 1891.92,606.88 1891.93,606.88 1891.94,606.88 1891.95,606.88 1891.96,606.88 1891.97,606.88 1891.98,606.88 1891.99,606.88 1892,606.88 1892,606.88 1892.01,606.88 1892.02,606.88 1892.03,606.88 1892.04,606.88 1892.05,606.88 1892.06,606.88 1892.07,606.88 1892.08,606.88 1892.09,606.88 1892.1,606.88 1892.11,606.88 1892.12,606.88 1892.12,606.88 1892.13,606.88 1892.14,606.88 1892.15,606.88 1892.16,606.88 1892.17,606.88 1892.18,606.88 1892.19,606.88 1892.2,606.88 1892.21,606.88 1892.22,606.88 1892.23,606.88 1892.23,606.88 1892.24,606.88 1892.25,606.88 1892.26,606.88 1892.27,606.88 1892.28,606.88 1892.29,606.88 1892.3,606.88 1892.31,606.88 1892.32,606.88 1892.33,606.88 1892.34,606.88 1892.34,606.88 1892.35,606.88 1892.36,606.88 1892.37,606.88 1892.38,606.88 1892.39,606.88 1892.4,606.88 1892.41,606.88 1892.42,606.88 1892.43,606.88 1892.44,606.88 1892.45,606.88 1892.46,606.88 1892.46,606.88 1892.47,606.88 1892.48,606.88 1892.49,606.88 1892.5,606.88 1892.51,606.88 1892.52,606.88 1892.53,606.88 1892.54,606.88 1892.55,606.88 1892.56,606.88 1892.57,606.88 1892.57,606.88 1892.58,606.88 1892.59,606.88 1892.6,606.88 1892.61,606.88 1892.62,606.88 1892.63,606.88 1892.64,606.88 1892.65,606.88 1892.66,606.88 1892.67,606.88 1892.68,606.88 1892.68,606.88 1892.69,606.88 1892.7,606.88 1892.71,606.88 1892.72,606.88 1892.73,606.88 1892.74,606.88 1892.75,606.88 1892.76,606.88 1892.77,606.88 1892.78,606.88 1892.79,606.88 1892.8,606.88 1892.8,606.88 1892.81,606.88 1892.82,606.88 1892.83,606.88 1892.84,606.88 1892.85,606.88 1892.86,606.88 1892.87,606.88 1892.88,606.88 1892.89,606.88 1892.9,606.88 1892.91,606.88 1892.91,606.88 1892.92,606.88 1892.93,606.88 1892.94,606.88 1892.95,606.88 1892.96,606.88 1892.97,606.88 1892.98,606.88 1892.99,606.88 1893,606.88 1893.01,606.88 1893.02,606.88 1893.02,606.88 1893.03,606.88 1893.04,606.88 1893.05,606.88 1893.06,606.88 1893.07,606.88 1893.08,606.88 1893.09,606.88 1893.1,606.88 1893.11,606.88 1893.12,606.88 1893.13,606.88 1893.14,606.88 1893.14,606.88 1893.15,606.88 1893.16,606.88 1893.17,606.88 1893.18,606.88 1893.19,606.88 1893.2,606.88 1893.21,606.88 1893.22,606.88 1893.23,606.88 1893.24,606.88 1893.25,606.88 1893.25,606.88 1893.26,606.88 1893.27,606.88 1893.28,606.88 1893.29,606.88 1893.3,606.88 1893.31,606.88 1893.32,606.88 1893.33,606.88 1893.34,606.88 1893.35,606.88 1893.36,606.88 1893.36,606.88 1893.37,606.88 1893.38,606.88 1893.39,606.88 1893.4,606.88 1893.41,606.88 1893.42,606.88 1893.43,606.88 1893.44,606.88 1893.45,606.88 1893.46,606.88 1893.47,606.88 1893.48,606.88 1893.48,606.88 1893.49,606.88 1893.5,606.88 1893.51,606.88 1893.52,606.88 1893.53,606.88 1893.54,606.88 1893.55,606.88 1893.56,606.88 1893.57,606.88 1893.58,606.88 1893.59,606.88 1893.59,606.88 1893.6,606.88 1893.61,606.88 1893.62,606.88 1893.63,606.88 1893.64,606.88 1893.65,606.88 1893.66,606.88 1893.67,606.88 1893.68,606.88 1893.69,606.88 1893.7,606.88 1893.7,606.88 1893.71,606.88 1893.72,606.88 1893.73,606.88 1893.74,606.88 1893.75,606.88 1893.76,606.88 1893.77,606.88 1893.78,606.88 1893.79,606.88 1893.8,606.88 1893.81,606.88 1893.82,606.88 1893.82,606.88 1893.83,606.88 1893.84,606.88 1893.85,606.88 1893.86,606.88 1893.87,606.88 1893.88,606.88 1893.89,606.88 1893.9,606.88 1893.91,606.88 1893.92,606.88 1893.93,606.88 1893.93,606.88 1893.94,606.88 1893.95,606.88 1893.96,606.88 1893.97,606.88 1893.98,606.88 1893.99,606.88 1894,606.88 1894.01,606.88 1894.02,606.88 1894.03,606.88 1894.04,606.88 1894.04,606.88 1894.05,606.88 1894.06,606.88 1894.07,606.88 1894.08,606.88 1894.09,606.88 1894.1,606.88 1894.11,606.88 1894.12,606.88 1894.13,606.88 1894.14,606.88 1894.15,606.88 1894.16,606.88 1894.16,606.88 1894.17,606.88 1894.18,606.88 1894.19,606.88 1894.2,606.88 1894.21,606.88 1894.22,606.88 1894.23,606.88 1894.24,606.88 1894.25,606.88 1894.26,606.88 1894.27,606.88 1894.27,606.88 1894.28,606.88 1894.29,606.88 1894.3,606.88 1894.31,606.88 1894.32,606.88 1894.33,606.88 1894.34,606.88 1894.35,606.88 1894.36,606.88 1894.37,606.88 1894.38,606.88 1894.38,606.88 1894.39,606.88 1894.4,606.88 1894.41,606.88 1894.42,606.88 1894.43,606.88 1894.44,606.88 1894.45,606.88 1894.46,606.88 1894.47,606.88 1894.48,606.88 1894.49,606.88 1894.5,606.88 1894.5,606.88 1894.51,606.88 1894.52,606.88 1894.53,606.88 1894.54,606.88 1894.55,606.88 1894.56,606.88 1894.57,606.88 1894.58,606.88 1894.59,606.88 1894.6,606.88 1894.61,606.88 1894.61,606.88 1894.62,606.88 1894.63,606.88 1894.64,606.88 1894.65,606.88 1894.66,606.88 1894.67,606.88 1894.68,606.88 1894.69,606.88 1894.7,606.88 1894.71,606.88 1894.72,606.88 1894.72,606.88 1894.73,606.88 1894.74,606.88 1894.75,606.88 1894.76,606.88 1894.77,606.88 1894.78,606.88 1894.79,606.88 1894.8,606.88 1894.81,606.88 1894.82,606.88 1894.83,606.88 1894.84,606.88 1894.84,606.88 1894.85,606.88 1894.86,606.88 1894.87,606.88 1894.88,606.88 1894.89,606.88 1894.9,606.88 1894.91,606.88 1894.92,606.88 1894.93,606.88 1894.94,606.88 1894.95,606.88 1894.95,606.88 1894.96,606.88 1894.97,606.88 1894.98,606.88 1894.99,606.88 1895,606.88 1895.01,606.88 1895.02,606.88 1895.03,606.88 1895.04,606.88 1895.05,606.88 1895.06,606.88 1895.06,606.88 1895.07,606.88 1895.08,606.88 1895.09,606.88 1895.1,606.88 1895.11,606.88 1895.12,606.88 1895.13,606.88 1895.14,606.88 1895.15,606.88 1895.16,606.88 1895.17,606.88 1895.18,606.88 1895.18,606.88 1895.19,606.88 1895.2,606.88 1895.21,606.88 1895.22,606.88 1895.23,606.88 1895.24,606.88 1895.25,606.88 1895.26,606.88 1895.27,606.88 1895.28,606.88 1895.29,606.88 1895.29,606.88 1895.3,606.88 1895.31,606.88 1895.32,606.88 1895.33,606.88 1895.34,606.88 1895.35,606.88 1895.36,606.88 1895.37,606.88 1895.38,606.88 1895.39,606.88 1895.4,606.88 1895.4,606.88 1895.41,606.88 1895.42,606.88 1895.43,606.88 1895.44,606.88 1895.45,606.88 1895.46,606.88 1895.47,606.88 1895.48,606.88 1895.49,606.88 1895.5,606.88 1895.51,606.88 1895.52,606.88 1895.52,606.88 1895.53,606.88 1895.54,606.88 1895.55,606.88 1895.56,606.88 1895.57,606.88 1895.58,606.88 1895.59,606.88 1895.6,606.88 1895.61,606.88 1895.62,606.88 1895.63,606.88 1895.63,606.88 1895.64,606.88 1895.65,606.88 1895.66,606.88 1895.67,606.88 1895.68,606.88 1895.69,606.88 1895.7,606.88 1895.71,606.88 1895.72,606.88 1895.73,606.88 1895.74,606.88 1895.74,606.88 1895.75,606.88 1895.76,606.88 1895.77,606.88 1895.78,606.88 1895.79,606.88 1895.8,606.88 1895.81,606.88 1895.82,606.88 1895.83,606.88 1895.84,606.88 1895.85,606.88 1895.86,606.88 1895.86,606.88 1895.87,606.88 1895.88,606.88 1895.89,606.88 1895.9,606.88 1895.91,606.88 1895.92,606.88 1895.93,606.88 1895.94,606.88 1895.95,606.88 1895.96,606.88 1895.97,606.88 1895.97,606.88 1895.98,606.88 1895.99,606.88 1896,606.88 1896.01,606.88 1896.02,606.88 1896.03,606.88 1896.04,606.88 1896.05,606.88 1896.06,606.88 1896.07,606.88 1896.08,606.88 1896.08,606.88 1896.09,606.88 1896.1,606.88 1896.11,606.88 1896.12,606.88 1896.13,606.88 1896.14,606.88 1896.15,606.88 1896.16,606.88 1896.17,606.88 1896.18,606.88 1896.19,606.88 1896.2,606.88 1896.2,606.88 1896.21,606.88 1896.22,606.88 1896.23,606.88 1896.24,606.88 1896.25,606.88 1896.26,606.88 1896.27,606.88 1896.28,606.88 1896.29,606.88 1896.3,606.88 1896.31,606.88 1896.31,606.88 1896.32,606.88 1896.33,606.88 1896.34,606.88 1896.35,606.88 1896.36,606.88 1896.37,606.88 1896.38,606.88 1896.39,606.88 1896.4,606.88 1896.41,606.88 1896.42,606.88 1896.42,606.88 1896.43,606.88 1896.44,606.88 1896.45,606.88 1896.46,606.88 1896.47,606.88 1896.48,606.88 1896.49,606.88 1896.5,606.88 1896.51,606.88 1896.52,606.88 1896.53,606.88 1896.54,606.88 1896.54,606.88 1896.55,606.88 1896.56,606.88 1896.57,606.88 1896.58,606.88 1896.59,606.88 1896.6,606.88 1896.61,606.88 1896.62,606.88 1896.63,606.88 1896.64,606.88 1896.65,606.88 1896.65,606.88 1896.66,606.88 1896.67,606.88 1896.68,606.88 1896.69,606.88 1896.7,606.88 1896.71,606.88 1896.72,606.88 1896.73,606.88 1896.74,606.88 1896.75,606.88 1896.76,606.88 1896.76,606.88 1896.77,606.88 1896.78,606.88 1896.79,606.88 1896.8,606.88 1896.81,606.88 1896.82,606.88 1896.83,606.88 1896.84,606.88 1896.85,606.88 1896.86,606.88 1896.87,606.88 1896.88,606.88 1896.88,606.88 1896.89,606.88 1896.9,606.88 1896.91,606.88 1896.92,606.88 1896.93,606.88 1896.94,606.88 1896.95,606.88 1896.96,606.88 1896.97,606.88 1896.98,606.88 1896.99,606.88 1896.99,606.88 1897,606.88 1897.01,606.88 1897.02,606.88 1897.03,606.88 1897.04,606.88 1897.05,606.88 1897.06,606.88 1897.07,606.88 1897.08,606.88 1897.09,606.88 1897.1,606.88 1897.1,606.88 1897.11,606.88 1897.12,606.88 1897.13,606.88 1897.14,606.88 1897.15,606.88 1897.16,606.88 1897.17,606.88 1897.18,606.88 1897.19,606.88 1897.2,606.88 1897.21,606.88 1897.22,606.88 1897.22,606.88 1897.23,606.88 1897.24,606.88 1897.25,606.88 1897.26,606.88 1897.27,606.88 1897.28,606.88 1897.29,606.88 1897.3,606.88 1897.31,606.88 1897.32,606.88 1897.33,606.88 1897.33,606.88 1897.34,606.88 1897.35,606.88 1897.36,606.88 1897.37,606.88 1897.38,606.88 1897.39,606.88 1897.4,606.88 1897.41,606.88 1897.42,606.88 1897.43,606.88 1897.44,606.88 1897.44,606.88 1897.45,606.88 1897.46,606.88 1897.47,606.88 1897.48,606.88 1897.49,606.88 1897.5,606.88 1897.51,606.88 1897.52,606.88 1897.53,606.88 1897.54,606.88 1897.55,606.88 1897.56,606.88 1897.56,606.88 1897.57,606.88 1897.58,606.88 1897.59,606.88 1897.6,606.88 1897.61,606.88 1897.62,606.88 1897.63,606.88 1897.64,606.88 1897.65,606.88 1897.66,606.88 1897.67,606.88 1897.67,606.88 1897.68,606.88 1897.69,606.88 1897.7,606.88 1897.71,606.88 1897.72,606.88 1897.73,606.88 1897.74,606.88 1897.75,606.88 1897.76,606.88 1897.77,606.88 1897.78,606.88 1897.78,606.88 1897.79,606.88 1897.8,606.88 1897.81,606.88 1897.82,606.88 1897.83,606.88 1897.84,606.88 1897.85,606.88 1897.86,606.88 1897.87,606.88 1897.88,606.88 1897.89,606.88 1897.9,606.88 1897.9,606.88 1897.91,606.88 1897.92,606.88 1897.93,606.88 1897.94,606.88 1897.95,606.88 1897.96,606.88 1897.97,606.88 1897.98,606.88 1897.99,606.88 1898,606.88 1898.01,606.88 1898.01,606.88 1898.02,606.88 1898.03,606.88 1898.04,606.88 1898.05,606.88 1898.06,606.88 1898.07,606.88 1898.08,606.88 1898.09,606.88 1898.1,606.88 1898.11,606.88 1898.12,606.88 1898.12,606.88 1898.13,606.88 1898.14,606.88 1898.15,606.88 1898.16,606.88 1898.17,606.88 1898.18,606.88 1898.19,606.88 1898.2,606.88 1898.21,606.88 1898.22,606.88 1898.23,606.88 1898.24,606.88 1898.24,606.88 1898.25,606.88 1898.26,606.88 1898.27,606.88 1898.28,606.88 1898.29,606.88 1898.3,606.88 1898.31,606.88 1898.32,606.88 1898.33,606.88 1898.34,606.88 1898.35,606.88 1898.35,606.88 1898.36,606.88 1898.37,606.88 1898.38,606.88 1898.39,606.88 1898.4,606.88 1898.41,606.88 1898.42,606.88 1898.43,606.88 1898.44,606.88 1898.45,606.88 1898.46,606.88 1898.46,606.88 1898.47,606.88 1898.48,606.88 1898.49,606.88 1898.5,606.88 1898.51,606.88 1898.52,606.88 1898.53,606.88 1898.54,606.88 1898.55,606.88 1898.56,606.88 1898.57,606.88 1898.58,606.88 1898.58,606.88 1898.59,606.88 1898.6,606.88 1898.61,606.88 1898.62,606.88 1898.63,606.88 1898.64,606.88 1898.65,606.88 1898.66,606.88 1898.67,606.88 1898.68,606.88 1898.69,606.88 1898.69,606.88 1898.7,606.88 1898.71,606.88 1898.72,606.88 1898.73,606.88 1898.74,606.88 1898.75,606.88 1898.76,606.88 1898.77,606.88 1898.78,606.88 1898.79,606.88 1898.8,606.88 1898.8,606.88 1898.81,606.88 1898.82,606.88 1898.83,606.88 1898.84,606.88 1898.85,606.88 1898.86,606.88 1898.87,606.88 1898.88,606.88 1898.89,606.88 1898.9,606.88 1898.91,606.88 1898.92,606.88 1898.92,606.88 1898.93,606.88 1898.94,606.88 1898.95,606.88 1898.96,606.88 1898.97,606.88 1898.98,606.88 1898.99,606.88 1899,606.88 1899.01,606.88 1899.02,606.88 1899.03,606.88 1899.03,606.88 1899.04,606.88 1899.05,606.88 1899.06,606.88 1899.07,606.88 1899.08,606.88 1899.09,606.88 1899.1,606.88 1899.11,606.88 1899.12,606.88 1899.13,606.88 1899.14,606.88 1899.14,606.88 1899.15,606.88 1899.16,606.88 1899.17,606.88 1899.18,606.88 1899.19,606.88 1899.2,606.88 1899.21,606.88 1899.22,606.88 1899.23,606.88 1899.24,606.88 1899.25,606.88 1899.26,606.88 1899.26,606.88 1899.27,606.88 1899.28,606.88 1899.29,606.88 1899.3,606.88 1899.31,606.88 1899.32,606.88 1899.33,606.88 1899.34,606.88 1899.35,606.88 1899.36,606.88 1899.37,606.88 1899.37,606.88 1899.38,606.88 1899.39,606.88 1899.4,606.88 1899.41,606.88 1899.42,606.88 1899.43,606.88 1899.44,606.88 1899.45,606.88 1899.46,606.88 1899.47,606.88 1899.48,606.88 1899.48,606.88 1899.49,606.88 1899.5,606.88 1899.51,606.88 1899.52,606.88 1899.53,606.88 1899.54,606.88 1899.55,606.88 1899.56,606.88 1899.57,606.88 1899.58,606.88 1899.59,606.88 1899.6,606.88 1899.6,606.88 1899.61,606.88 1899.62,606.88 1899.63,606.88 1899.64,606.88 1899.65,606.88 1899.66,606.88 1899.67,606.88 1899.68,606.88 1899.69,606.88 1899.7,606.88 1899.71,606.88 1899.71,606.88 1899.72,606.88 1899.73,606.88 1899.74,606.88 1899.75,606.88 1899.76,606.88 1899.77,606.88 1899.78,606.88 1899.79,606.88 1899.8,606.88 1899.81,606.88 1899.82,606.88 1899.82,606.88 1899.83,606.88 1899.84,606.88 1899.85,606.88 1899.86,606.88 1899.87,606.88 1899.88,606.88 1899.89,606.88 1899.9,606.88 1899.91,606.88 1899.92,606.88 1899.93,606.88 1899.94,606.88 1899.94,606.88 1899.95,606.88 1899.96,606.88 1899.97,606.88 1899.98,606.88 1899.99,606.88 1900,606.88 1900.01,606.88 1900.02,606.88 1900.03,606.88 1900.04,606.88 1900.05,606.88 1900.05,606.88 1900.06,606.88 1900.07,606.88 1900.08,606.88 1900.09,606.88 1900.1,606.88 1900.11,606.88 1900.12,606.88 1900.13,606.88 1900.14,606.88 1900.15,606.88 1900.16,606.88 1900.16,606.88 1900.17,606.88 1900.18,606.88 1900.19,606.88 1900.2,606.88 1900.21,606.88 1900.22,606.88 1900.23,606.88 1900.24,606.88 1900.25,606.88 1900.26,606.88 1900.27,606.88 1900.28,606.88 1900.28,606.88 1900.29,606.88 1900.3,606.88 1900.31,606.88 1900.32,606.88 1900.33,606.88 1900.34,606.88 1900.35,606.88 1900.36,606.88 1900.37,606.88 1900.38,606.88 1900.39,606.88 1900.39,606.88 1900.4,606.88 1900.41,606.88 1900.42,606.88 1900.43,606.88 1900.44,606.88 1900.45,606.88 1900.46,606.88 1900.47,606.88 1900.48,606.88 1900.49,606.88 1900.5,606.88 1900.51,606.88 1900.51,606.88 1900.52,606.88 1900.53,606.88 1900.54,606.88 1900.55,606.88 1900.56,606.88 1900.57,606.88 1900.58,606.88 1900.59,606.88 1900.6,606.88 1900.61,606.88 1900.62,606.88 1900.62,606.88 1900.63,606.88 1900.64,606.88 1900.65,606.88 1900.66,606.88 1900.67,606.88 1900.68,606.88 1900.69,606.88 1900.7,606.88 1900.71,606.88 1900.72,606.88 1900.73,606.88 1900.73,606.88 1900.74,606.88 1900.75,606.88 1900.76,606.88 1900.77,606.88 1900.78,606.88 1900.79,606.88 1900.8,606.88 1900.81,606.88 1900.82,606.88 1900.83,606.88 1900.84,606.88 1900.85,606.88 1900.85,606.88 1900.86,606.88 1900.87,606.88 1900.88,606.88 1900.89,606.88 1900.9,606.88 1900.91,606.88 1900.92,606.88 1900.93,606.88 1900.94,606.88 1900.95,606.88 1900.96,606.88 1900.96,606.88 1900.97,606.88 1900.98,606.88 1900.99,606.88 1901,606.88 1901.01,606.88 1901.02,606.88 1901.03,606.88 1901.04,606.88 1901.05,606.88 1901.06,606.88 1901.07,606.88 1901.07,606.88 1901.08,606.88 1901.09,606.88 1901.1,606.88 1901.11,606.88 1901.12,606.88 1901.13,606.88 1901.14,606.88 1901.15,606.88 1901.16,606.88 1901.17,606.88 1901.18,606.88 1901.19,606.88 1901.19,606.88 1901.2,606.88 1901.21,606.88 1901.22,606.88 1901.23,606.88 1901.24,606.88 1901.25,606.88 1901.26,606.88 1901.27,606.88 1901.28,606.88 1901.29,606.88 1901.3,606.88 1901.3,606.88 1901.31,606.88 1901.32,606.88 1901.33,606.88 1901.34,606.88 1901.35,606.88 1901.36,606.88 1901.37,606.88 1901.38,606.88 1901.39,606.88 1901.4,606.88 1901.41,606.88 1901.41,606.88 1901.42,606.88 1901.43,606.88 1901.44,606.88 1901.45,606.88 1901.46,606.88 1901.47,606.88 1901.48,606.88 1901.49,606.88 1901.5,606.88 1901.51,606.88 1901.52,606.88 1901.53,606.88 1901.53,606.88 1901.54,606.88 1901.55,606.88 1901.56,606.88 1901.57,606.88 1901.58,606.88 1901.59,606.88 1901.6,606.88 1901.61,606.88 1901.62,606.88 1901.63,606.88 1901.64,606.88 1901.64,606.88 1901.65,606.88 1901.66,606.88 1901.67,606.88 1901.68,606.88 1901.69,606.88 1901.7,606.88 1901.71,606.88 1901.72,606.88 1901.73,606.88 1901.74,606.88 1901.75,606.88 1901.75,606.88 1901.76,606.88 1901.77,606.88 1901.78,606.88 1901.79,606.88 1901.8,606.88 1901.81,606.88 1901.82,606.88 1901.83,606.88 1901.84,606.88 1901.85,606.88 1901.86,606.88 1901.87,606.88 1901.87,606.88 1901.88,606.88 1901.89,606.88 1901.9,606.88 1901.91,606.88 1901.92,606.88 1901.93,606.88 1901.94,606.88 1901.95,606.88 1901.96,606.88 1901.97,606.88 1901.98,606.88 1901.98,606.88 1901.99,606.88 1902,606.88 1902.01,606.88 1902.02,606.88 1902.03,606.88 1902.04,606.88 1902.05,606.88 1902.06,606.88 1902.07,606.88 1902.08,606.88 1902.09,606.88 1902.09,606.88 1902.1,606.88 1902.11,606.88 1902.12,606.88 1902.13,606.88 1902.14,606.88 1902.15,606.88 1902.16,606.88 1902.17,606.88 1902.18,606.88 1902.19,606.88 1902.2,606.88 1902.21,606.88 1902.21,606.88 1902.22,606.88 1902.23,606.88 1902.24,606.88 1902.25,606.88 1902.26,606.88 1902.27,606.88 1902.28,606.88 1902.29,606.88 1902.3,606.88 1902.31,606.88 1902.32,606.88 1902.32,606.88 1902.33,606.88 1902.34,606.88 1902.35,606.88 1902.36,606.88 1902.37,606.88 1902.38,606.88 1902.39,606.88 1902.4,606.88 1902.41,606.88 1902.42,606.88 1902.43,606.88 1902.43,606.88 1902.44,606.88 1902.45,606.88 1902.46,606.88 1902.47,606.88 1902.48,606.88 1902.49,606.88 1902.5,606.88 1902.51,606.88 1902.52,606.88 1902.53,606.88 1902.54,606.88 1902.55,606.88 1902.55,606.88 1902.56,606.88 1902.57,606.88 1902.58,606.88 1902.59,606.88 1902.6,606.88 1902.61,606.88 1902.62,606.88 1902.63,606.88 1902.64,606.88 1902.65,606.88 1902.66,606.88 1902.66,606.88 1902.67,606.88 1902.68,606.88 1902.69,606.88 1902.7,606.88 1902.71,606.88 1902.72,606.88 1902.73,606.88 1902.74,606.88 1902.75,606.88 1902.76,606.88 1902.77,606.88 1902.77,606.88 1902.78,606.88 1902.79,606.88 1902.8,606.88 1902.81,606.88 1902.82,606.88 1902.83,606.88 1902.84,606.88 1902.85,606.88 1902.86,606.88 1902.87,606.88 1902.88,606.88 1902.89,606.88 1902.89,606.88 1902.9,606.88 1902.91,606.88 1902.92,606.88 1902.93,606.88 1902.94,606.88 1902.95,606.88 1902.96,606.88 1902.97,606.88 1902.98,606.88 1902.99,606.88 1903,606.88 1903,606.88 1903.01,606.88 1903.02,606.88 1903.03,606.88 1903.04,606.88 1903.05,606.88 1903.06,606.88 1903.07,606.88 1903.08,606.88 1903.09,606.88 1903.1,606.88 1903.11,606.88 1903.11,606.88 1903.12,606.88 1903.13,606.88 1903.14,606.88 1903.15,606.88 1903.16,606.88 1903.17,606.88 1903.18,606.88 1903.19,606.88 1903.2,606.88 1903.21,606.88 1903.22,606.88 1903.23,606.88 1903.23,606.88 1903.24,606.88 1903.25,606.88 1903.26,606.88 1903.27,606.88 1903.28,606.88 1903.29,606.88 1903.3,606.88 1903.31,606.88 1903.32,606.88 1903.33,606.88 1903.34,606.88 1903.34,606.88 1903.35,606.88 1903.36,606.88 1903.37,606.88 1903.38,606.88 1903.39,606.88 1903.4,606.88 1903.41,606.88 1903.42,606.88 1903.43,606.88 1903.44,606.88 1903.45,606.88 1903.45,606.88 1903.46,606.88 1903.47,606.88 1903.48,606.88 1903.49,606.88 1903.5,606.88 1903.51,606.88 1903.52,606.88 1903.53,606.88 1903.54,606.88 1903.55,606.88 1903.56,606.88 1903.57,606.88 1903.57,606.88 1903.58,606.88 1903.59,606.88 1903.6,606.88 1903.61,606.88 1903.62,606.88 1903.63,606.88 1903.64,606.88 1903.65,606.88 1903.66,606.88 1903.67,606.88 1903.68,606.88 1903.68,606.88 1903.69,606.88 1903.7,606.88 1903.71,606.88 1903.72,606.88 1903.73,606.88 1903.74,606.88 1903.75,606.88 1903.76,606.88 1903.77,606.88 1903.78,606.88 1903.79,606.88 1903.79,606.88 1903.8,606.88 1903.81,606.88 1903.82,606.88 1903.83,606.88 1903.84,606.88 1903.85,606.88 1903.86,606.88 1903.87,606.88 1903.88,606.88 1903.89,606.88 1903.9,606.88 1903.91,606.88 1903.91,606.88 1903.92,606.88 1903.93,606.88 1903.94,606.88 1903.95,606.88 1903.96,606.88 1903.97,606.88 1903.98,606.88 1903.99,606.88 1904,606.88 1904.01,606.88 1904.02,606.88 1904.02,606.88 1904.03,606.88 1904.04,606.88 1904.05,606.88 1904.06,606.88 1904.07,606.88 1904.08,606.88 1904.09,606.88 1904.1,606.88 1904.11,606.88 1904.12,606.88 1904.13,606.88 1904.13,606.88 1904.14,606.88 1904.15,606.88 1904.16,606.88 1904.17,606.88 1904.18,606.88 1904.19,606.88 1904.2,606.88 1904.21,606.88 1904.22,606.88 1904.23,606.88 1904.24,606.88 1904.25,606.88 1904.25,606.88 1904.26,606.88 1904.27,606.88 1904.28,606.88 1904.29,606.88 1904.3,606.88 1904.31,606.88 1904.32,606.88 1904.33,606.88 1904.34,606.88 1904.35,606.88 1904.36,606.88 1904.36,606.88 1904.37,606.88 1904.38,606.88 1904.39,606.88 1904.4,606.88 1904.41,606.88 1904.42,606.88 1904.43,606.88 1904.44,606.88 1904.45,606.88 1904.46,606.88 1904.47,606.88 1904.47,606.88 1904.48,606.88 1904.49,606.88 1904.5,606.88 1904.51,606.88 1904.52,606.88 1904.53,606.88 1904.54,606.88 1904.55,606.88 1904.56,606.88 1904.57,606.88 1904.58,606.88 1904.59,606.88 1904.59,606.88 1904.6,606.88 1904.61,606.88 1904.62,606.88 1904.63,606.88 1904.64,606.88 1904.65,606.88 1904.66,606.88 1904.67,606.88 1904.68,606.88 1904.69,606.88 1904.7,606.88 1904.7,606.88 1904.71,606.88 1904.72,606.88 1904.73,606.88 1904.74,606.88 1904.75,606.88 1904.76,606.88 1904.77,606.88 1904.78,606.88 1904.79,606.88 1904.8,606.88 1904.81,606.88 1904.81,606.88 1904.82,606.88 1904.83,606.88 1904.84,606.88 1904.85,606.88 1904.86,606.88 1904.87,606.88 1904.88,606.88 1904.89,606.88 1904.9,606.88 1904.91,606.88 1904.92,606.88 1904.93,606.88 1904.93,606.88 1904.94,606.88 1904.95,606.88 1904.96,606.88 1904.97,606.88 1904.98,606.88 1904.99,606.88 1905,606.88 1905.01,606.88 1905.02,606.88 1905.03,606.88 1905.04,606.88 1905.04,606.88 1905.05,606.88 1905.06,606.88 1905.07,606.88 1905.08,606.88 1905.09,606.88 1905.1,606.88 1905.11,606.88 1905.12,606.88 1905.13,606.88 1905.14,606.88 1905.15,606.88 1905.15,606.88 1905.16,606.88 1905.17,606.88 1905.18,606.88 1905.19,606.88 1905.2,606.88 1905.21,606.88 1905.22,606.88 1905.23,606.88 1905.24,606.88 1905.25,606.88 1905.26,606.88 1905.27,606.88 1905.27,606.88 1905.28,606.88 1905.29,606.88 1905.3,606.88 1905.31,606.88 1905.32,606.88 1905.33,606.88 1905.34,606.88 1905.35,606.88 1905.36,606.88 1905.37,606.88 1905.38,606.88 1905.38,606.88 1905.39,606.88 1905.4,606.88 1905.41,606.88 1905.42,606.88 1905.43,606.88 1905.44,606.88 1905.45,606.88 1905.46,606.88 1905.47,606.88 1905.48,606.88 1905.49,606.88 1905.49,606.88 1905.5,606.88 1905.51,606.88 1905.52,606.88 1905.53,606.88 1905.54,606.88 1905.55,606.88 1905.56,606.88 1905.57,606.88 1905.58,606.88 1905.59,606.88 1905.6,606.88 1905.61,606.88 1905.61,606.88 1905.62,606.88 1905.63,606.88 1905.64,606.88 1905.65,606.88 1905.66,606.88 1905.67,606.88 1905.68,606.88 1905.69,606.88 1905.7,606.88 1905.71,606.88 1905.72,606.88 1905.72,606.88 1905.73,606.88 1905.74,606.88 1905.75,606.88 1905.76,606.88 1905.77,606.88 1905.78,606.88 1905.79,606.88 1905.8,606.88 1905.81,606.88 1905.82,606.88 1905.83,606.88 1905.83,606.88 1905.84,606.88 1905.85,606.88 1905.86,606.88 1905.87,606.88 1905.88,606.88 1905.89,606.88 1905.9,606.88 1905.91,606.88 1905.92,606.88 1905.93,606.88 1905.94,606.88 1905.95,606.88 1905.95,606.88 1905.96,606.88 1905.97,606.88 1905.98,606.88 1905.99,606.88 1906,606.88 1906.01,606.88 1906.02,606.88 1906.03,606.88 1906.04,606.88 1906.05,606.88 1906.06,606.88 1906.06,606.88 1906.07,606.88 1906.08,606.88 1906.09,606.88 1906.1,606.88 1906.11,606.88 1906.12,606.88 1906.13,606.88 1906.14,606.88 1906.15,606.88 1906.16,606.88 1906.17,606.88 1906.17,606.88 1906.18,606.88 1906.19,606.88 1906.2,606.88 1906.21,606.88 1906.22,606.88 1906.23,606.88 1906.24,606.88 1906.25,606.88 1906.26,606.88 1906.27,606.88 1906.28,606.88 1906.29,606.88 1906.29,606.88 1906.3,606.88 1906.31,606.88 1906.32,606.88 1906.33,606.88 1906.34,606.88 1906.35,606.88 1906.36,606.88 1906.37,606.88 1906.38,606.88 1906.39,606.88 1906.4,606.88 1906.4,606.88 1906.41,606.88 1906.42,606.88 1906.43,606.88 1906.44,606.88 1906.45,606.88 1906.46,606.88 1906.47,606.88 1906.48,606.88 1906.49,606.88 1906.5,606.88 1906.51,606.88 1906.51,606.88 1906.52,606.88 1906.53,606.88 1906.54,606.88 1906.55,606.88 1906.56,606.88 1906.57,606.88 1906.58,606.88 1906.59,606.88 1906.6,606.88 1906.61,606.88 1906.62,606.88 1906.63,606.88 1906.63,606.88 1906.64,606.88 1906.65,606.88 1906.66,606.88 1906.67,606.88 1906.68,606.88 1906.69,606.88 1906.7,606.88 1906.71,606.88 1906.72,606.88 1906.73,606.88 1906.74,606.88 1906.74,606.88 1906.75,606.88 1906.76,606.88 1906.77,606.88 1906.78,606.88 1906.79,606.88 1906.8,606.88 1906.81,606.88 1906.82,606.88 1906.83,606.88 1906.84,606.88 1906.85,606.88 1906.85,606.88 1906.86,606.88 1906.87,606.88 1906.88,606.88 1906.89,606.88 1906.9,606.88 1906.91,606.88 1906.92,606.88 1906.93,606.88 1906.94,606.88 1906.95,606.88 1906.96,606.88 1906.97,606.88 1906.97,606.88 1906.98,606.88 1906.99,606.88 1907,606.88 1907.01,606.88 1907.02,606.88 1907.03,606.88 1907.04,606.88 1907.05,606.88 1907.06,606.88 1907.07,606.88 1907.08,606.88 1907.08,606.88 1907.09,606.88 1907.1,606.88 1907.11,606.88 1907.12,606.88 1907.13,606.88 1907.14,606.88 1907.15,606.88 1907.16,606.88 1907.17,606.88 1907.18,606.88 1907.19,606.88 1907.19,606.88 1907.2,606.88 1907.21,606.88 1907.22,606.88 1907.23,606.88 1907.24,606.88 1907.25,606.88 1907.26,606.88 1907.27,606.88 1907.28,606.88 1907.29,606.88 1907.3,606.88 1907.31,606.88 1907.31,606.88 1907.32,606.88 1907.33,606.88 1907.34,606.88 1907.35,606.88 1907.36,606.88 1907.37,606.88 1907.38,606.88 1907.39,606.88 1907.4,606.88 1907.41,606.88 1907.42,606.88 1907.42,606.88 1907.43,606.88 1907.44,606.88 1907.45,606.88 1907.46,606.88 1907.47,606.88 1907.48,606.88 1907.49,606.88 1907.5,606.88 1907.51,606.88 1907.52,606.88 1907.53,606.88 1907.53,606.88 1907.54,606.88 1907.55,606.88 1907.56,606.88 1907.57,606.88 1907.58,606.88 1907.59,606.88 1907.6,606.88 1907.61,606.88 1907.62,606.88 1907.63,606.88 1907.64,606.88 1907.65,606.88 1907.65,606.88 1907.66,606.88 1907.67,606.88 1907.68,606.88 1907.69,606.88 1907.7,606.88 1907.71,606.88 1907.72,606.88 1907.73,606.88 1907.74,606.88 1907.75,606.88 1907.76,606.88 1907.76,606.88 1907.77,606.88 1907.78,606.88 1907.79,606.88 1907.8,606.88 1907.81,606.88 1907.82,606.88 1907.83,606.88 1907.84,606.88 1907.85,606.88 1907.86,606.88 1907.87,606.88 1907.87,606.88 1907.88,606.88 1907.89,606.88 1907.9,606.88 1907.91,606.88 1907.92,606.88 1907.93,606.88 1907.94,606.88 1907.95,606.88 1907.96,606.88 1907.97,606.88 1907.98,606.88 1907.99,606.88 1907.99,606.88 1908,606.88 1908.01,606.88 1908.02,606.88 1908.03,606.88 1908.04,606.88 1908.05,606.88 1908.06,606.88 1908.07,606.88 1908.08,606.88 1908.09,606.88 1908.1,606.88 1908.1,606.88 1908.11,606.88 1908.12,606.88 1908.13,606.88 1908.14,606.88 1908.15,606.88 1908.16,606.88 1908.17,606.88 1908.18,606.88 1908.19,606.88 1908.2,606.88 1908.21,606.88 1908.21,606.88 1908.22,606.88 1908.23,606.88 1908.24,606.88 1908.25,606.88 1908.26,606.88 1908.27,606.88 1908.28,606.88 1908.29,606.88 1908.3,606.88 1908.31,606.88 1908.32,606.88 1908.33,606.88 1908.33,606.88 1908.34,606.88 1908.35,606.88 1908.36,606.88 1908.37,606.88 1908.38,606.88 1908.39,606.88 1908.4,606.88 1908.41,606.88 1908.42,606.88 1908.43,606.88 1908.44,606.88 1908.44,606.88 1908.45,606.88 1908.46,606.88 1908.47,606.88 1908.48,606.88 1908.49,606.88 1908.5,606.88 1908.51,606.88 1908.52,606.88 1908.53,606.88 1908.54,606.88 1908.55,606.88 1908.55,606.88 1908.56,606.88 1908.57,606.88 1908.58,606.88 1908.59,606.88 1908.6,606.88 1908.61,606.88 1908.62,606.88 1908.63,606.88 1908.64,606.88 1908.65,606.88 1908.66,606.88 1908.67,606.88 1908.67,606.88 1908.68,606.88 1908.69,606.88 1908.7,606.88 1908.71,606.88 1908.72,606.88 1908.73,606.88 1908.74,606.88 1908.75,606.88 1908.76,606.88 1908.77,606.88 1908.78,606.88 1908.78,606.88 1908.79,606.88 1908.8,606.88 1908.81,606.88 1908.82,606.88 1908.83,606.88 1908.84,606.88 1908.85,606.88 1908.86,606.88 1908.87,606.88 1908.88,606.88 1908.89,606.88 1908.89,606.88 1908.9,606.88 1908.91,606.88 1908.92,606.88 1908.93,606.88 1908.94,606.88 1908.95,606.88 1908.96,606.88 1908.97,606.88 1908.98,606.88 1908.99,606.88 1909,606.88 1909.01,606.88 1909.01,606.88 1909.02,606.88 1909.03,606.88 1909.04,606.88 1909.05,606.88 1909.06,606.88 1909.07,606.88 1909.08,606.88 1909.09,606.88 1909.1,606.88 1909.11,606.88 1909.12,606.88 1909.12,606.88 1909.13,606.88 1909.14,606.88 1909.15,606.88 1909.16,606.88 1909.17,606.88 1909.18,606.88 1909.19,606.88 1909.2,606.88 1909.21,606.88 1909.22,606.88 1909.23,606.88 1909.23,606.88 1909.24,606.88 1909.25,606.88 1909.26,606.88 1909.27,606.88 1909.28,606.88 1909.29,606.88 1909.3,606.88 1909.31,606.88 1909.32,606.88 1909.33,606.88 1909.34,606.88 1909.35,606.88 1909.35,606.88 1909.36,606.88 1909.37,606.88 1909.38,606.88 1909.39,606.88 1909.4,606.88 1909.41,606.88 1909.42,606.88 1909.43,606.88 1909.44,606.88 1909.45,606.88 1909.46,606.88 1909.46,606.88 1909.47,606.88 1909.48,606.88 1909.49,606.88 1909.5,606.88 1909.51,606.88 1909.52,606.88 1909.53,606.88 1909.54,606.88 1909.55,606.88 1909.56,606.88 1909.57,606.88 1909.57,606.88 1909.58,606.88 1909.59,606.88 1909.6,606.88 1909.61,606.88 1909.62,606.88 1909.63,606.88 1909.64,606.88 1909.65,606.88 1909.66,606.88 1909.67,606.88 1909.68,606.88 1909.69,606.88 1909.69,606.88 1909.7,606.88 1909.71,606.88 1909.72,606.88 1909.73,606.88 1909.74,606.88 1909.75,606.88 1909.76,606.88 1909.77,606.88 1909.78,606.88 1909.79,606.88 1909.8,606.88 1909.8,606.88 1909.81,606.88 1909.82,606.88 1909.83,606.88 1909.84,606.88 1909.85,606.88 1909.86,606.88 1909.87,606.88 1909.88,606.88 1909.89,606.88 1909.9,606.88 1909.91,606.88 1909.91,606.88 1909.92,606.88 1909.93,606.88 1909.94,606.88 1909.95,606.88 1909.96,606.88 1909.97,606.88 1909.98,606.88 1909.99,606.88 1910,606.88 1910.01,606.88 1910.02,606.88 1910.03,606.88 1910.03,606.88 1910.04,606.88 1910.05,606.88 1910.06,606.88 1910.07,606.88 1910.08,606.88 1910.09,606.88 1910.1,606.88 1910.11,606.88 1910.12,606.88 1910.13,606.88 1910.14,606.88 1910.14,606.88 1910.15,606.88 1910.16,606.88 1910.17,606.88 1910.18,606.88 1910.19,606.88 1910.2,606.88 1910.21,606.88 1910.22,606.88 1910.23,606.88 1910.24,606.88 1910.25,606.88 1910.25,606.88 1910.26,606.88 1910.27,606.88 1910.28,606.88 1910.29,606.88 1910.3,606.88 1910.31,606.88 1910.32,606.88 1910.33,606.88 1910.34,606.88 1910.35,606.88 1910.36,606.88 1910.37,606.88 1910.37,606.88 1910.38,606.88 1910.39,606.88 1910.4,606.88 1910.41,606.88 1910.42,606.88 1910.43,606.88 1910.44,606.88 1910.45,606.88 1910.46,606.88 1910.47,606.88 1910.48,606.88 1910.48,606.88 1910.49,606.88 1910.5,606.88 1910.51,606.88 1910.52,606.88 1910.53,606.88 1910.54,606.88 1910.55,606.88 1910.56,606.88 1910.57,606.88 1910.58,606.88 1910.59,606.88 1910.59,606.88 1910.6,606.88 1910.61,606.88 1910.62,606.88 1910.63,606.88 1910.64,606.88 1910.65,606.88 1910.66,606.88 1910.67,606.88 1910.68,606.88 1910.69,606.88 1910.7,606.88 1910.71,606.88 1910.71,606.88 1910.72,606.88 1910.73,606.88 1910.74,606.88 1910.75,606.88 1910.76,606.88 1910.77,606.88 1910.78,606.88 1910.79,606.88 1910.8,606.88 1910.81,606.88 1910.82,606.88 1910.82,606.88 1910.83,606.88 1910.84,606.88 1910.85,606.88 1910.86,606.88 1910.87,606.88 1910.88,606.88 1910.89,606.88 1910.9,606.88 1910.91,606.88 1910.92,606.88 1910.93,606.88 1910.93,606.88 1910.94,606.88 1910.95,606.88 1910.96,606.88 1910.97,606.88 1910.98,606.88 1910.99,606.88 1911,606.88 1911.01,606.88 1911.02,606.88 1911.03,606.88 1911.04,606.88 1911.05,606.88 1911.05,606.88 1911.06,606.88 1911.07,606.88 1911.08,606.88 1911.09,606.88 1911.1,606.88 1911.11,606.88 1911.12,606.88 1911.13,606.88 1911.14,606.88 1911.15,606.88 1911.16,606.88 1911.16,606.88 1911.17,606.88 1911.18,606.88 1911.19,606.88 1911.2,606.88 1911.21,606.88 1911.22,606.88 1911.23,606.88 1911.24,606.88 1911.25,606.88 1911.26,606.88 1911.27,606.88 1911.27,606.88 1911.28,606.88 1911.29,606.88 1911.3,606.88 1911.31,606.88 1911.32,606.88 1911.33,606.88 1911.34,606.88 1911.35,606.88 1911.36,606.88 1911.37,606.88 1911.38,606.88 1911.39,606.88 1911.39,606.88 1911.4,606.88 1911.41,606.88 1911.42,606.88 1911.43,606.88 1911.44,606.88 1911.45,606.88 1911.46,606.88 1911.47,606.88 1911.48,606.88 1911.49,606.88 1911.5,606.88 1911.5,606.88 1911.51,606.88 1911.52,606.88 1911.53,606.88 1911.54,606.88 1911.55,606.88 1911.56,606.88 1911.57,606.88 1911.58,606.88 1911.59,606.88 1911.6,606.88 1911.61,606.88 1911.61,606.88 1911.62,606.88 1911.63,606.88 1911.64,606.88 1911.65,606.88 1911.66,606.88 1911.67,606.88 1911.68,606.88 1911.69,606.88 1911.7,606.88 1911.71,606.88 1911.72,606.88 1911.73,606.88 1911.73,606.88 1911.74,606.88 1911.75,606.88 1911.76,606.88 1911.77,606.88 1911.78,606.88 1911.79,606.88 1911.8,606.88 1911.81,606.88 1911.82,606.88 1911.83,606.88 1911.84,606.88 1911.84,606.88 1911.85,606.88 1911.86,606.88 1911.87,606.88 1911.88,606.88 1911.89,606.88 1911.9,606.88 1911.91,606.88 1911.92,606.88 1911.93,606.88 1911.94,606.88 1911.95,606.88 1911.95,606.88 1911.96,606.88 1911.97,606.88 1911.98,606.88 1911.99,606.88 1912,606.88 1912.01,606.88 1912.02,606.88 1912.03,606.88 1912.04,606.88 1912.05,606.88 1912.06,606.88 1912.07,606.88 1912.07,606.88 1912.08,606.88 1912.09,606.88 1912.1,606.88 1912.11,606.88 1912.12,606.88 1912.13,606.88 1912.14,606.88 1912.15,606.88 1912.16,606.88 1912.17,606.88 1912.18,606.88 1912.18,606.88 1912.19,606.88 1912.2,606.88 1912.21,606.88 1912.22,606.88 1912.23,606.88 1912.24,606.88 1912.25,606.88 1912.26,606.88 1912.27,606.88 1912.28,606.88 1912.29,606.88 1912.29,606.88 1912.3,606.88 1912.31,606.88 1912.32,606.88 1912.33,606.88 1912.34,606.88 1912.35,606.88 1912.36,606.88 1912.37,606.88 1912.38,606.88 1912.39,606.88 1912.4,606.88 1912.41,606.88 1912.41,606.88 1912.42,606.88 1912.43,606.88 1912.44,606.88 1912.45,606.88 1912.46,606.88 1912.47,606.88 1912.48,606.88 1912.49,606.88 1912.5,606.88 1912.51,606.88 1912.52,606.88 1912.52,606.88 1912.53,606.88 1912.54,606.88 1912.55,606.88 1912.56,606.88 1912.57,606.88 1912.58,606.88 1912.59,606.88 1912.6,606.88 1912.61,606.88 1912.62,606.88 1912.63,606.88 1912.63,606.88 1912.64,606.88 1912.65,606.88 1912.66,606.88 1912.67,606.88 1912.68,606.88 1912.69,606.88 1912.7,606.88 1912.71,606.88 1912.72,606.88 1912.73,606.88 1912.74,606.88 1912.75,606.88 1912.75,606.88 1912.76,606.88 1912.77,606.88 1912.78,606.88 1912.79,606.88 1912.8,606.88 1912.81,606.88 1912.82,606.88 1912.83,606.88 1912.84,606.88 1912.85,606.88 1912.86,606.88 1912.86,606.88 1912.87,606.88 1912.88,606.88 1912.89,606.88 1912.9,606.88 1912.91,606.88 1912.92,606.88 1912.93,606.88 1912.94,606.88 1912.95,606.88 1912.96,606.88 1912.97,606.88 1912.97,606.88 1912.98,606.88 1912.99,606.88 1913,606.88 1913.01,606.88 1913.02,606.88 1913.03,606.88 1913.04,606.88 1913.05,606.88 1913.06,606.88 1913.07,606.88 1913.08,606.88 1913.09,606.88 1913.09,606.88 1913.1,606.88 1913.11,606.88 1913.12,606.88 1913.13,606.88 1913.14,606.88 1913.15,606.88 1913.16,606.88 1913.17,606.88 1913.18,606.88 1913.19,606.88 1913.2,606.88 1913.2,606.88 1913.21,606.88 1913.22,606.88 1913.23,606.88 1913.24,606.88 1913.25,606.88 1913.26,606.88 1913.27,606.88 1913.28,606.88 1913.29,606.88 1913.3,606.88 1913.31,606.88 1913.31,606.88 1913.32,606.88 1913.33,606.88 1913.34,606.88 1913.35,606.88 1913.36,606.88 1913.37,606.88 1913.38,606.88 1913.39,606.88 1913.4,606.88 1913.41,606.88 1913.42,606.88 1913.43,606.88 1913.43,606.88 1913.44,606.88 1913.45,606.88 1913.46,606.88 1913.47,606.88 1913.48,606.88 1913.49,606.88 1913.5,606.88 1913.51,606.88 1913.52,606.88 1913.53,606.88 1913.54,606.88 1913.54,606.88 1913.55,606.88 1913.56,606.88 1913.57,606.88 1913.58,606.88 1913.59,606.88 1913.6,606.88 1913.61,606.88 1913.62,606.88 1913.63,606.88 1913.64,606.88 1913.65,606.88 1913.65,606.88 1913.66,606.88 1913.67,606.88 1913.68,606.88 1913.69,606.88 1913.7,606.88 1913.71,606.88 1913.72,606.88 1913.73,606.88 1913.74,606.88 1913.75,606.88 1913.76,606.88 1913.77,606.88 1913.77,606.88 1913.78,606.88 1913.79,606.88 1913.8,606.88 1913.81,606.88 1913.82,606.88 1913.83,606.88 1913.84,606.88 1913.85,606.88 1913.86,606.88 1913.87,606.88 1913.88,606.88 1913.88,606.88 1913.89,606.88 1913.9,606.88 1913.91,606.88 1913.92,606.88 1913.93,606.88 1913.94,606.88 1913.95,606.88 1913.96,606.88 1913.97,606.88 1913.98,606.88 1913.99,606.88 1913.99,606.88 1914,606.88 1914.01,606.88 1914.02,606.88 1914.03,606.88 1914.04,606.88 1914.05,606.88 1914.06,606.88 1914.07,606.88 1914.08,606.88 1914.09,606.88 1914.1,606.88 1914.11,606.88 1914.11,606.88 1914.12,606.88 1914.13,606.88 1914.14,606.88 1914.15,606.88 1914.16,606.88 1914.17,606.88 1914.18,606.88 1914.19,606.88 1914.2,606.88 1914.21,606.88 1914.22,606.88 1914.22,606.88 1914.23,606.88 1914.24,606.88 1914.25,606.88 1914.26,606.88 1914.27,606.88 1914.28,606.88 1914.29,606.88 1914.3,606.88 1914.31,606.88 1914.32,606.88 1914.33,606.88 1914.33,606.88 1914.34,606.88 1914.35,606.88 1914.36,606.88 1914.37,606.88 1914.38,606.88 1914.39,606.88 1914.4,606.88 1914.41,606.88 1914.42,606.88 1914.43,606.88 1914.44,606.88 1914.45,606.88 1914.45,606.88 1914.46,606.88 1914.47,606.88 1914.48,606.88 1914.49,606.88 1914.5,606.88 1914.51,606.88 1914.52,606.88 1914.53,606.88 1914.54,606.88 1914.55,606.88 1914.56,606.88 1914.56,606.88 1914.57,606.88 1914.58,606.88 1914.59,606.88 1914.6,606.88 1914.61,606.88 1914.62,606.88 1914.63,606.88 1914.64,606.88 1914.65,606.88 1914.66,606.88 1914.67,606.88 1914.67,606.88 1914.68,606.88 1914.69,606.88 1914.7,606.88 1914.71,606.88 1914.72,606.88 1914.73,606.88 1914.74,606.88 1914.75,606.88 1914.76,606.88 1914.77,606.88 1914.78,606.88 1914.79,606.88 1914.79,606.88 1914.8,606.88 1914.81,606.88 1914.82,606.88 1914.83,606.88 1914.84,606.88 1914.85,606.88 1914.86,606.88 1914.87,606.88 1914.88,606.88 1914.89,606.88 1914.9,606.88 1914.9,606.88 1914.91,606.88 1914.92,606.88 1914.93,606.88 1914.94,606.88 1914.95,606.88 1914.96,606.88 1914.97,606.88 1914.98,606.88 1914.99,606.88 1915,606.88 1915.01,606.88 1915.01,606.88 1915.02,606.88 1915.03,606.88 1915.04,606.88 1915.05,606.88 1915.06,606.88 1915.07,606.88 1915.08,606.88 1915.09,606.88 1915.1,606.88 1915.11,606.88 1915.12,606.88 1915.13,606.88 1915.13,606.88 1915.14,606.88 1915.15,606.88 1915.16,606.88 1915.17,606.88 1915.18,606.88 1915.19,606.88 1915.2,606.88 1915.21,606.88 1915.22,606.88 1915.23,606.88 1915.24,606.88 1915.24,606.88 1915.25,606.88 1915.26,606.88 1915.27,606.88 1915.28,606.88 1915.29,606.88 1915.3,606.88 1915.31,606.88 1915.32,606.88 1915.33,606.88 1915.34,606.88 1915.35,606.88 1915.35,606.88 1915.36,606.88 1915.37,606.88 1915.38,606.88 1915.39,606.88 1915.4,606.88 1915.41,606.88 1915.42,606.88 1915.43,606.88 1915.44,606.88 1915.45,606.88 1915.46,606.88 1915.47,606.88 1915.47,606.88 1915.48,606.88 1915.49,606.88 1915.5,606.88 1915.51,606.88 1915.52,606.88 1915.53,606.88 1915.54,606.88 1915.55,606.88 1915.56,606.88 1915.57,606.88 1915.58,606.88 1915.58,606.88 1915.59,606.88 1915.6,606.88 1915.61,606.88 1915.62,606.88 1915.63,606.88 1915.64,606.88 1915.65,606.88 1915.66,606.88 1915.67,606.88 1915.68,606.88 1915.69,606.88 1915.69,606.88 1915.7,606.88 1915.71,606.88 1915.72,606.88 1915.73,606.88 1915.74,606.88 1915.75,606.88 1915.76,606.88 1915.77,606.88 1915.78,606.88 1915.79,606.88 1915.8,606.88 1915.81,606.88 1915.81,606.88 1915.82,606.88 1915.83,606.88 1915.84,606.88 1915.85,606.88 1915.86,606.88 1915.87,606.88 1915.88,606.88 1915.89,606.88 1915.9,606.88 1915.91,606.88 1915.92,606.88 1915.92,606.88 1915.93,606.88 1915.94,606.88 1915.95,606.88 1915.96,606.88 1915.97,606.88 1915.98,606.88 1915.99,606.88 1916,606.88 1916.01,606.88 1916.02,606.88 1916.03,606.88 1916.03,606.88 1916.04,606.88 1916.05,606.88 1916.06,606.88 1916.07,606.88 1916.08,606.88 1916.09,606.88 1916.1,606.88 1916.11,606.88 1916.12,606.88 1916.13,606.88 1916.14,606.88 1916.15,606.88 1916.15,606.88 1916.16,606.88 1916.17,606.88 1916.18,606.88 1916.19,606.88 1916.2,606.88 1916.21,606.88 1916.22,606.88 1916.23,606.88 1916.24,606.88 1916.25,606.88 1916.26,606.88 1916.26,606.88 1916.27,606.88 1916.28,606.88 1916.29,606.88 1916.3,606.88 1916.31,606.88 1916.32,606.88 1916.33,606.88 1916.34,606.88 1916.35,606.88 1916.36,606.88 1916.37,606.88 1916.37,606.88 1916.38,606.88 1916.39,606.88 1916.4,606.88 1916.41,606.88 1916.42,606.88 1916.43,606.88 1916.44,606.88 1916.45,606.88 1916.46,606.88 1916.47,606.88 1916.48,606.88 1916.49,606.88 1916.49,606.88 1916.5,606.88 1916.51,606.88 1916.52,606.88 1916.53,606.88 1916.54,606.88 1916.55,606.88 1916.56,606.88 1916.57,606.88 1916.58,606.88 1916.59,606.88 1916.6,606.88 1916.6,606.88 1916.61,606.88 1916.62,606.88 1916.63,606.88 1916.64,606.88 1916.65,606.88 1916.66,606.88 1916.67,606.88 1916.68,606.88 1916.69,606.88 1916.7,606.88 1916.71,606.88 1916.71,606.88 1916.72,606.88 1916.73,606.88 1916.74,606.88 1916.75,606.88 1916.76,606.88 1916.77,606.88 1916.78,606.88 1916.79,606.88 1916.8,606.88 1916.81,606.88 1916.82,606.88 1916.83,606.88 1916.83,606.88 1916.84,606.88 1916.85,606.88 1916.86,606.88 1916.87,606.88 1916.88,606.88 1916.89,606.88 1916.9,606.88 1916.91,606.88 1916.92,606.88 1916.93,606.88 1916.94,606.88 1916.94,606.88 1916.95,606.88 1916.96,606.88 1916.97,606.88 1916.98,606.88 1916.99,606.88 1917,606.88 1917.01,606.88 1917.02,606.88 1917.03,606.88 1917.04,606.88 1917.05,606.88 1917.05,606.88 1917.06,606.88 1917.07,606.88 1917.08,606.88 1917.09,606.88 1917.1,606.88 1917.11,606.88 1917.12,606.88 1917.13,606.88 1917.14,606.88 1917.15,606.88 1917.16,606.88 1917.17,606.88 1917.17,606.88 1917.18,606.88 1917.19,606.88 1917.2,606.88 1917.21,606.88 1917.22,606.88 1917.23,606.88 1917.24,606.88 1917.25,606.88 1917.26,606.88 1917.27,606.88 1917.28,606.88 1917.28,606.88 1917.29,606.88 1917.3,606.88 1917.31,606.88 1917.32,606.88 1917.33,606.88 1917.34,606.88 1917.35,606.88 1917.36,606.88 1917.37,606.88 1917.38,606.88 1917.39,606.88 1917.39,606.88 1917.4,606.88 1917.41,606.88 1917.42,606.88 1917.43,606.88 1917.44,606.88 1917.45,606.88 1917.46,606.88 1917.47,606.88 1917.48,606.88 1917.49,606.88 1917.5,606.88 1917.51,606.88 1917.51,606.88 1917.52,606.88 1917.53,606.88 1917.54,606.88 1917.55,606.88 1917.56,606.88 1917.57,606.88 1917.58,606.88 1917.59,606.88 1917.6,606.88 1917.61,606.88 1917.62,606.88 1917.62,606.88 1917.63,606.88 1917.64,606.88 1917.65,606.88 1917.66,606.88 1917.67,606.88 1917.68,606.88 1917.69,606.88 1917.7,606.88 1917.71,606.88 1917.72,606.88 1917.73,606.88 1917.73,606.88 1917.74,606.88 1917.75,606.88 1917.76,606.88 1917.77,606.88 1917.78,606.88 1917.79,606.88 1917.8,606.88 1917.81,606.88 1917.82,606.88 1917.83,606.88 1917.84,606.88 1917.85,606.88 1917.85,606.88 1917.86,606.88 1917.87,606.88 1917.88,606.88 1917.89,606.88 1917.9,606.88 1917.91,606.88 1917.92,606.88 1917.93,606.88 1917.94,606.88 1917.95,606.88 1917.96,606.88 1917.96,606.88 1917.97,606.88 1917.98,606.88 1917.99,606.88 1918,606.88 1918.01,606.88 1918.02,606.88 1918.03,606.88 1918.04,606.88 1918.05,606.88 1918.06,606.88 1918.07,606.88 1918.07,606.88 1918.08,606.88 1918.09,606.88 1918.1,606.88 1918.11,606.88 1918.12,606.88 1918.13,606.88 1918.14,606.88 1918.15,606.88 1918.16,606.88 1918.17,606.88 1918.18,606.88 1918.19,606.88 1918.19,606.88 1918.2,606.88 1918.21,606.88 1918.22,606.88 1918.23,606.88 1918.24,606.88 1918.25,606.88 1918.26,606.88 1918.27,606.88 1918.28,606.88 1918.29,606.88 1918.3,606.88 1918.3,606.88 1918.31,606.88 1918.32,606.88 1918.33,606.88 1918.34,606.88 1918.35,606.88 1918.36,606.88 1918.37,606.88 1918.38,606.88 1918.39,606.88 1918.4,606.88 1918.41,606.88 1918.41,606.88 1918.42,606.88 1918.43,606.88 1918.44,606.88 1918.45,606.88 1918.46,606.88 1918.47,606.88 1918.48,606.88 1918.49,606.88 1918.5,606.88 1918.51,606.88 1918.52,606.88 1918.53,606.88 1918.53,606.88 1918.54,606.88 1918.55,606.88 1918.56,606.88 1918.57,606.88 1918.58,606.88 1918.59,606.88 1918.6,606.88 1918.61,606.88 1918.62,606.88 1918.63,606.88 1918.64,606.88 1918.64,606.88 1918.65,606.88 1918.66,606.88 1918.67,606.88 1918.68,606.88 1918.69,606.88 1918.7,606.88 1918.71,606.88 1918.72,606.88 1918.73,606.88 1918.74,606.88 1918.75,606.88 1918.75,606.88 1918.76,606.88 1918.77,606.88 1918.78,606.88 1918.79,606.88 1918.8,606.88 1918.81,606.88 1918.82,606.88 1918.83,606.88 1918.84,606.88 1918.85,606.88 1918.86,606.88 1918.87,606.88 1918.87,606.88 1918.88,606.88 1918.89,606.88 1918.9,606.88 1918.91,606.88 1918.92,606.88 1918.93,606.88 1918.94,606.88 1918.95,606.88 1918.96,606.88 1918.97,606.88 1918.98,606.88 1918.98,606.88 1918.99,606.88 1919,606.88 1919.01,606.88 1919.02,606.88 1919.03,606.88 1919.04,606.88 1919.05,606.88 1919.06,606.88 1919.07,606.88 1919.08,606.88 1919.09,606.88 1919.09,606.88 1919.1,606.88 1919.11,606.88 1919.12,606.88 1919.13,606.88 1919.14,606.88 1919.15,606.88 1919.16,606.88 1919.17,606.88 1919.18,606.88 1919.19,606.88 1919.2,606.88 1919.21,606.88 1919.21,606.88 1919.22,606.88 1919.23,606.88 1919.24,606.88 1919.25,606.88 1919.26,606.88 1919.27,606.88 1919.28,606.88 1919.29,606.88 1919.3,606.88 1919.31,606.88 1919.32,606.88 1919.32,606.88 1919.33,606.88 1919.34,606.88 1919.35,606.88 1919.36,606.88 1919.37,606.88 1919.38,606.88 1919.39,606.88 1919.4,606.88 1919.41,606.88 1919.42,606.88 1919.43,606.88 1919.43,606.88 1919.44,606.88 1919.45,606.88 1919.46,606.88 1919.47,606.88 1919.48,606.88 1919.49,606.88 1919.5,606.88 1919.51,606.88 1919.52,606.88 1919.53,606.88 1919.54,606.88 1919.55,606.88 1919.55,606.88 1919.56,606.88 1919.57,606.88 1919.58,606.88 1919.59,606.88 1919.6,606.88 1919.61,606.88 1919.62,606.88 1919.63,606.88 1919.64,606.88 1919.65,606.88 1919.66,606.88 1919.66,606.88 1919.67,606.88 1919.68,606.88 1919.69,606.88 1919.7,606.88 1919.71,606.88 1919.72,606.88 1919.73,606.88 1919.74,606.88 1919.75,606.88 1919.76,606.88 1919.77,606.88 1919.77,606.88 1919.78,606.88 1919.79,606.88 1919.8,606.88 1919.81,606.88 1919.82,606.88 1919.83,606.88 1919.84,606.88 1919.85,606.88 1919.86,606.88 1919.87,606.88 1919.88,606.88 1919.89,606.88 1919.89,606.88 1919.9,606.88 1919.91,606.88 1919.92,606.88 1919.93,606.88 1919.94,606.88 1919.95,606.88 1919.96,606.88 1919.97,606.88 1919.98,606.88 1919.99,606.88 1920,606.88 1920,606.88 1920.01,606.88 1920.02,606.88 1920.03,606.88 1920.04,606.88 1920.05,606.88 1920.06,606.88 1920.07,606.88 1920.08,606.88 1920.09,606.88 1920.1,606.88 1920.11,606.88 1920.11,606.88 1920.12,606.88 1920.13,606.88 1920.14,606.88 1920.15,606.88 1920.16,606.88 1920.17,606.88 1920.18,606.88 1920.19,606.88 1920.2,606.88 1920.21,606.88 1920.22,606.88 1920.23,606.88 1920.23,606.88 1920.24,606.88 1920.25,606.88 1920.26,606.88 1920.27,606.88 1920.28,606.88 1920.29,606.88 1920.3,606.88 1920.31,606.88 1920.32,606.88 1920.33,606.88 1920.34,606.88 1920.34,606.88 1920.35,606.88 1920.36,606.88 1920.37,606.88 1920.38,606.88 1920.39,606.88 1920.4,606.88 1920.41,606.88 1920.42,606.88 1920.43,606.88 1920.44,606.88 1920.45,606.88 1920.45,606.88 1920.46,606.88 1920.47,606.88 1920.48,606.88 1920.49,606.88 1920.5,606.88 1920.51,606.88 1920.52,606.88 1920.53,606.88 1920.54,606.88 1920.55,606.88 1920.56,606.88 1920.57,606.88 1920.57,606.88 1920.58,606.88 1920.59,606.88 1920.6,606.88 1920.61,606.88 1920.62,606.88 1920.63,606.88 1920.64,606.88 1920.65,606.88 1920.66,606.88 1920.67,606.88 1920.68,606.88 1920.68,606.88 1920.69,606.88 1920.7,606.88 1920.71,606.88 1920.72,606.88 1920.73,606.88 1920.74,606.88 1920.75,606.88 1920.76,606.88 1920.77,606.88 1920.78,606.88 1920.79,606.88 1920.79,606.88 1920.8,606.88 1920.81,606.88 1920.82,606.88 1920.83,606.88 1920.84,606.88 1920.85,606.88 1920.86,606.88 1920.87,606.88 1920.88,606.88 1920.89,606.88 1920.9,606.88 1920.91,606.88 1920.91,606.88 1920.92,606.88 1920.93,606.88 1920.94,606.88 1920.95,606.88 1920.96,606.88 1920.97,606.88 1920.98,606.88 1920.99,606.88 1921,606.88 1921.01,606.88 1921.02,606.88 1921.02,606.88 1921.03,606.88 1921.04,606.88 1921.05,606.88 1921.06,606.88 1921.07,606.88 1921.08,606.88 1921.09,606.88 1921.1,606.88 1921.11,606.88 1921.12,606.88 1921.13,606.88 1921.13,606.88 1921.14,606.88 1921.15,606.88 1921.16,606.88 1921.17,606.88 1921.18,606.88 1921.19,606.88 1921.2,606.88 1921.21,606.88 1921.22,606.88 1921.23,606.88 1921.24,606.88 1921.25,606.88 1921.25,606.88 1921.26,606.88 1921.27,606.88 1921.28,606.88 1921.29,606.88 1921.3,606.88 1921.31,606.88 1921.32,606.88 1921.33,606.88 1921.34,606.88 1921.35,606.88 1921.36,606.88 1921.36,606.88 1921.37,606.88 1921.38,606.88 1921.39,606.88 1921.4,606.88 1921.41,606.88 1921.42,606.88 1921.43,606.88 1921.44,606.88 1921.45,606.88 1921.46,606.88 1921.47,606.88 1921.47,606.88 1921.48,606.88 1921.49,606.88 1921.5,606.88 1921.51,606.88 1921.52,606.88 1921.53,606.88 1921.54,606.88 1921.55,606.88 1921.56,606.88 1921.57,606.88 1921.58,606.88 1921.59,606.88 1921.59,606.88 1921.6,606.88 1921.61,606.88 1921.62,606.88 1921.63,606.88 1921.64,606.88 1921.65,606.88 1921.66,606.88 1921.67,606.88 1921.68,606.88 1921.69,606.88 1921.7,606.88 1921.7,606.88 1921.71,606.88 1921.72,606.88 1921.73,606.88 1921.74,606.88 1921.75,606.88 1921.76,606.88 1921.77,606.88 1921.78,606.88 1921.79,606.88 1921.8,606.88 1921.81,606.88 1921.81,606.88 1921.82,606.88 1921.83,606.88 1921.84,606.88 1921.85,606.88 1921.86,606.88 1921.87,606.88 1921.88,606.88 1921.89,606.88 1921.9,606.88 1921.91,606.88 1921.92,606.88 1921.93,606.88 1921.93,606.88 1921.94,606.88 1921.95,606.88 1921.96,606.88 1921.97,606.88 1921.98,606.88 1921.99,606.88 1922,606.88 1922.01,606.88 1922.02,606.88 1922.03,606.88 1922.04,606.88 1922.04,606.88 1922.05,606.88 1922.06,606.88 1922.07,606.88 1922.08,606.88 1922.09,606.88 1922.1,606.88 1922.11,606.88 1922.12,606.88 1922.13,606.88 1922.14,606.88 1922.15,606.88 1922.15,606.88 1922.16,606.88 1922.17,606.88 1922.18,606.88 1922.19,606.88 1922.2,606.88 1922.21,606.88 1922.22,606.88 1922.23,606.88 1922.24,606.88 1922.25,606.88 1922.26,606.88 1922.27,606.88 1922.27,606.88 1922.28,606.88 1922.29,606.88 1922.3,606.88 1922.31,606.88 1922.32,606.88 1922.33,606.88 1922.34,606.88 1922.35,606.88 1922.36,606.88 1922.37,606.88 1922.38,606.88 1922.38,606.88 1922.39,606.88 1922.4,606.88 1922.41,606.88 1922.42,606.88 1922.43,606.88 1922.44,606.88 1922.45,606.88 1922.46,606.88 1922.47,606.88 1922.48,606.88 1922.49,606.88 1922.49,606.88 1922.5,606.88 1922.51,606.88 1922.52,606.88 1922.53,606.88 1922.54,606.88 1922.55,606.88 1922.56,606.88 1922.57,606.88 1922.58,606.88 1922.59,606.88 1922.6,606.88 1922.61,606.88 1922.61,606.88 1922.62,606.88 1922.63,606.88 1922.64,606.88 1922.65,606.88 1922.66,606.88 1922.67,606.88 1922.68,606.88 1922.69,606.88 1922.7,606.88 1922.71,606.88 1922.72,606.88 1922.72,606.88 1922.73,606.88 1922.74,606.88 1922.75,606.88 1922.76,606.88 1922.77,606.88 1922.78,606.88 1922.79,606.88 1922.8,606.88 1922.81,606.88 1922.82,606.88 1922.83,606.88 1922.83,606.88 1922.84,606.88 1922.85,606.88 1922.86,606.88 1922.87,606.88 1922.88,606.88 1922.89,606.88 1922.9,606.88 1922.91,606.88 1922.92,606.88 1922.93,606.88 1922.94,606.88 1922.95,606.88 1922.95,606.88 1922.96,606.88 1922.97,606.88 1922.98,606.88 1922.99,606.88 1923,606.88 1923.01,606.88 1923.02,606.88 1923.03,606.88 1923.04,606.88 1923.05,606.88 1923.06,606.88 1923.06,606.88 1923.07,606.88 1923.08,606.88 1923.09,606.88 1923.1,606.88 1923.11,606.88 1923.12,606.88 1923.13,606.88 1923.14,606.88 1923.15,606.88 1923.16,606.88 1923.17,606.88 1923.17,606.88 1923.18,606.88 1923.19,606.88 1923.2,606.88 1923.21,606.88 1923.22,606.88 1923.23,606.88 1923.24,606.88 1923.25,606.88 1923.26,606.88 1923.27,606.88 1923.28,606.88 1923.29,606.88 1923.29,606.88 1923.3,606.88 1923.31,606.88 1923.32,606.88 1923.33,606.88 1923.34,606.88 1923.35,606.88 1923.36,606.88 1923.37,606.88 1923.38,606.88 1923.39,606.88 1923.4,606.88 1923.4,606.88 1923.41,606.88 1923.42,606.88 1923.43,606.88 1923.44,606.88 1923.45,606.88 1923.46,606.88 1923.47,606.88 1923.48,606.88 1923.49,606.88 1923.5,606.88 1923.51,606.88 1923.51,606.88 1923.52,606.88 1923.53,606.88 1923.54,606.88 1923.55,606.88 1923.56,606.88 1923.57,606.88 1923.58,606.88 1923.59,606.88 1923.6,606.88 1923.61,606.88 1923.62,606.88 1923.63,606.88 1923.63,606.88 1923.64,606.88 1923.65,606.88 1923.66,606.88 1923.67,606.88 1923.68,606.88 1923.69,606.88 1923.7,606.88 1923.71,606.88 1923.72,606.88 1923.73,606.88 1923.74,606.88 1923.74,606.88 1923.75,606.88 1923.76,606.88 1923.77,606.88 1923.78,606.88 1923.79,606.88 1923.8,606.88 1923.81,606.88 1923.82,606.88 1923.83,606.88 1923.84,606.88 1923.85,606.88 1923.85,606.88 1923.86,606.88 1923.87,606.88 1923.88,606.88 1923.89,606.88 1923.9,606.88 1923.91,606.88 1923.92,606.88 1923.93,606.88 1923.94,606.88 1923.95,606.88 1923.96,606.88 1923.97,606.88 1923.97,606.88 1923.98,606.88 1923.99,606.88 1924,606.88 1924.01,606.88 1924.02,606.88 1924.03,606.88 1924.04,606.88 1924.05,606.88 1924.06,606.88 1924.07,606.88 1924.08,606.88 1924.08,606.88 1924.09,606.88 1924.1,606.88 1924.11,606.88 1924.12,606.88 1924.13,606.88 1924.14,606.88 1924.15,606.88 1924.16,606.88 1924.17,606.88 1924.18,606.88 1924.19,606.88 1924.19,606.88 1924.2,606.88 1924.21,606.88 1924.22,606.88 1924.23,606.88 1924.24,606.88 1924.25,606.88 1924.26,606.88 1924.27,606.88 1924.28,606.88 1924.29,606.88 1924.3,606.88 1924.31,606.88 1924.31,606.88 1924.32,606.88 1924.33,606.88 1924.34,606.88 1924.35,606.88 1924.36,606.88 1924.37,606.88 1924.38,606.88 1924.39,606.88 1924.4,606.88 1924.41,606.88 1924.42,606.88 1924.42,606.88 1924.43,606.88 1924.44,606.88 1924.45,606.88 1924.46,606.88 1924.47,606.88 1924.48,606.88 1924.49,606.88 1924.5,606.88 1924.51,606.88 1924.52,606.88 1924.53,606.88 1924.53,606.88 1924.54,606.88 1924.55,606.88 1924.56,606.88 1924.57,606.88 1924.58,606.88 1924.59,606.88 1924.6,606.88 1924.61,606.88 1924.62,606.88 1924.63,606.88 1924.64,606.88 1924.65,606.88 1924.65,606.88 1924.66,606.88 1924.67,606.88 1924.68,606.88 1924.69,606.88 1924.7,606.88 1924.71,606.88 1924.72,606.88 1924.73,606.88 1924.74,606.88 1924.75,606.88 1924.76,606.88 1924.76,606.88 1924.77,606.88 1924.78,606.88 1924.79,606.88 1924.8,606.88 1924.81,606.88 1924.82,606.88 1924.83,606.88 1924.84,606.88 1924.85,606.88 1924.86,606.88 1924.87,606.88 1924.87,606.88 1924.88,606.88 1924.89,606.88 1924.9,606.88 1924.91,606.88 1924.92,606.88 1924.93,606.88 1924.94,606.88 1924.95,606.88 1924.96,606.88 1924.97,606.88 1924.98,606.88 1924.99,606.88 1924.99,606.88 1925,606.88 1925.01,606.88 1925.02,606.88 1925.03,606.88 1925.04,606.88 1925.05,606.88 1925.06,606.88 1925.07,606.88 1925.08,606.88 1925.09,606.88 1925.1,606.88 1925.1,606.88 1925.11,606.88 1925.12,606.88 1925.13,606.88 1925.14,606.88 1925.15,606.88 1925.16,606.88 1925.17,606.88 1925.18,606.88 1925.19,606.88 1925.2,606.88 1925.21,606.88 1925.22,606.88 1925.22,606.88 1925.23,606.88 1925.24,606.88 1925.25,606.88 1925.26,606.88 1925.27,606.88 1925.28,606.88 1925.29,606.88 1925.3,606.88 1925.31,606.88 1925.32,606.88 1925.33,606.88 1925.33,606.88 1925.34,606.88 1925.35,606.88 1925.36,606.88 1925.37,606.88 1925.38,606.88 1925.39,606.88 1925.4,606.88 1925.41,606.88 1925.42,606.88 1925.43,606.88 1925.44,606.88 1925.44,606.88 1925.45,606.88 1925.46,606.88 1925.47,606.88 1925.48,606.88 1925.49,606.88 1925.5,606.88 1925.51,606.88 1925.52,606.88 1925.53,606.88 1925.54,606.88 1925.55,606.88 1925.56,606.88 1925.56,606.88 1925.57,606.88 1925.58,606.88 1925.59,606.88 1925.6,606.88 1925.61,606.88 1925.62,606.88 1925.63,606.88 1925.64,606.88 1925.65,606.88 1925.66,606.88 1925.67,606.88 1925.67,606.88 1925.68,606.88 1925.69,606.88 1925.7,606.88 1925.71,606.88 1925.72,606.88 1925.73,606.88 1925.74,606.88 1925.75,606.88 1925.76,606.88 1925.77,606.88 1925.78,606.88 1925.78,606.88 1925.79,606.88 1925.8,606.88 1925.81,606.88 1925.82,606.88 1925.83,606.88 1925.84,606.88 1925.85,606.88 1925.86,606.88 1925.87,606.88 1925.88,606.88 1925.89,606.88 1925.9,606.88 1925.9,606.88 1925.91,606.88 1925.92,606.88 1925.93,606.88 1925.94,606.88 1925.95,606.88 1925.96,606.88 1925.97,606.88 1925.98,606.88 1925.99,606.88 1926,606.88 1926.01,606.88 1926.01,606.88 1926.02,606.88 1926.03,606.88 1926.04,606.88 1926.05,606.88 1926.06,606.88 1926.07,606.88 1926.08,606.88 1926.09,606.88 1926.1,606.88 1926.11,606.88 1926.12,606.88 1926.12,606.88 1926.13,606.88 1926.14,606.88 1926.15,606.88 1926.16,606.88 1926.17,606.88 1926.18,606.88 1926.19,606.88 1926.2,606.88 1926.21,606.88 1926.22,606.88 1926.23,606.88 1926.24,606.88 1926.24,606.88 1926.25,606.88 1926.26,606.88 1926.27,606.88 1926.28,606.88 1926.29,606.88 1926.3,606.88 1926.31,606.88 1926.32,606.88 1926.33,606.88 1926.34,606.88 1926.35,606.88 1926.35,606.88 1926.36,606.88 1926.37,606.88 1926.38,606.88 1926.39,606.88 1926.4,606.88 1926.41,606.88 1926.42,606.88 1926.43,606.88 1926.44,606.88 1926.45,606.88 1926.46,606.88 1926.46,606.88 1926.47,606.88 1926.48,606.88 1926.49,606.88 1926.5,606.88 1926.51,606.88 1926.52,606.88 1926.53,606.88 1926.54,606.88 1926.55,606.88 1926.56,606.88 1926.57,606.88 1926.58,606.88 1926.58,606.88 1926.59,606.88 1926.6,606.88 1926.61,606.88 1926.62,606.88 1926.63,606.88 1926.64,606.88 1926.65,606.88 1926.66,606.88 1926.67,606.88 1926.68,606.88 1926.69,606.88 1926.69,606.88 1926.7,606.88 1926.71,606.88 1926.72,606.88 1926.73,606.88 1926.74,606.88 1926.75,606.88 1926.76,606.88 1926.77,606.88 1926.78,606.88 1926.79,606.88 1926.8,606.88 1926.8,606.88 1926.81,606.88 1926.82,606.88 1926.83,606.88 1926.84,606.88 1926.85,606.88 1926.86,606.88 1926.87,606.88 1926.88,606.88 1926.89,606.88 1926.9,606.88 1926.91,606.88 1926.92,606.88 1926.92,606.88 1926.93,606.88 1926.94,606.88 1926.95,606.88 1926.96,606.88 1926.97,606.88 1926.98,606.88 1926.99,606.88 1927,606.88 1927.01,606.88 1927.02,606.88 1927.03,606.88 1927.03,606.88 1927.04,606.88 1927.05,606.88 1927.06,606.88 1927.07,606.88 1927.08,606.88 1927.09,606.88 1927.1,606.88 1927.11,606.88 1927.12,606.88 1927.13,606.88 1927.14,606.88 1927.14,606.88 1927.15,606.88 1927.16,606.88 1927.17,606.88 1927.18,606.88 1927.19,606.88 1927.2,606.88 1927.21,606.88 1927.22,606.88 1927.23,606.88 1927.24,606.88 1927.25,606.88 1927.26,606.88 1927.26,606.88 1927.27,606.88 1927.28,606.88 1927.29,606.88 1927.3,606.88 1927.31,606.88 1927.32,606.88 1927.33,606.88 1927.34,606.88 1927.35,606.88 1927.36,606.88 1927.37,606.88 1927.37,606.88 1927.38,606.88 1927.39,606.88 1927.4,606.88 1927.41,606.88 1927.42,606.88 1927.43,606.88 1927.44,606.88 1927.45,606.88 1927.46,606.88 1927.47,606.88 1927.48,606.88 1927.48,606.88 1927.49,606.88 1927.5,606.88 1927.51,606.88 1927.52,606.88 1927.53,606.88 1927.54,606.88 1927.55,606.88 1927.56,606.88 1927.57,606.88 1927.58,606.88 1927.59,606.88 1927.6,606.88 1927.6,606.88 1927.61,606.88 1927.62,606.88 1927.63,606.88 1927.64,606.88 1927.65,606.88 1927.66,606.88 1927.67,606.88 1927.68,606.88 1927.69,606.88 1927.7,606.88 1927.71,606.88 1927.71,606.88 1927.72,606.88 1927.73,606.88 1927.74,606.88 1927.75,606.88 1927.76,606.88 1927.77,606.88 1927.78,606.88 1927.79,606.88 1927.8,606.88 1927.81,606.88 1927.82,606.88 1927.82,606.88 1927.83,606.88 1927.84,606.88 1927.85,606.88 1927.86,606.88 1927.87,606.88 1927.88,606.88 1927.89,606.88 1927.9,606.88 1927.91,606.88 1927.92,606.88 1927.93,606.88 1927.94,606.88 1927.94,606.88 1927.95,606.88 1927.96,606.88 1927.97,606.88 1927.98,606.88 1927.99,606.88 1928,606.88 1928.01,606.88 1928.02,606.88 1928.03,606.88 1928.04,606.88 1928.05,606.88 1928.05,606.88 1928.06,606.88 1928.07,606.88 1928.08,606.88 1928.09,606.88 1928.1,606.88 1928.11,606.88 1928.12,606.88 1928.13,606.88 1928.14,606.88 1928.15,606.88 1928.16,606.88 1928.16,606.88 1928.17,606.88 1928.18,606.88 1928.19,606.88 1928.2,606.88 1928.21,606.88 1928.22,606.88 1928.23,606.88 1928.24,606.88 1928.25,606.88 1928.26,606.88 1928.27,606.88 1928.28,606.88 1928.28,606.88 1928.29,606.88 1928.3,606.88 1928.31,606.88 1928.32,606.88 1928.33,606.88 1928.34,606.88 1928.35,606.88 1928.36,606.88 1928.37,606.88 1928.38,606.88 1928.39,606.88 1928.39,606.88 1928.4,606.88 1928.41,606.88 1928.42,606.88 1928.43,606.88 1928.44,606.88 1928.45,606.88 1928.46,606.88 1928.47,606.88 1928.48,606.88 1928.49,606.88 1928.5,606.88 1928.5,606.88 1928.51,606.88 1928.52,606.88 1928.53,606.88 1928.54,606.88 1928.55,606.88 1928.56,606.88 1928.57,606.88 1928.58,606.88 1928.59,606.88 1928.6,606.88 1928.61,606.88 1928.62,606.88 1928.62,606.88 1928.63,606.88 1928.64,606.88 1928.65,606.88 1928.66,606.88 1928.67,606.88 1928.68,606.88 1928.69,606.88 1928.7,606.88 1928.71,606.88 1928.72,606.88 1928.73,606.88 1928.73,606.88 1928.74,606.88 1928.75,606.88 1928.76,606.88 1928.77,606.88 1928.78,606.88 1928.79,606.88 1928.8,606.88 1928.81,606.88 1928.82,606.88 1928.83,606.88 1928.84,606.88 1928.84,606.88 1928.85,606.88 1928.86,606.88 1928.87,606.88 1928.88,606.88 1928.89,606.88 1928.9,606.88 1928.91,606.88 1928.92,606.88 1928.93,606.88 1928.94,606.88 1928.95,606.88 1928.96,606.88 1928.96,606.88 1928.97,606.88 1928.98,606.88 1928.99,606.88 1929,606.88 1929.01,606.88 1929.02,606.88 1929.03,606.88 1929.04,606.88 1929.05,606.88 1929.06,606.88 1929.07,606.88 1929.07,606.88 1929.08,606.88 1929.09,606.88 1929.1,606.88 1929.11,606.88 1929.12,606.88 1929.13,606.88 1929.14,606.88 1929.15,606.88 1929.16,606.88 1929.17,606.88 1929.18,606.88 1929.18,606.88 1929.19,606.88 1929.2,606.88 1929.21,606.88 1929.22,606.88 1929.23,606.88 1929.24,606.88 1929.25,606.88 1929.26,606.88 1929.27,606.88 1929.28,606.88 1929.29,606.88 1929.3,606.88 1929.3,606.88 1929.31,606.88 1929.32,606.88 1929.33,606.88 1929.34,606.88 1929.35,606.88 1929.36,606.88 1929.37,606.88 1929.38,606.88 1929.39,606.88 1929.4,606.88 1929.41,606.88 1929.41,606.88 1929.42,606.88 1929.43,606.88 1929.44,606.88 1929.45,606.88 1929.46,606.88 1929.47,606.88 1929.48,606.88 1929.49,606.88 1929.5,606.88 1929.51,606.88 1929.52,606.88 1929.52,606.88 1929.53,606.88 1929.54,606.88 1929.55,606.88 1929.56,606.88 1929.57,606.88 1929.58,606.88 1929.59,606.88 1929.6,606.88 1929.61,606.88 1929.62,606.88 1929.63,606.88 1929.64,606.88 1929.64,606.88 1929.65,606.88 1929.66,606.88 1929.67,606.88 1929.68,606.88 1929.69,606.88 1929.7,606.88 1929.71,606.88 1929.72,606.88 1929.73,606.88 1929.74,606.88 1929.75,606.88 1929.75,606.88 1929.76,606.88 1929.77,606.88 1929.78,606.88 1929.79,606.88 1929.8,606.88 1929.81,606.88 1929.82,606.88 1929.83,606.88 1929.84,606.88 1929.85,606.88 1929.86,606.88 1929.86,606.88 1929.87,606.88 1929.88,606.88 1929.89,606.88 1929.9,606.88 1929.91,606.88 1929.92,606.88 1929.93,606.88 1929.94,606.88 1929.95,606.88 1929.96,606.88 1929.97,606.88 1929.98,606.88 1929.98,606.88 1929.99,606.88 1930,606.88 1930.01,606.88 1930.02,606.88 1930.03,606.88 1930.04,606.88 1930.05,606.88 1930.06,606.88 1930.07,606.88 1930.08,606.88 1930.09,606.88 1930.09,606.88 1930.1,606.88 1930.11,606.88 1930.12,606.88 1930.13,606.88 1930.14,606.88 1930.15,606.88 1930.16,606.88 1930.17,606.88 1930.18,606.88 1930.19,606.88 1930.2,606.88 1930.2,606.88 1930.21,606.88 1930.22,606.88 1930.23,606.88 1930.24,606.88 1930.25,606.88 1930.26,606.88 1930.27,606.88 1930.28,606.88 1930.29,606.88 1930.3,606.88 1930.31,606.88 1930.32,606.88 1930.32,606.88 1930.33,606.88 1930.34,606.88 1930.35,606.88 1930.36,606.88 1930.37,606.88 1930.38,606.88 1930.39,606.88 1930.4,606.88 1930.41,606.88 1930.42,606.88 1930.43,606.88 1930.43,606.88 1930.44,606.88 1930.45,606.88 1930.46,606.88 1930.47,606.88 1930.48,606.88 1930.49,606.88 1930.5,606.88 1930.51,606.88 1930.52,606.88 1930.53,606.88 1930.54,606.88 1930.54,606.88 1930.55,606.88 1930.56,606.88 1930.57,606.88 1930.58,606.88 1930.59,606.88 1930.6,606.88 1930.61,606.88 1930.62,606.88 1930.63,606.88 1930.64,606.88 1930.65,606.88 1930.66,606.88 1930.66,606.88 1930.67,606.88 1930.68,606.88 1930.69,606.88 1930.7,606.88 1930.71,606.88 1930.72,606.88 1930.73,606.88 1930.74,606.88 1930.75,606.88 1930.76,606.88 1930.77,606.88 1930.77,606.88 1930.78,606.88 1930.79,606.88 1930.8,606.88 1930.81,606.88 1930.82,606.88 1930.83,606.88 1930.84,606.88 1930.85,606.88 1930.86,606.88 1930.87,606.88 1930.88,606.88 1930.88,606.88 1930.89,606.88 1930.9,606.88 1930.91,606.88 1930.92,606.88 1930.93,606.88 1930.94,606.88 1930.95,606.88 1930.96,606.88 1930.97,606.88 1930.98,606.88 1930.99,606.88 1931,606.88 1931,606.88 1931.01,606.88 1931.02,606.88 1931.03,606.88 1931.04,606.88 1931.05,606.88 1931.06,606.88 1931.07,606.88 1931.08,606.88 1931.09,606.88 1931.1,606.88 1931.11,606.88 1931.11,606.88 1931.12,606.88 1931.13,606.88 1931.14,606.88 1931.15,606.88 1931.16,606.88 1931.17,606.88 1931.18,606.88 1931.19,606.88 1931.2,606.88 1931.21,606.88 1931.22,606.88 1931.22,606.88 1931.23,606.88 1931.24,606.88 1931.25,606.88 1931.26,606.88 1931.27,606.88 1931.28,606.88 1931.29,606.88 1931.3,606.88 1931.31,606.88 1931.32,606.88 1931.33,606.88 1931.34,606.88 1931.34,606.88 1931.35,606.88 1931.36,606.88 1931.37,606.88 1931.38,606.88 1931.39,606.88 1931.4,606.88 1931.41,606.88 1931.42,606.88 1931.43,606.88 1931.44,606.88 1931.45,606.88 1931.45,606.88 1931.46,606.88 1931.47,606.88 1931.48,606.88 1931.49,606.88 1931.5,606.88 1931.51,606.88 1931.52,606.88 1931.53,606.88 1931.54,606.88 1931.55,606.88 1931.56,606.88 1931.56,606.88 1931.57,606.88 1931.58,606.88 1931.59,606.88 1931.6,606.88 1931.61,606.88 1931.62,606.88 1931.63,606.88 1931.64,606.88 1931.65,606.88 1931.66,606.88 1931.67,606.88 1931.68,606.88 1931.68,606.88 1931.69,606.88 1931.7,606.88 1931.71,606.88 1931.72,606.88 1931.73,606.88 1931.74,606.88 1931.75,606.88 1931.76,606.88 1931.77,606.88 1931.78,606.88 1931.79,606.88 1931.79,606.88 1931.8,606.88 1931.81,606.88 1931.82,606.88 1931.83,606.88 1931.84,606.88 1931.85,606.88 1931.86,606.88 1931.87,606.88 1931.88,606.88 1931.89,606.88 1931.9,606.88 1931.9,606.88 1931.91,606.88 1931.92,606.88 1931.93,606.88 1931.94,606.88 1931.95,606.88 1931.96,606.88 1931.97,606.88 1931.98,606.88 1931.99,606.88 1932,606.88 1932.01,606.88 1932.02,606.88 1932.02,606.88 1932.03,606.88 1932.04,606.88 1932.05,606.88 1932.06,606.88 1932.07,606.88 1932.08,606.88 1932.09,606.88 1932.1,606.88 1932.11,606.88 1932.12,606.88 1932.13,606.88 1932.13,606.88 1932.14,606.88 1932.15,606.88 1932.16,606.88 1932.17,606.88 1932.18,606.88 1932.19,606.88 1932.2,606.88 1932.21,606.88 1932.22,606.88 1932.23,606.88 1932.24,606.88 1932.24,606.88 1932.25,606.88 1932.26,606.88 1932.27,606.88 1932.28,606.88 1932.29,606.88 1932.3,606.88 1932.31,606.88 1932.32,606.88 1932.33,606.88 1932.34,606.88 1932.35,606.88 1932.36,606.88 1932.36,606.88 1932.37,606.88 1932.38,606.88 1932.39,606.88 1932.4,606.88 1932.41,606.88 1932.42,606.88 1932.43,606.88 1932.44,606.88 1932.45,606.88 1932.46,606.88 1932.47,606.88 1932.47,606.88 1932.48,606.88 1932.49,606.88 1932.5,606.88 1932.51,606.88 1932.52,606.88 1932.53,606.88 1932.54,606.88 1932.55,606.88 1932.56,606.88 1932.57,606.88 1932.58,606.88 1932.58,606.88 1932.59,606.88 1932.6,606.88 1932.61,606.88 1932.62,606.88 1932.63,606.88 1932.64,606.88 1932.65,606.88 1932.66,606.88 1932.67,606.88 1932.68,606.88 1932.69,606.88 1932.7,606.88 1932.7,606.88 1932.71,606.88 1932.72,606.88 1932.73,606.88 1932.74,606.88 1932.75,606.88 1932.76,606.88 1932.77,606.88 1932.78,606.88 1932.79,606.88 1932.8,606.88 1932.81,606.88 1932.81,606.88 1932.82,606.88 1932.83,606.88 1932.84,606.88 1932.85,606.88 1932.86,606.88 1932.87,606.88 1932.88,606.88 1932.89,606.88 1932.9,606.88 1932.91,606.88 1932.92,606.88 1932.92,606.88 1932.93,606.88 1932.94,606.88 1932.95,606.88 1932.96,606.88 1932.97,606.88 1932.98,606.88 1932.99,606.88 1933,606.88 1933.01,606.88 1933.02,606.88 1933.03,606.88 1933.04,606.88 1933.04,606.88 1933.05,606.88 1933.06,606.88 1933.07,606.88 1933.08,606.88 1933.09,606.88 1933.1,606.88 1933.11,606.88 1933.12,606.88 1933.13,606.88 1933.14,606.88 1933.15,606.88 1933.15,606.88 1933.16,606.88 1933.17,606.88 1933.18,606.88 1933.19,606.88 1933.2,606.88 1933.21,606.88 1933.22,606.88 1933.23,606.88 1933.24,606.88 1933.25,606.88 1933.26,606.88 1933.26,606.88 1933.27,606.88 1933.28,606.88 1933.29,606.88 1933.3,606.88 1933.31,606.88 1933.32,606.88 1933.33,606.88 1933.34,606.88 1933.35,606.88 1933.36,606.88 1933.37,606.88 1933.38,606.88 1933.38,606.88 1933.39,606.88 1933.4,606.88 1933.41,606.88 1933.42,606.88 1933.43,606.88 1933.44,606.88 1933.45,606.88 1933.46,606.88 1933.47,606.88 1933.48,606.88 1933.49,606.88 1933.49,606.88 1933.5,606.88 1933.51,606.88 1933.52,606.88 1933.53,606.88 1933.54,606.88 1933.55,606.88 1933.56,606.88 1933.57,606.88 1933.58,606.88 1933.59,606.88 1933.6,606.88 1933.6,606.88 1933.61,606.88 1933.62,606.88 1933.63,606.88 1933.64,606.88 1933.65,606.88 1933.66,606.88 1933.67,606.88 1933.68,606.88 1933.69,606.88 1933.7,606.88 1933.71,606.88 1933.72,606.88 1933.72,606.88 1933.73,606.88 1933.74,606.88 1933.75,606.88 1933.76,606.88 1933.77,606.88 1933.78,606.88 1933.79,606.88 1933.8,606.88 1933.81,606.88 1933.82,606.88 1933.83,606.88 1933.83,606.88 1933.84,606.88 1933.85,606.88 1933.86,606.88 1933.87,606.88 1933.88,606.88 1933.89,606.88 1933.9,606.88 1933.91,606.88 1933.92,606.88 1933.93,606.88 1933.94,606.88 1933.94,606.88 1933.95,606.88 1933.96,606.88 1933.97,606.88 1933.98,606.88 1933.99,606.88 1934,606.88 1934.01,606.88 1934.02,606.88 1934.03,606.88 1934.04,606.88 1934.05,606.88 1934.06,606.88 1934.06,606.88 1934.07,606.88 1934.08,606.88 1934.09,606.88 1934.1,606.88 1934.11,606.88 1934.12,606.88 1934.13,606.88 1934.14,606.88 1934.15,606.88 1934.16,606.88 1934.17,606.88 1934.17,606.88 1934.18,606.88 1934.19,606.88 1934.2,606.88 1934.21,606.88 1934.22,606.88 1934.23,606.88 1934.24,606.88 1934.25,606.88 1934.26,606.88 1934.27,606.88 1934.28,606.88 1934.28,606.88 1934.29,606.88 1934.3,606.88 1934.31,606.88 1934.32,606.88 1934.33,606.88 1934.34,606.88 1934.35,606.88 1934.36,606.88 1934.37,606.88 1934.38,606.88 1934.39,606.88 1934.4,606.88 1934.4,606.88 1934.41,606.88 1934.42,606.88 1934.43,606.88 1934.44,606.88 1934.45,606.88 1934.46,606.88 1934.47,606.88 1934.48,606.88 1934.49,606.88 1934.5,606.88 1934.51,606.88 1934.51,606.88 1934.52,606.88 1934.53,606.88 1934.54,606.88 1934.55,606.88 1934.56,606.88 1934.57,606.88 1934.58,606.88 1934.59,606.88 1934.6,606.88 1934.61,606.88 1934.62,606.88 1934.62,606.88 1934.63,606.88 1934.64,606.88 1934.65,606.88 1934.66,606.88 1934.67,606.88 1934.68,606.88 1934.69,606.88 1934.7,606.88 1934.71,606.88 1934.72,606.88 1934.73,606.88 1934.74,606.88 1934.74,606.88 1934.75,606.88 1934.76,606.88 1934.77,606.88 1934.78,606.88 1934.79,606.88 1934.8,606.88 1934.81,606.88 1934.82,606.88 1934.83,606.88 1934.84,606.88 1934.85,606.88 1934.85,606.88 1934.86,606.88 1934.87,606.88 1934.88,606.88 1934.89,606.88 1934.9,606.88 1934.91,606.88 1934.92,606.88 1934.93,606.88 1934.94,606.88 1934.95,606.88 1934.96,606.88 1934.96,606.88 1934.97,606.88 1934.98,606.88 1934.99,606.88 1935,606.88 1935.01,606.88 1935.02,606.88 1935.03,606.88 1935.04,606.88 1935.05,606.88 1935.06,606.88 1935.07,606.88 1935.08,606.88 1935.08,606.88 1935.09,606.88 1935.1,606.88 1935.11,606.88 1935.12,606.88 1935.13,606.88 1935.14,606.88 1935.15,606.88 1935.16,606.88 1935.17,606.88 1935.18,606.88 1935.19,606.88 1935.19,606.88 1935.2,606.88 1935.21,606.88 1935.22,606.88 1935.23,606.88 1935.24,606.88 1935.25,606.88 1935.26,606.88 1935.27,606.88 1935.28,606.88 1935.29,606.88 1935.3,606.88 1935.3,606.88 1935.31,606.88 1935.32,606.88 1935.33,606.88 1935.34,606.88 1935.35,606.88 1935.36,606.88 1935.37,606.88 1935.38,606.88 1935.39,606.88 1935.4,606.88 1935.41,606.88 1935.42,606.88 1935.42,606.88 1935.43,606.88 1935.44,606.88 1935.45,606.88 1935.46,606.88 1935.47,606.88 1935.48,606.88 1935.49,606.88 1935.5,606.88 1935.51,606.88 1935.52,606.88 1935.53,606.88 1935.53,606.88 1935.54,606.88 1935.55,606.88 1935.56,606.88 1935.57,606.88 1935.58,606.88 1935.59,606.88 1935.6,606.88 1935.61,606.88 1935.62,606.88 1935.63,606.88 1935.64,606.88 1935.64,606.88 1935.65,606.88 1935.66,606.88 1935.67,606.88 1935.68,606.88 1935.69,606.88 1935.7,606.88 1935.71,606.88 1935.72,606.88 1935.73,606.88 1935.74,606.88 1935.75,606.88 1935.76,606.88 1935.76,606.88 1935.77,606.88 1935.78,606.88 1935.79,606.88 1935.8,606.88 1935.81,606.88 1935.82,606.88 1935.83,606.88 1935.84,606.88 1935.85,606.88 1935.86,606.88 1935.87,606.88 1935.87,606.88 1935.88,606.88 1935.89,606.88 1935.9,606.88 1935.91,606.88 1935.92,606.88 1935.93,606.88 1935.94,606.88 1935.95,606.88 1935.96,606.88 1935.97,606.88 1935.98,606.88 1935.98,606.88 1935.99,606.88 1936,606.88 1936.01,606.88 1936.02,606.88 1936.03,606.88 1936.04,606.88 1936.05,606.88 1936.06,606.88 1936.07,606.88 1936.08,606.88 1936.09,606.88 1936.1,606.88 1936.1,606.88 1936.11,606.88 1936.12,606.88 1936.13,606.88 1936.14,606.88 1936.15,606.88 1936.16,606.88 1936.17,606.88 1936.18,606.88 1936.19,606.88 1936.2,606.88 1936.21,606.88 1936.21,606.88 1936.22,606.88 1936.23,606.88 1936.24,606.88 1936.25,606.88 1936.26,606.88 1936.27,606.88 1936.28,606.88 1936.29,606.88 1936.3,606.88 1936.31,606.88 1936.32,606.88 1936.32,606.88 1936.33,606.88 1936.34,606.88 1936.35,606.88 1936.36,606.88 1936.37,606.88 1936.38,606.88 1936.39,606.88 1936.4,606.88 1936.41,606.88 1936.42,606.88 1936.43,606.88 1936.44,606.88 1936.44,606.88 1936.45,606.88 1936.46,606.88 1936.47,606.88 1936.48,606.88 1936.49,606.88 1936.5,606.88 1936.51,606.88 1936.52,606.88 1936.53,606.88 1936.54,606.88 1936.55,606.88 1936.55,606.88 1936.56,606.88 1936.57,606.88 1936.58,606.88 1936.59,606.88 1936.6,606.88 1936.61,606.88 1936.62,606.88 1936.63,606.88 1936.64,606.88 1936.65,606.88 1936.66,606.88 1936.66,606.88 1936.67,606.88 1936.68,606.88 1936.69,606.88 1936.7,606.88 1936.71,606.88 1936.72,606.88 1936.73,606.88 1936.74,606.88 1936.75,606.88 1936.76,606.88 1936.77,606.88 1936.78,606.88 1936.78,606.88 1936.79,606.88 1936.8,606.88 1936.81,606.88 1936.82,606.88 1936.83,606.88 1936.84,606.88 1936.85,606.88 1936.86,606.88 1936.87,606.88 1936.88,606.88 1936.89,606.88 1936.89,606.88 1936.9,606.88 1936.91,606.88 1936.92,606.88 1936.93,606.88 1936.94,606.88 1936.95,606.88 1936.96,606.88 1936.97,606.88 1936.98,606.88 1936.99,606.88 1937,606.88 1937,606.88 1937.01,606.88 1937.02,606.88 1937.03,606.88 1937.04,606.88 1937.05,606.88 1937.06,606.88 1937.07,606.88 1937.08,606.88 1937.09,606.88 1937.1,606.88 1937.11,606.88 1937.12,606.88 1937.12,606.88 1937.13,606.88 1937.14,606.88 1937.15,606.88 1937.16,606.88 1937.17,606.88 1937.18,606.88 1937.19,606.88 1937.2,606.88 1937.21,606.88 1937.22,606.88 1937.23,606.88 1937.23,606.88 1937.24,606.88 1937.25,606.88 1937.26,606.88 1937.27,606.88 1937.28,606.88 1937.29,606.88 1937.3,606.88 1937.31,606.88 1937.32,606.88 1937.33,606.88 1937.34,606.88 1937.34,606.88 1937.35,606.88 1937.36,606.88 1937.37,606.88 1937.38,606.88 1937.39,606.88 1937.4,606.88 1937.41,606.88 1937.42,606.88 1937.43,606.88 1937.44,606.88 1937.45,606.88 1937.46,606.88 1937.46,606.88 1937.47,606.88 1937.48,606.88 1937.49,606.88 1937.5,606.88 1937.51,606.88 1937.52,606.88 1937.53,606.88 1937.54,606.88 1937.55,606.88 1937.56,606.88 1937.57,606.88 1937.57,606.88 1937.58,606.88 1937.59,606.88 1937.6,606.88 1937.61,606.88 1937.62,606.88 1937.63,606.88 1937.64,606.88 1937.65,606.88 1937.66,606.88 1937.67,606.88 1937.68,606.88 1937.68,606.88 1937.69,606.88 1937.7,606.88 1937.71,606.88 1937.72,606.88 1937.73,606.88 1937.74,606.88 1937.75,606.88 1937.76,606.88 1937.77,606.88 1937.78,606.88 1937.79,606.88 1937.8,606.88 1937.8,606.88 1937.81,606.88 1937.82,606.88 1937.83,606.88 1937.84,606.88 1937.85,606.88 1937.86,606.88 1937.87,606.88 1937.88,606.88 1937.89,606.88 1937.9,606.88 1937.91,606.88 1937.91,606.88 1937.92,606.88 1937.93,606.88 1937.94,606.88 1937.95,606.88 1937.96,606.88 1937.97,606.88 1937.98,606.88 1937.99,606.88 1938,606.88 1938.01,606.88 1938.02,606.88 1938.02,606.88 1938.03,606.88 1938.04,606.88 1938.05,606.88 1938.06,606.88 1938.07,606.88 1938.08,606.88 1938.09,606.88 1938.1,606.88 1938.11,606.88 1938.12,606.88 1938.13,606.88 1938.14,606.88 1938.14,606.88 1938.15,606.88 1938.16,606.88 1938.17,606.88 1938.18,606.88 1938.19,606.88 1938.2,606.88 1938.21,606.88 1938.22,606.88 1938.23,606.88 1938.24,606.88 1938.25,606.88 1938.25,606.88 1938.26,606.88 1938.27,606.88 1938.28,606.88 1938.29,606.88 1938.3,606.88 1938.31,606.88 1938.32,606.88 1938.33,606.88 1938.34,606.88 1938.35,606.88 1938.36,606.88 1938.36,606.88 1938.37,606.88 1938.38,606.88 1938.39,606.88 1938.4,606.88 1938.41,606.88 1938.42,606.88 1938.43,606.88 1938.44,606.88 1938.45,606.88 1938.46,606.88 1938.47,606.88 1938.48,606.88 1938.48,606.88 1938.49,606.88 1938.5,606.88 1938.51,606.88 1938.52,606.88 1938.53,606.88 1938.54,606.88 1938.55,606.88 1938.56,606.88 1938.57,606.88 1938.58,606.88 1938.59,606.88 1938.59,606.88 1938.6,606.88 1938.61,606.88 1938.62,606.88 1938.63,606.88 1938.64,606.88 1938.65,606.88 1938.66,606.88 1938.67,606.88 1938.68,606.88 1938.69,606.88 1938.7,606.88 1938.7,606.88 1938.71,606.88 1938.72,606.88 1938.73,606.88 1938.74,606.88 1938.75,606.88 1938.76,606.88 1938.77,606.88 1938.78,606.88 1938.79,606.88 1938.8,606.88 1938.81,606.88 1938.82,606.88 1938.82,606.88 1938.83,606.88 1938.84,606.88 1938.85,606.88 1938.86,606.88 1938.87,606.88 1938.88,606.88 1938.89,606.88 1938.9,606.88 1938.91,606.88 1938.92,606.88 1938.93,606.88 1938.93,606.88 1938.94,606.88 1938.95,606.88 1938.96,606.88 1938.97,606.88 1938.98,606.88 1938.99,606.88 1939,606.88 1939.01,606.88 1939.02,606.88 1939.03,606.88 1939.04,606.88 1939.04,606.88 1939.05,606.88 1939.06,606.88 1939.07,606.88 1939.08,606.88 1939.09,606.88 1939.1,606.88 1939.11,606.88 1939.12,606.88 1939.13,606.88 1939.14,606.88 1939.15,606.88 1939.16,606.88 1939.16,606.88 1939.17,606.88 1939.18,606.88 1939.19,606.88 1939.2,606.88 1939.21,606.88 1939.22,606.88 1939.23,606.88 1939.24,606.88 1939.25,606.88 1939.26,606.88 1939.27,606.88 1939.27,606.88 1939.28,606.88 1939.29,606.88 1939.3,606.88 1939.31,606.88 1939.32,606.88 1939.33,606.88 1939.34,606.88 1939.35,606.88 1939.36,606.88 1939.37,606.88 1939.38,606.88 1939.38,606.88 1939.39,606.88 1939.4,606.88 1939.41,606.88 1939.42,606.88 1939.43,606.88 1939.44,606.88 1939.45,606.88 1939.46,606.88 1939.47,606.88 1939.48,606.88 1939.49,606.88 1939.5,606.88 1939.5,606.88 1939.51,606.88 1939.52,606.88 1939.53,606.88 1939.54,606.88 1939.55,606.88 1939.56,606.88 1939.57,606.88 1939.58,606.88 1939.59,606.88 1939.6,606.88 1939.61,606.88 1939.61,606.88 1939.62,606.88 1939.63,606.88 1939.64,606.88 1939.65,606.88 1939.66,606.88 1939.67,606.88 1939.68,606.88 1939.69,606.88 1939.7,606.88 1939.71,606.88 1939.72,606.88 1939.72,606.88 1939.73,606.88 1939.74,606.88 1939.75,606.88 1939.76,606.88 1939.77,606.88 1939.78,606.88 1939.79,606.88 1939.8,606.88 1939.81,606.88 1939.82,606.88 1939.83,606.88 1939.84,606.88 1939.84,606.88 1939.85,606.88 1939.86,606.88 1939.87,606.88 1939.88,606.88 1939.89,606.88 1939.9,606.88 1939.91,606.88 1939.92,606.88 1939.93,606.88 1939.94,606.88 1939.95,606.88 1939.95,606.88 1939.96,606.88 1939.97,606.88 1939.98,606.88 1939.99,606.88 1940,606.88 1940.01,606.88 1940.02,606.88 1940.03,606.88 1940.04,606.88 1940.05,606.88 1940.06,606.88 1940.06,606.88 1940.07,606.88 1940.08,606.88 1940.09,606.88 1940.1,606.88 1940.11,606.88 1940.12,606.88 1940.13,606.88 1940.14,606.88 1940.15,606.88 1940.16,606.88 1940.17,606.88 1940.18,606.88 1940.18,606.88 1940.19,606.88 1940.2,606.88 1940.21,606.88 1940.22,606.88 1940.23,606.88 1940.24,606.88 1940.25,606.88 1940.26,606.88 1940.27,606.88 1940.28,606.88 1940.29,606.88 1940.29,606.88 1940.3,606.88 1940.31,606.88 1940.32,606.88 1940.33,606.88 1940.34,606.88 1940.35,606.88 1940.36,606.88 1940.37,606.88 1940.38,606.88 1940.39,606.88 1940.4,606.88 1940.4,606.88 1940.41,606.88 1940.42,606.88 1940.43,606.88 1940.44,606.88 1940.45,606.88 1940.46,606.88 1940.47,606.88 1940.48,606.88 1940.49,606.88 1940.5,606.88 1940.51,606.88 1940.52,606.88 1940.52,606.88 1940.53,606.88 1940.54,606.88 1940.55,606.88 1940.56,606.88 1940.57,606.88 1940.58,606.88 1940.59,606.88 1940.6,606.88 1940.61,606.88 1940.62,606.88 1940.63,606.88 1940.63,606.88 1940.64,606.88 1940.65,606.88 1940.66,606.88 1940.67,606.88 1940.68,606.88 1940.69,606.88 1940.7,606.88 1940.71,606.88 1940.72,606.88 1940.73,606.88 1940.74,606.88 1940.74,606.88 1940.75,606.88 1940.76,606.88 1940.77,606.88 1940.78,606.88 1940.79,606.88 1940.8,606.88 1940.81,606.88 1940.82,606.88 1940.83,606.88 1940.84,606.88 1940.85,606.88 1940.86,606.88 1940.86,606.88 1940.87,606.88 1940.88,606.88 1940.89,606.88 1940.9,606.88 1940.91,606.88 1940.92,606.88 1940.93,606.88 1940.94,606.88 1940.95,606.88 1940.96,606.88 1940.97,606.88 1940.97,606.88 1940.98,606.88 1940.99,606.88 1941,606.88 1941.01,606.88 1941.02,606.88 1941.03,606.88 1941.04,606.88 1941.05,606.88 1941.06,606.88 1941.07,606.88 1941.08,606.88 1941.08,606.88 1941.09,606.88 1941.1,606.88 1941.11,606.88 1941.12,606.88 1941.13,606.88 1941.14,606.88 1941.15,606.88 1941.16,606.88 1941.17,606.88 1941.18,606.88 1941.19,606.88 1941.2,606.88 1941.2,606.88 1941.21,606.88 1941.22,606.88 1941.23,606.88 1941.24,606.88 1941.25,606.88 1941.26,606.88 1941.27,606.88 1941.28,606.88 1941.29,606.88 1941.3,606.88 1941.31,606.88 1941.31,606.88 1941.32,606.88 1941.33,606.88 1941.34,606.88 1941.35,606.88 1941.36,606.88 1941.37,606.88 1941.38,606.88 1941.39,606.88 1941.4,606.88 1941.41,606.88 1941.42,606.88 1941.42,606.88 1941.43,606.88 1941.44,606.88 1941.45,606.88 1941.46,606.88 1941.47,606.88 1941.48,606.88 1941.49,606.88 1941.5,606.88 1941.51,606.88 1941.52,606.88 1941.53,606.88 1941.54,606.88 1941.54,606.88 1941.55,606.88 1941.56,606.88 1941.57,606.88 1941.58,606.88 1941.59,606.88 1941.6,606.88 1941.61,606.88 1941.62,606.88 1941.63,606.88 1941.64,606.88 1941.65,606.88 1941.65,606.88 1941.66,606.88 1941.67,606.88 1941.68,606.88 1941.69,606.88 1941.7,606.88 1941.71,606.88 1941.72,606.88 1941.73,606.88 1941.74,606.88 1941.75,606.88 1941.76,606.88 1941.76,606.88 1941.77,606.88 1941.78,606.88 1941.79,606.88 1941.8,606.88 1941.81,606.88 1941.82,606.88 1941.83,606.88 1941.84,606.88 1941.85,606.88 1941.86,606.88 1941.87,606.88 1941.88,606.88 1941.88,606.88 1941.89,606.88 1941.9,606.88 1941.91,606.88 1941.92,606.88 1941.93,606.88 1941.94,606.88 1941.95,606.88 1941.96,606.88 1941.97,606.88 1941.98,606.88 1941.99,606.88 1941.99,606.88 1942,606.88 1942.01,606.88 1942.02,606.88 1942.03,606.88 1942.04,606.88 1942.05,606.88 1942.06,606.88 1942.07,606.88 1942.08,606.88 1942.09,606.88 1942.1,606.88 1942.1,606.88 1942.11,606.88 1942.12,606.88 1942.13,606.88 1942.14,606.88 1942.15,606.88 1942.16,606.88 1942.17,606.88 1942.18,606.88 1942.19,606.88 1942.2,606.88 1942.21,606.88 1942.22,606.88 1942.22,606.88 1942.23,606.88 1942.24,606.88 1942.25,606.88 1942.26,606.88 1942.27,606.88 1942.28,606.88 1942.29,606.88 1942.3,606.88 1942.31,606.88 1942.32,606.88 1942.33,606.88 1942.33,606.88 1942.34,606.88 1942.35,606.88 1942.36,606.88 1942.37,606.88 1942.38,606.88 1942.39,606.88 1942.4,606.88 1942.41,606.88 1942.42,606.88 1942.43,606.88 1942.44,606.88 1942.44,606.88 1942.45,606.88 1942.46,606.88 1942.47,606.88 1942.48,606.88 1942.49,606.88 1942.5,606.88 1942.51,606.88 1942.52,606.88 1942.53,606.88 1942.54,606.88 1942.55,606.88 1942.56,606.88 1942.56,606.88 1942.57,606.88 1942.58,606.88 1942.59,606.88 1942.6,606.88 1942.61,606.88 1942.62,606.88 1942.63,606.88 1942.64,606.88 1942.65,606.88 1942.66,606.88 1942.67,606.88 1942.67,606.88 1942.68,606.88 1942.69,606.88 1942.7,606.88 1942.71,606.88 1942.72,606.88 1942.73,606.88 1942.74,606.88 1942.75,606.88 1942.76,606.88 1942.77,606.88 1942.78,606.88 1942.78,606.88 1942.79,606.88 1942.8,606.88 1942.81,606.88 1942.82,606.88 1942.83,606.88 1942.84,606.88 1942.85,606.88 1942.86,606.88 1942.87,606.88 1942.88,606.88 1942.89,606.88 1942.9,606.88 1942.9,606.88 1942.91,606.88 1942.92,606.88 1942.93,606.88 1942.94,606.88 1942.95,606.88 1942.96,606.88 1942.97,606.88 1942.98,606.88 1942.99,606.88 1943,606.88 1943.01,606.88 1943.01,606.88 1943.02,606.88 1943.03,606.88 1943.04,606.88 1943.05,606.88 1943.06,606.88 1943.07,606.88 1943.08,606.88 1943.09,606.88 1943.1,606.88 1943.11,606.88 1943.12,606.88 1943.12,606.88 1943.13,606.88 1943.14,606.88 1943.15,606.88 1943.16,606.88 1943.17,606.88 1943.18,606.88 1943.19,606.88 1943.2,606.88 1943.21,606.88 1943.22,606.88 1943.23,606.88 1943.24,606.88 1943.24,606.88 1943.25,606.88 1943.26,606.88 1943.27,606.88 1943.28,606.88 1943.29,606.88 1943.3,606.88 1943.31,606.88 1943.32,606.88 1943.33,606.88 1943.34,606.88 1943.35,606.88 1943.35,606.88 1943.36,606.88 1943.37,606.88 1943.38,606.88 1943.39,606.88 1943.4,606.88 1943.41,606.88 1943.42,606.88 1943.43,606.88 1943.44,606.88 1943.45,606.88 1943.46,606.88 1943.46,606.88 1943.47,606.88 1943.48,606.88 1943.49,606.88 1943.5,606.88 1943.51,606.88 1943.52,606.88 1943.53,606.88 1943.54,606.88 1943.55,606.88 1943.56,606.88 1943.57,606.88 1943.58,606.88 1943.58,606.88 1943.59,606.88 1943.6,606.88 1943.61,606.88 1943.62,606.88 1943.63,606.88 1943.64,606.88 1943.65,606.88 1943.66,606.88 1943.67,606.88 1943.68,606.88 1943.69,606.88 1943.69,606.88 1943.7,606.88 1943.71,606.88 1943.72,606.88 1943.73,606.88 1943.74,606.88 1943.75,606.88 1943.76,606.88 1943.77,606.88 1943.78,606.88 1943.79,606.88 1943.8,606.88 1943.8,606.88 1943.81,606.88 1943.82,606.88 1943.83,606.88 1943.84,606.88 1943.85,606.88 1943.86,606.88 1943.87,606.88 1943.88,606.88 1943.89,606.88 1943.9,606.88 1943.91,606.88 1943.92,606.88 1943.92,606.88 1943.93,606.88 1943.94,606.88 1943.95,606.88 1943.96,606.88 1943.97,606.88 1943.98,606.88 1943.99,606.88 1944,606.88 1944.01,606.88 1944.02,606.88 1944.03,606.88 1944.03,606.88 1944.04,606.88 1944.05,606.88 1944.06,606.88 1944.07,606.88 1944.08,606.88 1944.09,606.88 1944.1,606.88 1944.11,606.88 1944.12,606.88 1944.13,606.88 1944.14,606.88 1944.14,606.88 1944.15,606.88 1944.16,606.88 1944.17,606.88 1944.18,606.88 1944.19,606.88 1944.2,606.88 1944.21,606.88 1944.22,606.88 1944.23,606.88 1944.24,606.88 1944.25,606.88 1944.26,606.88 1944.26,606.88 1944.27,606.88 1944.28,606.88 1944.29,606.88 1944.3,606.88 1944.31,606.88 1944.32,606.88 1944.33,606.88 1944.34,606.88 1944.35,606.88 1944.36,606.88 1944.37,606.88 1944.37,606.88 1944.38,606.88 1944.39,606.88 1944.4,606.88 1944.41,606.88 1944.42,606.88 1944.43,606.88 1944.44,606.88 1944.45,606.88 1944.46,606.88 1944.47,606.88 1944.48,606.88 1944.48,606.88 1944.49,606.88 1944.5,606.88 1944.51,606.88 1944.52,606.88 1944.53,606.88 1944.54,606.88 1944.55,606.88 1944.56,606.88 1944.57,606.88 1944.58,606.88 1944.59,606.88 1944.6,606.88 1944.6,606.88 1944.61,606.88 1944.62,606.88 1944.63,606.88 1944.64,606.88 1944.65,606.88 1944.66,606.88 1944.67,606.88 1944.68,606.88 1944.69,606.88 1944.7,606.88 1944.71,606.88 1944.71,606.88 1944.72,606.88 1944.73,606.88 1944.74,606.88 1944.75,606.88 1944.76,606.88 1944.77,606.88 1944.78,606.88 1944.79,606.88 1944.8,606.88 1944.81,606.88 1944.82,606.88 1944.82,606.88 1944.83,606.88 1944.84,606.88 1944.85,606.88 1944.86,606.88 1944.87,606.88 1944.88,606.88 1944.89,606.88 1944.9,606.88 1944.91,606.88 1944.92,606.88 1944.93,606.88 1944.94,606.88 1944.94,606.88 1944.95,606.88 1944.96,606.88 1944.97,606.88 1944.98,606.88 1944.99,606.88 1945,606.88 1945.01,606.88 1945.02,606.88 1945.03,606.88 1945.04,606.88 1945.05,606.88 1945.05,606.88 1945.06,606.88 1945.07,606.88 1945.08,606.88 1945.09,606.88 1945.1,606.88 1945.11,606.88 1945.12,606.88 1945.13,606.88 1945.14,606.88 1945.15,606.88 1945.16,606.88 1945.16,606.88 1945.17,606.88 1945.18,606.88 1945.19,606.88 1945.2,606.88 1945.21,606.88 1945.22,606.88 1945.23,606.88 1945.24,606.88 1945.25,606.88 1945.26,606.88 1945.27,606.88 1945.28,606.88 1945.28,606.88 1945.29,606.88 1945.3,606.88 1945.31,606.88 1945.32,606.88 1945.33,606.88 1945.34,606.88 1945.35,606.88 1945.36,606.88 1945.37,606.88 1945.38,606.88 1945.39,606.88 1945.39,606.88 1945.4,606.88 1945.41,606.88 1945.42,606.88 1945.43,606.88 1945.44,606.88 1945.45,606.88 1945.46,606.88 1945.47,606.88 1945.48,606.88 1945.49,606.88 1945.5,606.88 1945.5,606.88 1945.51,606.88 1945.52,606.88 1945.53,606.88 1945.54,606.88 1945.55,606.88 1945.56,606.88 1945.57,606.88 1945.58,606.88 1945.59,606.88 1945.6,606.88 1945.61,606.88 1945.62,606.88 1945.62,606.88 1945.63,606.88 1945.64,606.88 1945.65,606.88 1945.66,606.88 1945.67,606.88 1945.68,606.88 1945.69,606.88 1945.7,606.88 1945.71,606.88 1945.72,606.88 1945.73,606.88 1945.73,606.88 1945.74,606.88 1945.75,606.88 1945.76,606.88 1945.77,606.88 1945.78,606.88 1945.79,606.88 1945.8,606.88 1945.81,606.88 1945.82,606.88 1945.83,606.88 1945.84,606.88 1945.84,606.88 1945.85,606.88 1945.86,606.88 1945.87,606.88 1945.88,606.88 1945.89,606.88 1945.9,606.88 1945.91,606.88 1945.92,606.88 1945.93,606.88 1945.94,606.88 1945.95,606.88 1945.96,606.88 1945.96,606.88 1945.97,606.88 1945.98,606.88 1945.99,606.88 1946,606.88 1946.01,606.88 1946.02,606.88 1946.03,606.88 1946.04,606.88 1946.05,606.88 1946.06,606.88 1946.07,606.88 1946.07,606.88 1946.08,606.88 1946.09,606.88 1946.1,606.88 1946.11,606.88 1946.12,606.88 1946.13,606.88 1946.14,606.88 1946.15,606.88 1946.16,606.88 1946.17,606.88 1946.18,606.88 1946.18,606.88 1946.19,606.88 1946.2,606.88 1946.21,606.88 1946.22,606.88 1946.23,606.88 1946.24,606.88 1946.25,606.88 1946.26,606.88 1946.27,606.88 1946.28,606.88 1946.29,606.88 1946.3,606.88 1946.3,606.88 1946.31,606.88 1946.32,606.88 1946.33,606.88 1946.34,606.88 1946.35,606.88 1946.36,606.88 1946.37,606.88 1946.38,606.88 1946.39,606.88 1946.4,606.88 1946.41,606.88 1946.41,606.88 1946.42,606.88 1946.43,606.88 1946.44,606.88 1946.45,606.88 1946.46,606.88 1946.47,606.88 1946.48,606.88 1946.49,606.88 1946.5,606.88 1946.51,606.88 1946.52,606.88 1946.52,606.88 1946.53,606.88 1946.54,606.88 1946.55,606.88 1946.56,606.88 1946.57,606.88 1946.58,606.88 1946.59,606.88 1946.6,606.88 1946.61,606.88 1946.62,606.88 1946.63,606.88 1946.64,606.88 1946.64,606.88 1946.65,606.88 1946.66,606.88 1946.67,606.88 1946.68,606.88 1946.69,606.88 1946.7,606.88 1946.71,606.88 1946.72,606.88 1946.73,606.88 1946.74,606.88 1946.75,606.88 1946.75,606.88 1946.76,606.88 1946.77,606.88 1946.78,606.88 1946.79,606.88 1946.8,606.88 1946.81,606.88 1946.82,606.88 1946.83,606.88 1946.84,606.88 1946.85,606.88 1946.86,606.88 1946.86,606.88 1946.87,606.88 1946.88,606.88 1946.89,606.88 1946.9,606.88 1946.91,606.88 1946.92,606.88 1946.93,606.88 1946.94,606.88 1946.95,606.88 1946.96,606.88 1946.97,606.88 1946.98,606.88 1946.98,606.88 1946.99,606.88 1947,606.88 1947.01,606.88 1947.02,606.88 1947.03,606.88 1947.04,606.88 1947.05,606.88 1947.06,606.88 1947.07,606.88 1947.08,606.88 1947.09,606.88 1947.09,606.88 1947.1,606.88 1947.11,606.88 1947.12,606.88 1947.13,606.88 1947.14,606.88 1947.15,606.88 1947.16,606.88 1947.17,606.88 1947.18,606.88 1947.19,606.88 1947.2,606.88 1947.2,606.88 1947.21,606.88 1947.22,606.88 1947.23,606.88 1947.24,606.88 1947.25,606.88 1947.26,606.88 1947.27,606.88 1947.28,606.88 1947.29,606.88 1947.3,606.88 1947.31,606.88 1947.32,606.88 1947.32,606.88 1947.33,606.88 1947.34,606.88 1947.35,606.88 1947.36,606.88 1947.37,606.88 1947.38,606.88 1947.39,606.88 1947.4,606.88 1947.41,606.88 1947.42,606.88 1947.43,606.88 1947.43,606.88 1947.44,606.88 1947.45,606.88 1947.46,606.88 1947.47,606.88 1947.48,606.88 1947.49,606.88 1947.5,606.88 1947.51,606.88 1947.52,606.88 1947.53,606.88 1947.54,606.88 1947.54,606.88 1947.55,606.88 1947.56,606.88 1947.57,606.88 1947.58,606.88 1947.59,606.88 1947.6,606.88 1947.61,606.88 1947.62,606.88 1947.63,606.88 1947.64,606.88 1947.65,606.88 1947.66,606.88 1947.66,606.88 1947.67,606.88 1947.68,606.88 1947.69,606.88 1947.7,606.88 1947.71,606.88 1947.72,606.88 1947.73,606.88 1947.74,606.88 1947.75,606.88 1947.76,606.88 1947.77,606.88 1947.77,606.88 1947.78,606.88 1947.79,606.88 1947.8,606.88 1947.81,606.88 1947.82,606.88 1947.83,606.88 1947.84,606.88 1947.85,606.88 1947.86,606.88 1947.87,606.88 1947.88,606.88 1947.88,606.88 1947.89,606.88 1947.9,606.88 1947.91,606.88 1947.92,606.88 1947.93,606.88 1947.94,606.88 1947.95,606.88 1947.96,606.88 1947.97,606.88 1947.98,606.88 1947.99,606.88 1948,606.88 1948,606.88 1948.01,606.88 1948.02,606.88 1948.03,606.88 1948.04,606.88 1948.05,606.88 1948.06,606.88 1948.07,606.88 1948.08,606.88 1948.09,606.88 1948.1,606.88 1948.11,606.88 1948.11,606.88 1948.12,606.88 1948.13,606.88 1948.14,606.88 1948.15,606.88 1948.16,606.88 1948.17,606.88 1948.18,606.88 1948.19,606.88 1948.2,606.88 1948.21,606.88 1948.22,606.88 1948.22,606.88 1948.23,606.88 1948.24,606.88 1948.25,606.88 1948.26,606.88 1948.27,606.88 1948.28,606.88 1948.29,606.88 1948.3,606.88 1948.31,606.88 1948.32,606.88 1948.33,606.88 1948.34,606.88 1948.34,606.88 1948.35,606.88 1948.36,606.88 1948.37,606.88 1948.38,606.88 1948.39,606.88 1948.4,606.88 1948.41,606.88 1948.42,606.88 1948.43,606.88 1948.44,606.88 1948.45,606.88 1948.45,606.88 1948.46,606.88 1948.47,606.88 1948.48,606.88 1948.49,606.88 1948.5,606.88 1948.51,606.88 1948.52,606.88 1948.53,606.88 1948.54,606.88 1948.55,606.88 1948.56,606.88 1948.56,606.88 1948.57,606.88 1948.58,606.88 1948.59,606.88 1948.6,606.88 1948.61,606.88 1948.62,606.88 1948.63,606.88 1948.64,606.88 1948.65,606.88 1948.66,606.88 1948.67,606.88 1948.68,606.88 1948.68,606.88 1948.69,606.88 1948.7,606.88 1948.71,606.88 1948.72,606.88 1948.73,606.88 1948.74,606.88 1948.75,606.88 1948.76,606.88 1948.77,606.88 1948.78,606.88 1948.79,606.88 1948.79,606.88 1948.8,606.88 1948.81,606.88 1948.82,606.88 1948.83,606.88 1948.84,606.88 1948.85,606.88 1948.86,606.88 1948.87,606.88 1948.88,606.88 1948.89,606.88 1948.9,606.88 1948.9,606.88 1948.91,606.88 1948.92,606.88 1948.93,606.88 1948.94,606.88 1948.95,606.88 1948.96,606.88 1948.97,606.88 1948.98,606.88 1948.99,606.88 1949,606.88 1949.01,606.88 1949.02,606.88 1949.02,606.88 1949.03,606.88 1949.04,606.88 1949.05,606.88 1949.06,606.88 1949.07,606.88 1949.08,606.88 1949.09,606.88 1949.1,606.88 1949.11,606.88 1949.12,606.88 1949.13,606.88 1949.13,606.88 1949.14,606.88 1949.15,606.88 1949.16,606.88 1949.17,606.88 1949.18,606.88 1949.19,606.88 1949.2,606.88 1949.21,606.88 1949.22,606.88 1949.23,606.88 1949.24,606.88 1949.24,606.88 1949.25,606.88 1949.26,606.88 1949.27,606.88 1949.28,606.88 1949.29,606.88 1949.3,606.88 1949.31,606.88 1949.32,606.88 1949.33,606.88 1949.34,606.88 1949.35,606.88 1949.36,606.88 1949.36,606.88 1949.37,606.88 1949.38,606.88 1949.39,606.88 1949.4,606.88 1949.41,606.88 1949.42,606.88 1949.43,606.88 1949.44,606.88 1949.45,606.88 1949.46,606.88 1949.47,606.88 1949.47,606.88 1949.48,606.88 1949.49,606.88 1949.5,606.88 1949.51,606.88 1949.52,606.88 1949.53,606.88 1949.54,606.88 1949.55,606.88 1949.56,606.88 1949.57,606.88 1949.58,606.88 1949.58,606.88 1949.59,606.88 1949.6,606.88 1949.61,606.88 1949.62,606.88 1949.63,606.88 1949.64,606.88 1949.65,606.88 1949.66,606.88 1949.67,606.88 1949.68,606.88 1949.69,606.88 1949.7,606.88 1949.7,606.88 1949.71,606.88 1949.72,606.88 1949.73,606.88 1949.74,606.88 1949.75,606.88 1949.76,606.88 1949.77,606.88 1949.78,606.88 1949.79,606.88 1949.8,606.88 1949.81,606.88 1949.81,606.88 1949.82,606.88 1949.83,606.88 1949.84,606.88 1949.85,606.88 1949.86,606.88 1949.87,606.88 1949.88,606.88 1949.89,606.88 1949.9,606.88 1949.91,606.88 1949.92,606.88 1949.93,606.88 1949.93,606.88 1949.94,606.88 1949.95,606.88 1949.96,606.88 1949.97,606.88 1949.98,606.88 1949.99,606.88 1950,606.88 1950.01,606.88 1950.02,606.88 1950.03,606.88 1950.04,606.88 1950.04,606.88 1950.05,606.88 1950.06,606.88 1950.07,606.88 1950.08,606.88 1950.09,606.88 1950.1,606.88 1950.11,606.88 1950.12,606.88 1950.13,606.88 1950.14,606.88 1950.15,606.88 1950.15,606.88 1950.16,606.88 1950.17,606.88 1950.18,606.88 1950.19,606.88 1950.2,606.88 1950.21,606.88 1950.22,606.88 1950.23,606.88 1950.24,606.88 1950.25,606.88 1950.26,606.88 1950.27,606.88 1950.27,606.88 1950.28,606.88 1950.29,606.88 1950.3,606.88 1950.31,606.88 1950.32,606.88 1950.33,606.88 1950.34,606.88 1950.35,606.88 1950.36,606.88 1950.37,606.88 1950.38,606.88 1950.38,606.88 1950.39,606.88 1950.4,606.88 1950.41,606.88 1950.42,606.88 1950.43,606.88 1950.44,606.88 1950.45,606.88 1950.46,606.88 1950.47,606.88 1950.48,606.88 1950.49,606.88 1950.49,606.88 1950.5,606.88 1950.51,606.88 1950.52,606.88 1950.53,606.88 1950.54,606.88 1950.55,606.88 1950.56,606.88 1950.57,606.88 1950.58,606.88 1950.59,606.88 1950.6,606.88 1950.61,606.88 1950.61,606.88 1950.62,606.88 1950.63,606.88 1950.64,606.88 1950.65,606.88 1950.66,606.88 1950.67,606.88 1950.68,606.88 1950.69,606.88 1950.7,606.88 1950.71,606.88 1950.72,606.88 1950.72,606.88 1950.73,606.88 1950.74,606.88 1950.75,606.88 1950.76,606.88 1950.77,606.88 1950.78,606.88 1950.79,606.88 1950.8,606.88 1950.81,606.88 1950.82,606.88 1950.83,606.88 1950.83,606.88 1950.84,606.88 1950.85,606.88 1950.86,606.88 1950.87,606.88 1950.88,606.88 1950.89,606.88 1950.9,606.88 1950.91,606.88 1950.92,606.88 1950.93,606.88 1950.94,606.88 1950.95,606.88 1950.95,606.88 1950.96,606.88 1950.97,606.88 1950.98,606.88 1950.99,606.88 1951,606.88 1951.01,606.88 1951.02,606.88 1951.03,606.88 1951.04,606.88 1951.05,606.88 1951.06,606.88 1951.06,606.88 1951.07,606.88 1951.08,606.88 1951.09,606.88 1951.1,606.88 1951.11,606.88 1951.12,606.88 1951.13,606.88 1951.14,606.88 1951.15,606.88 1951.16,606.88 1951.17,606.88 1951.17,606.88 1951.18,606.88 1951.19,606.88 1951.2,606.88 1951.21,606.88 1951.22,606.88 1951.23,606.88 1951.24,606.88 1951.25,606.88 1951.26,606.88 1951.27,606.88 1951.28,606.88 1951.29,606.88 1951.29,606.88 1951.3,606.88 1951.31,606.88 1951.32,606.88 1951.33,606.88 1951.34,606.88 1951.35,606.88 1951.36,606.88 1951.37,606.88 1951.38,606.88 1951.39,606.88 1951.4,606.88 1951.4,606.88 1951.41,606.88 1951.42,606.88 1951.43,606.88 1951.44,606.88 1951.45,606.88 1951.46,606.88 1951.47,606.88 1951.48,606.88 1951.49,606.88 1951.5,606.88 1951.51,606.88 1951.51,606.88 1951.52,606.88 1951.53,606.88 1951.54,606.88 1951.55,606.88 1951.56,606.88 1951.57,606.88 1951.58,606.88 1951.59,606.88 1951.6,606.88 1951.61,606.88 1951.62,606.88 1951.63,606.88 1951.63,606.88 1951.64,606.88 1951.65,606.88 1951.66,606.88 1951.67,606.88 1951.68,606.88 1951.69,606.88 1951.7,606.88 1951.71,606.88 1951.72,606.88 1951.73,606.88 1951.74,606.88 1951.74,606.88 1951.75,606.88 1951.76,606.88 1951.77,606.88 1951.78,606.88 1951.79,606.88 1951.8,606.88 1951.81,606.88 1951.82,606.88 1951.83,606.88 1951.84,606.88 1951.85,606.88 1951.85,606.88 1951.86,606.88 1951.87,606.88 1951.88,606.88 1951.89,606.88 1951.9,606.88 1951.91,606.88 1951.92,606.88 1951.93,606.88 1951.94,606.88 1951.95,606.88 1951.96,606.88 1951.97,606.88 1951.97,606.88 1951.98,606.88 1951.99,606.88 1952,606.88 1952.01,606.88 1952.02,606.88 1952.03,606.88 1952.04,606.88 1952.05,606.88 1952.06,606.88 1952.07,606.88 1952.08,606.88 1952.08,606.88 1952.09,606.88 1952.1,606.88 1952.11,606.88 1952.12,606.88 1952.13,606.88 1952.14,606.88 1952.15,606.88 1952.16,606.88 1952.17,606.88 1952.18,606.88 1952.19,606.88 1952.19,606.88 1952.2,606.88 1952.21,606.88 1952.22,606.88 1952.23,606.88 1952.24,606.88 1952.25,606.88 1952.26,606.88 1952.27,606.88 1952.28,606.88 1952.29,606.88 1952.3,606.88 1952.31,606.88 1952.31,606.88 1952.32,606.88 1952.33,606.88 1952.34,606.88 1952.35,606.88 1952.36,606.88 1952.37,606.88 1952.38,606.88 1952.39,606.88 1952.4,606.88 1952.41,606.88 1952.42,606.88 1952.42,606.88 1952.43,606.88 1952.44,606.88 1952.45,606.88 1952.46,606.88 1952.47,606.88 1952.48,606.88 1952.49,606.88 1952.5,606.88 1952.51,606.88 1952.52,606.88 1952.53,606.88 1952.53,606.88 1952.54,606.88 1952.55,606.88 1952.56,606.88 1952.57,606.88 1952.58,606.88 1952.59,606.88 1952.6,606.88 1952.61,606.88 1952.62,606.88 1952.63,606.88 1952.64,606.88 1952.65,606.88 1952.65,606.88 1952.66,606.88 1952.67,606.88 1952.68,606.88 1952.69,606.88 1952.7,606.88 1952.71,606.88 1952.72,606.88 1952.73,606.88 1952.74,606.88 1952.75,606.88 1952.76,606.88 1952.76,606.88 1952.77,606.88 1952.78,606.88 1952.79,606.88 1952.8,606.88 1952.81,606.88 1952.82,606.88 1952.83,606.88 1952.84,606.88 1952.85,606.88 1952.86,606.88 1952.87,606.88 1952.87,606.88 1952.88,606.88 1952.89,606.88 1952.9,606.88 1952.91,606.88 1952.92,606.88 1952.93,606.88 1952.94,606.88 1952.95,606.88 1952.96,606.88 1952.97,606.88 1952.98,606.88 1952.99,606.88 1952.99,606.88 1953,606.88 1953.01,606.88 1953.02,606.88 1953.03,606.88 1953.04,606.88 1953.05,606.88 1953.06,606.88 1953.07,606.88 1953.08,606.88 1953.09,606.88 1953.1,606.88 1953.1,606.88 1953.11,606.88 1953.12,606.88 1953.13,606.88 1953.14,606.88 1953.15,606.88 1953.16,606.88 1953.17,606.88 1953.18,606.88 1953.19,606.88 1953.2,606.88 1953.21,606.88 1953.21,606.88 1953.22,606.88 1953.23,606.88 1953.24,606.88 1953.25,606.88 1953.26,606.88 1953.27,606.88 1953.28,606.88 1953.29,606.88 1953.3,606.88 1953.31,606.88 1953.32,606.88 1953.33,606.88 1953.33,606.88 1953.34,606.88 1953.35,606.88 1953.36,606.88 1953.37,606.88 1953.38,606.88 1953.39,606.88 1953.4,606.88 1953.41,606.88 1953.42,606.88 1953.43,606.88 1953.44,606.88 1953.44,606.88 1953.45,606.88 1953.46,606.88 1953.47,606.88 1953.48,606.88 1953.49,606.88 1953.5,606.88 1953.51,606.88 1953.52,606.88 1953.53,606.88 1953.54,606.88 1953.55,606.88 1953.55,606.88 1953.56,606.88 1953.57,606.88 1953.58,606.88 1953.59,606.88 1953.6,606.88 1953.61,606.88 1953.62,606.88 1953.63,606.88 1953.64,606.88 1953.65,606.88 1953.66,606.88 1953.67,606.88 1953.67,606.88 1953.68,606.88 1953.69,606.88 1953.7,606.88 1953.71,606.88 1953.72,606.88 1953.73,606.88 1953.74,606.88 1953.75,606.88 1953.76,606.88 1953.77,606.88 1953.78,606.88 1953.78,606.88 1953.79,606.88 1953.8,606.88 1953.81,606.88 1953.82,606.88 1953.83,606.88 1953.84,606.88 1953.85,606.88 1953.86,606.88 1953.87,606.88 1953.88,606.88 1953.89,606.88 1953.89,606.88 1953.9,606.88 1953.91,606.88 1953.92,606.88 1953.93,606.88 1953.94,606.88 1953.95,606.88 1953.96,606.88 1953.97,606.88 1953.98,606.88 1953.99,606.88 1954,606.88 1954.01,606.88 1954.01,606.88 1954.02,606.88 1954.03,606.88 1954.04,606.88 1954.05,606.88 1954.06,606.88 1954.07,606.88 1954.08,606.88 1954.09,606.88 1954.1,606.88 1954.11,606.88 1954.12,606.88 1954.12,606.88 1954.13,606.88 1954.14,606.88 1954.15,606.88 1954.16,606.88 1954.17,606.88 1954.18,606.88 1954.19,606.88 1954.2,606.88 1954.21,606.88 1954.22,606.88 1954.23,606.88 1954.23,606.88 1954.24,606.88 1954.25,606.88 1954.26,606.88 1954.27,606.88 1954.28,606.88 1954.29,606.88 1954.3,606.88 1954.31,606.88 1954.32,606.88 1954.33,606.88 1954.34,606.88 1954.35,606.88 1954.35,606.88 1954.36,606.88 1954.37,606.88 1954.38,606.88 1954.39,606.88 1954.4,606.88 1954.41,606.88 1954.42,606.88 1954.43,606.88 1954.44,606.88 1954.45,606.88 1954.46,606.88 1954.46,606.88 1954.47,606.88 1954.48,606.88 1954.49,606.88 1954.5,606.88 1954.51,606.88 1954.52,606.88 1954.53,606.88 1954.54,606.88 1954.55,606.88 1954.56,606.88 1954.57,606.88 1954.57,606.88 1954.58,606.88 1954.59,606.88 1954.6,606.88 1954.61,606.88 1954.62,606.88 1954.63,606.88 1954.64,606.88 1954.65,606.88 1954.66,606.88 1954.67,606.88 1954.68,606.88 1954.69,606.88 1954.69,606.88 1954.7,606.88 1954.71,606.88 1954.72,606.88 1954.73,606.88 1954.74,606.88 1954.75,606.88 1954.76,606.88 1954.77,606.88 1954.78,606.88 1954.79,606.88 1954.8,606.88 1954.8,606.88 1954.81,606.88 1954.82,606.88 1954.83,606.88 1954.84,606.88 1954.85,606.88 1954.86,606.88 1954.87,606.88 1954.88,606.88 1954.89,606.88 1954.9,606.88 1954.91,606.88 1954.91,606.88 1954.92,606.88 1954.93,606.88 1954.94,606.88 1954.95,606.88 1954.96,606.88 1954.97,606.88 1954.98,606.88 1954.99,606.88 1955,606.88 1955.01,606.88 1955.02,606.88 1955.03,606.88 1955.03,606.88 1955.04,606.88 1955.05,606.88 1955.06,606.88 1955.07,606.88 1955.08,606.88 1955.09,606.88 1955.1,606.88 1955.11,606.88 1955.12,606.88 1955.13,606.88 1955.14,606.88 1955.14,606.88 1955.15,606.88 1955.16,606.88 1955.17,606.88 1955.18,606.88 1955.19,606.88 1955.2,606.88 1955.21,606.88 1955.22,606.88 1955.23,606.88 1955.24,606.88 1955.25,606.88 1955.25,606.88 1955.26,606.88 1955.27,606.88 1955.28,606.88 1955.29,606.88 1955.3,606.88 1955.31,606.88 1955.32,606.88 1955.33,606.88 1955.34,606.88 1955.35,606.88 1955.36,606.88 1955.37,606.88 1955.37,606.88 1955.38,606.88 1955.39,606.88 1955.4,606.88 1955.41,606.88 1955.42,606.88 1955.43,606.88 1955.44,606.88 1955.45,606.88 1955.46,606.88 1955.47,606.88 1955.48,606.88 1955.48,606.88 1955.49,606.88 1955.5,606.88 1955.51,606.88 1955.52,606.88 1955.53,606.88 1955.54,606.88 1955.55,606.88 1955.56,606.88 1955.57,606.88 1955.58,606.88 1955.59,606.88 1955.59,606.88 1955.6,606.88 1955.61,606.88 1955.62,606.88 1955.63,606.88 1955.64,606.88 1955.65,606.88 1955.66,606.88 1955.67,606.88 1955.68,606.88 1955.69,606.88 1955.7,606.88 1955.71,606.88 1955.71,606.88 1955.72,606.88 1955.73,606.88 1955.74,606.88 1955.75,606.88 1955.76,606.88 1955.77,606.88 1955.78,606.88 1955.79,606.88 1955.8,606.88 1955.81,606.88 1955.82,606.88 1955.82,606.88 1955.83,606.88 1955.84,606.88 1955.85,606.88 1955.86,606.88 1955.87,606.88 1955.88,606.88 1955.89,606.88 1955.9,606.88 1955.91,606.88 1955.92,606.88 1955.93,606.88 1955.93,606.88 1955.94,606.88 1955.95,606.88 1955.96,606.88 1955.97,606.88 1955.98,606.88 1955.99,606.88 1956,606.88 1956.01,606.88 1956.02,606.88 1956.03,606.88 1956.04,606.88 1956.05,606.88 1956.05,606.88 1956.06,606.88 1956.07,606.88 1956.08,606.88 1956.09,606.88 1956.1,606.88 1956.11,606.88 1956.12,606.88 1956.13,606.88 1956.14,606.88 1956.15,606.88 1956.16,606.88 1956.16,606.88 1956.17,606.88 1956.18,606.88 1956.19,606.88 1956.2,606.88 1956.21,606.88 1956.22,606.88 1956.23,606.88 1956.24,606.88 1956.25,606.88 1956.26,606.88 1956.27,606.88 1956.27,606.88 1956.28,606.88 1956.29,606.88 1956.3,606.88 1956.31,606.88 1956.32,606.88 1956.33,606.88 1956.34,606.88 1956.35,606.88 1956.36,606.88 1956.37,606.88 1956.38,606.88 1956.39,606.88 1956.39,606.88 1956.4,606.88 1956.41,606.88 1956.42,606.88 1956.43,606.88 1956.44,606.88 1956.45,606.88 1956.46,606.88 1956.47,606.88 1956.48,606.88 1956.49,606.88 1956.5,606.88 1956.5,606.88 1956.51,606.88 1956.52,606.88 1956.53,606.88 1956.54,606.88 1956.55,606.88 1956.56,606.88 1956.57,606.88 1956.58,606.88 1956.59,606.88 1956.6,606.88 1956.61,606.88 1956.61,606.88 1956.62,606.88 1956.63,606.88 1956.64,606.88 1956.65,606.88 1956.66,606.88 1956.67,606.88 1956.68,606.88 1956.69,606.88 1956.7,606.88 1956.71,606.88 1956.72,606.88 1956.73,606.88 1956.73,606.88 1956.74,606.88 1956.75,606.88 1956.76,606.88 1956.77,606.88 1956.78,606.88 1956.79,606.88 1956.8,606.88 1956.81,606.88 1956.82,606.88 1956.83,606.88 1956.84,606.88 1956.84,606.88 1956.85,606.88 1956.86,606.88 1956.87,606.88 1956.88,606.88 1956.89,606.88 1956.9,606.88 1956.91,606.88 1956.92,606.88 1956.93,606.88 1956.94,606.88 1956.95,606.88 1956.95,606.88 1956.96,606.88 1956.97,606.88 1956.98,606.88 1956.99,606.88 1957,606.88 1957.01,606.88 1957.02,606.88 1957.03,606.88 1957.04,606.88 1957.05,606.88 1957.06,606.88 1957.07,606.88 1957.07,606.88 1957.08,606.88 1957.09,606.88 1957.1,606.88 1957.11,606.88 1957.12,606.88 1957.13,606.88 1957.14,606.88 1957.15,606.88 1957.16,606.88 1957.17,606.88 1957.18,606.88 1957.18,606.88 1957.19,606.88 1957.2,606.88 1957.21,606.88 1957.22,606.88 1957.23,606.88 1957.24,606.88 1957.25,606.88 1957.26,606.88 1957.27,606.88 1957.28,606.88 1957.29,606.88 1957.29,606.88 1957.3,606.88 1957.31,606.88 1957.32,606.88 1957.33,606.88 1957.34,606.88 1957.35,606.88 1957.36,606.88 1957.37,606.88 1957.38,606.88 1957.39,606.88 1957.4,606.88 1957.41,606.88 1957.41,606.88 1957.42,606.88 1957.43,606.88 1957.44,606.88 1957.45,606.88 1957.46,606.88 1957.47,606.88 1957.48,606.88 1957.49,606.88 1957.5,606.88 1957.51,606.88 1957.52,606.88 1957.52,606.88 1957.53,606.88 1957.54,606.88 1957.55,606.88 1957.56,606.88 1957.57,606.88 1957.58,606.88 1957.59,606.88 1957.6,606.88 1957.61,606.88 1957.62,606.88 1957.63,606.88 1957.63,606.88 1957.64,606.88 1957.65,606.88 1957.66,606.88 1957.67,606.88 1957.68,606.88 1957.69,606.88 1957.7,606.88 1957.71,606.88 1957.72,606.88 1957.73,606.88 1957.74,606.88 1957.75,606.88 1957.75,606.88 1957.76,606.88 1957.77,606.88 1957.78,606.88 1957.79,606.88 1957.8,606.88 1957.81,606.88 1957.82,606.88 1957.83,606.88 1957.84,606.88 1957.85,606.88 1957.86,606.88 1957.86,606.88 1957.87,606.88 1957.88,606.88 1957.89,606.88 1957.9,606.88 1957.91,606.88 1957.92,606.88 1957.93,606.88 1957.94,606.88 1957.95,606.88 1957.96,606.88 1957.97,606.88 1957.97,606.88 1957.98,606.88 1957.99,606.88 1958,606.88 1958.01,606.88 1958.02,606.88 1958.03,606.88 1958.04,606.88 1958.05,606.88 1958.06,606.88 1958.07,606.88 1958.08,606.88 1958.09,606.88 1958.09,606.88 1958.1,606.88 1958.11,606.88 1958.12,606.88 1958.13,606.88 1958.14,606.88 1958.15,606.88 1958.16,606.88 1958.17,606.88 1958.18,606.88 1958.19,606.88 1958.2,606.88 1958.2,606.88 1958.21,606.88 1958.22,606.88 1958.23,606.88 1958.24,606.88 1958.25,606.88 1958.26,606.88 1958.27,606.88 1958.28,606.88 1958.29,606.88 1958.3,606.88 1958.31,606.88 1958.31,606.88 1958.32,606.88 1958.33,606.88 1958.34,606.88 1958.35,606.88 1958.36,606.88 1958.37,606.88 1958.38,606.88 1958.39,606.88 1958.4,606.88 1958.41,606.88 1958.42,606.88 1958.43,606.88 1958.43,606.88 1958.44,606.88 1958.45,606.88 1958.46,606.88 1958.47,606.88 1958.48,606.88 1958.49,606.88 1958.5,606.88 1958.51,606.88 1958.52,606.88 1958.53,606.88 1958.54,606.88 1958.54,606.88 1958.55,606.88 1958.56,606.88 1958.57,606.88 1958.58,606.88 1958.59,606.88 1958.6,606.88 1958.61,606.88 1958.62,606.88 1958.63,606.88 1958.64,606.88 1958.65,606.88 1958.65,606.88 1958.66,606.88 1958.67,606.88 1958.68,606.88 1958.69,606.88 1958.7,606.88 1958.71,606.88 1958.72,606.88 1958.73,606.88 1958.74,606.88 1958.75,606.88 1958.76,606.88 1958.77,606.88 1958.77,606.88 1958.78,606.88 1958.79,606.88 1958.8,606.88 1958.81,606.88 1958.82,606.88 1958.83,606.88 1958.84,606.88 1958.85,606.88 1958.86,606.88 1958.87,606.88 1958.88,606.88 1958.88,606.88 1958.89,606.88 1958.9,606.88 1958.91,606.88 1958.92,606.88 1958.93,606.88 1958.94,606.88 1958.95,606.88 1958.96,606.88 1958.97,606.88 1958.98,606.88 1958.99,606.88 1958.99,606.88 1959,606.88 1959.01,606.88 1959.02,606.88 1959.03,606.88 1959.04,606.88 1959.05,606.88 1959.06,606.88 1959.07,606.88 1959.08,606.88 1959.09,606.88 1959.1,606.88 1959.11,606.88 1959.11,606.88 1959.12,606.88 1959.13,606.88 1959.14,606.88 1959.15,606.88 1959.16,606.88 1959.17,606.88 1959.18,606.88 1959.19,606.88 1959.2,606.88 1959.21,606.88 1959.22,606.88 1959.22,606.88 1959.23,606.88 1959.24,606.88 1959.25,606.88 1959.26,606.88 1959.27,606.88 1959.28,606.88 1959.29,606.88 1959.3,606.88 1959.31,606.88 1959.32,606.88 1959.33,606.88 1959.33,606.88 1959.34,606.88 1959.35,606.88 1959.36,606.88 1959.37,606.88 1959.38,606.88 1959.39,606.88 1959.4,606.88 1959.41,606.88 1959.42,606.88 1959.43,606.88 1959.44,606.88 1959.45,606.88 1959.45,606.88 1959.46,606.88 1959.47,606.88 1959.48,606.88 1959.49,606.88 1959.5,606.88 1959.51,606.88 1959.52,606.88 1959.53,606.88 1959.54,606.88 1959.55,606.88 1959.56,606.88 1959.56,606.88 1959.57,606.88 1959.58,606.88 1959.59,606.88 1959.6,606.88 1959.61,606.88 1959.62,606.88 1959.63,606.88 1959.64,606.88 1959.65,606.88 1959.66,606.88 1959.67,606.88 1959.67,606.88 1959.68,606.88 1959.69,606.88 1959.7,606.88 1959.71,606.88 1959.72,606.88 1959.73,606.88 1959.74,606.88 1959.75,606.88 1959.76,606.88 1959.77,606.88 1959.78,606.88 1959.79,606.88 1959.79,606.88 1959.8,606.88 1959.81,606.88 1959.82,606.88 1959.83,606.88 1959.84,606.88 1959.85,606.88 1959.86,606.88 1959.87,606.88 1959.88,606.88 1959.89,606.88 1959.9,606.88 1959.9,606.88 1959.91,606.88 1959.92,606.88 1959.93,606.88 1959.94,606.88 1959.95,606.88 1959.96,606.88 1959.97,606.88 1959.98,606.88 1959.99,606.88 1960,606.88 1960.01,606.88 1960.01,606.88 1960.02,606.88 1960.03,606.88 1960.04,606.88 1960.05,606.88 1960.06,606.88 1960.07,606.88 1960.08,606.88 1960.09,606.88 1960.1,606.88 1960.11,606.88 1960.12,606.88 1960.13,606.88 1960.13,606.88 1960.14,606.88 1960.15,606.88 1960.16,606.88 1960.17,606.88 1960.18,606.88 1960.19,606.88 1960.2,606.88 1960.21,606.88 1960.22,606.88 1960.23,606.88 1960.24,606.88 1960.24,606.88 1960.25,606.88 1960.26,606.88 1960.27,606.88 1960.28,606.88 1960.29,606.88 1960.3,606.88 1960.31,606.88 1960.32,606.88 1960.33,606.88 1960.34,606.88 1960.35,606.88 1960.35,606.88 1960.36,606.88 1960.37,606.88 1960.38,606.88 1960.39,606.88 1960.4,606.88 1960.41,606.88 1960.42,606.88 1960.43,606.88 1960.44,606.88 1960.45,606.88 1960.46,606.88 1960.47,606.88 1960.47,606.88 1960.48,606.88 1960.49,606.88 1960.5,606.88 1960.51,606.88 1960.52,606.88 1960.53,606.88 1960.54,606.88 1960.55,606.88 1960.56,606.88 1960.57,606.88 1960.58,606.88 1960.58,606.88 1960.59,606.88 1960.6,606.88 1960.61,606.88 1960.62,606.88 1960.63,606.88 1960.64,606.88 1960.65,606.88 1960.66,606.88 1960.67,606.88 1960.68,606.88 1960.69,606.88 1960.69,606.88 1960.7,606.88 1960.71,606.88 1960.72,606.88 1960.73,606.88 1960.74,606.88 1960.75,606.88 1960.76,606.88 1960.77,606.88 1960.78,606.88 1960.79,606.88 1960.8,606.88 1960.81,606.88 1960.81,606.88 1960.82,606.88 1960.83,606.88 1960.84,606.88 1960.85,606.88 1960.86,606.88 1960.87,606.88 1960.88,606.88 1960.89,606.88 1960.9,606.88 1960.91,606.88 1960.92,606.88 1960.92,606.88 1960.93,606.88 1960.94,606.88 1960.95,606.88 1960.96,606.88 1960.97,606.88 1960.98,606.88 1960.99,606.88 1961,606.88 1961.01,606.88 1961.02,606.88 1961.03,606.88 1961.03,606.88 1961.04,606.88 1961.05,606.88 1961.06,606.88 1961.07,606.88 1961.08,606.88 1961.09,606.88 1961.1,606.88 1961.11,606.88 1961.12,606.88 1961.13,606.88 1961.14,606.88 1961.15,606.88 1961.15,606.88 1961.16,606.88 1961.17,606.88 1961.18,606.88 1961.19,606.88 1961.2,606.88 1961.21,606.88 1961.22,606.88 1961.23,606.88 1961.24,606.88 1961.25,606.88 1961.26,606.88 1961.26,606.88 1961.27,606.88 1961.28,606.88 1961.29,606.88 1961.3,606.88 1961.31,606.88 1961.32,606.88 1961.33,606.88 1961.34,606.88 1961.35,606.88 1961.36,606.88 1961.37,606.88 1961.37,606.88 1961.38,606.88 1961.39,606.88 1961.4,606.88 1961.41,606.88 1961.42,606.88 1961.43,606.88 1961.44,606.88 1961.45,606.88 1961.46,606.88 1961.47,606.88 1961.48,606.88 1961.49,606.88 1961.49,606.88 1961.5,606.88 1961.51,606.88 1961.52,606.88 1961.53,606.88 1961.54,606.88 1961.55,606.88 1961.56,606.88 1961.57,606.88 1961.58,606.88 1961.59,606.88 1961.6,606.88 1961.6,606.88 1961.61,606.88 1961.62,606.88 1961.63,606.88 1961.64,606.88 1961.65,606.88 1961.66,606.88 1961.67,606.88 1961.68,606.88 1961.69,606.88 1961.7,606.88 1961.71,606.88 1961.71,606.88 1961.72,606.88 1961.73,606.88 1961.74,606.88 1961.75,606.88 1961.76,606.88 1961.77,606.88 1961.78,606.88 1961.79,606.88 1961.8,606.88 1961.81,606.88 1961.82,606.88 1961.83,606.88 1961.83,606.88 1961.84,606.88 1961.85,606.88 1961.86,606.88 1961.87,606.88 1961.88,606.88 1961.89,606.88 1961.9,606.88 1961.91,606.88 1961.92,606.88 1961.93,606.88 1961.94,606.88 1961.94,606.88 1961.95,606.88 1961.96,606.88 1961.97,606.88 1961.98,606.88 1961.99,606.88 1962,606.88 1962.01,606.88 1962.02,606.88 1962.03,606.88 1962.04,606.88 1962.05,606.88 1962.05,606.88 1962.06,606.88 1962.07,606.88 1962.08,606.88 1962.09,606.88 1962.1,606.88 1962.11,606.88 1962.12,606.88 1962.13,606.88 1962.14,606.88 1962.15,606.88 1962.16,606.88 1962.17,606.88 1962.17,606.88 1962.18,606.88 1962.19,606.88 1962.2,606.88 1962.21,606.88 1962.22,606.88 1962.23,606.88 1962.24,606.88 1962.25,606.88 1962.26,606.88 1962.27,606.88 1962.28,606.88 1962.28,606.88 1962.29,606.88 1962.3,606.88 1962.31,606.88 1962.32,606.88 1962.33,606.88 1962.34,606.88 1962.35,606.88 1962.36,606.88 1962.37,606.88 1962.38,606.88 1962.39,606.88 1962.39,606.88 1962.4,606.88 1962.41,606.88 1962.42,606.88 1962.43,606.88 1962.44,606.88 1962.45,606.88 1962.46,606.88 1962.47,606.88 1962.48,606.88 1962.49,606.88 1962.5,606.88 1962.51,606.88 1962.51,606.88 1962.52,606.88 1962.53,606.88 1962.54,606.88 1962.55,606.88 1962.56,606.88 1962.57,606.88 1962.58,606.88 1962.59,606.88 1962.6,606.88 1962.61,606.88 1962.62,606.88 1962.62,606.88 1962.63,606.88 1962.64,606.88 1962.65,606.88 1962.66,606.88 1962.67,606.88 1962.68,606.88 1962.69,606.88 1962.7,606.88 1962.71,606.88 1962.72,606.88 1962.73,606.88 1962.73,606.88 1962.74,606.88 1962.75,606.88 1962.76,606.88 1962.77,606.88 1962.78,606.88 1962.79,606.88 1962.8,606.88 1962.81,606.88 1962.82,606.88 1962.83,606.88 1962.84,606.88 1962.85,606.88 1962.85,606.88 1962.86,606.88 1962.87,606.88 1962.88,606.88 1962.89,606.88 1962.9,606.88 1962.91,606.88 1962.92,606.88 1962.93,606.88 1962.94,606.88 1962.95,606.88 1962.96,606.88 1962.96,606.88 1962.97,606.88 1962.98,606.88 1962.99,606.88 1963,606.88 1963.01,606.88 1963.02,606.88 1963.03,606.88 1963.04,606.88 1963.05,606.88 1963.06,606.88 1963.07,606.88 1963.07,606.88 1963.08,606.88 1963.09,606.88 1963.1,606.88 1963.11,606.88 1963.12,606.88 1963.13,606.88 1963.14,606.88 1963.15,606.88 1963.16,606.88 1963.17,606.88 1963.18,606.88 1963.19,606.88 1963.19,606.88 1963.2,606.88 1963.21,606.88 1963.22,606.88 1963.23,606.88 1963.24,606.88 1963.25,606.88 1963.26,606.88 1963.27,606.88 1963.28,606.88 1963.29,606.88 1963.3,606.88 1963.3,606.88 1963.31,606.88 1963.32,606.88 1963.33,606.88 1963.34,606.88 1963.35,606.88 1963.36,606.88 1963.37,606.88 1963.38,606.88 1963.39,606.88 1963.4,606.88 1963.41,606.88 1963.41,606.88 1963.42,606.88 1963.43,606.88 1963.44,606.88 1963.45,606.88 1963.46,606.88 1963.47,606.88 1963.48,606.88 1963.49,606.88 1963.5,606.88 1963.51,606.88 1963.52,606.88 1963.53,606.88 1963.53,606.88 1963.54,606.88 1963.55,606.88 1963.56,606.88 1963.57,606.88 1963.58,606.88 1963.59,606.88 1963.6,606.88 1963.61,606.88 1963.62,606.88 1963.63,606.88 1963.64,606.88 1963.64,606.88 1963.65,606.88 1963.66,606.88 1963.67,606.88 1963.68,606.88 1963.69,606.88 1963.7,606.88 1963.71,606.88 1963.72,606.88 1963.73,606.88 1963.74,606.88 1963.75,606.88 1963.75,606.88 1963.76,606.88 1963.77,606.88 1963.78,606.88 1963.79,606.88 1963.8,606.88 1963.81,606.88 1963.82,606.88 1963.83,606.88 1963.84,606.88 1963.85,606.88 1963.86,606.88 1963.87,606.88 1963.87,606.88 1963.88,606.88 1963.89,606.88 1963.9,606.88 1963.91,606.88 1963.92,606.88 1963.93,606.88 1963.94,606.88 1963.95,606.88 1963.96,606.88 1963.97,606.88 1963.98,606.88 1963.98,606.88 1963.99,606.88 1964,606.88 1964.01,606.88 1964.02,606.88 1964.03,606.88 1964.04,606.88 1964.05,606.88 1964.06,606.88 1964.07,606.88 1964.08,606.88 1964.09,606.88 1964.09,606.88 1964.1,606.88 1964.11,606.88 1964.12,606.88 1964.13,606.88 1964.14,606.88 1964.15,606.88 1964.16,606.88 1964.17,606.88 1964.18,606.88 1964.19,606.88 1964.2,606.88 1964.21,606.88 1964.21,606.88 1964.22,606.88 1964.23,606.88 1964.24,606.88 1964.25,606.88 1964.26,606.88 1964.27,606.88 1964.28,606.88 1964.29,606.88 1964.3,606.88 1964.31,606.88 1964.32,606.88 1964.32,606.88 1964.33,606.88 1964.34,606.88 1964.35,606.88 1964.36,606.88 1964.37,606.88 1964.38,606.88 1964.39,606.88 1964.4,606.88 1964.41,606.88 1964.42,606.88 1964.43,606.88 1964.43,606.88 1964.44,606.88 1964.45,606.88 1964.46,606.88 1964.47,606.88 1964.48,606.88 1964.49,606.88 1964.5,606.88 1964.51,606.88 1964.52,606.88 1964.53,606.88 1964.54,606.88 1964.55,606.88 1964.55,606.88 1964.56,606.88 1964.57,606.88 1964.58,606.88 1964.59,606.88 1964.6,606.88 1964.61,606.88 1964.62,606.88 1964.63,606.88 1964.64,606.88 1964.65,606.88 1964.66,606.88 1964.66,606.88 1964.67,606.88 1964.68,606.88 1964.69,606.88 1964.7,606.88 1964.71,606.88 1964.72,606.88 1964.73,606.88 1964.74,606.88 1964.75,606.88 1964.76,606.88 1964.77,606.88 1964.77,606.88 1964.78,606.88 1964.79,606.88 1964.8,606.88 1964.81,606.88 1964.82,606.88 1964.83,606.88 1964.84,606.88 1964.85,606.88 1964.86,606.88 1964.87,606.88 1964.88,606.88 1964.89,606.88 1964.89,606.88 1964.9,606.88 1964.91,606.88 1964.92,606.88 1964.93,606.88 1964.94,606.88 1964.95,606.88 1964.96,606.88 1964.97,606.88 1964.98,606.88 1964.99,606.88 1965,606.88 1965,606.88 1965.01,606.88 1965.02,606.88 1965.03,606.88 1965.04,606.88 1965.05,606.88 1965.06,606.88 1965.07,606.88 1965.08,606.88 1965.09,606.88 1965.1,606.88 1965.11,606.88 1965.11,606.88 1965.12,606.88 1965.13,606.88 1965.14,606.88 1965.15,606.88 1965.16,606.88 1965.17,606.88 1965.18,606.88 1965.19,606.88 1965.2,606.88 1965.21,606.88 1965.22,606.88 1965.23,606.88 1965.23,606.88 1965.24,606.88 1965.25,606.88 1965.26,606.88 1965.27,606.88 1965.28,606.88 1965.29,606.88 1965.3,606.88 1965.31,606.88 1965.32,606.88 1965.33,606.88 1965.34,606.88 1965.34,606.88 1965.35,606.88 1965.36,606.88 1965.37,606.88 1965.38,606.88 1965.39,606.88 1965.4,606.88 1965.41,606.88 1965.42,606.88 1965.43,606.88 1965.44,606.88 1965.45,606.88 1965.45,606.88 1965.46,606.88 1965.47,606.88 1965.48,606.88 1965.49,606.88 1965.5,606.88 1965.51,606.88 1965.52,606.88 1965.53,606.88 1965.54,606.88 1965.55,606.88 1965.56,606.88 1965.57,606.88 1965.57,606.88 1965.58,606.88 1965.59,606.88 1965.6,606.88 1965.61,606.88 1965.62,606.88 1965.63,606.88 1965.64,606.88 1965.65,606.88 1965.66,606.88 1965.67,606.88 1965.68,606.88 1965.68,606.88 1965.69,606.88 1965.7,606.88 1965.71,606.88 1965.72,606.88 1965.73,606.88 1965.74,606.88 1965.75,606.88 1965.76,606.88 1965.77,606.88 1965.78,606.88 1965.79,606.88 1965.79,606.88 1965.8,606.88 1965.81,606.88 1965.82,606.88 1965.83,606.88 1965.84,606.88 1965.85,606.88 1965.86,606.88 1965.87,606.88 1965.88,606.88 1965.89,606.88 1965.9,606.88 1965.91,606.88 1965.91,606.88 1965.92,606.88 1965.93,606.88 1965.94,606.88 1965.95,606.88 1965.96,606.88 1965.97,606.88 1965.98,606.88 1965.99,606.88 1966,606.88 1966.01,606.88 1966.02,606.88 1966.02,606.88 1966.03,606.88 1966.04,606.88 1966.05,606.88 1966.06,606.88 1966.07,606.88 1966.08,606.88 1966.09,606.88 1966.1,606.88 1966.11,606.88 1966.12,606.88 1966.13,606.88 1966.13,606.88 1966.14,606.88 1966.15,606.88 1966.16,606.88 1966.17,606.88 1966.18,606.88 1966.19,606.88 1966.2,606.88 1966.21,606.88 1966.22,606.88 1966.23,606.88 1966.24,606.88 1966.25,606.88 1966.25,606.88 1966.26,606.88 1966.27,606.88 1966.28,606.88 1966.29,606.88 1966.3,606.88 1966.31,606.88 1966.32,606.88 1966.33,606.88 1966.34,606.88 1966.35,606.88 1966.36,606.88 1966.36,606.88 1966.37,606.88 1966.38,606.88 1966.39,606.88 1966.4,606.88 1966.41,606.88 1966.42,606.88 1966.43,606.88 1966.44,606.88 1966.45,606.88 1966.46,606.88 1966.47,606.88 1966.47,606.88 1966.48,606.88 1966.49,606.88 1966.5,606.88 1966.51,606.88 1966.52,606.88 1966.53,606.88 1966.54,606.88 1966.55,606.88 1966.56,606.88 1966.57,606.88 1966.58,606.88 1966.59,606.88 1966.59,606.88 1966.6,606.88 1966.61,606.88 1966.62,606.88 1966.63,606.88 1966.64,606.88 1966.65,606.88 1966.66,606.88 1966.67,606.88 1966.68,606.88 1966.69,606.88 1966.7,606.88 1966.7,606.88 1966.71,606.88 1966.72,606.88 1966.73,606.88 1966.74,606.88 1966.75,606.88 1966.76,606.88 1966.77,606.88 1966.78,606.88 1966.79,606.88 1966.8,606.88 1966.81,606.88 1966.81,606.88 1966.82,606.88 1966.83,606.88 1966.84,606.88 1966.85,606.88 1966.86,606.88 1966.87,606.88 1966.88,606.88 1966.89,606.88 1966.9,606.88 1966.91,606.88 1966.92,606.88 1966.93,606.88 1966.93,606.88 1966.94,606.88 1966.95,606.88 1966.96,606.88 1966.97,606.88 1966.98,606.88 1966.99,606.88 1967,606.88 1967.01,606.88 1967.02,606.88 1967.03,606.88 1967.04,606.88 1967.04,606.88 1967.05,606.88 1967.06,606.88 1967.07,606.88 1967.08,606.88 1967.09,606.88 1967.1,606.88 1967.11,606.88 1967.12,606.88 1967.13,606.88 1967.14,606.88 1967.15,606.88 1967.15,606.88 1967.16,606.88 1967.17,606.88 1967.18,606.88 1967.19,606.88 1967.2,606.88 1967.21,606.88 1967.22,606.88 1967.23,606.88 1967.24,606.88 1967.25,606.88 1967.26,606.88 1967.27,606.88 1967.27,606.88 1967.28,606.88 1967.29,606.88 1967.3,606.88 1967.31,606.88 1967.32,606.88 1967.33,606.88 1967.34,606.88 1967.35,606.88 1967.36,606.88 1967.37,606.88 1967.38,606.88 1967.38,606.88 1967.39,606.88 1967.4,606.88 1967.41,606.88 1967.42,606.88 1967.43,606.88 1967.44,606.88 1967.45,606.88 1967.46,606.88 1967.47,606.88 1967.48,606.88 1967.49,606.88 1967.49,606.88 1967.5,606.88 1967.51,606.88 1967.52,606.88 1967.53,606.88 1967.54,606.88 1967.55,606.88 1967.56,606.88 1967.57,606.88 1967.58,606.88 1967.59,606.88 1967.6,606.88 1967.61,606.88 1967.61,606.88 1967.62,606.88 1967.63,606.88 1967.64,606.88 1967.65,606.88 1967.66,606.88 1967.67,606.88 1967.68,606.88 1967.69,606.88 1967.7,606.88 1967.71,606.88 1967.72,606.88 1967.72,606.88 1967.73,606.88 1967.74,606.88 1967.75,606.88 1967.76,606.88 1967.77,606.88 1967.78,606.88 1967.79,606.88 1967.8,606.88 1967.81,606.88 1967.82,606.88 1967.83,606.88 1967.83,606.88 1967.84,606.88 1967.85,606.88 1967.86,606.88 1967.87,606.88 1967.88,606.88 1967.89,606.88 1967.9,606.88 1967.91,606.88 1967.92,606.88 1967.93,606.88 1967.94,606.88 1967.95,606.88 1967.95,606.88 1967.96,606.88 1967.97,606.88 1967.98,606.88 1967.99,606.88 1968,606.88 1968.01,606.88 1968.02,606.88 1968.03,606.88 1968.04,606.88 1968.05,606.88 1968.06,606.88 1968.06,606.88 1968.07,606.88 1968.08,606.88 1968.09,606.88 1968.1,606.88 1968.11,606.88 1968.12,606.88 1968.13,606.88 1968.14,606.88 1968.15,606.88 1968.16,606.88 1968.17,606.88 1968.17,606.88 1968.18,606.88 1968.19,606.88 1968.2,606.88 1968.21,606.88 1968.22,606.88 1968.23,606.88 1968.24,606.88 1968.25,606.88 1968.26,606.88 1968.27,606.88 1968.28,606.88 1968.29,606.88 1968.29,606.88 1968.3,606.88 1968.31,606.88 1968.32,606.88 1968.33,606.88 1968.34,606.88 1968.35,606.88 1968.36,606.88 1968.37,606.88 1968.38,606.88 1968.39,606.88 1968.4,606.88 1968.4,606.88 1968.41,606.88 1968.42,606.88 1968.43,606.88 1968.44,606.88 1968.45,606.88 1968.46,606.88 1968.47,606.88 1968.48,606.88 1968.49,606.88 1968.5,606.88 1968.51,606.88 1968.51,606.88 1968.52,606.88 1968.53,606.88 1968.54,606.88 1968.55,606.88 1968.56,606.88 1968.57,606.88 1968.58,606.88 1968.59,606.88 1968.6,606.88 1968.61,606.88 1968.62,606.88 1968.63,606.88 1968.63,606.88 1968.64,606.88 1968.65,606.88 1968.66,606.88 1968.67,606.88 1968.68,606.88 1968.69,606.88 1968.7,606.88 1968.71,606.88 1968.72,606.88 1968.73,606.88 1968.74,606.88 1968.74,606.88 1968.75,606.88 1968.76,606.88 1968.77,606.88 1968.78,606.88 1968.79,606.88 1968.8,606.88 1968.81,606.88 1968.82,606.88 1968.83,606.88 1968.84,606.88 1968.85,606.88 1968.85,606.88 1968.86,606.88 1968.87,606.88 1968.88,606.88 1968.89,606.88 1968.9,606.88 1968.91,606.88 1968.92,606.88 1968.93,606.88 1968.94,606.88 1968.95,606.88 1968.96,606.88 1968.97,606.88 1968.97,606.88 1968.98,606.88 1968.99,606.88 1969,606.88 1969.01,606.88 1969.02,606.88 1969.03,606.88 1969.04,606.88 1969.05,606.88 1969.06,606.88 1969.07,606.88 1969.08,606.88 1969.08,606.88 1969.09,606.88 1969.1,606.88 1969.11,606.88 1969.12,606.88 1969.13,606.88 1969.14,606.88 1969.15,606.88 1969.16,606.88 1969.17,606.88 1969.18,606.88 1969.19,606.88 1969.19,606.88 1969.2,606.88 1969.21,606.88 1969.22,606.88 1969.23,606.88 1969.24,606.88 1969.25,606.88 1969.26,606.88 1969.27,606.88 1969.28,606.88 1969.29,606.88 1969.3,606.88 1969.31,606.88 1969.31,606.88 1969.32,606.88 1969.33,606.88 1969.34,606.88 1969.35,606.88 1969.36,606.88 1969.37,606.88 1969.38,606.88 1969.39,606.88 1969.4,606.88 1969.41,606.88 1969.42,606.88 1969.42,606.88 1969.43,606.88 1969.44,606.88 1969.45,606.88 1969.46,606.88 1969.47,606.88 1969.48,606.88 1969.49,606.88 1969.5,606.88 1969.51,606.88 1969.52,606.88 1969.53,606.88 1969.53,606.88 1969.54,606.88 1969.55,606.88 1969.56,606.88 1969.57,606.88 1969.58,606.88 1969.59,606.88 1969.6,606.88 1969.61,606.88 1969.62,606.88 1969.63,606.88 1969.64,606.88 1969.65,606.88 1969.65,606.88 1969.66,606.88 1969.67,606.88 1969.68,606.88 1969.69,606.88 1969.7,606.88 1969.71,606.88 1969.72,606.88 1969.73,606.88 1969.74,606.88 1969.75,606.88 1969.76,606.88 1969.76,606.88 1969.77,606.88 1969.78,606.88 1969.79,606.88 1969.8,606.88 1969.81,606.88 1969.82,606.88 1969.83,606.88 1969.84,606.879 1969.85,606.879 1969.86,606.879 1969.87,606.879 1969.87,606.879 1969.88,606.878 1969.89,606.878 1969.9,606.878 1969.91,606.878 1969.92,606.877 1969.93,606.877 1969.94,606.877 1969.95,606.876 1969.96,606.876 1969.97,606.875 1969.98,606.875 1969.99,606.874 1969.99,606.874 1970,606.873 1970.01,606.873 1970.02,606.872 1970.03,606.871 1970.04,606.871 1970.05,606.87 1970.06,606.869 1970.07,606.868 1970.08,606.868 1970.09,606.867 1970.1,606.866 1970.1,606.865 1970.11,606.864 1970.12,606.864 1970.13,606.863 1970.14,606.862 1970.15,606.861 1970.16,606.86 1970.17,606.859 1970.18,606.858 1970.19,606.857 1970.2,606.856 1970.21,606.855 1970.21,606.853 1970.22,606.852 1970.23,606.851 1970.24,606.85 1970.25,606.849 1970.26,606.847 1970.27,606.846 1970.28,606.845 1970.29,606.844 1970.3,606.842 1970.31,606.841 1970.32,606.839 1970.33,606.838 1970.33,606.837 1970.34,606.835 1970.35,606.834 1970.36,606.832 1970.37,606.831 1970.38,606.829 1970.39,606.827 1970.4,606.826 1970.41,606.824 1970.42,606.823 1970.43,606.821 1970.44,606.819 1970.44,606.818 1970.45,606.816 1970.46,606.814 1970.47,606.812 1970.48,606.81 1970.49,606.809 1970.5,606.807 1970.51,606.805 1970.52,606.803 1970.53,606.801 1970.54,606.799 1970.55,606.797 1970.55,606.795 1970.56,606.793 1970.57,606.791 1970.58,606.789 1970.59,606.787 1970.6,606.785 1970.61,606.782 1970.62,606.78 1970.63,606.778 1970.64,606.776 1970.65,606.774 1970.66,606.771 1970.67,606.769 1970.67,606.767 1970.68,606.764 1970.69,606.762 1970.7,606.76 1970.71,606.757 1970.72,606.755 1970.73,606.752 1970.74,606.75 1970.75,606.747 1970.76,606.745 1970.77,606.742 1970.78,606.74 1970.78,606.737 1970.79,606.734 1970.8,606.732 1970.81,606.729 1970.82,606.726 1970.83,606.724 1970.84,606.721 1970.85,606.718 1970.86,606.715 1970.87,606.713 1970.88,606.71 1970.89,606.707 1970.89,606.704 1970.9,606.701 1970.91,606.698 1970.92,606.695 1970.93,606.692 1970.94,606.689 1970.95,606.686 1970.96,606.683 1970.97,606.68 1970.98,606.677 1970.99,606.674 1971,606.671 1971.01,606.668 1971.01,606.665 1971.02,606.661 1971.03,606.658 1971.04,606.655 1971.05,606.652 1971.06,606.648 1971.07,606.645 1971.08,606.642 1971.09,606.638 1971.1,606.635 1971.11,606.632 1971.12,606.628 1971.12,606.625 1971.13,606.621 1971.14,606.618 1971.15,606.614 1971.16,606.611 1971.17,606.607 1971.18,606.604 1971.19,606.6 1971.2,606.596 1971.21,606.593 1971.22,606.589 1971.23,606.585 1971.23,606.582 1971.24,606.578 1971.25,606.574 1971.26,606.57 1971.27,606.567 1971.28,606.563 1971.29,606.559 1971.3,606.555 1971.31,606.551 1971.32,606.547 1971.33,606.543 1971.34,606.539 1971.35,606.535 1971.35,606.531 1971.36,606.527 1971.37,606.523 1971.38,606.519 1971.39,606.515 1971.4,606.511 1971.41,606.507 1971.42,606.502 1971.43,606.498 1971.44,606.494 1971.45,606.49 1971.46,606.486 1971.46,606.481 1971.47,606.477 1971.48,606.473 1971.49,606.468 1971.5,606.464 1971.51,606.46 1971.52,606.455 1971.53,606.451 1971.54,606.446 1971.55,606.442 1971.56,606.437 1971.57,606.433 1971.57,606.428 1971.58,606.424 1971.59,606.419 1971.6,606.414 1971.61,606.41 1971.62,606.405 1971.63,606.4 1971.64,606.396 1971.65,606.391 1971.66,606.386 1971.67,606.382 1971.68,606.377 1971.69,606.372 1971.69,606.367 1971.7,606.362 1971.71,606.357 1971.72,606.352 1971.73,606.348 1971.74,606.343 1971.75,606.338 1971.76,606.333 1971.77,606.328 1971.78,606.323 1971.79,606.318 1971.8,606.312 1971.8,606.307 1971.81,606.302 1971.82,606.297 1971.83,606.292 1971.84,606.287 1971.85,606.282 1971.86,606.276 1971.87,606.271 1971.88,606.266 1971.89,606.261 1971.9,606.255 1971.91,606.25 1971.91,606.245 1971.92,606.239 1971.93,606.234 1971.94,606.228 1971.95,606.223 1971.96,606.217 1971.97,606.212 1971.98,606.206 1971.99,606.201 1972,606.195 1972.01,606.19 1972.02,606.184 1972.03,606.179 1972.03,606.173 1972.04,606.167 1972.05,606.162 1972.06,606.156 1972.07,606.15 1972.08,606.145 1972.09,606.139 1972.1,606.133 1972.11,606.127 1972.12,606.121 1972.13,606.115 1972.14,606.11 1972.14,606.104 1972.15,606.098 1972.16,606.092 1972.17,606.086 1972.18,606.08 1972.19,606.074 1972.2,606.068 1972.21,606.062 1972.22,606.056 1972.23,606.05 1972.24,606.044 1972.25,606.038 1972.25,606.031 1972.26,606.025 1972.27,606.019 1972.28,606.013 1972.29,606.007 1972.3,606 1972.31,605.994 1972.32,605.988 1972.33,605.981 1972.34,605.975 1972.35,605.969 1972.36,605.962 1972.37,605.956 1972.37,605.95 1972.38,605.943 1972.39,605.937 1972.4,605.93 1972.41,605.924 1972.42,605.917 1972.43,605.911 1972.44,605.904 1972.45,605.897 1972.46,605.891 1972.47,605.884 1972.48,605.878 1972.48,605.871 1972.49,605.864 1972.5,605.858 1972.51,605.851 1972.52,605.844 1972.53,605.837 1972.54,605.831 1972.55,605.824 1972.56,605.817 1972.57,605.81 1972.58,605.803 1972.59,605.796 1972.59,605.789 1972.6,605.782 1972.61,605.775 1972.62,605.768 1972.63,605.761 1972.64,605.754 1972.65,605.747 1972.66,605.74 1972.67,605.733 1972.68,605.726 1972.69,605.719 1972.7,605.712 1972.71,605.705 1972.71,605.698 1972.72,605.69 1972.73,605.683 1972.74,605.676 1972.75,605.669 1972.76,605.661 1972.77,605.654 1972.78,605.647 1972.79,605.639 1972.8,605.632 1972.81,605.625 1972.82,605.617 1972.82,605.61 1972.83,605.602 1972.84,605.595 1972.85,605.587 1972.86,605.58 1972.87,605.572 1972.88,605.565 1972.89,605.557 1972.9,605.55 1972.91,605.542 1972.92,605.534 1972.93,605.527 1972.93,605.519 1972.94,605.511 1972.95,605.504 1972.96,605.496 1972.97,605.488 1972.98,605.48 1972.99,605.473 1973,605.465 1973.01,605.457 1973.02,605.449 1973.03,605.441 1973.04,605.433 1973.05,605.425 1973.05,605.418 1973.06,605.41 1973.07,605.402 1973.08,605.394 1973.09,605.386 1973.1,605.378 1973.11,605.37 1973.12,605.361 1973.13,605.353 1973.14,605.345 1973.15,605.337 1973.16,605.329 1973.16,605.321 1973.17,605.313 1973.18,605.304 1973.19,605.296 1973.2,605.288 1973.21,605.28 1973.22,605.271 1973.23,605.263 1973.24,605.255 1973.25,605.246 1973.26,605.238 1973.27,605.23 1973.27,605.221 1973.28,605.213 1973.29,605.204 1973.3,605.196 1973.31,605.187 1973.32,605.179 1973.33,605.17 1973.34,605.162 1973.35,605.153 1973.36,605.145 1973.37,605.136 1973.38,605.127 1973.39,605.119 1973.39,605.11 1973.4,605.101 1973.41,605.093 1973.42,605.084 1973.43,605.075 1973.44,605.067 1973.45,605.058 1973.46,605.049 1973.47,605.04 1973.48,605.031 1973.49,605.022 1973.5,605.014 1973.5,605.005 1973.51,604.996 1973.52,604.987 1973.53,604.978 1973.54,604.969 1973.55,604.96 1973.56,604.951 1973.57,604.942 1973.58,604.933 1973.59,604.924 1973.6,604.915 1973.61,604.906 1973.61,604.896 1973.62,604.887 1973.63,604.878 1973.64,604.869 1973.65,604.86 1973.66,604.851 1973.67,604.841 1973.68,604.832 1973.69,604.823 1973.7,604.813 1973.71,604.804 1973.72,604.795 1973.73,604.785 1973.73,604.776 1973.74,604.767 1973.75,604.757 1973.76,604.748 1973.77,604.738 1973.78,604.729 1973.79,604.719 1973.8,604.71 1973.81,604.7 1973.82,604.691 1973.83,604.681 1973.84,604.672 1973.84,604.662 1973.85,604.652 1973.86,604.643 1973.87,604.633 1973.88,604.623 1973.89,604.614 1973.9,604.604 1973.91,604.594 1973.92,604.585 1973.93,604.575 1973.94,604.565 1973.95,604.555 1973.95,604.545 1973.96,604.536 1973.97,604.526 1973.98,604.516 1973.99,604.506 1974,604.496 1974.01,604.486 1974.02,604.476 1974.03,604.466 1974.04,604.456 1974.05,604.446 1974.06,604.436 1974.07,604.426 1974.07,604.416 1974.08,604.406 1974.09,604.396 1974.1,604.386 1974.11,604.375 1974.12,604.365 1974.13,604.355 1974.14,604.345 1974.15,604.335 1974.16,604.324 1974.17,604.314 1974.18,604.304 1974.18,604.294 1974.19,604.283 1974.2,604.273 1974.21,604.263 1974.22,604.252 1974.23,604.242 1974.24,604.231 1974.25,604.221 1974.26,604.21 1974.27,604.2 1974.28,604.19 1974.29,604.179 1974.29,604.169 1974.3,604.158 1974.31,604.147 1974.32,604.137 1974.33,604.126 1974.34,604.116 1974.35,604.105 1974.36,604.094 1974.37,604.084 1974.38,604.073 1974.39,604.062 1974.4,604.052 1974.41,604.041 1974.41,604.03 1974.42,604.019 1974.43,604.009 1974.44,603.998 1974.45,603.987 1974.46,603.976 1974.47,603.965 1974.48,603.954 1974.49,603.943 1974.5,603.933 1974.51,603.922 1974.52,603.911 1974.52,603.9 1974.53,603.889 1974.54,603.878 1974.55,603.867 1974.56,603.856 1974.57,603.845 1974.58,603.833 1974.59,603.822 1974.6,603.811 1974.61,603.8 1974.62,603.789 1974.63,603.778 1974.64,603.767 1974.64,603.755 1974.65,603.744 1974.66,603.733 1974.67,603.722 1974.68,603.71 1974.69,603.699 1974.7,603.688 1974.71,603.676 1974.72,603.665 1974.73,603.654 1974.74,603.642 1974.75,603.631 1974.75,603.619 1974.76,603.608 1974.77,603.597 1974.78,603.585 1974.79,603.574 1974.8,603.562 1974.81,603.551 1974.82,603.539 1974.83,603.527 1974.84,603.516 1974.85,603.504 1974.86,603.493 1974.86,603.481 1974.87,603.469 1974.88,603.458 1974.89,603.446 1974.9,603.434 1974.91,603.423 1974.92,603.411 1974.93,603.399 1974.94,603.387 1974.95,603.375 1974.96,603.364 1974.97,603.352 1974.98,603.34 1974.98,603.328 1974.99,603.316 1975,603.304 1975.01,603.292 1975.02,603.28 1975.03,603.269 1975.04,603.257 1975.05,603.245 1975.06,603.233 1975.07,603.221 1975.08,603.209 1975.09,603.196 1975.09,603.184 1975.1,603.172 1975.11,603.16 1975.12,603.148 1975.13,603.136 1975.14,603.124 1975.15,603.112 1975.16,603.099 1975.17,603.087 1975.18,603.075 1975.19,603.063 1975.2,603.05 1975.2,603.038 1975.21,603.026 1975.22,603.014 1975.23,603.001 1975.24,602.989 1975.25,602.976 1975.26,602.964 1975.27,602.952 1975.28,602.939 1975.29,602.927 1975.3,602.914 1975.31,602.902 1975.32,602.889 1975.32,602.877 1975.33,602.864 1975.34,602.852 1975.35,602.839 1975.36,602.827 1975.37,602.814 1975.38,602.802 1975.39,602.789 1975.4,602.776 1975.41,602.764 1975.42,602.751 1975.43,602.738 1975.43,602.726 1975.44,602.713 1975.45,602.7 1975.46,602.687 1975.47,602.674 1975.48,602.662 1975.49,602.649 1975.5,602.636 1975.51,602.623 1975.52,602.61 1975.53,602.597 1975.54,602.585 1975.54,602.572 1975.55,602.559 1975.56,602.546 1975.57,602.533 1975.58,602.52 1975.59,602.507 1975.6,602.494 1975.61,602.481 1975.62,602.468 1975.63,602.455 1975.64,602.442 1975.65,602.428 1975.66,602.415 1975.66,602.402 1975.67,602.389 1975.68,602.376 1975.69,602.363 1975.7,602.35 1975.71,602.336 1975.72,602.323 1975.73,602.31 1975.74,602.297 1975.75,602.283 1975.76,602.27 1975.77,602.257 1975.77,602.243 1975.78,602.23 1975.79,602.217 1975.8,602.203 1975.81,602.19 1975.82,602.176 1975.83,602.163 1975.84,602.15 1975.85,602.136 1975.86,602.123 1975.87,602.109 1975.88,602.096 1975.88,602.082 1975.89,602.069 1975.9,602.055 1975.91,602.041 1975.92,602.028 1975.93,602.014 1975.94,602.001 1975.95,601.987 1975.96,601.973 1975.97,601.96 1975.98,601.946 1975.99,601.932 1976,601.918 1976,601.905 1976.01,601.891 1976.02,601.877 1976.03,601.863 1976.04,601.85 1976.05,601.836 1976.06,601.822 1976.07,601.808 1976.08,601.794 1976.09,601.78 1976.1,601.766 1976.11,601.752 1976.11,601.738 1976.12,601.724 1976.13,601.711 1976.14,601.697 1976.15,601.683 1976.16,601.668 1976.17,601.654 1976.18,601.64 1976.19,601.626 1976.2,601.612 1976.21,601.598 1976.22,601.584 1976.22,601.57 1976.23,601.556 1976.24,601.542 1976.25,601.527 1976.26,601.513 1976.27,601.499 1976.28,601.485 1976.29,601.47 1976.3,601.456 1976.31,601.442 1976.32,601.428 1976.33,601.413 1976.34,601.399 1976.34,601.385 1976.35,601.37 1976.36,601.356 1976.37,601.342 1976.38,601.327 1976.39,601.313 1976.4,601.298 1976.41,601.284 1976.42,601.269 1976.43,601.255 1976.44,601.24 1976.45,601.226 1976.45,601.211 1976.46,601.197 1976.47,601.182 1976.48,601.168 1976.49,601.153 1976.5,601.138 1976.51,601.124 1976.52,601.109 1976.53,601.094 1976.54,601.08 1976.55,601.065 1976.56,601.05 1976.56,601.036 1976.57,601.021 1976.58,601.006 1976.59,600.991 1976.6,600.977 1976.61,600.962 1976.62,600.947 1976.63,600.932 1976.64,600.917 1976.65,600.902 1976.66,600.888 1976.67,600.873 1976.68,600.858 1976.68,600.843 1976.69,600.828 1976.7,600.813 1976.71,600.798 1976.72,600.783 1976.73,600.768 1976.74,600.753 1976.75,600.738 1976.76,600.723 1976.77,600.708 1976.78,600.693 1976.79,600.678 1976.79,600.662 1976.8,600.647 1976.81,600.632 1976.82,600.617 1976.83,600.602 1976.84,600.587 1976.85,600.571 1976.86,600.556 1976.87,600.541 1976.88,600.526 1976.89,600.51 1976.9,600.495 1976.9,600.48 1976.91,600.465 1976.92,600.449 1976.93,600.434 1976.94,600.418 1976.95,600.403 1976.96,600.388 1976.97,600.372 1976.98,600.357 1976.99,600.341 1977,600.326 1977.01,600.311 1977.02,600.295 1977.02,600.28 1977.03,600.264 1977.04,600.249 1977.05,600.233 1977.06,600.217 1977.07,600.202 1977.08,600.186 1977.09,600.171 1977.1,600.155 1977.11,600.139 1977.12,600.124 1977.13,600.108 1977.13,600.092 1977.14,600.077 1977.15,600.061 1977.16,600.045 1977.17,600.029 1977.18,600.014 1977.19,599.998 1977.2,599.982 1977.21,599.966 1977.22,599.951 1977.23,599.935 1977.24,599.919 1977.24,599.903 1977.25,599.887 1977.26,599.871 1977.27,599.855 1977.28,599.839 1977.29,599.823 1977.3,599.807 1977.31,599.792 1977.32,599.776 1977.33,599.76 1977.34,599.744 1977.35,599.727 1977.36,599.711 1977.36,599.695 1977.37,599.679 1977.38,599.663 1977.39,599.647 1977.4,599.631 1977.41,599.615 1977.42,599.599 1977.43,599.583 1977.44,599.566 1977.45,599.55 1977.46,599.534 1977.47,599.518 1977.47,599.502 1977.48,599.485 1977.49,599.469 1977.5,599.453 1977.51,599.436 1977.52,599.42 1977.53,599.404 1977.54,599.387 1977.55,599.371 1977.56,599.355 1977.57,599.338 1977.58,599.322 1977.58,599.306 1977.59,599.289 1977.6,599.273 1977.61,599.256 1977.62,599.24 1977.63,599.223 1977.64,599.207 1977.65,599.19 1977.66,599.174 1977.67,599.157 1977.68,599.141 1977.69,599.124 1977.7,599.107 1977.7,599.091 1977.71,599.074 1977.72,599.058 1977.73,599.041 1977.74,599.024 1977.75,599.008 1977.76,598.991 1977.77,598.974 1977.78,598.957 1977.79,598.941 1977.8,598.924 1977.81,598.907 1977.81,598.89 1977.82,598.874 1977.83,598.857 1977.84,598.84 1977.85,598.823 1977.86,598.806 1977.87,598.789 1977.88,598.773 1977.89,598.756 1977.9,598.739 1977.91,598.722 1977.92,598.705 1977.92,598.688 1977.93,598.671 1977.94,598.654 1977.95,598.637 1977.96,598.62 1977.97,598.603 1977.98,598.586 1977.99,598.569 1978,598.552 1978.01,598.535 1978.02,598.518 1978.03,598.501 1978.04,598.483 1978.04,598.466 1978.05,598.449 1978.06,598.432 1978.07,598.415 1978.08,598.398 1978.09,598.38 1978.1,598.363 1978.11,598.346 1978.12,598.329 1978.13,598.311 1978.14,598.294 1978.15,598.277 1978.15,598.26 1978.16,598.242 1978.17,598.225 1978.18,598.208 1978.19,598.19 1978.2,598.173 1978.21,598.155 1978.22,598.138 1978.23,598.121 1978.24,598.103 1978.25,598.086 1978.26,598.068 1978.26,598.051 1978.27,598.033 1978.28,598.016 1978.29,597.998 1978.3,597.981 1978.31,597.963 1978.32,597.946 1978.33,597.928 1978.34,597.91 1978.35,597.893 1978.36,597.875 1978.37,597.858 1978.38,597.84 1978.38,597.822 1978.39,597.805 1978.4,597.787 1978.41,597.769 1978.42,597.752 1978.43,597.734 1978.44,597.716 1978.45,597.698 1978.46,597.681 1978.47,597.663 1978.48,597.645 1978.49,597.627 1978.49,597.609 1978.5,597.591 1978.51,597.574 1978.52,597.556 1978.53,597.538 1978.54,597.52 1978.55,597.502 1978.56,597.484 1978.57,597.466 1978.58,597.448 1978.59,597.43 1978.6,597.412 1978.6,597.394 1978.61,597.376 1978.62,597.358 1978.63,597.34 1978.64,597.322 1978.65,597.304 1978.66,597.286 1978.67,597.268 1978.68,597.25 1978.69,597.232 1978.7,597.214 1978.71,597.196 1978.72,597.177 1978.72,597.159 1978.73,597.141 1978.74,597.123 1978.75,597.105 1978.76,597.086 1978.77,597.068 1978.78,597.05 1978.79,597.032 1978.8,597.013 1978.81,596.995 1978.82,596.977 1978.83,596.959 1978.83,596.94 1978.84,596.922 1978.85,596.903 1978.86,596.885 1978.87,596.867 1978.88,596.848 1978.89,596.83 1978.9,596.812 1978.91,596.793 1978.92,596.775 1978.93,596.756 1978.94,596.738 1978.94,596.719 1978.95,596.701 1978.96,596.682 1978.97,596.664 1978.98,596.645 1978.99,596.627 1979,596.608 1979.01,596.589 1979.02,596.571 1979.03,596.552 1979.04,596.534 1979.05,596.515 1979.06,596.496 1979.06,596.478 1979.07,596.459 1979.08,596.44 1979.09,596.422 1979.1,596.403 1979.11,596.384 1979.12,596.365 1979.13,596.347 1979.14,596.328 1979.15,596.309 1979.16,596.29 1979.17,596.271 1979.17,596.253 1979.18,596.234 1979.19,596.215 1979.2,596.196 1979.21,596.177 1979.22,596.158 1979.23,596.139 1979.24,596.12 1979.25,596.102 1979.26,596.083 1979.27,596.064 1979.28,596.045 1979.28,596.026 1979.29,596.007 1979.3,595.988 1979.31,595.969 1979.32,595.95 1979.33,595.931 1979.34,595.912 1979.35,595.892 1979.36,595.873 1979.37,595.854 1979.38,595.835 1979.39,595.816 1979.4,595.797 1979.4,595.778 1979.41,595.759 1979.42,595.739 1979.43,595.72 1979.44,595.701 1979.45,595.682 1979.46,595.663 1979.47,595.643 1979.48,595.624 1979.49,595.605 1979.5,595.586 1979.51,595.566 1979.51,595.547 1979.52,595.528 1979.53,595.508 1979.54,595.489 1979.55,595.47 1979.56,595.45 1979.57,595.431 1979.58,595.411 1979.59,595.392 1979.6,595.373 1979.61,595.353 1979.62,595.334 1979.62,595.314 1979.63,595.295 1979.64,595.275 1979.65,595.256 1979.66,595.236 1979.67,595.217 1979.68,595.197 1979.69,595.178 1979.7,595.158 1979.71,595.139 1979.72,595.119 1979.73,595.099 1979.74,595.08 1979.74,595.06 1979.75,595.041 1979.76,595.021 1979.77,595.001 1979.78,594.982 1979.79,594.962 1979.8,594.942 1979.81,594.922 1979.82,594.903 1979.83,594.883 1979.84,594.863 1979.85,594.844 1979.85,594.824 1979.86,594.804 1979.87,594.784 1979.88,594.764 1979.89,594.745 1979.9,594.725 1979.91,594.705 1979.92,594.685 1979.93,594.665 1979.94,594.645 1979.95,594.625 1979.96,594.605 1979.96,594.585 1979.97,594.566 1979.98,594.546 1979.99,594.526 1980,594.506 1980.01,594.486 1980.02,594.466 1980.03,594.446 1980.04,594.426 1980.05,594.406 1980.06,594.386 1980.07,594.365 1980.08,594.345 1980.08,594.325 1980.09,594.305 1980.1,594.285 1980.11,594.265 1980.12,594.245 1980.13,594.225 1980.14,594.205 1980.15,594.184 1980.16,594.164 1980.17,594.144 1980.18,594.124 1980.19,594.104 1980.19,594.083 1980.2,594.063 1980.21,594.043 1980.22,594.023 1980.23,594.002 1980.24,593.982 1980.25,593.962 1980.26,593.941 1980.27,593.921 1980.28,593.901 1980.29,593.88 1980.3,593.86 1980.3,593.84 1980.31,593.819 1980.32,593.799 1980.33,593.778 1980.34,593.758 1980.35,593.737 1980.36,593.717 1980.37,593.697 1980.38,593.676 1980.39,593.656 1980.4,593.635 1980.41,593.615 1980.42,593.594 1980.42,593.573 1980.43,593.553 1980.44,593.532 1980.45,593.512 1980.46,593.491 1980.47,593.471 1980.48,593.45 1980.49,593.429 1980.5,593.409 1980.51,593.388 1980.52,593.367 1980.53,593.347 1980.53,593.326 1980.54,593.305 1980.55,593.285 1980.56,593.264 1980.57,593.243 1980.58,593.222 1980.59,593.202 1980.6,593.181 1980.61,593.16 1980.62,593.139 1980.63,593.119 1980.64,593.098 1980.64,593.077 1980.65,593.056 1980.66,593.035 1980.67,593.014 1980.68,592.993 1980.69,592.973 1980.7,592.952 1980.71,592.931 1980.72,592.91 1980.73,592.889 1980.74,592.868 1980.75,592.847 1980.76,592.826 1980.76,592.805 1980.77,592.784 1980.78,592.763 1980.79,592.742 1980.8,592.721 1980.81,592.7 1980.82,592.679 1980.83,592.658 1980.84,592.637 1980.85,592.616 1980.86,592.595 1980.87,592.574 1980.87,592.552 1980.88,592.531 1980.89,592.51 1980.9,592.489 1980.91,592.468 1980.92,592.447 1980.93,592.425 1980.94,592.404 1980.95,592.383 1980.96,592.362 1980.97,592.341 1980.98,592.319 1980.98,592.298 1980.99,592.277 1981,592.255 1981.01,592.234 1981.02,592.213 1981.03,592.192 1981.04,592.17 1981.05,592.149 1981.06,592.128 1981.07,592.106 1981.08,592.085 1981.09,592.063 1981.1,592.042 1981.1,592.021 1981.11,591.999 1981.12,591.978 1981.13,591.956 1981.14,591.935 1981.15,591.913 1981.16,591.892 1981.17,591.87 1981.18,591.849 1981.19,591.827 1981.2,591.806 1981.21,591.784 1981.21,591.763 1981.22,591.741 1981.23,591.72 1981.24,591.698 1981.25,591.676 1981.26,591.655 1981.27,591.633 1981.28,591.612 1981.29,591.59 1981.3,591.568 1981.31,591.547 1981.32,591.525 1981.32,591.503 1981.33,591.482 1981.34,591.46 1981.35,591.438 1981.36,591.416 1981.37,591.395 1981.38,591.373 1981.39,591.351 1981.4,591.329 1981.41,591.308 1981.42,591.286 1981.43,591.264 1981.44,591.242 1981.44,591.22 1981.45,591.198 1981.46,591.177 1981.47,591.155 1981.48,591.133 1981.49,591.111 1981.5,591.089 1981.51,591.067 1981.52,591.045 1981.53,591.023 1981.54,591.001 1981.55,590.979 1981.55,590.957 1981.56,590.935 1981.57,590.913 1981.58,590.891 1981.59,590.869 1981.6,590.847 1981.61,590.825 1981.62,590.803 1981.63,590.781 1981.64,590.759 1981.65,590.737 1981.66,590.715 1981.66,590.693 1981.67,590.671 1981.68,590.649 1981.69,590.627 1981.7,590.604 1981.71,590.582 1981.72,590.56 1981.73,590.538 1981.74,590.516 1981.75,590.493 1981.76,590.471 1981.77,590.449 1981.78,590.427 1981.78,590.405 1981.79,590.382 1981.8,590.36 1981.81,590.338 1981.82,590.315 1981.83,590.293 1981.84,590.271 1981.85,590.249 1981.86,590.226 1981.87,590.204 1981.88,590.182 1981.89,590.159 1981.89,590.137 1981.9,590.114 1981.91,590.092 1981.92,590.07 1981.93,590.047 1981.94,590.025 1981.95,590.002 1981.96,589.98 1981.97,589.957 1981.98,589.935 1981.99,589.912 1982,589.89 1982,589.867 1982.01,589.845 1982.02,589.822 1982.03,589.8 1982.04,589.777 1982.05,589.755 1982.06,589.732 1982.07,589.71 1982.08,589.687 1982.09,589.664 1982.1,589.642 1982.11,589.619 1982.12,589.596 1982.12,589.574 1982.13,589.551 1982.14,589.529 1982.15,589.506 1982.16,589.483 1982.17,589.46 1982.18,589.438 1982.19,589.415 1982.2,589.392 1982.21,589.37 1982.22,589.347 1982.23,589.324 1982.23,589.301 1982.24,589.278 1982.25,589.256 1982.26,589.233 1982.27,589.21 1982.28,589.187 1982.29,589.164 1982.3,589.142 1982.31,589.119 1982.32,589.096 1982.33,589.073 1982.34,589.05 1982.34,589.027 1982.35,589.004 1982.36,588.981 1982.37,588.958 1982.38,588.935 1982.39,588.912 1982.4,588.889 1982.41,588.867 1982.42,588.844 1982.43,588.821 1982.44,588.798 1982.45,588.774 1982.46,588.751 1982.46,588.728 1982.47,588.705 1982.48,588.682 1982.49,588.659 1982.5,588.636 1982.51,588.613 1982.52,588.59 1982.53,588.567 1982.54,588.544 1982.55,588.521 1982.56,588.497 1982.57,588.474 1982.57,588.451 1982.58,588.428 1982.59,588.405 1982.6,588.382 1982.61,588.358 1982.62,588.335 1982.63,588.312 1982.64,588.289 1982.65,588.265 1982.66,588.242 1982.67,588.219 1982.68,588.196 1982.68,588.172 1982.69,588.149 1982.7,588.126 1982.71,588.102 1982.72,588.079 1982.73,588.056 1982.74,588.032 1982.75,588.009 1982.76,587.986 1982.77,587.962 1982.78,587.939 1982.79,587.916 1982.8,587.892 1982.8,587.869 1982.81,587.845 1982.82,587.822 1982.83,587.798 1982.84,587.775 1982.85,587.751 1982.86,587.728 1982.87,587.704 1982.88,587.681 1982.89,587.657 1982.9,587.634 1982.91,587.61 1982.91,587.587 1982.92,587.563 1982.93,587.54 1982.94,587.516 1982.95,587.493 1982.96,587.469 1982.97,587.445 1982.98,587.422 1982.99,587.398 1983,587.374 1983.01,587.351 1983.02,587.327 1983.02,587.304 1983.03,587.28 1983.04,587.256 1983.05,587.232 1983.06,587.209 1983.07,587.185 1983.08,587.161 1983.09,587.138 1983.1,587.114 1983.11,587.09 1983.12,587.066 1983.13,587.043 1983.14,587.019 1983.14,586.995 1983.15,586.971 1983.16,586.947 1983.17,586.924 1983.18,586.9 1983.19,586.876 1983.2,586.852 1983.21,586.828 1983.22,586.804 1983.23,586.78 1983.24,586.756 1983.25,586.733 1983.25,586.709 1983.26,586.685 1983.27,586.661 1983.28,586.637 1983.29,586.613 1983.3,586.589 1983.31,586.565 1983.32,586.541 1983.33,586.517 1983.34,586.493 1983.35,586.469 1983.36,586.445 1983.36,586.421 1983.37,586.397 1983.38,586.373 1983.39,586.349 1983.4,586.325 1983.41,586.301 1983.42,586.277 1983.43,586.252 1983.44,586.228 1983.45,586.204 1983.46,586.18 1983.47,586.156 1983.48,586.132 1983.48,586.108 1983.49,586.083 1983.5,586.059 1983.51,586.035 1983.52,586.011 1983.53,585.987 1983.54,585.962 1983.55,585.938 1983.56,585.914 1983.57,585.89 1983.58,585.865 1983.59,585.841 1983.59,585.817 1983.6,585.793 1983.61,585.768 1983.62,585.744 1983.63,585.72 1983.64,585.695 1983.65,585.671 1983.66,585.647 1983.67,585.622 1983.68,585.598 1983.69,585.574 1983.7,585.549 1983.7,585.525 1983.71,585.5 1983.72,585.476 1983.73,585.452 1983.74,585.427 1983.75,585.403 1983.76,585.378 1983.77,585.354 1983.78,585.329 1983.79,585.305 1983.8,585.28 1983.81,585.256 1983.82,585.231 1983.82,585.207 1983.83,585.182 1983.84,585.158 1983.85,585.133 1983.86,585.109 1983.87,585.084 1983.88,585.06 1983.89,585.035 1983.9,585.01 1983.91,584.986 1983.92,584.961 1983.93,584.937 1983.93,584.912 1983.94,584.887 1983.95,584.863 1983.96,584.838 1983.97,584.813 1983.98,584.789 1983.99,584.764 1984,584.739 1984.01,584.715 1984.02,584.69 1984.03,584.665 1984.04,584.64 1984.04,584.616 1984.05,584.591 1984.06,584.566 1984.07,584.541 1984.08,584.517 1984.09,584.492 1984.1,584.467 1984.11,584.442 1984.12,584.417 1984.13,584.393 1984.14,584.368 1984.15,584.343 1984.16,584.318 1984.16,584.293 1984.17,584.268 1984.18,584.244 1984.19,584.219 1984.2,584.194 1984.21,584.169 1984.22,584.144 1984.23,584.119 1984.24,584.094 1984.25,584.069 1984.26,584.044 1984.27,584.019 1984.27,583.994 1984.28,583.969 1984.29,583.944 1984.3,583.919 1984.31,583.894 1984.32,583.869 1984.33,583.844 1984.34,583.819 1984.35,583.794 1984.36,583.769 1984.37,583.744 1984.38,583.719 1984.38,583.694 1984.39,583.669 1984.4,583.644 1984.41,583.619 1984.42,583.593 1984.43,583.568 1984.44,583.543 1984.45,583.518 1984.46,583.493 1984.47,583.468 1984.48,583.442 1984.49,583.417 1984.5,583.392 1984.5,583.367 1984.51,583.342 1984.52,583.316 1984.53,583.291 1984.54,583.266 1984.55,583.241 1984.56,583.216 1984.57,583.19 1984.58,583.165 1984.59,583.14 1984.6,583.114 1984.61,583.089 1984.61,583.064 1984.62,583.038 1984.63,583.013 1984.64,582.988 1984.65,582.962 1984.66,582.937 1984.67,582.912 1984.68,582.886 1984.69,582.861 1984.7,582.836 1984.71,582.81 1984.72,582.785 1984.72,582.759 1984.73,582.734 1984.74,582.709 1984.75,582.683 1984.76,582.658 1984.77,582.632 1984.78,582.607 1984.79,582.581 1984.8,582.556 1984.81,582.53 1984.82,582.505 1984.83,582.479 1984.84,582.454 1984.84,582.428 1984.85,582.403 1984.86,582.377 1984.87,582.352 1984.88,582.326 1984.89,582.3 1984.9,582.275 1984.91,582.249 1984.92,582.224 1984.93,582.198 1984.94,582.172 1984.95,582.147 1984.95,582.121 1984.96,582.096 1984.97,582.07 1984.98,582.044 1984.99,582.019 1985,581.993 1985.01,581.967 1985.02,581.941 1985.03,581.916 1985.04,581.89 1985.05,581.864 1985.06,581.839 1985.06,581.813 1985.07,581.787 1985.08,581.761 1985.09,581.736 1985.1,581.71 1985.11,581.684 1985.12,581.658 1985.13,581.632 1985.14,581.607 1985.15,581.581 1985.16,581.555 1985.17,581.529 1985.18,581.503 1985.18,581.477 1985.19,581.452 1985.2,581.426 1985.21,581.4 1985.22,581.374 1985.23,581.348 1985.24,581.322 1985.25,581.296 1985.26,581.27 1985.27,581.244 1985.28,581.218 1985.29,581.192 1985.29,581.167 1985.3,581.141 1985.31,581.115 1985.32,581.089 1985.33,581.063 1985.34,581.037 1985.35,581.011 1985.36,580.985 1985.37,580.959 1985.38,580.933 1985.39,580.907 1985.4,580.88 1985.4,580.854 1985.41,580.828 1985.42,580.802 1985.43,580.776 1985.44,580.75 1985.45,580.724 1985.46,580.698 1985.47,580.672 1985.48,580.646 1985.49,580.619 1985.5,580.593 1985.51,580.567 1985.52,580.541 1985.52,580.515 1985.53,580.489 1985.54,580.463 1985.55,580.436 1985.56,580.41 1985.57,580.384 1985.58,580.358 1985.59,580.331 1985.6,580.305 1985.61,580.279 1985.62,580.253 1985.63,580.226 1985.63,580.2 1985.64,580.174 1985.65,580.148 1985.66,580.121 1985.67,580.095 1985.68,580.069 1985.69,580.042 1985.7,580.016 1985.71,579.99 1985.72,579.963 1985.73,579.937 1985.74,579.911 1985.74,579.884 1985.75,579.858 1985.76,579.832 1985.77,579.805 1985.78,579.779 1985.79,579.752 1985.8,579.726 1985.81,579.7 1985.82,579.673 1985.83,579.647 1985.84,579.62 1985.85,579.594 1985.86,579.567 1985.86,579.541 1985.87,579.514 1985.88,579.488 1985.89,579.461 1985.9,579.435 1985.91,579.408 1985.92,579.382 1985.93,579.355 1985.94,579.329 1985.95,579.302 1985.96,579.276 1985.97,579.249 1985.97,579.223 1985.98,579.196 1985.99,579.169 1986,579.143 1986.01,579.116 1986.02,579.09 1986.03,579.063 1986.04,579.036 1986.05,579.01 1986.06,578.983 1986.07,578.956 1986.08,578.93 1986.08,578.903 1986.09,578.876 1986.1,578.85 1986.11,578.823 1986.12,578.796 1986.13,578.77 1986.14,578.743 1986.15,578.716 1986.16,578.689 1986.17,578.663 1986.18,578.636 1986.19,578.609 1986.2,578.582 1986.2,578.556 1986.21,578.529 1986.22,578.502 1986.23,578.475 1986.24,578.448 1986.25,578.422 1986.26,578.395 1986.27,578.368 1986.28,578.341 1986.29,578.314 1986.3,578.288 1986.31,578.261 1986.31,578.234 1986.32,578.207 1986.33,578.18 1986.34,578.153 1986.35,578.126 1986.36,578.099 1986.37,578.072 1986.38,578.045 1986.39,578.019 1986.4,577.992 1986.41,577.965 1986.42,577.938 1986.42,577.911 1986.43,577.884 1986.44,577.857 1986.45,577.83 1986.46,577.803 1986.47,577.776 1986.48,577.749 1986.49,577.722 1986.5,577.695 1986.51,577.668 1986.52,577.641 1986.53,577.614 1986.54,577.587 1986.54,577.56 1986.55,577.532 1986.56,577.505 1986.57,577.478 1986.58,577.451 1986.59,577.424 1986.6,577.397 1986.61,577.37 1986.62,577.343 1986.63,577.316 1986.64,577.289 1986.65,577.261 1986.65,577.234 1986.66,577.207 1986.67,577.18 1986.68,577.153 1986.69,577.126 1986.7,577.098 1986.71,577.071 1986.72,577.044 1986.73,577.017 1986.74,576.989 1986.75,576.962 1986.76,576.935 1986.76,576.908 1986.77,576.88 1986.78,576.853 1986.79,576.826 1986.8,576.799 1986.81,576.771 1986.82,576.744 1986.83,576.717 1986.84,576.689 1986.85,576.662 1986.86,576.635 1986.87,576.608 1986.88,576.58 1986.88,576.553 1986.89,576.525 1986.9,576.498 1986.91,576.471 1986.92,576.443 1986.93,576.416 1986.94,576.389 1986.95,576.361 1986.96,576.334 1986.97,576.306 1986.98,576.279 1986.99,576.252 1986.99,576.224 1987,576.197 1987.01,576.169 1987.02,576.142 1987.03,576.114 1987.04,576.087 1987.05,576.059 1987.06,576.032 1987.07,576.004 1987.08,575.977 1987.09,575.949 1987.1,575.922 1987.1,575.894 1987.11,575.867 1987.12,575.839 1987.13,575.812 1987.14,575.784 1987.15,575.757 1987.16,575.729 1987.17,575.701 1987.18,575.674 1987.19,575.646 1987.2,575.619 1987.21,575.591 1987.22,575.563 1987.22,575.536 1987.23,575.508 1987.24,575.48 1987.25,575.453 1987.26,575.425 1987.27,575.398 1987.28,575.37 1987.29,575.342 1987.3,575.315 1987.31,575.287 1987.32,575.259 1987.33,575.231 1987.33,575.204 1987.34,575.176 1987.35,575.148 1987.36,575.121 1987.37,575.093 1987.38,575.065 1987.39,575.037 1987.4,575.01 1987.41,574.982 1987.42,574.954 1987.43,574.926 1987.44,574.898 1987.44,574.871 1987.45,574.843 1987.46,574.815 1987.47,574.787 1987.48,574.759 1987.49,574.732 1987.5,574.704 1987.51,574.676 1987.52,574.648 1987.53,574.62 1987.54,574.592 1987.55,574.564 1987.56,574.536 1987.56,574.509 1987.57,574.481 1987.58,574.453 1987.59,574.425 1987.6,574.397 1987.61,574.369 1987.62,574.341 1987.63,574.313 1987.64,574.285 1987.65,574.257 1987.66,574.229 1987.67,574.201 1987.67,574.173 1987.68,574.145 1987.69,574.117 1987.7,574.089 1987.71,574.061 1987.72,574.033 1987.73,574.005 1987.74,573.977 1987.75,573.949 1987.76,573.921 1987.77,573.893 1987.78,573.865 1987.78,573.837 1987.79,573.809 1987.8,573.781 1987.81,573.753 1987.82,573.725 1987.83,573.697 1987.84,573.669 1987.85,573.64 1987.86,573.612 1987.87,573.584 1987.88,573.556 1987.89,573.528 1987.9,573.5 1987.9,573.472 1987.91,573.443 1987.92,573.415 1987.93,573.387 1987.94,573.359 1987.95,573.331 1987.96,573.302 1987.97,573.274 1987.98,573.246 1987.99,573.218 1988,573.19 1988.01,573.161 1988.01,573.133 1988.02,573.105 1988.03,573.077 1988.04,573.048 1988.05,573.02 1988.06,572.992 1988.07,572.964 1988.08,572.935 1988.09,572.907 1988.1,572.879 1988.11,572.85 1988.12,572.822 1988.12,572.794 1988.13,572.765 1988.14,572.737 1988.15,572.709 1988.16,572.68 1988.17,572.652 1988.18,572.624 1988.19,572.595 1988.2,572.567 1988.21,572.539 1988.22,572.51 1988.23,572.482 1988.24,572.453 1988.24,572.425 1988.25,572.397 1988.26,572.368 1988.27,572.34 1988.28,572.311 1988.29,572.283 1988.3,572.254 1988.31,572.226 1988.32,572.197 1988.33,572.169 1988.34,572.141 1988.35,572.112 1988.35,572.084 1988.36,572.055 1988.37,572.027 1988.38,571.998 1988.39,571.97 1988.4,571.941 1988.41,571.912 1988.42,571.884 1988.43,571.855 1988.44,571.827 1988.45,571.798 1988.46,571.77 1988.46,571.741 1988.47,571.713 1988.48,571.684 1988.49,571.655 1988.5,571.627 1988.51,571.598 1988.52,571.57 1988.53,571.541 1988.54,571.512 1988.55,571.484 1988.56,571.455 1988.57,571.426 1988.58,571.398 1988.58,571.369 1988.59,571.34 1988.6,571.312 1988.61,571.283 1988.62,571.254 1988.63,571.226 1988.64,571.197 1988.65,571.168 1988.66,571.14 1988.67,571.111 1988.68,571.082 1988.69,571.053 1988.69,571.025 1988.7,570.996 1988.71,570.967 1988.72,570.938 1988.73,570.91 1988.74,570.881 1988.75,570.852 1988.76,570.823 1988.77,570.795 1988.78,570.766 1988.79,570.737 1988.8,570.708 1988.8,570.679 1988.81,570.65 1988.82,570.622 1988.83,570.593 1988.84,570.564 1988.85,570.535 1988.86,570.506 1988.87,570.477 1988.88,570.449 1988.89,570.42 1988.9,570.391 1988.91,570.362 1988.92,570.333 1988.92,570.304 1988.93,570.275 1988.94,570.246 1988.95,570.217 1988.96,570.188 1988.97,570.16 1988.98,570.131 1988.99,570.102 1989,570.073 1989.01,570.044 1989.02,570.015 1989.03,569.986 1989.03,569.957 1989.04,569.928 1989.05,569.899 1989.06,569.87 1989.07,569.841 1989.08,569.812 1989.09,569.783 1989.1,569.754 1989.11,569.725 1989.12,569.696 1989.13,569.667 1989.14,569.638 1989.14,569.609 1989.15,569.58 1989.16,569.55 1989.17,569.521 1989.18,569.492 1989.19,569.463 1989.2,569.434 1989.21,569.405 1989.22,569.376 1989.23,569.347 1989.24,569.318 1989.25,569.289 1989.26,569.259 1989.26,569.23 1989.27,569.201 1989.28,569.172 1989.29,569.143 1989.3,569.114 1989.31,569.085 1989.32,569.055 1989.33,569.026 1989.34,568.997 1989.35,568.968 1989.36,568.939 1989.37,568.909 1989.37,568.88 1989.38,568.851 1989.39,568.822 1989.4,568.793 1989.41,568.763 1989.42,568.734 1989.43,568.705 1989.44,568.676 1989.45,568.646 1989.46,568.617 1989.47,568.588 1989.48,568.558 1989.48,568.529 1989.49,568.5 1989.5,568.471 1989.51,568.441 1989.52,568.412 1989.53,568.383 1989.54,568.353 1989.55,568.324 1989.56,568.295 1989.57,568.265 1989.58,568.236 1989.59,568.207 1989.6,568.177 1989.6,568.148 1989.61,568.119 1989.62,568.089 1989.63,568.06 1989.64,568.03 1989.65,568.001 1989.66,567.972 1989.67,567.942 1989.68,567.913 1989.69,567.883 1989.7,567.854 1989.71,567.824 1989.71,567.795 1989.72,567.766 1989.73,567.736 1989.74,567.707 1989.75,567.677 1989.76,567.648 1989.77,567.618 1989.78,567.589 1989.79,567.559 1989.8,567.53 1989.81,567.5 1989.82,567.471 1989.82,567.441 1989.83,567.412 1989.84,567.382 1989.85,567.353 1989.86,567.323 1989.87,567.294 1989.88,567.264 1989.89,567.235 1989.9,567.205 1989.91,567.175 1989.92,567.146 1989.93,567.116 1989.94,567.087 1989.94,567.057 1989.95,567.028 1989.96,566.998 1989.97,566.968 1989.98,566.939 1989.99,566.909 1990,566.879 1990.01,566.85 1990.02,566.82 1990.03,566.791 1990.04,566.761 1990.05,566.731 1990.05,566.702 1990.06,566.672 1990.07,566.642 1990.08,566.613 1990.09,566.583 1990.1,566.553 1990.11,566.524 1990.12,566.494 1990.13,566.464 1990.14,566.434 1990.15,566.405 1990.16,566.375 1990.16,566.345 1990.17,566.315 1990.18,566.286 1990.19,566.256 1990.2,566.226 1990.21,566.196 1990.22,566.167 1990.23,566.137 1990.24,566.107 1990.25,566.077 1990.26,566.048 1990.27,566.018 1990.28,565.988 1990.28,565.958 1990.29,565.928 1990.3,565.899 1990.31,565.869 1990.32,565.839 1990.33,565.809 1990.34,565.779 1990.35,565.749 1990.36,565.72 1990.37,565.69 1990.38,565.66 1990.39,565.63 1990.39,565.6 1990.4,565.57 1990.41,565.54 1990.42,565.51 1990.43,565.481 1990.44,565.451 1990.45,565.421 1990.46,565.391 1990.47,565.361 1990.48,565.331 1990.49,565.301 1990.5,565.271 1990.5,565.241 1990.51,565.211 1990.52,565.181 1990.53,565.151 1990.54,565.121 1990.55,565.091 1990.56,565.061 1990.57,565.031 1990.58,565.001 1990.59,564.971 1990.6,564.941 1990.61,564.911 1990.62,564.881 1990.62,564.851 1990.63,564.821 1990.64,564.791 1990.65,564.761 1990.66,564.731 1990.67,564.701 1990.68,564.671 1990.69,564.641 1990.7,564.611 1990.71,564.581 1990.72,564.551 1990.73,564.521 1990.73,564.491 1990.74,564.461 1990.75,564.431 1990.76,564.4 1990.77,564.37 1990.78,564.34 1990.79,564.31 1990.8,564.28 1990.81,564.25 1990.82,564.22 1990.83,564.19 1990.84,564.159 1990.84,564.129 1990.85,564.099 1990.86,564.069 1990.87,564.039 1990.88,564.009 1990.89,563.978 1990.9,563.948 1990.91,563.918 1990.92,563.888 1990.93,563.858 1990.94,563.828 1990.95,563.797 1990.96,563.767 1990.96,563.737 1990.97,563.707 1990.98,563.676 1990.99,563.646 1991,563.616 1991.01,563.586 1991.02,563.555 1991.03,563.525 1991.04,563.495 1991.05,563.465 1991.06,563.434 1991.07,563.404 1991.07,563.374 1991.08,563.344 1991.09,563.313 1991.1,563.283 1991.11,563.253 1991.12,563.222 1991.13,563.192 1991.14,563.162 1991.15,563.131 1991.16,563.101 1991.17,563.071 1991.18,563.04 1991.18,563.01 1991.19,562.98 1991.2,562.949 1991.21,562.919 1991.22,562.888 1991.23,562.858 1991.24,562.828 1991.25,562.797 1991.26,562.767 1991.27,562.737 1991.28,562.706 1991.29,562.676 1991.3,562.645 1991.3,562.615 1991.31,562.584 1991.32,562.554 1991.33,562.524 1991.34,562.493 1991.35,562.463 1991.36,562.432 1991.37,562.402 1991.38,562.371 1991.39,562.341 1991.4,562.31 1991.41,562.28 1991.41,562.249 1991.42,562.219 1991.43,562.188 1991.44,562.158 1991.45,562.127 1991.46,562.097 1991.47,562.066 1991.48,562.036 1991.49,562.005 1991.5,561.975 1991.51,561.944 1991.52,561.914 1991.52,561.883 1991.53,561.853 1991.54,561.822 1991.55,561.792 1991.56,561.761 1991.57,561.73 1991.58,561.7 1991.59,561.669 1991.6,561.639 1991.61,561.608 1991.62,561.577 1991.63,561.547 1991.64,561.516 1991.64,561.486 1991.65,561.455 1991.66,561.424 1991.67,561.394 1991.68,561.363 1991.69,561.332 1991.7,561.302 1991.71,561.271 1991.72,561.241 1991.73,561.21 1991.74,561.179 1991.75,561.149 1991.75,561.118 1991.76,561.087 1991.77,561.057 1991.78,561.026 1991.79,560.995 1991.8,560.964 1991.81,560.934 1991.82,560.903 1991.83,560.872 1991.84,560.842 1991.85,560.811 1991.86,560.78 1991.86,560.749 1991.87,560.719 1991.88,560.688 1991.89,560.657 1991.9,560.626 1991.91,560.596 1991.92,560.565 1991.93,560.534 1991.94,560.503 1991.95,560.473 1991.96,560.442 1991.97,560.411 1991.98,560.38 1991.98,560.349 1991.99,560.319 1992,560.288 1992.01,560.257 1992.02,560.226 1992.03,560.195 1992.04,560.164 1992.05,560.134 1992.06,560.103 1992.07,560.072 1992.08,560.041 1992.09,560.01 1992.09,559.979 1992.1,559.948 1992.11,559.918 1992.12,559.887 1992.13,559.856 1992.14,559.825 1992.15,559.794 1992.16,559.763 1992.17,559.732 1992.18,559.701 1992.19,559.67 1992.2,559.64 1992.2,559.609 1992.21,559.578 1992.22,559.547 1992.23,559.516 1992.24,559.485 1992.25,559.454 1992.26,559.423 1992.27,559.392 1992.28,559.361 1992.29,559.33 1992.3,559.299 1992.31,559.268 1992.32,559.237 1992.32,559.206 1992.33,559.175 1992.34,559.144 1992.35,559.113 1992.36,559.082 1992.37,559.051 1992.38,559.02 1992.39,558.989 1992.4,558.958 1992.41,558.927 1992.42,558.896 1992.43,558.865 1992.43,558.834 1992.44,558.803 1992.45,558.772 1992.46,558.741 1992.47,558.71 1992.48,558.679 1992.49,558.648 1992.5,558.617 1992.51,558.585 1992.52,558.554 1992.53,558.523 1992.54,558.492 1992.54,558.461 1992.55,558.43 1992.56,558.399 1992.57,558.368 1992.58,558.337 1992.59,558.306 1992.6,558.274 1992.61,558.243 1992.62,558.212 1992.63,558.181 1992.64,558.15 1992.65,558.119 1992.66,558.088 1992.66,558.056 1992.67,558.025 1992.68,557.994 1992.69,557.963 1992.7,557.932 1992.71,557.9 1992.72,557.869 1992.73,557.838 1992.74,557.807 1992.75,557.776 1992.76,557.744 1992.77,557.713 1992.77,557.682 1992.78,557.651 1992.79,557.62 1992.8,557.588 1992.81,557.557 1992.82,557.526 1992.83,557.495 1992.84,557.463 1992.85,557.432 1992.86,557.401 1992.87,557.37 1992.88,557.338 1992.88,557.307 1992.89,557.276 1992.9,557.245 1992.91,557.213 1992.92,557.182 1992.93,557.151 1992.94,557.119 1992.95,557.088 1992.96,557.057 1992.97,557.025 1992.98,556.994 1992.99,556.963 1993,556.931 1993,556.9 1993.01,556.869 1993.02,556.837 1993.03,556.806 1993.04,556.775 1993.05,556.743 1993.06,556.712 1993.07,556.681 1993.08,556.649 1993.09,556.618 1993.1,556.587 1993.11,556.555 1993.11,556.524 1993.12,556.492 1993.13,556.461 1993.14,556.43 1993.15,556.398 1993.16,556.367 1993.17,556.335 1993.18,556.304 1993.19,556.272 1993.2,556.241 1993.21,556.21 1993.22,556.178 1993.22,556.147 1993.23,556.115 1993.24,556.084 1993.25,556.052 1993.26,556.021 1993.27,555.989 1993.28,555.958 1993.29,555.927 1993.3,555.895 1993.31,555.864 1993.32,555.832 1993.33,555.801 1993.34,555.769 1993.34,555.738 1993.35,555.706 1993.36,555.675 1993.37,555.643 1993.38,555.612 1993.39,555.58 1993.4,555.548 1993.41,555.517 1993.42,555.485 1993.43,555.454 1993.44,555.422 1993.45,555.391 1993.45,555.359 1993.46,555.328 1993.47,555.296 1993.48,555.265 1993.49,555.233 1993.5,555.201 1993.51,555.17 1993.52,555.138 1993.53,555.107 1993.54,555.075 1993.55,555.043 1993.56,555.012 1993.56,554.98 1993.57,554.949 1993.58,554.917 1993.59,554.885 1993.6,554.854 1993.61,554.822 1993.62,554.791 1993.63,554.759 1993.64,554.727 1993.65,554.696 1993.66,554.664 1993.67,554.632 1993.68,554.601 1993.68,554.569 1993.69,554.537 1993.7,554.506 1993.71,554.474 1993.72,554.442 1993.73,554.411 1993.74,554.379 1993.75,554.347 1993.76,554.316 1993.77,554.284 1993.78,554.252 1993.79,554.22 1993.79,554.189 1993.8,554.157 1993.81,554.125 1993.82,554.094 1993.83,554.062 1993.84,554.03 1993.85,553.998 1993.86,553.967 1993.87,553.935 1993.88,553.903 1993.89,553.871 1993.9,553.84 1993.9,553.808 1993.91,553.776 1993.92,553.744 1993.93,553.712 1993.94,553.681 1993.95,553.649 1993.96,553.617 1993.97,553.585 1993.98,553.554 1993.99,553.522 1994,553.49 1994.01,553.458 1994.02,553.426 1994.02,553.394 1994.03,553.363 1994.04,553.331 1994.05,553.299 1994.06,553.267 1994.07,553.235 1994.08,553.204 1994.09,553.172 1994.1,553.14 1994.11,553.108 1994.12,553.076 1994.13,553.044 1994.13,553.012 1994.14,552.98 1994.15,552.949 1994.16,552.917 1994.17,552.885 1994.18,552.853 1994.19,552.821 1994.2,552.789 1994.21,552.757 1994.22,552.725 1994.23,552.693 1994.24,552.662 1994.24,552.63 1994.25,552.598 1994.26,552.566 1994.27,552.534 1994.28,552.502 1994.29,552.47 1994.3,552.438 1994.31,552.406 1994.32,552.374 1994.33,552.342 1994.34,552.31 1994.35,552.278 1994.36,552.246 1994.36,552.214 1994.37,552.182 1994.38,552.15 1994.39,552.118 1994.4,552.086 1994.41,552.054 1994.42,552.022 1994.43,551.99 1994.44,551.958 1994.45,551.926 1994.46,551.894 1994.47,551.862 1994.47,551.83 1994.48,551.798 1994.49,551.766 1994.5,551.734 1994.51,551.702 1994.52,551.67 1994.53,551.638 1994.54,551.606 1994.55,551.574 1994.56,551.542 1994.57,551.51 1994.58,551.478 1994.58,551.446 1994.59,551.414 1994.6,551.382 1994.61,551.35 1994.62,551.318 1994.63,551.285 1994.64,551.253 1994.65,551.221 1994.66,551.189 1994.67,551.157 1994.68,551.125 1994.69,551.093 1994.7,551.061 1994.7,551.029 1994.71,550.996 1994.72,550.964 1994.73,550.932 1994.74,550.9 1994.75,550.868 1994.76,550.836 1994.77,550.804 1994.78,550.772 1994.79,550.739 1994.8,550.707 1994.81,550.675 1994.81,550.643 1994.82,550.611 1994.83,550.579 1994.84,550.546 1994.85,550.514 1994.86,550.482 1994.87,550.45 1994.88,550.418 1994.89,550.385 1994.9,550.353 1994.91,550.321 1994.92,550.289 1994.92,550.257 1994.93,550.224 1994.94,550.192 1994.95,550.16 1994.96,550.128 1994.97,550.096 1994.98,550.063 1994.99,550.031 1995,549.999 1995.01,549.967 1995.02,549.934 1995.03,549.902 1995.04,549.87 1995.04,549.838 1995.05,549.805 1995.06,549.773 1995.07,549.741 1995.08,549.708 1995.09,549.676 1995.1,549.644 1995.11,549.612 1995.12,549.579 1995.13,549.547 1995.14,549.515 1995.15,549.482 1995.15,549.45 1995.16,549.418 1995.17,549.386 1995.18,549.353 1995.19,549.321 1995.2,549.289 1995.21,549.256 1995.22,549.224 1995.23,549.192 1995.24,549.159 1995.25,549.127 1995.26,549.095 1995.26,549.062 1995.27,549.03 1995.28,548.998 1995.29,548.965 1995.3,548.933 1995.31,548.9 1995.32,548.868 1995.33,548.836 1995.34,548.803 1995.35,548.771 1995.36,548.739 1995.37,548.706 1995.38,548.674 1995.38,548.641 1995.39,548.609 1995.4,548.577 1995.41,548.544 1995.42,548.512 1995.43,548.479 1995.44,548.447 1995.45,548.414 1995.46,548.382 1995.47,548.35 1995.48,548.317 1995.49,548.285 1995.49,548.252 1995.5,548.22 1995.51,548.187 1995.52,548.155 1995.53,548.123 1995.54,548.09 1995.55,548.058 1995.56,548.025 1995.57,547.993 1995.58,547.96 1995.59,547.928 1995.6,547.895 1995.6,547.863 1995.61,547.83 1995.62,547.798 1995.63,547.765 1995.64,547.733 1995.65,547.7 1995.66,547.668 1995.67,547.635 1995.68,547.603 1995.69,547.57 1995.7,547.538 1995.71,547.505 1995.72,547.473 1995.72,547.44 1995.73,547.408 1995.74,547.375 1995.75,547.343 1995.76,547.31 1995.77,547.277 1995.78,547.245 1995.79,547.212 1995.8,547.18 1995.81,547.147 1995.82,547.115 1995.83,547.082 1995.83,547.05 1995.84,547.017 1995.85,546.984 1995.86,546.952 1995.87,546.919 1995.88,546.887 1995.89,546.854 1995.9,546.821 1995.91,546.789 1995.92,546.756 1995.93,546.724 1995.94,546.691 1995.94,546.658 1995.95,546.626 1995.96,546.593 1995.97,546.561 1995.98,546.528 1995.99,546.495 1996,546.463 1996.01,546.43 1996.02,546.397 1996.03,546.365 1996.04,546.332 1996.05,546.299 1996.06,546.267 1996.06,546.234 1996.07,546.201 1996.08,546.169 1996.09,546.136 1996.1,546.103 1996.11,546.071 1996.12,546.038 1996.13,546.005 1996.14,545.973 1996.15,545.94 1996.16,545.907 1996.17,545.875 1996.17,545.842 1996.18,545.809 1996.19,545.777 1996.2,545.744 1996.21,545.711 1996.22,545.678 1996.23,545.646 1996.24,545.613 1996.25,545.58 1996.26,545.547 1996.27,545.515 1996.28,545.482 1996.28,545.449 1996.29,545.417 1996.3,545.384 1996.31,545.351 1996.32,545.318 1996.33,545.286 1996.34,545.253 1996.35,545.22 1996.36,545.187 1996.37,545.154 1996.38,545.122 1996.39,545.089 1996.4,545.056 1996.4,545.023 1996.41,544.991 1996.42,544.958 1996.43,544.925 1996.44,544.892 1996.45,544.859 1996.46,544.827 1996.47,544.794 1996.48,544.761 1996.49,544.728 1996.5,544.695 1996.51,544.663 1996.51,544.63 1996.52,544.597 1996.53,544.564 1996.54,544.531 1996.55,544.498 1996.56,544.466 1996.57,544.433 1996.58,544.4 1996.59,544.367 1996.6,544.334 1996.61,544.301 1996.62,544.268 1996.62,544.236 1996.63,544.203 1996.64,544.17 1996.65,544.137 1996.66,544.104 1996.67,544.071 1996.68,544.038 1996.69,544.006 1996.7,543.973 1996.71,543.94 1996.72,543.907 1996.73,543.874 1996.74,543.841 1996.74,543.808 1996.75,543.775 1996.76,543.742 1996.77,543.709 1996.78,543.677 1996.79,543.644 1996.8,543.611 1996.81,543.578 1996.82,543.545 1996.83,543.512 1996.84,543.479 1996.85,543.446 1996.85,543.413 1996.86,543.38 1996.87,543.347 1996.88,543.314 1996.89,543.281 1996.9,543.248 1996.91,543.215 1996.92,543.182 1996.93,543.149 1996.94,543.116 1996.95,543.084 1996.96,543.051 1996.96,543.018 1996.97,542.985 1996.98,542.952 1996.99,542.919 1997,542.886 1997.01,542.853 1997.02,542.82 1997.03,542.787 1997.04,542.754 1997.05,542.721 1997.06,542.688 1997.07,542.655 1997.08,542.622 1997.08,542.589 1997.09,542.556 1997.1,542.523 1997.11,542.49 1997.12,542.456 1997.13,542.423 1997.14,542.39 1997.15,542.357 1997.16,542.324 1997.17,542.291 1997.18,542.258 1997.19,542.225 1997.19,542.192 1997.2,542.159 1997.21,542.126 1997.22,542.093 1997.23,542.06 1997.24,542.027 1997.25,541.994 1997.26,541.961 1997.27,541.928 1997.28,541.895 1997.29,541.861 1997.3,541.828 1997.3,541.795 1997.31,541.762 1997.32,541.729 1997.33,541.696 1997.34,541.663 1997.35,541.63 1997.36,541.597 1997.37,541.564 1997.38,541.53 1997.39,541.497 1997.4,541.464 1997.41,541.431 1997.42,541.398 1997.42,541.365 1997.43,541.332 1997.44,541.299 1997.45,541.265 1997.46,541.232 1997.47,541.199 1997.48,541.166 1997.49,541.133 1997.5,541.1 1997.51,541.067 1997.52,541.033 1997.53,541 1997.53,540.967 1997.54,540.934 1997.55,540.901 1997.56,540.868 1997.57,540.834 1997.58,540.801 1997.59,540.768 1997.6,540.735 1997.61,540.702 1997.62,540.668 1997.63,540.635 1997.64,540.602 1997.64,540.569 1997.65,540.536 1997.66,540.502 1997.67,540.469 1997.68,540.436 1997.69,540.403 1997.7,540.37 1997.71,540.336 1997.72,540.303 1997.73,540.27 1997.74,540.237 1997.75,540.203 1997.76,540.17 1997.76,540.137 1997.77,540.104 1997.78,540.071 1997.79,540.037 1997.8,540.004 1997.81,539.971 1997.82,539.938 1997.83,539.904 1997.84,539.871 1997.85,539.838 1997.86,539.804 1997.87,539.771 1997.87,539.738 1997.88,539.705 1997.89,539.671 1997.9,539.638 1997.91,539.605 1997.92,539.572 1997.93,539.538 1997.94,539.505 1997.95,539.472 1997.96,539.438 1997.97,539.405 1997.98,539.372 1997.98,539.338 1997.99,539.305 1998,539.272 1998.01,539.239 1998.02,539.205 1998.03,539.172 1998.04,539.139 1998.05,539.105 1998.06,539.072 1998.07,539.039 1998.08,539.005 1998.09,538.972 1998.1,538.939 1998.1,538.905 1998.11,538.872 1998.12,538.839 1998.13,538.805 1998.14,538.772 1998.15,538.739 1998.16,538.705 1998.17,538.672 1998.18,538.638 1998.19,538.605 1998.2,538.572 1998.21,538.538 1998.21,538.505 1998.22,538.472 1998.23,538.438 1998.24,538.405 1998.25,538.371 1998.26,538.338 1998.27,538.305 1998.28,538.271 1998.29,538.238 1998.3,538.205 1998.31,538.171 1998.32,538.138 1998.32,538.104 1998.33,538.071 1998.34,538.038 1998.35,538.004 1998.36,537.971 1998.37,537.937 1998.38,537.904 1998.39,537.87 1998.4,537.837 1998.41,537.804 1998.42,537.77 1998.43,537.737 1998.44,537.703 1998.44,537.67 1998.45,537.636 1998.46,537.603 1998.47,537.57 1998.48,537.536 1998.49,537.503 1998.5,537.469 1998.51,537.436 1998.52,537.402 1998.53,537.369 1998.54,537.335 1998.55,537.302 1998.55,537.268 1998.56,537.235 1998.57,537.201 1998.58,537.168 1998.59,537.134 1998.6,537.101 1998.61,537.068 1998.62,537.034 1998.63,537.001 1998.64,536.967 1998.65,536.934 1998.66,536.9 1998.66,536.867 1998.67,536.833 1998.68,536.8 1998.69,536.766 1998.7,536.733 1998.71,536.699 1998.72,536.665 1998.73,536.632 1998.74,536.598 1998.75,536.565 1998.76,536.531 1998.77,536.498 1998.78,536.464 1998.78,536.431 1998.79,536.397 1998.8,536.364 1998.81,536.33 1998.82,536.297 1998.83,536.263 1998.84,536.23 1998.85,536.196 1998.86,536.162 1998.87,536.129 1998.88,536.095 1998.89,536.062 1998.89,536.028 1998.9,535.995 1998.91,535.961 1998.92,535.927 1998.93,535.894 1998.94,535.86 1998.95,535.827 1998.96,535.793 1998.97,535.76 1998.98,535.726 1998.99,535.692 1999,535.659 1999,535.625 1999.01,535.592 1999.02,535.558 1999.03,535.524 1999.04,535.491 1999.05,535.457 1999.06,535.424 1999.07,535.39 1999.08,535.356 1999.09,535.323 1999.1,535.289 1999.11,535.256 1999.12,535.222 1999.12,535.188 1999.13,535.155 1999.14,535.121 1999.15,535.087 1999.16,535.054 1999.17,535.02 1999.18,534.987 1999.19,534.953 1999.2,534.919 1999.21,534.886 1999.22,534.852 1999.23,534.818 1999.23,534.785 1999.24,534.751 1999.25,534.717 1999.26,534.684 1999.27,534.65 1999.28,534.616 1999.29,534.583 1999.3,534.549 1999.31,534.515 1999.32,534.482 1999.33,534.448 1999.34,534.414 1999.35,534.381 1999.35,534.347 1999.36,534.313 1999.37,534.28 1999.38,534.246 1999.39,534.212 1999.4,534.178 1999.41,534.145 1999.42,534.111 1999.43,534.077 1999.44,534.044 1999.45,534.01 1999.46,533.976 1999.46,533.942 1999.47,533.909 1999.48,533.875 1999.49,533.841 1999.5,533.808 1999.51,533.774 1999.52,533.74 1999.53,533.706 1999.54,533.673 1999.55,533.639 1999.56,533.605 1999.57,533.571 1999.57,533.538 1999.58,533.504 1999.59,533.47 1999.6,533.437 1999.61,533.403 1999.62,533.369 1999.63,533.335 1999.64,533.302 1999.65,533.268 1999.66,533.234 1999.67,533.2 1999.68,533.166 1999.69,533.133 1999.69,533.099 1999.7,533.065 1999.71,533.031 1999.72,532.998 1999.73,532.964 1999.74,532.93 1999.75,532.896 1999.76,532.862 1999.77,532.829 1999.78,532.795 1999.79,532.761 1999.8,532.727 1999.8,532.693 1999.81,532.66 1999.82,532.626 1999.83,532.592 1999.84,532.558 1999.85,532.524 1999.86,532.491 1999.87,532.457 1999.88,532.423 1999.89,532.389 1999.9,532.355 1999.91,532.322 1999.91,532.288 1999.92,532.254 1999.93,532.22 1999.94,532.186 1999.95,532.152 1999.96,532.119 1999.97,532.085 1999.98,532.051 1999.99,532.017 2000,531.983 2000.01,531.949 2000.02,531.916 2000.03,531.882 2000.03,531.848 2000.04,531.814 2000.05,531.78 2000.06,531.746 2000.07,531.712 2000.08,531.679 2000.09,531.645 2000.1,531.611 2000.11,531.577 2000.12,531.543 2000.13,531.509 2000.14,531.475 2000.14,531.441 2000.15,531.408 2000.16,531.374 2000.17,531.34 2000.18,531.306 2000.19,531.272 2000.2,531.238 2000.21,531.204 2000.22,531.17 2000.23,531.136 2000.24,531.103 2000.25,531.069 2000.25,531.035 2000.26,531.001 2000.27,530.967 2000.28,530.933 2000.29,530.899 2000.3,530.865 2000.31,530.831 2000.32,530.797 2000.33,530.763 2000.34,530.73 2000.35,530.696 2000.36,530.662 2000.37,530.628 2000.37,530.594 2000.38,530.56 2000.39,530.526 2000.4,530.492 2000.41,530.458 2000.42,530.424 2000.43,530.39 2000.44,530.356 2000.45,530.322 2000.46,530.288 2000.47,530.254 2000.48,530.22 2000.48,530.187 2000.49,530.153 2000.5,530.119 2000.51,530.085 2000.52,530.051 2000.53,530.017 2000.54,529.983 2000.55,529.949 2000.56,529.915 2000.57,529.881 2000.58,529.847 2000.59,529.813 2000.59,529.779 2000.6,529.745 2000.61,529.711 2000.62,529.677 2000.63,529.643 2000.64,529.609 2000.65,529.575 2000.66,529.541 2000.67,529.507 2000.68,529.473 2000.69,529.439 2000.7,529.405 2000.71,529.371 2000.71,529.337 2000.72,529.303 2000.73,529.269 2000.74,529.235 2000.75,529.201 2000.76,529.167 2000.77,529.133 2000.78,529.099 2000.79,529.065 2000.8,529.031 2000.81,528.997 2000.82,528.963 2000.82,528.929 2000.83,528.895 2000.84,528.861 2000.85,528.827 2000.86,528.793 2000.87,528.759 2000.88,528.725 2000.89,528.691 2000.9,528.656 2000.91,528.622 2000.92,528.588 2000.93,528.554 2000.93,528.52 2000.94,528.486 2000.95,528.452 2000.96,528.418 2000.97,528.384 2000.98,528.35 2000.99,528.316 2001,528.282 2001.01,528.248 2001.02,528.214 2001.03,528.18 2001.04,528.146 2001.05,528.112 2001.05,528.077 2001.06,528.043 2001.07,528.009 2001.08,527.975 2001.09,527.941 2001.1,527.907 2001.11,527.873 2001.12,527.839 2001.13,527.805 2001.14,527.771 2001.15,527.737 2001.16,527.703 2001.16,527.668 2001.17,527.634 2001.18,527.6 2001.19,527.566 2001.2,527.532 2001.21,527.498 2001.22,527.464 2001.23,527.43 2001.24,527.396 2001.25,527.361 2001.26,527.327 2001.27,527.293 2001.27,527.259 2001.28,527.225 2001.29,527.191 2001.3,527.157 2001.31,527.123 2001.32,527.088 2001.33,527.054 2001.34,527.02 2001.35,526.986 2001.36,526.952 2001.37,526.918 2001.38,526.884 2001.39,526.85 2001.39,526.815 2001.4,526.781 2001.41,526.747 2001.42,526.713 2001.43,526.679 2001.44,526.645 2001.45,526.61 2001.46,526.576 2001.47,526.542 2001.48,526.508 2001.49,526.474 2001.5,526.44 2001.5,526.405 2001.51,526.371 2001.52,526.337 2001.53,526.303 2001.54,526.269 2001.55,526.235 2001.56,526.2 2001.57,526.166 2001.58,526.132 2001.59,526.098 2001.6,526.064 2001.61,526.03 2001.61,525.995 2001.62,525.961 2001.63,525.927 2001.64,525.893 2001.65,525.859 2001.66,525.824 2001.67,525.79 2001.68,525.756 2001.69,525.722 2001.7,525.688 2001.71,525.653 2001.72,525.619 2001.73,525.585 2001.73,525.551 2001.74,525.517 2001.75,525.482 2001.76,525.448 2001.77,525.414 2001.78,525.38 2001.79,525.346 2001.8,525.311 2001.81,525.277 2001.82,525.243 2001.83,525.209 2001.84,525.174 2001.84,525.14 2001.85,525.106 2001.86,525.072 2001.87,525.037 2001.88,525.003 2001.89,524.969 2001.9,524.935 2001.91,524.901 2001.92,524.866 2001.93,524.832 2001.94,524.798 2001.95,524.764 2001.95,524.729 2001.96,524.695 2001.97,524.661 2001.98,524.627 2001.99,524.592 2002,524.558 2002.01,524.524 2002.02,524.49 2002.03,524.455 2002.04,524.421 2002.05,524.387 2002.06,524.352 2002.07,524.318 2002.07,524.284 2002.08,524.25 2002.09,524.215 2002.1,524.181 2002.11,524.147 2002.12,524.113 2002.13,524.078 2002.14,524.044 2002.15,524.01 2002.16,523.975 2002.17,523.941 2002.18,523.907 2002.18,523.873 2002.19,523.838 2002.2,523.804 2002.21,523.77 2002.22,523.735 2002.23,523.701 2002.24,523.667 2002.25,523.633 2002.26,523.598 2002.27,523.564 2002.28,523.53 2002.29,523.495 2002.29,523.461 2002.3,523.427 2002.31,523.392 2002.32,523.358 2002.33,523.324 2002.34,523.289 2002.35,523.255 2002.36,523.221 2002.37,523.186 2002.38,523.152 2002.39,523.118 2002.4,523.084 2002.41,523.049 2002.41,523.015 2002.42,522.981 2002.43,522.946 2002.44,522.912 2002.45,522.878 2002.46,522.843 2002.47,522.809 2002.48,522.775 2002.49,522.74 2002.5,522.706 2002.51,522.672 2002.52,522.637 2002.52,522.603 2002.53,522.568 2002.54,522.534 2002.55,522.5 2002.56,522.465 2002.57,522.431 2002.58,522.397 2002.59,522.362 2002.6,522.328 2002.61,522.294 2002.62,522.259 2002.63,522.225 2002.63,522.191 2002.64,522.156 2002.65,522.122 2002.66,522.087 2002.67,522.053 2002.68,522.019 2002.69,521.984 2002.7,521.95 2002.71,521.916 2002.72,521.881 2002.73,521.847 2002.74,521.812 2002.75,521.778 2002.75,521.744 2002.76,521.709 2002.77,521.675 2002.78,521.641 2002.79,521.606 2002.8,521.572 2002.81,521.537 2002.82,521.503 2002.83,521.469 2002.84,521.434 2002.85,521.4 2002.86,521.365 2002.86,521.331 2002.87,521.297 2002.88,521.262 2002.89,521.228 2002.9,521.193 2002.91,521.159 2002.92,521.125 2002.93,521.09 2002.94,521.056 2002.95,521.021 2002.96,520.987 2002.97,520.953 2002.97,520.918 2002.98,520.884 2002.99,520.849 2003,520.815 2003.01,520.78 2003.02,520.746 2003.03,520.712 2003.04,520.677 2003.05,520.643 2003.06,520.608 2003.07,520.574 2003.08,520.539 2003.09,520.505 2003.09,520.471 2003.1,520.436 2003.11,520.402 2003.12,520.367 2003.13,520.333 2003.14,520.298 2003.15,520.264 2003.16,520.23 2003.17,520.195 2003.18,520.161 2003.19,520.126 2003.2,520.092 2003.2,520.057 2003.21,520.023 2003.22,519.988 2003.23,519.954 2003.24,519.919 2003.25,519.885 2003.26,519.851 2003.27,519.816 2003.28,519.782 2003.29,519.747 2003.3,519.713 2003.31,519.678 2003.31,519.644 2003.32,519.609 2003.33,519.575 2003.34,519.54 2003.35,519.506 2003.36,519.471 2003.37,519.437 2003.38,519.402 2003.39,519.368 2003.4,519.334 2003.41,519.299 2003.42,519.265 2003.43,519.23 2003.43,519.196 2003.44,519.161 2003.45,519.127 2003.46,519.092 2003.47,519.058 2003.48,519.023 2003.49,518.989 2003.5,518.954 2003.51,518.92 2003.52,518.885 2003.53,518.851 2003.54,518.816 2003.54,518.782 2003.55,518.747 2003.56,518.713 2003.57,518.678 2003.58,518.644 2003.59,518.609 2003.6,518.575 2003.61,518.54 2003.62,518.506 2003.63,518.471 2003.64,518.437 2003.65,518.402 2003.65,518.368 2003.66,518.333 2003.67,518.299 2003.68,518.264 2003.69,518.23 2003.7,518.195 2003.71,518.161 2003.72,518.126 2003.73,518.092 2003.74,518.057 2003.75,518.022 2003.76,517.988 2003.77,517.953 2003.77,517.919 2003.78,517.884 2003.79,517.85 2003.8,517.815 2003.81,517.781 2003.82,517.746 2003.83,517.712 2003.84,517.677 2003.85,517.643 2003.86,517.608 2003.87,517.574 2003.88,517.539 2003.88,517.504 2003.89,517.47 2003.9,517.435 2003.91,517.401 2003.92,517.366 2003.93,517.332 2003.94,517.297 2003.95,517.263 2003.96,517.228 2003.97,517.194 2003.98,517.159 2003.99,517.124 2003.99,517.09 2004,517.055 2004.01,517.021 2004.02,516.986 2004.03,516.952 2004.04,516.917 2004.05,516.882 2004.06,516.848 2004.07,516.813 2004.08,516.779 2004.09,516.744 2004.1,516.71 2004.11,516.675 2004.11,516.641 2004.12,516.606 2004.13,516.571 2004.14,516.537 2004.15,516.502 2004.16,516.468 2004.17,516.433 2004.18,516.399 2004.19,516.364 2004.2,516.329 2004.21,516.295 2004.22,516.26 2004.22,516.226 2004.23,516.191 2004.24,516.156 2004.25,516.122 2004.26,516.087 2004.27,516.053 2004.28,516.018 2004.29,515.983 2004.3,515.949 2004.31,515.914 2004.32,515.88 2004.33,515.845 2004.33,515.81 2004.34,515.776 2004.35,515.741 2004.36,515.707 2004.37,515.672 2004.38,515.637 2004.39,515.603 2004.4,515.568 2004.41,515.534 2004.42,515.499 2004.43,515.464 2004.44,515.43 2004.45,515.395 2004.45,515.361 2004.46,515.326 2004.47,515.291 2004.48,515.257 2004.49,515.222 2004.5,515.188 2004.51,515.153 2004.52,515.118 2004.53,515.084 2004.54,515.049 2004.55,515.014 2004.56,514.98 2004.56,514.945 2004.57,514.911 2004.58,514.876 2004.59,514.841 2004.6,514.807 2004.61,514.772 2004.62,514.737 2004.63,514.703 2004.64,514.668 2004.65,514.634 2004.66,514.599 2004.67,514.564 2004.67,514.53 2004.68,514.495 2004.69,514.46 2004.7,514.426 2004.71,514.391 2004.72,514.356 2004.73,514.322 2004.74,514.287 2004.75,514.253 2004.76,514.218 2004.77,514.183 2004.78,514.149 2004.79,514.114 2004.79,514.079 2004.8,514.045 2004.81,514.01 2004.82,513.975 2004.83,513.941 2004.84,513.906 2004.85,513.871 2004.86,513.837 2004.87,513.802 2004.88,513.767 2004.89,513.733 2004.9,513.698 2004.9,513.663 2004.91,513.629 2004.92,513.594 2004.93,513.56 2004.94,513.525 2004.95,513.49 2004.96,513.456 2004.97,513.421 2004.98,513.386 2004.99,513.352 2005,513.317 2005.01,513.282 2005.01,513.248 2005.02,513.213 2005.03,513.178 2005.04,513.143 2005.05,513.109 2005.06,513.074 2005.07,513.039 2005.08,513.005 2005.09,512.97 2005.1,512.935 2005.11,512.901 2005.12,512.866 2005.13,512.831 2005.13,512.797 2005.14,512.762 2005.15,512.727 2005.16,512.693 2005.17,512.658 2005.18,512.623 2005.19,512.589 2005.2,512.554 2005.21,512.519 2005.22,512.485 2005.23,512.45 2005.24,512.415 2005.24,512.38 2005.25,512.346 2005.26,512.311 2005.27,512.276 2005.28,512.242 2005.29,512.207 2005.3,512.172 2005.31,512.138 2005.32,512.103 2005.33,512.068 2005.34,512.033 2005.35,511.999 2005.35,511.964 2005.36,511.929 2005.37,511.895 2005.38,511.86 2005.39,511.825 2005.4,511.791 2005.41,511.756 2005.42,511.721 2005.43,511.686 2005.44,511.652 2005.45,511.617 2005.46,511.582 2005.47,511.548 2005.47,511.513 2005.48,511.478 2005.49,511.443 2005.5,511.409 2005.51,511.374 2005.52,511.339 2005.53,511.305 2005.54,511.27 2005.55,511.235 2005.56,511.2 2005.57,511.166 2005.58,511.131 2005.58,511.096 2005.59,511.062 2005.6,511.027 2005.61,510.992 2005.62,510.957 2005.63,510.923 2005.64,510.888 2005.65,510.853 2005.66,510.818 2005.67,510.784 2005.68,510.749 2005.69,510.714 2005.69,510.68 2005.7,510.645 2005.71,510.61 2005.72,510.575 2005.73,510.541 2005.74,510.506 2005.75,510.471 2005.76,510.436 2005.77,510.402 2005.78,510.367 2005.79,510.332 2005.8,510.297 2005.81,510.263 2005.81,510.228 2005.82,510.193 2005.83,510.158 2005.84,510.124 2005.85,510.089 2005.86,510.054 2005.87,510.019 2005.88,509.985 2005.89,509.95 2005.9,509.915 2005.91,509.88 2005.92,509.846 2005.92,509.811 2005.93,509.776 2005.94,509.741 2005.95,509.707 2005.96,509.672 2005.97,509.637 2005.98,509.602 2005.99,509.568 2006,509.533 2006.01,509.498 2006.02,509.463 2006.03,509.429 2006.03,509.394 2006.04,509.359 2006.05,509.324 2006.06,509.29 2006.07,509.255 2006.08,509.22 2006.09,509.185 2006.1,509.151 2006.11,509.116 2006.12,509.081 2006.13,509.046 2006.14,509.011 2006.15,508.977 2006.15,508.942 2006.16,508.907 2006.17,508.872 2006.18,508.838 2006.19,508.803 2006.2,508.768 2006.21,508.733 2006.22,508.699 2006.23,508.664 2006.24,508.629 2006.25,508.594 2006.26,508.559 2006.26,508.525 2006.27,508.49 2006.28,508.455 2006.29,508.42 2006.3,508.386 2006.31,508.351 2006.32,508.316 2006.33,508.281 2006.34,508.246 2006.35,508.212 2006.36,508.177 2006.37,508.142 2006.37,508.107 2006.38,508.073 2006.39,508.038 2006.4,508.003 2006.41,507.968 2006.42,507.933 2006.43,507.899 2006.44,507.864 2006.45,507.829 2006.46,507.794 2006.47,507.759 2006.48,507.725 2006.49,507.69 2006.49,507.655 2006.5,507.62 2006.51,507.585 2006.52,507.551 2006.53,507.516 2006.54,507.481 2006.55,507.446 2006.56,507.412 2006.57,507.377 2006.58,507.342 2006.59,507.307 2006.6,507.272 2006.6,507.238 2006.61,507.203 2006.62,507.168 2006.63,507.133 2006.64,507.098 2006.65,507.064 2006.66,507.029 2006.67,506.994 2006.68,506.959 2006.69,506.924 2006.7,506.889 2006.71,506.855 2006.71,506.82 2006.72,506.785 2006.73,506.75 2006.74,506.715 2006.75,506.681 2006.76,506.646 2006.77,506.611 2006.78,506.576 2006.79,506.541 2006.8,506.507 2006.81,506.472 2006.82,506.437 2006.83,506.402 2006.83,506.367 2006.84,506.333 2006.85,506.298 2006.86,506.263 2006.87,506.228 2006.88,506.193 2006.89,506.158 2006.9,506.124 2006.91,506.089 2006.92,506.054 2006.93,506.019 2006.94,505.984 2006.94,505.95 2006.95,505.915 2006.96,505.88 2006.97,505.845 2006.98,505.81 2006.99,505.775 2007,505.741 2007.01,505.706 2007.02,505.671 2007.03,505.636 2007.04,505.601 2007.05,505.567 2007.05,505.532 2007.06,505.497 2007.07,505.462 2007.08,505.427 2007.09,505.392 2007.1,505.358 2007.11,505.323 2007.12,505.288 2007.13,505.253 2007.14,505.218 2007.15,505.183 2007.16,505.149 2007.17,505.114 2007.17,505.079 2007.18,505.044 2007.19,505.009 2007.2,504.974 2007.21,504.94 2007.22,504.905 2007.23,504.87 2007.24,504.835 2007.25,504.8 2007.26,504.765 2007.27,504.731 2007.28,504.696 2007.28,504.661 2007.29,504.626 2007.3,504.591 2007.31,504.556 2007.32,504.522 2007.33,504.487 2007.34,504.452 2007.35,504.417 2007.36,504.382 2007.37,504.347 2007.38,504.313 2007.39,504.278 2007.39,504.243 2007.4,504.208 2007.41,504.173 2007.42,504.138 2007.43,504.103 2007.44,504.069 2007.45,504.034 2007.46,503.999 2007.47,503.964 2007.48,503.929 2007.49,503.894 2007.5,503.86 2007.51,503.825 2007.51,503.79 2007.52,503.755 2007.53,503.72 2007.54,503.685 2007.55,503.65 2007.56,503.616 2007.57,503.581 2007.58,503.546 2007.59,503.511 2007.6,503.476 2007.61,503.441 2007.62,503.406 2007.62,503.372 2007.63,503.337 2007.64,503.302 2007.65,503.267 2007.66,503.232 2007.67,503.197 2007.68,503.163 2007.69,503.128 2007.7,503.093 2007.71,503.058 2007.72,503.023 2007.73,502.988 2007.73,502.953 2007.74,502.919 2007.75,502.884 2007.76,502.849 2007.77,502.814 2007.78,502.779 2007.79,502.744 2007.8,502.709 2007.81,502.675 2007.82,502.64 2007.83,502.605 2007.84,502.57 2007.85,502.535 2007.85,502.5 2007.86,502.465 2007.87,502.43 2007.88,502.396 2007.89,502.361 2007.9,502.326 2007.91,502.291 2007.92,502.256 2007.93,502.221 2007.94,502.186 2007.95,502.152 2007.96,502.117 2007.96,502.082 2007.97,502.047 2007.98,502.012 2007.99,501.977 2008,501.942 2008.01,501.908 2008.02,501.873 2008.03,501.838 2008.04,501.803 2008.05,501.768 2008.06,501.733 2008.07,501.698 2008.07,501.663 2008.08,501.629 2008.09,501.594 2008.1,501.559 2008.11,501.524 2008.12,501.489 2008.13,501.454 2008.14,501.419 2008.15,501.384 2008.16,501.35 2008.17,501.315 2008.18,501.28 2008.19,501.245 2008.19,501.21 2008.2,501.175 2008.21,501.14 2008.22,501.105 2008.23,501.071 2008.24,501.036 2008.25,501.001 2008.26,500.966 2008.27,500.931 2008.28,500.896 2008.29,500.861 2008.3,500.826 2008.3,500.792 2008.31,500.757 2008.32,500.722 2008.33,500.687 2008.34,500.652 2008.35,500.617 2008.36,500.582 2008.37,500.547 2008.38,500.513 2008.39,500.478 2008.4,500.443 2008.41,500.408 2008.41,500.373 2008.42,500.338 2008.43,500.303 2008.44,500.268 2008.45,500.234 2008.46,500.199 2008.47,500.164 2008.48,500.129 2008.49,500.094 2008.5,500.059 2008.51,500.024 2008.52,499.989 2008.53,499.955 2008.53,499.92 2008.54,499.885 2008.55,499.85 2008.56,499.815 2008.57,499.78 2008.58,499.745 2008.59,499.71 2008.6,499.675 2008.61,499.641 2008.62,499.606 2008.63,499.571 2008.64,499.536 2008.64,499.501 2008.65,499.466 2008.66,499.431 2008.67,499.396 2008.68,499.362 2008.69,499.327 2008.7,499.292 2008.71,499.257 2008.72,499.222 2008.73,499.187 2008.74,499.152 2008.75,499.117 2008.75,499.082 2008.76,499.048 2008.77,499.013 2008.78,498.978 2008.79,498.943 2008.8,498.908 2008.81,498.873 2008.82,498.838 2008.83,498.803 2008.84,498.768 2008.85,498.734 2008.86,498.699 2008.87,498.664 2008.87,498.629 2008.88,498.594 2008.89,498.559 2008.9,498.524 2008.91,498.489 2008.92,498.454 2008.93,498.42 2008.94,498.385 2008.95,498.35 2008.96,498.315 2008.97,498.28 2008.98,498.245 2008.98,498.21 2008.99,498.175 2009,498.14 2009.01,498.106 2009.02,498.071 2009.03,498.036 2009.04,498.001 2009.05,497.966 2009.06,497.931 2009.07,497.896 2009.08,497.861 2009.09,497.826 2009.09,497.792 2009.1,497.757 2009.11,497.722 2009.12,497.687 2009.13,497.652 2009.14,497.617 2009.15,497.582 2009.16,497.547 2009.17,497.512 2009.18,497.477 2009.19,497.443 2009.2,497.408 2009.21,497.373 2009.21,497.338 2009.22,497.303 2009.23,497.268 2009.24,497.233 2009.25,497.198 2009.26,497.163 2009.27,497.129 2009.28,497.094 2009.29,497.059 2009.3,497.024 2009.31,496.989 2009.32,496.954 2009.32,496.919 2009.33,496.884 2009.34,496.849 2009.35,496.815 2009.36,496.78 2009.37,496.745 2009.38,496.71 2009.39,496.675 2009.4,496.64 2009.41,496.605 2009.42,496.57 2009.43,496.535 2009.43,496.5 2009.44,496.466 2009.45,496.431 2009.46,496.396 2009.47,496.361 2009.48,496.326 2009.49,496.291 2009.5,496.256 2009.51,496.221 2009.52,496.186 2009.53,496.152 2009.54,496.117 2009.55,496.082 2009.55,496.047 2009.56,496.012 2009.57,495.977 2009.58,495.942 2009.59,495.907 2009.6,495.872 2009.61,495.837 2009.62,495.803 2009.63,495.768 2009.64,495.733 2009.65,495.698 2009.66,495.663 2009.66,495.628 2009.67,495.593 2009.68,495.558 2009.69,495.523 2009.7,495.489 2009.71,495.454 2009.72,495.419 2009.73,495.384 2009.74,495.349 2009.75,495.314 2009.76,495.279 2009.77,495.244 2009.77,495.209 2009.78,495.174 2009.79,495.14 2009.8,495.105 2009.81,495.07 2009.82,495.035 2009.83,495 2009.84,494.965 2009.85,494.93 2009.86,494.895 2009.87,494.86 2009.88,494.825 2009.89,494.791 2009.89,494.756 2009.9,494.721 2009.91,494.686 2009.92,494.651 2009.93,494.616 2009.94,494.581 2009.95,494.546 2009.96,494.511 2009.97,494.477 2009.98,494.442 2009.99,494.407 2010,494.372 2010,494.337 2010.01,494.302 2010.02,494.267 2010.03,494.232 2010.04,494.197 2010.05,494.162 2010.06,494.128 2010.07,494.093 2010.08,494.058 2010.09,494.023 2010.1,493.988 2010.11,493.953 2010.11,493.918 2010.12,493.883 2010.13,493.848 2010.14,493.814 2010.15,493.779 2010.16,493.744 2010.17,493.709 2010.18,493.674 2010.19,493.639 2010.2,493.604 2010.21,493.569 2010.22,493.534 2010.23,493.5 2010.23,493.465 2010.24,493.43 2010.25,493.395 2010.26,493.36 2010.27,493.325 2010.28,493.29 2010.29,493.255 2010.3,493.22 2010.31,493.185 2010.32,493.151 2010.33,493.116 2010.34,493.081 2010.34,493.046 2010.35,493.011 2010.36,492.976 2010.37,492.941 2010.38,492.906 2010.39,492.871 2010.4,492.837 2010.41,492.802 2010.42,492.767 2010.43,492.732 2010.44,492.697 2010.45,492.662 2010.45,492.627 2010.46,492.592 2010.47,492.557 2010.48,492.523 2010.49,492.488 2010.5,492.453 2010.51,492.418 2010.52,492.383 2010.53,492.348 2010.54,492.313 2010.55,492.278 2010.56,492.243 2010.57,492.209 2010.57,492.174 2010.58,492.139 2010.59,492.104 2010.6,492.069 2010.61,492.034 2010.62,491.999 2010.63,491.964 2010.64,491.929 2010.65,491.895 2010.66,491.86 2010.67,491.825 2010.68,491.79 2010.68,491.755 2010.69,491.72 2010.7,491.685 2010.71,491.65 2010.72,491.615 2010.73,491.581 2010.74,491.546 2010.75,491.511 2010.76,491.476 2010.77,491.441 2010.78,491.406 2010.79,491.371 2010.79,491.336 2010.8,491.301 2010.81,491.267 2010.82,491.232 2010.83,491.197 2010.84,491.162 2010.85,491.127 2010.86,491.092 2010.87,491.057 2010.88,491.022 2010.89,490.988 2010.9,490.953 2010.91,490.918 2010.91,490.883 2010.92,490.848 2010.93,490.813 2010.94,490.778 2010.95,490.743 2010.96,490.708 2010.97,490.674 2010.98,490.639 2010.99,490.604 2011,490.569 2011.01,490.534 2011.02,490.499 2011.02,490.464 2011.03,490.429 2011.04,490.395 2011.05,490.36 2011.06,490.325 2011.07,490.29 2011.08,490.255 2011.09,490.22 2011.1,490.185 2011.11,490.15 2011.12,490.115 2011.13,490.081 2011.13,490.046 2011.14,490.011 2011.15,489.976 2011.16,489.941 2011.17,489.906 2011.18,489.871 2011.19,489.836 2011.2,489.802 2011.21,489.767 2011.22,489.732 2011.23,489.697 2011.24,489.662 2011.25,489.627 2011.25,489.592 2011.26,489.557 2011.27,489.523 2011.28,489.488 2011.29,489.453 2011.3,489.418 2011.31,489.383 2011.32,489.348 2011.33,489.313 2011.34,489.278 2011.35,489.244 2011.36,489.209 2011.36,489.174 2011.37,489.139 2011.38,489.104 2011.39,489.069 2011.4,489.034 2011.41,489 2011.42,488.965 2011.43,488.93 2011.44,488.895 2011.45,488.86 2011.46,488.825 2011.47,488.79 2011.47,488.755 2011.48,488.721 2011.49,488.686 2011.5,488.651 2011.51,488.616 2011.52,488.581 2011.53,488.546 2011.54,488.511 2011.55,488.476 2011.56,488.442 2011.57,488.407 2011.58,488.372 2011.59,488.337 2011.59,488.302 2011.6,488.267 2011.61,488.232 2011.62,488.198 2011.63,488.163 2011.64,488.128 2011.65,488.093 2011.66,488.058 2011.67,488.023 2011.68,487.988 2011.69,487.954 2011.7,487.919 2011.7,487.884 2011.71,487.849 2011.72,487.814 2011.73,487.779 2011.74,487.744 2011.75,487.71 2011.76,487.675 2011.77,487.64 2011.78,487.605 2011.79,487.57 2011.8,487.535 2011.81,487.5 2011.81,487.465 2011.82,487.431 2011.83,487.396 2011.84,487.361 2011.85,487.326 2011.86,487.291 2011.87,487.256 2011.88,487.222 2011.89,487.187 2011.9,487.152 2011.91,487.117 2011.92,487.082 2011.93,487.047 2011.93,487.012 2011.94,486.978 2011.95,486.943 2011.96,486.908 2011.97,486.873 2011.98,486.838 2011.99,486.803 2012,486.768 2012.01,486.734 2012.02,486.699 2012.03,486.664 2012.04,486.629 2012.04,486.594 2012.05,486.559 2012.06,486.524 2012.07,486.49 2012.08,486.455 2012.09,486.42 2012.1,486.385 2012.11,486.35 2012.12,486.315 2012.13,486.281 2012.14,486.246 2012.15,486.211 2012.15,486.176 2012.16,486.141 2012.17,486.106 2012.18,486.072 2012.19,486.037 2012.2,486.002 2012.21,485.967 2012.22,485.932 2012.23,485.897 2012.24,485.862 2012.25,485.828 2012.26,485.793 2012.27,485.758 2012.27,485.723 2012.28,485.688 2012.29,485.653 2012.3,485.619 2012.31,485.584 2012.32,485.549 2012.33,485.514 2012.34,485.479 2012.35,485.444 2012.36,485.41 2012.37,485.375 2012.38,485.34 2012.38,485.305 2012.39,485.27 2012.4,485.235 2012.41,485.201 2012.42,485.166 2012.43,485.131 2012.44,485.096 2012.45,485.061 2012.46,485.026 2012.47,484.992 2012.48,484.957 2012.49,484.922 2012.49,484.887 2012.5,484.852 2012.51,484.817 2012.52,484.783 2012.53,484.748 2012.54,484.713 2012.55,484.678 2012.56,484.643 2012.57,484.608 2012.58,484.574 2012.59,484.539 2012.6,484.504 2012.61,484.469 2012.61,484.434 2012.62,484.4 2012.63,484.365 2012.64,484.33 2012.65,484.295 2012.66,484.26 2012.67,484.225 2012.68,484.191 2012.69,484.156 2012.7,484.121 2012.71,484.086 2012.72,484.051 2012.72,484.017 2012.73,483.982 2012.74,483.947 2012.75,483.912 2012.76,483.877 2012.77,483.842 2012.78,483.808 2012.79,483.773 2012.8,483.738 2012.81,483.703 2012.82,483.668 2012.83,483.634 2012.83,483.599 2012.84,483.564 2012.85,483.529 2012.86,483.494 2012.87,483.46 2012.88,483.425 2012.89,483.39 2012.9,483.355 2012.91,483.32 2012.92,483.285 2012.93,483.251 2012.94,483.216 2012.95,483.181 2012.95,483.146 2012.96,483.111 2012.97,483.077 2012.98,483.042 2012.99,483.007 2013,482.972 2013.01,482.937 2013.02,482.903 2013.03,482.868 2013.04,482.833 2013.05,482.798 2013.06,482.763 2013.06,482.729 2013.07,482.694 2013.08,482.659 2013.09,482.624 2013.1,482.589 2013.11,482.555 2013.12,482.52 2013.13,482.485 2013.14,482.45 2013.15,482.415 2013.16,482.381 2013.17,482.346 2013.17,482.311 2013.18,482.276 2013.19,482.242 2013.2,482.207 2013.21,482.172 2013.22,482.137 2013.23,482.102 2013.24,482.068 2013.25,482.033 2013.26,481.998 2013.27,481.963 2013.28,481.928 2013.29,481.894 2013.29,481.859 2013.3,481.824 2013.31,481.789 2013.32,481.754 2013.33,481.72 2013.34,481.685 2013.35,481.65 2013.36,481.615 2013.37,481.581 2013.38,481.546 2013.39,481.511 2013.4,481.476 2013.4,481.441 2013.41,481.407 2013.42,481.372 2013.43,481.337 2013.44,481.302 2013.45,481.268 2013.46,481.233 2013.47,481.198 2013.48,481.163 2013.49,481.128 2013.5,481.094 2013.51,481.059 2013.51,481.024 2013.52,480.989 2013.53,480.955 2013.54,480.92 2013.55,480.885 2013.56,480.85 2013.57,480.816 2013.58,480.781 2013.59,480.746 2013.6,480.711 2013.61,480.676 2013.62,480.642 2013.63,480.607 2013.63,480.572 2013.64,480.537 2013.65,480.503 2013.66,480.468 2013.67,480.433 2013.68,480.398 2013.69,480.364 2013.7,480.329 2013.71,480.294 2013.72,480.259 2013.73,480.225 2013.74,480.19 2013.74,480.155 2013.75,480.12 2013.76,480.086 2013.77,480.051 2013.78,480.016 2013.79,479.981 2013.8,479.947 2013.81,479.912 2013.82,479.877 2013.83,479.842 2013.84,479.808 2013.85,479.773 2013.85,479.738 2013.86,479.703 2013.87,479.669 2013.88,479.634 2013.89,479.599 2013.9,479.564 2013.91,479.53 2013.92,479.495 2013.93,479.46 2013.94,479.425 2013.95,479.391 2013.96,479.356 2013.97,479.321 2013.97,479.286 2013.98,479.252 2013.99,479.217 2014,479.182 2014.01,479.147 2014.02,479.113 2014.03,479.078 2014.04,479.043 2014.05,479.008 2014.06,478.974 2014.07,478.939 2014.08,478.904 2014.08,478.869 2014.09,478.835 2014.1,478.8 2014.11,478.765 2014.12,478.731 2014.13,478.696 2014.14,478.661 2014.15,478.626 2014.16,478.592 2014.17,478.557 2014.18,478.522 2014.19,478.487 2014.19,478.453 2014.2,478.418 2014.21,478.383 2014.22,478.349 2014.23,478.314 2014.24,478.279 2014.25,478.244 2014.26,478.21 2014.27,478.175 2014.28,478.14 2014.29,478.106 2014.3,478.071 2014.31,478.036 2014.31,478.001 2014.32,477.967 2014.33,477.932 2014.34,477.897 2014.35,477.862 2014.36,477.828 2014.37,477.793 2014.38,477.758 2014.39,477.724 2014.4,477.689 2014.41,477.654 2014.42,477.62 2014.42,477.585 2014.43,477.55 2014.44,477.515 2014.45,477.481 2014.46,477.446 2014.47,477.411 2014.48,477.377 2014.49,477.342 2014.5,477.307 2014.51,477.272 2014.52,477.238 2014.53,477.203 2014.53,477.168 2014.54,477.134 2014.55,477.099 2014.56,477.064 2014.57,477.03 2014.58,476.995 2014.59,476.96 2014.6,476.925 2014.61,476.891 2014.62,476.856 2014.63,476.821 2014.64,476.787 2014.65,476.752 2014.65,476.717 2014.66,476.683 2014.67,476.648 2014.68,476.613 2014.69,476.579 2014.7,476.544 2014.71,476.509 2014.72,476.475 2014.73,476.44 2014.74,476.405 2014.75,476.37 2014.76,476.336 2014.76,476.301 2014.77,476.266 2014.78,476.232 2014.79,476.197 2014.8,476.162 2014.81,476.128 2014.82,476.093 2014.83,476.058 2014.84,476.024 2014.85,475.989 2014.86,475.954 2014.87,475.92 2014.87,475.885 2014.88,475.85 2014.89,475.816 2014.9,475.781 2014.91,475.746 2014.92,475.712 2014.93,475.677 2014.94,475.642 2014.95,475.608 2014.96,475.573 2014.97,475.538 2014.98,475.504 2014.99,475.469 2014.99,475.434 2015,475.4 2015.01,475.365 2015.02,475.33 2015.03,475.296 2015.04,475.261 2015.05,475.226 2015.06,475.192 2015.07,475.157 2015.08,475.122 2015.09,475.088 2015.1,475.053 2015.1,475.018 2015.11,474.984 2015.12,474.949 2015.13,474.914 2015.14,474.88 2015.15,474.845 2015.16,474.811 2015.17,474.776 2015.18,474.741 2015.19,474.707 2015.2,474.672 2015.21,474.637 2015.21,474.603 2015.22,474.568 2015.23,474.533 2015.24,474.499 2015.25,474.464 2015.26,474.429 2015.27,474.395 2015.28,474.36 2015.29,474.326 2015.3,474.291 2015.31,474.256 2015.32,474.222 2015.33,474.187 2015.33,474.152 2015.34,474.118 2015.35,474.083 2015.36,474.048 2015.37,474.014 2015.38,473.979 2015.39,473.945 2015.4,473.91 2015.41,473.875 2015.42,473.841 2015.43,473.806 2015.44,473.771 2015.44,473.737 2015.45,473.702 2015.46,473.668 2015.47,473.633 2015.48,473.598 2015.49,473.564 2015.5,473.529 2015.51,473.494 2015.52,473.46 2015.53,473.425 2015.54,473.391 2015.55,473.356 2015.55,473.321 2015.56,473.287 2015.57,473.252 2015.58,473.218 2015.59,473.183 2015.6,473.148 2015.61,473.114 2015.62,473.079 2015.63,473.045 2015.64,473.01 2015.65,472.975 2015.66,472.941 2015.67,472.906 2015.67,472.872 2015.68,472.837 2015.69,472.802 2015.7,472.768 2015.71,472.733 2015.72,472.699 2015.73,472.664 2015.74,472.629 2015.75,472.595 2015.76,472.56 2015.77,472.526 2015.78,472.491 2015.78,472.456 2015.79,472.422 2015.8,472.387 2015.81,472.353 2015.82,472.318 2015.83,472.283 2015.84,472.249 2015.85,472.214 2015.86,472.18 2015.87,472.145 2015.88,472.111 2015.89,472.076 2015.89,472.041 2015.9,472.007 2015.91,471.972 2015.92,471.938 2015.93,471.903 2015.94,471.868 2015.95,471.834 2015.96,471.799 2015.97,471.765 2015.98,471.73 2015.99,471.696 2016,471.661 2016.01,471.626 2016.01,471.592 2016.02,471.557 2016.03,471.523 2016.04,471.488 2016.05,471.454 2016.06,471.419 2016.07,471.384 2016.08,471.35 2016.09,471.315 2016.1,471.281 2016.11,471.246 2016.12,471.212 2016.12,471.177 2016.13,471.143 2016.14,471.108 2016.15,471.073 2016.16,471.039 2016.17,471.004 2016.18,470.97 2016.19,470.935 2016.2,470.901 2016.21,470.866 2016.22,470.832 2016.23,470.797 2016.23,470.763 2016.24,470.728 2016.25,470.693 2016.26,470.659 2016.27,470.624 2016.28,470.59 2016.29,470.555 2016.3,470.521 2016.31,470.486 2016.32,470.452 2016.33,470.417 2016.34,470.383 2016.35,470.348 2016.35,470.313 2016.36,470.279 2016.37,470.244 2016.38,470.21 2016.39,470.175 2016.4,470.141 2016.41,470.106 2016.42,470.072 2016.43,470.037 2016.44,470.003 2016.45,469.968 2016.46,469.934 2016.46,469.899 2016.47,469.865 2016.48,469.83 2016.49,469.796 2016.5,469.761 2016.51,469.727 2016.52,469.692 2016.53,469.658 2016.54,469.623 2016.55,469.588 2016.56,469.554 2016.57,469.519 2016.57,469.485 2016.58,469.45 2016.59,469.416 2016.6,469.381 2016.61,469.347 2016.62,469.312 2016.63,469.278 2016.64,469.243 2016.65,469.209 2016.66,469.174 2016.67,469.14 2016.68,469.105 2016.69,469.071 2016.69,469.036 2016.7,469.002 2016.71,468.967 2016.72,468.933 2016.73,468.898 2016.74,468.864 2016.75,468.829 2016.76,468.795 2016.77,468.76 2016.78,468.726 2016.79,468.691 2016.8,468.657 2016.8,468.622 2016.81,468.588 2016.82,468.553 2016.83,468.519 2016.84,468.485 2016.85,468.45 2016.86,468.416 2016.87,468.381 2016.88,468.347 2016.89,468.312 2016.9,468.278 2016.91,468.243 2016.91,468.209 2016.92,468.174 2016.93,468.14 2016.94,468.105 2016.95,468.071 2016.96,468.036 2016.97,468.002 2016.98,467.967 2016.99,467.933 2017,467.898 2017.01,467.864 2017.02,467.83 2017.03,467.795 2017.03,467.761 2017.04,467.726 2017.05,467.692 2017.06,467.657 2017.07,467.623 2017.08,467.588 2017.09,467.554 2017.1,467.519 2017.11,467.485 2017.12,467.45 2017.13,467.416 2017.14,467.382 2017.14,467.347 2017.15,467.313 2017.16,467.278 2017.17,467.244 2017.18,467.209 2017.19,467.175 2017.2,467.14 2017.21,467.106 2017.22,467.072 2017.23,467.037 2017.24,467.003 2017.25,466.968 2017.25,466.934 2017.26,466.899 2017.27,466.865 2017.28,466.831 2017.29,466.796 2017.3,466.762 2017.31,466.727 2017.32,466.693 2017.33,466.658 2017.34,466.624 2017.35,466.59 2017.36,466.555 2017.37,466.521 2017.37,466.486 2017.38,466.452 2017.39,466.417 2017.4,466.383 2017.41,466.349 2017.42,466.314 2017.43,466.28 2017.44,466.245 2017.45,466.211 2017.46,466.176 2017.47,466.142 2017.48,466.108 2017.48,466.073 2017.49,466.039 2017.5,466.004 2017.51,465.97 2017.52,465.936 2017.53,465.901 2017.54,465.867 2017.55,465.832 2017.56,465.798 2017.57,465.764 2017.58,465.729 2017.59,465.695 2017.59,465.66 2017.6,465.626 2017.61,465.592 2017.62,465.557 2017.63,465.523 2017.64,465.488 2017.65,465.454 2017.66,465.42 2017.67,465.385 2017.68,465.351 2017.69,465.316 2017.7,465.282 2017.71,465.248 2017.71,465.213 2017.72,465.179 2017.73,465.145 2017.74,465.11 2017.75,465.076 2017.76,465.041 2017.77,465.007 2017.78,464.973 2017.79,464.938 2017.8,464.904 2017.81,464.87 2017.82,464.835 2017.82,464.801 2017.83,464.766 2017.84,464.732 2017.85,464.698 2017.86,464.663 2017.87,464.629 2017.88,464.595 2017.89,464.56 2017.9,464.526 2017.91,464.492 2017.92,464.457 2017.93,464.423 2017.93,464.388 2017.94,464.354 2017.95,464.32 2017.96,464.285 2017.97,464.251 2017.98,464.217 2017.99,464.182 2018,464.148 2018.01,464.114 2018.02,464.079 2018.03,464.045 2018.04,464.011 2018.05,463.976 2018.05,463.942 2018.06,463.908 2018.07,463.873 2018.08,463.839 2018.09,463.805 2018.1,463.77 2018.11,463.736 2018.12,463.702 2018.13,463.667 2018.14,463.633 2018.15,463.599 2018.16,463.564 2018.16,463.53 2018.17,463.496 2018.18,463.461 2018.19,463.427 2018.2,463.393 2018.21,463.358 2018.22,463.324 2018.23,463.29 2018.24,463.255 2018.25,463.221 2018.26,463.187 2018.27,463.152 2018.27,463.118 2018.28,463.084 2018.29,463.049 2018.3,463.015 2018.31,462.981 2018.32,462.947 2018.33,462.912 2018.34,462.878 2018.35,462.844 2018.36,462.809 2018.37,462.775 2018.38,462.741 2018.39,462.706 2018.39,462.672 2018.4,462.638 2018.41,462.604 2018.42,462.569 2018.43,462.535 2018.44,462.501 2018.45,462.466 2018.46,462.432 2018.47,462.398 2018.48,462.363 2018.49,462.329 2018.5,462.295 2018.5,462.261 2018.51,462.226 2018.52,462.192 2018.53,462.158 2018.54,462.123 2018.55,462.089 2018.56,462.055 2018.57,462.021 2018.58,461.986 2018.59,461.952 2018.6,461.918 2018.61,461.884 2018.61,461.849 2018.62,461.815 2018.63,461.781 2018.64,461.746 2018.65,461.712 2018.66,461.678 2018.67,461.644 2018.68,461.609 2018.69,461.575 2018.7,461.541 2018.71,461.507 2018.72,461.472 2018.73,461.438 2018.73,461.404 2018.74,461.37 2018.75,461.335 2018.76,461.301 2018.77,461.267 2018.78,461.233 2018.79,461.198 2018.8,461.164 2018.81,461.13 2018.82,461.096 2018.83,461.061 2018.84,461.027 2018.84,460.993 2018.85,460.959 2018.86,460.924 2018.87,460.89 2018.88,460.856 2018.89,460.822 2018.9,460.787 2018.91,460.753 2018.92,460.719 2018.93,460.685 2018.94,460.651 2018.95,460.616 2018.95,460.582 2018.96,460.548 2018.97,460.514 2018.98,460.479 2018.99,460.445 2019,460.411 2019.01,460.377 2019.02,460.343 2019.03,460.308 2019.04,460.274 2019.05,460.24 2019.06,460.206 2019.07,460.171 2019.07,460.137 2019.08,460.103 2019.09,460.069 2019.1,460.035 2019.11,460 2019.12,459.966 2019.13,459.932 2019.14,459.898 2019.15,459.864 2019.16,459.829 2019.17,459.795 2019.18,459.761 2019.18,459.727 2019.19,459.693 2019.2,459.658 2019.21,459.624 2019.22,459.59 2019.23,459.556 2019.24,459.522 2019.25,459.488 2019.26,459.453 2019.27,459.419 2019.28,459.385 2019.29,459.351 2019.29,459.317 2019.3,459.282 2019.31,459.248 2019.32,459.214 2019.33,459.18 2019.34,459.146 2019.35,459.112 2019.36,459.077 2019.37,459.043 2019.38,459.009 2019.39,458.975 2019.4,458.941 2019.41,458.907 2019.41,458.872 2019.42,458.838 2019.43,458.804 2019.44,458.77 2019.45,458.736 2019.46,458.702 2019.47,458.667 2019.48,458.633 2019.49,458.599 2019.5,458.565 2019.51,458.531 2019.52,458.497 2019.52,458.463 2019.53,458.428 2019.54,458.394 2019.55,458.36 2019.56,458.326 2019.57,458.292 2019.58,458.258 2019.59,458.224 2019.6,458.189 2019.61,458.155 2019.62,458.121 2019.63,458.087 2019.63,458.053 2019.64,458.019 2019.65,457.985 2019.66,457.95 2019.67,457.916 2019.68,457.882 2019.69,457.848 2019.7,457.814 2019.71,457.78 2019.72,457.746 2019.73,457.712 2019.74,457.677 2019.75,457.643 2019.75,457.609 2019.76,457.575 2019.77,457.541 2019.78,457.507 2019.79,457.473 2019.8,457.439 2019.81,457.405 2019.82,457.37 2019.83,457.336 2019.84,457.302 2019.85,457.268 2019.86,457.234 2019.86,457.2 2019.87,457.166 2019.88,457.132 2019.89,457.098 2019.9,457.064 2019.91,457.03 2019.92,456.995 2019.93,456.961 2019.94,456.927 2019.95,456.893 2019.96,456.859 2019.97,456.825 2019.97,456.791 2019.98,456.757 2019.99,456.723 2020,456.689 2020.01,456.655 2020.02,456.62 2020.03,456.586 2020.04,456.552 2020.05,456.518 2020.06,456.484 2020.07,456.45 2020.08,456.416 2020.09,456.382 2020.09,456.348 2020.1,456.314 2020.11,456.28 2020.12,456.246 2020.13,456.212 2020.14,456.178 2020.15,456.144 2020.16,456.109 2020.17,456.075 2020.18,456.041 2020.19,456.007 2020.2,455.973 2020.2,455.939 2020.21,455.905 2020.22,455.871 2020.23,455.837 2020.24,455.803 2020.25,455.769 2020.26,455.735 2020.27,455.701 2020.28,455.667 2020.29,455.633 2020.3,455.599 2020.31,455.565 2020.31,455.531 2020.32,455.497 2020.33,455.463 2020.34,455.429 2020.35,455.395 2020.36,455.361 2020.37,455.327 2020.38,455.293 2020.39,455.259 2020.4,455.224 2020.41,455.19 2020.42,455.156 2020.43,455.122 2020.43,455.088 2020.44,455.054 2020.45,455.02 2020.46,454.986 2020.47,454.952 2020.48,454.918 2020.49,454.884 2020.5,454.85 2020.51,454.816 2020.52,454.782 2020.53,454.748 2020.54,454.714 2020.54,454.68 2020.55,454.646 2020.56,454.612 2020.57,454.578 2020.58,454.544 2020.59,454.51 2020.6,454.476 2020.61,454.442 2020.62,454.408 2020.63,454.374 2020.64,454.34 2020.65,454.306 2020.65,454.272 2020.66,454.238 2020.67,454.204 2020.68,454.171 2020.69,454.137 2020.7,454.103 2020.71,454.069 2020.72,454.035 2020.73,454.001 2020.74,453.967 2020.75,453.933 2020.76,453.899 2020.77,453.865 2020.77,453.831 2020.78,453.797 2020.79,453.763 2020.8,453.729 2020.81,453.695 2020.82,453.661 2020.83,453.627 2020.84,453.593 2020.85,453.559 2020.86,453.525 2020.87,453.491 2020.88,453.457 2020.88,453.423 2020.89,453.389 2020.9,453.355 2020.91,453.322 2020.92,453.288 2020.93,453.254 2020.94,453.22 2020.95,453.186 2020.96,453.152 2020.97,453.118 2020.98,453.084 2020.99,453.05 2020.99,453.016 2021,452.982 2021.01,452.948 2021.02,452.914 2021.03,452.88 2021.04,452.846 2021.05,452.813 2021.06,452.779 2021.07,452.745 2021.08,452.711 2021.09,452.677 2021.1,452.643 2021.11,452.609 2021.11,452.575 2021.12,452.541 2021.13,452.507 2021.14,452.473 2021.15,452.439 2021.16,452.406 2021.17,452.372 2021.18,452.338 2021.19,452.304 2021.2,452.27 2021.21,452.236 2021.22,452.202 2021.22,452.168 2021.23,452.134 2021.24,452.1 2021.25,452.067 2021.26,452.033 2021.27,451.999 2021.28,451.965 2021.29,451.931 2021.3,451.897 2021.31,451.863 2021.32,451.829 2021.33,451.796 2021.33,451.762 2021.34,451.728 2021.35,451.694 2021.36,451.66 2021.37,451.626 2021.38,451.592 2021.39,451.558 2021.4,451.525 2021.41,451.491 2021.42,451.457 2021.43,451.423 2021.44,451.389 2021.45,451.355 2021.45,451.321 2021.46,451.288 2021.47,451.254 2021.48,451.22 2021.49,451.186 2021.5,451.152 2021.51,451.118 2021.52,451.084 2021.53,451.051 2021.54,451.017 2021.55,450.983 2021.56,450.949 2021.56,450.915 2021.57,450.881 2021.58,450.848 2021.59,450.814 2021.6,450.78 2021.61,450.746 2021.62,450.712 2021.63,450.678 2021.64,450.645 2021.65,450.611 2021.66,450.577 2021.67,450.543 2021.67,450.509 2021.68,450.475 2021.69,450.442 2021.7,450.408 2021.71,450.374 2021.72,450.34 2021.73,450.306 2021.74,450.273 2021.75,450.239 2021.76,450.205 2021.77,450.171 2021.78,450.137 2021.79,450.103 2021.79,450.07 2021.8,450.036 2021.81,450.002 2021.82,449.968 2021.83,449.934 2021.84,449.901 2021.85,449.867 2021.86,449.833 2021.87,449.799 2021.88,449.765 2021.89,449.732 2021.9,449.698 2021.9,449.664 2021.91,449.63 2021.92,449.597 2021.93,449.563 2021.94,449.529 2021.95,449.495 2021.96,449.461 2021.97,449.428 2021.98,449.394 2021.99,449.36 2022,449.326 2022.01,449.293 2022.01,449.259 2022.02,449.225 2022.03,449.191 2022.04,449.158 2022.05,449.124 2022.06,449.09 2022.07,449.056 2022.08,449.023 2022.09,448.989 2022.1,448.955 2022.11,448.921 2022.12,448.887 2022.13,448.854 2022.13,448.82 2022.14,448.786 2022.15,448.753 2022.16,448.719 2022.17,448.685 2022.18,448.651 2022.19,448.618 2022.2,448.584 2022.21,448.55 2022.22,448.516 2022.23,448.483 2022.24,448.449 2022.24,448.415 2022.25,448.381 2022.26,448.348 2022.27,448.314 2022.28,448.28 2022.29,448.247 2022.3,448.213 2022.31,448.179 2022.32,448.145 2022.33,448.112 2022.34,448.078 2022.35,448.044 2022.35,448.011 2022.36,447.977 2022.37,447.943 2022.38,447.909 2022.39,447.876 2022.4,447.842 2022.41,447.808 2022.42,447.775 2022.43,447.741 2022.44,447.707 2022.45,447.673 2022.46,447.64 2022.47,447.606 2022.47,447.572 2022.48,447.539 2022.49,447.505 2022.5,447.471 2022.51,447.438 2022.52,447.404 2022.53,447.37 2022.54,447.337 2022.55,447.303 2022.56,447.269 2022.57,447.236 2022.58,447.202 2022.58,447.168 2022.59,447.135 2022.6,447.101 2022.61,447.067 2022.62,447.034 2022.63,447 2022.64,446.966 2022.65,446.933 2022.66,446.899 2022.67,446.865 2022.68,446.832 2022.69,446.798 2022.69,446.764 2022.7,446.731 2022.71,446.697 2022.72,446.663 2022.73,446.63 2022.74,446.596 2022.75,446.562 2022.76,446.529 2022.77,446.495 2022.78,446.461 2022.79,446.428 2022.8,446.394 2022.81,446.361 2022.81,446.327 2022.82,446.293 2022.83,446.26 2022.84,446.226 2022.85,446.192 2022.86,446.159 2022.87,446.125 2022.88,446.092 2022.89,446.058 2022.9,446.024 2022.91,445.991 2022.92,445.957 2022.92,445.923 2022.93,445.89 2022.94,445.856 2022.95,445.823 2022.96,445.789 2022.97,445.755 2022.98,445.722 2022.99,445.688 2023,445.655 2023.01,445.621 2023.02,445.587 2023.03,445.554 2023.03,445.52 2023.04,445.487 2023.05,445.453 2023.06,445.419 2023.07,445.386 2023.08,445.352 2023.09,445.319 2023.1,445.285 2023.11,445.252 2023.12,445.218 2023.13,445.184 2023.14,445.151 2023.15,445.117 2023.15,445.084 2023.16,445.05 2023.17,445.017 2023.18,444.983 2023.19,444.949 2023.2,444.916 2023.21,444.882 2023.22,444.849 2023.23,444.815 2023.24,444.782 2023.25,444.748 2023.26,444.714 2023.26,444.681 2023.27,444.647 2023.28,444.614 2023.29,444.58 2023.3,444.547 2023.31,444.513 2023.32,444.48 2023.33,444.446 2023.34,444.413 2023.35,444.379 2023.36,444.345 2023.37,444.312 2023.37,444.278 2023.38,444.245 2023.39,444.211 2023.4,444.178 2023.41,444.144 2023.42,444.111 2023.43,444.077 2023.44,444.044 2023.45,444.01 2023.46,443.977 2023.47,443.943 2023.48,443.91 2023.49,443.876 2023.49,443.843 2023.5,443.809 2023.51,443.776 2023.52,443.742 2023.53,443.709 2023.54,443.675 2023.55,443.642 2023.56,443.608 2023.57,443.575 2023.58,443.541 2023.59,443.508 2023.6,443.474 2023.6,443.441 2023.61,443.407 2023.62,443.374 2023.63,443.34 2023.64,443.307 2023.65,443.273 2023.66,443.24 2023.67,443.206 2023.68,443.173 2023.69,443.139 2023.7,443.106 2023.71,443.072 2023.71,443.039 2023.72,443.005 2023.73,442.972 2023.74,442.938 2023.75,442.905 2023.76,442.871 2023.77,442.838 2023.78,442.804 2023.79,442.771 2023.8,442.738 2023.81,442.704 2023.82,442.671 2023.83,442.637 2023.83,442.604 2023.84,442.57 2023.85,442.537 2023.86,442.503 2023.87,442.47 2023.88,442.436 2023.89,442.403 2023.9,442.37 2023.91,442.336 2023.92,442.303 2023.93,442.269 2023.94,442.236 2023.94,442.202 2023.95,442.169 2023.96,442.136 2023.97,442.102 2023.98,442.069 2023.99,442.035 2024,442.002 2024.01,441.968 2024.02,441.935 2024.03,441.902 2024.04,441.868 2024.05,441.835 2024.06,441.801 2024.06,441.768 2024.07,441.735 2024.08,441.701 2024.09,441.668 2024.1,441.634 2024.11,441.601 2024.12,441.568 2024.13,441.534 2024.14,441.501 2024.15,441.467 2024.16,441.434 2024.17,441.401 2024.17,441.367 2024.18,441.334 2024.19,441.3 2024.2,441.267 2024.21,441.234 2024.22,441.2 2024.23,441.167 2024.24,441.133 2024.25,441.1 2024.26,441.067 2024.27,441.033 2024.28,441 2024.28,440.967 2024.29,440.933 2024.3,440.9 2024.31,440.866 2024.32,440.833 2024.33,440.8 2024.34,440.766 2024.35,440.733 2024.36,440.7 2024.37,440.666 2024.38,440.633 2024.39,440.6 2024.4,440.566 2024.4,440.533 2024.41,440.5 2024.42,440.466 2024.43,440.433 2024.44,440.4 2024.45,440.366 2024.46,440.333 2024.47,440.3 2024.48,440.266 2024.49,440.233 2024.5,440.2 2024.51,440.166 2024.51,440.133 2024.52,440.1 2024.53,440.066 2024.54,440.033 2024.55,440 2024.56,439.966 2024.57,439.933 2024.58,439.9 2024.59,439.866 2024.6,439.833 2024.61,439.8 2024.62,439.766 2024.62,439.733 2024.63,439.7 2024.64,439.666 2024.65,439.633 2024.66,439.6 2024.67,439.567 2024.68,439.533 2024.69,439.5 2024.7,439.467 2024.71,439.433 2024.72,439.4 2024.73,439.367 2024.74,439.334 2024.74,439.3 2024.75,439.267 2024.76,439.234 2024.77,439.2 2024.78,439.167 2024.79,439.134 2024.8,439.101 2024.81,439.067 2024.82,439.034 2024.83,439.001 2024.84,438.967 2024.85,438.934 2024.85,438.901 2024.86,438.868 2024.87,438.834 2024.88,438.801 2024.89,438.768 2024.9,438.735 2024.91,438.701 2024.92,438.668 2024.93,438.635 2024.94,438.602 2024.95,438.568 2024.96,438.535 2024.96,438.502 2024.97,438.469 2024.98,438.435 2024.99,438.402 2025,438.369 2025.01,438.336 2025.02,438.302 2025.03,438.269 2025.04,438.236 2025.05,438.203 2025.06,438.17 2025.07,438.136 2025.08,438.103 2025.08,438.07 2025.09,438.037 2025.1,438.003 2025.11,437.97 2025.12,437.937 2025.13,437.904 2025.14,437.871 2025.15,437.837 2025.16,437.804 2025.17,437.771 2025.18,437.738 2025.19,437.705 2025.19,437.671 2025.2,437.638 2025.21,437.605 2025.22,437.572 2025.23,437.539 2025.24,437.505 2025.25,437.472 2025.26,437.439 2025.27,437.406 2025.28,437.373 2025.29,437.339 2025.3,437.306 2025.3,437.273 2025.31,437.24 2025.32,437.207 2025.33,437.174 2025.34,437.14 2025.35,437.107 2025.36,437.074 2025.37,437.041 2025.38,437.008 2025.39,436.975 2025.4,436.941 2025.41,436.908 2025.42,436.875 2025.42,436.842 2025.43,436.809 2025.44,436.776 2025.45,436.743 2025.46,436.709 2025.47,436.676 2025.48,436.643 2025.49,436.61 2025.5,436.577 2025.51,436.544 2025.52,436.511 2025.53,436.477 2025.53,436.444 2025.54,436.411 2025.55,436.378 2025.56,436.345 2025.57,436.312 2025.58,436.279 2025.59,436.245 2025.6,436.212 2025.61,436.179 2025.62,436.146 2025.63,436.113 2025.64,436.08 2025.64,436.047 2025.65,436.014 2025.66,435.981 2025.67,435.947 2025.68,435.914 2025.69,435.881 2025.7,435.848 2025.71,435.815 2025.72,435.782 2025.73,435.749 2025.74,435.716 2025.75,435.683 2025.76,435.65 2025.76,435.616 2025.77,435.583 2025.78,435.55 2025.79,435.517 2025.8,435.484 2025.81,435.451 2025.82,435.418 2025.83,435.385 2025.84,435.352 2025.85,435.319 2025.86,435.286 2025.87,435.253 2025.87,435.22 2025.88,435.186 2025.89,435.153 2025.9,435.12 2025.91,435.087 2025.92,435.054 2025.93,435.021 2025.94,434.988 2025.95,434.955 2025.96,434.922 2025.97,434.889 2025.98,434.856 2025.98,434.823 2025.99,434.79 2026,434.757 2026.01,434.724 2026.02,434.691 2026.03,434.658 2026.04,434.625 2026.05,434.592 2026.06,434.559 2026.07,434.526 2026.08,434.492 2026.09,434.459 2026.1,434.426 2026.1,434.393 2026.11,434.36 2026.12,434.327 2026.13,434.294 2026.14,434.261 2026.15,434.228 2026.16,434.195 2026.17,434.162 2026.18,434.129 2026.19,434.096 2026.2,434.063 2026.21,434.03 2026.21,433.997 2026.22,433.964 2026.23,433.931 2026.24,433.898 2026.25,433.865 2026.26,433.832 2026.27,433.799 2026.28,433.766 2026.29,433.733 2026.3,433.7 2026.31,433.667 2026.32,433.634 2026.32,433.601 2026.33,433.568 2026.34,433.535 2026.35,433.502 2026.36,433.47 2026.37,433.437 2026.38,433.404 2026.39,433.371 2026.4,433.338 2026.41,433.305 2026.42,433.272 2026.43,433.239 2026.44,433.206 2026.44,433.173 2026.45,433.14 2026.46,433.107 2026.47,433.074 2026.48,433.041 2026.49,433.008 2026.5,432.975 2026.51,432.942 2026.52,432.909 2026.53,432.876 2026.54,432.843 2026.55,432.81 2026.55,432.778 2026.56,432.745 2026.57,432.712 2026.58,432.679 2026.59,432.646 2026.6,432.613 2026.61,432.58 2026.62,432.547 2026.63,432.514 2026.64,432.481 2026.65,432.448 2026.66,432.415 2026.66,432.383 2026.67,432.35 2026.68,432.317 2026.69,432.284 2026.7,432.251 2026.71,432.218 2026.72,432.185 2026.73,432.152 2026.74,432.119 2026.75,432.086 2026.76,432.054 2026.77,432.021 2026.78,431.988 2026.78,431.955 2026.79,431.922 2026.8,431.889 2026.81,431.856 2026.82,431.823 2026.83,431.79 2026.84,431.758 2026.85,431.725 2026.86,431.692 2026.87,431.659 2026.88,431.626 2026.89,431.593 2026.89,431.56 2026.9,431.527 2026.91,431.495 2026.92,431.462 2026.93,431.429 2026.94,431.396 2026.95,431.363 2026.96,431.33 2026.97,431.298 2026.98,431.265 2026.99,431.232 2027,431.199 2027,431.166 2027.01,431.133 2027.02,431.1 2027.03,431.068 2027.04,431.035 2027.05,431.002 2027.06,430.969 2027.07,430.936 2027.08,430.903 2027.09,430.871 2027.1,430.838 2027.11,430.805 2027.12,430.772 2027.12,430.739 2027.13,430.707 2027.14,430.674 2027.15,430.641 2027.16,430.608 2027.17,430.575 2027.18,430.542 2027.19,430.51 2027.2,430.477 2027.21,430.444 2027.22,430.411 2027.23,430.378 2027.23,430.346 2027.24,430.313 2027.25,430.28 2027.26,430.247 2027.27,430.215 2027.28,430.182 2027.29,430.149 2027.3,430.116 2027.31,430.083 2027.32,430.051 2027.33,430.018 2027.34,429.985 2027.34,429.952 2027.35,429.92 2027.36,429.887 2027.37,429.854 2027.38,429.821 2027.39,429.788 2027.4,429.756 2027.41,429.723 2027.42,429.69 2027.43,429.657 2027.44,429.625 2027.45,429.592 2027.46,429.559 2027.46,429.526 2027.47,429.494 2027.48,429.461 2027.49,429.428 2027.5,429.395 2027.51,429.363 2027.52,429.33 2027.53,429.297 2027.54,429.265 2027.55,429.232 2027.56,429.199 2027.57,429.166 2027.57,429.134 2027.58,429.101 2027.59,429.068 2027.6,429.035 2027.61,429.003 2027.62,428.97 2027.63,428.937 2027.64,428.905 2027.65,428.872 2027.66,428.839 2027.67,428.807 2027.68,428.774 2027.68,428.741 2027.69,428.708 2027.7,428.676 2027.71,428.643 2027.72,428.61 2027.73,428.578 2027.74,428.545 2027.75,428.512 2027.76,428.48 2027.77,428.447 2027.78,428.414 2027.79,428.382 2027.8,428.349 2027.8,428.316 2027.81,428.283 2027.82,428.251 2027.83,428.218 2027.84,428.185 2027.85,428.153 2027.86,428.12 2027.87,428.087 2027.88,428.055 2027.89,428.022 2027.9,427.989 2027.91,427.957 2027.91,427.924 2027.92,427.892 2027.93,427.859 2027.94,427.826 2027.95,427.794 2027.96,427.761 2027.97,427.728 2027.98,427.696 2027.99,427.663 2028,427.63 2028.01,427.598 2028.02,427.565 2028.02,427.533 2028.03,427.5 2028.04,427.467 2028.05,427.435 2028.06,427.402 2028.07,427.369 2028.08,427.337 2028.09,427.304 2028.1,427.272 2028.11,427.239 2028.12,427.206 2028.13,427.174 2028.14,427.141 2028.14,427.108 2028.15,427.076 2028.16,427.043 2028.17,427.011 2028.18,426.978 2028.19,426.945 2028.2,426.913 2028.21,426.88 2028.22,426.848 2028.23,426.815 2028.24,426.783 2028.25,426.75 2028.25,426.717 2028.26,426.685 2028.27,426.652 2028.28,426.62 2028.29,426.587 2028.3,426.555 2028.31,426.522 2028.32,426.489 2028.33,426.457 2028.34,426.424 2028.35,426.392 2028.36,426.359 2028.36,426.327 2028.37,426.294 2028.38,426.261 2028.39,426.229 2028.4,426.196 2028.41,426.164 2028.42,426.131 2028.43,426.099 2028.44,426.066 2028.45,426.034 2028.46,426.001 2028.47,425.969 2028.48,425.936 2028.48,425.903 2028.49,425.871 2028.5,425.838 2028.51,425.806 2028.52,425.773 2028.53,425.741 2028.54,425.708 2028.55,425.676 2028.56,425.643 2028.57,425.611 2028.58,425.578 2028.59,425.546 2028.59,425.513 2028.6,425.481 2028.61,425.448 2028.62,425.416 2028.63,425.383 2028.64,425.351 2028.65,425.318 2028.66,425.286 2028.67,425.253 2028.68,425.221 2028.69,425.188 2028.7,425.156 2028.7,425.123 2028.71,425.091 2028.72,425.058 2028.73,425.026 2028.74,424.993 2028.75,424.961 2028.76,424.928 2028.77,424.896 2028.78,424.863 2028.79,424.831 2028.8,424.799 2028.81,424.766 2028.82,424.734 2028.82,424.701 2028.83,424.669 2028.84,424.636 2028.85,424.604 2028.86,424.571 2028.87,424.539 2028.88,424.506 2028.89,424.474 2028.9,424.442 2028.91,424.409 2028.92,424.377 2028.93,424.344 2028.93,424.312 2028.94,424.279 2028.95,424.247 2028.96,424.215 2028.97,424.182 2028.98,424.15 2028.99,424.117 2029,424.085 2029.01,424.052 2029.02,424.02 2029.03,423.988 2029.04,423.955 2029.04,423.923 2029.05,423.89 2029.06,423.858 2029.07,423.826 2029.08,423.793 2029.09,423.761 2029.1,423.728 2029.11,423.696 2029.12,423.664 2029.13,423.631 2029.14,423.599 2029.15,423.566 2029.16,423.534 2029.16,423.502 2029.17,423.469 2029.18,423.437 2029.19,423.404 2029.2,423.372 2029.21,423.34 2029.22,423.307 2029.23,423.275 2029.24,423.243 2029.25,423.21 2029.26,423.178 2029.27,423.145 2029.27,423.113 2029.28,423.081 2029.29,423.048 2029.3,423.016 2029.31,422.984 2029.32,422.951 2029.33,422.919 2029.34,422.887 2029.35,422.854 2029.36,422.822 2029.37,422.79 2029.38,422.757 2029.38,422.725 2029.39,422.693 2029.4,422.66 2029.41,422.628 2029.42,422.596 2029.43,422.563 2029.44,422.531 2029.45,422.499 2029.46,422.466 2029.47,422.434 2029.48,422.402 2029.49,422.369 2029.5,422.337 2029.5,422.305 2029.51,422.272 2029.52,422.24 2029.53,422.208 2029.54,422.175 2029.55,422.143 2029.56,422.111 2029.57,422.079 2029.58,422.046 2029.59,422.014 2029.6,421.982 2029.61,421.949 2029.61,421.917 2029.62,421.885 2029.63,421.853 2029.64,421.82 2029.65,421.788 2029.66,421.756 2029.67,421.723 2029.68,421.691 2029.69,421.659 2029.7,421.627 2029.71,421.594 2029.72,421.562 2029.72,421.53 2029.73,421.498 2029.74,421.465 2029.75,421.433 2029.76,421.401 2029.77,421.369 2029.78,421.336 2029.79,421.304 2029.8,421.272 2029.81,421.24 2029.82,421.207 2029.83,421.175 2029.84,421.143 2029.84,421.111 2029.85,421.078 2029.86,421.046 2029.87,421.014 2029.88,420.982 2029.89,420.949 2029.9,420.917 2029.91,420.885 2029.92,420.853 2029.93,420.821 2029.94,420.788 2029.95,420.756 2029.95,420.724 2029.96,420.692 2029.97,420.659 2029.98,420.627 2029.99,420.595 2030,420.563 2030.01,420.531 2030.02,420.498 2030.03,420.466 2030.04,420.434 2030.05,420.402 2030.06,420.37 2030.06,420.338 2030.07,420.305 2030.08,420.273 2030.09,420.241 2030.1,420.209 2030.11,420.177 2030.12,420.144 2030.13,420.112 2030.14,420.08 2030.15,420.048 2030.16,420.016 2030.17,419.984 2030.18,419.951 2030.18,419.919 2030.19,419.887 2030.2,419.855 2030.21,419.823 2030.22,419.791 2030.23,419.758 2030.24,419.726 2030.25,419.694 2030.26,419.662 2030.27,419.63 2030.28,419.598 2030.29,419.566 2030.29,419.533 2030.3,419.501 2030.31,419.469 2030.32,419.437 2030.33,419.405 2030.34,419.373 2030.35,419.341 2030.36,419.309 2030.37,419.276 2030.38,419.244 2030.39,419.212 2030.4,419.18 2030.4,419.148 2030.41,419.116 2030.42,419.084 2030.43,419.052 2030.44,419.02 2030.45,418.987 2030.46,418.955 2030.47,418.923 2030.48,418.891 2030.49,418.859 2030.5,418.827 2030.51,418.795 2030.52,418.763 2030.52,418.731 2030.53,418.699 2030.54,418.667 2030.55,418.634 2030.56,418.602 2030.57,418.57 2030.58,418.538 2030.59,418.506 2030.6,418.474 2030.61,418.442 2030.62,418.41 2030.63,418.378 2030.63,418.346 2030.64,418.314 2030.65,418.282 2030.66,418.25 2030.67,418.218 2030.68,418.186 2030.69,418.154 2030.7,418.122 2030.71,418.089 2030.72,418.057 2030.73,418.025 2030.74,417.993 2030.74,417.961 2030.75,417.929 2030.76,417.897 2030.77,417.865 2030.78,417.833 2030.79,417.801 2030.8,417.769 2030.81,417.737 2030.82,417.705 2030.83,417.673 2030.84,417.641 2030.85,417.609 2030.86,417.577 2030.86,417.545 2030.87,417.513 2030.88,417.481 2030.89,417.449 2030.9,417.417 2030.91,417.385 2030.92,417.353 2030.93,417.321 2030.94,417.289 2030.95,417.257 2030.96,417.225 2030.97,417.193 2030.97,417.161 2030.98,417.129 2030.99,417.097 2031,417.065 2031.01,417.033 2031.02,417.001 2031.03,416.969 2031.04,416.937 2031.05,416.905 2031.06,416.873 2031.07,416.841 2031.08,416.809 2031.08,416.777 2031.09,416.746 2031.1,416.714 2031.11,416.682 2031.12,416.65 2031.13,416.618 2031.14,416.586 2031.15,416.554 2031.16,416.522 2031.17,416.49 2031.18,416.458 2031.19,416.426 2031.2,416.394 2031.2,416.362 2031.21,416.33 2031.22,416.298 2031.23,416.266 2031.24,416.235 2031.25,416.203 2031.26,416.171 2031.27,416.139 2031.28,416.107 2031.29,416.075 2031.3,416.043 2031.31,416.011 2031.31,415.979 2031.32,415.947 2031.33,415.915 2031.34,415.883 2031.35,415.852 2031.36,415.82 2031.37,415.788 2031.38,415.756 2031.39,415.724 2031.4,415.692 2031.41,415.66 2031.42,415.628 2031.42,415.596 2031.43,415.565 2031.44,415.533 2031.45,415.501 2031.46,415.469 2031.47,415.437 2031.48,415.405 2031.49,415.373 2031.5,415.342 2031.51,415.31 2031.52,415.278 2031.53,415.246 2031.54,415.214 2031.54,415.182 2031.55,415.15 2031.56,415.119 2031.57,415.087 2031.58,415.055 2031.59,415.023 2031.6,414.991 2031.61,414.959 2031.62,414.927 2031.63,414.896 2031.64,414.864 2031.65,414.832 2031.65,414.8 2031.66,414.768 2031.67,414.737 2031.68,414.705 2031.69,414.673 2031.7,414.641 2031.71,414.609 2031.72,414.577 2031.73,414.546 2031.74,414.514 2031.75,414.482 2031.76,414.45 2031.76,414.418 2031.77,414.387 2031.78,414.355 2031.79,414.323 2031.8,414.291 2031.81,414.259 2031.82,414.228 2031.83,414.196 2031.84,414.164 2031.85,414.132 2031.86,414.1 2031.87,414.069 2031.88,414.037 2031.88,414.005 2031.89,413.973 2031.9,413.942 2031.91,413.91 2031.92,413.878 2031.93,413.846 2031.94,413.815 2031.95,413.783 2031.96,413.751 2031.97,413.719 2031.98,413.688 2031.99,413.656 2031.99,413.624 2032,413.592 2032.01,413.561 2032.02,413.529 2032.03,413.497 2032.04,413.465 2032.05,413.434 2032.06,413.402 2032.07,413.37 2032.08,413.338 2032.09,413.307 2032.1,413.275 2032.1,413.243 2032.11,413.211 2032.12,413.18 2032.13,413.148 2032.14,413.116 2032.15,413.085 2032.16,413.053 2032.17,413.021 2032.18,412.989 2032.19,412.958 2032.2,412.926 2032.21,412.894 2032.22,412.863 2032.22,412.831 2032.23,412.799 2032.24,412.768 2032.25,412.736 2032.26,412.704 2032.27,412.673 2032.28,412.641 2032.29,412.609 2032.3,412.578 2032.31,412.546 2032.32,412.514 2032.33,412.482 2032.33,412.451 2032.34,412.419 2032.35,412.387 2032.36,412.356 2032.37,412.324 2032.38,412.293 2032.39,412.261 2032.4,412.229 2032.41,412.198 2032.42,412.166 2032.43,412.134 2032.44,412.103 2032.44,412.071 2032.45,412.039 2032.46,412.008 2032.47,411.976 2032.48,411.944 2032.49,411.913 2032.5,411.881 2032.51,411.849 2032.52,411.818 2032.53,411.786 2032.54,411.755 2032.55,411.723 2032.56,411.691 2032.56,411.66 2032.57,411.628 2032.58,411.597 2032.59,411.565 2032.6,411.533 2032.61,411.502 2032.62,411.47 2032.63,411.439 2032.64,411.407 2032.65,411.375 2032.66,411.344 2032.67,411.312 2032.67,411.281 2032.68,411.249 2032.69,411.217 2032.7,411.186 2032.71,411.154 2032.72,411.123 2032.73,411.091 2032.74,411.059 2032.75,411.028 2032.76,410.996 2032.77,410.965 2032.78,410.933 2032.78,410.902 2032.79,410.87 2032.8,410.839 2032.81,410.807 2032.82,410.775 2032.83,410.744 2032.84,410.712 2032.85,410.681 2032.86,410.649 2032.87,410.618 2032.88,410.586 2032.89,410.555 2032.9,410.523 2032.9,410.491 2032.91,410.46 2032.92,410.428 2032.93,410.397 2032.94,410.365 2032.95,410.334 2032.96,410.302 2032.97,410.271 2032.98,410.239 2032.99,410.208 2033,410.176 2033.01,410.145 2033.01,410.113 2033.02,410.082 2033.03,410.05 2033.04,410.019 2033.05,409.987 2033.06,409.956 2033.07,409.924 2033.08,409.893 2033.09,409.861 2033.1,409.83 2033.11,409.798 2033.12,409.767 2033.12,409.735 2033.13,409.704 2033.14,409.672 2033.15,409.641 2033.16,409.609 2033.17,409.578 2033.18,409.546 2033.19,409.515 2033.2,409.483 2033.21,409.452 2033.22,409.421 2033.23,409.389 2033.24,409.358 2033.24,409.326 2033.25,409.295 2033.26,409.263 2033.27,409.232 2033.28,409.2 2033.29,409.169 2033.3,409.137 2033.31,409.106 2033.32,409.075 2033.33,409.043 2033.34,409.012 2033.35,408.98 2033.35,408.949 2033.36,408.917 2033.37,408.886 2033.38,408.855 2033.39,408.823 2033.4,408.792 2033.41,408.76 2033.42,408.729 2033.43,408.698 2033.44,408.666 2033.45,408.635 2033.46,408.603 2033.46,408.572 2033.47,408.54 2033.48,408.509 2033.49,408.478 2033.5,408.446 2033.51,408.415 2033.52,408.384 2033.53,408.352 2033.54,408.321 2033.55,408.289 2033.56,408.258 2033.57,408.227 2033.58,408.195 2033.58,408.164 2033.59,408.132 2033.6,408.101 2033.61,408.07 2033.62,408.038 2033.63,408.007 2033.64,407.976 2033.65,407.944 2033.66,407.913 2033.67,407.882 2033.68,407.85 2033.69,407.819 2033.69,407.788 2033.7,407.756 2033.71,407.725 2033.72,407.693 2033.73,407.662 2033.74,407.631 2033.75,407.599 2033.76,407.568 2033.77,407.537 2033.78,407.505 2033.79,407.474 2033.8,407.443 2033.8,407.412 2033.81,407.38 2033.82,407.349 2033.83,407.318 2033.84,407.286 2033.85,407.255 2033.86,407.224 2033.87,407.192 2033.88,407.161 2033.89,407.13 2033.9,407.098 2033.91,407.067 2033.92,407.036 2033.92,407.005 2033.93,406.973 2033.94,406.942 2033.95,406.911 2033.96,406.879 2033.97,406.848 2033.98,406.817 2033.99,406.786 2034,406.754 2034.01,406.723 2034.02,406.692 2034.03,406.66 2034.03,406.629 2034.04,406.598 2034.05,406.567 2034.06,406.535 2034.07,406.504 2034.08,406.473 2034.09,406.442 2034.1,406.41 2034.11,406.379 2034.12,406.348 2034.13,406.317 2034.14,406.285 2034.14,406.254 2034.15,406.223 2034.16,406.192 2034.17,406.16 2034.18,406.129 2034.19,406.098 2034.2,406.067 2034.21,406.036 2034.22,406.004 2034.23,405.973 2034.24,405.942 2034.25,405.911 2034.26,405.879 2034.26,405.848 2034.27,405.817 2034.28,405.786 2034.29,405.755 2034.3,405.723 2034.31,405.692 2034.32,405.661 2034.33,405.63 2034.34,405.599 2034.35,405.567 2034.36,405.536 2034.37,405.505 2034.37,405.474 2034.38,405.443 2034.39,405.412 2034.4,405.38 2034.41,405.349 2034.42,405.318 2034.43,405.287 2034.44,405.256 2034.45,405.224 2034.46,405.193 2034.47,405.162 2034.48,405.131 2034.48,405.1 2034.49,405.069 2034.5,405.038 2034.51,405.006 2034.52,404.975 2034.53,404.944 2034.54,404.913 2034.55,404.882 2034.56,404.851 2034.57,404.82 2034.58,404.788 2034.59,404.757 2034.6,404.726 2034.6,404.695 2034.61,404.664 2034.62,404.633 2034.63,404.602 2034.64,404.57 2034.65,404.539 2034.66,404.508 2034.67,404.477 2034.68,404.446 2034.69,404.415 2034.7,404.384 2034.71,404.353 2034.71,404.322 2034.72,404.291 2034.73,404.259 2034.74,404.228 2034.75,404.197 2034.76,404.166 2034.77,404.135 2034.78,404.104 2034.79,404.073 2034.8,404.042 2034.81,404.011 2034.82,403.98 2034.82,403.949 2034.83,403.917 2034.84,403.886 2034.85,403.855 2034.86,403.824 2034.87,403.793 2034.88,403.762 2034.89,403.731 2034.9,403.7 2034.91,403.669 2034.92,403.638 2034.93,403.607 2034.94,403.576 2034.94,403.545 2034.95,403.514 2034.96,403.483 2034.97,403.452 2034.98,403.421 2034.99,403.39 2035,403.359 2035.01,403.328 2035.02,403.296 2035.03,403.265 2035.04,403.234 2035.05,403.203 2035.05,403.172 2035.06,403.141 2035.07,403.11 2035.08,403.079 2035.09,403.048 2035.1,403.017 2035.11,402.986 2035.12,402.955 2035.13,402.924 2035.14,402.893 2035.15,402.862 2035.16,402.831 2035.16,402.8 2035.17,402.769 2035.18,402.738 2035.19,402.707 2035.2,402.676 2035.21,402.645 2035.22,402.614 2035.23,402.583 2035.24,402.552 2035.25,402.522 2035.26,402.491 2035.27,402.46 2035.28,402.429 2035.28,402.398 2035.29,402.367 2035.3,402.336 2035.31,402.305 2035.32,402.274 2035.33,402.243 2035.34,402.212 2035.35,402.181 2035.36,402.15 2035.37,402.119 2035.38,402.088 2035.39,402.057 2035.39,402.026 2035.4,401.995 2035.41,401.964 2035.42,401.933 2035.43,401.903 2035.44,401.872 2035.45,401.841 2035.46,401.81 2035.47,401.779 2035.48,401.748 2035.49,401.717 2035.5,401.686 2035.5,401.655 2035.51,401.624 2035.52,401.593 2035.53,401.562 2035.54,401.532 2035.55,401.501 2035.56,401.47 2035.57,401.439 2035.58,401.408 2035.59,401.377 2035.6,401.346 2035.61,401.315 2035.62,401.284 2035.62,401.254 2035.63,401.223 2035.64,401.192 2035.65,401.161 2035.66,401.13 2035.67,401.099 2035.68,401.068 2035.69,401.037 2035.7,401.007 2035.71,400.976 2035.72,400.945 2035.73,400.914 2035.73,400.883 2035.74,400.852 2035.75,400.822 2035.76,400.791 2035.77,400.76 2035.78,400.729 2035.79,400.698 2035.8,400.667 2035.81,400.636 2035.82,400.606 2035.83,400.575 2035.84,400.544 2035.84,400.513 2035.85,400.482 2035.86,400.452 2035.87,400.421 2035.88,400.39 2035.89,400.359 2035.9,400.328 2035.91,400.297 2035.92,400.267 2035.93,400.236 2035.94,400.205 2035.95,400.174 2035.96,400.143 2035.96,400.113 2035.97,400.082 2035.98,400.051 2035.99,400.02 2036,399.989 2036.01,399.959 2036.02,399.928 2036.03,399.897 2036.04,399.866 2036.05,399.836 2036.06,399.805 2036.07,399.774 2036.07,399.743 2036.08,399.713 2036.09,399.682 2036.1,399.651 2036.11,399.62 2036.12,399.589 2036.13,399.559 2036.14,399.528 2036.15,399.497 2036.16,399.466 2036.17,399.436 2036.18,399.405 2036.18,399.374 2036.19,399.343 2036.2,399.313 2036.21,399.282 2036.22,399.251 2036.23,399.221 2036.24,399.19 2036.25,399.159 2036.26,399.128 2036.27,399.098 2036.28,399.067 2036.29,399.036 2036.3,399.006 2036.3,398.975 2036.31,398.944 2036.32,398.913 2036.33,398.883 2036.34,398.852 2036.35,398.821 2036.36,398.791 2036.37,398.76 2036.38,398.729 2036.39,398.699 2036.4,398.668 2036.41,398.637 2036.41,398.606 2036.42,398.576 2036.43,398.545 2036.44,398.514 2036.45,398.484 2036.46,398.453 2036.47,398.422 2036.48,398.392 2036.49,398.361 2036.5,398.33 2036.51,398.3 2036.52,398.269 2036.52,398.238 2036.53,398.208 2036.54,398.177 2036.55,398.146 2036.56,398.116 2036.57,398.085 2036.58,398.055 2036.59,398.024 2036.6,397.993 2036.61,397.963 2036.62,397.932 2036.63,397.901 2036.64,397.871 2036.64,397.84 2036.65,397.809 2036.66,397.779 2036.67,397.748 2036.68,397.718 2036.69,397.687 2036.7,397.656 2036.71,397.626 2036.72,397.595 2036.73,397.565 2036.74,397.534 2036.75,397.503 2036.75,397.473 2036.76,397.442 2036.77,397.412 2036.78,397.381 2036.79,397.35 2036.8,397.32 2036.81,397.289 2036.82,397.259 2036.83,397.228 2036.84,397.197 2036.85,397.167 2036.86,397.136 2036.86,397.106 2036.87,397.075 2036.88,397.045 2036.89,397.014 2036.9,396.983 2036.91,396.953 2036.92,396.922 2036.93,396.892 2036.94,396.861 2036.95,396.831 2036.96,396.8 2036.97,396.77 2036.98,396.739 2036.98,396.709 2036.99,396.678 2037,396.647 2037.01,396.617 2037.02,396.586 2037.03,396.556 2037.04,396.525 2037.05,396.495 2037.06,396.464 2037.07,396.434 2037.08,396.403 2037.09,396.373 2037.09,396.342 2037.1,396.312 2037.11,396.281 2037.12,396.251 2037.13,396.22 2037.14,396.19 2037.15,396.159 2037.16,396.129 2037.17,396.098 2037.18,396.068 2037.19,396.037 2037.2,396.007 2037.2,395.976 2037.21,395.946 2037.22,395.915 2037.23,395.885 2037.24,395.854 2037.25,395.824 2037.26,395.793 2037.27,395.763 2037.28,395.732 2037.29,395.702 2037.3,395.671 2037.31,395.641 2037.32,395.611 2037.32,395.58 2037.33,395.55 2037.34,395.519 2037.35,395.489 2037.36,395.458 2037.37,395.428 2037.38,395.397 2037.39,395.367 2037.4,395.337 2037.41,395.306 2037.42,395.276 2037.43,395.245 2037.43,395.215 2037.44,395.184 2037.45,395.154 2037.46,395.124 2037.47,395.093 2037.48,395.063 2037.49,395.032 2037.5,395.002 2037.51,394.971 2037.52,394.941 2037.53,394.911 2037.54,394.88 2037.54,394.85 2037.55,394.819 2037.56,394.789 2037.57,394.759 2037.58,394.728 2037.59,394.698 2037.6,394.668 2037.61,394.637 2037.62,394.607 2037.63,394.576 2037.64,394.546 2037.65,394.516 2037.66,394.485 2037.66,394.455 2037.67,394.425 2037.68,394.394 2037.69,394.364 2037.7,394.333 2037.71,394.303 2037.72,394.273 2037.73,394.242 2037.74,394.212 2037.75,394.182 2037.76,394.151 2037.77,394.121 2037.77,394.091 2037.78,394.06 2037.79,394.03 2037.8,394 2037.81,393.969 2037.82,393.939 2037.83,393.909 2037.84,393.878 2037.85,393.848 2037.86,393.818 2037.87,393.787 2037.88,393.757 2037.88,393.727 2037.89,393.696 2037.9,393.666 2037.91,393.636 2037.92,393.605 2037.93,393.575 2037.94,393.545 2037.95,393.515 2037.96,393.484 2037.97,393.454 2037.98,393.424 2037.99,393.393 2038,393.363 2038,393.333 2038.01,393.303 2038.02,393.272 2038.03,393.242 2038.04,393.212 2038.05,393.181 2038.06,393.151 2038.07,393.121 2038.08,393.091 2038.09,393.06 2038.1,393.03 2038.11,393 2038.11,392.97 2038.12,392.939 2038.13,392.909 2038.14,392.879 2038.15,392.849 2038.16,392.818 2038.17,392.788 2038.18,392.758 2038.19,392.728 2038.2,392.697 2038.21,392.667 2038.22,392.637 2038.22,392.607 2038.23,392.576 2038.24,392.546 2038.25,392.516 2038.26,392.486 2038.27,392.456 2038.28,392.425 2038.29,392.395 2038.3,392.365 2038.31,392.335 2038.32,392.305 2038.33,392.274 2038.34,392.244 2038.34,392.214 2038.35,392.184 2038.36,392.154 2038.37,392.123 2038.38,392.093 2038.39,392.063 2038.4,392.033 2038.41,392.003 2038.42,391.972 2038.43,391.942 2038.44,391.912 2038.45,391.882 2038.45,391.852 2038.46,391.822 2038.47,391.791 2038.48,391.761 2038.49,391.731 2038.5,391.701 2038.51,391.671 2038.52,391.641 2038.53,391.61 2038.54,391.58 2038.55,391.55 2038.56,391.52 2038.56,391.49 2038.57,391.46 2038.58,391.43 2038.59,391.399 2038.6,391.369 2038.61,391.339 2038.62,391.309 2038.63,391.279 2038.64,391.249 2038.65,391.219 2038.66,391.189 2038.67,391.158 2038.68,391.128 2038.68,391.098 2038.69,391.068 2038.7,391.038 2038.71,391.008 2038.72,390.978 2038.73,390.948 2038.74,390.918 2038.75,390.888 2038.76,390.857 2038.77,390.827 2038.78,390.797 2038.79,390.767 2038.79,390.737 2038.8,390.707 2038.81,390.677 2038.82,390.647 2038.83,390.617 2038.84,390.587 2038.85,390.557 2038.86,390.527 2038.87,390.497 2038.88,390.466 2038.89,390.436 2038.9,390.406 2038.9,390.376 2038.91,390.346 2038.92,390.316 2038.93,390.286 2038.94,390.256 2038.95,390.226 2038.96,390.196 2038.97,390.166 2038.98,390.136 2038.99,390.106 2039,390.076 2039.01,390.046 2039.02,390.016 2039.02,389.986 2039.03,389.956 2039.04,389.926 2039.05,389.896 2039.06,389.866 2039.07,389.836 2039.08,389.806 2039.09,389.776 2039.1,389.746 2039.11,389.716 2039.12,389.686 2039.13,389.656 2039.13,389.626 2039.14,389.596 2039.15,389.566 2039.16,389.536 2039.17,389.506 2039.18,389.476 2039.19,389.446 2039.2,389.416 2039.21,389.386 2039.22,389.356 2039.23,389.326 2039.24,389.296 2039.24,389.266 2039.25,389.236 2039.26,389.206 2039.27,389.176 2039.28,389.146 2039.29,389.116 2039.3,389.086 2039.31,389.056 2039.32,389.026 2039.33,388.996 2039.34,388.966 2039.35,388.936 2039.36,388.906 2039.36,388.877 2039.37,388.847 2039.38,388.817 2039.39,388.787 2039.4,388.757 2039.41,388.727 2039.42,388.697 2039.43,388.667 2039.44,388.637 2039.45,388.607 2039.46,388.577 2039.47,388.547 2039.47,388.517 2039.48,388.488 2039.49,388.458 2039.5,388.428 2039.51,388.398 2039.52,388.368 2039.53,388.338 2039.54,388.308 2039.55,388.278 2039.56,388.248 2039.57,388.219 2039.58,388.189 2039.58,388.159 2039.59,388.129 2039.6,388.099 2039.61,388.069 2039.62,388.039 2039.63,388.009 2039.64,387.98 2039.65,387.95 2039.66,387.92 2039.67,387.89 2039.68,387.86 2039.69,387.83 2039.7,387.8 2039.7,387.771 2039.71,387.741 2039.72,387.711 2039.73,387.681 2039.74,387.651 2039.75,387.621 2039.76,387.591 2039.77,387.562 2039.78,387.532 2039.79,387.502 2039.8,387.472 2039.81,387.442 2039.81,387.413 2039.82,387.383 2039.83,387.353 2039.84,387.323 2039.85,387.293 2039.86,387.263 2039.87,387.234 2039.88,387.204 2039.89,387.174 2039.9,387.144 2039.91,387.114 2039.92,387.085 2039.92,387.055 2039.93,387.025 2039.94,386.995 2039.95,386.965 2039.96,386.936 2039.97,386.906 2039.98,386.876 2039.99,386.846 2040,386.817 2040.01,386.787 2040.02,386.757 2040.03,386.727 2040.04,386.698 2040.04,386.668 2040.05,386.638 2040.06,386.608 2040.07,386.578 2040.08,386.549 2040.09,386.519 2040.1,386.489 2040.11,386.459 2040.12,386.43 2040.13,386.4 2040.14,386.37 2040.15,386.341 2040.15,386.311 2040.16,386.281 2040.17,386.251 2040.18,386.222 2040.19,386.192 2040.2,386.162 2040.21,386.132 2040.22,386.103 2040.23,386.073 2040.24,386.043 2040.25,386.014 2040.26,385.984 2040.26,385.954 2040.27,385.924 2040.28,385.895 2040.29,385.865 2040.3,385.835 2040.31,385.806 2040.32,385.776 2040.33,385.746 2040.34,385.717 2040.35,385.687 2040.36,385.657 2040.37,385.628 2040.38,385.598 2040.38,385.568 2040.39,385.539 2040.4,385.509 2040.41,385.479 2040.42,385.45 2040.43,385.42 2040.44,385.39 2040.45,385.361 2040.46,385.331 2040.47,385.301 2040.48,385.272 2040.49,385.242 2040.49,385.212 2040.5,385.183 2040.51,385.153 2040.52,385.123 2040.53,385.094 2040.54,385.064 2040.55,385.035 2040.56,385.005 2040.57,384.975 2040.58,384.946 2040.59,384.916 2040.6,384.886 2040.6,384.857 2040.61,384.827 2040.62,384.798 2040.63,384.768 2040.64,384.738 2040.65,384.709 2040.66,384.679 2040.67,384.65 2040.68,384.62 2040.69,384.59 2040.7,384.561 2040.71,384.531 2040.72,384.502 2040.72,384.472 2040.73,384.442 2040.74,384.413 2040.75,384.383 2040.76,384.354 2040.77,384.324 2040.78,384.295 2040.79,384.265 2040.8,384.235 2040.81,384.206 2040.82,384.176 2040.83,384.147 2040.83,384.117 2040.84,384.088 2040.85,384.058 2040.86,384.028 2040.87,383.999 2040.88,383.969 2040.89,383.94 2040.9,383.91 2040.91,383.881 2040.92,383.851 2040.93,383.822 2040.94,383.792 2040.94,383.763 2040.95,383.733 2040.96,383.704 2040.97,383.674 2040.98,383.645 2040.99,383.615 2041,383.586 2041.01,383.556 2041.02,383.526 2041.03,383.497 2041.04,383.467 2041.05,383.438 2041.06,383.408 2041.06,383.379 2041.07,383.349 2041.08,383.32 2041.09,383.29 2041.1,383.261 2041.11,383.232 2041.12,383.202 2041.13,383.173 2041.14,383.143 2041.15,383.114 2041.16,383.084 2041.17,383.055 2041.17,383.025 2041.18,382.996 2041.19,382.966 2041.2,382.937 2041.21,382.907 2041.22,382.878 2041.23,382.848 2041.24,382.819 2041.25,382.79 2041.26,382.76 2041.27,382.731 2041.28,382.701 2041.28,382.672 2041.29,382.642 2041.3,382.613 2041.31,382.583 2041.32,382.554 2041.33,382.525 2041.34,382.495 2041.35,382.466 2041.36,382.436 2041.37,382.407 2041.38,382.377 2041.39,382.348 2041.4,382.319 2041.4,382.289 2041.41,382.26 2041.42,382.23 2041.43,382.201 2041.44,382.172 2041.45,382.142 2041.46,382.113 2041.47,382.083 2041.48,382.054 2041.49,382.025 2041.5,381.995 2041.51,381.966 2041.51,381.937 2041.52,381.907 2041.53,381.878 2041.54,381.848 2041.55,381.819 2041.56,381.79 2041.57,381.76 2041.58,381.731 2041.59,381.702 2041.6,381.672 2041.61,381.643 2041.62,381.614 2041.62,381.584 2041.63,381.555 2041.64,381.525 2041.65,381.496 2041.66,381.467 2041.67,381.437 2041.68,381.408 2041.69,381.379 2041.7,381.349 2041.71,381.32 2041.72,381.291 2041.73,381.261 2041.74,381.232 2041.74,381.203 2041.75,381.174 2041.76,381.144 2041.77,381.115 2041.78,381.086 2041.79,381.056 2041.8,381.027 2041.81,380.998 2041.82,380.968 2041.83,380.939 2041.84,380.91 2041.85,380.88 2041.85,380.851 2041.86,380.822 2041.87,380.793 2041.88,380.763 2041.89,380.734 2041.9,380.705 2041.91,380.675 2041.92,380.646 2041.93,380.617 2041.94,380.588 2041.95,380.558 2041.96,380.529 2041.96,380.5 2041.97,380.471 2041.98,380.441 2041.99,380.412 2042,380.383 2042.01,380.354 2042.02,380.324 2042.03,380.295 2042.04,380.266 2042.05,380.237 2042.06,380.207 2042.07,380.178 2042.08,380.149 2042.08,380.12 2042.09,380.09 2042.1,380.061 2042.11,380.032 2042.12,380.003 2042.13,379.974 2042.14,379.944 2042.15,379.915 2042.16,379.886 2042.17,379.857 2042.18,379.828 2042.19,379.798 2042.19,379.769 2042.2,379.74 2042.21,379.711 2042.22,379.682 2042.23,379.652 2042.24,379.623 2042.25,379.594 2042.26,379.565 2042.27,379.536 2042.28,379.506 2042.29,379.477 2042.3,379.448 2042.3,379.419 2042.31,379.39 2042.32,379.361 2042.33,379.331 2042.34,379.302 2042.35,379.273 2042.36,379.244 2042.37,379.215 2042.38,379.186 2042.39,379.156 2042.4,379.127 2042.41,379.098 2042.42,379.069 2042.42,379.04 2042.43,379.011 2042.44,378.982 2042.45,378.952 2042.46,378.923 2042.47,378.894 2042.48,378.865 2042.49,378.836 2042.5,378.807 2042.51,378.778 2042.52,378.749 2042.53,378.719 2042.53,378.69 2042.54,378.661 2042.55,378.632 2042.56,378.603 2042.57,378.574 2042.58,378.545 2042.59,378.516 2042.6,378.487 2042.61,378.458 2042.62,378.428 2042.63,378.399 2042.64,378.37 2042.64,378.341 2042.65,378.312 2042.66,378.283 2042.67,378.254 2042.68,378.225 2042.69,378.196 2042.7,378.167 2042.71,378.138 2042.72,378.109 2042.73,378.08 2042.74,378.05 2042.75,378.021 2042.76,377.992 2042.76,377.963 2042.77,377.934 2042.78,377.905 2042.79,377.876 2042.8,377.847 2042.81,377.818 2042.82,377.789 2042.83,377.76 2042.84,377.731 2042.85,377.702 2042.86,377.673 2042.87,377.644 2042.87,377.615 2042.88,377.586 2042.89,377.557 2042.9,377.528 2042.91,377.499 2042.92,377.47 2042.93,377.441 2042.94,377.412 2042.95,377.383 2042.96,377.354 2042.97,377.325 2042.98,377.296 2042.98,377.267 2042.99,377.238 2043,377.209 2043.01,377.18 2043.02,377.151 2043.03,377.122 2043.04,377.093 2043.05,377.064 2043.06,377.035 2043.07,377.006 2043.08,376.977 2043.09,376.948 2043.1,376.919 2043.1,376.89 2043.11,376.861 2043.12,376.832 2043.13,376.803 2043.14,376.774 2043.15,376.745 2043.16,376.716 2043.17,376.687 2043.18,376.658 2043.19,376.63 2043.2,376.601 2043.21,376.572 2043.21,376.543 2043.22,376.514 2043.23,376.485 2043.24,376.456 2043.25,376.427 2043.26,376.398 2043.27,376.369 2043.28,376.34 2043.29,376.311 2043.3,376.282 2043.31,376.254 2043.32,376.225 2043.32,376.196 2043.33,376.167 2043.34,376.138 2043.35,376.109 2043.36,376.08 2043.37,376.051 2043.38,376.022 2043.39,375.993 2043.4,375.965 2043.41,375.936 2043.42,375.907 2043.43,375.878 2043.44,375.849 2043.44,375.82 2043.45,375.791 2043.46,375.762 2043.47,375.734 2043.48,375.705 2043.49,375.676 2043.5,375.647 2043.51,375.618 2043.52,375.589 2043.53,375.56 2043.54,375.532 2043.55,375.503 2043.55,375.474 2043.56,375.445 2043.57,375.416 2043.58,375.387 2043.59,375.359 2043.6,375.33 2043.61,375.301 2043.62,375.272 2043.63,375.243 2043.64,375.214 2043.65,375.186 2043.66,375.157 2043.66,375.128 2043.67,375.099 2043.68,375.07 2043.69,375.042 2043.7,375.013 2043.71,374.984 2043.72,374.955 2043.73,374.926 2043.74,374.898 2043.75,374.869 2043.76,374.84 2043.77,374.811 2043.78,374.782 2043.78,374.754 2043.79,374.725 2043.8,374.696 2043.81,374.667 2043.82,374.638 2043.83,374.61 2043.84,374.581 2043.85,374.552 2043.86,374.523 2043.87,374.495 2043.88,374.466 2043.89,374.437 2043.89,374.408 2043.9,374.38 2043.91,374.351 2043.92,374.322 2043.93,374.293 2043.94,374.265 2043.95,374.236 2043.96,374.207 2043.97,374.178 2043.98,374.15 2043.99,374.121 2044,374.092 2044,374.064 2044.01,374.035 2044.02,374.006 2044.03,373.977 2044.04,373.949 2044.05,373.92 2044.06,373.891 2044.07,373.863 2044.08,373.834 2044.09,373.805 2044.1,373.776 2044.11,373.748 2044.12,373.719 2044.12,373.69 2044.13,373.662 2044.14,373.633 2044.15,373.604 2044.16,373.576 2044.17,373.547 2044.18,373.518 2044.19,373.49 2044.2,373.461 2044.21,373.432 2044.22,373.404 2044.23,373.375 2044.23,373.346 2044.24,373.318 2044.25,373.289 2044.26,373.26 2044.27,373.232 2044.28,373.203 2044.29,373.174 2044.3,373.146 2044.31,373.117 2044.32,373.088 2044.33,373.06 2044.34,373.031 2044.34,373.002 2044.35,372.974 2044.36,372.945 2044.37,372.917 2044.38,372.888 2044.39,372.859 2044.4,372.831 2044.41,372.802 2044.42,372.773 2044.43,372.745 2044.44,372.716 2044.45,372.688 2044.46,372.659 2044.46,372.63 2044.47,372.602 2044.48,372.573 2044.49,372.545 2044.5,372.516 2044.51,372.487 2044.52,372.459 2044.53,372.43 2044.54,372.402 2044.55,372.373 2044.56,372.344 2044.57,372.316 2044.57,372.287 2044.58,372.259 2044.59,372.23 2044.6,372.202 2044.61,372.173 2044.62,372.145 2044.63,372.116 2044.64,372.087 2044.65,372.059 2044.66,372.03 2044.67,372.002 2044.68,371.973 2044.68,371.945 2044.69,371.916 2044.7,371.888 2044.71,371.859 2044.72,371.831 2044.73,371.802 2044.74,371.773 2044.75,371.745 2044.76,371.716 2044.77,371.688 2044.78,371.659 2044.79,371.631 2044.8,371.602 2044.8,371.574 2044.81,371.545 2044.82,371.517 2044.83,371.488 2044.84,371.46 2044.85,371.431 2044.86,371.403 2044.87,371.374 2044.88,371.346 2044.89,371.317 2044.9,371.289 2044.91,371.26 2044.91,371.232 2044.92,371.203 2044.93,371.175 2044.94,371.146 2044.95,371.118 2044.96,371.089 2044.97,371.061 2044.98,371.033 2044.99,371.004 2045,370.976 2045.01,370.947 2045.02,370.919 2045.02,370.89 2045.03,370.862 2045.04,370.833 2045.05,370.805 2045.06,370.776 2045.07,370.748 2045.08,370.72 2045.09,370.691 2045.1,370.663 2045.11,370.634 2045.12,370.606 2045.13,370.577 2045.14,370.549 2045.14,370.521 2045.15,370.492 2045.16,370.464 2045.17,370.435 2045.18,370.407 2045.19,370.378 2045.2,370.35 2045.21,370.322 2045.22,370.293 2045.23,370.265 2045.24,370.236 2045.25,370.208 2045.25,370.18 2045.26,370.151 2045.27,370.123 2045.28,370.095 2045.29,370.066 2045.3,370.038 2045.31,370.009 2045.32,369.981 2045.33,369.953 2045.34,369.924 2045.35,369.896 2045.36,369.868 2045.36,369.839 2045.37,369.811 2045.38,369.782 2045.39,369.754 2045.4,369.726 2045.41,369.697 2045.42,369.669 2045.43,369.641 2045.44,369.612 2045.45,369.584 2045.46,369.556 2045.47,369.527 2045.48,369.499 2045.48,369.471 2045.49,369.442 2045.5,369.414 2045.51,369.386 2045.52,369.357 2045.53,369.329 2045.54,369.301 2045.55,369.272 2045.56,369.244 2045.57,369.216 2045.58,369.187 2045.59,369.159 2045.59,369.131 2045.6,369.103 2045.61,369.074 2045.62,369.046 2045.63,369.018 2045.64,368.989 2045.65,368.961 2045.66,368.933 2045.67,368.905 2045.68,368.876 2045.69,368.848 2045.7,368.82 2045.7,368.791 2045.71,368.763 2045.72,368.735 2045.73,368.707 2045.74,368.678 2045.75,368.65 2045.76,368.622 2045.77,368.594 2045.78,368.565 2045.79,368.537 2045.8,368.509 2045.81,368.481 2045.82,368.452 2045.82,368.424 2045.83,368.396 2045.84,368.368 2045.85,368.339 2045.86,368.311 2045.87,368.283 2045.88,368.255 2045.89,368.226 2045.9,368.198 2045.91,368.17 2045.92,368.142 2045.93,368.114 2045.93,368.085 2045.94,368.057 2045.95,368.029 2045.96,368.001 2045.97,367.973 2045.98,367.944 2045.99,367.916 2046,367.888 2046.01,367.86 2046.02,367.832 2046.03,367.803 2046.04,367.775 2046.04,367.747 2046.05,367.719 2046.06,367.691 2046.07,367.663 2046.08,367.634 2046.09,367.606 2046.1,367.578 2046.11,367.55 2046.12,367.522 2046.13,367.494 2046.14,367.465 2046.15,367.437 2046.16,367.409 2046.16,367.381 2046.17,367.353 2046.18,367.325 2046.19,367.296 2046.2,367.268 2046.21,367.24 2046.22,367.212 2046.23,367.184 2046.24,367.156 2046.25,367.128 2046.26,367.1 2046.27,367.071 2046.27,367.043 2046.28,367.015 2046.29,366.987 2046.3,366.959 2046.31,366.931 2046.32,366.903 2046.33,366.875 2046.34,366.847 2046.35,366.818 2046.36,366.79 2046.37,366.762 2046.38,366.734 2046.38,366.706 2046.39,366.678 2046.4,366.65 2046.41,366.622 2046.42,366.594 2046.43,366.566 2046.44,366.538 2046.45,366.509 2046.46,366.481 2046.47,366.453 2046.48,366.425 2046.49,366.397 2046.5,366.369 2046.5,366.341 2046.51,366.313 2046.52,366.285 2046.53,366.257 2046.54,366.229 2046.55,366.201 2046.56,366.173 2046.57,366.145 2046.58,366.117 2046.59,366.089 2046.6,366.061 2046.61,366.033 2046.61,366.005 2046.62,365.977 2046.63,365.949 2046.64,365.92 2046.65,365.892 2046.66,365.864 2046.67,365.836 2046.68,365.808 2046.69,365.78 2046.7,365.752 2046.71,365.724 2046.72,365.696 2046.72,365.668 2046.73,365.64 2046.74,365.612 2046.75,365.584 2046.76,365.556 2046.77,365.528 2046.78,365.5 2046.79,365.472 2046.8,365.444 2046.81,365.417 2046.82,365.389 2046.83,365.361 2046.84,365.333 2046.84,365.305 2046.85,365.277 2046.86,365.249 2046.87,365.221 2046.88,365.193 2046.89,365.165 2046.9,365.137 2046.91,365.109 2046.92,365.081 2046.93,365.053 2046.94,365.025 2046.95,364.997 2046.95,364.969 2046.96,364.941 2046.97,364.913 2046.98,364.885 2046.99,364.857 2047,364.83 2047.01,364.802 2047.02,364.774 2047.03,364.746 2047.04,364.718 2047.05,364.69 2047.06,364.662 2047.06,364.634 2047.07,364.606 2047.08,364.578 2047.09,364.55 2047.1,364.522 2047.11,364.495 2047.12,364.467 2047.13,364.439 2047.14,364.411 2047.15,364.383 2047.16,364.355 2047.17,364.327 2047.18,364.299 2047.18,364.272 2047.19,364.244 2047.2,364.216 2047.21,364.188 2047.22,364.16 2047.23,364.132 2047.24,364.104 2047.25,364.076 2047.26,364.049 2047.27,364.021 2047.28,363.993 2047.29,363.965 2047.29,363.937 2047.3,363.909 2047.31,363.881 2047.32,363.854 2047.33,363.826 2047.34,363.798 2047.35,363.77 2047.36,363.742 2047.37,363.714 2047.38,363.687 2047.39,363.659 2047.4,363.631 2047.4,363.603 2047.41,363.575 2047.42,363.548 2047.43,363.52 2047.44,363.492 2047.45,363.464 2047.46,363.436 2047.47,363.409 2047.48,363.381 2047.49,363.353 2047.5,363.325 2047.51,363.297 2047.52,363.27 2047.52,363.242 2047.53,363.214 2047.54,363.186 2047.55,363.158 2047.56,363.131 2047.57,363.103 2047.58,363.075 2047.59,363.047 2047.6,363.02 2047.61,362.992 2047.62,362.964 2047.63,362.936 2047.63,362.909 2047.64,362.881 2047.65,362.853 2047.66,362.825 2047.67,362.798 2047.68,362.77 2047.69,362.742 2047.7,362.714 2047.71,362.687 2047.72,362.659 2047.73,362.631 2047.74,362.603 2047.74,362.576 2047.75,362.548 2047.76,362.52 2047.77,362.492 2047.78,362.465 2047.79,362.437 2047.8,362.409 2047.81,362.382 2047.82,362.354 2047.83,362.326 2047.84,362.298 2047.85,362.271 2047.86,362.243 2047.86,362.215 2047.87,362.188 2047.88,362.16 2047.89,362.132 2047.9,362.105 2047.91,362.077 2047.92,362.049 2047.93,362.022 2047.94,361.994 2047.95,361.966 2047.96,361.939 2047.97,361.911 2047.97,361.883 2047.98,361.856 2047.99,361.828 2048,361.8 2048.01,361.773 2048.02,361.745 2048.03,361.717 2048.04,361.69 2048.05,361.662 2048.06,361.634 2048.07,361.607 2048.08,361.579 2048.08,361.551 2048.09,361.524 2048.1,361.496 2048.11,361.469 2048.12,361.441 2048.13,361.413 2048.14,361.386 2048.15,361.358 2048.16,361.33 2048.17,361.303 2048.18,361.275 2048.19,361.248 2048.2,361.22 2048.2,361.192 2048.21,361.165 2048.22,361.137 2048.23,361.11 2048.24,361.082 2048.25,361.054 2048.26,361.027 2048.27,360.999 2048.28,360.972 2048.29,360.944 2048.3,360.916 2048.31,360.889 2048.31,360.861 2048.32,360.834 2048.33,360.806 2048.34,360.779 2048.35,360.751 2048.36,360.723 2048.37,360.696 2048.38,360.668 2048.39,360.641 2048.4,360.613 2048.41,360.586 2048.42,360.558 2048.43,360.531 2048.43,360.503 2048.44,360.476 2048.45,360.448 2048.46,360.42 2048.47,360.393 2048.48,360.365 2048.49,360.338 2048.5,360.31 2048.51,360.283 2048.52,360.255 2048.53,360.228 2048.54,360.2 2048.54,360.173 2048.55,360.145 2048.56,360.118 2048.57,360.09 2048.58,360.063 2048.59,360.035 2048.6,360.008 2048.61,359.98 2048.62,359.953 2048.63,359.925 2048.64,359.898 2048.65,359.87 2048.65,359.843 2048.66,359.815 2048.67,359.788 2048.68,359.76 2048.69,359.733 2048.7,359.705 2048.71,359.678 2048.72,359.65 2048.73,359.623 2048.74,359.596 2048.75,359.568 2048.76,359.541 2048.77,359.513 2048.77,359.486 2048.78,359.458 2048.79,359.431 2048.8,359.403 2048.81,359.376 2048.82,359.349 2048.83,359.321 2048.84,359.294 2048.85,359.266 2048.86,359.239 2048.87,359.211 2048.88,359.184 2048.88,359.156 2048.89,359.129 2048.9,359.102 2048.91,359.074 2048.92,359.047 2048.93,359.019 2048.94,358.992 2048.95,358.965 2048.96,358.937 2048.97,358.91 2048.98,358.882 2048.99,358.855 2048.99,358.828 2049,358.8 2049.01,358.773 2049.02,358.745 2049.03,358.718 2049.04,358.691 2049.05,358.663 2049.06,358.636 2049.07,358.609 2049.08,358.581 2049.09,358.554 2049.1,358.526 2049.11,358.499 2049.11,358.472 2049.12,358.444 2049.13,358.417 2049.14,358.39 2049.15,358.362 2049.16,358.335 2049.17,358.308 2049.18,358.28 2049.19,358.253 2049.2,358.226 2049.21,358.198 2049.22,358.171 2049.22,358.144 2049.23,358.116 2049.24,358.089 2049.25,358.062 2049.26,358.034 2049.27,358.007 2049.28,357.98 2049.29,357.952 2049.3,357.925 2049.31,357.898 2049.32,357.87 2049.33,357.843 2049.33,357.816 2049.34,357.789 2049.35,357.761 2049.36,357.734 2049.37,357.707 2049.38,357.679 2049.39,357.652 2049.4,357.625 2049.41,357.598 2049.42,357.57 2049.43,357.543 2049.44,357.516 2049.45,357.488 2049.45,357.461 2049.46,357.434 2049.47,357.407 2049.48,357.379 2049.49,357.352 2049.5,357.325 2049.51,357.298 2049.52,357.27 2049.53,357.243 2049.54,357.216 2049.55,357.189 2049.56,357.161 2049.56,357.134 2049.57,357.107 2049.58,357.08 2049.59,357.052 2049.6,357.025 2049.61,356.998 2049.62,356.971 2049.63,356.943 2049.64,356.916 2049.65,356.889 2049.66,356.862 2049.67,356.835 2049.67,356.807 2049.68,356.78 2049.69,356.753 2049.7,356.726 2049.71,356.699 2049.72,356.671 2049.73,356.644 2049.74,356.617 2049.75,356.59 2049.76,356.563 2049.77,356.535 2049.78,356.508 2049.79,356.481 2049.79,356.454 2049.8,356.427 2049.81,356.4 2049.82,356.372 2049.83,356.345 2049.84,356.318 2049.85,356.291 2049.86,356.264 2049.87,356.237 2049.88,356.209 2049.89,356.182 2049.9,356.155 2049.9,356.128 2049.91,356.101 2049.92,356.074 2049.93,356.047 2049.94,356.019 2049.95,355.992 2049.96,355.965 2049.97,355.938 2049.98,355.911 2049.99,355.884 2050,355.857 2050.01,355.829 2050.01,355.802 2050.02,355.775 2050.03,355.748 2050.04,355.721 2050.05,355.694 2050.06,355.667 2050.07,355.64 2050.08,355.613 2050.09,355.586 2050.1,355.558 2050.11,355.531 2050.12,355.504 2050.13,355.477 2050.13,355.45 2050.14,355.423 2050.15,355.396 2050.16,355.369 2050.17,355.342 2050.18,355.315 2050.19,355.288 2050.2,355.261 2050.21,355.233 2050.22,355.206 2050.23,355.179 2050.24,355.152 2050.24,355.125 2050.25,355.098 2050.26,355.071 2050.27,355.044 2050.28,355.017 2050.29,354.99 2050.3,354.963 2050.31,354.936 2050.32,354.909 2050.33,354.882 2050.34,354.855 2050.35,354.828 2050.35,354.801 2050.36,354.774 2050.37,354.747 2050.38,354.72 2050.39,354.693 2050.4,354.666 2050.41,354.639 2050.42,354.612 2050.43,354.585 2050.44,354.558 2050.45,354.531 2050.46,354.504 2050.47,354.477 2050.47,354.45 2050.48,354.423 2050.49,354.396 2050.5,354.369 2050.51,354.342 2050.52,354.315 2050.53,354.288 2050.54,354.261 2050.55,354.234 2050.56,354.207 2050.57,354.18 2050.58,354.153 2050.58,354.126 2050.59,354.099 2050.6,354.072 2050.61,354.045 2050.62,354.018 2050.63,353.991 2050.64,353.964 2050.65,353.937 2050.66,353.91 2050.67,353.883 2050.68,353.856 2050.69,353.829 2050.69,353.802 2050.7,353.776 2050.71,353.749 2050.72,353.722 2050.73,353.695 2050.74,353.668 2050.75,353.641 2050.76,353.614 2050.77,353.587 2050.78,353.56 2050.79,353.533 2050.8,353.506 2050.81,353.479 2050.81,353.452 2050.82,353.426 2050.83,353.399 2050.84,353.372 2050.85,353.345 2050.86,353.318 2050.87,353.291 2050.88,353.264 2050.89,353.237 2050.9,353.21 2050.91,353.184 2050.92,353.157 2050.92,353.13 2050.93,353.103 2050.94,353.076 2050.95,353.049 2050.96,353.022 2050.97,352.995 2050.98,352.969 2050.99,352.942 2051,352.915 2051.01,352.888 2051.02,352.861 2051.03,352.834 2051.03,352.808 2051.04,352.781 2051.05,352.754 2051.06,352.727 2051.07,352.7 2051.08,352.673 2051.09,352.647 2051.1,352.62 2051.11,352.593 2051.12,352.566 2051.13,352.539 2051.14,352.512 2051.15,352.486 2051.15,352.459 2051.16,352.432 2051.17,352.405 2051.18,352.378 2051.19,352.352 2051.2,352.325 2051.21,352.298 2051.22,352.271 2051.23,352.244 2051.24,352.218 2051.25,352.191 2051.26,352.164 2051.26,352.137 2051.27,352.11 2051.28,352.084 2051.29,352.057 2051.3,352.03 2051.31,352.003 2051.32,351.977 2051.33,351.95 2051.34,351.923 2051.35,351.896 2051.36,351.87 2051.37,351.843 2051.37,351.816 2051.38,351.789 2051.39,351.762 2051.4,351.736 2051.41,351.709 2051.42,351.682 2051.43,351.656 2051.44,351.629 2051.45,351.602 2051.46,351.575 2051.47,351.549 2051.48,351.522 2051.49,351.495 2051.49,351.468 2051.5,351.442 2051.51,351.415 2051.52,351.388 2051.53,351.362 2051.54,351.335 2051.55,351.308 2051.56,351.281 2051.57,351.255 2051.58,351.228 2051.59,351.201 2051.6,351.175 2051.6,351.148 2051.61,351.121 2051.62,351.095 2051.63,351.068 2051.64,351.041 2051.65,351.015 2051.66,350.988 2051.67,350.961 2051.68,350.935 2051.69,350.908 2051.7,350.881 2051.71,350.855 2051.71,350.828 2051.72,350.801 2051.73,350.775 2051.74,350.748 2051.75,350.721 2051.76,350.695 2051.77,350.668 2051.78,350.641 2051.79,350.615 2051.8,350.588 2051.81,350.561 2051.82,350.535 2051.83,350.508 2051.83,350.481 2051.84,350.455 2051.85,350.428 2051.86,350.402 2051.87,350.375 2051.88,350.348 2051.89,350.322 2051.9,350.295 2051.91,350.269 2051.92,350.242 2051.93,350.215 2051.94,350.189 2051.94,350.162 2051.95,350.135 2051.96,350.109 2051.97,350.082 2051.98,350.056 2051.99,350.029 2052,350.003 2052.01,349.976 2052.02,349.949 2052.03,349.923 2052.04,349.896 2052.05,349.87 2052.05,349.843 2052.06,349.816 2052.07,349.79 2052.08,349.763 2052.09,349.737 2052.1,349.71 2052.11,349.684 2052.12,349.657 2052.13,349.631 2052.14,349.604 2052.15,349.577 2052.16,349.551 2052.17,349.524 2052.17,349.498 2052.18,349.471 2052.19,349.445 2052.2,349.418 2052.21,349.392 2052.22,349.365 2052.23,349.339 2052.24,349.312 2052.25,349.286 2052.26,349.259 2052.27,349.233 2052.28,349.206 2052.28,349.18 2052.29,349.153 2052.3,349.127 2052.31,349.1 2052.32,349.074 2052.33,349.047 2052.34,349.021 2052.35,348.994 2052.36,348.968 2052.37,348.941 2052.38,348.915 2052.39,348.888 2052.39,348.862 2052.4,348.835 2052.41,348.809 2052.42,348.782 2052.43,348.756 2052.44,348.729 2052.45,348.703 2052.46,348.676 2052.47,348.65 2052.48,348.623 2052.49,348.597 2052.5,348.571 2052.51,348.544 2052.51,348.518 2052.52,348.491 2052.53,348.465 2052.54,348.438 2052.55,348.412 2052.56,348.385 2052.57,348.359 2052.58,348.333 2052.59,348.306 2052.6,348.28 2052.61,348.253 2052.62,348.227 2052.62,348.2 2052.63,348.174 2052.64,348.148 2052.65,348.121 2052.66,348.095 2052.67,348.068 2052.68,348.042 2052.69,348.016 2052.7,347.989 2052.71,347.963 2052.72,347.936 2052.73,347.91 2052.73,347.884 2052.74,347.857 2052.75,347.831 2052.76,347.804 2052.77,347.778 2052.78,347.752 2052.79,347.725 2052.8,347.699 2052.81,347.673 2052.82,347.646 2052.83,347.62 2052.84,347.594 2052.85,347.567 2052.85,347.541 2052.86,347.514 2052.87,347.488 2052.88,347.462 2052.89,347.435 2052.9,347.409 2052.91,347.383 2052.92,347.356 2052.93,347.33 2052.94,347.304 2052.95,347.277 2052.96,347.251 2052.96,347.225 2052.97,347.198 2052.98,347.172 2052.99,347.146 2053,347.119 2053.01,347.093 2053.02,347.067 2053.03,347.04 2053.04,347.014 2053.05,346.988 2053.06,346.962 2053.07,346.935 2053.07,346.909 2053.08,346.883 2053.09,346.856 2053.1,346.83 2053.11,346.804 2053.12,346.778 2053.13,346.751 2053.14,346.725 2053.15,346.699 2053.16,346.672 2053.17,346.646 2053.18,346.62 2053.19,346.594 2053.19,346.567 2053.2,346.541 2053.21,346.515 2053.22,346.489 2053.23,346.462 2053.24,346.436 2053.25,346.41 2053.26,346.384 2053.27,346.357 2053.28,346.331 2053.29,346.305 2053.3,346.279 2053.3,346.252 2053.31,346.226 2053.32,346.2 2053.33,346.174 2053.34,346.147 2053.35,346.121 2053.36,346.095 2053.37,346.069 2053.38,346.043 2053.39,346.016 2053.4,345.99 2053.41,345.964 2053.41,345.938 2053.42,345.911 2053.43,345.885 2053.44,345.859 2053.45,345.833 2053.46,345.807 2053.47,345.78 2053.48,345.754 2053.49,345.728 2053.5,345.702 2053.51,345.676 2053.52,345.65 2053.53,345.623 2053.53,345.597 2053.54,345.571 2053.55,345.545 2053.56,345.519 2053.57,345.493 2053.58,345.466 2053.59,345.44 2053.6,345.414 2053.61,345.388 2053.62,345.362 2053.63,345.336 2053.64,345.309 2053.64,345.283 2053.65,345.257 2053.66,345.231 2053.67,345.205 2053.68,345.179 2053.69,345.153 2053.7,345.126 2053.71,345.1 2053.72,345.074 2053.73,345.048 2053.74,345.022 2053.75,344.996 2053.75,344.97 2053.76,344.944 2053.77,344.918 2053.78,344.891 2053.79,344.865 2053.8,344.839 2053.81,344.813 2053.82,344.787 2053.83,344.761 2053.84,344.735 2053.85,344.709 2053.86,344.683 2053.87,344.657 2053.87,344.63 2053.88,344.604 2053.89,344.578 2053.9,344.552 2053.91,344.526 2053.92,344.5 2053.93,344.474 2053.94,344.448 2053.95,344.422 2053.96,344.396 2053.97,344.37 2053.98,344.344 2053.98,344.318 2053.99,344.292 2054,344.266 2054.01,344.24 2054.02,344.213 2054.03,344.187 2054.04,344.161 2054.05,344.135 2054.06,344.109 2054.07,344.083 2054.08,344.057 2054.09,344.031 2054.09,344.005 2054.1,343.979 2054.11,343.953 2054.12,343.927 2054.13,343.901 2054.14,343.875 2054.15,343.849 2054.16,343.823 2054.17,343.797 2054.18,343.771 2054.19,343.745 2054.2,343.719 2054.21,343.693 2054.21,343.667 2054.22,343.641 2054.23,343.615 2054.24,343.589 2054.25,343.563 2054.26,343.537 2054.27,343.511 2054.28,343.485 2054.29,343.459 2054.3,343.433 2054.31,343.407 2054.32,343.381 2054.32,343.355 2054.33,343.329 2054.34,343.303 2054.35,343.278 2054.36,343.252 2054.37,343.226 2054.38,343.2 2054.39,343.174 2054.4,343.148 2054.41,343.122 2054.42,343.096 2054.43,343.07 2054.43,343.044 2054.44,343.018 2054.45,342.992 2054.46,342.966 2054.47,342.94 2054.48,342.914 2054.49,342.888 2054.5,342.863 2054.51,342.837 2054.52,342.811 2054.53,342.785 2054.54,342.759 2054.55,342.733 2054.55,342.707 2054.56,342.681 2054.57,342.655 2054.58,342.629 2054.59,342.604 2054.6,342.578 2054.61,342.552 2054.62,342.526 2054.63,342.5 2054.64,342.474 2054.65,342.448 2054.66,342.422 2054.66,342.396 2054.67,342.371 2054.68,342.345 2054.69,342.319 2054.7,342.293 2054.71,342.267 2054.72,342.241 2054.73,342.215 2054.74,342.19 2054.75,342.164 2054.76,342.138 2054.77,342.112 2054.77,342.086 2054.78,342.06 2054.79,342.035 2054.8,342.009 2054.81,341.983 2054.82,341.957 2054.83,341.931 2054.84,341.905 2054.85,341.88 2054.86,341.854 2054.87,341.828 2054.88,341.802 2054.89,341.776 2054.89,341.75 2054.9,341.725 2054.91,341.699 2054.92,341.673 2054.93,341.647 2054.94,341.621 2054.95,341.596 2054.96,341.57 2054.97,341.544 2054.98,341.518 2054.99,341.492 2055,341.467 2055,341.441 2055.01,341.415 2055.02,341.389 2055.03,341.364 2055.04,341.338 2055.05,341.312 2055.06,341.286 2055.07,341.261 2055.08,341.235 2055.09,341.209 2055.1,341.183 2055.11,341.157 2055.11,341.132 2055.12,341.106 2055.13,341.08 2055.14,341.054 2055.15,341.029 2055.16,341.003 2055.17,340.977 2055.18,340.952 2055.19,340.926 2055.2,340.9 2055.21,340.874 2055.22,340.849 2055.23,340.823 2055.23,340.797 2055.24,340.771 2055.25,340.746 2055.26,340.72 2055.27,340.694 2055.28,340.669 2055.29,340.643 2055.3,340.617 2055.31,340.591 2055.32,340.566 2055.33,340.54 2055.34,340.514 2055.34,340.489 2055.35,340.463 2055.36,340.437 2055.37,340.412 2055.38,340.386 2055.39,340.36 2055.4,340.335 2055.41,340.309 2055.42,340.283 2055.43,340.258 2055.44,340.232 2055.45,340.206 2055.45,340.181 2055.46,340.155 2055.47,340.129 2055.48,340.104 2055.49,340.078 2055.5,340.052 2055.51,340.027 2055.52,340.001 2055.53,339.975 2055.54,339.95 2055.55,339.924 2055.56,339.899 2055.57,339.873 2055.57,339.847 2055.58,339.822 2055.59,339.796 2055.6,339.77 2055.61,339.745 2055.62,339.719 2055.63,339.694 2055.64,339.668 2055.65,339.642 2055.66,339.617 2055.67,339.591 2055.68,339.565 2055.68,339.54 2055.69,339.514 2055.7,339.489 2055.71,339.463 2055.72,339.437 2055.73,339.412 2055.74,339.386 2055.75,339.361 2055.76,339.335 2055.77,339.31 2055.78,339.284 2055.79,339.258 2055.79,339.233 2055.8,339.207 2055.81,339.182 2055.82,339.156 2055.83,339.131 2055.84,339.105 2055.85,339.079 2055.86,339.054 2055.87,339.028 2055.88,339.003 2055.89,338.977 2055.9,338.952 2055.91,338.926 2055.91,338.901 2055.92,338.875 2055.93,338.85 2055.94,338.824 2055.95,338.799 2055.96,338.773 2055.97,338.747 2055.98,338.722 2055.99,338.696 2056,338.671 2056.01,338.645 2056.02,338.62 2056.02,338.594 2056.03,338.569 2056.04,338.543 2056.05,338.518 2056.06,338.492 2056.07,338.467 2056.08,338.441 2056.09,338.416 2056.1,338.39 2056.11,338.365 2056.12,338.339 2056.13,338.314 2056.13,338.288 2056.14,338.263 2056.15,338.238 2056.16,338.212 2056.17,338.187 2056.18,338.161 2056.19,338.136 2056.2,338.11 2056.21,338.085 2056.22,338.059 2056.23,338.034 2056.24,338.008 2056.25,337.983 2056.25,337.957 2056.26,337.932 2056.27,337.907 2056.28,337.881 2056.29,337.856 2056.3,337.83 2056.31,337.805 2056.32,337.779 2056.33,337.754 2056.34,337.729 2056.35,337.703 2056.36,337.678 2056.36,337.652 2056.37,337.627 2056.38,337.601 2056.39,337.576 2056.4,337.551 2056.41,337.525 2056.42,337.5 2056.43,337.474 2056.44,337.449 2056.45,337.424 2056.46,337.398 2056.47,337.373 2056.47,337.347 2056.48,337.322 2056.49,337.297 2056.5,337.271 2056.51,337.246 2056.52,337.22 2056.53,337.195 2056.54,337.17 2056.55,337.144 2056.56,337.119 2056.57,337.094 2056.58,337.068 2056.59,337.043 2056.59,337.018 2056.6,336.992 2056.61,336.967 2056.62,336.941 2056.63,336.916 2056.64,336.891 2056.65,336.865 2056.66,336.84 2056.67,336.815 2056.68,336.789 2056.69,336.764 2056.7,336.739 2056.7,336.713 2056.71,336.688 2056.72,336.663 2056.73,336.637 2056.74,336.612 2056.75,336.587 2056.76,336.562 2056.77,336.536 2056.78,336.511 2056.79,336.486 2056.8,336.46 2056.81,336.435 2056.81,336.41 2056.82,336.384 2056.83,336.359 2056.84,336.334 2056.85,336.309 2056.86,336.283 2056.87,336.258 2056.88,336.233 2056.89,336.207 2056.9,336.182 2056.91,336.157 2056.92,336.132 2056.93,336.106 2056.93,336.081 2056.94,336.056 2056.95,336.03 2056.96,336.005 2056.97,335.98 2056.98,335.955 2056.99,335.929 2057,335.904 2057.01,335.879 2057.02,335.854 2057.03,335.828 2057.04,335.803 2057.04,335.778 2057.05,335.753 2057.06,335.728 2057.07,335.702 2057.08,335.677 2057.09,335.652 2057.1,335.627 2057.11,335.601 2057.12,335.576 2057.13,335.551 2057.14,335.526 2057.15,335.501 2057.15,335.475 2057.16,335.45 2057.17,335.425 2057.18,335.4 2057.19,335.375 2057.2,335.349 2057.21,335.324 2057.22,335.299 2057.23,335.274 2057.24,335.249 2057.25,335.223 2057.26,335.198 2057.27,335.173 2057.27,335.148 2057.28,335.123 2057.29,335.097 2057.3,335.072 2057.31,335.047 2057.32,335.022 2057.33,334.997 2057.34,334.972 2057.35,334.946 2057.36,334.921 2057.37,334.896 2057.38,334.871 2057.38,334.846 2057.39,334.821 2057.4,334.796 2057.41,334.77 2057.42,334.745 2057.43,334.72 2057.44,334.695 2057.45,334.67 2057.46,334.645 2057.47,334.62 2057.48,334.595 2057.49,334.569 2057.49,334.544 2057.5,334.519 2057.51,334.494 2057.52,334.469 2057.53,334.444 2057.54,334.419 2057.55,334.394 2057.56,334.369 2057.57,334.343 2057.58,334.318 2057.59,334.293 2057.6,334.268 2057.61,334.243 2057.61,334.218 2057.62,334.193 2057.63,334.168 2057.64,334.143 2057.65,334.118 2057.66,334.093 2057.67,334.067 2057.68,334.042 2057.69,334.017 2057.7,333.992 2057.71,333.967 2057.72,333.942 2057.72,333.917 2057.73,333.892 2057.74,333.867 2057.75,333.842 2057.76,333.817 2057.77,333.792 2057.78,333.767 2057.79,333.742 2057.8,333.717 2057.81,333.692 2057.82,333.667 2057.83,333.642 2057.83,333.617 2057.84,333.592 2057.85,333.567 2057.86,333.542 2057.87,333.516 2057.88,333.491 2057.89,333.466 2057.9,333.441 2057.91,333.416 2057.92,333.391 2057.93,333.366 2057.94,333.341 2057.95,333.316 2057.95,333.291 2057.96,333.266 2057.97,333.241 2057.98,333.216 2057.99,333.191 2058,333.166 2058.01,333.141 2058.02,333.117 2058.03,333.092 2058.04,333.067 2058.05,333.042 2058.06,333.017 2058.06,332.992 2058.07,332.967 2058.08,332.942 2058.09,332.917 2058.1,332.892 2058.11,332.867 2058.12,332.842 2058.13,332.817 2058.14,332.792 2058.15,332.767 2058.16,332.742 2058.17,332.717 2058.17,332.692 2058.18,332.667 2058.19,332.642 2058.2,332.617 2058.21,332.592 2058.22,332.568 2058.23,332.543 2058.24,332.518 2058.25,332.493 2058.26,332.468 2058.27,332.443 2058.28,332.418 2058.29,332.393 2058.29,332.368 2058.3,332.343 2058.31,332.318 2058.32,332.294 2058.33,332.269 2058.34,332.244 2058.35,332.219 2058.36,332.194 2058.37,332.169 2058.38,332.144 2058.39,332.119 2058.4,332.094 2058.4,332.07 2058.41,332.045 2058.42,332.02 2058.43,331.995 2058.44,331.97 2058.45,331.945 2058.46,331.92 2058.47,331.895 2058.48,331.871 2058.49,331.846 2058.5,331.821 2058.51,331.796 2058.51,331.771 2058.52,331.746 2058.53,331.721 2058.54,331.697 2058.55,331.672 2058.56,331.647 2058.57,331.622 2058.58,331.597 2058.59,331.572 2058.6,331.548 2058.61,331.523 2058.62,331.498 2058.63,331.473 2058.63,331.448 2058.64,331.424 2058.65,331.399 2058.66,331.374 2058.67,331.349 2058.68,331.324 2058.69,331.299 2058.7,331.275 2058.71,331.25 2058.72,331.225 2058.73,331.2 2058.74,331.175 2058.74,331.151 2058.75,331.126 2058.76,331.101 2058.77,331.076 2058.78,331.052 2058.79,331.027 2058.8,331.002 2058.81,330.977 2058.82,330.952 2058.83,330.928 2058.84,330.903 2058.85,330.878 2058.85,330.853 2058.86,330.829 2058.87,330.804 2058.88,330.779 2058.89,330.754 2058.9,330.73 2058.91,330.705 2058.92,330.68 2058.93,330.655 2058.94,330.631 2058.95,330.606 2058.96,330.581 2058.97,330.557 2058.97,330.532 2058.98,330.507 2058.99,330.482 2059,330.458 2059.01,330.433 2059.02,330.408 2059.03,330.383 2059.04,330.359 2059.05,330.334 2059.06,330.309 2059.07,330.285 2059.08,330.26 2059.08,330.235 2059.09,330.211 2059.1,330.186 2059.11,330.161 2059.12,330.136 2059.13,330.112 2059.14,330.087 2059.15,330.062 2059.16,330.038 2059.17,330.013 2059.18,329.988 2059.19,329.964 2059.19,329.939 2059.2,329.914 2059.21,329.89 2059.22,329.865 2059.23,329.84 2059.24,329.816 2059.25,329.791 2059.26,329.766 2059.27,329.742 2059.28,329.717 2059.29,329.692 2059.3,329.668 2059.31,329.643 2059.31,329.619 2059.32,329.594 2059.33,329.569 2059.34,329.545 2059.35,329.52 2059.36,329.495 2059.37,329.471 2059.38,329.446 2059.39,329.422 2059.4,329.397 2059.41,329.372 2059.42,329.348 2059.42,329.323 2059.43,329.298 2059.44,329.274 2059.45,329.249 2059.46,329.225 2059.47,329.2 2059.48,329.175 2059.49,329.151 2059.5,329.126 2059.51,329.102 2059.52,329.077 2059.53,329.052 2059.53,329.028 2059.54,329.003 2059.55,328.979 2059.56,328.954 2059.57,328.93 2059.58,328.905 2059.59,328.88 2059.6,328.856 2059.61,328.831 2059.62,328.807 2059.63,328.782 2059.64,328.758 2059.65,328.733 2059.65,328.709 2059.66,328.684 2059.67,328.659 2059.68,328.635 2059.69,328.61 2059.7,328.586 2059.71,328.561 2059.72,328.537 2059.73,328.512 2059.74,328.488 2059.75,328.463 2059.76,328.439 2059.76,328.414 2059.77,328.39 2059.78,328.365 2059.79,328.341 2059.8,328.316 2059.81,328.292 2059.82,328.267 2059.83,328.243 2059.84,328.218 2059.85,328.194 2059.86,328.169 2059.87,328.145 2059.87,328.12 2059.88,328.096 2059.89,328.071 2059.9,328.047 2059.91,328.022 2059.92,327.998 2059.93,327.973 2059.94,327.949 2059.95,327.924 2059.96,327.9 2059.97,327.875 2059.98,327.851 2059.99,327.826 2059.99,327.802 2060,327.777 2060.01,327.753 2060.02,327.729 2060.03,327.704 2060.04,327.68 2060.05,327.655 2060.06,327.631 2060.07,327.606 2060.08,327.582 2060.09,327.557 2060.1,327.533 2060.1,327.509 2060.11,327.484 2060.12,327.46 2060.13,327.435 2060.14,327.411 2060.15,327.387 2060.16,327.362 2060.17,327.338 2060.18,327.313 2060.19,327.289 2060.2,327.264 2060.21,327.24 2060.21,327.216 2060.22,327.191 2060.23,327.167 2060.24,327.142 2060.25,327.118 2060.26,327.094 2060.27,327.069 2060.28,327.045 2060.29,327.021 2060.3,326.996 2060.31,326.972 2060.32,326.947 2060.33,326.923 2060.33,326.899 2060.34,326.874 2060.35,326.85 2060.36,326.826 2060.37,326.801 2060.38,326.777 2060.39,326.752 2060.4,326.728 2060.41,326.704 2060.42,326.679 2060.43,326.655 2060.44,326.631 2060.44,326.606 2060.45,326.582 2060.46,326.558 2060.47,326.533 2060.48,326.509 2060.49,326.485 2060.5,326.46 2060.51,326.436 2060.52,326.412 2060.53,326.387 2060.54,326.363 2060.55,326.339 2060.55,326.314 2060.56,326.29 2060.57,326.266 2060.58,326.242 2060.59,326.217 2060.6,326.193 2060.61,326.169 2060.62,326.144 2060.63,326.12 2060.64,326.096 2060.65,326.071 2060.66,326.047 2060.67,326.023 2060.67,325.999 2060.68,325.974 2060.69,325.95 2060.7,325.926 2060.71,325.901 2060.72,325.877 2060.73,325.853 2060.74,325.829 2060.75,325.804 2060.76,325.78 2060.77,325.756 2060.78,325.732 2060.78,325.707 2060.79,325.683 2060.8,325.659 2060.81,325.635 2060.82,325.61 2060.83,325.586 2060.84,325.562 2060.85,325.538 2060.86,325.513 2060.87,325.489 2060.88,325.465 2060.89,325.441 2060.89,325.417 2060.9,325.392 2060.91,325.368 2060.92,325.344 2060.93,325.32 2060.94,325.295 2060.95,325.271 2060.96,325.247 2060.97,325.223 2060.98,325.199 2060.99,325.174 2061,325.15 2061.01,325.126 2061.01,325.102 2061.02,325.078 2061.03,325.053 2061.04,325.029 2061.05,325.005 2061.06,324.981 2061.07,324.957 2061.08,324.933 2061.09,324.908 2061.1,324.884 2061.11,324.86 2061.12,324.836 2061.12,324.812 2061.13,324.788 2061.14,324.763 2061.15,324.739 2061.16,324.715 2061.17,324.691 2061.18,324.667 2061.19,324.643 2061.2,324.618 2061.21,324.594 2061.22,324.57 2061.23,324.546 2061.23,324.522 2061.24,324.498 2061.25,324.474 2061.26,324.45 2061.27,324.425 2061.28,324.401 2061.29,324.377 2061.3,324.353 2061.31,324.329 2061.32,324.305 2061.33,324.281 2061.34,324.257 2061.35,324.232 2061.35,324.208 2061.36,324.184 2061.37,324.16 2061.38,324.136 2061.39,324.112 2061.4,324.088 2061.41,324.064 2061.42,324.04 2061.43,324.016 2061.44,323.992 2061.45,323.967 2061.46,323.943 2061.46,323.919 2061.47,323.895 2061.48,323.871 2061.49,323.847 2061.5,323.823 2061.51,323.799 2061.52,323.775 2061.53,323.751 2061.54,323.727 2061.55,323.703 2061.56,323.679 2061.57,323.655 2061.57,323.631 2061.58,323.607 2061.59,323.582 2061.6,323.558 2061.61,323.534 2061.62,323.51 2061.63,323.486 2061.64,323.462 2061.65,323.438 2061.66,323.414 2061.67,323.39 2061.68,323.366 2061.69,323.342 2061.69,323.318 2061.7,323.294 2061.71,323.27 2061.72,323.246 2061.73,323.222 2061.74,323.198 2061.75,323.174 2061.76,323.15 2061.77,323.126 2061.78,323.102 2061.79,323.078 2061.8,323.054 2061.8,323.03 2061.81,323.006 2061.82,322.982 2061.83,322.958 2061.84,322.934 2061.85,322.91 2061.86,322.886 2061.87,322.862 2061.88,322.838 2061.89,322.814 2061.9,322.79 2061.91,322.766 2061.91,322.743 2061.92,322.719 2061.93,322.695 2061.94,322.671 2061.95,322.647 2061.96,322.623 2061.97,322.599 2061.98,322.575 2061.99,322.551 2062,322.527 2062.01,322.503 2062.02,322.479 2062.03,322.455 2062.03,322.431 2062.04,322.407 2062.05,322.383 2062.06,322.36 2062.07,322.336 2062.08,322.312 2062.09,322.288 2062.1,322.264 2062.11,322.24 2062.12,322.216 2062.13,322.192 2062.14,322.168 2062.14,322.144 2062.15,322.12 2062.16,322.097 2062.17,322.073 2062.18,322.049 2062.19,322.025 2062.2,322.001 2062.21,321.977 2062.22,321.953 2062.23,321.929 2062.24,321.905 2062.25,321.882 2062.25,321.858 2062.26,321.834 2062.27,321.81 2062.28,321.786 2062.29,321.762 2062.3,321.738 2062.31,321.715 2062.32,321.691 2062.33,321.667 2062.34,321.643 2062.35,321.619 2062.36,321.595 2062.37,321.571 2062.37,321.548 2062.38,321.524 2062.39,321.5 2062.4,321.476 2062.41,321.452 2062.42,321.428 2062.43,321.405 2062.44,321.381 2062.45,321.357 2062.46,321.333 2062.47,321.309 2062.48,321.286 2062.48,321.262 2062.49,321.238 2062.5,321.214 2062.51,321.19 2062.52,321.167 2062.53,321.143 2062.54,321.119 2062.55,321.095 2062.56,321.071 2062.57,321.048 2062.58,321.024 2062.59,321 2062.59,320.976 2062.6,320.952 2062.61,320.929 2062.62,320.905 2062.63,320.881 2062.64,320.857 2062.65,320.834 2062.66,320.81 2062.67,320.786 2062.68,320.762 2062.69,320.739 2062.7,320.715 2062.71,320.691 2062.71,320.667 2062.72,320.644 2062.73,320.62 2062.74,320.596 2062.75,320.572 2062.76,320.549 2062.77,320.525 2062.78,320.501 2062.79,320.477 2062.8,320.454 2062.81,320.43 2062.82,320.406 2062.82,320.382 2062.83,320.359 2062.84,320.335 2062.85,320.311 2062.86,320.288 2062.87,320.264 2062.88,320.24 2062.89,320.216 2062.9,320.193 2062.91,320.169 2062.92,320.145 2062.93,320.122 2062.93,320.098 2062.94,320.074 2062.95,320.051 2062.96,320.027 2062.97,320.003 2062.98,319.979 2062.99,319.956 2063,319.932 2063.01,319.908 2063.02,319.885 2063.03,319.861 2063.04,319.837 2063.05,319.814 2063.05,319.79 2063.06,319.766 2063.07,319.743 2063.08,319.719 2063.09,319.695 2063.1,319.672 2063.11,319.648 2063.12,319.625 2063.13,319.601 2063.14,319.577 2063.15,319.554 2063.16,319.53 2063.16,319.506 2063.17,319.483 2063.18,319.459 2063.19,319.435 2063.2,319.412 2063.21,319.388 2063.22,319.365 2063.23,319.341 2063.24,319.317 2063.25,319.294 2063.26,319.27 2063.27,319.247 2063.27,319.223 2063.28,319.199 2063.29,319.176 2063.3,319.152 2063.31,319.129 2063.32,319.105 2063.33,319.081 2063.34,319.058 2063.35,319.034 2063.36,319.011 2063.37,318.987 2063.38,318.963 2063.39,318.94 2063.39,318.916 2063.4,318.893 2063.41,318.869 2063.42,318.846 2063.43,318.822 2063.44,318.798 2063.45,318.775 2063.46,318.751 2063.47,318.728 2063.48,318.704 2063.49,318.681 2063.5,318.657 2063.5,318.634 2063.51,318.61 2063.52,318.586 2063.53,318.563 2063.54,318.539 2063.55,318.516 2063.56,318.492 2063.57,318.469 2063.58,318.445 2063.59,318.422 2063.6,318.398 2063.61,318.375 2063.61,318.351 2063.62,318.328 2063.63,318.304 2063.64,318.281 2063.65,318.257 2063.66,318.234 2063.67,318.21 2063.68,318.187 2063.69,318.163 2063.7,318.14 2063.71,318.116 2063.72,318.093 2063.73,318.069 2063.73,318.046 2063.74,318.022 2063.75,317.999 2063.76,317.975 2063.77,317.952 2063.78,317.928 2063.79,317.905 2063.8,317.881 2063.81,317.858 2063.82,317.834 2063.83,317.811 2063.84,317.787 2063.84,317.764 2063.85,317.74 2063.86,317.717 2063.87,317.694 2063.88,317.67 2063.89,317.647 2063.9,317.623 2063.91,317.6 2063.92,317.576 2063.93,317.553 2063.94,317.529 2063.95,317.506 2063.95,317.483 2063.96,317.459 2063.97,317.436 2063.98,317.412 2063.99,317.389 2064,317.365 2064.01,317.342 2064.02,317.319 2064.03,317.295 2064.04,317.272 2064.05,317.248 2064.06,317.225 2064.07,317.202 2064.07,317.178 2064.08,317.155 2064.09,317.131 2064.1,317.108 2064.11,317.085 2064.12,317.061 2064.13,317.038 2064.14,317.014 2064.15,316.991 2064.16,316.968 2064.17,316.944 2064.18,316.921 2064.18,316.898 2064.19,316.874 2064.2,316.851 2064.21,316.827 2064.22,316.804 2064.23,316.781 2064.24,316.757 2064.25,316.734 2064.26,316.711 2064.27,316.687 2064.28,316.664 2064.29,316.641 2064.29,316.617 2064.3,316.594 2064.31,316.571 2064.32,316.547 2064.33,316.524 2064.34,316.501 2064.35,316.477 2064.36,316.454 2064.37,316.431 2064.38,316.407 2064.39,316.384 2064.4,316.361 2064.41,316.337 2064.41,316.314 2064.42,316.291 2064.43,316.267 2064.44,316.244 2064.45,316.221 2064.46,316.198 2064.47,316.174 2064.48,316.151 2064.49,316.128 2064.5,316.104 2064.51,316.081 2064.52,316.058 2064.52,316.034 2064.53,316.011 2064.54,315.988 2064.55,315.965 2064.56,315.941 2064.57,315.918 2064.58,315.895 2064.59,315.872 2064.6,315.848 2064.61,315.825 2064.62,315.802 2064.63,315.778 2064.63,315.755 2064.64,315.732 2064.65,315.709 2064.66,315.685 2064.67,315.662 2064.68,315.639 2064.69,315.616 2064.7,315.592 2064.71,315.569 2064.72,315.546 2064.73,315.523 2064.74,315.5 2064.75,315.476 2064.75,315.453 2064.76,315.43 2064.77,315.407 2064.78,315.383 2064.79,315.36 2064.8,315.337 2064.81,315.314 2064.82,315.291 2064.83,315.267 2064.84,315.244 2064.85,315.221 2064.86,315.198 2064.86,315.175 2064.87,315.151 2064.88,315.128 2064.89,315.105 2064.9,315.082 2064.91,315.059 2064.92,315.035 2064.93,315.012 2064.94,314.989 2064.95,314.966 2064.96,314.943 2064.97,314.92 2064.97,314.896 2064.98,314.873 2064.99,314.85 2065,314.827 2065.01,314.804 2065.02,314.781 2065.03,314.757 2065.04,314.734 2065.05,314.711 2065.06,314.688 2065.07,314.665 2065.08,314.642 2065.09,314.619 2065.09,314.595 2065.1,314.572 2065.11,314.549 2065.12,314.526 2065.13,314.503 2065.14,314.48 2065.15,314.457 2065.16,314.433 2065.17,314.41 2065.18,314.387 2065.19,314.364 2065.2,314.341 2065.2,314.318 2065.21,314.295 2065.22,314.272 2065.23,314.249 2065.24,314.225 2065.25,314.202 2065.26,314.179 2065.27,314.156 2065.28,314.133 2065.29,314.11 2065.3,314.087 2065.31,314.064 2065.31,314.041 2065.32,314.018 2065.33,313.995 2065.34,313.971 2065.35,313.948 2065.36,313.925 2065.37,313.902 2065.38,313.879 2065.39,313.856 2065.4,313.833 2065.41,313.81 2065.42,313.787 2065.43,313.764 2065.43,313.741 2065.44,313.718 2065.45,313.695 2065.46,313.672 2065.47,313.649 2065.48,313.626 2065.49,313.603 2065.5,313.58 2065.51,313.557 2065.52,313.533 2065.53,313.51 2065.54,313.487 2065.54,313.464 2065.55,313.441 2065.56,313.418 2065.57,313.395 2065.58,313.372 2065.59,313.349 2065.6,313.326 2065.61,313.303 2065.62,313.28 2065.63,313.257 2065.64,313.234 2065.65,313.211 2065.65,313.188 2065.66,313.165 2065.67,313.142 2065.68,313.119 2065.69,313.096 2065.7,313.073 2065.71,313.05 2065.72,313.027 2065.73,313.004 2065.74,312.981 2065.75,312.958 2065.76,312.935 2065.77,312.913 2065.77,312.89 2065.78,312.867 2065.79,312.844 2065.8,312.821 2065.81,312.798 2065.82,312.775 2065.83,312.752 2065.84,312.729 2065.85,312.706 2065.86,312.683 2065.87,312.66 2065.88,312.637 2065.88,312.614 2065.89,312.591 2065.9,312.568 2065.91,312.545 2065.92,312.522 2065.93,312.499 2065.94,312.477 2065.95,312.454 2065.96,312.431 2065.97,312.408 2065.98,312.385 2065.99,312.362 2065.99,312.339 2066,312.316 2066.01,312.293 2066.02,312.27 2066.03,312.247 2066.04,312.225 2066.05,312.202 2066.06,312.179 2066.07,312.156 2066.08,312.133 2066.09,312.11 2066.1,312.087 2066.11,312.064 2066.11,312.041 2066.12,312.019 2066.13,311.996 2066.14,311.973 2066.15,311.95 2066.16,311.927 2066.17,311.904 2066.18,311.881 2066.19,311.858 2066.2,311.836 2066.21,311.813 2066.22,311.79 2066.22,311.767 2066.23,311.744 2066.24,311.721 2066.25,311.698 2066.26,311.676 2066.27,311.653 2066.28,311.63 2066.29,311.607 2066.3,311.584 2066.31,311.561 2066.32,311.539 2066.33,311.516 2066.33,311.493 2066.34,311.47 2066.35,311.447 2066.36,311.425 2066.37,311.402 2066.38,311.379 2066.39,311.356 2066.4,311.333 2066.41,311.31 2066.42,311.288 2066.43,311.265 2066.44,311.242 2066.45,311.219 2066.45,311.196 2066.46,311.174 2066.47,311.151 2066.48,311.128 2066.49,311.105 2066.5,311.083 2066.51,311.06 2066.52,311.037 2066.53,311.014 2066.54,310.991 2066.55,310.969 2066.56,310.946 2066.56,310.923 2066.57,310.9 2066.58,310.878 2066.59,310.855 2066.6,310.832 2066.61,310.809 2066.62,310.787 2066.63,310.764 2066.64,310.741 2066.65,310.718 2066.66,310.696 2066.67,310.673 2066.67,310.65 2066.68,310.627 2066.69,310.605 2066.7,310.582 2066.71,310.559 2066.72,310.536 2066.73,310.514 2066.74,310.491 2066.75,310.468 2066.76,310.446 2066.77,310.423 2066.78,310.4 2066.79,310.377 2066.79,310.355 2066.8,310.332 2066.81,310.309 2066.82,310.287 2066.83,310.264 2066.84,310.241 2066.85,310.219 2066.86,310.196 2066.87,310.173 2066.88,310.15 2066.89,310.128 2066.9,310.105 2066.9,310.082 2066.91,310.06 2066.92,310.037 2066.93,310.014 2066.94,309.992 2066.95,309.969 2066.96,309.946 2066.97,309.924 2066.98,309.901 2066.99,309.878 2067,309.856 2067.01,309.833 2067.01,309.81 2067.02,309.788 2067.03,309.765 2067.04,309.743 2067.05,309.72 2067.06,309.697 2067.07,309.675 2067.08,309.652 2067.09,309.629 2067.1,309.607 2067.11,309.584 2067.12,309.561 2067.13,309.539 2067.13,309.516 2067.14,309.494 2067.15,309.471 2067.16,309.448 2067.17,309.426 2067.18,309.403 2067.19,309.38 2067.2,309.358 2067.21,309.335 2067.22,309.313 2067.23,309.29 2067.24,309.267 2067.24,309.245 2067.25,309.222 2067.26,309.2 2067.27,309.177 2067.28,309.155 2067.29,309.132 2067.3,309.109 2067.31,309.087 2067.32,309.064 2067.33,309.042 2067.34,309.019 2067.35,308.996 2067.35,308.974 2067.36,308.951 2067.37,308.929 2067.38,308.906 2067.39,308.884 2067.4,308.861 2067.41,308.839 2067.42,308.816 2067.43,308.793 2067.44,308.771 2067.45,308.748 2067.46,308.726 2067.47,308.703 2067.47,308.681 2067.48,308.658 2067.49,308.636 2067.5,308.613 2067.51,308.591 2067.52,308.568 2067.53,308.546 2067.54,308.523 2067.55,308.501 2067.56,308.478 2067.57,308.456 2067.58,308.433 2067.58,308.411 2067.59,308.388 2067.6,308.365 2067.61,308.343 2067.62,308.32 2067.63,308.298 2067.64,308.276 2067.65,308.253 2067.66,308.231 2067.67,308.208 2067.68,308.186 2067.69,308.163 2067.69,308.141 2067.7,308.118 2067.71,308.096 2067.72,308.073 2067.73,308.051 2067.74,308.028 2067.75,308.006 2067.76,307.983 2067.77,307.961 2067.78,307.938 2067.79,307.916 2067.8,307.893 2067.81,307.871 2067.81,307.849 2067.82,307.826 2067.83,307.804 2067.84,307.781 2067.85,307.759 2067.86,307.736 2067.87,307.714 2067.88,307.691 2067.89,307.669 2067.9,307.647 2067.91,307.624 2067.92,307.602 2067.92,307.579 2067.93,307.557 2067.94,307.534 2067.95,307.512 2067.96,307.49 2067.97,307.467 2067.98,307.445 2067.99,307.422 2068,307.4 2068.01,307.378 2068.02,307.355 2068.03,307.333 2068.03,307.31 2068.04,307.288 2068.05,307.266 2068.06,307.243 2068.07,307.221 2068.08,307.198 2068.09,307.176 2068.1,307.154 2068.11,307.131 2068.12,307.109 2068.13,307.087 2068.14,307.064 2068.15,307.042 2068.15,307.019 2068.16,306.997 2068.17,306.975 2068.18,306.952 2068.19,306.93 2068.2,306.908 2068.21,306.885 2068.22,306.863 2068.23,306.841 2068.24,306.818 2068.25,306.796 2068.26,306.774 2068.26,306.751 2068.27,306.729 2068.28,306.707 2068.29,306.684 2068.3,306.662 2068.31,306.64 2068.32,306.617 2068.33,306.595 2068.34,306.573 2068.35,306.55 2068.36,306.528 2068.37,306.506 2068.37,306.483 2068.38,306.461 2068.39,306.439 2068.4,306.416 2068.41,306.394 2068.42,306.372 2068.43,306.35 2068.44,306.327 2068.45,306.305 2068.46,306.283 2068.47,306.26 2068.48,306.238 2068.49,306.216 2068.49,306.193 2068.5,306.171 2068.51,306.149 2068.52,306.127 2068.53,306.104 2068.54,306.082 2068.55,306.06 2068.56,306.038 2068.57,306.015 2068.58,305.993 2068.59,305.971 2068.6,305.949 2068.6,305.926 2068.61,305.904 2068.62,305.882 2068.63,305.86 2068.64,305.837 2068.65,305.815 2068.66,305.793 2068.67,305.771 2068.68,305.748 2068.69,305.726 2068.7,305.704 2068.71,305.682 2068.71,305.659 2068.72,305.637 2068.73,305.615 2068.74,305.593 2068.75,305.571 2068.76,305.548 2068.77,305.526 2068.78,305.504 2068.79,305.482 2068.8,305.459 2068.81,305.437 2068.82,305.415 2068.83,305.393 2068.83,305.371 2068.84,305.348 2068.85,305.326 2068.86,305.304 2068.87,305.282 2068.88,305.26 2068.89,305.238 2068.9,305.215 2068.91,305.193 2068.92,305.171 2068.93,305.149 2068.94,305.127 2068.94,305.105 2068.95,305.082 2068.96,305.06 2068.97,305.038 2068.98,305.016 2068.99,304.994 2069,304.972 2069.01,304.949 2069.02,304.927 2069.03,304.905 2069.04,304.883 2069.05,304.861 2069.05,304.839 2069.06,304.817 2069.07,304.794 2069.08,304.772 2069.09,304.75 2069.1,304.728 2069.11,304.706 2069.12,304.684 2069.13,304.662 2069.14,304.639 2069.15,304.617 2069.16,304.595 2069.17,304.573 2069.17,304.551 2069.18,304.529 2069.19,304.507 2069.2,304.485 2069.21,304.463 2069.22,304.44 2069.23,304.418 2069.24,304.396 2069.25,304.374 2069.26,304.352 2069.27,304.33 2069.28,304.308 2069.28,304.286 2069.29,304.264 2069.3,304.242 2069.31,304.22 2069.32,304.198 2069.33,304.175 2069.34,304.153 2069.35,304.131 2069.36,304.109 2069.37,304.087 2069.38,304.065 2069.39,304.043 2069.39,304.021 2069.4,303.999 2069.41,303.977 2069.42,303.955 2069.43,303.933 2069.44,303.911 2069.45,303.889 2069.46,303.867 2069.47,303.845 2069.48,303.823 2069.49,303.801 2069.5,303.779 2069.51,303.756 2069.51,303.734 2069.52,303.712 2069.53,303.69 2069.54,303.668 2069.55,303.646 2069.56,303.624 2069.57,303.602 2069.58,303.58 2069.59,303.558 2069.6,303.536 2069.61,303.514 2069.62,303.492 2069.62,303.47 2069.63,303.448 2069.64,303.426 2069.65,303.404 2069.66,303.382 2069.67,303.36 2069.68,303.338 2069.69,303.316 2069.7,303.294 2069.71,303.272 2069.72,303.25 2069.73,303.228 2069.73,303.206 2069.74,303.184 2069.75,303.163 2069.76,303.141 2069.77,303.119 2069.78,303.097 2069.79,303.075 2069.8,303.053 2069.81,303.031 2069.82,303.009 2069.83,302.987 2069.84,302.965 2069.85,302.943 2069.85,302.921 2069.86,302.899 2069.87,302.877 2069.88,302.855 2069.89,302.833 2069.9,302.811 2069.91,302.789 2069.92,302.767 2069.93,302.746 2069.94,302.724 2069.95,302.702 2069.96,302.68 2069.96,302.658 2069.97,302.636 2069.98,302.614 2069.99,302.592 2070,302.57 2070.01,302.548 2070.02,302.526 2070.03,302.505 2070.04,302.483 2070.05,302.461 2070.06,302.439 2070.07,302.417 2070.07,302.395 2070.08,302.373 2070.09,302.351 2070.1,302.329 2070.11,302.307 2070.12,302.286 2070.13,302.264 2070.14,302.242 2070.15,302.22 2070.16,302.198 2070.17,302.176 2070.18,302.154 2070.19,302.133 2070.19,302.111 2070.2,302.089 2070.21,302.067 2070.22,302.045 2070.23,302.023 2070.24,302.001 2070.25,301.98 2070.26,301.958 2070.27,301.936 2070.28,301.914 2070.29,301.892 2070.3,301.87 2070.3,301.849 2070.31,301.827 2070.32,301.805 2070.33,301.783 2070.34,301.761 2070.35,301.739 2070.36,301.718 2070.37,301.696 2070.38,301.674 2070.39,301.652 2070.4,301.63 2070.41,301.609 2070.41,301.587 2070.42,301.565 2070.43,301.543 2070.44,301.521 2070.45,301.5 2070.46,301.478 2070.47,301.456 2070.48,301.434 2070.49,301.412 2070.5,301.391 2070.51,301.369 2070.52,301.347 2070.53,301.325 2070.53,301.303 2070.54,301.282 2070.55,301.26 2070.56,301.238 2070.57,301.216 2070.58,301.195 2070.59,301.173 2070.6,301.151 2070.61,301.129 2070.62,301.108 2070.63,301.086 2070.64,301.064 2070.64,301.042 2070.65,301.021 2070.66,300.999 2070.67,300.977 2070.68,300.955 2070.69,300.934 2070.7,300.912 2070.71,300.89 2070.72,300.868 2070.73,300.847 2070.74,300.825 2070.75,300.803 2070.75,300.781 2070.76,300.76 2070.77,300.738 2070.78,300.716 2070.79,300.695 2070.8,300.673 2070.81,300.651 2070.82,300.629 2070.83,300.608 2070.84,300.586 2070.85,300.564 2070.86,300.543 2070.87,300.521 2070.87,300.499 2070.88,300.478 2070.89,300.456 2070.9,300.434 2070.91,300.413 2070.92,300.391 2070.93,300.369 2070.94,300.347 2070.95,300.326 2070.96,300.304 2070.97,300.282 2070.98,300.261 2070.98,300.239 2070.99,300.217 2071,300.196 2071.01,300.174 2071.02,300.152 2071.03,300.131 2071.04,300.109 2071.05,300.088 2071.06,300.066 2071.07,300.044 2071.08,300.023 2071.09,300.001 2071.09,299.979 2071.1,299.958 2071.11,299.936 2071.12,299.914 2071.13,299.893 2071.14,299.871 2071.15,299.85 2071.16,299.828 2071.17,299.806 2071.18,299.785 2071.19,299.763 2071.2,299.741 2071.21,299.72 2071.21,299.698 2071.22,299.677 2071.23,299.655 2071.24,299.633 2071.25,299.612 2071.26,299.59 2071.27,299.569 2071.28,299.547 2071.29,299.525 2071.3,299.504 2071.31,299.482 2071.32,299.461 2071.32,299.439 2071.33,299.417 2071.34,299.396 2071.35,299.374 2071.36,299.353 2071.37,299.331 2071.38,299.31 2071.39,299.288 2071.4,299.266 2071.41,299.245 2071.42,299.223 2071.43,299.202 2071.43,299.18 2071.44,299.159 2071.45,299.137 2071.46,299.116 2071.47,299.094 2071.48,299.073 2071.49,299.051 2071.5,299.029 2071.51,299.008 2071.52,298.986 2071.53,298.965 2071.54,298.943 2071.55,298.922 2071.55,298.9 2071.56,298.879 2071.57,298.857 2071.58,298.836 2071.59,298.814 2071.6,298.793 2071.61,298.771 2071.62,298.75 2071.63,298.728 2071.64,298.707 2071.65,298.685 2071.66,298.664 2071.66,298.642 2071.67,298.621 2071.68,298.599 2071.69,298.578 2071.7,298.556 2071.71,298.535 2071.72,298.513 2071.73,298.492 2071.74,298.47 2071.75,298.449 2071.76,298.427 2071.77,298.406 2071.77,298.384 2071.78,298.363 2071.79,298.341 2071.8,298.32 2071.81,298.298 2071.82,298.277 2071.83,298.255 2071.84,298.234 2071.85,298.213 2071.86,298.191 2071.87,298.17 2071.88,298.148 2071.89,298.127 2071.89,298.105 2071.9,298.084 2071.91,298.062 2071.92,298.041 2071.93,298.02 2071.94,297.998 2071.95,297.977 2071.96,297.955 2071.97,297.934 2071.98,297.912 2071.99,297.891 2072,297.87 2072,297.848 2072.01,297.827 2072.02,297.805 2072.03,297.784 2072.04,297.762 2072.05,297.741 2072.06,297.72 2072.07,297.698 2072.08,297.677 2072.09,297.655 2072.1,297.634 2072.11,297.613 2072.11,297.591 2072.12,297.57 2072.13,297.549 2072.14,297.527 2072.15,297.506 2072.16,297.484 2072.17,297.463 2072.18,297.442 2072.19,297.42 2072.2,297.399 2072.21,297.378 2072.22,297.356 2072.23,297.335 2072.23,297.313 2072.24,297.292 2072.25,297.271 2072.26,297.249 2072.27,297.228 2072.28,297.207 2072.29,297.185 2072.3,297.164 2072.31,297.143 2072.32,297.121 2072.33,297.1 2072.34,297.079 2072.34,297.057 2072.35,297.036 2072.36,297.015 2072.37,296.993 2072.38,296.972 2072.39,296.951 2072.4,296.929 2072.41,296.908 2072.42,296.887 2072.43,296.865 2072.44,296.844 2072.45,296.823 2072.45,296.801 2072.46,296.78 2072.47,296.759 2072.48,296.737 2072.49,296.716 2072.5,296.695 2072.51,296.674 2072.52,296.652 2072.53,296.631 2072.54,296.61 2072.55,296.588 2072.56,296.567 2072.57,296.546 2072.57,296.525 2072.58,296.503 2072.59,296.482 2072.6,296.461 2072.61,296.439 2072.62,296.418 2072.63,296.397 2072.64,296.376 2072.65,296.354 2072.66,296.333 2072.67,296.312 2072.68,296.291 2072.68,296.269 2072.69,296.248 2072.7,296.227 2072.71,296.206 2072.72,296.184 2072.73,296.163 2072.74,296.142 2072.75,296.121 2072.76,296.099 2072.77,296.078 2072.78,296.057 2072.79,296.036 2072.79,296.015 2072.8,295.993 2072.81,295.972 2072.82,295.951 2072.83,295.93 2072.84,295.908 2072.85,295.887 2072.86,295.866 2072.87,295.845 2072.88,295.824 2072.89,295.802 2072.9,295.781 2072.91,295.76 2072.91,295.739 2072.92,295.718 2072.93,295.696 2072.94,295.675 2072.95,295.654 2072.96,295.633 2072.97,295.612 2072.98,295.59 2072.99,295.569 2073,295.548 2073.01,295.527 2073.02,295.506 2073.02,295.485 2073.03,295.463 2073.04,295.442 2073.05,295.421 2073.06,295.4 2073.07,295.379 2073.08,295.358 2073.09,295.336 2073.1,295.315 2073.11,295.294 2073.12,295.273 2073.13,295.252 2073.14,295.231 2073.14,295.21 2073.15,295.188 2073.16,295.167 2073.17,295.146 2073.18,295.125 2073.19,295.104 2073.2,295.083 2073.21,295.062 2073.22,295.041 2073.23,295.019 2073.24,294.998 2073.25,294.977 2073.25,294.956 2073.26,294.935 2073.27,294.914 2073.28,294.893 2073.29,294.872 2073.3,294.851 2073.31,294.829 2073.32,294.808 2073.33,294.787 2073.34,294.766 2073.35,294.745 2073.36,294.724 2073.36,294.703 2073.37,294.682 2073.38,294.661 2073.39,294.64 2073.4,294.619 2073.41,294.597 2073.42,294.576 2073.43,294.555 2073.44,294.534 2073.45,294.513 2073.46,294.492 2073.47,294.471 2073.48,294.45 2073.48,294.429 2073.49,294.408 2073.5,294.387 2073.51,294.366 2073.52,294.345 2073.53,294.324 2073.54,294.303 2073.55,294.282 2073.56,294.26 2073.57,294.239 2073.58,294.218 2073.59,294.197 2073.59,294.176 2073.6,294.155 2073.61,294.134 2073.62,294.113 2073.63,294.092 2073.64,294.071 2073.65,294.05 2073.66,294.029 2073.67,294.008 2073.68,293.987 2073.69,293.966 2073.7,293.945 2073.7,293.924 2073.71,293.903 2073.72,293.882 2073.73,293.861 2073.74,293.84 2073.75,293.819 2073.76,293.798 2073.77,293.777 2073.78,293.756 2073.79,293.735 2073.8,293.714 2073.81,293.693 2073.82,293.672 2073.82,293.651 2073.83,293.63 2073.84,293.609 2073.85,293.588 2073.86,293.567 2073.87,293.546 2073.88,293.525 2073.89,293.504 2073.9,293.483 2073.91,293.462 2073.92,293.442 2073.93,293.421 2073.93,293.4 2073.94,293.379 2073.95,293.358 2073.96,293.337 2073.97,293.316 2073.98,293.295 2073.99,293.274 2074,293.253 2074.01,293.232 2074.02,293.211 2074.03,293.19 2074.04,293.169 2074.04,293.148 2074.05,293.127 2074.06,293.106 2074.07,293.086 2074.08,293.065 2074.09,293.044 2074.1,293.023 2074.11,293.002 2074.12,292.981 2074.13,292.96 2074.14,292.939 2074.15,292.918 2074.16,292.897 2074.16,292.876 2074.17,292.856 2074.18,292.835 2074.19,292.814 2074.2,292.793 2074.21,292.772 2074.22,292.751 2074.23,292.73 2074.24,292.709 2074.25,292.689 2074.26,292.668 2074.27,292.647 2074.27,292.626 2074.28,292.605 2074.29,292.584 2074.3,292.563 2074.31,292.542 2074.32,292.522 2074.33,292.501 2074.34,292.48 2074.35,292.459 2074.36,292.438 2074.37,292.417 2074.38,292.396 2074.38,292.376 2074.39,292.355 2074.4,292.334 2074.41,292.313 2074.42,292.292 2074.43,292.271 2074.44,292.251 2074.45,292.23 2074.46,292.209 2074.47,292.188 2074.48,292.167 2074.49,292.146 2074.5,292.126 2074.5,292.105 2074.51,292.084 2074.52,292.063 2074.53,292.042 2074.54,292.022 2074.55,292.001 2074.56,291.98 2074.57,291.959 2074.58,291.938 2074.59,291.918 2074.6,291.897 2074.61,291.876 2074.61,291.855 2074.62,291.834 2074.63,291.814 2074.64,291.793 2074.65,291.772 2074.66,291.751 2074.67,291.73 2074.68,291.71 2074.69,291.689 2074.7,291.668 2074.71,291.647 2074.72,291.627 2074.72,291.606 2074.73,291.585 2074.74,291.564 2074.75,291.544 2074.76,291.523 2074.77,291.502 2074.78,291.481 2074.79,291.461 2074.8,291.44 2074.81,291.419 2074.82,291.398 2074.83,291.378 2074.84,291.357 2074.84,291.336 2074.85,291.315 2074.86,291.295 2074.87,291.274 2074.88,291.253 2074.89,291.232 2074.9,291.212 2074.91,291.191 2074.92,291.17 2074.93,291.15 2074.94,291.129 2074.95,291.108 2074.95,291.087 2074.96,291.067 2074.97,291.046 2074.98,291.025 2074.99,291.005 2075,290.984 2075.01,290.963 2075.02,290.943 2075.03,290.922 2075.04,290.901 2075.05,290.88 2075.06,290.86 2075.06,290.839 2075.07,290.818 2075.08,290.798 2075.09,290.777 2075.1,290.756 2075.11,290.736 2075.12,290.715 2075.13,290.694 2075.14,290.674 2075.15,290.653 2075.16,290.632 2075.17,290.612 2075.18,290.591 2075.18,290.57 2075.19,290.55 2075.2,290.529 2075.21,290.508 2075.22,290.488 2075.23,290.467 2075.24,290.447 2075.25,290.426 2075.26,290.405 2075.27,290.385 2075.28,290.364 2075.29,290.343 2075.29,290.323 2075.3,290.302 2075.31,290.281 2075.32,290.261 2075.33,290.24 2075.34,290.22 2075.35,290.199 2075.36,290.178 2075.37,290.158 2075.38,290.137 2075.39,290.117 2075.4,290.096 2075.4,290.075 2075.41,290.055 2075.42,290.034 2075.43,290.014 2075.44,289.993 2075.45,289.972 2075.46,289.952 2075.47,289.931 2075.48,289.911 2075.49,289.89 2075.5,289.869 2075.51,289.849 2075.52,289.828 2075.52,289.808 2075.53,289.787 2075.54,289.767 2075.55,289.746 2075.56,289.725 2075.57,289.705 2075.58,289.684 2075.59,289.664 2075.6,289.643 2075.61,289.623 2075.62,289.602 2075.63,289.581 2075.63,289.561 2075.64,289.54 2075.65,289.52 2075.66,289.499 2075.67,289.479 2075.68,289.458 2075.69,289.438 2075.7,289.417 2075.71,289.397 2075.72,289.376 2075.73,289.356 2075.74,289.335 2075.74,289.314 2075.75,289.294 2075.76,289.273 2075.77,289.253 2075.78,289.232 2075.79,289.212 2075.8,289.191 2075.81,289.171 2075.82,289.15 2075.83,289.13 2075.84,289.109 2075.85,289.089 2075.86,289.068 2075.86,289.048 2075.87,289.027 2075.88,289.007 2075.89,288.986 2075.9,288.966 2075.91,288.945 2075.92,288.925 2075.93,288.904 2075.94,288.884 2075.95,288.864 2075.96,288.843 2075.97,288.823 2075.97,288.802 2075.98,288.782 2075.99,288.761 2076,288.741 2076.01,288.72 2076.02,288.7 2076.03,288.679 2076.04,288.659 2076.05,288.638 2076.06,288.618 2076.07,288.598 2076.08,288.577 2076.08,288.557 2076.09,288.536 2076.1,288.516 2076.11,288.495 2076.12,288.475 2076.13,288.454 2076.14,288.434 2076.15,288.414 2076.16,288.393 2076.17,288.373 2076.18,288.352 2076.19,288.332 2076.2,288.311 2076.2,288.291 2076.21,288.271 2076.22,288.25 2076.23,288.23 2076.24,288.209 2076.25,288.189 2076.26,288.169 2076.27,288.148 2076.28,288.128 2076.29,288.107 2076.3,288.087 2076.31,288.067 2076.31,288.046 2076.32,288.026 2076.33,288.005 2076.34,287.985 2076.35,287.965 2076.36,287.944 2076.37,287.924 2076.38,287.904 2076.39,287.883 2076.4,287.863 2076.41,287.842 2076.42,287.822 2076.42,287.802 2076.43,287.781 2076.44,287.761 2076.45,287.741 2076.46,287.72 2076.47,287.7 2076.48,287.68 2076.49,287.659 2076.5,287.639 2076.51,287.619 2076.52,287.598 2076.53,287.578 2076.54,287.557 2076.54,287.537 2076.55,287.517 2076.56,287.496 2076.57,287.476 2076.58,287.456 2076.59,287.436 2076.6,287.415 2076.61,287.395 2076.62,287.375 2076.63,287.354 2076.64,287.334 2076.65,287.314 2076.65,287.293 2076.66,287.273 2076.67,287.253 2076.68,287.232 2076.69,287.212 2076.7,287.192 2076.71,287.171 2076.72,287.151 2076.73,287.131 2076.74,287.111 2076.75,287.09 2076.76,287.07 2076.76,287.05 2076.77,287.029 2076.78,287.009 2076.79,286.989 2076.8,286.969 2076.81,286.948 2076.82,286.928 2076.83,286.908 2076.84,286.888 2076.85,286.867 2076.86,286.847 2076.87,286.827 2076.88,286.806 2076.88,286.786 2076.89,286.766 2076.9,286.746 2076.91,286.725 2076.92,286.705 2076.93,286.685 2076.94,286.665 2076.95,286.644 2076.96,286.624 2076.97,286.604 2076.98,286.584 2076.99,286.564 2076.99,286.543 2077,286.523 2077.01,286.503 2077.02,286.483 2077.03,286.462 2077.04,286.442 2077.05,286.422 2077.06,286.402 2077.07,286.382 2077.08,286.361 2077.09,286.341 2077.1,286.321 2077.1,286.301 2077.11,286.28 2077.12,286.26 2077.13,286.24 2077.14,286.22 2077.15,286.2 2077.16,286.179 2077.17,286.159 2077.18,286.139 2077.19,286.119 2077.2,286.099 2077.21,286.079 2077.22,286.058 2077.22,286.038 2077.23,286.018 2077.24,285.998 2077.25,285.978 2077.26,285.957 2077.27,285.937 2077.28,285.917 2077.29,285.897 2077.3,285.877 2077.31,285.857 2077.32,285.837 2077.33,285.816 2077.33,285.796 2077.34,285.776 2077.35,285.756 2077.36,285.736 2077.37,285.716 2077.38,285.695 2077.39,285.675 2077.4,285.655 2077.41,285.635 2077.42,285.615 2077.43,285.595 2077.44,285.575 2077.44,285.555 2077.45,285.534 2077.46,285.514 2077.47,285.494 2077.48,285.474 2077.49,285.454 2077.5,285.434 2077.51,285.414 2077.52,285.394 2077.53,285.374 2077.54,285.353 2077.55,285.333 2077.56,285.313 2077.56,285.293 2077.57,285.273 2077.58,285.253 2077.59,285.233 2077.6,285.213 2077.61,285.193 2077.62,285.173 2077.63,285.152 2077.64,285.132 2077.65,285.112 2077.66,285.092 2077.67,285.072 2077.67,285.052 2077.68,285.032 2077.69,285.012 2077.7,284.992 2077.71,284.972 2077.72,284.952 2077.73,284.932 2077.74,284.912 2077.75,284.892 2077.76,284.871 2077.77,284.851 2077.78,284.831 2077.78,284.811 2077.79,284.791 2077.8,284.771 2077.81,284.751 2077.82,284.731 2077.83,284.711 2077.84,284.691 2077.85,284.671 2077.86,284.651 2077.87,284.631 2077.88,284.611 2077.89,284.591 2077.9,284.571 2077.9,284.551 2077.91,284.531 2077.92,284.511 2077.93,284.491 2077.94,284.471 2077.95,284.451 2077.96,284.431 2077.97,284.411 2077.98,284.391 2077.99,284.371 2078,284.351 2078.01,284.331 2078.01,284.311 2078.02,284.291 2078.03,284.271 2078.04,284.251 2078.05,284.231 2078.06,284.211 2078.07,284.191 2078.08,284.171 2078.09,284.151 2078.1,284.131 2078.11,284.111 2078.12,284.091 2078.12,284.071 2078.13,284.051 2078.14,284.031 2078.15,284.011 2078.16,283.991 2078.17,283.971 2078.18,283.951 2078.19,283.931 2078.2,283.911 2078.21,283.891 2078.22,283.871 2078.23,283.851 2078.24,283.832 2078.24,283.812 2078.25,283.792 2078.26,283.772 2078.27,283.752 2078.28,283.732 2078.29,283.712 2078.3,283.692 2078.31,283.672 2078.32,283.652 2078.33,283.632 2078.34,283.612 2078.35,283.592 2078.35,283.572 2078.36,283.553 2078.37,283.533 2078.38,283.513 2078.39,283.493 2078.4,283.473 2078.41,283.453 2078.42,283.433 2078.43,283.413 2078.44,283.393 2078.45,283.373 2078.46,283.353 2078.46,283.334 2078.47,283.314 2078.48,283.294 2078.49,283.274 2078.5,283.254 2078.51,283.234 2078.52,283.214 2078.53,283.194 2078.54,283.175 2078.55,283.155 2078.56,283.135 2078.57,283.115 2078.58,283.095 2078.58,283.075 2078.59,283.055 2078.6,283.035 2078.61,283.016 2078.62,282.996 2078.63,282.976 2078.64,282.956 2078.65,282.936 2078.66,282.916 2078.67,282.897 2078.68,282.877 2078.69,282.857 2078.69,282.837 2078.7,282.817 2078.71,282.797 2078.72,282.777 2078.73,282.758 2078.74,282.738 2078.75,282.718 2078.76,282.698 2078.77,282.678 2078.78,282.659 2078.79,282.639 2078.8,282.619 2078.8,282.599 2078.81,282.579 2078.82,282.559 2078.83,282.54 2078.84,282.52 2078.85,282.5 2078.86,282.48 2078.87,282.46 2078.88,282.441 2078.89,282.421 2078.9,282.401 2078.91,282.381 2078.92,282.361 2078.92,282.342 2078.93,282.322 2078.94,282.302 2078.95,282.282 2078.96,282.263 2078.97,282.243 2078.98,282.223 2078.99,282.203 2079,282.183 2079.01,282.164 2079.02,282.144 2079.03,282.124 2079.03,282.104 2079.04,282.085 2079.05,282.065 2079.06,282.045 2079.07,282.025 2079.08,282.006 2079.09,281.986 2079.1,281.966 2079.11,281.946 2079.12,281.927 2079.13,281.907 2079.14,281.887 2079.14,281.867 2079.15,281.848 2079.16,281.828 2079.17,281.808 2079.18,281.788 2079.19,281.769 2079.2,281.749 2079.21,281.729 2079.22,281.71 2079.23,281.69 2079.24,281.67 2079.25,281.65 2079.26,281.631 2079.26,281.611 2079.27,281.591 2079.28,281.572 2079.29,281.552 2079.3,281.532 2079.31,281.513 2079.32,281.493 2079.33,281.473 2079.34,281.453 2079.35,281.434 2079.36,281.414 2079.37,281.394 2079.37,281.375 2079.38,281.355 2079.39,281.335 2079.4,281.316 2079.41,281.296 2079.42,281.276 2079.43,281.257 2079.44,281.237 2079.45,281.217 2079.46,281.198 2079.47,281.178 2079.48,281.158 2079.48,281.139 2079.49,281.119 2079.5,281.099 2079.51,281.08 2079.52,281.06 2079.53,281.04 2079.54,281.021 2079.55,281.001 2079.56,280.981 2079.57,280.962 2079.58,280.942 2079.59,280.922 2079.6,280.903 2079.6,280.883 2079.61,280.864 2079.62,280.844 2079.63,280.824 2079.64,280.805 2079.65,280.785 2079.66,280.765 2079.67,280.746 2079.68,280.726 2079.69,280.707 2079.7,280.687 2079.71,280.667 2079.71,280.648 2079.72,280.628 2079.73,280.609 2079.74,280.589 2079.75,280.569 2079.76,280.55 2079.77,280.53 2079.78,280.511 2079.79,280.491 2079.8,280.471 2079.81,280.452 2079.82,280.432 2079.82,280.413 2079.83,280.393 2079.84,280.374 2079.85,280.354 2079.86,280.334 2079.87,280.315 2079.88,280.295 2079.89,280.276 2079.9,280.256 2079.91,280.237 2079.92,280.217 2079.93,280.197 2079.94,280.178 2079.94,280.158 2079.95,280.139 2079.96,280.119 2079.97,280.1 2079.98,280.08 2079.99,280.061 2080,280.041 2080.01,280.021 2080.02,280.002 2080.03,279.982 2080.04,279.963 2080.05,279.943 2080.05,279.924 2080.06,279.904 2080.07,279.885 2080.08,279.865 2080.09,279.846 2080.1,279.826 2080.11,279.807 2080.12,279.787 2080.13,279.768 2080.14,279.748 2080.15,279.729 2080.16,279.709 2080.16,279.69 2080.17,279.67 2080.18,279.651 2080.19,279.631 2080.2,279.612 2080.21,279.592 2080.22,279.573 2080.23,279.553 2080.24,279.534 2080.25,279.514 2080.26,279.495 2080.27,279.475 2080.28,279.456 2080.28,279.436 2080.29,279.417 2080.3,279.397 2080.31,279.378 2080.32,279.358 2080.33,279.339 2080.34,279.319 2080.35,279.3 2080.36,279.28 2080.37,279.261 2080.38,279.242 2080.39,279.222 2080.39,279.203 2080.4,279.183 2080.41,279.164 2080.42,279.144 2080.43,279.125 2080.44,279.105 2080.45,279.086 2080.46,279.066 2080.47,279.047 2080.48,279.028 2080.49,279.008 2080.5,278.989 2080.5,278.969 2080.51,278.95 2080.52,278.93 2080.53,278.911 2080.54,278.892 2080.55,278.872 2080.56,278.853 2080.57,278.833 2080.58,278.814 2080.59,278.795 2080.6,278.775 2080.61,278.756 2080.62,278.736 2080.62,278.717 2080.63,278.698 2080.64,278.678 2080.65,278.659 2080.66,278.639 2080.67,278.62 2080.68,278.601 2080.69,278.581 2080.7,278.562 2080.71,278.542 2080.72,278.523 2080.73,278.504 2080.73,278.484 2080.74,278.465 2080.75,278.446 2080.76,278.426 2080.77,278.407 2080.78,278.387 2080.79,278.368 2080.8,278.349 2080.81,278.329 2080.82,278.31 2080.83,278.291 2080.84,278.271 2080.84,278.252 2080.85,278.233 2080.86,278.213 2080.87,278.194 2080.88,278.174 2080.89,278.155 2080.9,278.136 2080.91,278.116 2080.92,278.097 2080.93,278.078 2080.94,278.058 2080.95,278.039 2080.96,278.02 2080.96,278 2080.97,277.981 2080.98,277.962 2080.99,277.943 2081,277.923 2081.01,277.904 2081.02,277.885 2081.03,277.865 2081.04,277.846 2081.05,277.827 2081.06,277.807 2081.07,277.788 2081.07,277.769 2081.08,277.749 2081.09,277.73 2081.1,277.711 2081.11,277.692 2081.12,277.672 2081.13,277.653 2081.14,277.634 2081.15,277.614 2081.16,277.595 2081.17,277.576 2081.18,277.557 2081.18,277.537 2081.19,277.518 2081.2,277.499 2081.21,277.479 2081.22,277.46 2081.23,277.441 2081.24,277.422 2081.25,277.402 2081.26,277.383 2081.27,277.364 2081.28,277.345 2081.29,277.325 2081.3,277.306 2081.3,277.287 2081.31,277.268 2081.32,277.248 2081.33,277.229 2081.34,277.21 2081.35,277.191 2081.36,277.171 2081.37,277.152 2081.38,277.133 2081.39,277.114 2081.4,277.094 2081.41,277.075 2081.41,277.056 2081.42,277.037 2081.43,277.018 2081.44,276.998 2081.45,276.979 2081.46,276.96 2081.47,276.941 2081.48,276.921 2081.49,276.902 2081.5,276.883 2081.51,276.864 2081.52,276.845 2081.52,276.825 2081.53,276.806 2081.54,276.787 2081.55,276.768 2081.56,276.749 2081.57,276.729 2081.58,276.71 2081.59,276.691 2081.6,276.672 2081.61,276.653 2081.62,276.634 2081.63,276.614 2081.64,276.595 2081.64,276.576 2081.65,276.557 2081.66,276.538 2081.67,276.519 2081.68,276.499 2081.69,276.48 2081.7,276.461 2081.71,276.442 2081.72,276.423 2081.73,276.404 2081.74,276.384 2081.75,276.365 2081.75,276.346 2081.76,276.327 2081.77,276.308 2081.78,276.289 2081.79,276.27 2081.8,276.25 2081.81,276.231 2081.82,276.212 2081.83,276.193 2081.84,276.174 2081.85,276.155 2081.86,276.136 2081.86,276.116 2081.87,276.097 2081.88,276.078 2081.89,276.059 2081.9,276.04 2081.91,276.021 2081.92,276.002 2081.93,275.983 2081.94,275.964 2081.95,275.944 2081.96,275.925 2081.97,275.906 2081.98,275.887 2081.98,275.868 2081.99,275.849 2082,275.83 2082.01,275.811 2082.02,275.792 2082.03,275.773 2082.04,275.753 2082.05,275.734 2082.06,275.715 2082.07,275.696 2082.08,275.677 2082.09,275.658 2082.09,275.639 2082.1,275.62 2082.11,275.601 2082.12,275.582 2082.13,275.563 2082.14,275.544 2082.15,275.525 2082.16,275.506 2082.17,275.486 2082.18,275.467 2082.19,275.448 2082.2,275.429 2082.2,275.41 2082.21,275.391 2082.22,275.372 2082.23,275.353 2082.24,275.334 2082.25,275.315 2082.26,275.296 2082.27,275.277 2082.28,275.258 2082.29,275.239 2082.3,275.22 2082.31,275.201 2082.32,275.182 2082.32,275.163 2082.33,275.144 2082.34,275.125 2082.35,275.106 2082.36,275.087 2082.37,275.068 2082.38,275.049 2082.39,275.03 2082.4,275.011 2082.41,274.992 2082.42,274.973 2082.43,274.954 2082.43,274.935 2082.44,274.916 2082.45,274.897 2082.46,274.878 2082.47,274.859 2082.48,274.84 2082.49,274.821 2082.5,274.802 2082.51,274.783 2082.52,274.764 2082.53,274.745 2082.54,274.726 2082.54,274.707 2082.55,274.688 2082.56,274.669 2082.57,274.65 2082.58,274.631 2082.59,274.612 2082.6,274.593 2082.61,274.574 2082.62,274.555 2082.63,274.536 2082.64,274.517 2082.65,274.498 2082.66,274.479 2082.66,274.46 2082.67,274.441 2082.68,274.422 2082.69,274.403 2082.7,274.385 2082.71,274.366 2082.72,274.347 2082.73,274.328 2082.74,274.309 2082.75,274.29 2082.76,274.271 2082.77,274.252 2082.77,274.233 2082.78,274.214 2082.79,274.195 2082.8,274.176 2082.81,274.157 2082.82,274.138 2082.83,274.12 2082.84,274.101 2082.85,274.082 2082.86,274.063 2082.87,274.044 2082.88,274.025 2082.88,274.006 2082.89,273.987 2082.9,273.968 2082.91,273.949 2082.92,273.931 2082.93,273.912 2082.94,273.893 2082.95,273.874 2082.96,273.855 2082.97,273.836 2082.98,273.817 2082.99,273.798 2083,273.779 2083,273.761 2083.01,273.742 2083.02,273.723 2083.03,273.704 2083.04,273.685 2083.05,273.666 2083.06,273.647 2083.07,273.629 2083.08,273.61 2083.09,273.591 2083.1,273.572 2083.11,273.553 2083.11,273.534 2083.12,273.515 2083.13,273.497 2083.14,273.478 2083.15,273.459 2083.16,273.44 2083.17,273.421 2083.18,273.402 2083.19,273.384 2083.2,273.365 2083.21,273.346 2083.22,273.327 2083.22,273.308 2083.23,273.289 2083.24,273.271 2083.25,273.252 2083.26,273.233 2083.27,273.214 2083.28,273.195 2083.29,273.176 2083.3,273.158 2083.31,273.139 2083.32,273.12 2083.33,273.101 2083.34,273.082 2083.34,273.064 2083.35,273.045 2083.36,273.026 2083.37,273.007 2083.38,272.988 2083.39,272.97 2083.4,272.951 2083.41,272.932 2083.42,272.913 2083.43,272.895 2083.44,272.876 2083.45,272.857 2083.45,272.838 2083.46,272.819 2083.47,272.801 2083.48,272.782 2083.49,272.763 2083.5,272.744 2083.51,272.726 2083.52,272.707 2083.53,272.688 2083.54,272.669 2083.55,272.651 2083.56,272.632 2083.56,272.613 2083.57,272.594 2083.58,272.576 2083.59,272.557 2083.6,272.538 2083.61,272.519 2083.62,272.501 2083.63,272.482 2083.64,272.463 2083.65,272.444 2083.66,272.426 2083.67,272.407 2083.68,272.388 2083.68,272.369 2083.69,272.351 2083.7,272.332 2083.71,272.313 2083.72,272.295 2083.73,272.276 2083.74,272.257 2083.75,272.238 2083.76,272.22 2083.77,272.201 2083.78,272.182 2083.79,272.164 2083.79,272.145 2083.8,272.126 2083.81,272.107 2083.82,272.089 2083.83,272.07 2083.84,272.051 2083.85,272.033 2083.86,272.014 2083.87,271.995 2083.88,271.977 2083.89,271.958 2083.9,271.939 2083.9,271.921 2083.91,271.902 2083.92,271.883 2083.93,271.865 2083.94,271.846 2083.95,271.827 2083.96,271.809 2083.97,271.79 2083.98,271.771 2083.99,271.753 2084,271.734 2084.01,271.715 2084.02,271.697 2084.02,271.678 2084.03,271.659 2084.04,271.641 2084.05,271.622 2084.06,271.603 2084.07,271.585 2084.08,271.566 2084.09,271.547 2084.1,271.529 2084.11,271.51 2084.12,271.492 2084.13,271.473 2084.13,271.454 2084.14,271.436 2084.15,271.417 2084.16,271.398 2084.17,271.38 2084.18,271.361 2084.19,271.343 2084.2,271.324 2084.21,271.305 2084.22,271.287 2084.23,271.268 2084.24,271.25 2084.24,271.231 2084.25,271.212 2084.26,271.194 2084.27,271.175 2084.28,271.157 2084.29,271.138 2084.3,271.119 2084.31,271.101 2084.32,271.082 2084.33,271.064 2084.34,271.045 2084.35,271.026 2084.36,271.008 2084.36,270.989 2084.37,270.971 2084.38,270.952 2084.39,270.934 2084.4,270.915 2084.41,270.896 2084.42,270.878 2084.43,270.859 2084.44,270.841 2084.45,270.822 2084.46,270.804 2084.47,270.785 2084.47,270.766 2084.48,270.748 2084.49,270.729 2084.5,270.711 2084.51,270.692 2084.52,270.674 2084.53,270.655 2084.54,270.637 2084.55,270.618 2084.56,270.6 2084.57,270.581 2084.58,270.562 2084.58,270.544 2084.59,270.525 2084.6,270.507 2084.61,270.488 2084.62,270.47 2084.63,270.451 2084.64,270.433 2084.65,270.414 2084.66,270.396 2084.67,270.377 2084.68,270.359 2084.69,270.34 2084.7,270.322 2084.7,270.303 2084.71,270.285 2084.72,270.266 2084.73,270.248 2084.74,270.229 2084.75,270.211 2084.76,270.192 2084.77,270.174 2084.78,270.155 2084.79,270.137 2084.8,270.118 2084.81,270.1 2084.81,270.081 2084.82,270.063 2084.83,270.044 2084.84,270.026 2084.85,270.007 2084.86,269.989 2084.87,269.97 2084.88,269.952 2084.89,269.934 2084.9,269.915 2084.91,269.897 2084.92,269.878 2084.92,269.86 2084.93,269.841 2084.94,269.823 2084.95,269.804 2084.96,269.786 2084.97,269.767 2084.98,269.749 2084.99,269.731 2085,269.712 2085.01,269.694 2085.02,269.675 2085.03,269.657 2085.04,269.638 2085.04,269.62 2085.05,269.601 2085.06,269.583 2085.07,269.565 2085.08,269.546 2085.09,269.528 2085.1,269.509 2085.11,269.491 2085.12,269.473 2085.13,269.454 2085.14,269.436 2085.15,269.417 2085.15,269.399 2085.16,269.38 2085.17,269.362 2085.18,269.344 2085.19,269.325 2085.2,269.307 2085.21,269.288 2085.22,269.27 2085.23,269.252 2085.24,269.233 2085.25,269.215 2085.26,269.197 2085.26,269.178 2085.27,269.16 2085.28,269.141 2085.29,269.123 2085.3,269.105 2085.31,269.086 2085.32,269.068 2085.33,269.049 2085.34,269.031 2085.35,269.013 2085.36,268.994 2085.37,268.976 2085.38,268.958 2085.38,268.939 2085.39,268.921 2085.4,268.903 2085.41,268.884 2085.42,268.866 2085.43,268.848 2085.44,268.829 2085.45,268.811 2085.46,268.793 2085.47,268.774 2085.48,268.756 2085.49,268.737 2085.49,268.719 2085.5,268.701 2085.51,268.682 2085.52,268.664 2085.53,268.646 2085.54,268.627 2085.55,268.609 2085.56,268.591 2085.57,268.573 2085.58,268.554 2085.59,268.536 2085.6,268.518 2085.6,268.499 2085.61,268.481 2085.62,268.463 2085.63,268.444 2085.64,268.426 2085.65,268.408 2085.66,268.389 2085.67,268.371 2085.68,268.353 2085.69,268.335 2085.7,268.316 2085.71,268.298 2085.72,268.28 2085.72,268.261 2085.73,268.243 2085.74,268.225 2085.75,268.207 2085.76,268.188 2085.77,268.17 2085.78,268.152 2085.79,268.133 2085.8,268.115 2085.81,268.097 2085.82,268.079 2085.83,268.06 2085.83,268.042 2085.84,268.024 2085.85,268.006 2085.86,267.987 2085.87,267.969 2085.88,267.951 2085.89,267.933 2085.9,267.914 2085.91,267.896 2085.92,267.878 2085.93,267.86 2085.94,267.841 2085.94,267.823 2085.95,267.805 2085.96,267.787 2085.97,267.768 2085.98,267.75 2085.99,267.732 2086,267.714 2086.01,267.695 2086.02,267.677 2086.03,267.659 2086.04,267.641 2086.05,267.623 2086.06,267.604 2086.06,267.586 2086.07,267.568 2086.08,267.55 2086.09,267.532 2086.1,267.513 2086.11,267.495 2086.12,267.477 2086.13,267.459 2086.14,267.44 2086.15,267.422 2086.16,267.404 2086.17,267.386 2086.17,267.368 2086.18,267.35 2086.19,267.331 2086.2,267.313 2086.21,267.295 2086.22,267.277 2086.23,267.259 2086.24,267.24 2086.25,267.222 2086.26,267.204 2086.27,267.186 2086.28,267.168 2086.28,267.15 2086.29,267.131 2086.3,267.113 2086.31,267.095 2086.32,267.077 2086.33,267.059 2086.34,267.041 2086.35,267.022 2086.36,267.004 2086.37,266.986 2086.38,266.968 2086.39,266.95 2086.4,266.932 2086.4,266.914 2086.41,266.895 2086.42,266.877 2086.43,266.859 2086.44,266.841 2086.45,266.823 2086.46,266.805 2086.47,266.787 2086.48,266.768 2086.49,266.75 2086.5,266.732 2086.51,266.714 2086.51,266.696 2086.52,266.678 2086.53,266.66 2086.54,266.642 2086.55,266.624 2086.56,266.605 2086.57,266.587 2086.58,266.569 2086.59,266.551 2086.6,266.533 2086.61,266.515 2086.62,266.497 2086.62,266.479 2086.63,266.461 2086.64,266.443 2086.65,266.424 2086.66,266.406 2086.67,266.388 2086.68,266.37 2086.69,266.352 2086.7,266.334 2086.71,266.316 2086.72,266.298 2086.73,266.28 2086.74,266.262 2086.74,266.244 2086.75,266.226 2086.76,266.207 2086.77,266.189 2086.78,266.171 2086.79,266.153 2086.8,266.135 2086.81,266.117 2086.82,266.099 2086.83,266.081 2086.84,266.063 2086.85,266.045 2086.85,266.027 2086.86,266.009 2086.87,265.991 2086.88,265.973 2086.89,265.955 2086.9,265.937 2086.91,265.919 2086.92,265.901 2086.93,265.883 2086.94,265.865 2086.95,265.847 2086.96,265.829 2086.96,265.811 2086.97,265.792 2086.98,265.774 2086.99,265.756 2087,265.738 2087.01,265.72 2087.02,265.702 2087.03,265.684 2087.04,265.666 2087.05,265.648 2087.06,265.63 2087.07,265.612 2087.08,265.594 2087.08,265.576 2087.09,265.558 2087.1,265.54 2087.11,265.522 2087.12,265.504 2087.13,265.486 2087.14,265.468 2087.15,265.45 2087.16,265.432 2087.17,265.414 2087.18,265.396 2087.19,265.378 2087.19,265.361 2087.2,265.343 2087.21,265.325 2087.22,265.307 2087.23,265.289 2087.24,265.271 2087.25,265.253 2087.26,265.235 2087.27,265.217 2087.28,265.199 2087.29,265.181 2087.3,265.163 2087.3,265.145 2087.31,265.127 2087.32,265.109 2087.33,265.091 2087.34,265.073 2087.35,265.055 2087.36,265.037 2087.37,265.019 2087.38,265.001 2087.39,264.983 2087.4,264.966 2087.41,264.948 2087.42,264.93 2087.42,264.912 2087.43,264.894 2087.44,264.876 2087.45,264.858 2087.46,264.84 2087.47,264.822 2087.48,264.804 2087.49,264.786 2087.5,264.768 2087.51,264.75 2087.52,264.733 2087.53,264.715 2087.53,264.697 2087.54,264.679 2087.55,264.661 2087.56,264.643 2087.57,264.625 2087.58,264.607 2087.59,264.589 2087.6,264.571 2087.61,264.554 2087.62,264.536 2087.63,264.518 2087.64,264.5 2087.64,264.482 2087.65,264.464 2087.66,264.446 2087.67,264.428 2087.68,264.41 2087.69,264.393 2087.7,264.375 2087.71,264.357 2087.72,264.339 2087.73,264.321 2087.74,264.303 2087.75,264.285 2087.76,264.268 2087.76,264.25 2087.77,264.232 2087.78,264.214 2087.79,264.196 2087.8,264.178 2087.81,264.16 2087.82,264.143 2087.83,264.125 2087.84,264.107 2087.85,264.089 2087.86,264.071 2087.87,264.053 2087.87,264.036 2087.88,264.018 2087.89,264 2087.9,263.982 2087.91,263.964 2087.92,263.946 2087.93,263.929 2087.94,263.911 2087.95,263.893 2087.96,263.875 2087.97,263.857 2087.98,263.84 2087.98,263.822 2087.99,263.804 2088,263.786 2088.01,263.768 2088.02,263.75 2088.03,263.733 2088.04,263.715 2088.05,263.697 2088.06,263.679 2088.07,263.661 2088.08,263.644 2088.09,263.626 2088.1,263.608 2088.1,263.59 2088.11,263.573 2088.12,263.555 2088.13,263.537 2088.14,263.519 2088.15,263.501 2088.16,263.484 2088.17,263.466 2088.18,263.448 2088.19,263.43 2088.2,263.413 2088.21,263.395 2088.21,263.377 2088.22,263.359 2088.23,263.341 2088.24,263.324 2088.25,263.306 2088.26,263.288 2088.27,263.27 2088.28,263.253 2088.29,263.235 2088.3,263.217 2088.31,263.199 2088.32,263.182 2088.32,263.164 2088.33,263.146 2088.34,263.129 2088.35,263.111 2088.36,263.093 2088.37,263.075 2088.38,263.058 2088.39,263.04 2088.4,263.022 2088.41,263.004 2088.42,262.987 2088.43,262.969 2088.44,262.951 2088.44,262.934 2088.45,262.916 2088.46,262.898 2088.47,262.88 2088.48,262.863 2088.49,262.845 2088.5,262.827 2088.51,262.81 2088.52,262.792 2088.53,262.774 2088.54,262.756 2088.55,262.739 2088.55,262.721 2088.56,262.703 2088.57,262.686 2088.58,262.668 2088.59,262.65 2088.6,262.633 2088.61,262.615 2088.62,262.597 2088.63,262.58 2088.64,262.562 2088.65,262.544 2088.66,262.527 2088.66,262.509 2088.67,262.491 2088.68,262.474 2088.69,262.456 2088.7,262.438 2088.71,262.421 2088.72,262.403 2088.73,262.385 2088.74,262.368 2088.75,262.35 2088.76,262.332 2088.77,262.315 2088.78,262.297 2088.78,262.279 2088.79,262.262 2088.8,262.244 2088.81,262.226 2088.82,262.209 2088.83,262.191 2088.84,262.174 2088.85,262.156 2088.86,262.138 2088.87,262.121 2088.88,262.103 2088.89,262.085 2088.89,262.068 2088.9,262.05 2088.91,262.032 2088.92,262.015 2088.93,261.997 2088.94,261.98 2088.95,261.962 2088.96,261.944 2088.97,261.927 2088.98,261.909 2088.99,261.892 2089,261.874 2089,261.856 2089.01,261.839 2089.02,261.821 2089.03,261.804 2089.04,261.786 2089.05,261.768 2089.06,261.751 2089.07,261.733 2089.08,261.716 2089.09,261.698 2089.1,261.68 2089.11,261.663 2089.12,261.645 2089.12,261.628 2089.13,261.61 2089.14,261.593 2089.15,261.575 2089.16,261.557 2089.17,261.54 2089.18,261.522 2089.19,261.505 2089.2,261.487 2089.21,261.47 2089.22,261.452 2089.23,261.435 2089.23,261.417 2089.24,261.399 2089.25,261.382 2089.26,261.364 2089.27,261.347 2089.28,261.329 2089.29,261.312 2089.3,261.294 2089.31,261.277 2089.32,261.259 2089.33,261.242 2089.34,261.224 2089.34,261.206 2089.35,261.189 2089.36,261.171 2089.37,261.154 2089.38,261.136 2089.39,261.119 2089.4,261.101 2089.41,261.084 2089.42,261.066 2089.43,261.049 2089.44,261.031 2089.45,261.014 2089.46,260.996 2089.46,260.979 2089.47,260.961 2089.48,260.944 2089.49,260.926 2089.5,260.909 2089.51,260.891 2089.52,260.874 2089.53,260.856 2089.54,260.839 2089.55,260.821 2089.56,260.804 2089.57,260.786 2089.57,260.769 2089.58,260.751 2089.59,260.734 2089.6,260.716 2089.61,260.699 2089.62,260.681 2089.63,260.664 2089.64,260.646 2089.65,260.629 2089.66,260.612 2089.67,260.594 2089.68,260.577 2089.68,260.559 2089.69,260.542 2089.7,260.524 2089.71,260.507 2089.72,260.489 2089.73,260.472 2089.74,260.454 2089.75,260.437 2089.76,260.419 2089.77,260.402 2089.78,260.385 2089.79,260.367 2089.8,260.35 2089.8,260.332 2089.81,260.315 2089.82,260.297 2089.83,260.28 2089.84,260.263 2089.85,260.245 2089.86,260.228 2089.87,260.21 2089.88,260.193 2089.89,260.175 2089.9,260.158 2089.91,260.141 2089.91,260.123 2089.92,260.106 2089.93,260.088 2089.94,260.071 2089.95,260.054 2089.96,260.036 2089.97,260.019 2089.98,260.001 2089.99,259.984 2090,259.967 2090.01,259.949 2090.02,259.932 2090.02,259.914 2090.03,259.897 2090.04,259.88 2090.05,259.862 2090.06,259.845 2090.07,259.827 2090.08,259.81 2090.09,259.793 2090.1,259.775 2090.11,259.758 2090.12,259.741 2090.13,259.723 2090.14,259.706 2090.14,259.688 2090.15,259.671 2090.16,259.654 2090.17,259.636 2090.18,259.619 2090.19,259.602 2090.2,259.584 2090.21,259.567 2090.22,259.55 2090.23,259.532 2090.24,259.515 2090.25,259.497 2090.25,259.48 2090.26,259.463 2090.27,259.445 2090.28,259.428 2090.29,259.411 2090.3,259.393 2090.31,259.376 2090.32,259.359 2090.33,259.341 2090.34,259.324 2090.35,259.307 2090.36,259.289 2090.36,259.272 2090.37,259.255 2090.38,259.237 2090.39,259.22 2090.4,259.203 2090.41,259.186 2090.42,259.168 2090.43,259.151 2090.44,259.134 2090.45,259.116 2090.46,259.099 2090.47,259.082 2090.48,259.064 2090.48,259.047 2090.49,259.03 2090.5,259.012 2090.51,258.995 2090.52,258.978 2090.53,258.961 2090.54,258.943 2090.55,258.926 2090.56,258.909 2090.57,258.891 2090.58,258.874 2090.59,258.857 2090.59,258.84 2090.6,258.822 2090.61,258.805 2090.62,258.788 2090.63,258.771 2090.64,258.753 2090.65,258.736 2090.66,258.719 2090.67,258.701 2090.68,258.684 2090.69,258.667 2090.7,258.65 2090.7,258.632 2090.71,258.615 2090.72,258.598 2090.73,258.581 2090.74,258.563 2090.75,258.546 2090.76,258.529 2090.77,258.512 2090.78,258.494 2090.79,258.477 2090.8,258.46 2090.81,258.443 2090.82,258.425 2090.82,258.408 2090.83,258.391 2090.84,258.374 2090.85,258.357 2090.86,258.339 2090.87,258.322 2090.88,258.305 2090.89,258.288 2090.9,258.27 2090.91,258.253 2090.92,258.236 2090.93,258.219 2090.93,258.202 2090.94,258.184 2090.95,258.167 2090.96,258.15 2090.97,258.133 2090.98,258.116 2090.99,258.098 2091,258.081 2091.01,258.064 2091.02,258.047 2091.03,258.03 2091.04,258.012 2091.04,257.995 2091.05,257.978 2091.06,257.961 2091.07,257.944 2091.08,257.927 2091.09,257.909 2091.1,257.892 2091.11,257.875 2091.12,257.858 2091.13,257.841 2091.14,257.823 2091.15,257.806 2091.16,257.789 2091.16,257.772 2091.17,257.755 2091.18,257.738 2091.19,257.72 2091.2,257.703 2091.21,257.686 2091.22,257.669 2091.23,257.652 2091.24,257.635 2091.25,257.618 2091.26,257.6 2091.27,257.583 2091.27,257.566 2091.28,257.549 2091.29,257.532 2091.3,257.515 2091.31,257.498 2091.32,257.48 2091.33,257.463 2091.34,257.446 2091.35,257.429 2091.36,257.412 2091.37,257.395 2091.38,257.378 2091.38,257.361 2091.39,257.343 2091.4,257.326 2091.41,257.309 2091.42,257.292 2091.43,257.275 2091.44,257.258 2091.45,257.241 2091.46,257.224 2091.47,257.207 2091.48,257.19 2091.49,257.172 2091.5,257.155 2091.5,257.138 2091.51,257.121 2091.52,257.104 2091.53,257.087 2091.54,257.07 2091.55,257.053 2091.56,257.036 2091.57,257.019 2091.58,257.002 2091.59,256.984 2091.6,256.967 2091.61,256.95 2091.61,256.933 2091.62,256.916 2091.63,256.899 2091.64,256.882 2091.65,256.865 2091.66,256.848 2091.67,256.831 2091.68,256.814 2091.69,256.797 2091.7,256.78 2091.71,256.763 2091.72,256.746 2091.72,256.728 2091.73,256.711 2091.74,256.694 2091.75,256.677 2091.76,256.66 2091.77,256.643 2091.78,256.626 2091.79,256.609 2091.8,256.592 2091.81,256.575 2091.82,256.558 2091.83,256.541 2091.84,256.524 2091.84,256.507 2091.85,256.49 2091.86,256.473 2091.87,256.456 2091.88,256.439 2091.89,256.422 2091.9,256.405 2091.91,256.388 2091.92,256.371 2091.93,256.354 2091.94,256.337 2091.95,256.32 2091.95,256.303 2091.96,256.286 2091.97,256.269 2091.98,256.252 2091.99,256.235 2092,256.218 2092.01,256.201 2092.02,256.184 2092.03,256.167 2092.04,256.15 2092.05,256.133 2092.06,256.116 2092.06,256.099 2092.07,256.082 2092.08,256.065 2092.09,256.048 2092.1,256.031 2092.11,256.014 2092.12,255.997 2092.13,255.98 2092.14,255.963 2092.15,255.946 2092.16,255.929 2092.17,255.912 2092.18,255.895 2092.18,255.878 2092.19,255.861 2092.2,255.844 2092.21,255.827 2092.22,255.81 2092.23,255.793 2092.24,255.777 2092.25,255.76 2092.26,255.743 2092.27,255.726 2092.28,255.709 2092.29,255.692 2092.29,255.675 2092.3,255.658 2092.31,255.641 2092.32,255.624 2092.33,255.607 2092.34,255.59 2092.35,255.573 2092.36,255.556 2092.37,255.539 2092.38,255.522 2092.39,255.506 2092.4,255.489 2092.4,255.472 2092.41,255.455 2092.42,255.438 2092.43,255.421 2092.44,255.404 2092.45,255.387 2092.46,255.37 2092.47,255.353 2092.48,255.336 2092.49,255.32 2092.5,255.303 2092.51,255.286 2092.52,255.269 2092.52,255.252 2092.53,255.235 2092.54,255.218 2092.55,255.201 2092.56,255.184 2092.57,255.168 2092.58,255.151 2092.59,255.134 2092.6,255.117 2092.61,255.1 2092.62,255.083 2092.63,255.066 2092.63,255.049 2092.64,255.033 2092.65,255.016 2092.66,254.999 2092.67,254.982 2092.68,254.965 2092.69,254.948 2092.7,254.931 2092.71,254.914 2092.72,254.898 2092.73,254.881 2092.74,254.864 2092.74,254.847 2092.75,254.83 2092.76,254.813 2092.77,254.797 2092.78,254.78 2092.79,254.763 2092.8,254.746 2092.81,254.729 2092.82,254.712 2092.83,254.696 2092.84,254.679 2092.85,254.662 2092.86,254.645 2092.86,254.628 2092.87,254.611 2092.88,254.595 2092.89,254.578 2092.9,254.561 2092.91,254.544 2092.92,254.527 2092.93,254.51 2092.94,254.494 2092.95,254.477 2092.96,254.46 2092.97,254.443 2092.97,254.426 2092.98,254.41 2092.99,254.393 2093,254.376 2093.01,254.359 2093.02,254.342 2093.03,254.326 2093.04,254.309 2093.05,254.292 2093.06,254.275 2093.07,254.258 2093.08,254.242 2093.08,254.225 2093.09,254.208 2093.1,254.191 2093.11,254.175 2093.12,254.158 2093.13,254.141 2093.14,254.124 2093.15,254.107 2093.16,254.091 2093.17,254.074 2093.18,254.057 2093.19,254.04 2093.2,254.024 2093.2,254.007 2093.21,253.99 2093.22,253.973 2093.23,253.957 2093.24,253.94 2093.25,253.923 2093.26,253.906 2093.27,253.89 2093.28,253.873 2093.29,253.856 2093.3,253.839 2093.31,253.823 2093.31,253.806 2093.32,253.789 2093.33,253.772 2093.34,253.756 2093.35,253.739 2093.36,253.722 2093.37,253.706 2093.38,253.689 2093.39,253.672 2093.4,253.655 2093.41,253.639 2093.42,253.622 2093.42,253.605 2093.43,253.588 2093.44,253.572 2093.45,253.555 2093.46,253.538 2093.47,253.522 2093.48,253.505 2093.49,253.488 2093.5,253.472 2093.51,253.455 2093.52,253.438 2093.53,253.421 2093.54,253.405 2093.54,253.388 2093.55,253.371 2093.56,253.355 2093.57,253.338 2093.58,253.321 2093.59,253.305 2093.6,253.288 2093.61,253.271 2093.62,253.255 2093.63,253.238 2093.64,253.221 2093.65,253.205 2093.65,253.188 2093.66,253.171 2093.67,253.155 2093.68,253.138 2093.69,253.121 2093.7,253.105 2093.71,253.088 2093.72,253.071 2093.73,253.055 2093.74,253.038 2093.75,253.021 2093.76,253.005 2093.76,252.988 2093.77,252.971 2093.78,252.955 2093.79,252.938 2093.8,252.921 2093.81,252.905 2093.82,252.888 2093.83,252.871 2093.84,252.855 2093.85,252.838 2093.86,252.822 2093.87,252.805 2093.88,252.788 2093.88,252.772 2093.89,252.755 2093.9,252.738 2093.91,252.722 2093.92,252.705 2093.93,252.689 2093.94,252.672 2093.95,252.655 2093.96,252.639 2093.97,252.622 2093.98,252.605 2093.99,252.589 2093.99,252.572 2094,252.556 2094.01,252.539 2094.02,252.522 2094.03,252.506 2094.04,252.489 2094.05,252.473 2094.06,252.456 2094.07,252.439 2094.08,252.423 2094.09,252.406 2094.1,252.39 2094.1,252.373 2094.11,252.357 2094.12,252.34 2094.13,252.323 2094.14,252.307 2094.15,252.29 2094.16,252.274 2094.17,252.257 2094.18,252.24 2094.19,252.224 2094.2,252.207 2094.21,252.191 2094.22,252.174 2094.22,252.158 2094.23,252.141 2094.24,252.125 2094.25,252.108 2094.26,252.091 2094.27,252.075 2094.28,252.058 2094.29,252.042 2094.3,252.025 2094.31,252.009 2094.32,251.992 2094.33,251.976 2094.33,251.959 2094.34,251.943 2094.35,251.926 2094.36,251.909 2094.37,251.893 2094.38,251.876 2094.39,251.86 2094.4,251.843 2094.41,251.827 2094.42,251.81 2094.43,251.794 2094.44,251.777 2094.44,251.761 2094.45,251.744 2094.46,251.728 2094.47,251.711 2094.48,251.695 2094.49,251.678 2094.5,251.662 2094.51,251.645 2094.52,251.629 2094.53,251.612 2094.54,251.596 2094.55,251.579 2094.56,251.563 2094.56,251.546 2094.57,251.53 2094.58,251.513 2094.59,251.497 2094.6,251.48 2094.61,251.464 2094.62,251.447 2094.63,251.431 2094.64,251.414 2094.65,251.398 2094.66,251.381 2094.67,251.365 2094.67,251.348 2094.68,251.332 2094.69,251.315 2094.7,251.299 2094.71,251.282 2094.72,251.266 2094.73,251.25 2094.74,251.233 2094.75,251.217 2094.76,251.2 2094.77,251.184 2094.78,251.167 2094.78,251.151 2094.79,251.134 2094.8,251.118 2094.81,251.101 2094.82,251.085 2094.83,251.069 2094.84,251.052 2094.85,251.036 2094.86,251.019 2094.87,251.003 2094.88,250.986 2094.89,250.97 2094.9,250.953 2094.9,250.937 2094.91,250.921 2094.92,250.904 2094.93,250.888 2094.94,250.871 2094.95,250.855 2094.96,250.838 2094.97,250.822 2094.98,250.806 2094.99,250.789 2095,250.773 2095.01,250.756 2095.01,250.74 2095.02,250.724 2095.03,250.707 2095.04,250.691 2095.05,250.674 2095.06,250.658 2095.07,250.642 2095.08,250.625 2095.09,250.609 2095.1,250.592 2095.11,250.576 2095.12,250.56 2095.12,250.543 2095.13,250.527 2095.14,250.51 2095.15,250.494 2095.16,250.478 2095.17,250.461 2095.18,250.445 2095.19,250.429 2095.2,250.412 2095.21,250.396 2095.22,250.379 2095.23,250.363 2095.24,250.347 2095.24,250.33 2095.25,250.314 2095.26,250.298 2095.27,250.281 2095.28,250.265 2095.29,250.249 2095.3,250.232 2095.31,250.216 2095.32,250.199 2095.33,250.183 2095.34,250.167 2095.35,250.15 2095.35,250.134 2095.36,250.118 2095.37,250.101 2095.38,250.085 2095.39,250.069 2095.4,250.052 2095.41,250.036 2095.42,250.02 2095.43,250.003 2095.44,249.987 2095.45,249.971 2095.46,249.954 2095.46,249.938 2095.47,249.922 2095.48,249.905 2095.49,249.889 2095.5,249.873 2095.51,249.856 2095.52,249.84 2095.53,249.824 2095.54,249.808 2095.55,249.791 2095.56,249.775 2095.57,249.759 2095.58,249.742 2095.58,249.726 2095.59,249.71 2095.6,249.693 2095.61,249.677 2095.62,249.661 2095.63,249.645 2095.64,249.628 2095.65,249.612 2095.66,249.596 2095.67,249.579 2095.68,249.563 2095.69,249.547 2095.69,249.531 2095.7,249.514 2095.71,249.498 2095.72,249.482 2095.73,249.465 2095.74,249.449 2095.75,249.433 2095.76,249.417 2095.77,249.4 2095.78,249.384 2095.79,249.368 2095.8,249.352 2095.8,249.335 2095.81,249.319 2095.82,249.303 2095.83,249.287 2095.84,249.27 2095.85,249.254 2095.86,249.238 2095.87,249.222 2095.88,249.205 2095.89,249.189 2095.9,249.173 2095.91,249.157 2095.92,249.14 2095.92,249.124 2095.93,249.108 2095.94,249.092 2095.95,249.075 2095.96,249.059 2095.97,249.043 2095.98,249.027 2095.99,249.01 2096,248.994 2096.01,248.978 2096.02,248.962 2096.03,248.946 2096.03,248.929 2096.04,248.913 2096.05,248.897 2096.06,248.881 2096.07,248.865 2096.08,248.848 2096.09,248.832 2096.1,248.816 2096.11,248.8 2096.12,248.784 2096.13,248.767 2096.14,248.751 2096.14,248.735 2096.15,248.719 2096.16,248.703 2096.17,248.686 2096.18,248.67 2096.19,248.654 2096.2,248.638 2096.21,248.622 2096.22,248.605 2096.23,248.589 2096.24,248.573 2096.25,248.557 2096.26,248.541 2096.26,248.525 2096.27,248.508 2096.28,248.492 2096.29,248.476 2096.3,248.46 2096.31,248.444 2096.32,248.428 2096.33,248.411 2096.34,248.395 2096.35,248.379 2096.36,248.363 2096.37,248.347 2096.37,248.331 2096.38,248.314 2096.39,248.298 2096.4,248.282 2096.41,248.266 2096.42,248.25 2096.43,248.234 2096.44,248.218 2096.45,248.201 2096.46,248.185 2096.47,248.169 2096.48,248.153 2096.48,248.137 2096.49,248.121 2096.5,248.105 2096.51,248.089 2096.52,248.072 2096.53,248.056 2096.54,248.04 2096.55,248.024 2096.56,248.008 2096.57,247.992 2096.58,247.976 2096.59,247.96 2096.6,247.944 2096.6,247.927 2096.61,247.911 2096.62,247.895 2096.63,247.879 2096.64,247.863 2096.65,247.847 2096.66,247.831 2096.67,247.815 2096.68,247.799 2096.69,247.782 2096.7,247.766 2096.71,247.75 2096.71,247.734 2096.72,247.718 2096.73,247.702 2096.74,247.686 2096.75,247.67 2096.76,247.654 2096.77,247.638 2096.78,247.622 2096.79,247.606 2096.8,247.59 2096.81,247.573 2096.82,247.557 2096.82,247.541 2096.83,247.525 2096.84,247.509 2096.85,247.493 2096.86,247.477 2096.87,247.461 2096.88,247.445 2096.89,247.429 2096.9,247.413 2096.91,247.397 2096.92,247.381 2096.93,247.365 2096.94,247.349 2096.94,247.333 2096.95,247.317 2096.96,247.301 2096.97,247.284 2096.98,247.268 2096.99,247.252 2097,247.236 2097.01,247.22 2097.02,247.204 2097.03,247.188 2097.04,247.172 2097.05,247.156 2097.05,247.14 2097.06,247.124 2097.07,247.108 2097.08,247.092 2097.09,247.076 2097.1,247.06 2097.11,247.044 2097.12,247.028 2097.13,247.012 2097.14,246.996 2097.15,246.98 2097.16,246.964 2097.16,246.948 2097.17,246.932 2097.18,246.916 2097.19,246.9 2097.2,246.884 2097.21,246.868 2097.22,246.852 2097.23,246.836 2097.24,246.82 2097.25,246.804 2097.26,246.788 2097.27,246.772 2097.28,246.756 2097.28,246.74 2097.29,246.724 2097.3,246.708 2097.31,246.692 2097.32,246.676 2097.33,246.66 2097.34,246.644 2097.35,246.628 2097.36,246.612 2097.37,246.596 2097.38,246.58 2097.39,246.564 2097.39,246.548 2097.4,246.533 2097.41,246.517 2097.42,246.501 2097.43,246.485 2097.44,246.469 2097.45,246.453 2097.46,246.437 2097.47,246.421 2097.48,246.405 2097.49,246.389 2097.5,246.373 2097.5,246.357 2097.51,246.341 2097.52,246.325 2097.53,246.309 2097.54,246.293 2097.55,246.277 2097.56,246.261 2097.57,246.246 2097.58,246.23 2097.59,246.214 2097.6,246.198 2097.61,246.182 2097.62,246.166 2097.62,246.15 2097.63,246.134 2097.64,246.118 2097.65,246.102 2097.66,246.086 2097.67,246.07 2097.68,246.055 2097.69,246.039 2097.7,246.023 2097.71,246.007 2097.72,245.991 2097.73,245.975 2097.73,245.959 2097.74,245.943 2097.75,245.927 2097.76,245.911 2097.77,245.896 2097.78,245.88 2097.79,245.864 2097.8,245.848 2097.81,245.832 2097.82,245.816 2097.83,245.8 2097.84,245.784 2097.85,245.768 2097.85,245.753 2097.86,245.737 2097.87,245.721 2097.88,245.705 2097.89,245.689 2097.9,245.673 2097.91,245.657 2097.92,245.642 2097.93,245.626 2097.94,245.61 2097.95,245.594 2097.96,245.578 2097.96,245.562 2097.97,245.546 2097.98,245.531 2097.99,245.515 2098,245.499 2098.01,245.483 2098.02,245.467 2098.03,245.451 2098.04,245.435 2098.05,245.42 2098.06,245.404 2098.07,245.388 2098.07,245.372 2098.08,245.356 2098.09,245.34 2098.1,245.325 2098.11,245.309 2098.12,245.293 2098.13,245.277 2098.14,245.261 2098.15,245.245 2098.16,245.23 2098.17,245.214 2098.18,245.198 2098.19,245.182 2098.19,245.166 2098.2,245.151 2098.21,245.135 2098.22,245.119 2098.23,245.103 2098.24,245.087 2098.25,245.072 2098.26,245.056 2098.27,245.04 2098.28,245.024 2098.29,245.008 2098.3,244.993 2098.3,244.977 2098.31,244.961 2098.32,244.945 2098.33,244.929 2098.34,244.914 2098.35,244.898 2098.36,244.882 2098.37,244.866 2098.38,244.85 2098.39,244.835 2098.4,244.819 2098.41,244.803 2098.41,244.787 2098.42,244.772 2098.43,244.756 2098.44,244.74 2098.45,244.724 2098.46,244.709 2098.47,244.693 2098.48,244.677 2098.49,244.661 2098.5,244.646 2098.51,244.63 2098.52,244.614 2098.53,244.598 2098.53,244.582 2098.54,244.567 2098.55,244.551 2098.56,244.535 2098.57,244.52 2098.58,244.504 2098.59,244.488 2098.6,244.472 2098.61,244.457 2098.62,244.441 2098.63,244.425 2098.64,244.409 2098.64,244.394 2098.65,244.378 2098.66,244.362 2098.67,244.346 2098.68,244.331 2098.69,244.315 2098.7,244.299 2098.71,244.284 2098.72,244.268 2098.73,244.252 2098.74,244.236 2098.75,244.221 2098.75,244.205 2098.76,244.189 2098.77,244.174 2098.78,244.158 2098.79,244.142 2098.8,244.126 2098.81,244.111 2098.82,244.095 2098.83,244.079 2098.84,244.064 2098.85,244.048 2098.86,244.032 2098.87,244.017 2098.87,244.001 2098.88,243.985 2098.89,243.97 2098.9,243.954 2098.91,243.938 2098.92,243.922 2098.93,243.907 2098.94,243.891 2098.95,243.875 2098.96,243.86 2098.97,243.844 2098.98,243.828 2098.98,243.813 2098.99,243.797 2099,243.781 2099.01,243.766 2099.02,243.75 2099.03,243.734 2099.04,243.719 2099.05,243.703 2099.06,243.687 2099.07,243.672 2099.08,243.656 2099.09,243.641 2099.09,243.625 2099.1,243.609 2099.11,243.594 2099.12,243.578 2099.13,243.562 2099.14,243.547 2099.15,243.531 2099.16,243.515 2099.17,243.5 2099.18,243.484 2099.19,243.468 2099.2,243.453 2099.21,243.437 2099.21,243.422 2099.22,243.406 2099.23,243.39 2099.24,243.375 2099.25,243.359 2099.26,243.343 2099.27,243.328 2099.28,243.312 2099.29,243.297 2099.3,243.281 2099.31,243.265 2099.32,243.25 2099.32,243.234 2099.33,243.219 2099.34,243.203 2099.35,243.187 2099.36,243.172 2099.37,243.156 2099.38,243.141 2099.39,243.125 2099.4,243.109 2099.41,243.094 2099.42,243.078 2099.43,243.063 2099.43,243.047 2099.44,243.031 2099.45,243.016 2099.46,243 2099.47,242.985 2099.48,242.969 2099.49,242.954 2099.5,242.938 2099.51,242.922 2099.52,242.907 2099.53,242.891 2099.54,242.876 2099.55,242.86 2099.55,242.845 2099.56,242.829 2099.57,242.813 2099.58,242.798 2099.59,242.782 2099.6,242.767 2099.61,242.751 2099.62,242.736 2099.63,242.72 2099.64,242.705 2099.65,242.689 2099.66,242.673 2099.66,242.658 2099.67,242.642 2099.68,242.627 2099.69,242.611 2099.7,242.596 2099.71,242.58 2099.72,242.565 2099.73,242.549 2099.74,242.534 2099.75,242.518 2099.76,242.503 2099.77,242.487 2099.77,242.472 2099.78,242.456 2099.79,242.44 2099.8,242.425 2099.81,242.409 2099.82,242.394 2099.83,242.378 2099.84,242.363 2099.85,242.347 2099.86,242.332 2099.87,242.316 2099.88,242.301 2099.89,242.285 2099.89,242.27 2099.9,242.254 2099.91,242.239 2099.92,242.223 2099.93,242.208 2099.94,242.192 2099.95,242.177 2099.96,242.161 2099.97,242.146 2099.98,242.13 2099.99,242.115 2100,242.099 2100,242.084 2100.01,242.068 2100.02,242.053 2100.03,242.037 2100.04,242.022 2100.05,242.007 2100.06,241.991 2100.07,241.976 2100.08,241.96 2100.09,241.945 2100.1,241.929 2100.11,241.914 2100.11,241.898 2100.12,241.883 2100.13,241.867 2100.14,241.852 2100.15,241.836 2100.16,241.821 2100.17,241.805 2100.18,241.79 2100.19,241.775 2100.2,241.759 2100.21,241.744 2100.22,241.728 2100.23,241.713 2100.23,241.697 2100.24,241.682 2100.25,241.666 2100.26,241.651 2100.27,241.636 2100.28,241.62 2100.29,241.605 2100.3,241.589 2100.31,241.574 2100.32,241.558 2100.33,241.543 2100.34,241.528 2100.34,241.512 2100.35,241.497 2100.36,241.481 2100.37,241.466 2100.38,241.451 2100.39,241.435 2100.4,241.42 2100.41,241.404 2100.42,241.389 2100.43,241.373 2100.44,241.358 2100.45,241.343 2100.45,241.327 2100.46,241.312 2100.47,241.296 2100.48,241.281 2100.49,241.266 2100.5,241.25 2100.51,241.235 2100.52,241.219 2100.53,241.204 2100.54,241.189 2100.55,241.173 2100.56,241.158 2100.57,241.143 2100.57,241.127 2100.58,241.112 2100.59,241.096 2100.6,241.081 2100.61,241.066 2100.62,241.05 2100.63,241.035 2100.64,241.02 2100.65,241.004 2100.66,240.989 2100.67,240.973 2100.68,240.958 2100.68,240.943 2100.69,240.927 2100.7,240.912 2100.71,240.897 2100.72,240.881 2100.73,240.866 2100.74,240.851 2100.75,240.835 2100.76,240.82 2100.77,240.804 2100.78,240.789 2100.79,240.774 2100.79,240.758 2100.8,240.743 2100.81,240.728 2100.82,240.712 2100.83,240.697 2100.84,240.682 2100.85,240.666 2100.86,240.651 2100.87,240.636 2100.88,240.62 2100.89,240.605 2100.9,240.59 2100.91,240.574 2100.91,240.559 2100.92,240.544 2100.93,240.529 2100.94,240.513 2100.95,240.498 2100.96,240.483 2100.97,240.467 2100.98,240.452 2100.99,240.437 2101,240.421 2101.01,240.406 2101.02,240.391 2101.02,240.375 2101.03,240.36 2101.04,240.345 2101.05,240.33 2101.06,240.314 2101.07,240.299 2101.08,240.284 2101.09,240.268 2101.1,240.253 2101.11,240.238 2101.12,240.223 2101.13,240.207 2101.13,240.192 2101.14,240.177 2101.15,240.161 2101.16,240.146 2101.17,240.131 2101.18,240.116 2101.19,240.1 2101.2,240.085 2101.21,240.07 2101.22,240.054 2101.23,240.039 2101.24,240.024 2101.25,240.009 2101.25,239.993 2101.26,239.978 2101.27,239.963 2101.28,239.948 2101.29,239.932 2101.3,239.917 2101.31,239.902 2101.32,239.887 2101.33,239.871 2101.34,239.856 2101.35,239.841 2101.36,239.826 2101.36,239.81 2101.37,239.795 2101.38,239.78 2101.39,239.765 2101.4,239.749 2101.41,239.734 2101.42,239.719 2101.43,239.704 2101.44,239.689 2101.45,239.673 2101.46,239.658 2101.47,239.643 2101.47,239.628 2101.48,239.612 2101.49,239.597 2101.5,239.582 2101.51,239.567 2101.52,239.552 2101.53,239.536 2101.54,239.521 2101.55,239.506 2101.56,239.491 2101.57,239.476 2101.58,239.46 2101.59,239.445 2101.59,239.43 2101.6,239.415 2101.61,239.4 2101.62,239.384 2101.63,239.369 2101.64,239.354 2101.65,239.339 2101.66,239.324 2101.67,239.308 2101.68,239.293 2101.69,239.278 2101.7,239.263 2101.7,239.248 2101.71,239.232 2101.72,239.217 2101.73,239.202 2101.74,239.187 2101.75,239.172 2101.76,239.157 2101.77,239.141 2101.78,239.126 2101.79,239.111 2101.8,239.096 2101.81,239.081 2101.81,239.066 2101.82,239.05 2101.83,239.035 2101.84,239.02 2101.85,239.005 2101.86,238.99 2101.87,238.975 2101.88,238.959 2101.89,238.944 2101.9,238.929 2101.91,238.914 2101.92,238.899 2101.93,238.884 2101.93,238.869 2101.94,238.853 2101.95,238.838 2101.96,238.823 2101.97,238.808 2101.98,238.793 2101.99,238.778 2102,238.763 2102.01,238.748 2102.02,238.732 2102.03,238.717 2102.04,238.702 2102.04,238.687 2102.05,238.672 2102.06,238.657 2102.07,238.642 2102.08,238.627 2102.09,238.611 2102.1,238.596 2102.11,238.581 2102.12,238.566 2102.13,238.551 2102.14,238.536 2102.15,238.521 2102.15,238.506 2102.16,238.491 2102.17,238.476 2102.18,238.46 2102.19,238.445 2102.2,238.43 2102.21,238.415 2102.22,238.4 2102.23,238.385 2102.24,238.37 2102.25,238.355 2102.26,238.34 2102.27,238.325 2102.27,238.31 2102.28,238.294 2102.29,238.279 2102.3,238.264 2102.31,238.249 2102.32,238.234 2102.33,238.219 2102.34,238.204 2102.35,238.189 2102.36,238.174 2102.37,238.159 2102.38,238.144 2102.38,238.129 2102.39,238.114 2102.4,238.099 2102.41,238.083 2102.42,238.068 2102.43,238.053 2102.44,238.038 2102.45,238.023 2102.46,238.008 2102.47,237.993 2102.48,237.978 2102.49,237.963 2102.49,237.948 2102.5,237.933 2102.51,237.918 2102.52,237.903 2102.53,237.888 2102.54,237.873 2102.55,237.858 2102.56,237.843 2102.57,237.828 2102.58,237.813 2102.59,237.798 2102.6,237.783 2102.61,237.768 2102.61,237.753 2102.62,237.738 2102.63,237.723 2102.64,237.708 2102.65,237.693 2102.66,237.678 2102.67,237.663 2102.68,237.648 2102.69,237.633 2102.7,237.617 2102.71,237.602 2102.72,237.587 2102.72,237.572 2102.73,237.557 2102.74,237.542 2102.75,237.527 2102.76,237.512 2102.77,237.497 2102.78,237.482 2102.79,237.468 2102.8,237.453 2102.81,237.438 2102.82,237.423 2102.83,237.408 2102.83,237.393 2102.84,237.378 2102.85,237.363 2102.86,237.348 2102.87,237.333 2102.88,237.318 2102.89,237.303 2102.9,237.288 2102.91,237.273 2102.92,237.258 2102.93,237.243 2102.94,237.228 2102.95,237.213 2102.95,237.198 2102.96,237.183 2102.97,237.168 2102.98,237.153 2102.99,237.138 2103,237.123 2103.01,237.108 2103.02,237.093 2103.03,237.078 2103.04,237.063 2103.05,237.048 2103.06,237.033 2103.06,237.018 2103.07,237.004 2103.08,236.989 2103.09,236.974 2103.1,236.959 2103.11,236.944 2103.12,236.929 2103.13,236.914 2103.14,236.899 2103.15,236.884 2103.16,236.869 2103.17,236.854 2103.17,236.839 2103.18,236.824 2103.19,236.809 2103.2,236.795 2103.21,236.78 2103.22,236.765 2103.23,236.75 2103.24,236.735 2103.25,236.72 2103.26,236.705 2103.27,236.69 2103.28,236.675 2103.29,236.66 2103.29,236.645 2103.3,236.63 2103.31,236.616 2103.32,236.601 2103.33,236.586 2103.34,236.571 2103.35,236.556 2103.36,236.541 2103.37,236.526 2103.38,236.511 2103.39,236.496 2103.4,236.482 2103.4,236.467 2103.41,236.452 2103.42,236.437 2103.43,236.422 2103.44,236.407 2103.45,236.392 2103.46,236.377 2103.47,236.362 2103.48,236.348 2103.49,236.333 2103.5,236.318 2103.51,236.303 2103.51,236.288 2103.52,236.273 2103.53,236.258 2103.54,236.244 2103.55,236.229 2103.56,236.214 2103.57,236.199 2103.58,236.184 2103.59,236.169 2103.6,236.154 2103.61,236.14 2103.62,236.125 2103.63,236.11 2103.63,236.095 2103.64,236.08 2103.65,236.065 2103.66,236.05 2103.67,236.036 2103.68,236.021 2103.69,236.006 2103.7,235.991 2103.71,235.976 2103.72,235.961 2103.73,235.947 2103.74,235.932 2103.74,235.917 2103.75,235.902 2103.76,235.887 2103.77,235.873 2103.78,235.858 2103.79,235.843 2103.8,235.828 2103.81,235.813 2103.82,235.798 2103.83,235.784 2103.84,235.769 2103.85,235.754 2103.85,235.739 2103.86,235.724 2103.87,235.71 2103.88,235.695 2103.89,235.68 2103.9,235.665 2103.91,235.65 2103.92,235.636 2103.93,235.621 2103.94,235.606 2103.95,235.591 2103.96,235.576 2103.97,235.562 2103.97,235.547 2103.98,235.532 2103.99,235.517 2104,235.502 2104.01,235.488 2104.02,235.473 2104.03,235.458 2104.04,235.443 2104.05,235.429 2104.06,235.414 2104.07,235.399 2104.08,235.384 2104.08,235.369 2104.09,235.355 2104.1,235.34 2104.11,235.325 2104.12,235.31 2104.13,235.296 2104.14,235.281 2104.15,235.266 2104.16,235.251 2104.17,235.237 2104.18,235.222 2104.19,235.207 2104.19,235.192 2104.2,235.178 2104.21,235.163 2104.22,235.148 2104.23,235.133 2104.24,235.119 2104.25,235.104 2104.26,235.089 2104.27,235.074 2104.28,235.06 2104.29,235.045 2104.3,235.03 2104.31,235.016 2104.31,235.001 2104.32,234.986 2104.33,234.971 2104.34,234.957 2104.35,234.942 2104.36,234.927 2104.37,234.912 2104.38,234.898 2104.39,234.883 2104.4,234.868 2104.41,234.854 2104.42,234.839 2104.42,234.824 2104.43,234.809 2104.44,234.795 2104.45,234.78 2104.46,234.765 2104.47,234.751 2104.48,234.736 2104.49,234.721 2104.5,234.706 2104.51,234.692 2104.52,234.677 2104.53,234.662 2104.53,234.648 2104.54,234.633 2104.55,234.618 2104.56,234.604 2104.57,234.589 2104.58,234.574 2104.59,234.56 2104.6,234.545 2104.61,234.53 2104.62,234.516 2104.63,234.501 2104.64,234.486 2104.65,234.472 2104.65,234.457 2104.66,234.442 2104.67,234.428 2104.68,234.413 2104.69,234.398 2104.7,234.384 2104.71,234.369 2104.72,234.354 2104.73,234.34 2104.74,234.325 2104.75,234.31 2104.76,234.296 2104.76,234.281 2104.77,234.266 2104.78,234.252 2104.79,234.237 2104.8,234.222 2104.81,234.208 2104.82,234.193 2104.83,234.178 2104.84,234.164 2104.85,234.149 2104.86,234.134 2104.87,234.12 2104.87,234.105 2104.88,234.091 2104.89,234.076 2104.9,234.061 2104.91,234.047 2104.92,234.032 2104.93,234.017 2104.94,234.003 2104.95,233.988 2104.96,233.974 2104.97,233.959 2104.98,233.944 2104.99,233.93 2104.99,233.915 2105,233.9 2105.01,233.886 2105.02,233.871 2105.03,233.857 2105.04,233.842 2105.05,233.827 2105.06,233.813 2105.07,233.798 2105.08,233.784 2105.09,233.769 2105.1,233.754 2105.1,233.74 2105.11,233.725 2105.12,233.711 2105.13,233.696 2105.14,233.681 2105.15,233.667 2105.16,233.652 2105.17,233.638 2105.18,233.623 2105.19,233.609 2105.2,233.594 2105.21,233.579 2105.21,233.565 2105.22,233.55 2105.23,233.536 2105.24,233.521 2105.25,233.506 2105.26,233.492 2105.27,233.477 2105.28,233.463 2105.29,233.448 2105.3,233.434 2105.31,233.419 2105.32,233.405 2105.33,233.39 2105.33,233.375 2105.34,233.361 2105.35,233.346 2105.36,233.332 2105.37,233.317 2105.38,233.303 2105.39,233.288 2105.4,233.274 2105.41,233.259 2105.42,233.244 2105.43,233.23 2105.44,233.215 2105.44,233.201 2105.45,233.186 2105.46,233.172 2105.47,233.157 2105.48,233.143 2105.49,233.128 2105.5,233.114 2105.51,233.099 2105.52,233.085 2105.53,233.07 2105.54,233.056 2105.55,233.041 2105.55,233.026 2105.56,233.012 2105.57,232.997 2105.58,232.983 2105.59,232.968 2105.6,232.954 2105.61,232.939 2105.62,232.925 2105.63,232.91 2105.64,232.896 2105.65,232.881 2105.66,232.867 2105.67,232.852 2105.67,232.838 2105.68,232.823 2105.69,232.809 2105.7,232.794 2105.71,232.78 2105.72,232.765 2105.73,232.751 2105.74,232.736 2105.75,232.722 2105.76,232.707 2105.77,232.693 2105.78,232.678 2105.78,232.664 2105.79,232.649 2105.8,232.635 2105.81,232.621 2105.82,232.606 2105.83,232.592 2105.84,232.577 2105.85,232.563 2105.86,232.548 2105.87,232.534 2105.88,232.519 2105.89,232.505 2105.89,232.49 2105.9,232.476 2105.91,232.461 2105.92,232.447 2105.93,232.432 2105.94,232.418 2105.95,232.404 2105.96,232.389 2105.97,232.375 2105.98,232.36 2105.99,232.346 2106,232.331 2106.01,232.317 2106.01,232.302 2106.02,232.288 2106.03,232.274 2106.04,232.259 2106.05,232.245 2106.06,232.23 2106.07,232.216 2106.08,232.201 2106.09,232.187 2106.1,232.172 2106.11,232.158 2106.12,232.144 2106.12,232.129 2106.13,232.115 2106.14,232.1 2106.15,232.086 2106.16,232.072 2106.17,232.057 2106.18,232.043 2106.19,232.028 2106.2,232.014 2106.21,231.999 2106.22,231.985 2106.23,231.971 2106.23,231.956 2106.24,231.942 2106.25,231.927 2106.26,231.913 2106.27,231.899 2106.28,231.884 2106.29,231.87 2106.3,231.855 2106.31,231.841 2106.32,231.827 2106.33,231.812 2106.34,231.798 2106.35,231.783 2106.35,231.769 2106.36,231.755 2106.37,231.74 2106.38,231.726 2106.39,231.712 2106.4,231.697 2106.41,231.683 2106.42,231.668 2106.43,231.654 2106.44,231.64 2106.45,231.625 2106.46,231.611 2106.46,231.597 2106.47,231.582 2106.48,231.568 2106.49,231.553 2106.5,231.539 2106.51,231.525 2106.52,231.51 2106.53,231.496 2106.54,231.482 2106.55,231.467 2106.56,231.453 2106.57,231.439 2106.57,231.424 2106.58,231.41 2106.59,231.396 2106.6,231.381 2106.61,231.367 2106.62,231.352 2106.63,231.338 2106.64,231.324 2106.65,231.309 2106.66,231.295 2106.67,231.281 2106.68,231.266 2106.69,231.252 2106.69,231.238 2106.7,231.223 2106.71,231.209 2106.72,231.195 2106.73,231.18 2106.74,231.166 2106.75,231.152 2106.76,231.138 2106.77,231.123 2106.78,231.109 2106.79,231.095 2106.8,231.08 2106.8,231.066 2106.81,231.052 2106.82,231.037 2106.83,231.023 2106.84,231.009 2106.85,230.994 2106.86,230.98 2106.87,230.966 2106.88,230.951 2106.89,230.937 2106.9,230.923 2106.91,230.909 2106.91,230.894 2106.92,230.88 2106.93,230.866 2106.94,230.851 2106.95,230.837 2106.96,230.823 2106.97,230.809 2106.98,230.794 2106.99,230.78 2107,230.766 2107.01,230.751 2107.02,230.737 2107.03,230.723 2107.03,230.709 2107.04,230.694 2107.05,230.68 2107.06,230.666 2107.07,230.651 2107.08,230.637 2107.09,230.623 2107.1,230.609 2107.11,230.594 2107.12,230.58 2107.13,230.566 2107.14,230.552 2107.14,230.537 2107.15,230.523 2107.16,230.509 2107.17,230.495 2107.18,230.48 2107.19,230.466 2107.2,230.452 2107.21,230.438 2107.22,230.423 2107.23,230.409 2107.24,230.395 2107.25,230.381 2107.25,230.366 2107.26,230.352 2107.27,230.338 2107.28,230.324 2107.29,230.309 2107.3,230.295 2107.31,230.281 2107.32,230.267 2107.33,230.253 2107.34,230.238 2107.35,230.224 2107.36,230.21 2107.37,230.196 2107.37,230.181 2107.38,230.167 2107.39,230.153 2107.4,230.139 2107.41,230.125 2107.42,230.11 2107.43,230.096 2107.44,230.082 2107.45,230.068 2107.46,230.054 2107.47,230.039 2107.48,230.025 2107.48,230.011 2107.49,229.997 2107.5,229.983 2107.51,229.968 2107.52,229.954 2107.53,229.94 2107.54,229.926 2107.55,229.912 2107.56,229.897 2107.57,229.883 2107.58,229.869 2107.59,229.855 2107.59,229.841 2107.6,229.826 2107.61,229.812 2107.62,229.798 2107.63,229.784 2107.64,229.77 2107.65,229.756 2107.66,229.741 2107.67,229.727 2107.68,229.713 2107.69,229.699 2107.7,229.685 2107.71,229.671 2107.71,229.656 2107.72,229.642 2107.73,229.628 2107.74,229.614 2107.75,229.6 2107.76,229.586 2107.77,229.571 2107.78,229.557 2107.79,229.543 2107.8,229.529 2107.81,229.515 2107.82,229.501 2107.82,229.486 2107.83,229.472 2107.84,229.458 2107.85,229.444 2107.86,229.43 2107.87,229.416 2107.88,229.402 2107.89,229.388 2107.9,229.373 2107.91,229.359 2107.92,229.345 2107.93,229.331 2107.93,229.317 2107.94,229.303 2107.95,229.289 2107.96,229.274 2107.97,229.26 2107.98,229.246 2107.99,229.232 2108,229.218 2108.01,229.204 2108.02,229.19 2108.03,229.176 2108.04,229.162 2108.05,229.147 2108.05,229.133 2108.06,229.119 2108.07,229.105 2108.08,229.091 2108.09,229.077 2108.1,229.063 2108.11,229.049 2108.12,229.035 2108.13,229.02 2108.14,229.006 2108.15,228.992 2108.16,228.978 2108.16,228.964 2108.17,228.95 2108.18,228.936 2108.19,228.922 2108.2,228.908 2108.21,228.894 2108.22,228.88 2108.23,228.866 2108.24,228.851 2108.25,228.837 2108.26,228.823 2108.27,228.809 2108.27,228.795 2108.28,228.781 2108.29,228.767 2108.3,228.753 2108.31,228.739 2108.32,228.725 2108.33,228.711 2108.34,228.697 2108.35,228.683 2108.36,228.669 2108.37,228.654 2108.38,228.64 2108.39,228.626 2108.39,228.612 2108.4,228.598 2108.41,228.584 2108.42,228.57 2108.43,228.556 2108.44,228.542 2108.45,228.528 2108.46,228.514 2108.47,228.5 2108.48,228.486 2108.49,228.472 2108.5,228.458 2108.5,228.444 2108.51,228.43 2108.52,228.416 2108.53,228.402 2108.54,228.388 2108.55,228.374 2108.56,228.36 2108.57,228.346 2108.58,228.332 2108.59,228.318 2108.6,228.303 2108.61,228.289 2108.61,228.275 2108.62,228.261 2108.63,228.247 2108.64,228.233 2108.65,228.219 2108.66,228.205 2108.67,228.191 2108.68,228.177 2108.69,228.163 2108.7,228.149 2108.71,228.135 2108.72,228.121 2108.73,228.107 2108.73,228.093 2108.74,228.079 2108.75,228.065 2108.76,228.051 2108.77,228.037 2108.78,228.023 2108.79,228.009 2108.8,227.995 2108.81,227.981 2108.82,227.967 2108.83,227.953 2108.84,227.939 2108.84,227.925 2108.85,227.911 2108.86,227.897 2108.87,227.884 2108.88,227.87 2108.89,227.856 2108.9,227.842 2108.91,227.828 2108.92,227.814 2108.93,227.8 2108.94,227.786 2108.95,227.772 2108.95,227.758 2108.96,227.744 2108.97,227.73 2108.98,227.716 2108.99,227.702 2109,227.688 2109.01,227.674 2109.02,227.66 2109.03,227.646 2109.04,227.632 2109.05,227.618 2109.06,227.604 2109.07,227.59 2109.07,227.576 2109.08,227.562 2109.09,227.548 2109.1,227.535 2109.11,227.521 2109.12,227.507 2109.13,227.493 2109.14,227.479 2109.15,227.465 2109.16,227.451 2109.17,227.437 2109.18,227.423 2109.18,227.409 2109.19,227.395 2109.2,227.381 2109.21,227.367 2109.22,227.353 2109.23,227.34 2109.24,227.326 2109.25,227.312 2109.26,227.298 2109.27,227.284 2109.28,227.27 2109.29,227.256 2109.29,227.242 2109.3,227.228 2109.31,227.214 2109.32,227.2 2109.33,227.187 2109.34,227.173 2109.35,227.159 2109.36,227.145 2109.37,227.131 2109.38,227.117 2109.39,227.103 2109.4,227.089 2109.41,227.075 2109.41,227.061 2109.42,227.048 2109.43,227.034 2109.44,227.02 2109.45,227.006 2109.46,226.992 2109.47,226.978 2109.48,226.964 2109.49,226.95 2109.5,226.936 2109.51,226.923 2109.52,226.909 2109.52,226.895 2109.53,226.881 2109.54,226.867 2109.55,226.853 2109.56,226.839 2109.57,226.826 2109.58,226.812 2109.59,226.798 2109.6,226.784 2109.61,226.77 2109.62,226.756 2109.63,226.742 2109.63,226.728 2109.64,226.715 2109.65,226.701 2109.66,226.687 2109.67,226.673 2109.68,226.659 2109.69,226.645 2109.7,226.632 2109.71,226.618 2109.72,226.604 2109.73,226.59 2109.74,226.576 2109.75,226.562 2109.75,226.548 2109.76,226.535 2109.77,226.521 2109.78,226.507 2109.79,226.493 2109.8,226.479 2109.81,226.465 2109.82,226.452 2109.83,226.438 2109.84,226.424 2109.85,226.41 2109.86,226.396 2109.86,226.383 2109.87,226.369 2109.88,226.355 2109.89,226.341 2109.9,226.327 2109.91,226.313 2109.92,226.3 2109.93,226.286 2109.94,226.272 2109.95,226.258 2109.96,226.244 2109.97,226.231 2109.97,226.217 2109.98,226.203 2109.99,226.189 2110,226.175 2110.01,226.162 2110.02,226.148 2110.03,226.134 2110.04,226.12 2110.05,226.106 2110.06,226.093 2110.07,226.079 2110.08,226.065 2110.09,226.051 2110.09,226.038 2110.1,226.024 2110.11,226.01 2110.12,225.996 2110.13,225.982 2110.14,225.969 2110.15,225.955 2110.16,225.941 2110.17,225.927 2110.18,225.914 2110.19,225.9 2110.2,225.886 2110.2,225.872 2110.21,225.858 2110.22,225.845 2110.23,225.831 2110.24,225.817 2110.25,225.803 2110.26,225.79 2110.27,225.776 2110.28,225.762 2110.29,225.748 2110.3,225.735 2110.31,225.721 2110.31,225.707 2110.32,225.693 2110.33,225.68 2110.34,225.666 2110.35,225.652 2110.36,225.638 2110.37,225.625 2110.38,225.611 2110.39,225.597 2110.4,225.583 2110.41,225.57 2110.42,225.556 2110.43,225.542 2110.43,225.529 2110.44,225.515 2110.45,225.501 2110.46,225.487 2110.47,225.474 2110.48,225.46 2110.49,225.446 2110.5,225.432 2110.51,225.419 2110.52,225.405 2110.53,225.391 2110.54,225.378 2110.54,225.364 2110.55,225.35 2110.56,225.336 2110.57,225.323 2110.58,225.309 2110.59,225.295 2110.6,225.282 2110.61,225.268 2110.62,225.254 2110.63,225.241 2110.64,225.227 2110.65,225.213 2110.65,225.199 2110.66,225.186 2110.67,225.172 2110.68,225.158 2110.69,225.145 2110.7,225.131 2110.71,225.117 2110.72,225.104 2110.73,225.09 2110.74,225.076 2110.75,225.063 2110.76,225.049 2110.77,225.035 2110.77,225.022 2110.78,225.008 2110.79,224.994 2110.8,224.981 2110.81,224.967 2110.82,224.953 2110.83,224.939 2110.84,224.926 2110.85,224.912 2110.86,224.899 2110.87,224.885 2110.88,224.871 2110.88,224.858 2110.89,224.844 2110.9,224.83 2110.91,224.817 2110.92,224.803 2110.93,224.789 2110.94,224.776 2110.95,224.762 2110.96,224.748 2110.97,224.735 2110.98,224.721 2110.99,224.707 2110.99,224.694 2111,224.68 2111.01,224.666 2111.02,224.653 2111.03,224.639 2111.04,224.626 2111.05,224.612 2111.06,224.598 2111.07,224.585 2111.08,224.571 2111.09,224.557 2111.1,224.544 2111.11,224.53 2111.11,224.516 2111.12,224.503 2111.13,224.489 2111.14,224.476 2111.15,224.462 2111.16,224.448 2111.17,224.435 2111.18,224.421 2111.19,224.408 2111.2,224.394 2111.21,224.38 2111.22,224.367 2111.22,224.353 2111.23,224.339 2111.24,224.326 2111.25,224.312 2111.26,224.299 2111.27,224.285 2111.28,224.271 2111.29,224.258 2111.3,224.244 2111.31,224.231 2111.32,224.217 2111.33,224.204 2111.33,224.19 2111.34,224.176 2111.35,224.163 2111.36,224.149 2111.37,224.136 2111.38,224.122 2111.39,224.108 2111.4,224.095 2111.41,224.081 2111.42,224.068 2111.43,224.054 2111.44,224.041 2111.45,224.027 2111.45,224.013 2111.46,224 2111.47,223.986 2111.48,223.973 2111.49,223.959 2111.5,223.946 2111.51,223.932 2111.52,223.918 2111.53,223.905 2111.54,223.891 2111.55,223.878 2111.56,223.864 2111.56,223.851 2111.57,223.837 2111.58,223.824 2111.59,223.81 2111.6,223.796 2111.61,223.783 2111.62,223.769 2111.63,223.756 2111.64,223.742 2111.65,223.729 2111.66,223.715 2111.67,223.702 2111.67,223.688 2111.68,223.675 2111.69,223.661 2111.7,223.647 2111.71,223.634 2111.72,223.62 2111.73,223.607 2111.74,223.593 2111.75,223.58 2111.76,223.566 2111.77,223.553 2111.78,223.539 2111.79,223.526 2111.79,223.512 2111.8,223.499 2111.81,223.485 2111.82,223.472 2111.83,223.458 2111.84,223.445 2111.85,223.431 2111.86,223.418 2111.87,223.404 2111.88,223.391 2111.89,223.377 2111.9,223.364 2111.9,223.35 2111.91,223.337 2111.92,223.323 2111.93,223.31 2111.94,223.296 2111.95,223.283 2111.96,223.269 2111.97,223.256 2111.98,223.242 2111.99,223.229 2112,223.215 2112.01,223.202 2112.01,223.188 2112.02,223.175 2112.03,223.161 2112.04,223.148 2112.05,223.134 2112.06,223.121 2112.07,223.107 2112.08,223.094 2112.09,223.08 2112.1,223.067 2112.11,223.053 2112.12,223.04 2112.13,223.026 2112.13,223.013 2112.14,223 2112.15,222.986 2112.16,222.973 2112.17,222.959 2112.18,222.946 2112.19,222.932 2112.2,222.919 2112.21,222.905 2112.22,222.892 2112.23,222.878 2112.24,222.865 2112.24,222.852 2112.25,222.838 2112.26,222.825 2112.27,222.811 2112.28,222.798 2112.29,222.784 2112.3,222.771 2112.31,222.757 2112.32,222.744 2112.33,222.731 2112.34,222.717 2112.35,222.704 2112.35,222.69 2112.36,222.677 2112.37,222.663 2112.38,222.65 2112.39,222.637 2112.4,222.623 2112.41,222.61 2112.42,222.596 2112.43,222.583 2112.44,222.569 2112.45,222.556 2112.46,222.543 2112.47,222.529 2112.47,222.516 2112.48,222.502 2112.49,222.489 2112.5,222.475 2112.51,222.462 2112.52,222.449 2112.53,222.435 2112.54,222.422 2112.55,222.408 2112.56,222.395 2112.57,222.382 2112.58,222.368 2112.58,222.355 2112.59,222.341 2112.6,222.328 2112.61,222.315 2112.62,222.301 2112.63,222.288 2112.64,222.275 2112.65,222.261 2112.66,222.248 2112.67,222.234 2112.68,222.221 2112.69,222.208 2112.69,222.194 2112.7,222.181 2112.71,222.167 2112.72,222.154 2112.73,222.141 2112.74,222.127 2112.75,222.114 2112.76,222.101 2112.77,222.087 2112.78,222.074 2112.79,222.06 2112.8,222.047 2112.81,222.034 2112.81,222.02 2112.82,222.007 2112.83,221.994 2112.84,221.98 2112.85,221.967 2112.86,221.954 2112.87,221.94 2112.88,221.927 2112.89,221.914 2112.9,221.9 2112.91,221.887 2112.92,221.873 2112.92,221.86 2112.93,221.847 2112.94,221.833 2112.95,221.82 2112.96,221.807 2112.97,221.793 2112.98,221.78 2112.99,221.767 2113,221.753 2113.01,221.74 2113.02,221.727 2113.03,221.713 2113.03,221.7 2113.04,221.687 2113.05,221.673 2113.06,221.66 2113.07,221.647 2113.08,221.633 2113.09,221.62 2113.1,221.607 2113.11,221.593 2113.12,221.58 2113.13,221.567 2113.14,221.554 2113.15,221.54 2113.15,221.527 2113.16,221.514 2113.17,221.5 2113.18,221.487 2113.19,221.474 2113.2,221.46 2113.21,221.447 2113.22,221.434 2113.23,221.42 2113.24,221.407 2113.25,221.394 2113.26,221.381 2113.26,221.367 2113.27,221.354 2113.28,221.341 2113.29,221.327 2113.3,221.314 2113.31,221.301 2113.32,221.288 2113.33,221.274 2113.34,221.261 2113.35,221.248 2113.36,221.234 2113.37,221.221 2113.37,221.208 2113.38,221.195 2113.39,221.181 2113.4,221.168 2113.41,221.155 2113.42,221.141 2113.43,221.128 2113.44,221.115 2113.45,221.102 2113.46,221.088 2113.47,221.075 2113.48,221.062 2113.49,221.049 2113.49,221.035 2113.5,221.022 2113.51,221.009 2113.52,220.996 2113.53,220.982 2113.54,220.969 2113.55,220.956 2113.56,220.943 2113.57,220.929 2113.58,220.916 2113.59,220.903 2113.6,220.89 2113.6,220.876 2113.61,220.863 2113.62,220.85 2113.63,220.837 2113.64,220.823 2113.65,220.81 2113.66,220.797 2113.67,220.784 2113.68,220.77 2113.69,220.757 2113.7,220.744 2113.71,220.731 2113.71,220.717 2113.72,220.704 2113.73,220.691 2113.74,220.678 2113.75,220.665 2113.76,220.651 2113.77,220.638 2113.78,220.625 2113.79,220.612 2113.8,220.599 2113.81,220.585 2113.82,220.572 2113.83,220.559 2113.83,220.546 2113.84,220.532 2113.85,220.519 2113.86,220.506 2113.87,220.493 2113.88,220.48 2113.89,220.466 2113.9,220.453 2113.91,220.44 2113.92,220.427 2113.93,220.414 2113.94,220.4 2113.94,220.387 2113.95,220.374 2113.96,220.361 2113.97,220.348 2113.98,220.334 2113.99,220.321 2114,220.308 2114.01,220.295 2114.02,220.282 2114.03,220.269 2114.04,220.255 2114.05,220.242 2114.05,220.229 2114.06,220.216 2114.07,220.203 2114.08,220.19 2114.09,220.176 2114.1,220.163 2114.11,220.15 2114.12,220.137 2114.13,220.124 2114.14,220.111 2114.15,220.097 2114.16,220.084 2114.17,220.071 2114.17,220.058 2114.18,220.045 2114.19,220.032 2114.2,220.018 2114.21,220.005 2114.22,219.992 2114.23,219.979 2114.24,219.966 2114.25,219.953 2114.26,219.939 2114.27,219.926 2114.28,219.913 2114.28,219.9 2114.29,219.887 2114.3,219.874 2114.31,219.861 2114.32,219.848 2114.33,219.834 2114.34,219.821 2114.35,219.808 2114.36,219.795 2114.37,219.782 2114.38,219.769 2114.39,219.756 2114.39,219.742 2114.4,219.729 2114.41,219.716 2114.42,219.703 2114.43,219.69 2114.44,219.677 2114.45,219.664 2114.46,219.651 2114.47,219.637 2114.48,219.624 2114.49,219.611 2114.5,219.598 2114.51,219.585 2114.51,219.572 2114.52,219.559 2114.53,219.546 2114.54,219.533 2114.55,219.52 2114.56,219.506 2114.57,219.493 2114.58,219.48 2114.59,219.467 2114.6,219.454 2114.61,219.441 2114.62,219.428 2114.62,219.415 2114.63,219.402 2114.64,219.389 2114.65,219.375 2114.66,219.362 2114.67,219.349 2114.68,219.336 2114.69,219.323 2114.7,219.31 2114.71,219.297 2114.72,219.284 2114.73,219.271 2114.73,219.258 2114.74,219.245 2114.75,219.232 2114.76,219.219 2114.77,219.205 2114.78,219.192 2114.79,219.179 2114.8,219.166 2114.81,219.153 2114.82,219.14 2114.83,219.127 2114.84,219.114 2114.85,219.101 2114.85,219.088 2114.86,219.075 2114.87,219.062 2114.88,219.049 2114.89,219.036 2114.9,219.023 2114.91,219.01 2114.92,218.997 2114.93,218.983 2114.94,218.97 2114.95,218.957 2114.96,218.944 2114.96,218.931 2114.97,218.918 2114.98,218.905 2114.99,218.892 2115,218.879 2115.01,218.866 2115.02,218.853 2115.03,218.84 2115.04,218.827 2115.05,218.814 2115.06,218.801 2115.07,218.788 2115.07,218.775 2115.08,218.762 2115.09,218.749 2115.1,218.736 2115.11,218.723 2115.12,218.71 2115.13,218.697 2115.14,218.684 2115.15,218.671 2115.16,218.658 2115.17,218.645 2115.18,218.632 2115.19,218.619 2115.19,218.606 2115.2,218.593 2115.21,218.58 2115.22,218.567 2115.23,218.554 2115.24,218.541 2115.25,218.528 2115.26,218.515 2115.27,218.502 2115.28,218.489 2115.29,218.476 2115.3,218.463 2115.3,218.45 2115.31,218.437 2115.32,218.424 2115.33,218.411 2115.34,218.398 2115.35,218.385 2115.36,218.372 2115.37,218.359 2115.38,218.346 2115.39,218.333 2115.4,218.32 2115.41,218.307 2115.41,218.294 2115.42,218.281 2115.43,218.268 2115.44,218.255 2115.45,218.242 2115.46,218.229 2115.47,218.216 2115.48,218.203 2115.49,218.19 2115.5,218.177 2115.51,218.164 2115.52,218.151 2115.53,218.138 2115.53,218.125 2115.54,218.112 2115.55,218.099 2115.56,218.086 2115.57,218.073 2115.58,218.061 2115.59,218.048 2115.6,218.035 2115.61,218.022 2115.62,218.009 2115.63,217.996 2115.64,217.983 2115.64,217.97 2115.65,217.957 2115.66,217.944 2115.67,217.931 2115.68,217.918 2115.69,217.905 2115.7,217.892 2115.71,217.879 2115.72,217.866 2115.73,217.853 2115.74,217.841 2115.75,217.828 2115.75,217.815 2115.76,217.802 2115.77,217.789 2115.78,217.776 2115.79,217.763 2115.8,217.75 2115.81,217.737 2115.82,217.724 2115.83,217.711 2115.84,217.698 2115.85,217.686 2115.86,217.673 2115.87,217.66 2115.87,217.647 2115.88,217.634 2115.89,217.621 2115.9,217.608 2115.91,217.595 2115.92,217.582 2115.93,217.569 2115.94,217.556 2115.95,217.544 2115.96,217.531 2115.97,217.518 2115.98,217.505 2115.98,217.492 2115.99,217.479 2116,217.466 2116.01,217.453 2116.02,217.44 2116.03,217.428 2116.04,217.415 2116.05,217.402 2116.06,217.389 2116.07,217.376 2116.08,217.363 2116.09,217.35 2116.09,217.337 2116.1,217.325 2116.11,217.312 2116.12,217.299 2116.13,217.286 2116.14,217.273 2116.15,217.26 2116.16,217.247 2116.17,217.234 2116.18,217.222 2116.19,217.209 2116.2,217.196 2116.21,217.183 2116.21,217.17 2116.22,217.157 2116.23,217.144 2116.24,217.132 2116.25,217.119 2116.26,217.106 2116.27,217.093 2116.28,217.08 2116.29,217.067 2116.3,217.054 2116.31,217.042 2116.32,217.029 2116.32,217.016 2116.33,217.003 2116.34,216.99 2116.35,216.977 2116.36,216.965 2116.37,216.952 2116.38,216.939 2116.39,216.926 2116.4,216.913 2116.41,216.9 2116.42,216.888 2116.43,216.875 2116.43,216.862 2116.44,216.849 2116.45,216.836 2116.46,216.823 2116.47,216.811 2116.48,216.798 2116.49,216.785 2116.5,216.772 2116.51,216.759 2116.52,216.746 2116.53,216.734 2116.54,216.721 2116.55,216.708 2116.55,216.695 2116.56,216.682 2116.57,216.67 2116.58,216.657 2116.59,216.644 2116.6,216.631 2116.61,216.618 2116.62,216.606 2116.63,216.593 2116.64,216.58 2116.65,216.567 2116.66,216.554 2116.66,216.542 2116.67,216.529 2116.68,216.516 2116.69,216.503 2116.7,216.49 2116.71,216.478 2116.72,216.465 2116.73,216.452 2116.74,216.439 2116.75,216.427 2116.76,216.414 2116.77,216.401 2116.77,216.388 2116.78,216.375 2116.79,216.363 2116.8,216.35 2116.81,216.337 2116.82,216.324 2116.83,216.312 2116.84,216.299 2116.85,216.286 2116.86,216.273 2116.87,216.26 2116.88,216.248 2116.89,216.235 2116.89,216.222 2116.9,216.209 2116.91,216.197 2116.92,216.184 2116.93,216.171 2116.94,216.158 2116.95,216.146 2116.96,216.133 2116.97,216.12 2116.98,216.107 2116.99,216.095 2117,216.082 2117,216.069 2117.01,216.056 2117.02,216.044 2117.03,216.031 2117.04,216.018 2117.05,216.005 2117.06,215.993 2117.07,215.98 2117.08,215.967 2117.09,215.954 2117.1,215.942 2117.11,215.929 2117.11,215.916 2117.12,215.904 2117.13,215.891 2117.14,215.878 2117.15,215.865 2117.16,215.853 2117.17,215.84 2117.18,215.827 2117.19,215.814 2117.2,215.802 2117.21,215.789 2117.22,215.776 2117.23,215.764 2117.23,215.751 2117.24,215.738 2117.25,215.725 2117.26,215.713 2117.27,215.7 2117.28,215.687 2117.29,215.675 2117.3,215.662 2117.31,215.649 2117.32,215.637 2117.33,215.624 2117.34,215.611 2117.34,215.598 2117.35,215.586 2117.36,215.573 2117.37,215.56 2117.38,215.548 2117.39,215.535 2117.4,215.522 2117.41,215.51 2117.42,215.497 2117.43,215.484 2117.44,215.472 2117.45,215.459 2117.45,215.446 2117.46,215.433 2117.47,215.421 2117.48,215.408 2117.49,215.395 2117.5,215.383 2117.51,215.37 2117.52,215.357 2117.53,215.345 2117.54,215.332 2117.55,215.319 2117.56,215.307 2117.57,215.294 2117.57,215.281 2117.58,215.269 2117.59,215.256 2117.6,215.243 2117.61,215.231 2117.62,215.218 2117.63,215.205 2117.64,215.193 2117.65,215.18 2117.66,215.168 2117.67,215.155 2117.68,215.142 2117.68,215.13 2117.69,215.117 2117.7,215.104 2117.71,215.092 2117.72,215.079 2117.73,215.066 2117.74,215.054 2117.75,215.041 2117.76,215.028 2117.77,215.016 2117.78,215.003 2117.79,214.991 2117.79,214.978 2117.8,214.965 2117.81,214.953 2117.82,214.94 2117.83,214.927 2117.84,214.915 2117.85,214.902 2117.86,214.889 2117.87,214.877 2117.88,214.864 2117.89,214.852 2117.9,214.839 2117.91,214.826 2117.91,214.814 2117.92,214.801 2117.93,214.789 2117.94,214.776 2117.95,214.763 2117.96,214.751 2117.97,214.738 2117.98,214.725 2117.99,214.713 2118,214.7 2118.01,214.688 2118.02,214.675 2118.02,214.662 2118.03,214.65 2118.04,214.637 2118.05,214.625 2118.06,214.612 2118.07,214.599 2118.08,214.587 2118.09,214.574 2118.1,214.562 2118.11,214.549 2118.12,214.537 2118.13,214.524 2118.13,214.511 2118.14,214.499 2118.15,214.486 2118.16,214.474 2118.17,214.461 2118.18,214.448 2118.19,214.436 2118.2,214.423 2118.21,214.411 2118.22,214.398 2118.23,214.386 2118.24,214.373 2118.25,214.36 2118.25,214.348 2118.26,214.335 2118.27,214.323 2118.28,214.31 2118.29,214.298 2118.3,214.285 2118.31,214.272 2118.32,214.26 2118.33,214.247 2118.34,214.235 2118.35,214.222 2118.36,214.21 2118.36,214.197 2118.37,214.185 2118.38,214.172 2118.39,214.159 2118.4,214.147 2118.41,214.134 2118.42,214.122 2118.43,214.109 2118.44,214.097 2118.45,214.084 2118.46,214.072 2118.47,214.059 2118.47,214.047 2118.48,214.034 2118.49,214.022 2118.5,214.009 2118.51,213.996 2118.52,213.984 2118.53,213.971 2118.54,213.959 2118.55,213.946 2118.56,213.934 2118.57,213.921 2118.58,213.909 2118.59,213.896 2118.59,213.884 2118.6,213.871 2118.61,213.859 2118.62,213.846 2118.63,213.834 2118.64,213.821 2118.65,213.809 2118.66,213.796 2118.67,213.784 2118.68,213.771 2118.69,213.759 2118.7,213.746 2118.7,213.734 2118.71,213.721 2118.72,213.709 2118.73,213.696 2118.74,213.684 2118.75,213.671 2118.76,213.659 2118.77,213.646 2118.78,213.634 2118.79,213.621 2118.8,213.609 2118.81,213.596 2118.81,213.584 2118.82,213.571 2118.83,213.559 2118.84,213.546 2118.85,213.534 2118.86,213.521 2118.87,213.509 2118.88,213.496 2118.89,213.484 2118.9,213.471 2118.91,213.459 2118.92,213.446 2118.93,213.434 2118.93,213.421 2118.94,213.409 2118.95,213.396 2118.96,213.384 2118.97,213.371 2118.98,213.359 2118.99,213.347 2119,213.334 2119.01,213.322 2119.02,213.309 2119.03,213.297 2119.04,213.284 2119.04,213.272 2119.05,213.259 2119.06,213.247 2119.07,213.234 2119.08,213.222 2119.09,213.209 2119.1,213.197 2119.11,213.185 2119.12,213.172 2119.13,213.16 2119.14,213.147 2119.15,213.135 2119.15,213.122 2119.16,213.11 2119.17,213.097 2119.18,213.085 2119.19,213.073 2119.2,213.06 2119.21,213.048 2119.22,213.035 2119.23,213.023 2119.24,213.01 2119.25,212.998 2119.26,212.986 2119.27,212.973 2119.27,212.961 2119.28,212.948 2119.29,212.936 2119.3,212.923 2119.31,212.911 2119.32,212.899 2119.33,212.886 2119.34,212.874 2119.35,212.861 2119.36,212.849 2119.37,212.837 2119.38,212.824 2119.38,212.812 2119.39,212.799 2119.4,212.787 2119.41,212.774 2119.42,212.762 2119.43,212.75 2119.44,212.737 2119.45,212.725 2119.46,212.712 2119.47,212.7 2119.48,212.688 2119.49,212.675 2119.49,212.663 2119.5,212.65 2119.51,212.638 2119.52,212.626 2119.53,212.613 2119.54,212.601 2119.55,212.588 2119.56,212.576 2119.57,212.564 2119.58,212.551 2119.59,212.539 2119.6,212.527 2119.61,212.514 2119.61,212.502 2119.62,212.489 2119.63,212.477 2119.64,212.465 2119.65,212.452 2119.66,212.44 2119.67,212.428 2119.68,212.415 2119.69,212.403 2119.7,212.39 2119.71,212.378 2119.72,212.366 2119.72,212.353 2119.73,212.341 2119.74,212.329 2119.75,212.316 2119.76,212.304 2119.77,212.292 2119.78,212.279 2119.79,212.267 2119.8,212.254 2119.81,212.242 2119.82,212.23 2119.83,212.217 2119.83,212.205 2119.84,212.193 2119.85,212.18 2119.86,212.168 2119.87,212.156 2119.88,212.143 2119.89,212.131 2119.9,212.119 2119.91,212.106 2119.92,212.094 2119.93,212.082 2119.94,212.069 2119.95,212.057 2119.95,212.045 2119.96,212.032 2119.97,212.02 2119.98,212.008 2119.99,211.995 2120,211.983 2120.01,211.971 2120.02,211.958 2120.03,211.946 2120.04,211.934 2120.05,211.921 2120.06,211.909 2120.06,211.897 2120.07,211.884 2120.08,211.872 2120.09,211.86 2120.1,211.848 2120.11,211.835 2120.12,211.823 2120.13,211.811 2120.14,211.798 2120.15,211.786 2120.16,211.774 2120.17,211.761 2120.17,211.749 2120.18,211.737 2120.19,211.724 2120.2,211.712 2120.21,211.7 2120.22,211.688 2120.23,211.675 2120.24,211.663 2120.25,211.651 2120.26,211.638 2120.27,211.626 2120.28,211.614 2120.29,211.602 2120.29,211.589 2120.3,211.577 2120.31,211.565 2120.32,211.552 2120.33,211.54 2120.34,211.528 2120.35,211.516 2120.36,211.503 2120.37,211.491 2120.38,211.479 2120.39,211.466 2120.4,211.454 2120.4,211.442 2120.41,211.43 2120.42,211.417 2120.43,211.405 2120.44,211.393 2120.45,211.381 2120.46,211.368 2120.47,211.356 2120.48,211.344 2120.49,211.332 2120.5,211.319 2120.51,211.307 2120.51,211.295 2120.52,211.282 2120.53,211.27 2120.54,211.258 2120.55,211.246 2120.56,211.233 2120.57,211.221 2120.58,211.209 2120.59,211.197 2120.6,211.184 2120.61,211.172 2120.62,211.16 2120.63,211.148 2120.63,211.136 2120.64,211.123 2120.65,211.111 2120.66,211.099 2120.67,211.087 2120.68,211.074 2120.69,211.062 2120.7,211.05 2120.71,211.038 2120.72,211.025 2120.73,211.013 2120.74,211.001 2120.74,210.989 2120.75,210.977 2120.76,210.964 2120.77,210.952 2120.78,210.94 2120.79,210.928 2120.8,210.915 2120.81,210.903 2120.82,210.891 2120.83,210.879 2120.84,210.867 2120.85,210.854 2120.85,210.842 2120.86,210.83 2120.87,210.818 2120.88,210.806 2120.89,210.793 2120.9,210.781 2120.91,210.769 2120.92,210.757 2120.93,210.744 2120.94,210.732 2120.95,210.72 2120.96,210.708 2120.97,210.696 2120.97,210.684 2120.98,210.671 2120.99,210.659 2121,210.647 2121.01,210.635 2121.02,210.623 2121.03,210.61 2121.04,210.598 2121.05,210.586 2121.06,210.574 2121.07,210.562 2121.08,210.549 2121.08,210.537 2121.09,210.525 2121.1,210.513 2121.11,210.501 2121.12,210.489 2121.13,210.476 2121.14,210.464 2121.15,210.452 2121.16,210.44 2121.17,210.428 2121.18,210.416 2121.19,210.403 2121.19,210.391 2121.2,210.379 2121.21,210.367 2121.22,210.355 2121.23,210.343 2121.24,210.33 2121.25,210.318 2121.26,210.306 2121.27,210.294 2121.28,210.282 2121.29,210.27 2121.3,210.258 2121.31,210.245 2121.31,210.233 2121.32,210.221 2121.33,210.209 2121.34,210.197 2121.35,210.185 2121.36,210.172 2121.37,210.16 2121.38,210.148 2121.39,210.136 2121.4,210.124 2121.41,210.112 2121.42,210.1 2121.42,210.088 2121.43,210.075 2121.44,210.063 2121.45,210.051 2121.46,210.039 2121.47,210.027 2121.48,210.015 2121.49,210.003 2121.5,209.991 2121.51,209.978 2121.52,209.966 2121.53,209.954 2121.53,209.942 2121.54,209.93 2121.55,209.918 2121.56,209.906 2121.57,209.894 2121.58,209.881 2121.59,209.869 2121.6,209.857 2121.61,209.845 2121.62,209.833 2121.63,209.821 2121.64,209.809 2121.65,209.797 2121.65,209.785 2121.66,209.773 2121.67,209.76 2121.68,209.748 2121.69,209.736 2121.7,209.724 2121.71,209.712 2121.72,209.7 2121.73,209.688 2121.74,209.676 2121.75,209.664 2121.76,209.652 2121.76,209.639 2121.77,209.627 2121.78,209.615 2121.79,209.603 2121.8,209.591 2121.81,209.579 2121.82,209.567 2121.83,209.555 2121.84,209.543 2121.85,209.531 2121.86,209.519 2121.87,209.507 2121.87,209.495 2121.88,209.482 2121.89,209.47 2121.9,209.458 2121.91,209.446 2121.92,209.434 2121.93,209.422 2121.94,209.41 2121.95,209.398 2121.96,209.386 2121.97,209.374 2121.98,209.362 2121.99,209.35 2121.99,209.338 2122,209.326 2122.01,209.314 2122.02,209.302 2122.03,209.289 2122.04,209.277 2122.05,209.265 2122.06,209.253 2122.07,209.241 2122.08,209.229 2122.09,209.217 2122.1,209.205 2122.1,209.193 2122.11,209.181 2122.12,209.169 2122.13,209.157 2122.14,209.145 2122.15,209.133 2122.16,209.121 2122.17,209.109 2122.18,209.097 2122.19,209.085 2122.2,209.073 2122.21,209.061 2122.21,209.049 2122.22,209.037 2122.23,209.025 2122.24,209.013 2122.25,209.001 2122.26,208.989 2122.27,208.977 2122.28,208.965 2122.29,208.952 2122.3,208.94 2122.31,208.928 2122.32,208.916 2122.33,208.904 2122.33,208.892 2122.34,208.88 2122.35,208.868 2122.36,208.856 2122.37,208.844 2122.38,208.832 2122.39,208.82 2122.4,208.808 2122.41,208.796 2122.42,208.784 2122.43,208.772 2122.44,208.76 2122.44,208.748 2122.45,208.736 2122.46,208.724 2122.47,208.712 2122.48,208.7 2122.49,208.688 2122.5,208.676 2122.51,208.664 2122.52,208.652 2122.53,208.64 2122.54,208.628 2122.55,208.616 2122.56,208.605 2122.56,208.593 2122.57,208.581 2122.58,208.569 2122.59,208.557 2122.6,208.545 2122.61,208.533 2122.62,208.521 2122.63,208.509 2122.64,208.497 2122.65,208.485 2122.66,208.473 2122.67,208.461 2122.67,208.449 2122.68,208.437 2122.69,208.425 2122.7,208.413 2122.71,208.401 2122.72,208.389 2122.73,208.377 2122.74,208.365 2122.75,208.353 2122.76,208.341 2122.77,208.329 2122.78,208.317 2122.78,208.305 2122.79,208.293 2122.8,208.281 2122.81,208.269 2122.82,208.258 2122.83,208.246 2122.84,208.234 2122.85,208.222 2122.86,208.21 2122.87,208.198 2122.88,208.186 2122.89,208.174 2122.9,208.162 2122.9,208.15 2122.91,208.138 2122.92,208.126 2122.93,208.114 2122.94,208.102 2122.95,208.09 2122.96,208.078 2122.97,208.067 2122.98,208.055 2122.99,208.043 2123,208.031 2123.01,208.019 2123.01,208.007 2123.02,207.995 2123.03,207.983 2123.04,207.971 2123.05,207.959 2123.06,207.947 2123.07,207.935 2123.08,207.923 2123.09,207.912 2123.1,207.9 2123.11,207.888 2123.12,207.876 2123.12,207.864 2123.13,207.852 2123.14,207.84 2123.15,207.828 2123.16,207.816 2123.17,207.804 2123.18,207.793 2123.19,207.781 2123.2,207.769 2123.21,207.757 2123.22,207.745 2123.23,207.733 2123.24,207.721 2123.24,207.709 2123.25,207.697 2123.26,207.685 2123.27,207.674 2123.28,207.662 2123.29,207.65 2123.3,207.638 2123.31,207.626 2123.32,207.614 2123.33,207.602 2123.34,207.59 2123.35,207.579 2123.35,207.567 2123.36,207.555 2123.37,207.543 2123.38,207.531 2123.39,207.519 2123.4,207.507 2123.41,207.495 2123.42,207.484 2123.43,207.472 2123.44,207.46 2123.45,207.448 2123.46,207.436 2123.46,207.424 2123.47,207.412 2123.48,207.4 2123.49,207.389 2123.5,207.377 2123.51,207.365 2123.52,207.353 2123.53,207.341 2123.54,207.329 2123.55,207.317 2123.56,207.306 2123.57,207.294 2123.58,207.282 2123.58,207.27 2123.59,207.258 2123.6,207.246 2123.61,207.235 2123.62,207.223 2123.63,207.211 2123.64,207.199 2123.65,207.187 2123.66,207.175 2123.67,207.164 2123.68,207.152 2123.69,207.14 2123.69,207.128 2123.7,207.116 2123.71,207.104 2123.72,207.093 2123.73,207.081 2123.74,207.069 2123.75,207.057 2123.76,207.045 2123.77,207.033 2123.78,207.022 2123.79,207.01 2123.8,206.998 2123.8,206.986 2123.81,206.974 2123.82,206.962 2123.83,206.951 2123.84,206.939 2123.85,206.927 2123.86,206.915 2123.87,206.903 2123.88,206.892 2123.89,206.88 2123.9,206.868 2123.91,206.856 2123.92,206.844 2123.92,206.833 2123.93,206.821 2123.94,206.809 2123.95,206.797 2123.96,206.785 2123.97,206.774 2123.98,206.762 2123.99,206.75 2124,206.738 2124.01,206.726 2124.02,206.715 2124.03,206.703 2124.03,206.691 2124.04,206.679 2124.05,206.667 2124.06,206.656 2124.07,206.644 2124.08,206.632 2124.09,206.62 2124.1,206.609 2124.11,206.597 2124.12,206.585 2124.13,206.573 2124.14,206.561 2124.14,206.55 2124.15,206.538 2124.16,206.526 2124.17,206.514 2124.18,206.503 2124.19,206.491 2124.2,206.479 2124.21,206.467 2124.22,206.455 2124.23,206.444 2124.24,206.432 2124.25,206.42 2124.26,206.408 2124.26,206.397 2124.27,206.385 2124.28,206.373 2124.29,206.361 2124.3,206.35 2124.31,206.338 2124.32,206.326 2124.33,206.314 2124.34,206.303 2124.35,206.291 2124.36,206.279 2124.37,206.267 2124.37,206.256 2124.38,206.244 2124.39,206.232 2124.4,206.22 2124.41,206.209 2124.42,206.197 2124.43,206.185 2124.44,206.173 2124.45,206.162 2124.46,206.15 2124.47,206.138 2124.48,206.127 2124.48,206.115 2124.49,206.103 2124.5,206.091 2124.51,206.08 2124.52,206.068 2124.53,206.056 2124.54,206.044 2124.55,206.033 2124.56,206.021 2124.57,206.009 2124.58,205.998 2124.59,205.986 2124.6,205.974 2124.6,205.962 2124.61,205.951 2124.62,205.939 2124.63,205.927 2124.64,205.916 2124.65,205.904 2124.66,205.892 2124.67,205.88 2124.68,205.869 2124.69,205.857 2124.7,205.845 2124.71,205.834 2124.71,205.822 2124.72,205.81 2124.73,205.798 2124.74,205.787 2124.75,205.775 2124.76,205.763 2124.77,205.752 2124.78,205.74 2124.79,205.728 2124.8,205.717 2124.81,205.705 2124.82,205.693 2124.82,205.682 2124.83,205.67 2124.84,205.658 2124.85,205.647 2124.86,205.635 2124.87,205.623 2124.88,205.611 2124.89,205.6 2124.9,205.588 2124.91,205.576 2124.92,205.565 2124.93,205.553 2124.94,205.541 2124.94,205.53 2124.95,205.518 2124.96,205.506 2124.97,205.495 2124.98,205.483 2124.99,205.471 2125,205.46 2125.01,205.448 2125.02,205.436 2125.03,205.425 2125.04,205.413 2125.05,205.401 2125.05,205.39 2125.06,205.378 2125.07,205.366 2125.08,205.355 2125.09,205.343 2125.1,205.331 2125.11,205.32 2125.12,205.308 2125.13,205.297 2125.14,205.285 2125.15,205.273 2125.16,205.262 2125.16,205.25 2125.17,205.238 2125.18,205.227 2125.19,205.215 2125.2,205.203 2125.21,205.192 2125.22,205.18 2125.23,205.168 2125.24,205.157 2125.25,205.145 2125.26,205.134 2125.27,205.122 2125.28,205.11 2125.28,205.099 2125.29,205.087 2125.3,205.075 2125.31,205.064 2125.32,205.052 2125.33,205.041 2125.34,205.029 2125.35,205.017 2125.36,205.006 2125.37,204.994 2125.38,204.982 2125.39,204.971 2125.39,204.959 2125.4,204.948 2125.41,204.936 2125.42,204.924 2125.43,204.913 2125.44,204.901 2125.45,204.89 2125.46,204.878 2125.47,204.866 2125.48,204.855 2125.49,204.843 2125.5,204.832 2125.5,204.82 2125.51,204.808 2125.52,204.797 2125.53,204.785 2125.54,204.774 2125.55,204.762 2125.56,204.75 2125.57,204.739 2125.58,204.727 2125.59,204.716 2125.6,204.704 2125.61,204.692 2125.62,204.681 2125.62,204.669 2125.63,204.658 2125.64,204.646 2125.65,204.634 2125.66,204.623 2125.67,204.611 2125.68,204.6 2125.69,204.588 2125.7,204.577 2125.71,204.565 2125.72,204.553 2125.73,204.542 2125.73,204.53 2125.74,204.519 2125.75,204.507 2125.76,204.496 2125.77,204.484 2125.78,204.472 2125.79,204.461 2125.8,204.449 2125.81,204.438 2125.82,204.426 2125.83,204.415 2125.84,204.403 2125.84,204.391 2125.85,204.38 2125.86,204.368 2125.87,204.357 2125.88,204.345 2125.89,204.334 2125.9,204.322 2125.91,204.311 2125.92,204.299 2125.93,204.288 2125.94,204.276 2125.95,204.264 2125.96,204.253 2125.96,204.241 2125.97,204.23 2125.98,204.218 2125.99,204.207 2126,204.195 2126.01,204.184 2126.02,204.172 2126.03,204.161 2126.04,204.149 2126.05,204.138 2126.06,204.126 2126.07,204.114 2126.07,204.103 2126.08,204.091 2126.09,204.08 2126.1,204.068 2126.11,204.057 2126.12,204.045 2126.13,204.034 2126.14,204.022 2126.15,204.011 2126.16,203.999 2126.17,203.988 2126.18,203.976 2126.18,203.965 2126.19,203.953 2126.2,203.942 2126.21,203.93 2126.22,203.919 2126.23,203.907 2126.24,203.896 2126.25,203.884 2126.26,203.873 2126.27,203.861 2126.28,203.85 2126.29,203.838 2126.3,203.827 2126.3,203.815 2126.31,203.804 2126.32,203.792 2126.33,203.781 2126.34,203.769 2126.35,203.758 2126.36,203.746 2126.37,203.735 2126.38,203.723 2126.39,203.712 2126.4,203.7 2126.41,203.689 2126.41,203.677 2126.42,203.666 2126.43,203.654 2126.44,203.643 2126.45,203.631 2126.46,203.62 2126.47,203.608 2126.48,203.597 2126.49,203.585 2126.5,203.574 2126.51,203.562 2126.52,203.551 2126.52,203.539 2126.53,203.528 2126.54,203.516 2126.55,203.505 2126.56,203.494 2126.57,203.482 2126.58,203.471 2126.59,203.459 2126.6,203.448 2126.61,203.436 2126.62,203.425 2126.63,203.413 2126.64,203.402 2126.64,203.39 2126.65,203.379 2126.66,203.367 2126.67,203.356 2126.68,203.345 2126.69,203.333 2126.7,203.322 2126.71,203.31 2126.72,203.299 2126.73,203.287 2126.74,203.276 2126.75,203.264 2126.75,203.253 2126.76,203.241 2126.77,203.23 2126.78,203.219 2126.79,203.207 2126.8,203.196 2126.81,203.184 2126.82,203.173 2126.83,203.161 2126.84,203.15 2126.85,203.139 2126.86,203.127 2126.86,203.116 2126.87,203.104 2126.88,203.093 2126.89,203.081 2126.9,203.07 2126.91,203.059 2126.92,203.047 2126.93,203.036 2126.94,203.024 2126.95,203.013 2126.96,203.001 2126.97,202.99 2126.98,202.979 2126.98,202.967 2126.99,202.956 2127,202.944 2127.01,202.933 2127.02,202.922 2127.03,202.91 2127.04,202.899 2127.05,202.887 2127.06,202.876 2127.07,202.864 2127.08,202.853 2127.09,202.842 2127.09,202.83 2127.1,202.819 2127.11,202.807 2127.12,202.796 2127.13,202.785 2127.14,202.773 2127.15,202.762 2127.16,202.751 2127.17,202.739 2127.18,202.728 2127.19,202.716 2127.2,202.705 2127.2,202.694 2127.21,202.682 2127.22,202.671 2127.23,202.659 2127.24,202.648 2127.25,202.637 2127.26,202.625 2127.27,202.614 2127.28,202.602 2127.29,202.591 2127.3,202.58 2127.31,202.568 2127.32,202.557 2127.32,202.546 2127.33,202.534 2127.34,202.523 2127.35,202.511 2127.36,202.5 2127.37,202.489 2127.38,202.477 2127.39,202.466 2127.4,202.455 2127.41,202.443 2127.42,202.432 2127.43,202.421 2127.43,202.409 2127.44,202.398 2127.45,202.386 2127.46,202.375 2127.47,202.364 2127.48,202.352 2127.49,202.341 2127.5,202.33 2127.51,202.318 2127.52,202.307 2127.53,202.296 2127.54,202.284 2127.54,202.273 2127.55,202.262 2127.56,202.25 2127.57,202.239 2127.58,202.228 2127.59,202.216 2127.6,202.205 2127.61,202.194 2127.62,202.182 2127.63,202.171 2127.64,202.16 2127.65,202.148 2127.66,202.137 2127.66,202.126 2127.67,202.114 2127.68,202.103 2127.69,202.092 2127.7,202.08 2127.71,202.069 2127.72,202.058 2127.73,202.046 2127.74,202.035 2127.75,202.024 2127.76,202.012 2127.77,202.001 2127.77,201.99 2127.78,201.978 2127.79,201.967 2127.8,201.956 2127.81,201.944 2127.82,201.933 2127.83,201.922 2127.84,201.91 2127.85,201.899 2127.86,201.888 2127.87,201.877 2127.88,201.865 2127.88,201.854 2127.89,201.843 2127.9,201.831 2127.91,201.82 2127.92,201.809 2127.93,201.797 2127.94,201.786 2127.95,201.775 2127.96,201.764 2127.97,201.752 2127.98,201.741 2127.99,201.73 2128,201.718 2128,201.707 2128.01,201.696 2128.02,201.684 2128.03,201.673 2128.04,201.662 2128.05,201.651 2128.06,201.639 2128.07,201.628 2128.08,201.617 2128.09,201.605 2128.1,201.594 2128.11,201.583 2128.11,201.572 2128.12,201.56 2128.13,201.549 2128.14,201.538 2128.15,201.527 2128.16,201.515 2128.17,201.504 2128.18,201.493 2128.19,201.481 2128.2,201.47 2128.21,201.459 2128.22,201.448 2128.22,201.436 2128.23,201.425 2128.24,201.414 2128.25,201.403 2128.26,201.391 2128.27,201.38 2128.28,201.369 2128.29,201.358 2128.3,201.346 2128.31,201.335 2128.32,201.324 2128.33,201.313 2128.34,201.301 2128.34,201.29 2128.35,201.279 2128.36,201.268 2128.37,201.256 2128.38,201.245 2128.39,201.234 2128.4,201.223 2128.41,201.211 2128.42,201.2 2128.43,201.189 2128.44,201.178 2128.45,201.166 2128.45,201.155 2128.46,201.144 2128.47,201.133 2128.48,201.121 2128.49,201.11 2128.5,201.099 2128.51,201.088 2128.52,201.077 2128.53,201.065 2128.54,201.054 2128.55,201.043 2128.56,201.032 2128.56,201.02 2128.57,201.009 2128.58,200.998 2128.59,200.987 2128.6,200.976 2128.61,200.964 2128.62,200.953 2128.63,200.942 2128.64,200.931 2128.65,200.919 2128.66,200.908 2128.67,200.897 2128.68,200.886 2128.68,200.875 2128.69,200.863 2128.7,200.852 2128.71,200.841 2128.72,200.83 2128.73,200.819 2128.74,200.807 2128.75,200.796 2128.76,200.785 2128.77,200.774 2128.78,200.763 2128.79,200.751 2128.79,200.74 2128.8,200.729 2128.81,200.718 2128.82,200.707 2128.83,200.695 2128.84,200.684 2128.85,200.673 2128.86,200.662 2128.87,200.651 2128.88,200.64 2128.89,200.628 2128.9,200.617 2128.9,200.606 2128.91,200.595 2128.92,200.584 2128.93,200.572 2128.94,200.561 2128.95,200.55 2128.96,200.539 2128.97,200.528 2128.98,200.517 2128.99,200.505 2129,200.494 2129.01,200.483 2129.02,200.472 2129.02,200.461 2129.03,200.45 2129.04,200.438 2129.05,200.427 2129.06,200.416 2129.07,200.405 2129.08,200.394 2129.09,200.383 2129.1,200.371 2129.11,200.36 2129.12,200.349 2129.13,200.338 2129.13,200.327 2129.14,200.316 2129.15,200.305 2129.16,200.293 2129.17,200.282 2129.18,200.271 2129.19,200.26 2129.2,200.249 2129.21,200.238 2129.22,200.226 2129.23,200.215 2129.24,200.204 2129.24,200.193 2129.25,200.182 2129.26,200.171 2129.27,200.16 2129.28,200.148 2129.29,200.137 2129.3,200.126 2129.31,200.115 2129.32,200.104 2129.33,200.093 2129.34,200.082 2129.35,200.071 2129.36,200.059 2129.36,200.048 2129.37,200.037 2129.38,200.026 2129.39,200.015 2129.4,200.004 2129.41,199.993 2129.42,199.982 2129.43,199.97 2129.44,199.959 2129.45,199.948 2129.46,199.937 2129.47,199.926 2129.47,199.915 2129.48,199.904 2129.49,199.893 2129.5,199.882 2129.51,199.87 2129.52,199.859 2129.53,199.848 2129.54,199.837 2129.55,199.826 2129.56,199.815 2129.57,199.804 2129.58,199.793 2129.58,199.782 2129.59,199.771 2129.6,199.759 2129.61,199.748 2129.62,199.737 2129.63,199.726 2129.64,199.715 2129.65,199.704 2129.66,199.693 2129.67,199.682 2129.68,199.671 2129.69,199.66 2129.7,199.648 2129.7,199.637 2129.71,199.626 2129.72,199.615 2129.73,199.604 2129.74,199.593 2129.75,199.582 2129.76,199.571 2129.77,199.56 2129.78,199.549 2129.79,199.538 2129.8,199.527 2129.81,199.516 2129.81,199.504 2129.82,199.493 2129.83,199.482 2129.84,199.471 2129.85,199.46 2129.86,199.449 2129.87,199.438 2129.88,199.427 2129.89,199.416 2129.9,199.405 2129.91,199.394 2129.92,199.383 2129.92,199.372 2129.93,199.361 2129.94,199.35 2129.95,199.339 2129.96,199.327 2129.97,199.316 2129.98,199.305 2129.99,199.294 2130,199.283 2130.01,199.272 2130.02,199.261 2130.03,199.25 2130.04,199.239 2130.04,199.228 2130.05,199.217 2130.06,199.206 2130.07,199.195 2130.08,199.184 2130.09,199.173 2130.1,199.162 2130.11,199.151 2130.12,199.14 2130.13,199.129 2130.14,199.118 2130.15,199.107 2130.15,199.096 2130.16,199.085 2130.17,199.073 2130.18,199.062 2130.19,199.051 2130.2,199.04 2130.21,199.029 2130.22,199.018 2130.23,199.007 2130.24,198.996 2130.25,198.985 2130.26,198.974 2130.26,198.963 2130.27,198.952 2130.28,198.941 2130.29,198.93 2130.3,198.919 2130.31,198.908 2130.32,198.897 2130.33,198.886 2130.34,198.875 2130.35,198.864 2130.36,198.853 2130.37,198.842 2130.38,198.831 2130.38,198.82 2130.39,198.809 2130.4,198.798 2130.41,198.787 2130.42,198.776 2130.43,198.765 2130.44,198.754 2130.45,198.743 2130.46,198.732 2130.47,198.721 2130.48,198.71 2130.49,198.699 2130.49,198.688 2130.5,198.677 2130.51,198.666 2130.52,198.655 2130.53,198.644 2130.54,198.633 2130.55,198.622 2130.56,198.611 2130.57,198.6 2130.58,198.589 2130.59,198.578 2130.6,198.567 2130.6,198.556 2130.61,198.545 2130.62,198.534 2130.63,198.523 2130.64,198.512 2130.65,198.501 2130.66,198.49 2130.67,198.479 2130.68,198.468 2130.69,198.458 2130.7,198.447 2130.71,198.436 2130.72,198.425 2130.72,198.414 2130.73,198.403 2130.74,198.392 2130.75,198.381 2130.76,198.37 2130.77,198.359 2130.78,198.348 2130.79,198.337 2130.8,198.326 2130.81,198.315 2130.82,198.304 2130.83,198.293 2130.83,198.282 2130.84,198.271 2130.85,198.26 2130.86,198.249 2130.87,198.238 2130.88,198.227 2130.89,198.216 2130.9,198.206 2130.91,198.195 2130.92,198.184 2130.93,198.173 2130.94,198.162 2130.94,198.151 2130.95,198.14 2130.96,198.129 2130.97,198.118 2130.98,198.107 2130.99,198.096 2131,198.085 2131.01,198.074 2131.02,198.063 2131.03,198.052 2131.04,198.041 2131.05,198.031 2131.06,198.02 2131.06,198.009 2131.07,197.998 2131.08,197.987 2131.09,197.976 2131.1,197.965 2131.11,197.954 2131.12,197.943 2131.13,197.932 2131.14,197.921 2131.15,197.91 2131.16,197.899 2131.17,197.889 2131.17,197.878 2131.18,197.867 2131.19,197.856 2131.2,197.845 2131.21,197.834 2131.22,197.823 2131.23,197.812 2131.24,197.801 2131.25,197.79 2131.26,197.779 2131.27,197.769 2131.28,197.758 2131.28,197.747 2131.29,197.736 2131.3,197.725 2131.31,197.714 2131.32,197.703 2131.33,197.692 2131.34,197.681 2131.35,197.671 2131.36,197.66 2131.37,197.649 2131.38,197.638 2131.39,197.627 2131.4,197.616 2131.4,197.605 2131.41,197.594 2131.42,197.583 2131.43,197.573 2131.44,197.562 2131.45,197.551 2131.46,197.54 2131.47,197.529 2131.48,197.518 2131.49,197.507 2131.5,197.496 2131.51,197.486 2131.51,197.475 2131.52,197.464 2131.53,197.453 2131.54,197.442 2131.55,197.431 2131.56,197.42 2131.57,197.409 2131.58,197.399 2131.59,197.388 2131.6,197.377 2131.61,197.366 2131.62,197.355 2131.62,197.344 2131.63,197.333 2131.64,197.323 2131.65,197.312 2131.66,197.301 2131.67,197.29 2131.68,197.279 2131.69,197.268 2131.7,197.257 2131.71,197.247 2131.72,197.236 2131.73,197.225 2131.74,197.214 2131.74,197.203 2131.75,197.192 2131.76,197.181 2131.77,197.171 2131.78,197.16 2131.79,197.149 2131.8,197.138 2131.81,197.127 2131.82,197.116 2131.83,197.106 2131.84,197.095 2131.85,197.084 2131.85,197.073 2131.86,197.062 2131.87,197.051 2131.88,197.041 2131.89,197.03 2131.9,197.019 2131.91,197.008 2131.92,196.997 2131.93,196.986 2131.94,196.976 2131.95,196.965 2131.96,196.954 2131.96,196.943 2131.97,196.932 2131.98,196.921 2131.99,196.911 2132,196.9 2132.01,196.889 2132.02,196.878 2132.03,196.867 2132.04,196.857 2132.05,196.846 2132.06,196.835 2132.07,196.824 2132.08,196.813 2132.08,196.803 2132.09,196.792 2132.1,196.781 2132.11,196.77 2132.12,196.759 2132.13,196.749 2132.14,196.738 2132.15,196.727 2132.16,196.716 2132.17,196.705 2132.18,196.695 2132.19,196.684 2132.19,196.673 2132.2,196.662 2132.21,196.651 2132.22,196.641 2132.23,196.63 2132.24,196.619 2132.25,196.608 2132.26,196.597 2132.27,196.587 2132.28,196.576 2132.29,196.565 2132.3,196.554 2132.3,196.543 2132.31,196.533 2132.32,196.522 2132.33,196.511 2132.34,196.5 2132.35,196.49 2132.36,196.479 2132.37,196.468 2132.38,196.457 2132.39,196.446 2132.4,196.436 2132.41,196.425 2132.42,196.414 2132.42,196.403 2132.43,196.393 2132.44,196.382 2132.45,196.371 2132.46,196.36 2132.47,196.35 2132.48,196.339 2132.49,196.328 2132.5,196.317 2132.51,196.307 2132.52,196.296 2132.53,196.285 2132.53,196.274 2132.54,196.264 2132.55,196.253 2132.56,196.242 2132.57,196.231 2132.58,196.22 2132.59,196.21 2132.6,196.199 2132.61,196.188 2132.62,196.178 2132.63,196.167 2132.64,196.156 2132.64,196.145 2132.65,196.135 2132.66,196.124 2132.67,196.113 2132.68,196.102 2132.69,196.092 2132.7,196.081 2132.71,196.07 2132.72,196.059 2132.73,196.049 2132.74,196.038 2132.75,196.027 2132.76,196.016 2132.76,196.006 2132.77,195.995 2132.78,195.984 2132.79,195.974 2132.8,195.963 2132.81,195.952 2132.82,195.941 2132.83,195.931 2132.84,195.92 2132.85,195.909 2132.86,195.898 2132.87,195.888 2132.87,195.877 2132.88,195.866 2132.89,195.856 2132.9,195.845 2132.91,195.834 2132.92,195.823 2132.93,195.813 2132.94,195.802 2132.95,195.791 2132.96,195.781 2132.97,195.77 2132.98,195.759 2132.98,195.748 2132.99,195.738 2133,195.727 2133.01,195.716 2133.02,195.706 2133.03,195.695 2133.04,195.684 2133.05,195.674 2133.06,195.663 2133.07,195.652 2133.08,195.641 2133.09,195.631 2133.1,195.62 2133.1,195.609 2133.11,195.599 2133.12,195.588 2133.13,195.577 2133.14,195.567 2133.15,195.556 2133.16,195.545 2133.17,195.535 2133.18,195.524 2133.19,195.513 2133.2,195.503 2133.21,195.492 2133.21,195.481 2133.22,195.471 2133.23,195.46 2133.24,195.449 2133.25,195.438 2133.26,195.428 2133.27,195.417 2133.28,195.406 2133.29,195.396 2133.3,195.385 2133.31,195.374 2133.32,195.364 2133.32,195.353 2133.33,195.342 2133.34,195.332 2133.35,195.321 2133.36,195.31 2133.37,195.3 2133.38,195.289 2133.39,195.278 2133.4,195.268 2133.41,195.257 2133.42,195.247 2133.43,195.236 2133.44,195.225 2133.44,195.215 2133.45,195.204 2133.46,195.193 2133.47,195.183 2133.48,195.172 2133.49,195.161 2133.5,195.151 2133.51,195.14 2133.52,195.129 2133.53,195.119 2133.54,195.108 2133.55,195.097 2133.55,195.087 2133.56,195.076 2133.57,195.066 2133.58,195.055 2133.59,195.044 2133.6,195.034 2133.61,195.023 2133.62,195.012 2133.63,195.002 2133.64,194.991 2133.65,194.98 2133.66,194.97 2133.66,194.959 2133.67,194.949 2133.68,194.938 2133.69,194.927 2133.7,194.917 2133.71,194.906 2133.72,194.895 2133.73,194.885 2133.74,194.874 2133.75,194.864 2133.76,194.853 2133.77,194.842 2133.78,194.832 2133.78,194.821 2133.79,194.811 2133.8,194.8 2133.81,194.789 2133.82,194.779 2133.83,194.768 2133.84,194.757 2133.85,194.747 2133.86,194.736 2133.87,194.726 2133.88,194.715 2133.89,194.704 2133.89,194.694 2133.9,194.683 2133.91,194.673 2133.92,194.662 2133.93,194.651 2133.94,194.641 2133.95,194.63 2133.96,194.62 2133.97,194.609 2133.98,194.598 2133.99,194.588 2134,194.577 2134,194.567 2134.01,194.556 2134.02,194.545 2134.03,194.535 2134.04,194.524 2134.05,194.514 2134.06,194.503 2134.07,194.493 2134.08,194.482 2134.09,194.471 2134.1,194.461 2134.11,194.45 2134.12,194.44 2134.12,194.429 2134.13,194.419 2134.14,194.408 2134.15,194.397 2134.16,194.387 2134.17,194.376 2134.18,194.366 2134.19,194.355 2134.2,194.345 2134.21,194.334 2134.22,194.323 2134.23,194.313 2134.23,194.302 2134.24,194.292 2134.25,194.281 2134.26,194.271 2134.27,194.26 2134.28,194.249 2134.29,194.239 2134.3,194.228 2134.31,194.218 2134.32,194.207 2134.33,194.197 2134.34,194.186 2134.34,194.176 2134.35,194.165 2134.36,194.154 2134.37,194.144 2134.38,194.133 2134.39,194.123 2134.4,194.112 2134.41,194.102 2134.42,194.091 2134.43,194.081 2134.44,194.07 2134.45,194.06 2134.46,194.049 2134.46,194.038 2134.47,194.028 2134.48,194.017 2134.49,194.007 2134.5,193.996 2134.51,193.986 2134.52,193.975 2134.53,193.965 2134.54,193.954 2134.55,193.944 2134.56,193.933 2134.57,193.923 2134.57,193.912 2134.58,193.902 2134.59,193.891 2134.6,193.88 2134.61,193.87 2134.62,193.859 2134.63,193.849 2134.64,193.838 2134.65,193.828 2134.66,193.817 2134.67,193.807 2134.68,193.796 2134.68,193.786 2134.69,193.775 2134.7,193.765 2134.71,193.754 2134.72,193.744 2134.73,193.733 2134.74,193.723 2134.75,193.712 2134.76,193.702 2134.77,193.691 2134.78,193.681 2134.79,193.67 2134.8,193.66 2134.8,193.649 2134.81,193.639 2134.82,193.628 2134.83,193.618 2134.84,193.607 2134.85,193.597 2134.86,193.586 2134.87,193.576 2134.88,193.565 2134.89,193.555 2134.9,193.544 2134.91,193.534 2134.91,193.523 2134.92,193.513 2134.93,193.502 2134.94,193.492 2134.95,193.481 2134.96,193.471 2134.97,193.46 2134.98,193.45 2134.99,193.439 2135,193.429 2135.01,193.418 2135.02,193.408 2135.02,193.397 2135.03,193.387 2135.04,193.377 2135.05,193.366 2135.06,193.356 2135.07,193.345 2135.08,193.335 2135.09,193.324 2135.1,193.314 2135.11,193.303 2135.12,193.293 2135.13,193.282 2135.14,193.272 2135.14,193.261 2135.15,193.251 2135.16,193.24 2135.17,193.23 2135.18,193.22 2135.19,193.209 2135.2,193.199 2135.21,193.188 2135.22,193.178 2135.23,193.167 2135.24,193.157 2135.25,193.146 2135.25,193.136 2135.26,193.125 2135.27,193.115 2135.28,193.105 2135.29,193.094 2135.3,193.084 2135.31,193.073 2135.32,193.063 2135.33,193.052 2135.34,193.042 2135.35,193.031 2135.36,193.021 2135.36,193.011 2135.37,193 2135.38,192.99 2135.39,192.979 2135.4,192.969 2135.41,192.958 2135.42,192.948 2135.43,192.937 2135.44,192.927 2135.45,192.917 2135.46,192.906 2135.47,192.896 2135.48,192.885 2135.48,192.875 2135.49,192.864 2135.5,192.854 2135.51,192.844 2135.52,192.833 2135.53,192.823 2135.54,192.812 2135.55,192.802 2135.56,192.791 2135.57,192.781 2135.58,192.771 2135.59,192.76 2135.59,192.75 2135.6,192.739 2135.61,192.729 2135.62,192.719 2135.63,192.708 2135.64,192.698 2135.65,192.687 2135.66,192.677 2135.67,192.667 2135.68,192.656 2135.69,192.646 2135.7,192.635 2135.7,192.625 2135.71,192.615 2135.72,192.604 2135.73,192.594 2135.74,192.583 2135.75,192.573 2135.76,192.563 2135.77,192.552 2135.78,192.542 2135.79,192.531 2135.8,192.521 2135.81,192.511 2135.82,192.5 2135.82,192.49 2135.83,192.479 2135.84,192.469 2135.85,192.459 2135.86,192.448 2135.87,192.438 2135.88,192.427 2135.89,192.417 2135.9,192.407 2135.91,192.396 2135.92,192.386 2135.93,192.376 2135.93,192.365 2135.94,192.355 2135.95,192.344 2135.96,192.334 2135.97,192.324 2135.98,192.313 2135.99,192.303 2136,192.293 2136.01,192.282 2136.02,192.272 2136.03,192.261 2136.04,192.251 2136.04,192.241 2136.05,192.23 2136.06,192.22 2136.07,192.21 2136.08,192.199 2136.09,192.189 2136.1,192.179 2136.11,192.168 2136.12,192.158 2136.13,192.147 2136.14,192.137 2136.15,192.127 2136.16,192.116 2136.16,192.106 2136.17,192.096 2136.18,192.085 2136.19,192.075 2136.2,192.065 2136.21,192.054 2136.22,192.044 2136.23,192.034 2136.24,192.023 2136.25,192.013 2136.26,192.003 2136.27,191.992 2136.27,191.982 2136.28,191.972 2136.29,191.961 2136.3,191.951 2136.31,191.941 2136.32,191.93 2136.33,191.92 2136.34,191.91 2136.35,191.899 2136.36,191.889 2136.37,191.879 2136.38,191.868 2136.38,191.858 2136.39,191.848 2136.4,191.837 2136.41,191.827 2136.42,191.817 2136.43,191.806 2136.44,191.796 2136.45,191.786 2136.46,191.775 2136.47,191.765 2136.48,191.755 2136.49,191.744 2136.5,191.734 2136.5,191.724 2136.51,191.713 2136.52,191.703 2136.53,191.693 2136.54,191.682 2136.55,191.672 2136.56,191.662 2136.57,191.651 2136.58,191.641 2136.59,191.631 2136.6,191.621 2136.61,191.61 2136.61,191.6 2136.62,191.59 2136.63,191.579 2136.64,191.569 2136.65,191.559 2136.66,191.548 2136.67,191.538 2136.68,191.528 2136.69,191.518 2136.7,191.507 2136.71,191.497 2136.72,191.487 2136.72,191.476 2136.73,191.466 2136.74,191.456 2136.75,191.445 2136.76,191.435 2136.77,191.425 2136.78,191.415 2136.79,191.404 2136.8,191.394 2136.81,191.384 2136.82,191.373 2136.83,191.363 2136.84,191.353 2136.84,191.343 2136.85,191.332 2136.86,191.322 2136.87,191.312 2136.88,191.302 2136.89,191.291 2136.9,191.281 2136.91,191.271 2136.92,191.26 2136.93,191.25 2136.94,191.24 2136.95,191.23 2136.95,191.219 2136.96,191.209 2136.97,191.199 2136.98,191.189 2136.99,191.178 2137,191.168 2137.01,191.158 2137.02,191.147 2137.03,191.137 2137.04,191.127 2137.05,191.117 2137.06,191.106 2137.06,191.096 2137.07,191.086 2137.08,191.076 2137.09,191.065 2137.1,191.055 2137.11,191.045 2137.12,191.035 2137.13,191.024 2137.14,191.014 2137.15,191.004 2137.16,190.994 2137.17,190.983 2137.18,190.973 2137.18,190.963 2137.19,190.953 2137.2,190.942 2137.21,190.932 2137.22,190.922 2137.23,190.912 2137.24,190.901 2137.25,190.891 2137.26,190.881 2137.27,190.871 2137.28,190.861 2137.29,190.85 2137.29,190.84 2137.3,190.83 2137.31,190.82 2137.32,190.809 2137.33,190.799 2137.34,190.789 2137.35,190.779 2137.36,190.768 2137.37,190.758 2137.38,190.748 2137.39,190.738 2137.4,190.728 2137.4,190.717 2137.41,190.707 2137.42,190.697 2137.43,190.687 2137.44,190.676 2137.45,190.666 2137.46,190.656 2137.47,190.646 2137.48,190.636 2137.49,190.625 2137.5,190.615 2137.51,190.605 2137.52,190.595 2137.52,190.585 2137.53,190.574 2137.54,190.564 2137.55,190.554 2137.56,190.544 2137.57,190.534 2137.58,190.523 2137.59,190.513 2137.6,190.503 2137.61,190.493 2137.62,190.483 2137.63,190.472 2137.63,190.462 2137.64,190.452 2137.65,190.442 2137.66,190.432 2137.67,190.421 2137.68,190.411 2137.69,190.401 2137.7,190.391 2137.71,190.381 2137.72,190.37 2137.73,190.36 2137.74,190.35 2137.74,190.34 2137.75,190.33 2137.76,190.32 2137.77,190.309 2137.78,190.299 2137.79,190.289 2137.8,190.279 2137.81,190.269 2137.82,190.258 2137.83,190.248 2137.84,190.238 2137.85,190.228 2137.86,190.218 2137.86,190.208 2137.87,190.197 2137.88,190.187 2137.89,190.177 2137.9,190.167 2137.91,190.157 2137.92,190.147 2137.93,190.136 2137.94,190.126 2137.95,190.116 2137.96,190.106 2137.97,190.096 2137.97,190.086 2137.98,190.075 2137.99,190.065 2138,190.055 2138.01,190.045 2138.02,190.035 2138.03,190.025 2138.04,190.014 2138.05,190.004 2138.06,189.994 2138.07,189.984 2138.08,189.974 2138.08,189.964 2138.09,189.954 2138.1,189.943 2138.11,189.933 2138.12,189.923 2138.13,189.913 2138.14,189.903 2138.15,189.893 2138.16,189.883 2138.17,189.872 2138.18,189.862 2138.19,189.852 2138.2,189.842 2138.2,189.832 2138.21,189.822 2138.22,189.812 2138.23,189.801 2138.24,189.791 2138.25,189.781 2138.26,189.771 2138.27,189.761 2138.28,189.751 2138.29,189.741 2138.3,189.731 2138.31,189.72 2138.31,189.71 2138.32,189.7 2138.33,189.69 2138.34,189.68 2138.35,189.67 2138.36,189.66 2138.37,189.65 2138.38,189.639 2138.39,189.629 2138.4,189.619 2138.41,189.609 2138.42,189.599 2138.42,189.589 2138.43,189.579 2138.44,189.569 2138.45,189.559 2138.46,189.548 2138.47,189.538 2138.48,189.528 2138.49,189.518 2138.5,189.508 2138.51,189.498 2138.52,189.488 2138.53,189.478 2138.54,189.468 2138.54,189.457 2138.55,189.447 2138.56,189.437 2138.57,189.427 2138.58,189.417 2138.59,189.407 2138.6,189.397 2138.61,189.387 2138.62,189.377 2138.63,189.367 2138.64,189.357 2138.65,189.346 2138.65,189.336 2138.66,189.326 2138.67,189.316 2138.68,189.306 2138.69,189.296 2138.7,189.286 2138.71,189.276 2138.72,189.266 2138.73,189.256 2138.74,189.246 2138.75,189.236 2138.76,189.225 2138.76,189.215 2138.77,189.205 2138.78,189.195 2138.79,189.185 2138.8,189.175 2138.81,189.165 2138.82,189.155 2138.83,189.145 2138.84,189.135 2138.85,189.125 2138.86,189.115 2138.87,189.105 2138.88,189.094 2138.88,189.084 2138.89,189.074 2138.9,189.064 2138.91,189.054 2138.92,189.044 2138.93,189.034 2138.94,189.024 2138.95,189.014 2138.96,189.004 2138.97,188.994 2138.98,188.984 2138.99,188.974 2138.99,188.964 2139,188.954 2139.01,188.944 2139.02,188.934 2139.03,188.924 2139.04,188.913 2139.05,188.903 2139.06,188.893 2139.07,188.883 2139.08,188.873 2139.09,188.863 2139.1,188.853 2139.1,188.843 2139.11,188.833 2139.12,188.823 2139.13,188.813 2139.14,188.803 2139.15,188.793 2139.16,188.783 2139.17,188.773 2139.18,188.763 2139.19,188.753 2139.2,188.743 2139.21,188.733 2139.22,188.723 2139.22,188.713 2139.23,188.703 2139.24,188.693 2139.25,188.683 2139.26,188.673 2139.27,188.663 2139.28,188.652 2139.29,188.642 2139.3,188.632 2139.31,188.622 2139.32,188.612 2139.33,188.602 2139.33,188.592 2139.34,188.582 2139.35,188.572 2139.36,188.562 2139.37,188.552 2139.38,188.542 2139.39,188.532 2139.4,188.522 2139.41,188.512 2139.42,188.502 2139.43,188.492 2139.44,188.482 2139.44,188.472 2139.45,188.462 2139.46,188.452 2139.47,188.442 2139.48,188.432 2139.49,188.422 2139.5,188.412 2139.51,188.402 2139.52,188.392 2139.53,188.382 2139.54,188.372 2139.55,188.362 2139.56,188.352 2139.56,188.342 2139.57,188.332 2139.58,188.322 2139.59,188.312 2139.6,188.302 2139.61,188.292 2139.62,188.282 2139.63,188.272 2139.64,188.262 2139.65,188.252 2139.66,188.242 2139.67,188.232 2139.67,188.222 2139.68,188.212 2139.69,188.202 2139.7,188.192 2139.71,188.182 2139.72,188.172 2139.73,188.162 2139.74,188.152 2139.75,188.142 2139.76,188.132 2139.77,188.123 2139.78,188.113 2139.78,188.103 2139.79,188.093 2139.8,188.083 2139.81,188.073 2139.82,188.063 2139.83,188.053 2139.84,188.043 2139.85,188.033 2139.86,188.023 2139.87,188.013 2139.88,188.003 2139.89,187.993 2139.9,187.983 2139.9,187.973 2139.91,187.963 2139.92,187.953 2139.93,187.943 2139.94,187.933 2139.95,187.923 2139.96,187.913 2139.97,187.903 2139.98,187.893 2139.99,187.883 2140,187.873 2140.01,187.863 2140.01,187.854 2140.02,187.844 2140.03,187.834 2140.04,187.824 2140.05,187.814 2140.06,187.804 2140.07,187.794 2140.08,187.784 2140.09,187.774 2140.1,187.764 2140.11,187.754 2140.12,187.744 2140.12,187.734 2140.13,187.724 2140.14,187.714 2140.15,187.704 2140.16,187.694 2140.17,187.685 2140.18,187.675 2140.19,187.665 2140.2,187.655 2140.21,187.645 2140.22,187.635 2140.23,187.625 2140.24,187.615 2140.24,187.605 2140.25,187.595 2140.26,187.585 2140.27,187.575 2140.28,187.565 2140.29,187.555 2140.3,187.546 2140.31,187.536 2140.32,187.526 2140.33,187.516 2140.34,187.506 2140.35,187.496 2140.35,187.486 2140.36,187.476 2140.37,187.466 2140.38,187.456 2140.39,187.446 2140.4,187.436 2140.41,187.427 2140.42,187.417 2140.43,187.407 2140.44,187.397 2140.45,187.387 2140.46,187.377 2140.46,187.367 2140.47,187.357 2140.48,187.347 2140.49,187.337 2140.5,187.328 2140.51,187.318 2140.52,187.308 2140.53,187.298 2140.54,187.288 2140.55,187.278 2140.56,187.268 2140.57,187.258 2140.58,187.248 2140.58,187.238 2140.59,187.229 2140.6,187.219 2140.61,187.209 2140.62,187.199 2140.63,187.189 2140.64,187.179 2140.65,187.169 2140.66,187.159 2140.67,187.149 2140.68,187.14 2140.69,187.13 2140.69,187.12 2140.7,187.11 2140.71,187.1 2140.72,187.09 2140.73,187.08 2140.74,187.07 2140.75,187.061 2140.76,187.051 2140.77,187.041 2140.78,187.031 2140.79,187.021 2140.8,187.011 2140.8,187.001 2140.81,186.991 2140.82,186.982 2140.83,186.972 2140.84,186.962 2140.85,186.952 2140.86,186.942 2140.87,186.932 2140.88,186.922 2140.89,186.913 2140.9,186.903 2140.91,186.893 2140.92,186.883 2140.92,186.873 2140.93,186.863 2140.94,186.853 2140.95,186.844 2140.96,186.834 2140.97,186.824 2140.98,186.814 2140.99,186.804 2141,186.794 2141.01,186.784 2141.02,186.775 2141.03,186.765 2141.03,186.755 2141.04,186.745 2141.05,186.735 2141.06,186.725 2141.07,186.716 2141.08,186.706 2141.09,186.696 2141.1,186.686 2141.11,186.676 2141.12,186.666 2141.13,186.656 2141.14,186.647 2141.14,186.637 2141.15,186.627 2141.16,186.617 2141.17,186.607 2141.18,186.597 2141.19,186.588 2141.2,186.578 2141.21,186.568 2141.22,186.558 2141.23,186.548 2141.24,186.539 2141.25,186.529 2141.26,186.519 2141.26,186.509 2141.27,186.499 2141.28,186.489 2141.29,186.48 2141.3,186.47 2141.31,186.46 2141.32,186.45 2141.33,186.44 2141.34,186.43 2141.35,186.421 2141.36,186.411 2141.37,186.401 2141.37,186.391 2141.38,186.381 2141.39,186.372 2141.4,186.362 2141.41,186.352 2141.42,186.342 2141.43,186.332 2141.44,186.323 2141.45,186.313 2141.46,186.303 2141.47,186.293 2141.48,186.283 2141.48,186.274 2141.49,186.264 2141.5,186.254 2141.51,186.244 2141.52,186.234 2141.53,186.225 2141.54,186.215 2141.55,186.205 2141.56,186.195 2141.57,186.185 2141.58,186.176 2141.59,186.166 2141.6,186.156 2141.6,186.146 2141.61,186.136 2141.62,186.127 2141.63,186.117 2141.64,186.107 2141.65,186.097 2141.66,186.087 2141.67,186.078 2141.68,186.068 2141.69,186.058 2141.7,186.048 2141.71,186.039 2141.71,186.029 2141.72,186.019 2141.73,186.009 2141.74,185.999 2141.75,185.99 2141.76,185.98 2141.77,185.97 2141.78,185.96 2141.79,185.951 2141.8,185.941 2141.81,185.931 2141.82,185.921 2141.82,185.912 2141.83,185.902 2141.84,185.892 2141.85,185.882 2141.86,185.872 2141.87,185.863 2141.88,185.853 2141.89,185.843 2141.9,185.833 2141.91,185.824 2141.92,185.814 2141.93,185.804 2141.94,185.794 2141.94,185.785 2141.95,185.775 2141.96,185.765 2141.97,185.755 2141.98,185.746 2141.99,185.736 2142,185.726 2142.01,185.716 2142.02,185.707 2142.03,185.697 2142.04,185.687 2142.05,185.677 2142.05,185.668 2142.06,185.658 2142.07,185.648 2142.08,185.638 2142.09,185.629 2142.1,185.619 2142.11,185.609 2142.12,185.599 2142.13,185.59 2142.14,185.58 2142.15,185.57 2142.16,185.56 2142.16,185.551 2142.17,185.541 2142.18,185.531 2142.19,185.522 2142.2,185.512 2142.21,185.502 2142.22,185.492 2142.23,185.483 2142.24,185.473 2142.25,185.463 2142.26,185.453 2142.27,185.444 2142.28,185.434 2142.28,185.424 2142.29,185.415 2142.3,185.405 2142.31,185.395 2142.32,185.385 2142.33,185.376 2142.34,185.366 2142.35,185.356 2142.36,185.347 2142.37,185.337 2142.38,185.327 2142.39,185.317 2142.39,185.308 2142.4,185.298 2142.41,185.288 2142.42,185.279 2142.43,185.269 2142.44,185.259 2142.45,185.249 2142.46,185.24 2142.47,185.23 2142.48,185.22 2142.49,185.211 2142.5,185.201 2142.5,185.191 2142.51,185.181 2142.52,185.172 2142.53,185.162 2142.54,185.152 2142.55,185.143 2142.56,185.133 2142.57,185.123 2142.58,185.114 2142.59,185.104 2142.6,185.094 2142.61,185.085 2142.62,185.075 2142.62,185.065 2142.63,185.055 2142.64,185.046 2142.65,185.036 2142.66,185.026 2142.67,185.017 2142.68,185.007 2142.69,184.997 2142.7,184.988 2142.71,184.978 2142.72,184.968 2142.73,184.959 2142.73,184.949 2142.74,184.939 2142.75,184.93 2142.76,184.92 2142.77,184.91 2142.78,184.901 2142.79,184.891 2142.8,184.881 2142.81,184.872 2142.82,184.862 2142.83,184.852 2142.84,184.843 2142.84,184.833 2142.85,184.823 2142.86,184.814 2142.87,184.804 2142.88,184.794 2142.89,184.785 2142.9,184.775 2142.91,184.765 2142.92,184.756 2142.93,184.746 2142.94,184.736 2142.95,184.727 2142.96,184.717 2142.96,184.707 2142.97,184.698 2142.98,184.688 2142.99,184.678 2143,184.669 2143.01,184.659 2143.02,184.649 2143.03,184.64 2143.04,184.63 2143.05,184.62 2143.06,184.611 2143.07,184.601 2143.07,184.591 2143.08,184.582 2143.09,184.572 2143.1,184.563 2143.11,184.553 2143.12,184.543 2143.13,184.534 2143.14,184.524 2143.15,184.514 2143.16,184.505 2143.17,184.495 2143.18,184.485 2143.18,184.476 2143.19,184.466 2143.2,184.457 2143.21,184.447 2143.22,184.437 2143.23,184.428 2143.24,184.418 2143.25,184.408 2143.26,184.399 2143.27,184.389 2143.28,184.38 2143.29,184.37 2143.3,184.36 2143.3,184.351 2143.31,184.341 2143.32,184.331 2143.33,184.322 2143.34,184.312 2143.35,184.303 2143.36,184.293 2143.37,184.283 2143.38,184.274 2143.39,184.264 2143.4,184.254 2143.41,184.245 2143.41,184.235 2143.42,184.226 2143.43,184.216 2143.44,184.206 2143.45,184.197 2143.46,184.187 2143.47,184.178 2143.48,184.168 2143.49,184.158 2143.5,184.149 2143.51,184.139 2143.52,184.13 2143.52,184.12 2143.53,184.11 2143.54,184.101 2143.55,184.091 2143.56,184.082 2143.57,184.072 2143.58,184.062 2143.59,184.053 2143.6,184.043 2143.61,184.034 2143.62,184.024 2143.63,184.014 2143.64,184.005 2143.64,183.995 2143.65,183.986 2143.66,183.976 2143.67,183.966 2143.68,183.957 2143.69,183.947 2143.7,183.938 2143.71,183.928 2143.72,183.919 2143.73,183.909 2143.74,183.899 2143.75,183.89 2143.75,183.88 2143.76,183.871 2143.77,183.861 2143.78,183.851 2143.79,183.842 2143.8,183.832 2143.81,183.823 2143.82,183.813 2143.83,183.804 2143.84,183.794 2143.85,183.784 2143.86,183.775 2143.86,183.765 2143.87,183.756 2143.88,183.746 2143.89,183.737 2143.9,183.727 2143.91,183.717 2143.92,183.708 2143.93,183.698 2143.94,183.689 2143.95,183.679 2143.96,183.67 2143.97,183.66 2143.98,183.651 2143.98,183.641 2143.99,183.631 2144,183.622 2144.01,183.612 2144.02,183.603 2144.03,183.593 2144.04,183.584 2144.05,183.574 2144.06,183.565 2144.07,183.555 2144.08,183.545 2144.09,183.536 2144.09,183.526 2144.1,183.517 2144.11,183.507 2144.12,183.498 2144.13,183.488 2144.14,183.479 2144.15,183.469 2144.16,183.46 2144.17,183.45 2144.18,183.44 2144.19,183.431 2144.2,183.421 2144.2,183.412 2144.21,183.402 2144.22,183.393 2144.23,183.383 2144.24,183.374 2144.25,183.364 2144.26,183.355 2144.27,183.345 2144.28,183.336 2144.29,183.326 2144.3,183.317 2144.31,183.307 2144.32,183.297 2144.32,183.288 2144.33,183.278 2144.34,183.269 2144.35,183.259 2144.36,183.25 2144.37,183.24 2144.38,183.231 2144.39,183.221 2144.4,183.212 2144.41,183.202 2144.42,183.193 2144.43,183.183 2144.43,183.174 2144.44,183.164 2144.45,183.155 2144.46,183.145 2144.47,183.136 2144.48,183.126 2144.49,183.117 2144.5,183.107 2144.51,183.098 2144.52,183.088 2144.53,183.079 2144.54,183.069 2144.54,183.06 2144.55,183.05 2144.56,183.041 2144.57,183.031 2144.58,183.022 2144.59,183.012 2144.6,183.003 2144.61,182.993 2144.62,182.984 2144.63,182.974 2144.64,182.965 2144.65,182.955 2144.66,182.946 2144.66,182.936 2144.67,182.927 2144.68,182.917 2144.69,182.908 2144.7,182.898 2144.71,182.889 2144.72,182.879 2144.73,182.87 2144.74,182.86 2144.75,182.851 2144.76,182.841 2144.77,182.832 2144.77,182.822 2144.78,182.813 2144.79,182.803 2144.8,182.794 2144.81,182.784 2144.82,182.775 2144.83,182.765 2144.84,182.756 2144.85,182.746 2144.86,182.737 2144.87,182.728 2144.88,182.718 2144.88,182.709 2144.89,182.699 2144.9,182.69 2144.91,182.68 2144.92,182.671 2144.93,182.661 2144.94,182.652 2144.95,182.642 2144.96,182.633 2144.97,182.623 2144.98,182.614 2144.99,182.604 2145,182.595 2145,182.586 2145.01,182.576 2145.02,182.567 2145.03,182.557 2145.04,182.548 2145.05,182.538 2145.06,182.529 2145.07,182.519 2145.08,182.51 2145.09,182.5 2145.1,182.491 2145.11,182.481 2145.11,182.472 2145.12,182.463 2145.13,182.453 2145.14,182.444 2145.15,182.434 2145.16,182.425 2145.17,182.415 2145.18,182.406 2145.19,182.396 2145.2,182.387 2145.21,182.378 2145.22,182.368 2145.22,182.359 2145.23,182.349 2145.24,182.34 2145.25,182.33 2145.26,182.321 2145.27,182.312 2145.28,182.302 2145.29,182.293 2145.3,182.283 2145.31,182.274 2145.32,182.264 2145.33,182.255 2145.34,182.245 2145.34,182.236 2145.35,182.227 2145.36,182.217 2145.37,182.208 2145.38,182.198 2145.39,182.189 2145.4,182.18 2145.41,182.17 2145.42,182.161 2145.43,182.151 2145.44,182.142 2145.45,182.132 2145.45,182.123 2145.46,182.114 2145.47,182.104 2145.48,182.095 2145.49,182.085 2145.5,182.076 2145.51,182.066 2145.52,182.057 2145.53,182.048 2145.54,182.038 2145.55,182.029 2145.56,182.019 2145.56,182.01 2145.57,182.001 2145.58,181.991 2145.59,181.982 2145.6,181.972 2145.61,181.963 2145.62,181.954 2145.63,181.944 2145.64,181.935 2145.65,181.925 2145.66,181.916 2145.67,181.907 2145.68,181.897 2145.68,181.888 2145.69,181.878 2145.7,181.869 2145.71,181.86 2145.72,181.85 2145.73,181.841 2145.74,181.831 2145.75,181.822 2145.76,181.813 2145.77,181.803 2145.78,181.794 2145.79,181.784 2145.79,181.775 2145.8,181.766 2145.81,181.756 2145.82,181.747 2145.83,181.738 2145.84,181.728 2145.85,181.719 2145.86,181.709 2145.87,181.7 2145.88,181.691 2145.89,181.681 2145.9,181.672 2145.9,181.663 2145.91,181.653 2145.92,181.644 2145.93,181.634 2145.94,181.625 2145.95,181.616 2145.96,181.606 2145.97,181.597 2145.98,181.588 2145.99,181.578 2146,181.569 2146.01,181.559 2146.02,181.55 2146.02,181.541 2146.03,181.531 2146.04,181.522 2146.05,181.513 2146.06,181.503 2146.07,181.494 2146.08,181.485 2146.09,181.475 2146.1,181.466 2146.11,181.456 2146.12,181.447 2146.13,181.438 2146.13,181.428 2146.14,181.419 2146.15,181.41 2146.16,181.4 2146.17,181.391 2146.18,181.382 2146.19,181.372 2146.2,181.363 2146.21,181.354 2146.22,181.344 2146.23,181.335 2146.24,181.326 2146.24,181.316 2146.25,181.307 2146.26,181.298 2146.27,181.288 2146.28,181.279 2146.29,181.269 2146.3,181.26 2146.31,181.251 2146.32,181.241 2146.33,181.232 2146.34,181.223 2146.35,181.213 2146.36,181.204 2146.36,181.195 2146.37,181.185 2146.38,181.176 2146.39,181.167 2146.4,181.157 2146.41,181.148 2146.42,181.139 2146.43,181.129 2146.44,181.12 2146.45,181.111 2146.46,181.101 2146.47,181.092 2146.47,181.083 2146.48,181.074 2146.49,181.064 2146.5,181.055 2146.51,181.046 2146.52,181.036 2146.53,181.027 2146.54,181.018 2146.55,181.008 2146.56,180.999 2146.57,180.99 2146.58,180.98 2146.58,180.971 2146.59,180.962 2146.6,180.952 2146.61,180.943 2146.62,180.934 2146.63,180.924 2146.64,180.915 2146.65,180.906 2146.66,180.897 2146.67,180.887 2146.68,180.878 2146.69,180.869 2146.7,180.859 2146.7,180.85 2146.71,180.841 2146.72,180.831 2146.73,180.822 2146.74,180.813 2146.75,180.804 2146.76,180.794 2146.77,180.785 2146.78,180.776 2146.79,180.766 2146.8,180.757 2146.81,180.748 2146.81,180.738 2146.82,180.729 2146.83,180.72 2146.84,180.711 2146.85,180.701 2146.86,180.692 2146.87,180.683 2146.88,180.673 2146.89,180.664 2146.9,180.655 2146.91,180.646 2146.92,180.636 2146.92,180.627 2146.93,180.618 2146.94,180.608 2146.95,180.599 2146.96,180.59 2146.97,180.581 2146.98,180.571 2146.99,180.562 2147,180.553 2147.01,180.544 2147.02,180.534 2147.03,180.525 2147.04,180.516 2147.04,180.506 2147.05,180.497 2147.06,180.488 2147.07,180.479 2147.08,180.469 2147.09,180.46 2147.1,180.451 2147.11,180.442 2147.12,180.432 2147.13,180.423 2147.14,180.414 2147.15,180.404 2147.15,180.395 2147.16,180.386 2147.17,180.377 2147.18,180.367 2147.19,180.358 2147.2,180.349 2147.21,180.34 2147.22,180.33 2147.23,180.321 2147.24,180.312 2147.25,180.303 2147.26,180.293 2147.27,180.284 2147.27,180.275 2147.28,180.266 2147.29,180.256 2147.3,180.247 2147.31,180.238 2147.32,180.229 2147.33,180.219 2147.34,180.21 2147.35,180.201 2147.36,180.192 2147.37,180.182 2147.38,180.173 2147.38,180.164 2147.39,180.155 2147.4,180.145 2147.41,180.136 2147.42,180.127 2147.43,180.118 2147.44,180.109 2147.45,180.099 2147.46,180.09 2147.47,180.081 2147.48,180.072 2147.49,180.062 2147.49,180.053 2147.5,180.044 2147.51,180.035 2147.52,180.025 2147.53,180.016 2147.54,180.007 2147.55,179.998 2147.56,179.989 2147.57,179.979 2147.58,179.97 2147.59,179.961 2147.6,179.952 2147.61,179.942 2147.61,179.933 2147.62,179.924 2147.63,179.915 2147.64,179.906 2147.65,179.896 2147.66,179.887 2147.67,179.878 2147.68,179.869 2147.69,179.859 2147.7,179.85 2147.71,179.841 2147.72,179.832 2147.72,179.823 2147.73,179.813 2147.74,179.804 2147.75,179.795 2147.76,179.786 2147.77,179.777 2147.78,179.767 2147.79,179.758 2147.8,179.749 2147.81,179.74 2147.82,179.731 2147.83,179.721 2147.83,179.712 2147.84,179.703 2147.85,179.694 2147.86,179.685 2147.87,179.675 2147.88,179.666 2147.89,179.657 2147.9,179.648 2147.91,179.639 2147.92,179.629 2147.93,179.62 2147.94,179.611 2147.95,179.602 2147.95,179.593 2147.96,179.583 2147.97,179.574 2147.98,179.565 2147.99,179.556 2148,179.547 2148.01,179.538 2148.02,179.528 2148.03,179.519 2148.04,179.51 2148.05,179.501 2148.06,179.492 2148.06,179.482 2148.07,179.473 2148.08,179.464 2148.09,179.455 2148.1,179.446 2148.11,179.437 2148.12,179.427 2148.13,179.418 2148.14,179.409 2148.15,179.4 2148.16,179.391 2148.17,179.382 2148.17,179.372 2148.18,179.363 2148.19,179.354 2148.2,179.345 2148.21,179.336 2148.22,179.327 2148.23,179.317 2148.24,179.308 2148.25,179.299 2148.26,179.29 2148.27,179.281 2148.28,179.272 2148.29,179.262 2148.29,179.253 2148.3,179.244 2148.31,179.235 2148.32,179.226 2148.33,179.217 2148.34,179.207 2148.35,179.198 2148.36,179.189 2148.37,179.18 2148.38,179.171 2148.39,179.162 2148.4,179.153 2148.4,179.143 2148.41,179.134 2148.42,179.125 2148.43,179.116 2148.44,179.107 2148.45,179.098 2148.46,179.089 2148.47,179.079 2148.48,179.07 2148.49,179.061 2148.5,179.052 2148.51,179.043 2148.51,179.034 2148.52,179.025 2148.53,179.015 2148.54,179.006 2148.55,178.997 2148.56,178.988 2148.57,178.979 2148.58,178.97 2148.59,178.961 2148.6,178.951 2148.61,178.942 2148.62,178.933 2148.63,178.924 2148.63,178.915 2148.64,178.906 2148.65,178.897 2148.66,178.888 2148.67,178.878 2148.68,178.869 2148.69,178.86 2148.7,178.851 2148.71,178.842 2148.72,178.833 2148.73,178.824 2148.74,178.815 2148.74,178.805 2148.75,178.796 2148.76,178.787 2148.77,178.778 2148.78,178.769 2148.79,178.76 2148.8,178.751 2148.81,178.742 2148.82,178.733 2148.83,178.723 2148.84,178.714 2148.85,178.705 2148.85,178.696 2148.86,178.687 2148.87,178.678 2148.88,178.669 2148.89,178.66 2148.9,178.651 2148.91,178.641 2148.92,178.632 2148.93,178.623 2148.94,178.614 2148.95,178.605 2148.96,178.596 2148.97,178.587 2148.97,178.578 2148.98,178.569 2148.99,178.56 2149,178.55 2149.01,178.541 2149.02,178.532 2149.03,178.523 2149.04,178.514 2149.05,178.505 2149.06,178.496 2149.07,178.487 2149.08,178.478 2149.08,178.469 2149.09,178.46 2149.1,178.45 2149.11,178.441 2149.12,178.432 2149.13,178.423 2149.14,178.414 2149.15,178.405 2149.16,178.396 2149.17,178.387 2149.18,178.378 2149.19,178.369 2149.19,178.36 2149.2,178.351 2149.21,178.342 2149.22,178.332 2149.23,178.323 2149.24,178.314 2149.25,178.305 2149.26,178.296 2149.27,178.287 2149.28,178.278 2149.29,178.269 2149.3,178.26 2149.31,178.251 2149.31,178.242 2149.32,178.233 2149.33,178.224 2149.34,178.215 2149.35,178.205 2149.36,178.196 2149.37,178.187 2149.38,178.178 2149.39,178.169 2149.4,178.16 2149.41,178.151 2149.42,178.142 2149.42,178.133 2149.43,178.124 2149.44,178.115 2149.45,178.106 2149.46,178.097 2149.47,178.088 2149.48,178.079 2149.49,178.07 2149.5,178.061 2149.51,178.051 2149.52,178.042 2149.53,178.033 2149.53,178.024 2149.54,178.015 2149.55,178.006 2149.56,177.997 2149.57,177.988 2149.58,177.979 2149.59,177.97 2149.6,177.961 2149.61,177.952 2149.62,177.943 2149.63,177.934 2149.64,177.925 2149.65,177.916 2149.65,177.907 2149.66,177.898 2149.67,177.889 2149.68,177.88 2149.69,177.871 2149.7,177.862 2149.71,177.853 2149.72,177.844 2149.73,177.835 2149.74,177.825 2149.75,177.816 2149.76,177.807 2149.76,177.798 2149.77,177.789 2149.78,177.78 2149.79,177.771 2149.8,177.762 2149.81,177.753 2149.82,177.744 2149.83,177.735 2149.84,177.726 2149.85,177.717 2149.86,177.708 2149.87,177.699 2149.87,177.69 2149.88,177.681 2149.89,177.672 2149.9,177.663 2149.91,177.654 2149.92,177.645 2149.93,177.636 2149.94,177.627 2149.95,177.618 2149.96,177.609 2149.97,177.6 2149.98,177.591 2149.99,177.582 2149.99,177.573 2150,177.564 2150.01,177.555 2150.02,177.546 2150.03,177.537 2150.04,177.528 2150.05,177.519 2150.06,177.51 2150.07,177.501 2150.08,177.492 2150.09,177.483 2150.1,177.474 2150.1,177.465 2150.11,177.456 2150.12,177.447 2150.13,177.438 2150.14,177.429 2150.15,177.42 2150.16,177.411 2150.17,177.402 2150.18,177.393 2150.19,177.384 2150.2,177.375 2150.21,177.366 2150.21,177.357 2150.22,177.348 2150.23,177.339 2150.24,177.33 2150.25,177.321 2150.26,177.312 2150.27,177.303 2150.28,177.294 2150.29,177.285 2150.3,177.276 2150.31,177.267 2150.32,177.258 2150.33,177.249 2150.33,177.24 2150.34,177.231 2150.35,177.222 2150.36,177.213 2150.37,177.204 2150.38,177.195 2150.39,177.186 2150.4,177.177 2150.41,177.168 2150.42,177.159 2150.43,177.15 2150.44,177.141 2150.44,177.133 2150.45,177.124 2150.46,177.115 2150.47,177.106 2150.48,177.097 2150.49,177.088 2150.5,177.079 2150.51,177.07 2150.52,177.061 2150.53,177.052 2150.54,177.043 2150.55,177.034 2150.55,177.025 2150.56,177.016 2150.57,177.007 2150.58,176.998 2150.59,176.989 2150.6,176.98 2150.61,176.971 2150.62,176.962 2150.63,176.953 2150.64,176.944 2150.65,176.935 2150.66,176.926 2150.67,176.917 2150.67,176.909 2150.68,176.9 2150.69,176.891 2150.7,176.882 2150.71,176.873 2150.72,176.864 2150.73,176.855 2150.74,176.846 2150.75,176.837 2150.76,176.828 2150.77,176.819 2150.78,176.81 2150.78,176.801 2150.79,176.792 2150.8,176.783 2150.81,176.774 2150.82,176.765 2150.83,176.757 2150.84,176.748 2150.85,176.739 2150.86,176.73 2150.87,176.721 2150.88,176.712 2150.89,176.703 2150.89,176.694 2150.9,176.685 2150.91,176.676 2150.92,176.667 2150.93,176.658 2150.94,176.649 2150.95,176.64 2150.96,176.632 2150.97,176.623 2150.98,176.614 2150.99,176.605 2151,176.596 2151.01,176.587 2151.01,176.578 2151.02,176.569 2151.03,176.56 2151.04,176.551 2151.05,176.542 2151.06,176.533 2151.07,176.524 2151.08,176.516 2151.09,176.507 2151.1,176.498 2151.11,176.489 2151.12,176.48 2151.12,176.471 2151.13,176.462 2151.14,176.453 2151.15,176.444 2151.16,176.435 2151.17,176.426 2151.18,176.418 2151.19,176.409 2151.2,176.4 2151.21,176.391 2151.22,176.382 2151.23,176.373 2151.23,176.364 2151.24,176.355 2151.25,176.346 2151.26,176.337 2151.27,176.329 2151.28,176.32 2151.29,176.311 2151.3,176.302 2151.31,176.293 2151.32,176.284 2151.33,176.275 2151.34,176.266 2151.35,176.257 2151.35,176.248 2151.36,176.24 2151.37,176.231 2151.38,176.222 2151.39,176.213 2151.4,176.204 2151.41,176.195 2151.42,176.186 2151.43,176.177 2151.44,176.169 2151.45,176.16 2151.46,176.151 2151.46,176.142 2151.47,176.133 2151.48,176.124 2151.49,176.115 2151.5,176.106 2151.51,176.097 2151.52,176.089 2151.53,176.08 2151.54,176.071 2151.55,176.062 2151.56,176.053 2151.57,176.044 2151.57,176.035 2151.58,176.026 2151.59,176.018 2151.6,176.009 2151.61,176 2151.62,175.991 2151.63,175.982 2151.64,175.973 2151.65,175.964 2151.66,175.956 2151.67,175.947 2151.68,175.938 2151.69,175.929 2151.69,175.92 2151.7,175.911 2151.71,175.902 2151.72,175.893 2151.73,175.885 2151.74,175.876 2151.75,175.867 2151.76,175.858 2151.77,175.849 2151.78,175.84 2151.79,175.831 2151.8,175.823 2151.8,175.814 2151.81,175.805 2151.82,175.796 2151.83,175.787 2151.84,175.778 2151.85,175.77 2151.86,175.761 2151.87,175.752 2151.88,175.743 2151.89,175.734 2151.9,175.725 2151.91,175.716 2151.91,175.708 2151.92,175.699 2151.93,175.69 2151.94,175.681 2151.95,175.672 2151.96,175.663 2151.97,175.655 2151.98,175.646 2151.99,175.637 2152,175.628 2152.01,175.619 2152.02,175.61 2152.03,175.602 2152.03,175.593 2152.04,175.584 2152.05,175.575 2152.06,175.566 2152.07,175.557 2152.08,175.549 2152.09,175.54 2152.1,175.531 2152.11,175.522 2152.12,175.513 2152.13,175.504 2152.14,175.496 2152.14,175.487 2152.15,175.478 2152.16,175.469 2152.17,175.46 2152.18,175.451 2152.19,175.443 2152.2,175.434 2152.21,175.425 2152.22,175.416 2152.23,175.407 2152.24,175.399 2152.25,175.39 2152.25,175.381 2152.26,175.372 2152.27,175.363 2152.28,175.355 2152.29,175.346 2152.3,175.337 2152.31,175.328 2152.32,175.319 2152.33,175.31 2152.34,175.302 2152.35,175.293 2152.36,175.284 2152.37,175.275 2152.37,175.266 2152.38,175.258 2152.39,175.249 2152.4,175.24 2152.41,175.231 2152.42,175.222 2152.43,175.214 2152.44,175.205 2152.45,175.196 2152.46,175.187 2152.47,175.178 2152.48,175.17 2152.48,175.161 2152.49,175.152 2152.5,175.143 2152.51,175.134 2152.52,175.126 2152.53,175.117 2152.54,175.108 2152.55,175.099 2152.56,175.091 2152.57,175.082 2152.58,175.073 2152.59,175.064 2152.59,175.055 2152.6,175.047 2152.61,175.038 2152.62,175.029 2152.63,175.02 2152.64,175.011 2152.65,175.003 2152.66,174.994 2152.67,174.985 2152.68,174.976 2152.69,174.968 2152.7,174.959 2152.71,174.95 2152.71,174.941 2152.72,174.932 2152.73,174.924 2152.74,174.915 2152.75,174.906 2152.76,174.897 2152.77,174.889 2152.78,174.88 2152.79,174.871 2152.8,174.862 2152.81,174.853 2152.82,174.845 2152.82,174.836 2152.83,174.827 2152.84,174.818 2152.85,174.81 2152.86,174.801 2152.87,174.792 2152.88,174.783 2152.89,174.775 2152.9,174.766 2152.91,174.757 2152.92,174.748 2152.93,174.74 2152.93,174.731 2152.94,174.722 2152.95,174.713 2152.96,174.705 2152.97,174.696 2152.98,174.687 2152.99,174.678 2153,174.67 2153.01,174.661 2153.02,174.652 2153.03,174.643 2153.04,174.635 2153.05,174.626 2153.05,174.617 2153.06,174.608 2153.07,174.6 2153.08,174.591 2153.09,174.582 2153.1,174.573 2153.11,174.565 2153.12,174.556 2153.13,174.547 2153.14,174.538 2153.15,174.53 2153.16,174.521 2153.16,174.512 2153.17,174.503 2153.18,174.495 2153.19,174.486 2153.2,174.477 2153.21,174.468 2153.22,174.46 2153.23,174.451 2153.24,174.442 2153.25,174.434 2153.26,174.425 2153.27,174.416 2153.27,174.407 2153.28,174.399 2153.29,174.39 2153.3,174.381 2153.31,174.372 2153.32,174.364 2153.33,174.355 2153.34,174.346 2153.35,174.338 2153.36,174.329 2153.37,174.32 2153.38,174.311 2153.39,174.303 2153.39,174.294 2153.4,174.285 2153.41,174.276 2153.42,174.268 2153.43,174.259 2153.44,174.25 2153.45,174.242 2153.46,174.233 2153.47,174.224 2153.48,174.215 2153.49,174.207 2153.5,174.198 2153.5,174.189 2153.51,174.181 2153.52,174.172 2153.53,174.163 2153.54,174.154 2153.55,174.146 2153.56,174.137 2153.57,174.128 2153.58,174.12 2153.59,174.111 2153.6,174.102 2153.61,174.094 2153.61,174.085 2153.62,174.076 2153.63,174.067 2153.64,174.059 2153.65,174.05 2153.66,174.041 2153.67,174.033 2153.68,174.024 2153.69,174.015 2153.7,174.007 2153.71,173.998 2153.72,173.989 2153.73,173.981 2153.73,173.972 2153.74,173.963 2153.75,173.954 2153.76,173.946 2153.77,173.937 2153.78,173.928 2153.79,173.92 2153.8,173.911 2153.81,173.902 2153.82,173.894 2153.83,173.885 2153.84,173.876 2153.84,173.868 2153.85,173.859 2153.86,173.85 2153.87,173.842 2153.88,173.833 2153.89,173.824 2153.9,173.815 2153.91,173.807 2153.92,173.798 2153.93,173.789 2153.94,173.781 2153.95,173.772 2153.95,173.763 2153.96,173.755 2153.97,173.746 2153.98,173.737 2153.99,173.729 2154,173.72 2154.01,173.711 2154.02,173.703 2154.03,173.694 2154.04,173.685 2154.05,173.677 2154.06,173.668 2154.07,173.659 2154.07,173.651 2154.08,173.642 2154.09,173.633 2154.1,173.625 2154.11,173.616 2154.12,173.607 2154.13,173.599 2154.14,173.59 2154.15,173.581 2154.16,173.573 2154.17,173.564 2154.18,173.556 2154.18,173.547 2154.19,173.538 2154.2,173.53 2154.21,173.521 2154.22,173.512 2154.23,173.504 2154.24,173.495 2154.25,173.486 2154.26,173.478 2154.27,173.469 2154.28,173.46 2154.29,173.452 2154.29,173.443 2154.3,173.434 2154.31,173.426 2154.32,173.417 2154.33,173.408 2154.34,173.4 2154.35,173.391 2154.36,173.383 2154.37,173.374 2154.38,173.365 2154.39,173.357 2154.4,173.348 2154.41,173.339 2154.41,173.331 2154.42,173.322 2154.43,173.313 2154.44,173.305 2154.45,173.296 2154.46,173.288 2154.47,173.279 2154.48,173.27 2154.49,173.262 2154.5,173.253 2154.51,173.244 2154.52,173.236 2154.52,173.227 2154.53,173.219 2154.54,173.21 2154.55,173.201 2154.56,173.193 2154.57,173.184 2154.58,173.175 2154.59,173.167 2154.6,173.158 2154.61,173.15 2154.62,173.141 2154.63,173.132 2154.63,173.124 2154.64,173.115 2154.65,173.106 2154.66,173.098 2154.67,173.089 2154.68,173.081 2154.69,173.072 2154.7,173.063 2154.71,173.055 2154.72,173.046 2154.73,173.038 2154.74,173.029 2154.75,173.02 2154.75,173.012 2154.76,173.003 2154.77,172.995 2154.78,172.986 2154.79,172.977 2154.8,172.969 2154.81,172.96 2154.82,172.951 2154.83,172.943 2154.84,172.934 2154.85,172.926 2154.86,172.917 2154.86,172.908 2154.87,172.9 2154.88,172.891 2154.89,172.883 2154.9,172.874 2154.91,172.866 2154.92,172.857 2154.93,172.848 2154.94,172.84 2154.95,172.831 2154.96,172.823 2154.97,172.814 2154.97,172.805 2154.98,172.797 2154.99,172.788 2155,172.78 2155.01,172.771 2155.02,172.762 2155.03,172.754 2155.04,172.745 2155.05,172.737 2155.06,172.728 2155.07,172.719 2155.08,172.711 2155.09,172.702 2155.09,172.694 2155.1,172.685 2155.11,172.677 2155.12,172.668 2155.13,172.659 2155.14,172.651 2155.15,172.642 2155.16,172.634 2155.17,172.625 2155.18,172.617 2155.19,172.608 2155.2,172.599 2155.2,172.591 2155.21,172.582 2155.22,172.574 2155.23,172.565 2155.24,172.557 2155.25,172.548 2155.26,172.539 2155.27,172.531 2155.28,172.522 2155.29,172.514 2155.3,172.505 2155.31,172.497 2155.31,172.488 2155.32,172.479 2155.33,172.471 2155.34,172.462 2155.35,172.454 2155.36,172.445 2155.37,172.437 2155.38,172.428 2155.39,172.42 2155.4,172.411 2155.41,172.402 2155.42,172.394 2155.43,172.385 2155.43,172.377 2155.44,172.368 2155.45,172.36 2155.46,172.351 2155.47,172.343 2155.48,172.334 2155.49,172.325 2155.5,172.317 2155.51,172.308 2155.52,172.3 2155.53,172.291 2155.54,172.283 2155.54,172.274 2155.55,172.266 2155.56,172.257 2155.57,172.249 2155.58,172.24 2155.59,172.231 2155.6,172.223 2155.61,172.214 2155.62,172.206 2155.63,172.197 2155.64,172.189 2155.65,172.18 2155.65,172.172 2155.66,172.163 2155.67,172.155 2155.68,172.146 2155.69,172.138 2155.7,172.129 2155.71,172.121 2155.72,172.112 2155.73,172.103 2155.74,172.095 2155.75,172.086 2155.76,172.078 2155.77,172.069 2155.77,172.061 2155.78,172.052 2155.79,172.044 2155.8,172.035 2155.81,172.027 2155.82,172.018 2155.83,172.01 2155.84,172.001 2155.85,171.993 2155.86,171.984 2155.87,171.976 2155.88,171.967 2155.88,171.959 2155.89,171.95 2155.9,171.942 2155.91,171.933 2155.92,171.924 2155.93,171.916 2155.94,171.907 2155.95,171.899 2155.96,171.89 2155.97,171.882 2155.98,171.873 2155.99,171.865 2155.99,171.856 2156,171.848 2156.01,171.839 2156.02,171.831 2156.03,171.822 2156.04,171.814 2156.05,171.805 2156.06,171.797 2156.07,171.788 2156.08,171.78 2156.09,171.771 2156.1,171.763 2156.11,171.754 2156.11,171.746 2156.12,171.737 2156.13,171.729 2156.14,171.72 2156.15,171.712 2156.16,171.703 2156.17,171.695 2156.18,171.686 2156.19,171.678 2156.2,171.669 2156.21,171.661 2156.22,171.652 2156.22,171.644 2156.23,171.635 2156.24,171.627 2156.25,171.618 2156.26,171.61 2156.27,171.601 2156.28,171.593 2156.29,171.584 2156.3,171.576 2156.31,171.568 2156.32,171.559 2156.33,171.551 2156.33,171.542 2156.34,171.534 2156.35,171.525 2156.36,171.517 2156.37,171.508 2156.38,171.5 2156.39,171.491 2156.4,171.483 2156.41,171.474 2156.42,171.466 2156.43,171.457 2156.44,171.449 2156.45,171.44 2156.45,171.432 2156.46,171.423 2156.47,171.415 2156.48,171.406 2156.49,171.398 2156.5,171.39 2156.51,171.381 2156.52,171.373 2156.53,171.364 2156.54,171.356 2156.55,171.347 2156.56,171.339 2156.56,171.33 2156.57,171.322 2156.58,171.313 2156.59,171.305 2156.6,171.296 2156.61,171.288 2156.62,171.279 2156.63,171.271 2156.64,171.263 2156.65,171.254 2156.66,171.246 2156.67,171.237 2156.67,171.229 2156.68,171.22 2156.69,171.212 2156.7,171.203 2156.71,171.195 2156.72,171.186 2156.73,171.178 2156.74,171.17 2156.75,171.161 2156.76,171.153 2156.77,171.144 2156.78,171.136 2156.79,171.127 2156.79,171.119 2156.8,171.11 2156.81,171.102 2156.82,171.094 2156.83,171.085 2156.84,171.077 2156.85,171.068 2156.86,171.06 2156.87,171.051 2156.88,171.043 2156.89,171.034 2156.9,171.026 2156.9,171.018 2156.91,171.009 2156.92,171.001 2156.93,170.992 2156.94,170.984 2156.95,170.975 2156.96,170.967 2156.97,170.959 2156.98,170.95 2156.99,170.942 2157,170.933 2157.01,170.925 2157.01,170.916 2157.02,170.908 2157.03,170.9 2157.04,170.891 2157.05,170.883 2157.06,170.874 2157.07,170.866 2157.08,170.857 2157.09,170.849 2157.1,170.841 2157.11,170.832 2157.12,170.824 2157.13,170.815 2157.13,170.807 2157.14,170.798 2157.15,170.79 2157.16,170.782 2157.17,170.773 2157.18,170.765 2157.19,170.756 2157.2,170.748 2157.21,170.74 2157.22,170.731 2157.23,170.723 2157.24,170.714 2157.24,170.706 2157.25,170.698 2157.26,170.689 2157.27,170.681 2157.28,170.672 2157.29,170.664 2157.3,170.655 2157.31,170.647 2157.32,170.639 2157.33,170.63 2157.34,170.622 2157.35,170.613 2157.35,170.605 2157.36,170.597 2157.37,170.588 2157.38,170.58 2157.39,170.571 2157.4,170.563 2157.41,170.555 2157.42,170.546 2157.43,170.538 2157.44,170.529 2157.45,170.521 2157.46,170.513 2157.47,170.504 2157.47,170.496 2157.48,170.488 2157.49,170.479 2157.5,170.471 2157.51,170.462 2157.52,170.454 2157.53,170.446 2157.54,170.437 2157.55,170.429 2157.56,170.42 2157.57,170.412 2157.58,170.404 2157.58,170.395 2157.59,170.387 2157.6,170.378 2157.61,170.37 2157.62,170.362 2157.63,170.353 2157.64,170.345 2157.65,170.337 2157.66,170.328 2157.67,170.32 2157.68,170.311 2157.69,170.303 2157.69,170.295 2157.7,170.286 2157.71,170.278 2157.72,170.27 2157.73,170.261 2157.74,170.253 2157.75,170.244 2157.76,170.236 2157.77,170.228 2157.78,170.219 2157.79,170.211 2157.8,170.203 2157.81,170.194 2157.81,170.186 2157.82,170.177 2157.83,170.169 2157.84,170.161 2157.85,170.152 2157.86,170.144 2157.87,170.136 2157.88,170.127 2157.89,170.119 2157.9,170.111 2157.91,170.102 2157.92,170.094 2157.92,170.086 2157.93,170.077 2157.94,170.069 2157.95,170.06 2157.96,170.052 2157.97,170.044 2157.98,170.035 2157.99,170.027 2158,170.019 2158.01,170.01 2158.02,170.002 2158.03,169.994 2158.03,169.985 2158.04,169.977 2158.05,169.969 2158.06,169.96 2158.07,169.952 2158.08,169.944 2158.09,169.935 2158.1,169.927 2158.11,169.919 2158.12,169.91 2158.13,169.902 2158.14,169.893 2158.15,169.885 2158.15,169.877 2158.16,169.868 2158.17,169.86 2158.18,169.852 2158.19,169.843 2158.2,169.835 2158.21,169.827 2158.22,169.818 2158.23,169.81 2158.24,169.802 2158.25,169.793 2158.26,169.785 2158.26,169.777 2158.27,169.768 2158.28,169.76 2158.29,169.752 2158.3,169.743 2158.31,169.735 2158.32,169.727 2158.33,169.718 2158.34,169.71 2158.35,169.702 2158.36,169.693 2158.37,169.685 2158.37,169.677 2158.38,169.669 2158.39,169.66 2158.4,169.652 2158.41,169.644 2158.42,169.635 2158.43,169.627 2158.44,169.619 2158.45,169.61 2158.46,169.602 2158.47,169.594 2158.48,169.585 2158.49,169.577 2158.49,169.569 2158.5,169.56 2158.51,169.552 2158.52,169.544 2158.53,169.535 2158.54,169.527 2158.55,169.519 2158.56,169.511 2158.57,169.502 2158.58,169.494 2158.59,169.486 2158.6,169.477 2158.6,169.469 2158.61,169.461 2158.62,169.452 2158.63,169.444 2158.64,169.436 2158.65,169.427 2158.66,169.419 2158.67,169.411 2158.68,169.403 2158.69,169.394 2158.7,169.386 2158.71,169.378 2158.71,169.369 2158.72,169.361 2158.73,169.353 2158.74,169.344 2158.75,169.336 2158.76,169.328 2158.77,169.32 2158.78,169.311 2158.79,169.303 2158.8,169.295 2158.81,169.286 2158.82,169.278 2158.83,169.27 2158.83,169.262 2158.84,169.253 2158.85,169.245 2158.86,169.237 2158.87,169.228 2158.88,169.22 2158.89,169.212 2158.9,169.204 2158.91,169.195 2158.92,169.187 2158.93,169.179 2158.94,169.17 2158.94,169.162 2158.95,169.154 2158.96,169.146 2158.97,169.137 2158.98,169.129 2158.99,169.121 2159,169.112 2159.01,169.104 2159.02,169.096 2159.03,169.088 2159.04,169.079 2159.05,169.071 2159.05,169.063 2159.06,169.055 2159.07,169.046 2159.08,169.038 2159.09,169.03 2159.1,169.021 2159.11,169.013 2159.12,169.005 2159.13,168.997 2159.14,168.988 2159.15,168.98 2159.16,168.972 2159.17,168.964 2159.17,168.955 2159.18,168.947 2159.19,168.939 2159.2,168.931 2159.21,168.922 2159.22,168.914 2159.23,168.906 2159.24,168.898 2159.25,168.889 2159.26,168.881 2159.27,168.873 2159.28,168.865 2159.28,168.856 2159.29,168.848 2159.3,168.84 2159.31,168.832 2159.32,168.823 2159.33,168.815 2159.34,168.807 2159.35,168.799 2159.36,168.79 2159.37,168.782 2159.38,168.774 2159.39,168.766 2159.39,168.757 2159.4,168.749 2159.41,168.741 2159.42,168.733 2159.43,168.724 2159.44,168.716 2159.45,168.708 2159.46,168.7 2159.47,168.691 2159.48,168.683 2159.49,168.675 2159.5,168.667 2159.51,168.658 2159.51,168.65 2159.52,168.642 2159.53,168.634 2159.54,168.625 2159.55,168.617 2159.56,168.609 2159.57,168.601 2159.58,168.592 2159.59,168.584 2159.6,168.576 2159.61,168.568 2159.62,168.56 2159.62,168.551 2159.63,168.543 2159.64,168.535 2159.65,168.527 2159.66,168.518 2159.67,168.51 2159.68,168.502 2159.69,168.494 2159.7,168.486 2159.71,168.477 2159.72,168.469 2159.73,168.461 2159.73,168.453 2159.74,168.444 2159.75,168.436 2159.76,168.428 2159.77,168.42 2159.78,168.412 2159.79,168.403 2159.8,168.395 2159.81,168.387 2159.82,168.379 2159.83,168.37 2159.84,168.362 2159.85,168.354 2159.85,168.346 2159.86,168.338 2159.87,168.329 2159.88,168.321 2159.89,168.313 2159.9,168.305 2159.91,168.297 2159.92,168.288 2159.93,168.28 2159.94,168.272 2159.95,168.264 2159.96,168.256 2159.96,168.247 2159.97,168.239 2159.98,168.231 2159.99,168.223 2160,168.215 2160.01,168.206 2160.02,168.198 2160.03,168.19 2160.04,168.182 2160.05,168.174 2160.06,168.165 2160.07,168.157 2160.07,168.149 2160.08,168.141 2160.09,168.133 2160.1,168.124 2160.11,168.116 2160.12,168.108 2160.13,168.1 2160.14,168.092 2160.15,168.083 2160.16,168.075 2160.17,168.067 2160.18,168.059 2160.19,168.051 2160.19,168.042 2160.2,168.034 2160.21,168.026 2160.22,168.018 2160.23,168.01 2160.24,168.002 2160.25,167.993 2160.26,167.985 2160.27,167.977 2160.28,167.969 2160.29,167.961 2160.3,167.952 2160.3,167.944 2160.31,167.936 2160.32,167.928 2160.33,167.92 2160.34,167.912 2160.35,167.903 2160.36,167.895 2160.37,167.887 2160.38,167.879 2160.39,167.871 2160.4,167.863 2160.41,167.854 2160.41,167.846 2160.42,167.838 2160.43,167.83 2160.44,167.822 2160.45,167.814 2160.46,167.805 2160.47,167.797 2160.48,167.789 2160.49,167.781 2160.5,167.773 2160.51,167.765 2160.52,167.756 2160.53,167.748 2160.53,167.74 2160.54,167.732 2160.55,167.724 2160.56,167.716 2160.57,167.707 2160.58,167.699 2160.59,167.691 2160.6,167.683 2160.61,167.675 2160.62,167.667 2160.63,167.658 2160.64,167.65 2160.64,167.642 2160.65,167.634 2160.66,167.626 2160.67,167.618 2160.68,167.61 2160.69,167.601 2160.7,167.593 2160.71,167.585 2160.72,167.577 2160.73,167.569 2160.74,167.561 2160.75,167.553 2160.75,167.544 2160.76,167.536 2160.77,167.528 2160.78,167.52 2160.79,167.512 2160.8,167.504 2160.81,167.496 2160.82,167.487 2160.83,167.479 2160.84,167.471 2160.85,167.463 2160.86,167.455 2160.87,167.447 2160.87,167.439 2160.88,167.43 2160.89,167.422 2160.9,167.414 2160.91,167.406 2160.92,167.398 2160.93,167.39 2160.94,167.382 2160.95,167.374 2160.96,167.365 2160.97,167.357 2160.98,167.349 2160.98,167.341 2160.99,167.333 2161,167.325 2161.01,167.317 2161.02,167.308 2161.03,167.3 2161.04,167.292 2161.05,167.284 2161.06,167.276 2161.07,167.268 2161.08,167.26 2161.09,167.252 2161.09,167.244 2161.1,167.235 2161.11,167.227 2161.12,167.219 2161.13,167.211 2161.14,167.203 2161.15,167.195 2161.16,167.187 2161.17,167.179 2161.18,167.17 2161.19,167.162 2161.2,167.154 2161.21,167.146 2161.21,167.138 2161.22,167.13 2161.23,167.122 2161.24,167.114 2161.25,167.106 2161.26,167.097 2161.27,167.089 2161.28,167.081 2161.29,167.073 2161.3,167.065 2161.31,167.057 2161.32,167.049 2161.32,167.041 2161.33,167.033 2161.34,167.025 2161.35,167.016 2161.36,167.008 2161.37,167 2161.38,166.992 2161.39,166.984 2161.4,166.976 2161.41,166.968 2161.42,166.96 2161.43,166.952 2161.43,166.944 2161.44,166.935 2161.45,166.927 2161.46,166.919 2161.47,166.911 2161.48,166.903 2161.49,166.895 2161.5,166.887 2161.51,166.879 2161.52,166.871 2161.53,166.863 2161.54,166.855 2161.55,166.846 2161.55,166.838 2161.56,166.83 2161.57,166.822 2161.58,166.814 2161.59,166.806 2161.6,166.798 2161.61,166.79 2161.62,166.782 2161.63,166.774 2161.64,166.766 2161.65,166.758 2161.66,166.749 2161.66,166.741 2161.67,166.733 2161.68,166.725 2161.69,166.717 2161.7,166.709 2161.71,166.701 2161.72,166.693 2161.73,166.685 2161.74,166.677 2161.75,166.669 2161.76,166.661 2161.77,166.653 2161.77,166.644 2161.78,166.636 2161.79,166.628 2161.8,166.62 2161.81,166.612 2161.82,166.604 2161.83,166.596 2161.84,166.588 2161.85,166.58 2161.86,166.572 2161.87,166.564 2161.88,166.556 2161.89,166.548 2161.89,166.54 2161.9,166.532 2161.91,166.523 2161.92,166.515 2161.93,166.507 2161.94,166.499 2161.95,166.491 2161.96,166.483 2161.97,166.475 2161.98,166.467 2161.99,166.459 2162,166.451 2162,166.443 2162.01,166.435 2162.02,166.427 2162.03,166.419 2162.04,166.411 2162.05,166.403 2162.06,166.395 2162.07,166.387 2162.08,166.379 2162.09,166.37 2162.1,166.362 2162.11,166.354 2162.11,166.346 2162.12,166.338 2162.13,166.33 2162.14,166.322 2162.15,166.314 2162.16,166.306 2162.17,166.298 2162.18,166.29 2162.19,166.282 2162.2,166.274 2162.21,166.266 2162.22,166.258 2162.23,166.25 2162.23,166.242 2162.24,166.234 2162.25,166.226 2162.26,166.218 2162.27,166.21 2162.28,166.202 2162.29,166.194 2162.3,166.186 2162.31,166.178 2162.32,166.169 2162.33,166.161 2162.34,166.153 2162.34,166.145 2162.35,166.137 2162.36,166.129 2162.37,166.121 2162.38,166.113 2162.39,166.105 2162.4,166.097 2162.41,166.089 2162.42,166.081 2162.43,166.073 2162.44,166.065 2162.45,166.057 2162.45,166.049 2162.46,166.041 2162.47,166.033 2162.48,166.025 2162.49,166.017 2162.5,166.009 2162.51,166.001 2162.52,165.993 2162.53,165.985 2162.54,165.977 2162.55,165.969 2162.56,165.961 2162.57,165.953 2162.57,165.945 2162.58,165.937 2162.59,165.929 2162.6,165.921 2162.61,165.913 2162.62,165.905 2162.63,165.897 2162.64,165.889 2162.65,165.881 2162.66,165.873 2162.67,165.865 2162.68,165.857 2162.68,165.849 2162.69,165.841 2162.7,165.833 2162.71,165.825 2162.72,165.817 2162.73,165.809 2162.74,165.801 2162.75,165.793 2162.76,165.785 2162.77,165.777 2162.78,165.769 2162.79,165.761 2162.79,165.753 2162.8,165.745 2162.81,165.737 2162.82,165.729 2162.83,165.721 2162.84,165.713 2162.85,165.705 2162.86,165.697 2162.87,165.689 2162.88,165.681 2162.89,165.673 2162.9,165.665 2162.91,165.657 2162.91,165.649 2162.92,165.641 2162.93,165.633 2162.94,165.625 2162.95,165.617 2162.96,165.609 2162.97,165.601 2162.98,165.593 2162.99,165.585 2163,165.577 2163.01,165.569 2163.02,165.561 2163.02,165.553 2163.03,165.545 2163.04,165.537 2163.05,165.529 2163.06,165.521 2163.07,165.513 2163.08,165.505 2163.09,165.497 2163.1,165.489 2163.11,165.481 2163.12,165.473 2163.13,165.465 2163.13,165.457 2163.14,165.449 2163.15,165.441 2163.16,165.433 2163.17,165.425 2163.18,165.417 2163.19,165.409 2163.2,165.402 2163.21,165.394 2163.22,165.386 2163.23,165.378 2163.24,165.37 2163.25,165.362 2163.25,165.354 2163.26,165.346 2163.27,165.338 2163.28,165.33 2163.29,165.322 2163.3,165.314 2163.31,165.306 2163.32,165.298 2163.33,165.29 2163.34,165.282 2163.35,165.274 2163.36,165.266 2163.36,165.258 2163.37,165.25 2163.38,165.242 2163.39,165.234 2163.4,165.226 2163.41,165.218 2163.42,165.21 2163.43,165.203 2163.44,165.195 2163.45,165.187 2163.46,165.179 2163.47,165.171 2163.47,165.163 2163.48,165.155 2163.49,165.147 2163.5,165.139 2163.51,165.131 2163.52,165.123 2163.53,165.115 2163.54,165.107 2163.55,165.099 2163.56,165.091 2163.57,165.083 2163.58,165.075 2163.59,165.067 2163.59,165.059 2163.6,165.052 2163.61,165.044 2163.62,165.036 2163.63,165.028 2163.64,165.02 2163.65,165.012 2163.66,165.004 2163.67,164.996 2163.68,164.988 2163.69,164.98 2163.7,164.972 2163.7,164.964 2163.71,164.956 2163.72,164.948 2163.73,164.94 2163.74,164.933 2163.75,164.925 2163.76,164.917 2163.77,164.909 2163.78,164.901 2163.79,164.893 2163.8,164.885 2163.81,164.877 2163.81,164.869 2163.82,164.861 2163.83,164.853 2163.84,164.845 2163.85,164.837 2163.86,164.829 2163.87,164.822 2163.88,164.814 2163.89,164.806 2163.9,164.798 2163.91,164.79 2163.92,164.782 2163.93,164.774 2163.93,164.766 2163.94,164.758 2163.95,164.75 2163.96,164.742 2163.97,164.734 2163.98,164.727 2163.99,164.719 2164,164.711 2164.01,164.703 2164.02,164.695 2164.03,164.687 2164.04,164.679 2164.04,164.671 2164.05,164.663 2164.06,164.655 2164.07,164.647 2164.08,164.64 2164.09,164.632 2164.1,164.624 2164.11,164.616 2164.12,164.608 2164.13,164.6 2164.14,164.592 2164.15,164.584 2164.15,164.576 2164.16,164.568 2164.17,164.561 2164.18,164.553 2164.19,164.545 2164.2,164.537 2164.21,164.529 2164.22,164.521 2164.23,164.513 2164.24,164.505 2164.25,164.497 2164.26,164.489 2164.27,164.482 2164.27,164.474 2164.28,164.466 2164.29,164.458 2164.3,164.45 2164.31,164.442 2164.32,164.434 2164.33,164.426 2164.34,164.418 2164.35,164.411 2164.36,164.403 2164.37,164.395 2164.38,164.387 2164.38,164.379 2164.39,164.371 2164.4,164.363 2164.41,164.355 2164.42,164.347 2164.43,164.34 2164.44,164.332 2164.45,164.324 2164.46,164.316 2164.47,164.308 2164.48,164.3 2164.49,164.292 2164.49,164.284 2164.5,164.277 2164.51,164.269 2164.52,164.261 2164.53,164.253 2164.54,164.245 2164.55,164.237 2164.56,164.229 2164.57,164.221 2164.58,164.214 2164.59,164.206 2164.6,164.198 2164.61,164.19 2164.61,164.182 2164.62,164.174 2164.63,164.166 2164.64,164.158 2164.65,164.151 2164.66,164.143 2164.67,164.135 2164.68,164.127 2164.69,164.119 2164.7,164.111 2164.71,164.103 2164.72,164.096 2164.72,164.088 2164.73,164.08 2164.74,164.072 2164.75,164.064 2164.76,164.056 2164.77,164.048 2164.78,164.041 2164.79,164.033 2164.8,164.025 2164.81,164.017 2164.82,164.009 2164.83,164.001 2164.83,163.993 2164.84,163.986 2164.85,163.978 2164.86,163.97 2164.87,163.962 2164.88,163.954 2164.89,163.946 2164.9,163.938 2164.91,163.931 2164.92,163.923 2164.93,163.915 2164.94,163.907 2164.95,163.899 2164.95,163.891 2164.96,163.883 2164.97,163.876 2164.98,163.868 2164.99,163.86 2165,163.852 2165.01,163.844 2165.02,163.836 2165.03,163.829 2165.04,163.821 2165.05,163.813 2165.06,163.805 2165.06,163.797 2165.07,163.789 2165.08,163.782 2165.09,163.774 2165.1,163.766 2165.11,163.758 2165.12,163.75 2165.13,163.742 2165.14,163.735 2165.15,163.727 2165.16,163.719 2165.17,163.711 2165.17,163.703 2165.18,163.695 2165.19,163.688 2165.2,163.68 2165.21,163.672 2165.22,163.664 2165.23,163.656 2165.24,163.648 2165.25,163.641 2165.26,163.633 2165.27,163.625 2165.28,163.617 2165.29,163.609 2165.29,163.601 2165.3,163.594 2165.31,163.586 2165.32,163.578 2165.33,163.57 2165.34,163.562 2165.35,163.555 2165.36,163.547 2165.37,163.539 2165.38,163.531 2165.39,163.523 2165.4,163.515 2165.4,163.508 2165.41,163.5 2165.42,163.492 2165.43,163.484 2165.44,163.476 2165.45,163.469 2165.46,163.461 2165.47,163.453 2165.48,163.445 2165.49,163.437 2165.5,163.43 2165.51,163.422 2165.51,163.414 2165.52,163.406 2165.53,163.398 2165.54,163.391 2165.55,163.383 2165.56,163.375 2165.57,163.367 2165.58,163.359 2165.59,163.351 2165.6,163.344 2165.61,163.336 2165.62,163.328 2165.63,163.32 2165.63,163.312 2165.64,163.305 2165.65,163.297 2165.66,163.289 2165.67,163.281 2165.68,163.273 2165.69,163.266 2165.7,163.258 2165.71,163.25 2165.72,163.242 2165.73,163.235 2165.74,163.227 2165.74,163.219 2165.75,163.211 2165.76,163.203 2165.77,163.196 2165.78,163.188 2165.79,163.18 2165.8,163.172 2165.81,163.164 2165.82,163.157 2165.83,163.149 2165.84,163.141 2165.85,163.133 2165.85,163.125 2165.86,163.118 2165.87,163.11 2165.88,163.102 2165.89,163.094 2165.9,163.087 2165.91,163.079 2165.92,163.071 2165.93,163.063 2165.94,163.055 2165.95,163.048 2165.96,163.04 2165.97,163.032 2165.97,163.024 2165.98,163.017 2165.99,163.009 2166,163.001 2166.01,162.993 2166.02,162.985 2166.03,162.978 2166.04,162.97 2166.05,162.962 2166.06,162.954 2166.07,162.947 2166.08,162.939 2166.08,162.931 2166.09,162.923 2166.1,162.916 2166.11,162.908 2166.12,162.9 2166.13,162.892 2166.14,162.884 2166.15,162.877 2166.16,162.869 2166.17,162.861 2166.18,162.853 2166.19,162.846 2166.19,162.838 2166.2,162.83 2166.21,162.822 2166.22,162.815 2166.23,162.807 2166.24,162.799 2166.25,162.791 2166.26,162.784 2166.27,162.776 2166.28,162.768 2166.29,162.76 2166.3,162.753 2166.31,162.745 2166.31,162.737 2166.32,162.729 2166.33,162.722 2166.34,162.714 2166.35,162.706 2166.36,162.698 2166.37,162.691 2166.38,162.683 2166.39,162.675 2166.4,162.667 2166.41,162.66 2166.42,162.652 2166.42,162.644 2166.43,162.636 2166.44,162.629 2166.45,162.621 2166.46,162.613 2166.47,162.605 2166.48,162.598 2166.49,162.59 2166.5,162.582 2166.51,162.574 2166.52,162.567 2166.53,162.559 2166.53,162.551 2166.54,162.543 2166.55,162.536 2166.56,162.528 2166.57,162.52 2166.58,162.512 2166.59,162.505 2166.6,162.497 2166.61,162.489 2166.62,162.482 2166.63,162.474 2166.64,162.466 2166.65,162.458 2166.65,162.451 2166.66,162.443 2166.67,162.435 2166.68,162.427 2166.69,162.42 2166.7,162.412 2166.71,162.404 2166.72,162.397 2166.73,162.389 2166.74,162.381 2166.75,162.373 2166.76,162.366 2166.76,162.358 2166.77,162.35 2166.78,162.342 2166.79,162.335 2166.8,162.327 2166.81,162.319 2166.82,162.312 2166.83,162.304 2166.84,162.296 2166.85,162.288 2166.86,162.281 2166.87,162.273 2166.87,162.265 2166.88,162.258 2166.89,162.25 2166.9,162.242 2166.91,162.234 2166.92,162.227 2166.93,162.219 2166.94,162.211 2166.95,162.204 2166.96,162.196 2166.97,162.188 2166.98,162.18 2166.99,162.173 2166.99,162.165 2167,162.157 2167.01,162.15 2167.02,162.142 2167.03,162.134 2167.04,162.126 2167.05,162.119 2167.06,162.111 2167.07,162.103 2167.08,162.096 2167.09,162.088 2167.1,162.08 2167.1,162.073 2167.11,162.065 2167.12,162.057 2167.13,162.049 2167.14,162.042 2167.15,162.034 2167.16,162.026 2167.17,162.019 2167.18,162.011 2167.19,162.003 2167.2,161.996 2167.21,161.988 2167.21,161.98 2167.22,161.972 2167.23,161.965 2167.24,161.957 2167.25,161.949 2167.26,161.942 2167.27,161.934 2167.28,161.926 2167.29,161.919 2167.3,161.911 2167.31,161.903 2167.32,161.896 2167.33,161.888 2167.33,161.88 2167.34,161.873 2167.35,161.865 2167.36,161.857 2167.37,161.849 2167.38,161.842 2167.39,161.834 2167.4,161.826 2167.41,161.819 2167.42,161.811 2167.43,161.803 2167.44,161.796 2167.44,161.788 2167.45,161.78 2167.46,161.773 2167.47,161.765 2167.48,161.757 2167.49,161.75 2167.5,161.742 2167.51,161.734 2167.52,161.727 2167.53,161.719 2167.54,161.711 2167.55,161.704 2167.55,161.696 2167.56,161.688 2167.57,161.681 2167.58,161.673 2167.59,161.665 2167.6,161.658 2167.61,161.65 2167.62,161.642 2167.63,161.635 2167.64,161.627 2167.65,161.619 2167.66,161.612 2167.67,161.604 2167.67,161.596 2167.68,161.589 2167.69,161.581 2167.7,161.573 2167.71,161.566 2167.72,161.558 2167.73,161.55 2167.74,161.543 2167.75,161.535 2167.76,161.527 2167.77,161.52 2167.78,161.512 2167.78,161.504 2167.79,161.497 2167.8,161.489 2167.81,161.481 2167.82,161.474 2167.83,161.466 2167.84,161.458 2167.85,161.451 2167.86,161.443 2167.87,161.436 2167.88,161.428 2167.89,161.42 2167.89,161.413 2167.9,161.405 2167.91,161.397 2167.92,161.39 2167.93,161.382 2167.94,161.374 2167.95,161.367 2167.96,161.359 2167.97,161.351 2167.98,161.344 2167.99,161.336 2168,161.328 2168.01,161.321 2168.01,161.313 2168.02,161.306 2168.03,161.298 2168.04,161.29 2168.05,161.283 2168.06,161.275 2168.07,161.267 2168.08,161.26 2168.09,161.252 2168.1,161.244 2168.11,161.237 2168.12,161.229 2168.12,161.222 2168.13,161.214 2168.14,161.206 2168.15,161.199 2168.16,161.191 2168.17,161.183 2168.18,161.176 2168.19,161.168 2168.2,161.161 2168.21,161.153 2168.22,161.145 2168.23,161.138 2168.23,161.13 2168.24,161.122 2168.25,161.115 2168.26,161.107 2168.27,161.1 2168.28,161.092 2168.29,161.084 2168.3,161.077 2168.31,161.069 2168.32,161.061 2168.33,161.054 2168.34,161.046 2168.35,161.039 2168.35,161.031 2168.36,161.023 2168.37,161.016 2168.38,161.008 2168.39,161 2168.4,160.993 2168.41,160.985 2168.42,160.978 2168.43,160.97 2168.44,160.962 2168.45,160.955 2168.46,160.947 2168.46,160.94 2168.47,160.932 2168.48,160.924 2168.49,160.917 2168.5,160.909 2168.51,160.902 2168.52,160.894 2168.53,160.886 2168.54,160.879 2168.55,160.871 2168.56,160.863 2168.57,160.856 2168.57,160.848 2168.58,160.841 2168.59,160.833 2168.6,160.825 2168.61,160.818 2168.62,160.81 2168.63,160.803 2168.64,160.795 2168.65,160.787 2168.66,160.78 2168.67,160.772 2168.68,160.765 2168.69,160.757 2168.69,160.749 2168.7,160.742 2168.71,160.734 2168.72,160.727 2168.73,160.719 2168.74,160.711 2168.75,160.704 2168.76,160.696 2168.77,160.689 2168.78,160.681 2168.79,160.674 2168.8,160.666 2168.8,160.658 2168.81,160.651 2168.82,160.643 2168.83,160.636 2168.84,160.628 2168.85,160.62 2168.86,160.613 2168.87,160.605 2168.88,160.598 2168.89,160.59 2168.9,160.582 2168.91,160.575 2168.91,160.567 2168.92,160.56 2168.93,160.552 2168.94,160.545 2168.95,160.537 2168.96,160.529 2168.97,160.522 2168.98,160.514 2168.99,160.507 2169,160.499 2169.01,160.492 2169.02,160.484 2169.03,160.476 2169.03,160.469 2169.04,160.461 2169.05,160.454 2169.06,160.446 2169.07,160.439 2169.08,160.431 2169.09,160.423 2169.1,160.416 2169.11,160.408 2169.12,160.401 2169.13,160.393 2169.14,160.386 2169.14,160.378 2169.15,160.37 2169.16,160.363 2169.17,160.355 2169.18,160.348 2169.19,160.34 2169.2,160.333 2169.21,160.325 2169.22,160.317 2169.23,160.31 2169.24,160.302 2169.25,160.295 2169.25,160.287 2169.26,160.28 2169.27,160.272 2169.28,160.265 2169.29,160.257 2169.3,160.249 2169.31,160.242 2169.32,160.234 2169.33,160.227 2169.34,160.219 2169.35,160.212 2169.36,160.204 2169.37,160.197 2169.37,160.189 2169.38,160.181 2169.39,160.174 2169.4,160.166 2169.41,160.159 2169.42,160.151 2169.43,160.144 2169.44,160.136 2169.45,160.129 2169.46,160.121 2169.47,160.114 2169.48,160.106 2169.48,160.098 2169.49,160.091 2169.5,160.083 2169.51,160.076 2169.52,160.068 2169.53,160.061 2169.54,160.053 2169.55,160.046 2169.56,160.038 2169.57,160.031 2169.58,160.023 2169.59,160.015 2169.59,160.008 2169.6,160 2169.61,159.993 2169.62,159.985 2169.63,159.978 2169.64,159.97 2169.65,159.963 2169.66,159.955 2169.67,159.948 2169.68,159.94 2169.69,159.933 2169.7,159.925 2169.71,159.918 2169.71,159.91 2169.72,159.902 2169.73,159.895 2169.74,159.887 2169.75,159.88 2169.76,159.872 2169.77,159.865 2169.78,159.857 2169.79,159.85 2169.8,159.842 2169.81,159.835 2169.82,159.827 2169.82,159.82 2169.83,159.812 2169.84,159.805 2169.85,159.797 2169.86,159.79 2169.87,159.782 2169.88,159.775 2169.89,159.767 2169.9,159.759 2169.91,159.752 2169.92,159.744 2169.93,159.737 2169.93,159.729 2169.94,159.722 2169.95,159.714 2169.96,159.707 2169.97,159.699 2169.98,159.692 2169.99,159.684 2170,159.677 2170.01,159.669 2170.02,159.662 2170.03,159.654 2170.04,159.647 2170.05,159.639 2170.05,159.632 2170.06,159.624 2170.07,159.617 2170.08,159.609 2170.09,159.602 2170.1,159.594 2170.11,159.587 2170.12,159.579 2170.13,159.572 2170.14,159.564 2170.15,159.557 2170.16,159.549 2170.16,159.542 2170.17,159.534 2170.18,159.527 2170.19,159.519 2170.2,159.512 2170.21,159.504 2170.22,159.497 2170.23,159.489 2170.24,159.482 2170.25,159.474 2170.26,159.467 2170.27,159.459 2170.27,159.452 2170.28,159.444 2170.29,159.437 2170.3,159.429 2170.31,159.422 2170.32,159.414 2170.33,159.407 2170.34,159.399 2170.35,159.392 2170.36,159.384 2170.37,159.377 2170.38,159.369 2170.39,159.362 2170.39,159.354 2170.4,159.347 2170.41,159.339 2170.42,159.332 2170.43,159.324 2170.44,159.317 2170.45,159.309 2170.46,159.302 2170.47,159.294 2170.48,159.287 2170.49,159.279 2170.5,159.272 2170.5,159.265 2170.51,159.257 2170.52,159.25 2170.53,159.242 2170.54,159.235 2170.55,159.227 2170.56,159.22 2170.57,159.212 2170.58,159.205 2170.59,159.197 2170.6,159.19 2170.61,159.182 2170.61,159.175 2170.62,159.167 2170.63,159.16 2170.64,159.152 2170.65,159.145 2170.66,159.137 2170.67,159.13 2170.68,159.122 2170.69,159.115 2170.7,159.108 2170.71,159.1 2170.72,159.093 2170.73,159.085 2170.73,159.078 2170.74,159.07 2170.75,159.063 2170.76,159.055 2170.77,159.048 2170.78,159.04 2170.79,159.033 2170.8,159.025 2170.81,159.018 2170.82,159.011 2170.83,159.003 2170.84,158.996 2170.84,158.988 2170.85,158.981 2170.86,158.973 2170.87,158.966 2170.88,158.958 2170.89,158.951 2170.9,158.943 2170.91,158.936 2170.92,158.928 2170.93,158.921 2170.94,158.914 2170.95,158.906 2170.95,158.899 2170.96,158.891 2170.97,158.884 2170.98,158.876 2170.99,158.869 2171,158.861 2171.01,158.854 2171.02,158.847 2171.03,158.839 2171.04,158.832 2171.05,158.824 2171.06,158.817 2171.07,158.809 2171.07,158.802 2171.08,158.794 2171.09,158.787 2171.1,158.78 2171.11,158.772 2171.12,158.765 2171.13,158.757 2171.14,158.75 2171.15,158.742 2171.16,158.735 2171.17,158.727 2171.18,158.72 2171.18,158.713 2171.19,158.705 2171.2,158.698 2171.21,158.69 2171.22,158.683 2171.23,158.675 2171.24,158.668 2171.25,158.661 2171.26,158.653 2171.27,158.646 2171.28,158.638 2171.29,158.631 2171.29,158.623 2171.3,158.616 2171.31,158.608 2171.32,158.601 2171.33,158.594 2171.34,158.586 2171.35,158.579 2171.36,158.571 2171.37,158.564 2171.38,158.556 2171.39,158.549 2171.4,158.542 2171.41,158.534 2171.41,158.527 2171.42,158.519 2171.43,158.512 2171.44,158.505 2171.45,158.497 2171.46,158.49 2171.47,158.482 2171.48,158.475 2171.49,158.467 2171.5,158.46 2171.51,158.453 2171.52,158.445 2171.52,158.438 2171.53,158.43 2171.54,158.423 2171.55,158.416 2171.56,158.408 2171.57,158.401 2171.58,158.393 2171.59,158.386 2171.6,158.378 2171.61,158.371 2171.62,158.364 2171.63,158.356 2171.64,158.349 2171.64,158.341 2171.65,158.334 2171.66,158.327 2171.67,158.319 2171.68,158.312 2171.69,158.304 2171.7,158.297 2171.71,158.29 2171.72,158.282 2171.73,158.275 2171.74,158.267 2171.75,158.26 2171.75,158.253 2171.76,158.245 2171.77,158.238 2171.78,158.23 2171.79,158.223 2171.8,158.216 2171.81,158.208 2171.82,158.201 2171.83,158.193 2171.84,158.186 2171.85,158.179 2171.86,158.171 2171.86,158.164 2171.87,158.156 2171.88,158.149 2171.89,158.142 2171.9,158.134 2171.91,158.127 2171.92,158.119 2171.93,158.112 2171.94,158.105 2171.95,158.097 2171.96,158.09 2171.97,158.082 2171.98,158.075 2171.98,158.068 2171.99,158.06 2172,158.053 2172.01,158.045 2172.02,158.038 2172.03,158.031 2172.04,158.023 2172.05,158.016 2172.06,158.009 2172.07,158.001 2172.08,157.994 2172.09,157.986 2172.09,157.979 2172.1,157.972 2172.11,157.964 2172.12,157.957 2172.13,157.95 2172.14,157.942 2172.15,157.935 2172.16,157.927 2172.17,157.92 2172.18,157.913 2172.19,157.905 2172.2,157.898 2172.2,157.89 2172.21,157.883 2172.22,157.876 2172.23,157.868 2172.24,157.861 2172.25,157.854 2172.26,157.846 2172.27,157.839 2172.28,157.832 2172.29,157.824 2172.3,157.817 2172.31,157.809 2172.32,157.802 2172.32,157.795 2172.33,157.787 2172.34,157.78 2172.35,157.773 2172.36,157.765 2172.37,157.758 2172.38,157.75 2172.39,157.743 2172.4,157.736 2172.41,157.728 2172.42,157.721 2172.43,157.714 2172.43,157.706 2172.44,157.699 2172.45,157.692 2172.46,157.684 2172.47,157.677 2172.48,157.669 2172.49,157.662 2172.5,157.655 2172.51,157.647 2172.52,157.64 2172.53,157.633 2172.54,157.625 2172.54,157.618 2172.55,157.611 2172.56,157.603 2172.57,157.596 2172.58,157.589 2172.59,157.581 2172.6,157.574 2172.61,157.567 2172.62,157.559 2172.63,157.552 2172.64,157.544 2172.65,157.537 2172.66,157.53 2172.66,157.522 2172.67,157.515 2172.68,157.508 2172.69,157.5 2172.7,157.493 2172.71,157.486 2172.72,157.478 2172.73,157.471 2172.74,157.464 2172.75,157.456 2172.76,157.449 2172.77,157.442 2172.77,157.434 2172.78,157.427 2172.79,157.42 2172.8,157.412 2172.81,157.405 2172.82,157.398 2172.83,157.39 2172.84,157.383 2172.85,157.376 2172.86,157.368 2172.87,157.361 2172.88,157.354 2172.88,157.346 2172.89,157.339 2172.9,157.332 2172.91,157.324 2172.92,157.317 2172.93,157.31 2172.94,157.302 2172.95,157.295 2172.96,157.288 2172.97,157.28 2172.98,157.273 2172.99,157.266 2173,157.258 2173,157.251 2173.01,157.244 2173.02,157.236 2173.03,157.229 2173.04,157.222 2173.05,157.214 2173.06,157.207 2173.07,157.2 2173.08,157.192 2173.09,157.185 2173.1,157.178 2173.11,157.17 2173.11,157.163 2173.12,157.156 2173.13,157.149 2173.14,157.141 2173.15,157.134 2173.16,157.127 2173.17,157.119 2173.18,157.112 2173.19,157.105 2173.2,157.097 2173.21,157.09 2173.22,157.083 2173.22,157.075 2173.23,157.068 2173.24,157.061 2173.25,157.053 2173.26,157.046 2173.27,157.039 2173.28,157.031 2173.29,157.024 2173.3,157.017 2173.31,157.01 2173.32,157.002 2173.33,156.995 2173.34,156.988 2173.34,156.98 2173.35,156.973 2173.36,156.966 2173.37,156.958 2173.38,156.951 2173.39,156.944 2173.4,156.937 2173.41,156.929 2173.42,156.922 2173.43,156.915 2173.44,156.907 2173.45,156.9 2173.45,156.893 2173.46,156.885 2173.47,156.878 2173.48,156.871 2173.49,156.864 2173.5,156.856 2173.51,156.849 2173.52,156.842 2173.53,156.834 2173.54,156.827 2173.55,156.82 2173.56,156.812 2173.56,156.805 2173.57,156.798 2173.58,156.791 2173.59,156.783 2173.6,156.776 2173.61,156.769 2173.62,156.761 2173.63,156.754 2173.64,156.747 2173.65,156.74 2173.66,156.732 2173.67,156.725 2173.68,156.718 2173.68,156.71 2173.69,156.703 2173.7,156.696 2173.71,156.689 2173.72,156.681 2173.73,156.674 2173.74,156.667 2173.75,156.659 2173.76,156.652 2173.77,156.645 2173.78,156.638 2173.79,156.63 2173.79,156.623 2173.8,156.616 2173.81,156.608 2173.82,156.601 2173.83,156.594 2173.84,156.587 2173.85,156.579 2173.86,156.572 2173.87,156.565 2173.88,156.558 2173.89,156.55 2173.9,156.543 2173.9,156.536 2173.91,156.528 2173.92,156.521 2173.93,156.514 2173.94,156.507 2173.95,156.499 2173.96,156.492 2173.97,156.485 2173.98,156.478 2173.99,156.47 2174,156.463 2174.01,156.456 2174.02,156.449 2174.02,156.441 2174.03,156.434 2174.04,156.427 2174.05,156.419 2174.06,156.412 2174.07,156.405 2174.08,156.398 2174.09,156.39 2174.1,156.383 2174.11,156.376 2174.12,156.369 2174.13,156.361 2174.13,156.354 2174.14,156.347 2174.15,156.34 2174.16,156.332 2174.17,156.325 2174.18,156.318 2174.19,156.311 2174.2,156.303 2174.21,156.296 2174.22,156.289 2174.23,156.282 2174.24,156.274 2174.24,156.267 2174.25,156.26 2174.26,156.253 2174.27,156.245 2174.28,156.238 2174.29,156.231 2174.3,156.224 2174.31,156.216 2174.32,156.209 2174.33,156.202 2174.34,156.195 2174.35,156.187 2174.36,156.18 2174.36,156.173 2174.37,156.166 2174.38,156.158 2174.39,156.151 2174.4,156.144 2174.41,156.137 2174.42,156.129 2174.43,156.122 2174.44,156.115 2174.45,156.108 2174.46,156.1 2174.47,156.093 2174.47,156.086 2174.48,156.079 2174.49,156.071 2174.5,156.064 2174.51,156.057 2174.52,156.05 2174.53,156.042 2174.54,156.035 2174.55,156.028 2174.56,156.021 2174.57,156.014 2174.58,156.006 2174.58,155.999 2174.59,155.992 2174.6,155.985 2174.61,155.977 2174.62,155.97 2174.63,155.963 2174.64,155.956 2174.65,155.948 2174.66,155.941 2174.67,155.934 2174.68,155.927 2174.69,155.92 2174.7,155.912 2174.7,155.905 2174.71,155.898 2174.72,155.891 2174.73,155.883 2174.74,155.876 2174.75,155.869 2174.76,155.862 2174.77,155.855 2174.78,155.847 2174.79,155.84 2174.8,155.833 2174.81,155.826 2174.81,155.818 2174.82,155.811 2174.83,155.804 2174.84,155.797 2174.85,155.79 2174.86,155.782 2174.87,155.775 2174.88,155.768 2174.89,155.761 2174.9,155.754 2174.91,155.746 2174.92,155.739 2174.92,155.732 2174.93,155.725 2174.94,155.717 2174.95,155.71 2174.96,155.703 2174.97,155.696 2174.98,155.689 2174.99,155.681 2175,155.674 2175.01,155.667 2175.02,155.66 2175.03,155.653 2175.04,155.645 2175.04,155.638 2175.05,155.631 2175.06,155.624 2175.07,155.617 2175.08,155.609 2175.09,155.602 2175.1,155.595 2175.11,155.588 2175.12,155.581 2175.13,155.573 2175.14,155.566 2175.15,155.559 2175.15,155.552 2175.16,155.545 2175.17,155.537 2175.18,155.53 2175.19,155.523 2175.2,155.516 2175.21,155.509 2175.22,155.501 2175.23,155.494 2175.24,155.487 2175.25,155.48 2175.26,155.473 2175.26,155.465 2175.27,155.458 2175.28,155.451 2175.29,155.444 2175.3,155.437 2175.31,155.429 2175.32,155.422 2175.33,155.415 2175.34,155.408 2175.35,155.401 2175.36,155.394 2175.37,155.386 2175.38,155.379 2175.38,155.372 2175.39,155.365 2175.4,155.358 2175.41,155.35 2175.42,155.343 2175.43,155.336 2175.44,155.329 2175.45,155.322 2175.46,155.315 2175.47,155.307 2175.48,155.3 2175.49,155.293 2175.49,155.286 2175.5,155.279 2175.51,155.271 2175.52,155.264 2175.53,155.257 2175.54,155.25 2175.55,155.243 2175.56,155.236 2175.57,155.228 2175.58,155.221 2175.59,155.214 2175.6,155.207 2175.6,155.2 2175.61,155.193 2175.62,155.185 2175.63,155.178 2175.64,155.171 2175.65,155.164 2175.66,155.157 2175.67,155.15 2175.68,155.142 2175.69,155.135 2175.7,155.128 2175.71,155.121 2175.72,155.114 2175.72,155.107 2175.73,155.099 2175.74,155.092 2175.75,155.085 2175.76,155.078 2175.77,155.071 2175.78,155.064 2175.79,155.056 2175.8,155.049 2175.81,155.042 2175.82,155.035 2175.83,155.028 2175.83,155.021 2175.84,155.013 2175.85,155.006 2175.86,154.999 2175.87,154.992 2175.88,154.985 2175.89,154.978 2175.9,154.97 2175.91,154.963 2175.92,154.956 2175.93,154.949 2175.94,154.942 2175.94,154.935 2175.95,154.928 2175.96,154.92 2175.97,154.913 2175.98,154.906 2175.99,154.899 2176,154.892 2176.01,154.885 2176.02,154.878 2176.03,154.87 2176.04,154.863 2176.05,154.856 2176.06,154.849 2176.06,154.842 2176.07,154.835 2176.08,154.827 2176.09,154.82 2176.1,154.813 2176.11,154.806 2176.12,154.799 2176.13,154.792 2176.14,154.785 2176.15,154.777 2176.16,154.77 2176.17,154.763 2176.17,154.756 2176.18,154.749 2176.19,154.742 2176.2,154.735 2176.21,154.728 2176.22,154.72 2176.23,154.713 2176.24,154.706 2176.25,154.699 2176.26,154.692 2176.27,154.685 2176.28,154.678 2176.28,154.67 2176.29,154.663 2176.3,154.656 2176.31,154.649 2176.32,154.642 2176.33,154.635 2176.34,154.628 2176.35,154.621 2176.36,154.613 2176.37,154.606 2176.38,154.599 2176.39,154.592 2176.4,154.585 2176.4,154.578 2176.41,154.571 2176.42,154.564 2176.43,154.556 2176.44,154.549 2176.45,154.542 2176.46,154.535 2176.47,154.528 2176.48,154.521 2176.49,154.514 2176.5,154.507 2176.51,154.499 2176.51,154.492 2176.52,154.485 2176.53,154.478 2176.54,154.471 2176.55,154.464 2176.56,154.457 2176.57,154.45 2176.58,154.442 2176.59,154.435 2176.6,154.428 2176.61,154.421 2176.62,154.414 2176.62,154.407 2176.63,154.4 2176.64,154.393 2176.65,154.386 2176.66,154.378 2176.67,154.371 2176.68,154.364 2176.69,154.357 2176.7,154.35 2176.71,154.343 2176.72,154.336 2176.73,154.329 2176.74,154.322 2176.74,154.314 2176.75,154.307 2176.76,154.3 2176.77,154.293 2176.78,154.286 2176.79,154.279 2176.8,154.272 2176.81,154.265 2176.82,154.258 2176.83,154.251 2176.84,154.243 2176.85,154.236 2176.85,154.229 2176.86,154.222 2176.87,154.215 2176.88,154.208 2176.89,154.201 2176.9,154.194 2176.91,154.187 2176.92,154.18 2176.93,154.172 2176.94,154.165 2176.95,154.158 2176.96,154.151 2176.96,154.144 2176.97,154.137 2176.98,154.13 2176.99,154.123 2177,154.116 2177.01,154.109 2177.02,154.102 2177.03,154.094 2177.04,154.087 2177.05,154.08 2177.06,154.073 2177.07,154.066 2177.08,154.059 2177.08,154.052 2177.09,154.045 2177.1,154.038 2177.11,154.031 2177.12,154.024 2177.13,154.016 2177.14,154.009 2177.15,154.002 2177.16,153.995 2177.17,153.988 2177.18,153.981 2177.19,153.974 2177.19,153.967 2177.2,153.96 2177.21,153.953 2177.22,153.946 2177.23,153.939 2177.24,153.931 2177.25,153.924 2177.26,153.917 2177.27,153.91 2177.28,153.903 2177.29,153.896 2177.3,153.889 2177.3,153.882 2177.31,153.875 2177.32,153.868 2177.33,153.861 2177.34,153.854 2177.35,153.847 2177.36,153.84 2177.37,153.832 2177.38,153.825 2177.39,153.818 2177.4,153.811 2177.41,153.804 2177.42,153.797 2177.42,153.79 2177.43,153.783 2177.44,153.776 2177.45,153.769 2177.46,153.762 2177.47,153.755 2177.48,153.748 2177.49,153.741 2177.5,153.733 2177.51,153.726 2177.52,153.719 2177.53,153.712 2177.53,153.705 2177.54,153.698 2177.55,153.691 2177.56,153.684 2177.57,153.677 2177.58,153.67 2177.59,153.663 2177.6,153.656 2177.61,153.649 2177.62,153.642 2177.63,153.635 2177.64,153.628 2177.64,153.621 2177.65,153.613 2177.66,153.606 2177.67,153.599 2177.68,153.592 2177.69,153.585 2177.7,153.578 2177.71,153.571 2177.72,153.564 2177.73,153.557 2177.74,153.55 2177.75,153.543 2177.76,153.536 2177.76,153.529 2177.77,153.522 2177.78,153.515 2177.79,153.508 2177.8,153.501 2177.81,153.494 2177.82,153.487 2177.83,153.48 2177.84,153.472 2177.85,153.465 2177.86,153.458 2177.87,153.451 2177.87,153.444 2177.88,153.437 2177.89,153.43 2177.9,153.423 2177.91,153.416 2177.92,153.409 2177.93,153.402 2177.94,153.395 2177.95,153.388 2177.96,153.381 2177.97,153.374 2177.98,153.367 2177.98,153.36 2177.99,153.353 2178,153.346 2178.01,153.339 2178.02,153.332 2178.03,153.325 2178.04,153.318 2178.05,153.311 2178.06,153.304 2178.07,153.297 2178.08,153.29 2178.09,153.282 2178.1,153.275 2178.1,153.268 2178.11,153.261 2178.12,153.254 2178.13,153.247 2178.14,153.24 2178.15,153.233 2178.16,153.226 2178.17,153.219 2178.18,153.212 2178.19,153.205 2178.2,153.198 2178.21,153.191 2178.21,153.184 2178.22,153.177 2178.23,153.17 2178.24,153.163 2178.25,153.156 2178.26,153.149 2178.27,153.142 2178.28,153.135 2178.29,153.128 2178.3,153.121 2178.31,153.114 2178.32,153.107 2178.32,153.1 2178.33,153.093 2178.34,153.086 2178.35,153.079 2178.36,153.072 2178.37,153.065 2178.38,153.058 2178.39,153.051 2178.4,153.044 2178.41,153.037 2178.42,153.03 2178.43,153.023 2178.44,153.016 2178.44,153.009 2178.45,153.002 2178.46,152.995 2178.47,152.988 2178.48,152.981 2178.49,152.974 2178.5,152.967 2178.51,152.96 2178.52,152.953 2178.53,152.946 2178.54,152.939 2178.55,152.932 2178.55,152.925 2178.56,152.918 2178.57,152.911 2178.58,152.904 2178.59,152.897 2178.6,152.89 2178.61,152.883 2178.62,152.876 2178.63,152.869 2178.64,152.862 2178.65,152.855 2178.66,152.848 2178.66,152.841 2178.67,152.834 2178.68,152.827 2178.69,152.82 2178.7,152.813 2178.71,152.806 2178.72,152.799 2178.73,152.792 2178.74,152.785 2178.75,152.778 2178.76,152.771 2178.77,152.764 2178.78,152.757 2178.78,152.75 2178.79,152.743 2178.8,152.736 2178.81,152.729 2178.82,152.722 2178.83,152.715 2178.84,152.708 2178.85,152.701 2178.86,152.694 2178.87,152.687 2178.88,152.68 2178.89,152.673 2178.89,152.666 2178.9,152.659 2178.91,152.652 2178.92,152.645 2178.93,152.638 2178.94,152.631 2178.95,152.624 2178.96,152.617 2178.97,152.61 2178.98,152.603 2178.99,152.596 2179,152.589 2179,152.582 2179.01,152.575 2179.02,152.568 2179.03,152.561 2179.04,152.554 2179.05,152.547 2179.06,152.54 2179.07,152.533 2179.08,152.526 2179.09,152.519 2179.1,152.512 2179.11,152.505 2179.12,152.498 2179.12,152.491 2179.13,152.484 2179.14,152.477 2179.15,152.47 2179.16,152.463 2179.17,152.456 2179.18,152.449 2179.19,152.442 2179.2,152.435 2179.21,152.428 2179.22,152.422 2179.23,152.415 2179.23,152.408 2179.24,152.401 2179.25,152.394 2179.26,152.387 2179.27,152.38 2179.28,152.373 2179.29,152.366 2179.3,152.359 2179.31,152.352 2179.32,152.345 2179.33,152.338 2179.34,152.331 2179.34,152.324 2179.35,152.317 2179.36,152.31 2179.37,152.303 2179.38,152.296 2179.39,152.289 2179.4,152.282 2179.41,152.275 2179.42,152.268 2179.43,152.261 2179.44,152.254 2179.45,152.247 2179.46,152.241 2179.46,152.234 2179.47,152.227 2179.48,152.22 2179.49,152.213 2179.5,152.206 2179.51,152.199 2179.52,152.192 2179.53,152.185 2179.54,152.178 2179.55,152.171 2179.56,152.164 2179.57,152.157 2179.57,152.15 2179.58,152.143 2179.59,152.136 2179.6,152.129 2179.61,152.122 2179.62,152.115 2179.63,152.108 2179.64,152.102 2179.65,152.095 2179.66,152.088 2179.67,152.081 2179.68,152.074 2179.68,152.067 2179.69,152.06 2179.7,152.053 2179.71,152.046 2179.72,152.039 2179.73,152.032 2179.74,152.025 2179.75,152.018 2179.76,152.011 2179.77,152.004 2179.78,151.997 2179.79,151.99 2179.8,151.984 2179.8,151.977 2179.81,151.97 2179.82,151.963 2179.83,151.956 2179.84,151.949 2179.85,151.942 2179.86,151.935 2179.87,151.928 2179.88,151.921 2179.89,151.914 2179.9,151.907 2179.91,151.9 2179.91,151.893 2179.92,151.886 2179.93,151.88 2179.94,151.873 2179.95,151.866 2179.96,151.859 2179.97,151.852 2179.98,151.845 2179.99,151.838 2180,151.831 2180.01,151.824 2180.02,151.817 2180.02,151.81 2180.03,151.803 2180.04,151.796 2180.05,151.789 2180.06,151.783 2180.07,151.776 2180.08,151.769 2180.09,151.762 2180.1,151.755 2180.11,151.748 2180.12,151.741 2180.13,151.734 2180.14,151.727 2180.14,151.72 2180.15,151.713 2180.16,151.706 2180.17,151.7 2180.18,151.693 2180.19,151.686 2180.2,151.679 2180.21,151.672 2180.22,151.665 2180.23,151.658 2180.24,151.651 2180.25,151.644 2180.25,151.637 2180.26,151.63 2180.27,151.623 2180.28,151.617 2180.29,151.61 2180.3,151.603 2180.31,151.596 2180.32,151.589 2180.33,151.582 2180.34,151.575 2180.35,151.568 2180.36,151.561 2180.36,151.554 2180.37,151.547 2180.38,151.541 2180.39,151.534 2180.4,151.527 2180.41,151.52 2180.42,151.513 2180.43,151.506 2180.44,151.499 2180.45,151.492 2180.46,151.485 2180.47,151.478 2180.48,151.472 2180.48,151.465 2180.49,151.458 2180.5,151.451 2180.51,151.444 2180.52,151.437 2180.53,151.43 2180.54,151.423 2180.55,151.416 2180.56,151.409 2180.57,151.403 2180.58,151.396 2180.59,151.389 2180.59,151.382 2180.6,151.375 2180.61,151.368 2180.62,151.361 2180.63,151.354 2180.64,151.347 2180.65,151.341 2180.66,151.334 2180.67,151.327 2180.68,151.32 2180.69,151.313 2180.7,151.306 2180.7,151.299 2180.71,151.292 2180.72,151.285 2180.73,151.279 2180.74,151.272 2180.75,151.265 2180.76,151.258 2180.77,151.251 2180.78,151.244 2180.79,151.237 2180.8,151.23 2180.81,151.223 2180.82,151.217 2180.82,151.21 2180.83,151.203 2180.84,151.196 2180.85,151.189 2180.86,151.182 2180.87,151.175 2180.88,151.168 2180.89,151.162 2180.9,151.155 2180.91,151.148 2180.92,151.141 2180.93,151.134 2180.93,151.127 2180.94,151.12 2180.95,151.113 2180.96,151.107 2180.97,151.1 2180.98,151.093 2180.99,151.086 2181,151.079 2181.01,151.072 2181.02,151.065 2181.03,151.058 2181.04,151.052 2181.04,151.045 2181.05,151.038 2181.06,151.031 2181.07,151.024 2181.08,151.017 2181.09,151.01 2181.1,151.003 2181.11,150.997 2181.12,150.99 2181.13,150.983 2181.14,150.976 2181.15,150.969 2181.16,150.962 2181.16,150.955 2181.17,150.949 2181.18,150.942 2181.19,150.935 2181.2,150.928 2181.21,150.921 2181.22,150.914 2181.23,150.907 2181.24,150.901 2181.25,150.894 2181.26,150.887 2181.27,150.88 2181.27,150.873 2181.28,150.866 2181.29,150.859 2181.3,150.853 2181.31,150.846 2181.32,150.839 2181.33,150.832 2181.34,150.825 2181.35,150.818 2181.36,150.811 2181.37,150.805 2181.38,150.798 2181.38,150.791 2181.39,150.784 2181.4,150.777 2181.41,150.77 2181.42,150.763 2181.43,150.757 2181.44,150.75 2181.45,150.743 2181.46,150.736 2181.47,150.729 2181.48,150.722 2181.49,150.715 2181.5,150.709 2181.5,150.702 2181.51,150.695 2181.52,150.688 2181.53,150.681 2181.54,150.674 2181.55,150.668 2181.56,150.661 2181.57,150.654 2181.58,150.647 2181.59,150.64 2181.6,150.633 2181.61,150.627 2181.61,150.62 2181.62,150.613 2181.63,150.606 2181.64,150.599 2181.65,150.592 2181.66,150.585 2181.67,150.579 2181.68,150.572 2181.69,150.565 2181.7,150.558 2181.71,150.551 2181.72,150.544 2181.72,150.538 2181.73,150.531 2181.74,150.524 2181.75,150.517 2181.76,150.51 2181.77,150.503 2181.78,150.497 2181.79,150.49 2181.8,150.483 2181.81,150.476 2181.82,150.469 2181.83,150.463 2181.84,150.456 2181.84,150.449 2181.85,150.442 2181.86,150.435 2181.87,150.428 2181.88,150.422 2181.89,150.415 2181.9,150.408 2181.91,150.401 2181.92,150.394 2181.93,150.387 2181.94,150.381 2181.95,150.374 2181.95,150.367 2181.96,150.36 2181.97,150.353 2181.98,150.346 2181.99,150.34 2182,150.333 2182.01,150.326 2182.02,150.319 2182.03,150.312 2182.04,150.306 2182.05,150.299 2182.06,150.292 2182.06,150.285 2182.07,150.278 2182.08,150.271 2182.09,150.265 2182.1,150.258 2182.11,150.251 2182.12,150.244 2182.13,150.237 2182.14,150.231 2182.15,150.224 2182.16,150.217 2182.17,150.21 2182.18,150.203 2182.18,150.197 2182.19,150.19 2182.2,150.183 2182.21,150.176 2182.22,150.169 2182.23,150.163 2182.24,150.156 2182.25,150.149 2182.26,150.142 2182.27,150.135 2182.28,150.128 2182.29,150.122 2182.29,150.115 2182.3,150.108 2182.31,150.101 2182.32,150.094 2182.33,150.088 2182.34,150.081 2182.35,150.074 2182.36,150.067 2182.37,150.06 2182.38,150.054 2182.39,150.047 2182.4,150.04 2182.4,150.033 2182.41,150.026 2182.42,150.02 2182.43,150.013 2182.44,150.006 2182.45,149.999 2182.46,149.992 2182.47,149.986 2182.48,149.979 2182.49,149.972 2182.5,149.965 2182.51,149.959 2182.52,149.952 2182.52,149.945 2182.53,149.938 2182.54,149.931 2182.55,149.925 2182.56,149.918 2182.57,149.911 2182.58,149.904 2182.59,149.897 2182.6,149.891 2182.61,149.884 2182.62,149.877 2182.63,149.87 2182.63,149.863 2182.64,149.857 2182.65,149.85 2182.66,149.843 2182.67,149.836 2182.68,149.83 2182.69,149.823 2182.7,149.816 2182.71,149.809 2182.72,149.802 2182.73,149.796 2182.74,149.789 2182.74,149.782 2182.75,149.775 2182.76,149.768 2182.77,149.762 2182.78,149.755 2182.79,149.748 2182.8,149.741 2182.81,149.735 2182.82,149.728 2182.83,149.721 2182.84,149.714 2182.85,149.707 2182.86,149.701 2182.86,149.694 2182.87,149.687 2182.88,149.68 2182.89,149.674 2182.9,149.667 2182.91,149.66 2182.92,149.653 2182.93,149.647 2182.94,149.64 2182.95,149.633 2182.96,149.626 2182.97,149.619 2182.97,149.613 2182.98,149.606 2182.99,149.599 2183,149.592 2183.01,149.586 2183.02,149.579 2183.03,149.572 2183.04,149.565 2183.05,149.559 2183.06,149.552 2183.07,149.545 2183.08,149.538 2183.08,149.531 2183.09,149.525 2183.1,149.518 2183.11,149.511 2183.12,149.504 2183.13,149.498 2183.14,149.491 2183.15,149.484 2183.16,149.477 2183.17,149.471 2183.18,149.464 2183.19,149.457 2183.2,149.45 2183.2,149.444 2183.21,149.437 2183.22,149.43 2183.23,149.423 2183.24,149.417 2183.25,149.41 2183.26,149.403 2183.27,149.396 2183.28,149.39 2183.29,149.383 2183.3,149.376 2183.31,149.369 2183.31,149.363 2183.32,149.356 2183.33,149.349 2183.34,149.342 2183.35,149.336 2183.36,149.329 2183.37,149.322 2183.38,149.315 2183.39,149.309 2183.4,149.302 2183.41,149.295 2183.42,149.288 2183.42,149.282 2183.43,149.275 2183.44,149.268 2183.45,149.261 2183.46,149.255 2183.47,149.248 2183.48,149.241 2183.49,149.234 2183.5,149.228 2183.51,149.221 2183.52,149.214 2183.53,149.207 2183.54,149.201 2183.54,149.194 2183.55,149.187 2183.56,149.18 2183.57,149.174 2183.58,149.167 2183.59,149.16 2183.6,149.153 2183.61,149.147 2183.62,149.14 2183.63,149.133 2183.64,149.127 2183.65,149.12 2183.65,149.113 2183.66,149.106 2183.67,149.1 2183.68,149.093 2183.69,149.086 2183.7,149.079 2183.71,149.073 2183.72,149.066 2183.73,149.059 2183.74,149.052 2183.75,149.046 2183.76,149.039 2183.76,149.032 2183.77,149.026 2183.78,149.019 2183.79,149.012 2183.8,149.005 2183.81,148.999 2183.82,148.992 2183.83,148.985 2183.84,148.978 2183.85,148.972 2183.86,148.965 2183.87,148.958 2183.88,148.952 2183.88,148.945 2183.89,148.938 2183.9,148.931 2183.91,148.925 2183.92,148.918 2183.93,148.911 2183.94,148.905 2183.95,148.898 2183.96,148.891 2183.97,148.884 2183.98,148.878 2183.99,148.871 2183.99,148.864 2184,148.858 2184.01,148.851 2184.02,148.844 2184.03,148.837 2184.04,148.831 2184.05,148.824 2184.06,148.817 2184.07,148.811 2184.08,148.804 2184.09,148.797 2184.1,148.79 2184.1,148.784 2184.11,148.777 2184.12,148.77 2184.13,148.764 2184.14,148.757 2184.15,148.75 2184.16,148.743 2184.17,148.737 2184.18,148.73 2184.19,148.723 2184.2,148.717 2184.21,148.71 2184.22,148.703 2184.22,148.696 2184.23,148.69 2184.24,148.683 2184.25,148.676 2184.26,148.67 2184.27,148.663 2184.28,148.656 2184.29,148.65 2184.3,148.643 2184.31,148.636 2184.32,148.629 2184.33,148.623 2184.33,148.616 2184.34,148.609 2184.35,148.603 2184.36,148.596 2184.37,148.589 2184.38,148.583 2184.39,148.576 2184.4,148.569 2184.41,148.562 2184.42,148.556 2184.43,148.549 2184.44,148.542 2184.44,148.536 2184.45,148.529 2184.46,148.522 2184.47,148.516 2184.48,148.509 2184.49,148.502 2184.5,148.496 2184.51,148.489 2184.52,148.482 2184.53,148.475 2184.54,148.469 2184.55,148.462 2184.56,148.455 2184.56,148.449 2184.57,148.442 2184.58,148.435 2184.59,148.429 2184.6,148.422 2184.61,148.415 2184.62,148.409 2184.63,148.402 2184.64,148.395 2184.65,148.389 2184.66,148.382 2184.67,148.375 2184.67,148.368 2184.68,148.362 2184.69,148.355 2184.7,148.348 2184.71,148.342 2184.72,148.335 2184.73,148.328 2184.74,148.322 2184.75,148.315 2184.76,148.308 2184.77,148.302 2184.78,148.295 2184.78,148.288 2184.79,148.282 2184.8,148.275 2184.81,148.268 2184.82,148.262 2184.83,148.255 2184.84,148.248 2184.85,148.242 2184.86,148.235 2184.87,148.228 2184.88,148.222 2184.89,148.215 2184.9,148.208 2184.9,148.202 2184.91,148.195 2184.92,148.188 2184.93,148.182 2184.94,148.175 2184.95,148.168 2184.96,148.162 2184.97,148.155 2184.98,148.148 2184.99,148.142 2185,148.135 2185.01,148.128 2185.01,148.122 2185.02,148.115 2185.03,148.108 2185.04,148.102 2185.05,148.095 2185.06,148.088 2185.07,148.082 2185.08,148.075 2185.09,148.068 2185.1,148.062 2185.11,148.055 2185.12,148.048 2185.12,148.042 2185.13,148.035 2185.14,148.028 2185.15,148.022 2185.16,148.015 2185.17,148.008 2185.18,148.002 2185.19,147.995 2185.2,147.988 2185.21,147.982 2185.22,147.975 2185.23,147.968 2185.24,147.962 2185.24,147.955 2185.25,147.948 2185.26,147.942 2185.27,147.935 2185.28,147.928 2185.29,147.922 2185.3,147.915 2185.31,147.908 2185.32,147.902 2185.33,147.895 2185.34,147.889 2185.35,147.882 2185.35,147.875 2185.36,147.869 2185.37,147.862 2185.38,147.855 2185.39,147.849 2185.4,147.842 2185.41,147.835 2185.42,147.829 2185.43,147.822 2185.44,147.815 2185.45,147.809 2185.46,147.802 2185.46,147.795 2185.47,147.789 2185.48,147.782 2185.49,147.776 2185.5,147.769 2185.51,147.762 2185.52,147.756 2185.53,147.749 2185.54,147.742 2185.55,147.736 2185.56,147.729 2185.57,147.722 2185.58,147.716 2185.58,147.709 2185.59,147.703 2185.6,147.696 2185.61,147.689 2185.62,147.683 2185.63,147.676 2185.64,147.669 2185.65,147.663 2185.66,147.656 2185.67,147.649 2185.68,147.643 2185.69,147.636 2185.69,147.63 2185.7,147.623 2185.71,147.616 2185.72,147.61 2185.73,147.603 2185.74,147.596 2185.75,147.59 2185.76,147.583 2185.77,147.577 2185.78,147.57 2185.79,147.563 2185.8,147.557 2185.8,147.55 2185.81,147.543 2185.82,147.537 2185.83,147.53 2185.84,147.523 2185.85,147.517 2185.86,147.51 2185.87,147.504 2185.88,147.497 2185.89,147.49 2185.9,147.484 2185.91,147.477 2185.92,147.471 2185.92,147.464 2185.93,147.457 2185.94,147.451 2185.95,147.444 2185.96,147.437 2185.97,147.431 2185.98,147.424 2185.99,147.418 2186,147.411 2186.01,147.404 2186.02,147.398 2186.03,147.391 2186.03,147.384 2186.04,147.378 2186.05,147.371 2186.06,147.365 2186.07,147.358 2186.08,147.351 2186.09,147.345 2186.1,147.338 2186.11,147.332 2186.12,147.325 2186.13,147.318 2186.14,147.312 2186.14,147.305 2186.15,147.299 2186.16,147.292 2186.17,147.285 2186.18,147.279 2186.19,147.272 2186.2,147.265 2186.21,147.259 2186.22,147.252 2186.23,147.246 2186.24,147.239 2186.25,147.232 2186.26,147.226 2186.26,147.219 2186.27,147.213 2186.28,147.206 2186.29,147.199 2186.3,147.193 2186.31,147.186 2186.32,147.18 2186.33,147.173 2186.34,147.166 2186.35,147.16 2186.36,147.153 2186.37,147.147 2186.37,147.14 2186.38,147.133 2186.39,147.127 2186.4,147.12 2186.41,147.114 2186.42,147.107 2186.43,147.1 2186.44,147.094 2186.45,147.087 2186.46,147.081 2186.47,147.074 2186.48,147.067 2186.48,147.061 2186.49,147.054 2186.5,147.048 2186.51,147.041 2186.52,147.035 2186.53,147.028 2186.54,147.021 2186.55,147.015 2186.56,147.008 2186.57,147.002 2186.58,146.995 2186.59,146.988 2186.6,146.982 2186.6,146.975 2186.61,146.969 2186.62,146.962 2186.63,146.955 2186.64,146.949 2186.65,146.942 2186.66,146.936 2186.67,146.929 2186.68,146.923 2186.69,146.916 2186.7,146.909 2186.71,146.903 2186.71,146.896 2186.72,146.89 2186.73,146.883 2186.74,146.876 2186.75,146.87 2186.76,146.863 2186.77,146.857 2186.78,146.85 2186.79,146.844 2186.8,146.837 2186.81,146.83 2186.82,146.824 2186.82,146.817 2186.83,146.811 2186.84,146.804 2186.85,146.798 2186.86,146.791 2186.87,146.784 2186.88,146.778 2186.89,146.771 2186.9,146.765 2186.91,146.758 2186.92,146.751 2186.93,146.745 2186.94,146.738 2186.94,146.732 2186.95,146.725 2186.96,146.719 2186.97,146.712 2186.98,146.706 2186.99,146.699 2187,146.692 2187.01,146.686 2187.02,146.679 2187.03,146.673 2187.04,146.666 2187.05,146.66 2187.05,146.653 2187.06,146.646 2187.07,146.64 2187.08,146.633 2187.09,146.627 2187.1,146.62 2187.11,146.614 2187.12,146.607 2187.13,146.6 2187.14,146.594 2187.15,146.587 2187.16,146.581 2187.16,146.574 2187.17,146.568 2187.18,146.561 2187.19,146.555 2187.2,146.548 2187.21,146.541 2187.22,146.535 2187.23,146.528 2187.24,146.522 2187.25,146.515 2187.26,146.509 2187.27,146.502 2187.28,146.496 2187.28,146.489 2187.29,146.482 2187.3,146.476 2187.31,146.469 2187.32,146.463 2187.33,146.456 2187.34,146.45 2187.35,146.443 2187.36,146.437 2187.37,146.43 2187.38,146.423 2187.39,146.417 2187.39,146.41 2187.4,146.404 2187.41,146.397 2187.42,146.391 2187.43,146.384 2187.44,146.378 2187.45,146.371 2187.46,146.365 2187.47,146.358 2187.48,146.351 2187.49,146.345 2187.5,146.338 2187.5,146.332 2187.51,146.325 2187.52,146.319 2187.53,146.312 2187.54,146.306 2187.55,146.299 2187.56,146.293 2187.57,146.286 2187.58,146.279 2187.59,146.273 2187.6,146.266 2187.61,146.26 2187.62,146.253 2187.62,146.247 2187.63,146.24 2187.64,146.234 2187.65,146.227 2187.66,146.221 2187.67,146.214 2187.68,146.208 2187.69,146.201 2187.7,146.194 2187.71,146.188 2187.72,146.181 2187.73,146.175 2187.73,146.168 2187.74,146.162 2187.75,146.155 2187.76,146.149 2187.77,146.142 2187.78,146.136 2187.79,146.129 2187.8,146.123 2187.81,146.116 2187.82,146.11 2187.83,146.103 2187.84,146.096 2187.84,146.09 2187.85,146.083 2187.86,146.077 2187.87,146.07 2187.88,146.064 2187.89,146.057 2187.9,146.051 2187.91,146.044 2187.92,146.038 2187.93,146.031 2187.94,146.025 2187.95,146.018 2187.96,146.012 2187.96,146.005 2187.97,145.999 2187.98,145.992 2187.99,145.986 2188,145.979 2188.01,145.973 2188.02,145.966 2188.03,145.96 2188.04,145.953 2188.05,145.946 2188.06,145.94 2188.07,145.933 2188.07,145.927 2188.08,145.92 2188.09,145.914 2188.1,145.907 2188.11,145.901 2188.12,145.894 2188.13,145.888 2188.14,145.881 2188.15,145.875 2188.16,145.868 2188.17,145.862 2188.18,145.855 2188.18,145.849 2188.19,145.842 2188.2,145.836 2188.21,145.829 2188.22,145.823 2188.23,145.816 2188.24,145.81 2188.25,145.803 2188.26,145.797 2188.27,145.79 2188.28,145.784 2188.29,145.777 2188.3,145.771 2188.3,145.764 2188.31,145.758 2188.32,145.751 2188.33,145.745 2188.34,145.738 2188.35,145.732 2188.36,145.725 2188.37,145.719 2188.38,145.712 2188.39,145.706 2188.4,145.699 2188.41,145.693 2188.41,145.686 2188.42,145.68 2188.43,145.673 2188.44,145.667 2188.45,145.66 2188.46,145.654 2188.47,145.647 2188.48,145.641 2188.49,145.634 2188.5,145.628 2188.51,145.621 2188.52,145.615 2188.52,145.608 2188.53,145.602 2188.54,145.595 2188.55,145.589 2188.56,145.582 2188.57,145.576 2188.58,145.569 2188.59,145.563 2188.6,145.556 2188.61,145.55 2188.62,145.543 2188.63,145.537 2188.64,145.53 2188.64,145.524 2188.65,145.517 2188.66,145.511 2188.67,145.504 2188.68,145.498 2188.69,145.491 2188.7,145.485 2188.71,145.478 2188.72,145.472 2188.73,145.465 2188.74,145.459 2188.75,145.452 2188.75,145.446 2188.76,145.439 2188.77,145.433 2188.78,145.426 2188.79,145.42 2188.8,145.413 2188.81,145.407 2188.82,145.4 2188.83,145.394 2188.84,145.388 2188.85,145.381 2188.86,145.375 2188.86,145.368 2188.87,145.362 2188.88,145.355 2188.89,145.349 2188.9,145.342 2188.91,145.336 2188.92,145.329 2188.93,145.323 2188.94,145.316 2188.95,145.31 2188.96,145.303 2188.97,145.297 2188.98,145.29 2188.98,145.284 2188.99,145.277 2189,145.271 2189.01,145.264 2189.02,145.258 2189.03,145.252 2189.04,145.245 2189.05,145.239 2189.06,145.232 2189.07,145.226 2189.08,145.219 2189.09,145.213 2189.09,145.206 2189.1,145.2 2189.11,145.193 2189.12,145.187 2189.13,145.18 2189.14,145.174 2189.15,145.167 2189.16,145.161 2189.17,145.154 2189.18,145.148 2189.19,145.142 2189.2,145.135 2189.2,145.129 2189.21,145.122 2189.22,145.116 2189.23,145.109 2189.24,145.103 2189.25,145.096 2189.26,145.09 2189.27,145.083 2189.28,145.077 2189.29,145.07 2189.3,145.064 2189.31,145.058 2189.32,145.051 2189.32,145.045 2189.33,145.038 2189.34,145.032 2189.35,145.025 2189.36,145.019 2189.37,145.012 2189.38,145.006 2189.39,144.999 2189.4,144.993 2189.41,144.987 2189.42,144.98 2189.43,144.974 2189.43,144.967 2189.44,144.961 2189.45,144.954 2189.46,144.948 2189.47,144.941 2189.48,144.935 2189.49,144.928 2189.5,144.922 2189.51,144.916 2189.52,144.909 2189.53,144.903 2189.54,144.896 2189.54,144.89 2189.55,144.883 2189.56,144.877 2189.57,144.87 2189.58,144.864 2189.59,144.858 2189.6,144.851 2189.61,144.845 2189.62,144.838 2189.63,144.832 2189.64,144.825 2189.65,144.819 2189.66,144.812 2189.66,144.806 2189.67,144.8 2189.68,144.793 2189.69,144.787 2189.7,144.78 2189.71,144.774 2189.72,144.767 2189.73,144.761 2189.74,144.754 2189.75,144.748 2189.76,144.742 2189.77,144.735 2189.77,144.729 2189.78,144.722 2189.79,144.716 2189.8,144.709 2189.81,144.703 2189.82,144.697 2189.83,144.69 2189.84,144.684 2189.85,144.677 2189.86,144.671 2189.87,144.664 2189.88,144.658 2189.88,144.652 2189.89,144.645 2189.9,144.639 2189.91,144.632 2189.92,144.626 2189.93,144.619 2189.94,144.613 2189.95,144.606 2189.96,144.6 2189.97,144.594 2189.98,144.587 2189.99,144.581 2190,144.574 2190,144.568 2190.01,144.561 2190.02,144.555 2190.03,144.549 2190.04,144.542 2190.05,144.536 2190.06,144.529 2190.07,144.523 2190.08,144.517 2190.09,144.51 2190.1,144.504 2190.11,144.497 2190.11,144.491 2190.12,144.484 2190.13,144.478 2190.14,144.472 2190.15,144.465 2190.16,144.459 2190.17,144.452 2190.18,144.446 2190.19,144.439 2190.2,144.433 2190.21,144.427 2190.22,144.42 2190.22,144.414 2190.23,144.407 2190.24,144.401 2190.25,144.395 2190.26,144.388 2190.27,144.382 2190.28,144.375 2190.29,144.369 2190.3,144.362 2190.31,144.356 2190.32,144.35 2190.33,144.343 2190.34,144.337 2190.34,144.33 2190.35,144.324 2190.36,144.318 2190.37,144.311 2190.38,144.305 2190.39,144.298 2190.4,144.292 2190.41,144.286 2190.42,144.279 2190.43,144.273 2190.44,144.266 2190.45,144.26 2190.45,144.254 2190.46,144.247 2190.47,144.241 2190.48,144.234 2190.49,144.228 2190.5,144.221 2190.51,144.215 2190.52,144.209 2190.53,144.202 2190.54,144.196 2190.55,144.189 2190.56,144.183 2190.56,144.177 2190.57,144.17 2190.58,144.164 2190.59,144.157 2190.6,144.151 2190.61,144.145 2190.62,144.138 2190.63,144.132 2190.64,144.125 2190.65,144.119 2190.66,144.113 2190.67,144.106 2190.68,144.1 2190.68,144.094 2190.69,144.087 2190.7,144.081 2190.71,144.074 2190.72,144.068 2190.73,144.062 2190.74,144.055 2190.75,144.049 2190.76,144.042 2190.77,144.036 2190.78,144.03 2190.79,144.023 2190.79,144.017 2190.8,144.01 2190.81,144.004 2190.82,143.998 2190.83,143.991 2190.84,143.985 2190.85,143.978 2190.86,143.972 2190.87,143.966 2190.88,143.959 2190.89,143.953 2190.9,143.947 2190.9,143.94 2190.91,143.934 2190.92,143.927 2190.93,143.921 2190.94,143.915 2190.95,143.908 2190.96,143.902 2190.97,143.895 2190.98,143.889 2190.99,143.883 2191,143.876 2191.01,143.87 2191.02,143.864 2191.02,143.857 2191.03,143.851 2191.04,143.844 2191.05,143.838 2191.06,143.832 2191.07,143.825 2191.08,143.819 2191.09,143.813 2191.1,143.806 2191.11,143.8 2191.12,143.793 2191.13,143.787 2191.13,143.781 2191.14,143.774 2191.15,143.768 2191.16,143.762 2191.17,143.755 2191.18,143.749 2191.19,143.742 2191.2,143.736 2191.21,143.73 2191.22,143.723 2191.23,143.717 2191.24,143.711 2191.24,143.704 2191.25,143.698 2191.26,143.691 2191.27,143.685 2191.28,143.679 2191.29,143.672 2191.3,143.666 2191.31,143.66 2191.32,143.653 2191.33,143.647 2191.34,143.64 2191.35,143.634 2191.36,143.628 2191.36,143.621 2191.37,143.615 2191.38,143.609 2191.39,143.602 2191.4,143.596 2191.41,143.59 2191.42,143.583 2191.43,143.577 2191.44,143.57 2191.45,143.564 2191.46,143.558 2191.47,143.551 2191.47,143.545 2191.48,143.539 2191.49,143.532 2191.5,143.526 2191.51,143.52 2191.52,143.513 2191.53,143.507 2191.54,143.501 2191.55,143.494 2191.56,143.488 2191.57,143.481 2191.58,143.475 2191.58,143.469 2191.59,143.462 2191.6,143.456 2191.61,143.45 2191.62,143.443 2191.63,143.437 2191.64,143.431 2191.65,143.424 2191.66,143.418 2191.67,143.412 2191.68,143.405 2191.69,143.399 2191.7,143.393 2191.7,143.386 2191.71,143.38 2191.72,143.373 2191.73,143.367 2191.74,143.361 2191.75,143.354 2191.76,143.348 2191.77,143.342 2191.78,143.335 2191.79,143.329 2191.8,143.323 2191.81,143.316 2191.81,143.31 2191.82,143.304 2191.83,143.297 2191.84,143.291 2191.85,143.285 2191.86,143.278 2191.87,143.272 2191.88,143.266 2191.89,143.259 2191.9,143.253 2191.91,143.247 2191.92,143.24 2191.92,143.234 2191.93,143.228 2191.94,143.221 2191.95,143.215 2191.96,143.209 2191.97,143.202 2191.98,143.196 2191.99,143.19 2192,143.183 2192.01,143.177 2192.02,143.171 2192.03,143.164 2192.04,143.158 2192.04,143.152 2192.05,143.145 2192.06,143.139 2192.07,143.133 2192.08,143.126 2192.09,143.12 2192.1,143.114 2192.11,143.107 2192.12,143.101 2192.13,143.095 2192.14,143.088 2192.15,143.082 2192.15,143.076 2192.16,143.069 2192.17,143.063 2192.18,143.057 2192.19,143.05 2192.2,143.044 2192.21,143.038 2192.22,143.031 2192.23,143.025 2192.24,143.019 2192.25,143.012 2192.26,143.006 2192.26,143 2192.27,142.993 2192.28,142.987 2192.29,142.981 2192.3,142.974 2192.31,142.968 2192.32,142.962 2192.33,142.955 2192.34,142.949 2192.35,142.943 2192.36,142.936 2192.37,142.93 2192.38,142.924 2192.38,142.917 2192.39,142.911 2192.4,142.905 2192.41,142.898 2192.42,142.892 2192.43,142.886 2192.44,142.88 2192.45,142.873 2192.46,142.867 2192.47,142.861 2192.48,142.854 2192.49,142.848 2192.49,142.842 2192.5,142.835 2192.51,142.829 2192.52,142.823 2192.53,142.816 2192.54,142.81 2192.55,142.804 2192.56,142.797 2192.57,142.791 2192.58,142.785 2192.59,142.778 2192.6,142.772 2192.6,142.766 2192.61,142.76 2192.62,142.753 2192.63,142.747 2192.64,142.741 2192.65,142.734 2192.66,142.728 2192.67,142.722 2192.68,142.715 2192.69,142.709 2192.7,142.703 2192.71,142.696 2192.72,142.69 2192.72,142.684 2192.73,142.678 2192.74,142.671 2192.75,142.665 2192.76,142.659 2192.77,142.652 2192.78,142.646 2192.79,142.64 2192.8,142.633 2192.81,142.627 2192.82,142.621 2192.83,142.615 2192.83,142.608 2192.84,142.602 2192.85,142.596 2192.86,142.589 2192.87,142.583 2192.88,142.577 2192.89,142.57 2192.9,142.564 2192.91,142.558 2192.92,142.552 2192.93,142.545 2192.94,142.539 2192.94,142.533 2192.95,142.526 2192.96,142.52 2192.97,142.514 2192.98,142.508 2192.99,142.501 2193,142.495 2193.01,142.489 2193.02,142.482 2193.03,142.476 2193.04,142.47 2193.05,142.463 2193.06,142.457 2193.06,142.451 2193.07,142.445 2193.08,142.438 2193.09,142.432 2193.1,142.426 2193.11,142.419 2193.12,142.413 2193.13,142.407 2193.14,142.401 2193.15,142.394 2193.16,142.388 2193.17,142.382 2193.17,142.375 2193.18,142.369 2193.19,142.363 2193.2,142.357 2193.21,142.35 2193.22,142.344 2193.23,142.338 2193.24,142.331 2193.25,142.325 2193.26,142.319 2193.27,142.313 2193.28,142.306 2193.28,142.3 2193.29,142.294 2193.3,142.288 2193.31,142.281 2193.32,142.275 2193.33,142.269 2193.34,142.262 2193.35,142.256 2193.36,142.25 2193.37,142.244 2193.38,142.237 2193.39,142.231 2193.4,142.225 2193.4,142.218 2193.41,142.212 2193.42,142.206 2193.43,142.2 2193.44,142.193 2193.45,142.187 2193.46,142.181 2193.47,142.175 2193.48,142.168 2193.49,142.162 2193.5,142.156 2193.51,142.149 2193.51,142.143 2193.52,142.137 2193.53,142.131 2193.54,142.124 2193.55,142.118 2193.56,142.112 2193.57,142.106 2193.58,142.099 2193.59,142.093 2193.6,142.087 2193.61,142.081 2193.62,142.074 2193.62,142.068 2193.63,142.062 2193.64,142.055 2193.65,142.049 2193.66,142.043 2193.67,142.037 2193.68,142.03 2193.69,142.024 2193.7,142.018 2193.71,142.012 2193.72,142.005 2193.73,141.999 2193.74,141.993 2193.74,141.987 2193.75,141.98 2193.76,141.974 2193.77,141.968 2193.78,141.962 2193.79,141.955 2193.8,141.949 2193.81,141.943 2193.82,141.937 2193.83,141.93 2193.84,141.924 2193.85,141.918 2193.85,141.912 2193.86,141.905 2193.87,141.899 2193.88,141.893 2193.89,141.886 2193.9,141.88 2193.91,141.874 2193.92,141.868 2193.93,141.861 2193.94,141.855 2193.95,141.849 2193.96,141.843 2193.96,141.836 2193.97,141.83 2193.98,141.824 2193.99,141.818 2194,141.811 2194.01,141.805 2194.02,141.799 2194.03,141.793 2194.04,141.786 2194.05,141.78 2194.06,141.774 2194.07,141.768 2194.08,141.762 2194.08,141.755 2194.09,141.749 2194.1,141.743 2194.11,141.737 2194.12,141.73 2194.13,141.724 2194.14,141.718 2194.15,141.712 2194.16,141.705 2194.17,141.699 2194.18,141.693 2194.19,141.687 2194.19,141.68 2194.2,141.674 2194.21,141.668 2194.22,141.662 2194.23,141.655 2194.24,141.649 2194.25,141.643 2194.26,141.637 2194.27,141.63 2194.28,141.624 2194.29,141.618 2194.3,141.612 2194.3,141.605 2194.31,141.599 2194.32,141.593 2194.33,141.587 2194.34,141.581 2194.35,141.574 2194.36,141.568 2194.37,141.562 2194.38,141.556 2194.39,141.549 2194.4,141.543 2194.41,141.537 2194.42,141.531 2194.42,141.524 2194.43,141.518 2194.44,141.512 2194.45,141.506 2194.46,141.5 2194.47,141.493 2194.48,141.487 2194.49,141.481 2194.5,141.475 2194.51,141.468 2194.52,141.462 2194.53,141.456 2194.53,141.45 2194.54,141.443 2194.55,141.437 2194.56,141.431 2194.57,141.425 2194.58,141.419 2194.59,141.412 2194.6,141.406 2194.61,141.4 2194.62,141.394 2194.63,141.387 2194.64,141.381 2194.64,141.375 2194.65,141.369 2194.66,141.363 2194.67,141.356 2194.68,141.35 2194.69,141.344 2194.7,141.338 2194.71,141.332 2194.72,141.325 2194.73,141.319 2194.74,141.313 2194.75,141.307 2194.76,141.3 2194.76,141.294 2194.77,141.288 2194.78,141.282 2194.79,141.276 2194.8,141.269 2194.81,141.263 2194.82,141.257 2194.83,141.251 2194.84,141.244 2194.85,141.238 2194.86,141.232 2194.87,141.226 2194.87,141.22 2194.88,141.213 2194.89,141.207 2194.9,141.201 2194.91,141.195 2194.92,141.189 2194.93,141.182 2194.94,141.176 2194.95,141.17 2194.96,141.164 2194.97,141.158 2194.98,141.151 2194.98,141.145 2194.99,141.139 2195,141.133 2195.01,141.127 2195.02,141.12 2195.03,141.114 2195.04,141.108 2195.05,141.102 2195.06,141.095 2195.07,141.089 2195.08,141.083 2195.09,141.077 2195.1,141.071 2195.1,141.064 2195.11,141.058 2195.12,141.052 2195.13,141.046 2195.14,141.04 2195.15,141.033 2195.16,141.027 2195.17,141.021 2195.18,141.015 2195.19,141.009 2195.2,141.002 2195.21,140.996 2195.21,140.99 2195.22,140.984 2195.23,140.978 2195.24,140.971 2195.25,140.965 2195.26,140.959 2195.27,140.953 2195.28,140.947 2195.29,140.941 2195.3,140.934 2195.31,140.928 2195.32,140.922 2195.32,140.916 2195.33,140.91 2195.34,140.903 2195.35,140.897 2195.36,140.891 2195.37,140.885 2195.38,140.879 2195.39,140.872 2195.4,140.866 2195.41,140.86 2195.42,140.854 2195.43,140.848 2195.44,140.841 2195.44,140.835 2195.45,140.829 2195.46,140.823 2195.47,140.817 2195.48,140.811 2195.49,140.804 2195.5,140.798 2195.51,140.792 2195.52,140.786 2195.53,140.78 2195.54,140.773 2195.55,140.767 2195.55,140.761 2195.56,140.755 2195.57,140.749 2195.58,140.743 2195.59,140.736 2195.6,140.73 2195.61,140.724 2195.62,140.718 2195.63,140.712 2195.64,140.705 2195.65,140.699 2195.66,140.693 2195.66,140.687 2195.67,140.681 2195.68,140.675 2195.69,140.668 2195.7,140.662 2195.71,140.656 2195.72,140.65 2195.73,140.644 2195.74,140.637 2195.75,140.631 2195.76,140.625 2195.77,140.619 2195.78,140.613 2195.78,140.607 2195.79,140.6 2195.8,140.594 2195.81,140.588 2195.82,140.582 2195.83,140.576 2195.84,140.57 2195.85,140.563 2195.86,140.557 2195.87,140.551 2195.88,140.545 2195.89,140.539 2195.89,140.533 2195.9,140.526 2195.91,140.52 2195.92,140.514 2195.93,140.508 2195.94,140.502 2195.95,140.496 2195.96,140.489 2195.97,140.483 2195.98,140.477 2195.99,140.471 2196,140.465 2196,140.459 2196.01,140.452 2196.02,140.446 2196.03,140.44 2196.04,140.434 2196.05,140.428 2196.06,140.422 2196.07,140.415 2196.08,140.409 2196.09,140.403 2196.1,140.397 2196.11,140.391 2196.12,140.385 2196.12,140.378 2196.13,140.372 2196.14,140.366 2196.15,140.36 2196.16,140.354 2196.17,140.348 2196.18,140.342 2196.19,140.335 2196.2,140.329 2196.21,140.323 2196.22,140.317 2196.23,140.311 2196.23,140.305 2196.24,140.298 2196.25,140.292 2196.26,140.286 2196.27,140.28 2196.28,140.274 2196.29,140.268 2196.3,140.262 2196.31,140.255 2196.32,140.249 2196.33,140.243 2196.34,140.237 2196.35,140.231 2196.35,140.225 2196.36,140.218 2196.37,140.212 2196.38,140.206 2196.39,140.2 2196.4,140.194 2196.41,140.188 2196.42,140.182 2196.43,140.175 2196.44,140.169 2196.45,140.163 2196.46,140.157 2196.46,140.151 2196.47,140.145 2196.48,140.139 2196.49,140.132 2196.5,140.126 2196.51,140.12 2196.52,140.114 2196.53,140.108 2196.54,140.102 2196.55,140.096 2196.56,140.089 2196.57,140.083 2196.57,140.077 2196.58,140.071 2196.59,140.065 2196.6,140.059 2196.61,140.053 2196.62,140.046 2196.63,140.04 2196.64,140.034 2196.65,140.028 2196.66,140.022 2196.67,140.016 2196.68,140.01 2196.69,140.004 2196.69,139.997 2196.7,139.991 2196.71,139.985 2196.72,139.979 2196.73,139.973 2196.74,139.967 2196.75,139.961 2196.76,139.954 2196.77,139.948 2196.78,139.942 2196.79,139.936 2196.8,139.93 2196.8,139.924 2196.81,139.918 2196.82,139.912 2196.83,139.905 2196.84,139.899 2196.85,139.893 2196.86,139.887 2196.87,139.881 2196.88,139.875 2196.89,139.869 2196.9,139.863 2196.91,139.856 2196.91,139.85 2196.92,139.844 2196.93,139.838 2196.94,139.832 2196.95,139.826 2196.96,139.82 2196.97,139.814 2196.98,139.807 2196.99,139.801 2197,139.795 2197.01,139.789 2197.02,139.783 2197.03,139.777 2197.03,139.771 2197.04,139.765 2197.05,139.758 2197.06,139.752 2197.07,139.746 2197.08,139.74 2197.09,139.734 2197.1,139.728 2197.11,139.722 2197.12,139.716 2197.13,139.709 2197.14,139.703 2197.14,139.697 2197.15,139.691 2197.16,139.685 2197.17,139.679 2197.18,139.673 2197.19,139.667 2197.2,139.661 2197.21,139.654 2197.22,139.648 2197.23,139.642 2197.24,139.636 2197.25,139.63 2197.25,139.624 2197.26,139.618 2197.27,139.612 2197.28,139.606 2197.29,139.599 2197.3,139.593 2197.31,139.587 2197.32,139.581 2197.33,139.575 2197.34,139.569 2197.35,139.563 2197.36,139.557 2197.37,139.551 2197.37,139.544 2197.38,139.538 2197.39,139.532 2197.4,139.526 2197.41,139.52 2197.42,139.514 2197.43,139.508 2197.44,139.502 2197.45,139.496 2197.46,139.489 2197.47,139.483 2197.48,139.477 2197.48,139.471 2197.49,139.465 2197.5,139.459 2197.51,139.453 2197.52,139.447 2197.53,139.441 2197.54,139.435 2197.55,139.428 2197.56,139.422 2197.57,139.416 2197.58,139.41 2197.59,139.404 2197.59,139.398 2197.6,139.392 2197.61,139.386 2197.62,139.38 2197.63,139.374 2197.64,139.367 2197.65,139.361 2197.66,139.355 2197.67,139.349 2197.68,139.343 2197.69,139.337 2197.7,139.331 2197.71,139.325 2197.71,139.319 2197.72,139.313 2197.73,139.307 2197.74,139.3 2197.75,139.294 2197.76,139.288 2197.77,139.282 2197.78,139.276 2197.79,139.27 2197.8,139.264 2197.81,139.258 2197.82,139.252 2197.82,139.246 2197.83,139.24 2197.84,139.233 2197.85,139.227 2197.86,139.221 2197.87,139.215 2197.88,139.209 2197.89,139.203 2197.9,139.197 2197.91,139.191 2197.92,139.185 2197.93,139.179 2197.93,139.173 2197.94,139.166 2197.95,139.16 2197.96,139.154 2197.97,139.148 2197.98,139.142 2197.99,139.136 2198,139.13 2198.01,139.124 2198.02,139.118 2198.03,139.112 2198.04,139.106 2198.05,139.1 2198.05,139.094 2198.06,139.087 2198.07,139.081 2198.08,139.075 2198.09,139.069 2198.1,139.063 2198.11,139.057 2198.12,139.051 2198.13,139.045 2198.14,139.039 2198.15,139.033 2198.16,139.027 2198.16,139.021 2198.17,139.015 2198.18,139.008 2198.19,139.002 2198.2,138.996 2198.21,138.99 2198.22,138.984 2198.23,138.978 2198.24,138.972 2198.25,138.966 2198.26,138.96 2198.27,138.954 2198.27,138.948 2198.28,138.942 2198.29,138.936 2198.3,138.929 2198.31,138.923 2198.32,138.917 2198.33,138.911 2198.34,138.905 2198.35,138.899 2198.36,138.893 2198.37,138.887 2198.38,138.881 2198.39,138.875 2198.39,138.869 2198.4,138.863 2198.41,138.857 2198.42,138.851 2198.43,138.845 2198.44,138.838 2198.45,138.832 2198.46,138.826 2198.47,138.82 2198.48,138.814 2198.49,138.808 2198.5,138.802 2198.5,138.796 2198.51,138.79 2198.52,138.784 2198.53,138.778 2198.54,138.772 2198.55,138.766 2198.56,138.76 2198.57,138.754 2198.58,138.748 2198.59,138.742 2198.6,138.735 2198.61,138.729 2198.61,138.723 2198.62,138.717 2198.63,138.711 2198.64,138.705 2198.65,138.699 2198.66,138.693 2198.67,138.687 2198.68,138.681 2198.69,138.675 2198.7,138.669 2198.71,138.663 2198.72,138.657 2198.73,138.651 2198.73,138.645 2198.74,138.639 2198.75,138.633 2198.76,138.626 2198.77,138.62 2198.78,138.614 2198.79,138.608 2198.8,138.602 2198.81,138.596 2198.82,138.59 2198.83,138.584 2198.84,138.578 2198.84,138.572 2198.85,138.566 2198.86,138.56 2198.87,138.554 2198.88,138.548 2198.89,138.542 2198.9,138.536 2198.91,138.53 2198.92,138.524 2198.93,138.518 2198.94,138.512 2198.95,138.506 2198.95,138.499 2198.96,138.493 2198.97,138.487 2198.98,138.481 2198.99,138.475 2199,138.469 2199.01,138.463 2199.02,138.457 2199.03,138.451 2199.04,138.445 2199.05,138.439 2199.06,138.433 2199.07,138.427 2199.07,138.421 2199.08,138.415 2199.09,138.409 2199.1,138.403 2199.11,138.397 2199.12,138.391 2199.13,138.385 2199.14,138.379 2199.15,138.373 2199.16,138.367 2199.17,138.361 2199.18,138.355 2199.18,138.349 2199.19,138.342 2199.2,138.336 2199.21,138.33 2199.22,138.324 2199.23,138.318 2199.24,138.312 2199.25,138.306 2199.26,138.3 2199.27,138.294 2199.28,138.288 2199.29,138.282 2199.29,138.276 2199.3,138.27 2199.31,138.264 2199.32,138.258 2199.33,138.252 2199.34,138.246 2199.35,138.24 2199.36,138.234 2199.37,138.228 2199.38,138.222 2199.39,138.216 2199.4,138.21 2199.41,138.204 2199.41,138.198 2199.42,138.192 2199.43,138.186 2199.44,138.18 2199.45,138.174 2199.46,138.168 2199.47,138.162 2199.48,138.156 2199.49,138.15 2199.5,138.144 2199.51,138.138 2199.52,138.132 2199.52,138.125 2199.53,138.119 2199.54,138.113 2199.55,138.107 2199.56,138.101 2199.57,138.095 2199.58,138.089 2199.59,138.083 2199.6,138.077 2199.61,138.071 2199.62,138.065 2199.63,138.059 2199.63,138.053 2199.64,138.047 2199.65,138.041 2199.66,138.035 2199.67,138.029 2199.68,138.023 2199.69,138.017 2199.7,138.011 2199.71,138.005 2199.72,137.999 2199.73,137.993 2199.74,137.987 2199.75,137.981 2199.75,137.975 2199.76,137.969 2199.77,137.963 2199.78,137.957 2199.79,137.951 2199.8,137.945 2199.81,137.939 2199.82,137.933 2199.83,137.927 2199.84,137.921 2199.85,137.915 2199.86,137.909 2199.86,137.903 2199.87,137.897 2199.88,137.891 2199.89,137.885 2199.9,137.879 2199.91,137.873 2199.92,137.867 2199.93,137.861 2199.94,137.855 2199.95,137.849 2199.96,137.843 2199.97,137.837 2199.97,137.831 2199.98,137.825 2199.99,137.819 2200,137.813 2200.01,137.807 2200.02,137.801 2200.03,137.795 2200.04,137.789 2200.05,137.783 2200.06,137.777 2200.07,137.771 2200.08,137.765 2200.09,137.759 2200.09,137.753 2200.1,137.747 2200.11,137.741 2200.12,137.735 2200.13,137.729 2200.14,137.723 2200.15,137.717 2200.16,137.711 2200.17,137.705 2200.18,137.699 2200.19,137.693 2200.2,137.687 2200.2,137.681 2200.21,137.675 2200.22,137.669 2200.23,137.663 2200.24,137.657 2200.25,137.651 2200.26,137.645 2200.27,137.639 2200.28,137.633 2200.29,137.627 2200.3,137.621 2200.31,137.615 2200.31,137.609 2200.32,137.603 2200.33,137.597 2200.34,137.591 2200.35,137.585 2200.36,137.579 2200.37,137.573 2200.38,137.567 2200.39,137.561 2200.4,137.555 2200.41,137.549 2200.42,137.543 2200.43,137.537 2200.43,137.531 2200.44,137.525 2200.45,137.519 2200.46,137.513 2200.47,137.507 2200.48,137.501 2200.49,137.495 2200.5,137.489 2200.51,137.483 2200.52,137.477 2200.53,137.471 2200.54,137.465 2200.54,137.459 2200.55,137.453 2200.56,137.447 2200.57,137.441 2200.58,137.435 2200.59,137.429 2200.6,137.423 2200.61,137.418 2200.62,137.412 2200.63,137.406 2200.64,137.4 2200.65,137.394 2200.65,137.388 2200.66,137.382 2200.67,137.376 2200.68,137.37 2200.69,137.364 2200.7,137.358 2200.71,137.352 2200.72,137.346 2200.73,137.34 2200.74,137.334 2200.75,137.328 2200.76,137.322 2200.77,137.316 2200.77,137.31 2200.78,137.304 2200.79,137.298 2200.8,137.292 2200.81,137.286 2200.82,137.28 2200.83,137.274 2200.84,137.268 2200.85,137.262 2200.86,137.256 2200.87,137.25 2200.88,137.244 2200.88,137.238 2200.89,137.232 2200.9,137.226 2200.91,137.22 2200.92,137.214 2200.93,137.208 2200.94,137.203 2200.95,137.197 2200.96,137.191 2200.97,137.185 2200.98,137.179 2200.99,137.173 2200.99,137.167 2201,137.161 2201.01,137.155 2201.02,137.149 2201.03,137.143 2201.04,137.137 2201.05,137.131 2201.06,137.125 2201.07,137.119 2201.08,137.113 2201.09,137.107 2201.1,137.101 2201.11,137.095 2201.11,137.089 2201.12,137.083 2201.13,137.077 2201.14,137.071 2201.15,137.065 2201.16,137.059 2201.17,137.053 2201.18,137.048 2201.19,137.042 2201.2,137.036 2201.21,137.03 2201.22,137.024 2201.22,137.018 2201.23,137.012 2201.24,137.006 2201.25,137 2201.26,136.994 2201.27,136.988 2201.28,136.982 2201.29,136.976 2201.3,136.97 2201.31,136.964 2201.32,136.958 2201.33,136.952 2201.33,136.946 2201.34,136.94 2201.35,136.934 2201.36,136.928 2201.37,136.923 2201.38,136.917 2201.39,136.911 2201.4,136.905 2201.41,136.899 2201.42,136.893 2201.43,136.887 2201.44,136.881 2201.45,136.875 2201.45,136.869 2201.46,136.863 2201.47,136.857 2201.48,136.851 2201.49,136.845 2201.5,136.839 2201.51,136.833 2201.52,136.827 2201.53,136.821 2201.54,136.815 2201.55,136.81 2201.56,136.804 2201.56,136.798 2201.57,136.792 2201.58,136.786 2201.59,136.78 2201.6,136.774 2201.61,136.768 2201.62,136.762 2201.63,136.756 2201.64,136.75 2201.65,136.744 2201.66,136.738 2201.67,136.732 2201.67,136.726 2201.68,136.72 2201.69,136.715 2201.7,136.709 2201.71,136.703 2201.72,136.697 2201.73,136.691 2201.74,136.685 2201.75,136.679 2201.76,136.673 2201.77,136.667 2201.78,136.661 2201.79,136.655 2201.79,136.649 2201.8,136.643 2201.81,136.637 2201.82,136.631 2201.83,136.625 2201.84,136.62 2201.85,136.614 2201.86,136.608 2201.87,136.602 2201.88,136.596 2201.89,136.59 2201.9,136.584 2201.9,136.578 2201.91,136.572 2201.92,136.566 2201.93,136.56 2201.94,136.554 2201.95,136.548 2201.96,136.542 2201.97,136.537 2201.98,136.531 2201.99,136.525 2202,136.519 2202.01,136.513 2202.01,136.507 2202.02,136.501 2202.03,136.495 2202.04,136.489 2202.05,136.483 2202.06,136.477 2202.07,136.471 2202.08,136.465 2202.09,136.46 2202.1,136.454 2202.11,136.448 2202.12,136.442 2202.13,136.436 2202.13,136.43 2202.14,136.424 2202.15,136.418 2202.16,136.412 2202.17,136.406 2202.18,136.4 2202.19,136.394 2202.2,136.388 2202.21,136.383 2202.22,136.377 2202.23,136.371 2202.24,136.365 2202.24,136.359 2202.25,136.353 2202.26,136.347 2202.27,136.341 2202.28,136.335 2202.29,136.329 2202.3,136.323 2202.31,136.318 2202.32,136.312 2202.33,136.306 2202.34,136.3 2202.35,136.294 2202.35,136.288 2202.36,136.282 2202.37,136.276 2202.38,136.27 2202.39,136.264 2202.4,136.258 2202.41,136.252 2202.42,136.247 2202.43,136.241 2202.44,136.235 2202.45,136.229 2202.46,136.223 2202.47,136.217 2202.47,136.211 2202.48,136.205 2202.49,136.199 2202.5,136.193 2202.51,136.187 2202.52,136.182 2202.53,136.176 2202.54,136.17 2202.55,136.164 2202.56,136.158 2202.57,136.152 2202.58,136.146 2202.58,136.14 2202.59,136.134 2202.6,136.128 2202.61,136.123 2202.62,136.117 2202.63,136.111 2202.64,136.105 2202.65,136.099 2202.66,136.093 2202.67,136.087 2202.68,136.081 2202.69,136.075 2202.69,136.069 2202.7,136.064 2202.71,136.058 2202.72,136.052 2202.73,136.046 2202.74,136.04 2202.75,136.034 2202.76,136.028 2202.77,136.022 2202.78,136.016 2202.79,136.01 2202.8,136.005 2202.81,135.999 2202.81,135.993 2202.82,135.987 2202.83,135.981 2202.84,135.975 2202.85,135.969 2202.86,135.963 2202.87,135.957 2202.88,135.952 2202.89,135.946 2202.9,135.94 2202.91,135.934 2202.92,135.928 2202.92,135.922 2202.93,135.916 2202.94,135.91 2202.95,135.904 2202.96,135.899 2202.97,135.893 2202.98,135.887 2202.99,135.881 2203,135.875 2203.01,135.869 2203.02,135.863 2203.03,135.857 2203.03,135.851 2203.04,135.846 2203.05,135.84 2203.06,135.834 2203.07,135.828 2203.08,135.822 2203.09,135.816 2203.1,135.81 2203.11,135.804 2203.12,135.798 2203.13,135.793 2203.14,135.787 2203.15,135.781 2203.15,135.775 2203.16,135.769 2203.17,135.763 2203.18,135.757 2203.19,135.751 2203.2,135.746 2203.21,135.74 2203.22,135.734 2203.23,135.728 2203.24,135.722 2203.25,135.716 2203.26,135.71 2203.26,135.704 2203.27,135.698 2203.28,135.693 2203.29,135.687 2203.3,135.681 2203.31,135.675 2203.32,135.669 2203.33,135.663 2203.34,135.657 2203.35,135.651 2203.36,135.646 2203.37,135.64 2203.37,135.634 2203.38,135.628 2203.39,135.622 2203.4,135.616 2203.41,135.61 2203.42,135.604 2203.43,135.599 2203.44,135.593 2203.45,135.587 2203.46,135.581 2203.47,135.575 2203.48,135.569 2203.49,135.563 2203.49,135.558 2203.5,135.552 2203.51,135.546 2203.52,135.54 2203.53,135.534 2203.54,135.528 2203.55,135.522 2203.56,135.516 2203.57,135.511 2203.58,135.505 2203.59,135.499 2203.6,135.493 2203.6,135.487 2203.61,135.481 2203.62,135.475 2203.63,135.47 2203.64,135.464 2203.65,135.458 2203.66,135.452 2203.67,135.446 2203.68,135.44 2203.69,135.434 2203.7,135.428 2203.71,135.423 2203.71,135.417 2203.72,135.411 2203.73,135.405 2203.74,135.399 2203.75,135.393 2203.76,135.387 2203.77,135.382 2203.78,135.376 2203.79,135.37 2203.8,135.364 2203.81,135.358 2203.82,135.352 2203.83,135.346 2203.83,135.341 2203.84,135.335 2203.85,135.329 2203.86,135.323 2203.87,135.317 2203.88,135.311 2203.89,135.305 2203.9,135.3 2203.91,135.294 2203.92,135.288 2203.93,135.282 2203.94,135.276 2203.94,135.27 2203.95,135.264 2203.96,135.259 2203.97,135.253 2203.98,135.247 2203.99,135.241 2204,135.235 2204.01,135.229 2204.02,135.224 2204.03,135.218 2204.04,135.212 2204.05,135.206 2204.05,135.2 2204.06,135.194 2204.07,135.188 2204.08,135.183 2204.09,135.177 2204.1,135.171 2204.11,135.165 2204.12,135.159 2204.13,135.153 2204.14,135.147 2204.15,135.142 2204.16,135.136 2204.17,135.13 2204.17,135.124 2204.18,135.118 2204.19,135.112 2204.2,135.107 2204.21,135.101 2204.22,135.095 2204.23,135.089 2204.24,135.083 2204.25,135.077 2204.26,135.072 2204.27,135.066 2204.28,135.06 2204.28,135.054 2204.29,135.048 2204.3,135.042 2204.31,135.036 2204.32,135.031 2204.33,135.025 2204.34,135.019 2204.35,135.013 2204.36,135.007 2204.37,135.001 2204.38,134.996 2204.39,134.99 2204.39,134.984 2204.4,134.978 2204.41,134.972 2204.42,134.966 2204.43,134.961 2204.44,134.955 2204.45,134.949 2204.46,134.943 2204.47,134.937 2204.48,134.931 2204.49,134.926 2204.5,134.92 2204.51,134.914 2204.51,134.908 2204.52,134.902 2204.53,134.896 2204.54,134.891 2204.55,134.885 2204.56,134.879 2204.57,134.873 2204.58,134.867 2204.59,134.861 2204.6,134.856 2204.61,134.85 2204.62,134.844 2204.62,134.838 2204.63,134.832 2204.64,134.826 2204.65,134.821 2204.66,134.815 2204.67,134.809 2204.68,134.803 2204.69,134.797 2204.7,134.792 2204.71,134.786 2204.72,134.78 2204.73,134.774 2204.73,134.768 2204.74,134.762 2204.75,134.757 2204.76,134.751 2204.77,134.745 2204.78,134.739 2204.79,134.733 2204.8,134.727 2204.81,134.722 2204.82,134.716 2204.83,134.71 2204.84,134.704 2204.85,134.698 2204.85,134.693 2204.86,134.687 2204.87,134.681 2204.88,134.675 2204.89,134.669 2204.9,134.663 2204.91,134.658 2204.92,134.652 2204.93,134.646 2204.94,134.64 2204.95,134.634 2204.96,134.629 2204.96,134.623 2204.97,134.617 2204.98,134.611 2204.99,134.605 2205,134.599 2205.01,134.594 2205.02,134.588 2205.03,134.582 2205.04,134.576 2205.05,134.57 2205.06,134.565 2205.07,134.559 2205.07,134.553 2205.08,134.547 2205.09,134.541 2205.1,134.536 2205.11,134.53 2205.12,134.524 2205.13,134.518 2205.14,134.512 2205.15,134.506 2205.16,134.501 2205.17,134.495 2205.18,134.489 2205.19,134.483 2205.19,134.477 2205.2,134.472 2205.21,134.466 2205.22,134.46 2205.23,134.454 2205.24,134.448 2205.25,134.443 2205.26,134.437 2205.27,134.431 2205.28,134.425 2205.29,134.419 2205.3,134.414 2205.3,134.408 2205.31,134.402 2205.32,134.396 2205.33,134.39 2205.34,134.385 2205.35,134.379 2205.36,134.373 2205.37,134.367 2205.38,134.361 2205.39,134.356 2205.4,134.35 2205.41,134.344 2205.41,134.338 2205.42,134.332 2205.43,134.327 2205.44,134.321 2205.45,134.315 2205.46,134.309 2205.47,134.303 2205.48,134.298 2205.49,134.292 2205.5,134.286 2205.51,134.28 2205.52,134.274 2205.53,134.269 2205.53,134.263 2205.54,134.257 2205.55,134.251 2205.56,134.245 2205.57,134.24 2205.58,134.234 2205.59,134.228 2205.6,134.222 2205.61,134.216 2205.62,134.211 2205.63,134.205 2205.64,134.199 2205.64,134.193 2205.65,134.187 2205.66,134.182 2205.67,134.176 2205.68,134.17 2205.69,134.164 2205.7,134.159 2205.71,134.153 2205.72,134.147 2205.73,134.141 2205.74,134.135 2205.75,134.13 2205.75,134.124 2205.76,134.118 2205.77,134.112 2205.78,134.106 2205.79,134.101 2205.8,134.095 2205.81,134.089 2205.82,134.083 2205.83,134.077 2205.84,134.072 2205.85,134.066 2205.86,134.06 2205.87,134.054 2205.87,134.049 2205.88,134.043 2205.89,134.037 2205.9,134.031 2205.91,134.025 2205.92,134.02 2205.93,134.014 2205.94,134.008 2205.95,134.002 2205.96,133.997 2205.97,133.991 2205.98,133.985 2205.98,133.979 2205.99,133.973 2206,133.968 2206.01,133.962 2206.02,133.956 2206.03,133.95 2206.04,133.945 2206.05,133.939 2206.06,133.933 2206.07,133.927 2206.08,133.921 2206.09,133.916 2206.09,133.91 2206.1,133.904 2206.11,133.898 2206.12,133.893 2206.13,133.887 2206.14,133.881 2206.15,133.875 2206.16,133.869 2206.17,133.864 2206.18,133.858 2206.19,133.852 2206.2,133.846 2206.21,133.841 2206.21,133.835 2206.22,133.829 2206.23,133.823 2206.24,133.818 2206.25,133.812 2206.26,133.806 2206.27,133.8 2206.28,133.794 2206.29,133.789 2206.3,133.783 2206.31,133.777 2206.32,133.771 2206.32,133.766 2206.33,133.76 2206.34,133.754 2206.35,133.748 2206.36,133.743 2206.37,133.737 2206.38,133.731 2206.39,133.725 2206.4,133.719 2206.41,133.714 2206.42,133.708 2206.43,133.702 2206.43,133.696 2206.44,133.691 2206.45,133.685 2206.46,133.679 2206.47,133.673 2206.48,133.668 2206.49,133.662 2206.5,133.656 2206.51,133.65 2206.52,133.645 2206.53,133.639 2206.54,133.633 2206.55,133.627 2206.55,133.622 2206.56,133.616 2206.57,133.61 2206.58,133.604 2206.59,133.598 2206.6,133.593 2206.61,133.587 2206.62,133.581 2206.63,133.575 2206.64,133.57 2206.65,133.564 2206.66,133.558 2206.66,133.552 2206.67,133.547 2206.68,133.541 2206.69,133.535 2206.7,133.529 2206.71,133.524 2206.72,133.518 2206.73,133.512 2206.74,133.506 2206.75,133.501 2206.76,133.495 2206.77,133.489 2206.77,133.483 2206.78,133.478 2206.79,133.472 2206.8,133.466 2206.81,133.46 2206.82,133.455 2206.83,133.449 2206.84,133.443 2206.85,133.437 2206.86,133.432 2206.87,133.426 2206.88,133.42 2206.89,133.414 2206.89,133.409 2206.9,133.403 2206.91,133.397 2206.92,133.391 2206.93,133.386 2206.94,133.38 2206.95,133.374 2206.96,133.368 2206.97,133.363 2206.98,133.357 2206.99,133.351 2207,133.345 2207,133.34 2207.01,133.334 2207.02,133.328 2207.03,133.322 2207.04,133.317 2207.05,133.311 2207.06,133.305 2207.07,133.3 2207.08,133.294 2207.09,133.288 2207.1,133.282 2207.11,133.277 2207.11,133.271 2207.12,133.265 2207.13,133.259 2207.14,133.254 2207.15,133.248 2207.16,133.242 2207.17,133.236 2207.18,133.231 2207.19,133.225 2207.2,133.219 2207.21,133.213 2207.22,133.208 2207.23,133.202 2207.23,133.196 2207.24,133.19 2207.25,133.185 2207.26,133.179 2207.27,133.173 2207.28,133.168 2207.29,133.162 2207.3,133.156 2207.31,133.15 2207.32,133.145 2207.33,133.139 2207.34,133.133 2207.34,133.127 2207.35,133.122 2207.36,133.116 2207.37,133.11 2207.38,133.105 2207.39,133.099 2207.4,133.093 2207.41,133.087 2207.42,133.082 2207.43,133.076 2207.44,133.07 2207.45,133.064 2207.45,133.059 2207.46,133.053 2207.47,133.047 2207.48,133.041 2207.49,133.036 2207.5,133.03 2207.51,133.024 2207.52,133.019 2207.53,133.013 2207.54,133.007 2207.55,133.001 2207.56,132.996 2207.57,132.99 2207.57,132.984 2207.58,132.979 2207.59,132.973 2207.6,132.967 2207.61,132.961 2207.62,132.956 2207.63,132.95 2207.64,132.944 2207.65,132.938 2207.66,132.933 2207.67,132.927 2207.68,132.921 2207.68,132.916 2207.69,132.91 2207.7,132.904 2207.71,132.898 2207.72,132.893 2207.73,132.887 2207.74,132.881 2207.75,132.876 2207.76,132.87 2207.77,132.864 2207.78,132.858 2207.79,132.853 2207.79,132.847 2207.8,132.841 2207.81,132.836 2207.82,132.83 2207.83,132.824 2207.84,132.818 2207.85,132.813 2207.86,132.807 2207.87,132.801 2207.88,132.796 2207.89,132.79 2207.9,132.784 2207.91,132.778 2207.91,132.773 2207.92,132.767 2207.93,132.761 2207.94,132.756 2207.95,132.75 2207.96,132.744 2207.97,132.738 2207.98,132.733 2207.99,132.727 2208,132.721 2208.01,132.716 2208.02,132.71 2208.02,132.704 2208.03,132.698 2208.04,132.693 2208.05,132.687 2208.06,132.681 2208.07,132.676 2208.08,132.67 2208.09,132.664 2208.1,132.659 2208.11,132.653 2208.12,132.647 2208.13,132.641 2208.13,132.636 2208.14,132.63 2208.15,132.624 2208.16,132.619 2208.17,132.613 2208.18,132.607 2208.19,132.601 2208.2,132.596 2208.21,132.59 2208.22,132.584 2208.23,132.579 2208.24,132.573 2208.25,132.567 2208.25,132.562 2208.26,132.556 2208.27,132.55 2208.28,132.544 2208.29,132.539 2208.3,132.533 2208.31,132.527 2208.32,132.522 2208.33,132.516 2208.34,132.51 2208.35,132.505 2208.36,132.499 2208.36,132.493 2208.37,132.488 2208.38,132.482 2208.39,132.476 2208.4,132.47 2208.41,132.465 2208.42,132.459 2208.43,132.453 2208.44,132.448 2208.45,132.442 2208.46,132.436 2208.47,132.431 2208.47,132.425 2208.48,132.419 2208.49,132.413 2208.5,132.408 2208.51,132.402 2208.52,132.396 2208.53,132.391 2208.54,132.385 2208.55,132.379 2208.56,132.374 2208.57,132.368 2208.58,132.362 2208.59,132.357 2208.59,132.351 2208.6,132.345 2208.61,132.34 2208.62,132.334 2208.63,132.328 2208.64,132.322 2208.65,132.317 2208.66,132.311 2208.67,132.305 2208.68,132.3 2208.69,132.294 2208.7,132.288 2208.7,132.283 2208.71,132.277 2208.72,132.271 2208.73,132.266 2208.74,132.26 2208.75,132.254 2208.76,132.249 2208.77,132.243 2208.78,132.237 2208.79,132.232 2208.8,132.226 2208.81,132.22 2208.81,132.214 2208.82,132.209 2208.83,132.203 2208.84,132.197 2208.85,132.192 2208.86,132.186 2208.87,132.18 2208.88,132.175 2208.89,132.169 2208.9,132.163 2208.91,132.158 2208.92,132.152 2208.93,132.146 2208.93,132.141 2208.94,132.135 2208.95,132.129 2208.96,132.124 2208.97,132.118 2208.98,132.112 2208.99,132.107 2209,132.101 2209.01,132.095 2209.02,132.09 2209.03,132.084 2209.04,132.078 2209.04,132.073 2209.05,132.067 2209.06,132.061 2209.07,132.056 2209.08,132.05 2209.09,132.044 2209.1,132.038 2209.11,132.033 2209.12,132.027 2209.13,132.021 2209.14,132.016 2209.15,132.01 2209.15,132.004 2209.16,131.999 2209.17,131.993 2209.18,131.987 2209.19,131.982 2209.2,131.976 2209.21,131.97 2209.22,131.965 2209.23,131.959 2209.24,131.953 2209.25,131.948 2209.26,131.942 2209.27,131.936 2209.27,131.931 2209.28,131.925 2209.29,131.919 2209.3,131.914 2209.31,131.908 2209.32,131.902 2209.33,131.897 2209.34,131.891 2209.35,131.885 2209.36,131.88 2209.37,131.874 2209.38,131.868 2209.38,131.863 2209.39,131.857 2209.4,131.852 2209.41,131.846 2209.42,131.84 2209.43,131.835 2209.44,131.829 2209.45,131.823 2209.46,131.818 2209.47,131.812 2209.48,131.806 2209.49,131.801 2209.49,131.795 2209.5,131.789 2209.51,131.784 2209.52,131.778 2209.53,131.772 2209.54,131.767 2209.55,131.761 2209.56,131.755 2209.57,131.75 2209.58,131.744 2209.59,131.738 2209.6,131.733 2209.61,131.727 2209.61,131.721 2209.62,131.716 2209.63,131.71 2209.64,131.704 2209.65,131.699 2209.66,131.693 2209.67,131.687 2209.68,131.682 2209.69,131.676 2209.7,131.671 2209.71,131.665 2209.72,131.659 2209.72,131.654 2209.73,131.648 2209.74,131.642 2209.75,131.637 2209.76,131.631 2209.77,131.625 2209.78,131.62 2209.79,131.614 2209.8,131.608 2209.81,131.603 2209.82,131.597 2209.83,131.591 2209.83,131.586 2209.84,131.58 2209.85,131.574 2209.86,131.569 2209.87,131.563 2209.88,131.558 2209.89,131.552 2209.9,131.546 2209.91,131.541 2209.92,131.535 2209.93,131.529 2209.94,131.524 2209.95,131.518 2209.95,131.512 2209.96,131.507 2209.97,131.501 2209.98,131.495 2209.99,131.49 2210,131.484 2210.01,131.479 2210.02,131.473 2210.03,131.467 2210.04,131.462 2210.05,131.456 2210.06,131.45 2210.06,131.445 2210.07,131.439 2210.08,131.433 2210.09,131.428 2210.1,131.422 2210.11,131.417 2210.12,131.411 2210.13,131.405 2210.14,131.4 2210.15,131.394 2210.16,131.388 2210.17,131.383 2210.17,131.377 2210.18,131.371 2210.19,131.366 2210.2,131.36 2210.21,131.355 2210.22,131.349 2210.23,131.343 2210.24,131.338 2210.25,131.332 2210.26,131.326 2210.27,131.321 2210.28,131.315 2210.29,131.309 2210.29,131.304 2210.3,131.298 2210.31,131.293 2210.32,131.287 2210.33,131.281 2210.34,131.276 2210.35,131.27 2210.36,131.264 2210.37,131.259 2210.38,131.253 2210.39,131.248 2210.4,131.242 2210.4,131.236 2210.41,131.231 2210.42,131.225 2210.43,131.219 2210.44,131.214 2210.45,131.208 2210.46,131.203 2210.47,131.197 2210.48,131.191 2210.49,131.186 2210.5,131.18 2210.51,131.174 2210.51,131.169 2210.52,131.163 2210.53,131.158 2210.54,131.152 2210.55,131.146 2210.56,131.141 2210.57,131.135 2210.58,131.129 2210.59,131.124 2210.6,131.118 2210.61,131.113 2210.62,131.107 2210.63,131.101 2210.63,131.096 2210.64,131.09 2210.65,131.084 2210.66,131.079 2210.67,131.073 2210.68,131.068 2210.69,131.062 2210.7,131.056 2210.71,131.051 2210.72,131.045 2210.73,131.039 2210.74,131.034 2210.74,131.028 2210.75,131.023 2210.76,131.017 2210.77,131.011 2210.78,131.006 2210.79,131 2210.8,130.995 2210.81,130.989 2210.82,130.983 2210.83,130.978 2210.84,130.972 2210.85,130.966 2210.85,130.961 2210.86,130.955 2210.87,130.95 2210.88,130.944 2210.89,130.938 2210.9,130.933 2210.91,130.927 2210.92,130.922 2210.93,130.916 2210.94,130.91 2210.95,130.905 2210.96,130.899 2210.97,130.894 2210.97,130.888 2210.98,130.882 2210.99,130.877 2211,130.871 2211.01,130.866 2211.02,130.86 2211.03,130.854 2211.04,130.849 2211.05,130.843 2211.06,130.837 2211.07,130.832 2211.08,130.826 2211.08,130.821 2211.09,130.815 2211.1,130.809 2211.11,130.804 2211.12,130.798 2211.13,130.793 2211.14,130.787 2211.15,130.781 2211.16,130.776 2211.17,130.77 2211.18,130.765 2211.19,130.759 2211.19,130.753 2211.2,130.748 2211.21,130.742 2211.22,130.737 2211.23,130.731 2211.24,130.725 2211.25,130.72 2211.26,130.714 2211.27,130.709 2211.28,130.703 2211.29,130.697 2211.3,130.692 2211.31,130.686 2211.31,130.681 2211.32,130.675 2211.33,130.669 2211.34,130.664 2211.35,130.658 2211.36,130.653 2211.37,130.647 2211.38,130.641 2211.39,130.636 2211.4,130.63 2211.41,130.625 2211.42,130.619 2211.42,130.613 2211.43,130.608 2211.44,130.602 2211.45,130.597 2211.46,130.591 2211.47,130.585 2211.48,130.58 2211.49,130.574 2211.5,130.569 2211.51,130.563 2211.52,130.558 2211.53,130.552 2211.53,130.546 2211.54,130.541 2211.55,130.535 2211.56,130.53 2211.57,130.524 2211.58,130.518 2211.59,130.513 2211.6,130.507 2211.61,130.502 2211.62,130.496 2211.63,130.49 2211.64,130.485 2211.65,130.479 2211.65,130.474 2211.66,130.468 2211.67,130.463 2211.68,130.457 2211.69,130.451 2211.7,130.446 2211.71,130.44 2211.72,130.435 2211.73,130.429 2211.74,130.423 2211.75,130.418 2211.76,130.412 2211.76,130.407 2211.77,130.401 2211.78,130.396 2211.79,130.39 2211.8,130.384 2211.81,130.379 2211.82,130.373 2211.83,130.368 2211.84,130.362 2211.85,130.356 2211.86,130.351 2211.87,130.345 2211.87,130.34 2211.88,130.334 2211.89,130.329 2211.9,130.323 2211.91,130.317 2211.92,130.312 2211.93,130.306 2211.94,130.301 2211.95,130.295 2211.96,130.29 2211.97,130.284 2211.98,130.278 2211.99,130.273 2211.99,130.267 2212,130.262 2212.01,130.256 2212.02,130.25 2212.03,130.245 2212.04,130.239 2212.05,130.234 2212.06,130.228 2212.07,130.223 2212.08,130.217 2212.09,130.211 2212.1,130.206 2212.1,130.2 2212.11,130.195 2212.12,130.189 2212.13,130.184 2212.14,130.178 2212.15,130.172 2212.16,130.167 2212.17,130.161 2212.18,130.156 2212.19,130.15 2212.2,130.145 2212.21,130.139 2212.21,130.133 2212.22,130.128 2212.23,130.122 2212.24,130.117 2212.25,130.111 2212.26,130.106 2212.27,130.1 2212.28,130.094 2212.29,130.089 2212.3,130.083 2212.31,130.078 2212.32,130.072 2212.33,130.067 2212.33,130.061 2212.34,130.056 2212.35,130.05 2212.36,130.044 2212.37,130.039 2212.38,130.033 2212.39,130.028 2212.4,130.022 2212.41,130.017 2212.42,130.011 2212.43,130.005 2212.44,130 2212.44,129.994 2212.45,129.989 2212.46,129.983 2212.47,129.978 2212.48,129.972 2212.49,129.967 2212.5,129.961 2212.51,129.955 2212.52,129.95 2212.53,129.944 2212.54,129.939 2212.55,129.933 2212.55,129.928 2212.56,129.922 2212.57,129.917 2212.58,129.911 2212.59,129.905 2212.6,129.9 2212.61,129.894 2212.62,129.889 2212.63,129.883 2212.64,129.878 2212.65,129.872 2212.66,129.867 2212.67,129.861 2212.67,129.855 2212.68,129.85 2212.69,129.844 2212.7,129.839 2212.71,129.833 2212.72,129.828 2212.73,129.822 2212.74,129.817 2212.75,129.811 2212.76,129.805 2212.77,129.8 2212.78,129.794 2212.78,129.789 2212.79,129.783 2212.8,129.778 2212.81,129.772 2212.82,129.767 2212.83,129.761 2212.84,129.755 2212.85,129.75 2212.86,129.744 2212.87,129.739 2212.88,129.733 2212.89,129.728 2212.89,129.722 2212.9,129.717 2212.91,129.711 2212.92,129.706 2212.93,129.7 2212.94,129.694 2212.95,129.689 2212.96,129.683 2212.97,129.678 2212.98,129.672 2212.99,129.667 2213,129.661 2213.01,129.656 2213.01,129.65 2213.02,129.645 2213.03,129.639 2213.04,129.633 2213.05,129.628 2213.06,129.622 2213.07,129.617 2213.08,129.611 2213.09,129.606 2213.1,129.6 2213.11,129.595 2213.12,129.589 2213.12,129.584 2213.13,129.578 2213.14,129.573 2213.15,129.567 2213.16,129.561 2213.17,129.556 2213.18,129.55 2213.19,129.545 2213.2,129.539 2213.21,129.534 2213.22,129.528 2213.23,129.523 2213.23,129.517 2213.24,129.512 2213.25,129.506 2213.26,129.501 2213.27,129.495 2213.28,129.489 2213.29,129.484 2213.3,129.478 2213.31,129.473 2213.32,129.467 2213.33,129.462 2213.34,129.456 2213.35,129.451 2213.35,129.445 2213.36,129.44 2213.37,129.434 2213.38,129.429 2213.39,129.423 2213.4,129.418 2213.41,129.412 2213.42,129.406 2213.43,129.401 2213.44,129.395 2213.45,129.39 2213.46,129.384 2213.46,129.379 2213.47,129.373 2213.48,129.368 2213.49,129.362 2213.5,129.357 2213.51,129.351 2213.52,129.346 2213.53,129.34 2213.54,129.335 2213.55,129.329 2213.56,129.324 2213.57,129.318 2213.57,129.313 2213.58,129.307 2213.59,129.301 2213.6,129.296 2213.61,129.29 2213.62,129.285 2213.63,129.279 2213.64,129.274 2213.65,129.268 2213.66,129.263 2213.67,129.257 2213.68,129.252 2213.69,129.246 2213.69,129.241 2213.7,129.235 2213.71,129.23 2213.72,129.224 2213.73,129.219 2213.74,129.213 2213.75,129.208 2213.76,129.202 2213.77,129.197 2213.78,129.191 2213.79,129.185 2213.8,129.18 2213.8,129.174 2213.81,129.169 2213.82,129.163 2213.83,129.158 2213.84,129.152 2213.85,129.147 2213.86,129.141 2213.87,129.136 2213.88,129.13 2213.89,129.125 2213.9,129.119 2213.91,129.114 2213.91,129.108 2213.92,129.103 2213.93,129.097 2213.94,129.092 2213.95,129.086 2213.96,129.081 2213.97,129.075 2213.98,129.07 2213.99,129.064 2214,129.059 2214.01,129.053 2214.02,129.048 2214.03,129.042 2214.03,129.037 2214.04,129.031 2214.05,129.026 2214.06,129.02 2214.07,129.015 2214.08,129.009 2214.09,129.004 2214.1,128.998 2214.11,128.993 2214.12,128.987 2214.13,128.981 2214.14,128.976 2214.14,128.97 2214.15,128.965 2214.16,128.959 2214.17,128.954 2214.18,128.948 2214.19,128.943 2214.2,128.937 2214.21,128.932 2214.22,128.926 2214.23,128.921 2214.24,128.915 2214.25,128.91 2214.25,128.904 2214.26,128.899 2214.27,128.893 2214.28,128.888 2214.29,128.882 2214.3,128.877 2214.31,128.871 2214.32,128.866 2214.33,128.86 2214.34,128.855 2214.35,128.849 2214.36,128.844 2214.37,128.838 2214.37,128.833 2214.38,128.827 2214.39,128.822 2214.4,128.816 2214.41,128.811 2214.42,128.805 2214.43,128.8 2214.44,128.794 2214.45,128.789 2214.46,128.783 2214.47,128.778 2214.48,128.772 2214.48,128.767 2214.49,128.761 2214.5,128.756 2214.51,128.75 2214.52,128.745 2214.53,128.739 2214.54,128.734 2214.55,128.728 2214.56,128.723 2214.57,128.717 2214.58,128.712 2214.59,128.706 2214.59,128.701 2214.6,128.695 2214.61,128.69 2214.62,128.684 2214.63,128.679 2214.64,128.673 2214.65,128.668 2214.66,128.662 2214.67,128.657 2214.68,128.652 2214.69,128.646 2214.7,128.641 2214.71,128.635 2214.71,128.63 2214.72,128.624 2214.73,128.619 2214.74,128.613 2214.75,128.608 2214.76,128.602 2214.77,128.597 2214.78,128.591 2214.79,128.586 2214.8,128.58 2214.81,128.575 2214.82,128.569 2214.82,128.564 2214.83,128.558 2214.84,128.553 2214.85,128.547 2214.86,128.542 2214.87,128.536 2214.88,128.531 2214.89,128.525 2214.9,128.52 2214.91,128.514 2214.92,128.509 2214.93,128.503 2214.93,128.498 2214.94,128.492 2214.95,128.487 2214.96,128.481 2214.97,128.476 2214.98,128.47 2214.99,128.465 2215,128.46 2215.01,128.454 2215.02,128.449 2215.03,128.443 2215.04,128.438 2215.05,128.432 2215.05,128.427 2215.06,128.421 2215.07,128.416 2215.08,128.41 2215.09,128.405 2215.1,128.399 2215.11,128.394 2215.12,128.388 2215.13,128.383 2215.14,128.377 2215.15,128.372 2215.16,128.366 2215.16,128.361 2215.17,128.355 2215.18,128.35 2215.19,128.344 2215.2,128.339 2215.21,128.334 2215.22,128.328 2215.23,128.323 2215.24,128.317 2215.25,128.312 2215.26,128.306 2215.27,128.301 2215.27,128.295 2215.28,128.29 2215.29,128.284 2215.3,128.279 2215.31,128.273 2215.32,128.268 2215.33,128.262 2215.34,128.257 2215.35,128.251 2215.36,128.246 2215.37,128.24 2215.38,128.235 2215.39,128.23 2215.39,128.224 2215.4,128.219 2215.41,128.213 2215.42,128.208 2215.43,128.202 2215.44,128.197 2215.45,128.191 2215.46,128.186 2215.47,128.18 2215.48,128.175 2215.49,128.169 2215.5,128.164 2215.5,128.158 2215.51,128.153 2215.52,128.148 2215.53,128.142 2215.54,128.137 2215.55,128.131 2215.56,128.126 2215.57,128.12 2215.58,128.115 2215.59,128.109 2215.6,128.104 2215.61,128.098 2215.61,128.093 2215.62,128.087 2215.63,128.082 2215.64,128.077 2215.65,128.071 2215.66,128.066 2215.67,128.06 2215.68,128.055 2215.69,128.049 2215.7,128.044 2215.71,128.038 2215.72,128.033 2215.73,128.027 2215.73,128.022 2215.74,128.016 2215.75,128.011 2215.76,128.006 2215.77,128 2215.78,127.995 2215.79,127.989 2215.8,127.984 2215.81,127.978 2215.82,127.973 2215.83,127.967 2215.84,127.962 2215.84,127.956 2215.85,127.951 2215.86,127.946 2215.87,127.94 2215.88,127.935 2215.89,127.929 2215.9,127.924 2215.91,127.918 2215.92,127.913 2215.93,127.907 2215.94,127.902 2215.95,127.896 2215.95,127.891 2215.96,127.886 2215.97,127.88 2215.98,127.875 2215.99,127.869 2216,127.864 2216.01,127.858 2216.02,127.853 2216.03,127.847 2216.04,127.842 2216.05,127.836 2216.06,127.831 2216.07,127.826 2216.07,127.82 2216.08,127.815 2216.09,127.809 2216.1,127.804 2216.11,127.798 2216.12,127.793 2216.13,127.787 2216.14,127.782 2216.15,127.777 2216.16,127.771 2216.17,127.766 2216.18,127.76 2216.18,127.755 2216.19,127.749 2216.2,127.744 2216.21,127.738 2216.22,127.733 2216.23,127.728 2216.24,127.722 2216.25,127.717 2216.26,127.711 2216.27,127.706 2216.28,127.7 2216.29,127.695 2216.29,127.689 2216.3,127.684 2216.31,127.679 2216.32,127.673 2216.33,127.668 2216.34,127.662 2216.35,127.657 2216.36,127.651 2216.37,127.646 2216.38,127.64 2216.39,127.635 2216.4,127.63 2216.41,127.624 2216.41,127.619 2216.42,127.613 2216.43,127.608 2216.44,127.602 2216.45,127.597 2216.46,127.592 2216.47,127.586 2216.48,127.581 2216.49,127.575 2216.5,127.57 2216.51,127.564 2216.52,127.559 2216.52,127.553 2216.53,127.548 2216.54,127.543 2216.55,127.537 2216.56,127.532 2216.57,127.526 2216.58,127.521 2216.59,127.515 2216.6,127.51 2216.61,127.505 2216.62,127.499 2216.63,127.494 2216.63,127.488 2216.64,127.483 2216.65,127.477 2216.66,127.472 2216.67,127.467 2216.68,127.461 2216.69,127.456 2216.7,127.45 2216.71,127.445 2216.72,127.439 2216.73,127.434 2216.74,127.429 2216.75,127.423 2216.75,127.418 2216.76,127.412 2216.77,127.407 2216.78,127.401 2216.79,127.396 2216.8,127.391 2216.81,127.385 2216.82,127.38 2216.83,127.374 2216.84,127.369 2216.85,127.363 2216.86,127.358 2216.86,127.353 2216.87,127.347 2216.88,127.342 2216.89,127.336 2216.9,127.331 2216.91,127.325 2216.92,127.32 2216.93,127.315 2216.94,127.309 2216.95,127.304 2216.96,127.298 2216.97,127.293 2216.97,127.287 2216.98,127.282 2216.99,127.277 2217,127.271 2217.01,127.266 2217.02,127.26 2217.03,127.255 2217.04,127.25 2217.05,127.244 2217.06,127.239 2217.07,127.233 2217.08,127.228 2217.09,127.222 2217.09,127.217 2217.1,127.212 2217.11,127.206 2217.12,127.201 2217.13,127.195 2217.14,127.19 2217.15,127.185 2217.16,127.179 2217.17,127.174 2217.18,127.168 2217.19,127.163 2217.2,127.157 2217.2,127.152 2217.21,127.147 2217.22,127.141 2217.23,127.136 2217.24,127.13 2217.25,127.125 2217.26,127.12 2217.27,127.114 2217.28,127.109 2217.29,127.103 2217.3,127.098 2217.31,127.093 2217.31,127.087 2217.32,127.082 2217.33,127.076 2217.34,127.071 2217.35,127.065 2217.36,127.06 2217.37,127.055 2217.38,127.049 2217.39,127.044 2217.4,127.038 2217.41,127.033 2217.42,127.028 2217.43,127.022 2217.43,127.017 2217.44,127.011 2217.45,127.006 2217.46,127.001 2217.47,126.995 2217.48,126.99 2217.49,126.984 2217.5,126.979 2217.51,126.974 2217.52,126.968 2217.53,126.963 2217.54,126.957 2217.54,126.952 2217.55,126.946 2217.56,126.941 2217.57,126.936 2217.58,126.93 2217.59,126.925 2217.6,126.919 2217.61,126.914 2217.62,126.909 2217.63,126.903 2217.64,126.898 2217.65,126.892 2217.65,126.887 2217.66,126.882 2217.67,126.876 2217.68,126.871 2217.69,126.865 2217.7,126.86 2217.71,126.855 2217.72,126.849 2217.73,126.844 2217.74,126.838 2217.75,126.833 2217.76,126.828 2217.77,126.822 2217.77,126.817 2217.78,126.811 2217.79,126.806 2217.8,126.801 2217.81,126.795 2217.82,126.79 2217.83,126.784 2217.84,126.779 2217.85,126.774 2217.86,126.768 2217.87,126.763 2217.88,126.758 2217.88,126.752 2217.89,126.747 2217.9,126.741 2217.91,126.736 2217.92,126.731 2217.93,126.725 2217.94,126.72 2217.95,126.714 2217.96,126.709 2217.97,126.704 2217.98,126.698 2217.99,126.693 2217.99,126.687 2218,126.682 2218.01,126.677 2218.02,126.671 2218.03,126.666 2218.04,126.66 2218.05,126.655 2218.06,126.65 2218.07,126.644 2218.08,126.639 2218.09,126.633 2218.1,126.628 2218.11,126.623 2218.11,126.617 2218.12,126.612 2218.13,126.607 2218.14,126.601 2218.15,126.596 2218.16,126.59 2218.17,126.585 2218.18,126.58 2218.19,126.574 2218.2,126.569 2218.21,126.563 2218.22,126.558 2218.22,126.553 2218.23,126.547 2218.24,126.542 2218.25,126.537 2218.26,126.531 2218.27,126.526 2218.28,126.52 2218.29,126.515 2218.3,126.51 2218.31,126.504 2218.32,126.499 2218.33,126.493 2218.33,126.488 2218.34,126.483 2218.35,126.477 2218.36,126.472 2218.37,126.467 2218.38,126.461 2218.39,126.456 2218.4,126.45 2218.41,126.445 2218.42,126.44 2218.43,126.434 2218.44,126.429 2218.45,126.424 2218.45,126.418 2218.46,126.413 2218.47,126.407 2218.48,126.402 2218.49,126.397 2218.5,126.391 2218.51,126.386 2218.52,126.381 2218.53,126.375 2218.54,126.37 2218.55,126.364 2218.56,126.359 2218.56,126.354 2218.57,126.348 2218.58,126.343 2218.59,126.338 2218.6,126.332 2218.61,126.327 2218.62,126.321 2218.63,126.316 2218.64,126.311 2218.65,126.305 2218.66,126.3 2218.67,126.295 2218.67,126.289 2218.68,126.284 2218.69,126.278 2218.7,126.273 2218.71,126.268 2218.72,126.262 2218.73,126.257 2218.74,126.252 2218.75,126.246 2218.76,126.241 2218.77,126.235 2218.78,126.23 2218.79,126.225 2218.79,126.219 2218.8,126.214 2218.81,126.209 2218.82,126.203 2218.83,126.198 2218.84,126.193 2218.85,126.187 2218.86,126.182 2218.87,126.176 2218.88,126.171 2218.89,126.166 2218.9,126.16 2218.9,126.155 2218.91,126.15 2218.92,126.144 2218.93,126.139 2218.94,126.134 2218.95,126.128 2218.96,126.123 2218.97,126.117 2218.98,126.112 2218.99,126.107 2219,126.101 2219.01,126.096 2219.01,126.091 2219.02,126.085 2219.03,126.08 2219.04,126.075 2219.05,126.069 2219.06,126.064 2219.07,126.058 2219.08,126.053 2219.09,126.048 2219.1,126.042 2219.11,126.037 2219.12,126.032 2219.13,126.026 2219.13,126.021 2219.14,126.016 2219.15,126.01 2219.16,126.005 2219.17,125.999 2219.18,125.994 2219.19,125.989 2219.2,125.983 2219.21,125.978 2219.22,125.973 2219.23,125.967 2219.24,125.962 2219.24,125.957 2219.25,125.951 2219.26,125.946 2219.27,125.941 2219.28,125.935 2219.29,125.93 2219.3,125.925 2219.31,125.919 2219.32,125.914 2219.33,125.908 2219.34,125.903 2219.35,125.898 2219.35,125.892 2219.36,125.887 2219.37,125.882 2219.38,125.876 2219.39,125.871 2219.4,125.866 2219.41,125.86 2219.42,125.855 2219.43,125.85 2219.44,125.844 2219.45,125.839 2219.46,125.834 2219.47,125.828 2219.47,125.823 2219.48,125.817 2219.49,125.812 2219.5,125.807 2219.51,125.801 2219.52,125.796 2219.53,125.791 2219.54,125.785 2219.55,125.78 2219.56,125.775 2219.57,125.769 2219.58,125.764 2219.58,125.759 2219.59,125.753 2219.6,125.748 2219.61,125.743 2219.62,125.737 2219.63,125.732 2219.64,125.727 2219.65,125.721 2219.66,125.716 2219.67,125.711 2219.68,125.705 2219.69,125.7 2219.69,125.695 2219.7,125.689 2219.71,125.684 2219.72,125.679 2219.73,125.673 2219.74,125.668 2219.75,125.663 2219.76,125.657 2219.77,125.652 2219.78,125.646 2219.79,125.641 2219.8,125.636 2219.81,125.63 2219.81,125.625 2219.82,125.62 2219.83,125.614 2219.84,125.609 2219.85,125.604 2219.86,125.598 2219.87,125.593 2219.88,125.588 2219.89,125.582 2219.9,125.577 2219.91,125.572 2219.92,125.566 2219.92,125.561 2219.93,125.556 2219.94,125.55 2219.95,125.545 2219.96,125.54 2219.97,125.534 2219.98,125.529 2219.99,125.524 2220,125.518 2220.01,125.513 2220.02,125.508 2220.03,125.502 2220.03,125.497 2220.04,125.492 2220.05,125.486 2220.06,125.481 2220.07,125.476 2220.08,125.47 2220.09,125.465 2220.1,125.46 2220.11,125.454 2220.12,125.449 2220.13,125.444 2220.14,125.438 2220.15,125.433 2220.15,125.428 2220.16,125.422 2220.17,125.417 2220.18,125.412 2220.19,125.406 2220.2,125.401 2220.21,125.396 2220.22,125.39 2220.23,125.385 2220.24,125.38 2220.25,125.374 2220.26,125.369 2220.26,125.364 2220.27,125.359 2220.28,125.353 2220.29,125.348 2220.3,125.343 2220.31,125.337 2220.32,125.332 2220.33,125.327 2220.34,125.321 2220.35,125.316 2220.36,125.311 2220.37,125.305 2220.37,125.3 2220.38,125.295 2220.39,125.289 2220.4,125.284 2220.41,125.279 2220.42,125.273 2220.43,125.268 2220.44,125.263 2220.45,125.257 2220.46,125.252 2220.47,125.247 2220.48,125.241 2220.49,125.236 2220.49,125.231 2220.5,125.225 2220.51,125.22 2220.52,125.215 2220.53,125.209 2220.54,125.204 2220.55,125.199 2220.56,125.194 2220.57,125.188 2220.58,125.183 2220.59,125.178 2220.6,125.172 2220.6,125.167 2220.61,125.162 2220.62,125.156 2220.63,125.151 2220.64,125.146 2220.65,125.14 2220.66,125.135 2220.67,125.13 2220.68,125.124 2220.69,125.119 2220.7,125.114 2220.71,125.108 2220.71,125.103 2220.72,125.098 2220.73,125.093 2220.74,125.087 2220.75,125.082 2220.76,125.077 2220.77,125.071 2220.78,125.066 2220.79,125.061 2220.8,125.055 2220.81,125.05 2220.82,125.045 2220.83,125.039 2220.83,125.034 2220.84,125.029 2220.85,125.023 2220.86,125.018 2220.87,125.013 2220.88,125.008 2220.89,125.002 2220.9,124.997 2220.91,124.992 2220.92,124.986 2220.93,124.981 2220.94,124.976 2220.94,124.97 2220.95,124.965 2220.96,124.96 2220.97,124.954 2220.98,124.949 2220.99,124.944 2221,124.939 2221.01,124.933 2221.02,124.928 2221.03,124.923 2221.04,124.917 2221.05,124.912 2221.06,124.907 2221.06,124.901 2221.07,124.896 2221.08,124.891 2221.09,124.886 2221.1,124.88 2221.11,124.875 2221.12,124.87 2221.13,124.864 2221.14,124.859 2221.15,124.854 2221.16,124.848 2221.17,124.843 2221.17,124.838 2221.18,124.833 2221.19,124.827 2221.2,124.822 2221.21,124.817 2221.22,124.811 2221.23,124.806 2221.24,124.801 2221.25,124.795 2221.26,124.79 2221.27,124.785 2221.28,124.78 2221.28,124.774 2221.29,124.769 2221.3,124.764 2221.31,124.758 2221.32,124.753 2221.33,124.748 2221.34,124.742 2221.35,124.737 2221.36,124.732 2221.37,124.727 2221.38,124.721 2221.39,124.716 2221.4,124.711 2221.4,124.705 2221.41,124.7 2221.42,124.695 2221.43,124.69 2221.44,124.684 2221.45,124.679 2221.46,124.674 2221.47,124.668 2221.48,124.663 2221.49,124.658 2221.5,124.652 2221.51,124.647 2221.51,124.642 2221.52,124.637 2221.53,124.631 2221.54,124.626 2221.55,124.621 2221.56,124.615 2221.57,124.61 2221.58,124.605 2221.59,124.6 2221.6,124.594 2221.61,124.589 2221.62,124.584 2221.62,124.578 2221.63,124.573 2221.64,124.568 2221.65,124.563 2221.66,124.557 2221.67,124.552 2221.68,124.547 2221.69,124.541 2221.7,124.536 2221.71,124.531 2221.72,124.526 2221.73,124.52 2221.74,124.515 2221.74,124.51 2221.75,124.504 2221.76,124.499 2221.77,124.494 2221.78,124.489 2221.79,124.483 2221.8,124.478 2221.81,124.473 2221.82,124.467 2221.83,124.462 2221.84,124.457 2221.85,124.452 2221.85,124.446 2221.86,124.441 2221.87,124.436 2221.88,124.43 2221.89,124.425 2221.9,124.42 2221.91,124.415 2221.92,124.409 2221.93,124.404 2221.94,124.399 2221.95,124.393 2221.96,124.388 2221.96,124.383 2221.97,124.378 2221.98,124.372 2221.99,124.367 2222,124.362 2222.01,124.357 2222.02,124.351 2222.03,124.346 2222.04,124.341 2222.05,124.335 2222.06,124.33 2222.07,124.325 2222.08,124.32 2222.08,124.314 2222.09,124.309 2222.1,124.304 2222.11,124.298 2222.12,124.293 2222.13,124.288 2222.14,124.283 2222.15,124.277 2222.16,124.272 2222.17,124.267 2222.18,124.262 2222.19,124.256 2222.19,124.251 2222.2,124.246 2222.21,124.24 2222.22,124.235 2222.23,124.23 2222.24,124.225 2222.25,124.219 2222.26,124.214 2222.27,124.209 2222.28,124.204 2222.29,124.198 2222.3,124.193 2222.3,124.188 2222.31,124.183 2222.32,124.177 2222.33,124.172 2222.34,124.167 2222.35,124.161 2222.36,124.156 2222.37,124.151 2222.38,124.146 2222.39,124.14 2222.4,124.135 2222.41,124.13 2222.42,124.125 2222.42,124.119 2222.43,124.114 2222.44,124.109 2222.45,124.103 2222.46,124.098 2222.47,124.093 2222.48,124.088 2222.49,124.082 2222.5,124.077 2222.51,124.072 2222.52,124.067 2222.53,124.061 2222.53,124.056 2222.54,124.051 2222.55,124.046 2222.56,124.04 2222.57,124.035 2222.58,124.03 2222.59,124.025 2222.6,124.019 2222.61,124.014 2222.62,124.009 2222.63,124.004 2222.64,123.998 2222.64,123.993 2222.65,123.988 2222.66,123.982 2222.67,123.977 2222.68,123.972 2222.69,123.967 2222.7,123.961 2222.71,123.956 2222.72,123.951 2222.73,123.946 2222.74,123.94 2222.75,123.935 2222.76,123.93 2222.76,123.925 2222.77,123.919 2222.78,123.914 2222.79,123.909 2222.8,123.904 2222.81,123.898 2222.82,123.893 2222.83,123.888 2222.84,123.883 2222.85,123.877 2222.86,123.872 2222.87,123.867 2222.87,123.862 2222.88,123.856 2222.89,123.851 2222.9,123.846 2222.91,123.841 2222.92,123.835 2222.93,123.83 2222.94,123.825 2222.95,123.82 2222.96,123.814 2222.97,123.809 2222.98,123.804 2222.98,123.799 2222.99,123.793 2223,123.788 2223.01,123.783 2223.02,123.778 2223.03,123.772 2223.04,123.767 2223.05,123.762 2223.06,123.757 2223.07,123.751 2223.08,123.746 2223.09,123.741 2223.1,123.736 2223.1,123.73 2223.11,123.725 2223.12,123.72 2223.13,123.715 2223.14,123.709 2223.15,123.704 2223.16,123.699 2223.17,123.694 2223.18,123.688 2223.19,123.683 2223.2,123.678 2223.21,123.673 2223.21,123.667 2223.22,123.662 2223.23,123.657 2223.24,123.652 2223.25,123.646 2223.26,123.641 2223.27,123.636 2223.28,123.631 2223.29,123.625 2223.3,123.62 2223.31,123.615 2223.32,123.61 2223.32,123.604 2223.33,123.599 2223.34,123.594 2223.35,123.589 2223.36,123.583 2223.37,123.578 2223.38,123.573 2223.39,123.568 2223.4,123.562 2223.41,123.557 2223.42,123.552 2223.43,123.547 2223.44,123.542 2223.44,123.536 2223.45,123.531 2223.46,123.526 2223.47,123.521 2223.48,123.515 2223.49,123.51 2223.5,123.505 2223.51,123.5 2223.52,123.494 2223.53,123.489 2223.54,123.484 2223.55,123.479 2223.55,123.473 2223.56,123.468 2223.57,123.463 2223.58,123.458 2223.59,123.453 2223.6,123.447 2223.61,123.442 2223.62,123.437 2223.63,123.432 2223.64,123.426 2223.65,123.421 2223.66,123.416 2223.66,123.411 2223.67,123.405 2223.68,123.4 2223.69,123.395 2223.7,123.39 2223.71,123.384 2223.72,123.379 2223.73,123.374 2223.74,123.369 2223.75,123.364 2223.76,123.358 2223.77,123.353 2223.78,123.348 2223.78,123.343 2223.79,123.337 2223.8,123.332 2223.81,123.327 2223.82,123.322 2223.83,123.316 2223.84,123.311 2223.85,123.306 2223.86,123.301 2223.87,123.296 2223.88,123.29 2223.89,123.285 2223.89,123.28 2223.9,123.275 2223.91,123.269 2223.92,123.264 2223.93,123.259 2223.94,123.254 2223.95,123.249 2223.96,123.243 2223.97,123.238 2223.98,123.233 2223.99,123.228 2224,123.222 2224,123.217 2224.01,123.212 2224.02,123.207 2224.03,123.202 2224.04,123.196 2224.05,123.191 2224.06,123.186 2224.07,123.181 2224.08,123.175 2224.09,123.17 2224.1,123.165 2224.11,123.16 2224.12,123.155 2224.12,123.149 2224.13,123.144 2224.14,123.139 2224.15,123.134 2224.16,123.128 2224.17,123.123 2224.18,123.118 2224.19,123.113 2224.2,123.108 2224.21,123.102 2224.22,123.097 2224.23,123.092 2224.23,123.087 2224.24,123.081 2224.25,123.076 2224.26,123.071 2224.27,123.066 2224.28,123.061 2224.29,123.055 2224.3,123.05 2224.31,123.045 2224.32,123.04 2224.33,123.035 2224.34,123.029 2224.34,123.024 2224.35,123.019 2224.36,123.014 2224.37,123.008 2224.38,123.003 2224.39,122.998 2224.4,122.993 2224.41,122.988 2224.42,122.982 2224.43,122.977 2224.44,122.972 2224.45,122.967 2224.46,122.962 2224.46,122.956 2224.47,122.951 2224.48,122.946 2224.49,122.941 2224.5,122.935 2224.51,122.93 2224.52,122.925 2224.53,122.92 2224.54,122.915 2224.55,122.909 2224.56,122.904 2224.57,122.899 2224.57,122.894 2224.58,122.889 2224.59,122.883 2224.6,122.878 2224.61,122.873 2224.62,122.868 2224.63,122.863 2224.64,122.857 2224.65,122.852 2224.66,122.847 2224.67,122.842 2224.68,122.837 2224.68,122.831 2224.69,122.826 2224.7,122.821 2224.71,122.816 2224.72,122.811 2224.73,122.805 2224.74,122.8 2224.75,122.795 2224.76,122.79 2224.77,122.784 2224.78,122.779 2224.79,122.774 2224.8,122.769 2224.8,122.764 2224.81,122.758 2224.82,122.753 2224.83,122.748 2224.84,122.743 2224.85,122.738 2224.86,122.732 2224.87,122.727 2224.88,122.722 2224.89,122.717 2224.9,122.712 2224.91,122.706 2224.91,122.701 2224.92,122.696 2224.93,122.691 2224.94,122.686 2224.95,122.68 2224.96,122.675 2224.97,122.67 2224.98,122.665 2224.99,122.66 2225,122.654 2225.01,122.649 2225.02,122.644 2225.02,122.639 2225.03,122.634 2225.04,122.628 2225.05,122.623 2225.06,122.618 2225.07,122.613 2225.08,122.608 2225.09,122.603 2225.1,122.597 2225.11,122.592 2225.12,122.587 2225.13,122.582 2225.14,122.577 2225.14,122.571 2225.15,122.566 2225.16,122.561 2225.17,122.556 2225.18,122.551 2225.19,122.545 2225.2,122.54 2225.21,122.535 2225.22,122.53 2225.23,122.525 2225.24,122.519 2225.25,122.514 2225.25,122.509 2225.26,122.504 2225.27,122.499 2225.28,122.493 2225.29,122.488 2225.3,122.483 2225.31,122.478 2225.32,122.473 2225.33,122.468 2225.34,122.462 2225.35,122.457 2225.36,122.452 2225.36,122.447 2225.37,122.442 2225.38,122.436 2225.39,122.431 2225.4,122.426 2225.41,122.421 2225.42,122.416 2225.43,122.41 2225.44,122.405 2225.45,122.4 2225.46,122.395 2225.47,122.39 2225.48,122.385 2225.48,122.379 2225.49,122.374 2225.5,122.369 2225.51,122.364 2225.52,122.359 2225.53,122.353 2225.54,122.348 2225.55,122.343 2225.56,122.338 2225.57,122.333 2225.58,122.328 2225.59,122.322 2225.59,122.317 2225.6,122.312 2225.61,122.307 2225.62,122.302 2225.63,122.296 2225.64,122.291 2225.65,122.286 2225.66,122.281 2225.67,122.276 2225.68,122.271 2225.69,122.265 2225.7,122.26 2225.7,122.255 2225.71,122.25 2225.72,122.245 2225.73,122.239 2225.74,122.234 2225.75,122.229 2225.76,122.224 2225.77,122.219 2225.78,122.214 2225.79,122.208 2225.8,122.203 2225.81,122.198 2225.82,122.193 2225.82,122.188 2225.83,122.183 2225.84,122.177 2225.85,122.172 2225.86,122.167 2225.87,122.162 2225.88,122.157 2225.89,122.151 2225.9,122.146 2225.91,122.141 2225.92,122.136 2225.93,122.131 2225.93,122.126 2225.94,122.12 2225.95,122.115 2225.96,122.11 2225.97,122.105 2225.98,122.1 2225.99,122.095 2226,122.089 2226.01,122.084 2226.02,122.079 2226.03,122.074 2226.04,122.069 2226.04,122.064 2226.05,122.058 2226.06,122.053 2226.07,122.048 2226.08,122.043 2226.09,122.038 2226.1,122.033 2226.11,122.027 2226.12,122.022 2226.13,122.017 2226.14,122.012 2226.15,122.007 2226.16,122.002 2226.16,121.996 2226.17,121.991 2226.18,121.986 2226.19,121.981 2226.2,121.976 2226.21,121.971 2226.22,121.965 2226.23,121.96 2226.24,121.955 2226.25,121.95 2226.26,121.945 2226.27,121.94 2226.27,121.934 2226.28,121.929 2226.29,121.924 2226.3,121.919 2226.31,121.914 2226.32,121.909 2226.33,121.903 2226.34,121.898 2226.35,121.893 2226.36,121.888 2226.37,121.883 2226.38,121.878 2226.38,121.872 2226.39,121.867 2226.4,121.862 2226.41,121.857 2226.42,121.852 2226.43,121.847 2226.44,121.841 2226.45,121.836 2226.46,121.831 2226.47,121.826 2226.48,121.821 2226.49,121.816 2226.5,121.81 2226.5,121.805 2226.51,121.8 2226.52,121.795 2226.53,121.79 2226.54,121.785 2226.55,121.78 2226.56,121.774 2226.57,121.769 2226.58,121.764 2226.59,121.759 2226.6,121.754 2226.61,121.749 2226.61,121.743 2226.62,121.738 2226.63,121.733 2226.64,121.728 2226.65,121.723 2226.66,121.718 2226.67,121.713 2226.68,121.707 2226.69,121.702 2226.7,121.697 2226.71,121.692 2226.72,121.687 2226.72,121.682 2226.73,121.676 2226.74,121.671 2226.75,121.666 2226.76,121.661 2226.77,121.656 2226.78,121.651 2226.79,121.646 2226.8,121.64 2226.81,121.635 2226.82,121.63 2226.83,121.625 2226.84,121.62 2226.84,121.615 2226.85,121.609 2226.86,121.604 2226.87,121.599 2226.88,121.594 2226.89,121.589 2226.9,121.584 2226.91,121.579 2226.92,121.573 2226.93,121.568 2226.94,121.563 2226.95,121.558 2226.95,121.553 2226.96,121.548 2226.97,121.543 2226.98,121.537 2226.99,121.532 2227,121.527 2227.01,121.522 2227.02,121.517 2227.03,121.512 2227.04,121.507 2227.05,121.501 2227.06,121.496 2227.06,121.491 2227.07,121.486 2227.08,121.481 2227.09,121.476 2227.1,121.471 2227.11,121.465 2227.12,121.46 2227.13,121.455 2227.14,121.45 2227.15,121.445 2227.16,121.44 2227.17,121.435 2227.18,121.429 2227.18,121.424 2227.19,121.419 2227.2,121.414 2227.21,121.409 2227.22,121.404 2227.23,121.399 2227.24,121.393 2227.25,121.388 2227.26,121.383 2227.27,121.378 2227.28,121.373 2227.29,121.368 2227.29,121.363 2227.3,121.357 2227.31,121.352 2227.32,121.347 2227.33,121.342 2227.34,121.337 2227.35,121.332 2227.36,121.327 2227.37,121.321 2227.38,121.316 2227.39,121.311 2227.4,121.306 2227.4,121.301 2227.41,121.296 2227.42,121.291 2227.43,121.286 2227.44,121.28 2227.45,121.275 2227.46,121.27 2227.47,121.265 2227.48,121.26 2227.49,121.255 2227.5,121.25 2227.51,121.244 2227.52,121.239 2227.52,121.234 2227.53,121.229 2227.54,121.224 2227.55,121.219 2227.56,121.214 2227.57,121.209 2227.58,121.203 2227.59,121.198 2227.6,121.193 2227.61,121.188 2227.62,121.183 2227.63,121.178 2227.63,121.173 2227.64,121.167 2227.65,121.162 2227.66,121.157 2227.67,121.152 2227.68,121.147 2227.69,121.142 2227.7,121.137 2227.71,121.132 2227.72,121.126 2227.73,121.121 2227.74,121.116 2227.74,121.111 2227.75,121.106 2227.76,121.101 2227.77,121.096 2227.78,121.091 2227.79,121.085 2227.8,121.08 2227.81,121.075 2227.82,121.07 2227.83,121.065 2227.84,121.06 2227.85,121.055 2227.86,121.05 2227.86,121.044 2227.87,121.039 2227.88,121.034 2227.89,121.029 2227.9,121.024 2227.91,121.019 2227.92,121.014 2227.93,121.009 2227.94,121.003 2227.95,120.998 2227.96,120.993 2227.97,120.988 2227.97,120.983 2227.98,120.978 2227.99,120.973 2228,120.968 2228.01,120.963 2228.02,120.957 2228.03,120.952 2228.04,120.947 2228.05,120.942 2228.06,120.937 2228.07,120.932 2228.08,120.927 2228.08,120.922 2228.09,120.916 2228.1,120.911 2228.11,120.906 2228.12,120.901 2228.13,120.896 2228.14,120.891 2228.15,120.886 2228.16,120.881 2228.17,120.875 2228.18,120.87 2228.19,120.865 2228.2,120.86 2228.2,120.855 2228.21,120.85 2228.22,120.845 2228.23,120.84 2228.24,120.835 2228.25,120.829 2228.26,120.824 2228.27,120.819 2228.28,120.814 2228.29,120.809 2228.3,120.804 2228.31,120.799 2228.31,120.794 2228.32,120.789 2228.33,120.783 2228.34,120.778 2228.35,120.773 2228.36,120.768 2228.37,120.763 2228.38,120.758 2228.39,120.753 2228.4,120.748 2228.41,120.743 2228.42,120.737 2228.42,120.732 2228.43,120.727 2228.44,120.722 2228.45,120.717 2228.46,120.712 2228.47,120.707 2228.48,120.702 2228.49,120.697 2228.5,120.691 2228.51,120.686 2228.52,120.681 2228.53,120.676 2228.54,120.671 2228.54,120.666 2228.55,120.661 2228.56,120.656 2228.57,120.651 2228.58,120.645 2228.59,120.64 2228.6,120.635 2228.61,120.63 2228.62,120.625 2228.63,120.62 2228.64,120.615 2228.65,120.61 2228.65,120.605 2228.66,120.6 2228.67,120.594 2228.68,120.589 2228.69,120.584 2228.7,120.579 2228.71,120.574 2228.72,120.569 2228.73,120.564 2228.74,120.559 2228.75,120.554 2228.76,120.549 2228.76,120.543 2228.77,120.538 2228.78,120.533 2228.79,120.528 2228.8,120.523 2228.81,120.518 2228.82,120.513 2228.83,120.508 2228.84,120.503 2228.85,120.498 2228.86,120.492 2228.87,120.487 2228.88,120.482 2228.88,120.477 2228.89,120.472 2228.9,120.467 2228.91,120.462 2228.92,120.457 2228.93,120.452 2228.94,120.447 2228.95,120.441 2228.96,120.436 2228.97,120.431 2228.98,120.426 2228.99,120.421 2228.99,120.416 2229,120.411 2229.01,120.406 2229.02,120.401 2229.03,120.396 2229.04,120.39 2229.05,120.385 2229.06,120.38 2229.07,120.375 2229.08,120.37 2229.09,120.365 2229.1,120.36 2229.1,120.355 2229.11,120.35 2229.12,120.345 2229.13,120.34 2229.14,120.334 2229.15,120.329 2229.16,120.324 2229.17,120.319 2229.18,120.314 2229.19,120.309 2229.2,120.304 2229.21,120.299 2229.22,120.294 2229.22,120.289 2229.23,120.284 2229.24,120.278 2229.25,120.273 2229.26,120.268 2229.27,120.263 2229.28,120.258 2229.29,120.253 2229.3,120.248 2229.31,120.243 2229.32,120.238 2229.33,120.233 2229.33,120.228 2229.34,120.222 2229.35,120.217 2229.36,120.212 2229.37,120.207 2229.38,120.202 2229.39,120.197 2229.4,120.192 2229.41,120.187 2229.42,120.182 2229.43,120.177 2229.44,120.172 2229.44,120.167 2229.45,120.161 2229.46,120.156 2229.47,120.151 2229.48,120.146 2229.49,120.141 2229.5,120.136 2229.51,120.131 2229.52,120.126 2229.53,120.121 2229.54,120.116 2229.55,120.111 2229.56,120.106 2229.56,120.1 2229.57,120.095 2229.58,120.09 2229.59,120.085 2229.6,120.08 2229.61,120.075 2229.62,120.07 2229.63,120.065 2229.64,120.06 2229.65,120.055 2229.66,120.05 2229.67,120.045 2229.67,120.039 2229.68,120.034 2229.69,120.029 2229.7,120.024 2229.71,120.019 2229.72,120.014 2229.73,120.009 2229.74,120.004 2229.75,119.999 2229.76,119.994 2229.77,119.989 2229.78,119.984 2229.78,119.979 2229.79,119.973 2229.8,119.968 2229.81,119.963 2229.82,119.958 2229.83,119.953 2229.84,119.948 2229.85,119.943 2229.86,119.938 2229.87,119.933 2229.88,119.928 2229.89,119.923 2229.9,119.918 2229.9,119.913 2229.91,119.907 2229.92,119.902 2229.93,119.897 2229.94,119.892 2229.95,119.887 2229.96,119.882 2229.97,119.877 2229.98,119.872 2229.99,119.867 2230,119.862 2230.01,119.857 2230.01,119.852 2230.02,119.847 2230.03,119.842 2230.04,119.836 2230.05,119.831 2230.06,119.826 2230.07,119.821 2230.08,119.816 2230.09,119.811 2230.1,119.806 2230.11,119.801 2230.12,119.796 2230.12,119.791 2230.13,119.786 2230.14,119.781 2230.15,119.776 2230.16,119.771 2230.17,119.766 2230.18,119.76 2230.19,119.755 2230.2,119.75 2230.21,119.745 2230.22,119.74 2230.23,119.735 2230.24,119.73 2230.24,119.725 2230.25,119.72 2230.26,119.715 2230.27,119.71 2230.28,119.705 2230.29,119.7 2230.3,119.695 2230.31,119.69 2230.32,119.684 2230.33,119.679 2230.34,119.674 2230.35,119.669 2230.35,119.664 2230.36,119.659 2230.37,119.654 2230.38,119.649 2230.39,119.644 2230.4,119.639 2230.41,119.634 2230.42,119.629 2230.43,119.624 2230.44,119.619 2230.45,119.614 2230.46,119.609 2230.46,119.603 2230.47,119.598 2230.48,119.593 2230.49,119.588 2230.5,119.583 2230.51,119.578 2230.52,119.573 2230.53,119.568 2230.54,119.563 2230.55,119.558 2230.56,119.553 2230.57,119.548 2230.58,119.543 2230.58,119.538 2230.59,119.533 2230.6,119.528 2230.61,119.523 2230.62,119.517 2230.63,119.512 2230.64,119.507 2230.65,119.502 2230.66,119.497 2230.67,119.492 2230.68,119.487 2230.69,119.482 2230.69,119.477 2230.7,119.472 2230.71,119.467 2230.72,119.462 2230.73,119.457 2230.74,119.452 2230.75,119.447 2230.76,119.442 2230.77,119.437 2230.78,119.432 2230.79,119.427 2230.8,119.421 2230.8,119.416 2230.81,119.411 2230.82,119.406 2230.83,119.401 2230.84,119.396 2230.85,119.391 2230.86,119.386 2230.87,119.381 2230.88,119.376 2230.89,119.371 2230.9,119.366 2230.91,119.361 2230.92,119.356 2230.92,119.351 2230.93,119.346 2230.94,119.341 2230.95,119.336 2230.96,119.331 2230.97,119.326 2230.98,119.32 2230.99,119.315 2231,119.31 2231.01,119.305 2231.02,119.3 2231.03,119.295 2231.03,119.29 2231.04,119.285 2231.05,119.28 2231.06,119.275 2231.07,119.27 2231.08,119.265 2231.09,119.26 2231.1,119.255 2231.11,119.25 2231.12,119.245 2231.13,119.24 2231.14,119.235 2231.14,119.23 2231.15,119.225 2231.16,119.22 2231.17,119.215 2231.18,119.209 2231.19,119.204 2231.2,119.199 2231.21,119.194 2231.22,119.189 2231.23,119.184 2231.24,119.179 2231.25,119.174 2231.26,119.169 2231.26,119.164 2231.27,119.159 2231.28,119.154 2231.29,119.149 2231.3,119.144 2231.31,119.139 2231.32,119.134 2231.33,119.129 2231.34,119.124 2231.35,119.119 2231.36,119.114 2231.37,119.109 2231.37,119.104 2231.38,119.099 2231.39,119.094 2231.4,119.088 2231.41,119.083 2231.42,119.078 2231.43,119.073 2231.44,119.068 2231.45,119.063 2231.46,119.058 2231.47,119.053 2231.48,119.048 2231.48,119.043 2231.49,119.038 2231.5,119.033 2231.51,119.028 2231.52,119.023 2231.53,119.018 2231.54,119.013 2231.55,119.008 2231.56,119.003 2231.57,118.998 2231.58,118.993 2231.59,118.988 2231.6,118.983 2231.6,118.978 2231.61,118.973 2231.62,118.968 2231.63,118.963 2231.64,118.958 2231.65,118.953 2231.66,118.948 2231.67,118.942 2231.68,118.937 2231.69,118.932 2231.7,118.927 2231.71,118.922 2231.71,118.917 2231.72,118.912 2231.73,118.907 2231.74,118.902 2231.75,118.897 2231.76,118.892 2231.77,118.887 2231.78,118.882 2231.79,118.877 2231.8,118.872 2231.81,118.867 2231.82,118.862 2231.82,118.857 2231.83,118.852 2231.84,118.847 2231.85,118.842 2231.86,118.837 2231.87,118.832 2231.88,118.827 2231.89,118.822 2231.9,118.817 2231.91,118.812 2231.92,118.807 2231.93,118.802 2231.94,118.797 2231.94,118.792 2231.95,118.787 2231.96,118.782 2231.97,118.777 2231.98,118.772 2231.99,118.767 2232,118.762 2232.01,118.756 2232.02,118.751 2232.03,118.746 2232.04,118.741 2232.05,118.736 2232.05,118.731 2232.06,118.726 2232.07,118.721 2232.08,118.716 2232.09,118.711 2232.1,118.706 2232.11,118.701 2232.12,118.696 2232.13,118.691 2232.14,118.686 2232.15,118.681 2232.16,118.676 2232.16,118.671 2232.17,118.666 2232.18,118.661 2232.19,118.656 2232.2,118.651 2232.21,118.646 2232.22,118.641 2232.23,118.636 2232.24,118.631 2232.25,118.626 2232.26,118.621 2232.27,118.616 2232.28,118.611 2232.28,118.606 2232.29,118.601 2232.3,118.596 2232.31,118.591 2232.32,118.586 2232.33,118.581 2232.34,118.576 2232.35,118.571 2232.36,118.566 2232.37,118.561 2232.38,118.556 2232.39,118.551 2232.39,118.546 2232.4,118.541 2232.41,118.536 2232.42,118.531 2232.43,118.526 2232.44,118.521 2232.45,118.516 2232.46,118.511 2232.47,118.506 2232.48,118.501 2232.49,118.496 2232.5,118.491 2232.5,118.486 2232.51,118.481 2232.52,118.476 2232.53,118.47 2232.54,118.465 2232.55,118.46 2232.56,118.455 2232.57,118.45 2232.58,118.445 2232.59,118.44 2232.6,118.435 2232.61,118.43 2232.62,118.425 2232.62,118.42 2232.63,118.415 2232.64,118.41 2232.65,118.405 2232.66,118.4 2232.67,118.395 2232.68,118.39 2232.69,118.385 2232.7,118.38 2232.71,118.375 2232.72,118.37 2232.73,118.365 2232.73,118.36 2232.74,118.355 2232.75,118.35 2232.76,118.345 2232.77,118.34 2232.78,118.335 2232.79,118.33 2232.8,118.325 2232.81,118.32 2232.82,118.315 2232.83,118.31 2232.84,118.305 2232.84,118.3 2232.85,118.295 2232.86,118.29 2232.87,118.285 2232.88,118.28 2232.89,118.275 2232.9,118.27 2232.91,118.265 2232.92,118.26 2232.93,118.255 2232.94,118.25 2232.95,118.245 2232.96,118.24 2232.96,118.235 2232.97,118.23 2232.98,118.225 2232.99,118.22 2233,118.215 2233.01,118.21 2233.02,118.205 2233.03,118.2 2233.04,118.195 2233.05,118.19 2233.06,118.185 2233.07,118.18 2233.07,118.175 2233.08,118.17 2233.09,118.165 2233.1,118.16 2233.11,118.155 2233.12,118.15 2233.13,118.145 2233.14,118.14 2233.15,118.135 2233.16,118.13 2233.17,118.125 2233.18,118.12 2233.18,118.115 2233.19,118.11 2233.2,118.105 2233.21,118.1 2233.22,118.095 2233.23,118.09 2233.24,118.085 2233.25,118.08 2233.26,118.075 2233.27,118.07 2233.28,118.065 2233.29,118.06 2233.3,118.055 2233.3,118.05 2233.31,118.045 2233.32,118.04 2233.33,118.035 2233.34,118.03 2233.35,118.025 2233.36,118.02 2233.37,118.015 2233.38,118.01 2233.39,118.005 2233.4,118 2233.41,117.995 2233.41,117.99 2233.42,117.985 2233.43,117.98 2233.44,117.975 2233.45,117.97 2233.46,117.965 2233.47,117.96 2233.48,117.955 2233.49,117.95 2233.5,117.945 2233.51,117.94 2233.52,117.936 2233.52,117.931 2233.53,117.926 2233.54,117.921 2233.55,117.916 2233.56,117.911 2233.57,117.906 2233.58,117.901 2233.59,117.896 2233.6,117.891 2233.61,117.886 2233.62,117.881 2233.63,117.876 2233.64,117.871 2233.64,117.866 2233.65,117.861 2233.66,117.856 2233.67,117.851 2233.68,117.846 2233.69,117.841 2233.7,117.836 2233.71,117.831 2233.72,117.826 2233.73,117.821 2233.74,117.816 2233.75,117.811 2233.75,117.806 2233.76,117.801 2233.77,117.796 2233.78,117.791 2233.79,117.786 2233.8,117.781 2233.81,117.776 2233.82,117.771 2233.83,117.766 2233.84,117.761 2233.85,117.756 2233.86,117.751 2233.86,117.746 2233.87,117.741 2233.88,117.736 2233.89,117.731 2233.9,117.726 2233.91,117.721 2233.92,117.716 2233.93,117.711 2233.94,117.706 2233.95,117.701 2233.96,117.696 2233.97,117.691 2233.98,117.686 2233.98,117.681 2233.99,117.676 2234,117.671 2234.01,117.666 2234.02,117.661 2234.03,117.656 2234.04,117.652 2234.05,117.647 2234.06,117.642 2234.07,117.637 2234.08,117.632 2234.09,117.627 2234.09,117.622 2234.1,117.617 2234.11,117.612 2234.12,117.607 2234.13,117.602 2234.14,117.597 2234.15,117.592 2234.16,117.587 2234.17,117.582 2234.18,117.577 2234.19,117.572 2234.2,117.567 2234.2,117.562 2234.21,117.557 2234.22,117.552 2234.23,117.547 2234.24,117.542 2234.25,117.537 2234.26,117.532 2234.27,117.527 2234.28,117.522 2234.29,117.517 2234.3,117.512 2234.31,117.507 2234.32,117.502 2234.32,117.497 2234.33,117.492 2234.34,117.487 2234.35,117.482 2234.36,117.477 2234.37,117.472 2234.38,117.468 2234.39,117.463 2234.4,117.458 2234.41,117.453 2234.42,117.448 2234.43,117.443 2234.43,117.438 2234.44,117.433 2234.45,117.428 2234.46,117.423 2234.47,117.418 2234.48,117.413 2234.49,117.408 2234.5,117.403 2234.51,117.398 2234.52,117.393 2234.53,117.388 2234.54,117.383 2234.54,117.378 2234.55,117.373 2234.56,117.368 2234.57,117.363 2234.58,117.358 2234.59,117.353 2234.6,117.348 2234.61,117.343 2234.62,117.338 2234.63,117.333 2234.64,117.328 2234.65,117.324 2234.66,117.319 2234.66,117.314 2234.67,117.309 2234.68,117.304 2234.69,117.299 2234.7,117.294 2234.71,117.289 2234.72,117.284 2234.73,117.279 2234.74,117.274 2234.75,117.269 2234.76,117.264 2234.77,117.259 2234.77,117.254 2234.78,117.249 2234.79,117.244 2234.8,117.239 2234.81,117.234 2234.82,117.229 2234.83,117.224 2234.84,117.219 2234.85,117.214 2234.86,117.209 2234.87,117.204 2234.88,117.199 2234.88,117.195 2234.89,117.19 2234.9,117.185 2234.91,117.18 2234.92,117.175 2234.93,117.17 2234.94,117.165 2234.95,117.16 2234.96,117.155 2234.97,117.15 2234.98,117.145 2234.99,117.14 2235,117.135 2235,117.13 2235.01,117.125 2235.02,117.12 2235.03,117.115 2235.04,117.11 2235.05,117.105 2235.06,117.1 2235.07,117.095 2235.08,117.09 2235.09,117.086 2235.1,117.081 2235.11,117.076 2235.11,117.071 2235.12,117.066 2235.13,117.061 2235.14,117.056 2235.15,117.051 2235.16,117.046 2235.17,117.041 2235.18,117.036 2235.19,117.031 2235.2,117.026 2235.21,117.021 2235.22,117.016 2235.22,117.011 2235.23,117.006 2235.24,117.001 2235.25,116.996 2235.26,116.991 2235.27,116.987 2235.28,116.982 2235.29,116.977 2235.3,116.972 2235.31,116.967 2235.32,116.962 2235.33,116.957 2235.34,116.952 2235.34,116.947 2235.35,116.942 2235.36,116.937 2235.37,116.932 2235.38,116.927 2235.39,116.922 2235.4,116.917 2235.41,116.912 2235.42,116.907 2235.43,116.902 2235.44,116.897 2235.45,116.893 2235.45,116.888 2235.46,116.883 2235.47,116.878 2235.48,116.873 2235.49,116.868 2235.5,116.863 2235.51,116.858 2235.52,116.853 2235.53,116.848 2235.54,116.843 2235.55,116.838 2235.56,116.833 2235.56,116.828 2235.57,116.823 2235.58,116.818 2235.59,116.813 2235.6,116.808 2235.61,116.804 2235.62,116.799 2235.63,116.794 2235.64,116.789 2235.65,116.784 2235.66,116.779 2235.67,116.774 2235.68,116.769 2235.68,116.764 2235.69,116.759 2235.7,116.754 2235.71,116.749 2235.72,116.744 2235.73,116.739 2235.74,116.734 2235.75,116.729 2235.76,116.725 2235.77,116.72 2235.78,116.715 2235.79,116.71 2235.79,116.705 2235.8,116.7 2235.81,116.695 2235.82,116.69 2235.83,116.685 2235.84,116.68 2235.85,116.675 2235.86,116.67 2235.87,116.665 2235.88,116.66 2235.89,116.655 2235.9,116.65 2235.9,116.646 2235.91,116.641 2235.92,116.636 2235.93,116.631 2235.94,116.626 2235.95,116.621 2235.96,116.616 2235.97,116.611 2235.98,116.606 2235.99,116.601 2236,116.596 2236.01,116.591 2236.02,116.586 2236.02,116.581 2236.03,116.576 2236.04,116.572 2236.05,116.567 2236.06,116.562 2236.07,116.557 2236.08,116.552 2236.09,116.547 2236.1,116.542 2236.11,116.537 2236.12,116.532 2236.13,116.527 2236.13,116.522 2236.14,116.517 2236.15,116.512 2236.16,116.507 2236.17,116.502 2236.18,116.498 2236.19,116.493 2236.2,116.488 2236.21,116.483 2236.22,116.478 2236.23,116.473 2236.24,116.468 2236.24,116.463 2236.25,116.458 2236.26,116.453 2236.27,116.448 2236.28,116.443 2236.29,116.438 2236.3,116.434 2236.31,116.429 2236.32,116.424 2236.33,116.419 2236.34,116.414 2236.35,116.409 2236.36,116.404 2236.36,116.399 2236.37,116.394 2236.38,116.389 2236.39,116.384 2236.4,116.379 2236.41,116.374 2236.42,116.369 2236.43,116.365 2236.44,116.36 2236.45,116.355 2236.46,116.35 2236.47,116.345 2236.47,116.34 2236.48,116.335 2236.49,116.33 2236.5,116.325 2236.51,116.32 2236.52,116.315 2236.53,116.31 2236.54,116.306 2236.55,116.301 2236.56,116.296 2236.57,116.291 2236.58,116.286 2236.58,116.281 2236.59,116.276 2236.6,116.271 2236.61,116.266 2236.62,116.261 2236.63,116.256 2236.64,116.251 2236.65,116.246 2236.66,116.242 2236.67,116.237 2236.68,116.232 2236.69,116.227 2236.7,116.222 2236.7,116.217 2236.71,116.212 2236.72,116.207 2236.73,116.202 2236.74,116.197 2236.75,116.192 2236.76,116.187 2236.77,116.183 2236.78,116.178 2236.79,116.173 2236.8,116.168 2236.81,116.163 2236.81,116.158 2236.82,116.153 2236.83,116.148 2236.84,116.143 2236.85,116.138 2236.86,116.133 2236.87,116.128 2236.88,116.124 2236.89,116.119 2236.9,116.114 2236.91,116.109 2236.92,116.104 2236.92,116.099 2236.93,116.094 2236.94,116.089 2236.95,116.084 2236.96,116.079 2236.97,116.074 2236.98,116.07 2236.99,116.065 2237,116.06 2237.01,116.055 2237.02,116.05 2237.03,116.045 2237.04,116.04 2237.04,116.035 2237.05,116.03 2237.06,116.025 2237.07,116.02 2237.08,116.016 2237.09,116.011 2237.1,116.006 2237.11,116.001 2237.12,115.996 2237.13,115.991 2237.14,115.986 2237.15,115.981 2237.15,115.976 2237.16,115.971 2237.17,115.966 2237.18,115.962 2237.19,115.957 2237.2,115.952 2237.21,115.947 2237.22,115.942 2237.23,115.937 2237.24,115.932 2237.25,115.927 2237.26,115.922 2237.26,115.917 2237.27,115.912 2237.28,115.908 2237.29,115.903 2237.3,115.898 2237.31,115.893 2237.32,115.888 2237.33,115.883 2237.34,115.878 2237.35,115.873 2237.36,115.868 2237.37,115.863 2237.38,115.859 2237.38,115.854 2237.39,115.849 2237.4,115.844 2237.41,115.839 2237.42,115.834 2237.43,115.829 2237.44,115.824 2237.45,115.819 2237.46,115.814 2237.47,115.81 2237.48,115.805 2237.49,115.8 2237.49,115.795 2237.5,115.79 2237.51,115.785 2237.52,115.78 2237.53,115.775 2237.54,115.77 2237.55,115.765 2237.56,115.761 2237.57,115.756 2237.58,115.751 2237.59,115.746 2237.6,115.741 2237.6,115.736 2237.61,115.731 2237.62,115.726 2237.63,115.721 2237.64,115.716 2237.65,115.712 2237.66,115.707 2237.67,115.702 2237.68,115.697 2237.69,115.692 2237.7,115.687 2237.71,115.682 2237.72,115.677 2237.72,115.672 2237.73,115.667 2237.74,115.663 2237.75,115.658 2237.76,115.653 2237.77,115.648 2237.78,115.643 2237.79,115.638 2237.8,115.633 2237.81,115.628 2237.82,115.623 2237.83,115.619 2237.83,115.614 2237.84,115.609 2237.85,115.604 2237.86,115.599 2237.87,115.594 2237.88,115.589 2237.89,115.584 2237.9,115.579 2237.91,115.575 2237.92,115.57 2237.93,115.565 2237.94,115.56 2237.94,115.555 2237.95,115.55 2237.96,115.545 2237.97,115.54 2237.98,115.535 2237.99,115.53 2238,115.526 2238.01,115.521 2238.02,115.516 2238.03,115.511 2238.04,115.506 2238.05,115.501 2238.06,115.496 2238.06,115.491 2238.07,115.486 2238.08,115.482 2238.09,115.477 2238.1,115.472 2238.11,115.467 2238.12,115.462 2238.13,115.457 2238.14,115.452 2238.15,115.447 2238.16,115.443 2238.17,115.438 2238.17,115.433 2238.18,115.428 2238.19,115.423 2238.2,115.418 2238.21,115.413 2238.22,115.408 2238.23,115.403 2238.24,115.399 2238.25,115.394 2238.26,115.389 2238.27,115.384 2238.28,115.379 2238.28,115.374 2238.29,115.369 2238.3,115.364 2238.31,115.359 2238.32,115.355 2238.33,115.35 2238.34,115.345 2238.35,115.34 2238.36,115.335 2238.37,115.33 2238.38,115.325 2238.39,115.32 2238.4,115.316 2238.4,115.311 2238.41,115.306 2238.42,115.301 2238.43,115.296 2238.44,115.291 2238.45,115.286 2238.46,115.281 2238.47,115.276 2238.48,115.272 2238.49,115.267 2238.5,115.262 2238.51,115.257 2238.51,115.252 2238.52,115.247 2238.53,115.242 2238.54,115.237 2238.55,115.233 2238.56,115.228 2238.57,115.223 2238.58,115.218 2238.59,115.213 2238.6,115.208 2238.61,115.203 2238.62,115.198 2238.62,115.194 2238.63,115.189 2238.64,115.184 2238.65,115.179 2238.66,115.174 2238.67,115.169 2238.68,115.164 2238.69,115.159 2238.7,115.155 2238.71,115.15 2238.72,115.145 2238.73,115.14 2238.74,115.135 2238.74,115.13 2238.75,115.125 2238.76,115.12 2238.77,115.116 2238.78,115.111 2238.79,115.106 2238.8,115.101 2238.81,115.096 2238.82,115.091 2238.83,115.086 2238.84,115.081 2238.85,115.077 2238.85,115.072 2238.86,115.067 2238.87,115.062 2238.88,115.057 2238.89,115.052 2238.9,115.047 2238.91,115.043 2238.92,115.038 2238.93,115.033 2238.94,115.028 2238.95,115.023 2238.96,115.018 2238.96,115.013 2238.97,115.008 2238.98,115.004 2238.99,114.999 2239,114.994 2239.01,114.989 2239.02,114.984 2239.03,114.979 2239.04,114.974 2239.05,114.969 2239.06,114.965 2239.07,114.96 2239.08,114.955 2239.08,114.95 2239.09,114.945 2239.1,114.94 2239.11,114.935 2239.12,114.931 2239.13,114.926 2239.14,114.921 2239.15,114.916 2239.16,114.911 2239.17,114.906 2239.18,114.901 2239.19,114.897 2239.19,114.892 2239.2,114.887 2239.21,114.882 2239.22,114.877 2239.23,114.872 2239.24,114.867 2239.25,114.862 2239.26,114.858 2239.27,114.853 2239.28,114.848 2239.29,114.843 2239.3,114.838 2239.3,114.833 2239.31,114.828 2239.32,114.824 2239.33,114.819 2239.34,114.814 2239.35,114.809 2239.36,114.804 2239.37,114.799 2239.38,114.794 2239.39,114.79 2239.4,114.785 2239.41,114.78 2239.42,114.775 2239.42,114.77 2239.43,114.765 2239.44,114.76 2239.45,114.756 2239.46,114.751 2239.47,114.746 2239.48,114.741 2239.49,114.736 2239.5,114.731 2239.51,114.726 2239.52,114.722 2239.53,114.717 2239.53,114.712 2239.54,114.707 2239.55,114.702 2239.56,114.697 2239.57,114.692 2239.58,114.688 2239.59,114.683 2239.6,114.678 2239.61,114.673 2239.62,114.668 2239.63,114.663 2239.64,114.658 2239.64,114.654 2239.65,114.649 2239.66,114.644 2239.67,114.639 2239.68,114.634 2239.69,114.629 2239.7,114.624 2239.71,114.62 2239.72,114.615 2239.73,114.61 2239.74,114.605 2239.75,114.6 2239.76,114.595 2239.76,114.59 2239.77,114.586 2239.78,114.581 2239.79,114.576 2239.8,114.571 2239.81,114.566 2239.82,114.561 2239.83,114.556 2239.84,114.552 2239.85,114.547 2239.86,114.542 2239.87,114.537 2239.87,114.532 2239.88,114.527 2239.89,114.523 2239.9,114.518 2239.91,114.513 2239.92,114.508 2239.93,114.503 2239.94,114.498 2239.95,114.493 2239.96,114.489 2239.97,114.484 2239.98,114.479 2239.98,114.474 2239.99,114.469 2240,114.464 2240.01,114.459 2240.02,114.455 2240.03,114.45 2240.04,114.445 2240.05,114.44 2240.06,114.435 2240.07,114.43 2240.08,114.426 2240.09,114.421 2240.1,114.416 2240.1,114.411 2240.11,114.406 2240.12,114.401 2240.13,114.397 2240.14,114.392 2240.15,114.387 2240.16,114.382 2240.17,114.377 2240.18,114.372 2240.19,114.367 2240.2,114.363 2240.21,114.358 2240.21,114.353 2240.22,114.348 2240.23,114.343 2240.24,114.338 2240.25,114.334 2240.26,114.329 2240.27,114.324 2240.28,114.319 2240.29,114.314 2240.3,114.309 2240.31,114.304 2240.32,114.3 2240.32,114.295 2240.33,114.29 2240.34,114.285 2240.35,114.28 2240.36,114.275 2240.37,114.271 2240.38,114.266 2240.39,114.261 2240.4,114.256 2240.41,114.251 2240.42,114.246 2240.43,114.242 2240.44,114.237 2240.44,114.232 2240.45,114.227 2240.46,114.222 2240.47,114.217 2240.48,114.213 2240.49,114.208 2240.5,114.203 2240.51,114.198 2240.52,114.193 2240.53,114.188 2240.54,114.184 2240.55,114.179 2240.55,114.174 2240.56,114.169 2240.57,114.164 2240.58,114.159 2240.59,114.155 2240.6,114.15 2240.61,114.145 2240.62,114.14 2240.63,114.135 2240.64,114.13 2240.65,114.126 2240.66,114.121 2240.66,114.116 2240.67,114.111 2240.68,114.106 2240.69,114.101 2240.7,114.097 2240.71,114.092 2240.72,114.087 2240.73,114.082 2240.74,114.077 2240.75,114.072 2240.76,114.068 2240.77,114.063 2240.78,114.058 2240.78,114.053 2240.79,114.048 2240.8,114.043 2240.81,114.039 2240.82,114.034 2240.83,114.029 2240.84,114.024 2240.85,114.019 2240.86,114.014 2240.87,114.01 2240.88,114.005 2240.89,114 2240.89,113.995 2240.9,113.99 2240.91,113.985 2240.92,113.981 2240.93,113.976 2240.94,113.971 2240.95,113.966 2240.96,113.961 2240.97,113.956 2240.98,113.952 2240.99,113.947 2241,113.942 2241,113.937 2241.01,113.932 2241.02,113.927 2241.03,113.923 2241.04,113.918 2241.05,113.913 2241.06,113.908 2241.07,113.903 2241.08,113.899 2241.09,113.894 2241.1,113.889 2241.11,113.884 2241.12,113.879 2241.12,113.874 2241.13,113.87 2241.14,113.865 2241.15,113.86 2241.16,113.855 2241.17,113.85 2241.18,113.845 2241.19,113.841 2241.2,113.836 2241.21,113.831 2241.22,113.826 2241.23,113.821 2241.23,113.817 2241.24,113.812 2241.25,113.807 2241.26,113.802 2241.27,113.797 2241.28,113.792 2241.29,113.788 2241.3,113.783 2241.31,113.778 2241.32,113.773 2241.33,113.768 2241.34,113.763 2241.34,113.759 2241.35,113.754 2241.36,113.749 2241.37,113.744 2241.38,113.739 2241.39,113.735 2241.4,113.73 2241.41,113.725 2241.42,113.72 2241.43,113.715 2241.44,113.71 2241.45,113.706 2241.46,113.701 2241.46,113.696 2241.47,113.691 2241.48,113.686 2241.49,113.682 2241.5,113.677 2241.51,113.672 2241.52,113.667 2241.53,113.662 2241.54,113.657 2241.55,113.653 2241.56,113.648 2241.57,113.643 2241.57,113.638 2241.58,113.633 2241.59,113.629 2241.6,113.624 2241.61,113.619 2241.62,113.614 2241.63,113.609 2241.64,113.605 2241.65,113.6 2241.66,113.595 2241.67,113.59 2241.68,113.585 2241.68,113.58 2241.69,113.576 2241.7,113.571 2241.71,113.566 2241.72,113.561 2241.73,113.556 2241.74,113.552 2241.75,113.547 2241.76,113.542 2241.77,113.537 2241.78,113.532 2241.79,113.528 2241.8,113.523 2241.8,113.518 2241.81,113.513 2241.82,113.508 2241.83,113.503 2241.84,113.499 2241.85,113.494 2241.86,113.489 2241.87,113.484 2241.88,113.479 2241.89,113.475 2241.9,113.47 2241.91,113.465 2241.91,113.46 2241.92,113.455 2241.93,113.451 2241.94,113.446 2241.95,113.441 2241.96,113.436 2241.97,113.431 2241.98,113.427 2241.99,113.422 2242,113.417 2242.01,113.412 2242.02,113.407 2242.02,113.403 2242.03,113.398 2242.04,113.393 2242.05,113.388 2242.06,113.383 2242.07,113.378 2242.08,113.374 2242.09,113.369 2242.1,113.364 2242.11,113.359 2242.12,113.354 2242.13,113.35 2242.14,113.345 2242.14,113.34 2242.15,113.335 2242.16,113.33 2242.17,113.326 2242.18,113.321 2242.19,113.316 2242.2,113.311 2242.21,113.306 2242.22,113.302 2242.23,113.297 2242.24,113.292 2242.25,113.287 2242.25,113.282 2242.26,113.278 2242.27,113.273 2242.28,113.268 2242.29,113.263 2242.3,113.258 2242.31,113.254 2242.32,113.249 2242.33,113.244 2242.34,113.239 2242.35,113.234 2242.36,113.23 2242.36,113.225 2242.37,113.22 2242.38,113.215 2242.39,113.21 2242.4,113.206 2242.41,113.201 2242.42,113.196 2242.43,113.191 2242.44,113.186 2242.45,113.182 2242.46,113.177 2242.47,113.172 2242.48,113.167 2242.48,113.162 2242.49,113.158 2242.5,113.153 2242.51,113.148 2242.52,113.143 2242.53,113.138 2242.54,113.134 2242.55,113.129 2242.56,113.124 2242.57,113.119 2242.58,113.114 2242.59,113.11 2242.59,113.105 2242.6,113.1 2242.61,113.095 2242.62,113.091 2242.63,113.086 2242.64,113.081 2242.65,113.076 2242.66,113.071 2242.67,113.067 2242.68,113.062 2242.69,113.057 2242.7,113.052 2242.7,113.047 2242.71,113.043 2242.72,113.038 2242.73,113.033 2242.74,113.028 2242.75,113.023 2242.76,113.019 2242.77,113.014 2242.78,113.009 2242.79,113.004 2242.8,112.999 2242.81,112.995 2242.82,112.99 2242.82,112.985 2242.83,112.98 2242.84,112.976 2242.85,112.971 2242.86,112.966 2242.87,112.961 2242.88,112.956 2242.89,112.952 2242.9,112.947 2242.91,112.942 2242.92,112.937 2242.93,112.932 2242.93,112.928 2242.94,112.923 2242.95,112.918 2242.96,112.913 2242.97,112.908 2242.98,112.904 2242.99,112.899 2243,112.894 2243.01,112.889 2243.02,112.885 2243.03,112.88 2243.04,112.875 2243.04,112.87 2243.05,112.865 2243.06,112.861 2243.07,112.856 2243.08,112.851 2243.09,112.846 2243.1,112.841 2243.11,112.837 2243.12,112.832 2243.13,112.827 2243.14,112.822 2243.15,112.818 2243.16,112.813 2243.16,112.808 2243.17,112.803 2243.18,112.798 2243.19,112.794 2243.2,112.789 2243.21,112.784 2243.22,112.779 2243.23,112.775 2243.24,112.77 2243.25,112.765 2243.26,112.76 2243.27,112.755 2243.27,112.751 2243.28,112.746 2243.29,112.741 2243.3,112.736 2243.31,112.731 2243.32,112.727 2243.33,112.722 2243.34,112.717 2243.35,112.712 2243.36,112.708 2243.37,112.703 2243.38,112.698 2243.38,112.693 2243.39,112.688 2243.4,112.684 2243.41,112.679 2243.42,112.674 2243.43,112.669 2243.44,112.665 2243.45,112.66 2243.46,112.655 2243.47,112.65 2243.48,112.645 2243.49,112.641 2243.5,112.636 2243.5,112.631 2243.51,112.626 2243.52,112.622 2243.53,112.617 2243.54,112.612 2243.55,112.607 2243.56,112.602 2243.57,112.598 2243.58,112.593 2243.59,112.588 2243.6,112.583 2243.61,112.579 2243.61,112.574 2243.62,112.569 2243.63,112.564 2243.64,112.56 2243.65,112.555 2243.66,112.55 2243.67,112.545 2243.68,112.54 2243.69,112.536 2243.7,112.531 2243.71,112.526 2243.72,112.521 2243.72,112.517 2243.73,112.512 2243.74,112.507 2243.75,112.502 2243.76,112.497 2243.77,112.493 2243.78,112.488 2243.79,112.483 2243.8,112.478 2243.81,112.474 2243.82,112.469 2243.83,112.464 2243.84,112.459 2243.84,112.455 2243.85,112.45 2243.86,112.445 2243.87,112.44 2243.88,112.435 2243.89,112.431 2243.9,112.426 2243.91,112.421 2243.92,112.416 2243.93,112.412 2243.94,112.407 2243.95,112.402 2243.95,112.397 2243.96,112.393 2243.97,112.388 2243.98,112.383 2243.99,112.378 2244,112.373 2244.01,112.369 2244.02,112.364 2244.03,112.359 2244.04,112.354 2244.05,112.35 2244.06,112.345 2244.06,112.34 2244.07,112.335 2244.08,112.331 2244.09,112.326 2244.1,112.321 2244.11,112.316 2244.12,112.312 2244.13,112.307 2244.14,112.302 2244.15,112.297 2244.16,112.292 2244.17,112.288 2244.18,112.283 2244.18,112.278 2244.19,112.273 2244.2,112.269 2244.21,112.264 2244.22,112.259 2244.23,112.254 2244.24,112.25 2244.25,112.245 2244.26,112.24 2244.27,112.235 2244.28,112.231 2244.29,112.226 2244.29,112.221 2244.3,112.216 2244.31,112.211 2244.32,112.207 2244.33,112.202 2244.34,112.197 2244.35,112.192 2244.36,112.188 2244.37,112.183 2244.38,112.178 2244.39,112.173 2244.4,112.169 2244.4,112.164 2244.41,112.159 2244.42,112.154 2244.43,112.15 2244.44,112.145 2244.45,112.14 2244.46,112.135 2244.47,112.131 2244.48,112.126 2244.49,112.121 2244.5,112.116 2244.51,112.112 2244.52,112.107 2244.52,112.102 2244.53,112.097 2244.54,112.093 2244.55,112.088 2244.56,112.083 2244.57,112.078 2244.58,112.073 2244.59,112.069 2244.6,112.064 2244.61,112.059 2244.62,112.054 2244.63,112.05 2244.63,112.045 2244.64,112.04 2244.65,112.035 2244.66,112.031 2244.67,112.026 2244.68,112.021 2244.69,112.016 2244.7,112.012 2244.71,112.007 2244.72,112.002 2244.73,111.997 2244.74,111.993 2244.74,111.988 2244.75,111.983 2244.76,111.978 2244.77,111.974 2244.78,111.969 2244.79,111.964 2244.8,111.959 2244.81,111.955 2244.82,111.95 2244.83,111.945 2244.84,111.94 2244.85,111.936 2244.86,111.931 2244.86,111.926 2244.87,111.921 2244.88,111.917 2244.89,111.912 2244.9,111.907 2244.91,111.902 2244.92,111.898 2244.93,111.893 2244.94,111.888 2244.95,111.883 2244.96,111.879 2244.97,111.874 2244.97,111.869 2244.98,111.864 2244.99,111.86 2245,111.855 2245.01,111.85 2245.02,111.845 2245.03,111.841 2245.04,111.836 2245.05,111.831 2245.06,111.826 2245.07,111.822 2245.08,111.817 2245.08,111.812 2245.09,111.807 2245.1,111.803 2245.11,111.798 2245.12,111.793 2245.13,111.788 2245.14,111.784 2245.15,111.779 2245.16,111.774 2245.17,111.769 2245.18,111.765 2245.19,111.76 2245.2,111.755 2245.2,111.751 2245.21,111.746 2245.22,111.741 2245.23,111.736 2245.24,111.732 2245.25,111.727 2245.26,111.722 2245.27,111.717 2245.28,111.713 2245.29,111.708 2245.3,111.703 2245.31,111.698 2245.31,111.694 2245.32,111.689 2245.33,111.684 2245.34,111.679 2245.35,111.675 2245.36,111.67 2245.37,111.665 2245.38,111.66 2245.39,111.656 2245.4,111.651 2245.41,111.646 2245.42,111.641 2245.42,111.637 2245.43,111.632 2245.44,111.627 2245.45,111.623 2245.46,111.618 2245.47,111.613 2245.48,111.608 2245.49,111.604 2245.5,111.599 2245.51,111.594 2245.52,111.589 2245.53,111.585 2245.54,111.58 2245.54,111.575 2245.55,111.57 2245.56,111.566 2245.57,111.561 2245.58,111.556 2245.59,111.551 2245.6,111.547 2245.61,111.542 2245.62,111.537 2245.63,111.532 2245.64,111.528 2245.65,111.523 2245.65,111.518 2245.66,111.514 2245.67,111.509 2245.68,111.504 2245.69,111.499 2245.7,111.495 2245.71,111.49 2245.72,111.485 2245.73,111.48 2245.74,111.476 2245.75,111.471 2245.76,111.466 2245.77,111.461 2245.77,111.457 2245.78,111.452 2245.79,111.447 2245.8,111.443 2245.81,111.438 2245.82,111.433 2245.83,111.428 2245.84,111.424 2245.85,111.419 2245.86,111.414 2245.87,111.409 2245.88,111.405 2245.88,111.4 2245.89,111.395 2245.9,111.391 2245.91,111.386 2245.92,111.381 2245.93,111.376 2245.94,111.372 2245.95,111.367 2245.96,111.362 2245.97,111.357 2245.98,111.353 2245.99,111.348 2245.99,111.343 2246,111.338 2246.01,111.334 2246.02,111.329 2246.03,111.324 2246.04,111.32 2246.05,111.315 2246.06,111.31 2246.07,111.305 2246.08,111.301 2246.09,111.296 2246.1,111.291 2246.11,111.286 2246.11,111.282 2246.12,111.277 2246.13,111.272 2246.14,111.268 2246.15,111.263 2246.16,111.258 2246.17,111.253 2246.18,111.249 2246.19,111.244 2246.2,111.239 2246.21,111.234 2246.22,111.23 2246.22,111.225 2246.23,111.22 2246.24,111.216 2246.25,111.211 2246.26,111.206 2246.27,111.201 2246.28,111.197 2246.29,111.192 2246.3,111.187 2246.31,111.183 2246.32,111.178 2246.33,111.173 2246.33,111.168 2246.34,111.164 2246.35,111.159 2246.36,111.154 2246.37,111.149 2246.38,111.145 2246.39,111.14 2246.4,111.135 2246.41,111.131 2246.42,111.126 2246.43,111.121 2246.44,111.116 2246.45,111.112 2246.45,111.107 2246.46,111.102 2246.47,111.098 2246.48,111.093 2246.49,111.088 2246.5,111.083 2246.51,111.079 2246.52,111.074 2246.53,111.069 2246.54,111.065 2246.55,111.06 2246.56,111.055 2246.56,111.05 2246.57,111.046 2246.58,111.041 2246.59,111.036 2246.6,111.031 2246.61,111.027 2246.62,111.022 2246.63,111.017 2246.64,111.013 2246.65,111.008 2246.66,111.003 2246.67,110.998 2246.67,110.994 2246.68,110.989 2246.69,110.984 2246.7,110.98 2246.71,110.975 2246.72,110.97 2246.73,110.965 2246.74,110.961 2246.75,110.956 2246.76,110.951 2246.77,110.947 2246.78,110.942 2246.79,110.937 2246.79,110.932 2246.8,110.928 2246.81,110.923 2246.82,110.918 2246.83,110.914 2246.84,110.909 2246.85,110.904 2246.86,110.899 2246.87,110.895 2246.88,110.89 2246.89,110.885 2246.9,110.881 2246.9,110.876 2246.91,110.871 2246.92,110.866 2246.93,110.862 2246.94,110.857 2246.95,110.852 2246.96,110.848 2246.97,110.843 2246.98,110.838 2246.99,110.834 2247,110.829 2247.01,110.824 2247.01,110.819 2247.02,110.815 2247.03,110.81 2247.04,110.805 2247.05,110.801 2247.06,110.796 2247.07,110.791 2247.08,110.786 2247.09,110.782 2247.1,110.777 2247.11,110.772 2247.12,110.768 2247.13,110.763 2247.13,110.758 2247.14,110.753 2247.15,110.749 2247.16,110.744 2247.17,110.739 2247.18,110.735 2247.19,110.73 2247.2,110.725 2247.21,110.721 2247.22,110.716 2247.23,110.711 2247.24,110.706 2247.24,110.702 2247.25,110.697 2247.26,110.692 2247.27,110.688 2247.28,110.683 2247.29,110.678 2247.3,110.673 2247.31,110.669 2247.32,110.664 2247.33,110.659 2247.34,110.655 2247.35,110.65 2247.35,110.645 2247.36,110.641 2247.37,110.636 2247.38,110.631 2247.39,110.626 2247.4,110.622 2247.41,110.617 2247.42,110.612 2247.43,110.608 2247.44,110.603 2247.45,110.598 2247.46,110.594 2247.47,110.589 2247.47,110.584 2247.48,110.579 2247.49,110.575 2247.5,110.57 2247.51,110.565 2247.52,110.561 2247.53,110.556 2247.54,110.551 2247.55,110.547 2247.56,110.542 2247.57,110.537 2247.58,110.532 2247.58,110.528 2247.59,110.523 2247.6,110.518 2247.61,110.514 2247.62,110.509 2247.63,110.504 2247.64,110.5 2247.65,110.495 2247.66,110.49 2247.67,110.485 2247.68,110.481 2247.69,110.476 2247.69,110.471 2247.7,110.467 2247.71,110.462 2247.72,110.457 2247.73,110.453 2247.74,110.448 2247.75,110.443 2247.76,110.438 2247.77,110.434 2247.78,110.429 2247.79,110.424 2247.8,110.42 2247.81,110.415 2247.81,110.41 2247.82,110.406 2247.83,110.401 2247.84,110.396 2247.85,110.392 2247.86,110.387 2247.87,110.382 2247.88,110.377 2247.89,110.373 2247.9,110.368 2247.91,110.363 2247.92,110.359 2247.92,110.354 2247.93,110.349 2247.94,110.345 2247.95,110.34 2247.96,110.335 2247.97,110.331 2247.98,110.326 2247.99,110.321 2248,110.316 2248.01,110.312 2248.02,110.307 2248.03,110.302 2248.03,110.298 2248.04,110.293 2248.05,110.288 2248.06,110.284 2248.07,110.279 2248.08,110.274 2248.09,110.27 2248.1,110.265 2248.11,110.26 2248.12,110.255 2248.13,110.251 2248.14,110.246 2248.15,110.241 2248.15,110.237 2248.16,110.232 2248.17,110.227 2248.18,110.223 2248.19,110.218 2248.2,110.213 2248.21,110.209 2248.22,110.204 2248.23,110.199 2248.24,110.195 2248.25,110.19 2248.26,110.185 2248.26,110.18 2248.27,110.176 2248.28,110.171 2248.29,110.166 2248.3,110.162 2248.31,110.157 2248.32,110.152 2248.33,110.148 2248.34,110.143 2248.35,110.138 2248.36,110.134 2248.37,110.129 2248.37,110.124 2248.38,110.12 2248.39,110.115 2248.4,110.11 2248.41,110.105 2248.42,110.101 2248.43,110.096 2248.44,110.091 2248.45,110.087 2248.46,110.082 2248.47,110.077 2248.48,110.073 2248.49,110.068 2248.49,110.063 2248.5,110.059 2248.51,110.054 2248.52,110.049 2248.53,110.045 2248.54,110.04 2248.55,110.035 2248.56,110.031 2248.57,110.026 2248.58,110.021 2248.59,110.017 2248.6,110.012 2248.6,110.007 2248.61,110.002 2248.62,109.998 2248.63,109.993 2248.64,109.988 2248.65,109.984 2248.66,109.979 2248.67,109.974 2248.68,109.97 2248.69,109.965 2248.7,109.96 2248.71,109.956 2248.71,109.951 2248.72,109.946 2248.73,109.942 2248.74,109.937 2248.75,109.932 2248.76,109.928 2248.77,109.923 2248.78,109.918 2248.79,109.914 2248.8,109.909 2248.81,109.904 2248.82,109.9 2248.83,109.895 2248.83,109.89 2248.84,109.886 2248.85,109.881 2248.86,109.876 2248.87,109.872 2248.88,109.867 2248.89,109.862 2248.9,109.857 2248.91,109.853 2248.92,109.848 2248.93,109.843 2248.94,109.839 2248.94,109.834 2248.95,109.829 2248.96,109.825 2248.97,109.82 2248.98,109.815 2248.99,109.811 2249,109.806 2249.01,109.801 2249.02,109.797 2249.03,109.792 2249.04,109.787 2249.05,109.783 2249.05,109.778 2249.06,109.773 2249.07,109.769 2249.08,109.764 2249.09,109.759 2249.1,109.755 2249.11,109.75 2249.12,109.745 2249.13,109.741 2249.14,109.736 2249.15,109.731 2249.16,109.727 2249.17,109.722 2249.17,109.717 2249.18,109.713 2249.19,109.708 2249.2,109.703 2249.21,109.699 2249.22,109.694 2249.23,109.689 2249.24,109.685 2249.25,109.68 2249.26,109.675 2249.27,109.671 2249.28,109.666 2249.28,109.661 2249.29,109.657 2249.3,109.652 2249.31,109.647 2249.32,109.643 2249.33,109.638 2249.34,109.633 2249.35,109.629 2249.36,109.624 2249.37,109.619 2249.38,109.615 2249.39,109.61 2249.39,109.605 2249.4,109.601 2249.41,109.596 2249.42,109.591 2249.43,109.587 2249.44,109.582 2249.45,109.577 2249.46,109.573 2249.47,109.568 2249.48,109.563 2249.49,109.559 2249.5,109.554 2249.51,109.549 2249.51,109.545 2249.52,109.54 2249.53,109.535 2249.54,109.531 2249.55,109.526 2249.56,109.521 2249.57,109.517 2249.58,109.512 2249.59,109.507 2249.6,109.503 2249.61,109.498 2249.62,109.493 2249.62,109.489 2249.63,109.484 2249.64,109.479 2249.65,109.475 2249.66,109.47 2249.67,109.465 2249.68,109.461 2249.69,109.456 2249.7,109.451 2249.71,109.447 2249.72,109.442 2249.73,109.437 2249.73,109.433 2249.74,109.428 2249.75,109.423 2249.76,109.419 2249.77,109.414 2249.78,109.409 2249.79,109.405 2249.8,109.4 2249.81,109.395 2249.82,109.391 2249.83,109.386 2249.84,109.381 2249.85,109.377 2249.85,109.372 2249.86,109.368 2249.87,109.363 2249.88,109.358 2249.89,109.354 2249.9,109.349 2249.91,109.344 2249.92,109.34 2249.93,109.335 2249.94,109.33 2249.95,109.326 2249.96,109.321 2249.96,109.316 2249.97,109.312 2249.98,109.307 2249.99,109.302 2250,109.298 2250.01,109.293 2250.02,109.288 2250.03,109.284 2250.04,109.279 2250.05,109.274 2250.06,109.27 2250.07,109.265 2250.07,109.26 2250.08,109.256 2250.09,109.251 2250.1,109.246 2250.11,109.242 2250.12,109.237 2250.13,109.232 2250.14,109.228 2250.15,109.223 2250.16,109.219 2250.17,109.214 2250.18,109.209 2250.19,109.205 2250.19,109.2 2250.2,109.195 2250.21,109.191 2250.22,109.186 2250.23,109.181 2250.24,109.177 2250.25,109.172 2250.26,109.167 2250.27,109.163 2250.28,109.158 2250.29,109.153 2250.3,109.149 2250.3,109.144 2250.31,109.139 2250.32,109.135 2250.33,109.13 2250.34,109.126 2250.35,109.121 2250.36,109.116 2250.37,109.112 2250.38,109.107 2250.39,109.102 2250.4,109.098 2250.41,109.093 2250.41,109.088 2250.42,109.084 2250.43,109.079 2250.44,109.074 2250.45,109.07 2250.46,109.065 2250.47,109.06 2250.48,109.056 2250.49,109.051 2250.5,109.047 2250.51,109.042 2250.52,109.037 2250.53,109.033 2250.53,109.028 2250.54,109.023 2250.55,109.019 2250.56,109.014 2250.57,109.009 2250.58,109.005 2250.59,109 2250.6,108.995 2250.61,108.991 2250.62,108.986 2250.63,108.981 2250.64,108.977 2250.64,108.972 2250.65,108.968 2250.66,108.963 2250.67,108.958 2250.68,108.954 2250.69,108.949 2250.7,108.944 2250.71,108.94 2250.72,108.935 2250.73,108.93 2250.74,108.926 2250.75,108.921 2250.75,108.916 2250.76,108.912 2250.77,108.907 2250.78,108.903 2250.79,108.898 2250.8,108.893 2250.81,108.889 2250.82,108.884 2250.83,108.879 2250.84,108.875 2250.85,108.87 2250.86,108.865 2250.87,108.861 2250.87,108.856 2250.88,108.851 2250.89,108.847 2250.9,108.842 2250.91,108.838 2250.92,108.833 2250.93,108.828 2250.94,108.824 2250.95,108.819 2250.96,108.814 2250.97,108.81 2250.98,108.805 2250.98,108.8 2250.99,108.796 2251,108.791 2251.01,108.787 2251.02,108.782 2251.03,108.777 2251.04,108.773 2251.05,108.768 2251.06,108.763 2251.07,108.759 2251.08,108.754 2251.09,108.749 2251.09,108.745 2251.1,108.74 2251.11,108.736 2251.12,108.731 2251.13,108.726 2251.14,108.722 2251.15,108.717 2251.16,108.712 2251.17,108.708 2251.18,108.703 2251.19,108.698 2251.2,108.694 2251.21,108.689 2251.21,108.685 2251.22,108.68 2251.23,108.675 2251.24,108.671 2251.25,108.666 2251.26,108.661 2251.27,108.657 2251.28,108.652 2251.29,108.648 2251.3,108.643 2251.31,108.638 2251.32,108.634 2251.32,108.629 2251.33,108.624 2251.34,108.62 2251.35,108.615 2251.36,108.61 2251.37,108.606 2251.38,108.601 2251.39,108.597 2251.4,108.592 2251.41,108.587 2251.42,108.583 2251.43,108.578 2251.43,108.573 2251.44,108.569 2251.45,108.564 2251.46,108.56 2251.47,108.555 2251.48,108.55 2251.49,108.546 2251.5,108.541 2251.51,108.536 2251.52,108.532 2251.53,108.527 2251.54,108.522 2251.55,108.518 2251.55,108.513 2251.56,108.509 2251.57,108.504 2251.58,108.499 2251.59,108.495 2251.6,108.49 2251.61,108.485 2251.62,108.481 2251.63,108.476 2251.64,108.472 2251.65,108.467 2251.66,108.462 2251.66,108.458 2251.67,108.453 2251.68,108.448 2251.69,108.444 2251.7,108.439 2251.71,108.435 2251.72,108.43 2251.73,108.425 2251.74,108.421 2251.75,108.416 2251.76,108.411 2251.77,108.407 2251.77,108.402 2251.78,108.398 2251.79,108.393 2251.8,108.388 2251.81,108.384 2251.82,108.379 2251.83,108.374 2251.84,108.37 2251.85,108.365 2251.86,108.361 2251.87,108.356 2251.88,108.351 2251.89,108.347 2251.89,108.342 2251.9,108.337 2251.91,108.333 2251.92,108.328 2251.93,108.324 2251.94,108.319 2251.95,108.314 2251.96,108.31 2251.97,108.305 2251.98,108.3 2251.99,108.296 2252,108.291 2252,108.287 2252.01,108.282 2252.02,108.277 2252.03,108.273 2252.04,108.268 2252.05,108.264 2252.06,108.259 2252.07,108.254 2252.08,108.25 2252.09,108.245 2252.1,108.24 2252.11,108.236 2252.11,108.231 2252.12,108.227 2252.13,108.222 2252.14,108.217 2252.15,108.213 2252.16,108.208 2252.17,108.203 2252.18,108.199 2252.19,108.194 2252.2,108.19 2252.21,108.185 2252.22,108.18 2252.23,108.176 2252.23,108.171 2252.24,108.167 2252.25,108.162 2252.26,108.157 2252.27,108.153 2252.28,108.148 2252.29,108.143 2252.3,108.139 2252.31,108.134 2252.32,108.13 2252.33,108.125 2252.34,108.12 2252.34,108.116 2252.35,108.111 2252.36,108.107 2252.37,108.102 2252.38,108.097 2252.39,108.093 2252.4,108.088 2252.41,108.083 2252.42,108.079 2252.43,108.074 2252.44,108.07 2252.45,108.065 2252.45,108.06 2252.46,108.056 2252.47,108.051 2252.48,108.047 2252.49,108.042 2252.5,108.037 2252.51,108.033 2252.52,108.028 2252.53,108.024 2252.54,108.019 2252.55,108.014 2252.56,108.01 2252.57,108.005 2252.57,108 2252.58,107.996 2252.59,107.991 2252.6,107.987 2252.61,107.982 2252.62,107.977 2252.63,107.973 2252.64,107.968 2252.65,107.964 2252.66,107.959 2252.67,107.954 2252.68,107.95 2252.68,107.945 2252.69,107.941 2252.7,107.936 2252.71,107.931 2252.72,107.927 2252.73,107.922 2252.74,107.918 2252.75,107.913 2252.76,107.908 2252.77,107.904 2252.78,107.899 2252.79,107.894 2252.79,107.89 2252.8,107.885 2252.81,107.881 2252.82,107.876 2252.83,107.871 2252.84,107.867 2252.85,107.862 2252.86,107.858 2252.87,107.853 2252.88,107.848 2252.89,107.844 2252.9,107.839 2252.91,107.835 2252.91,107.83 2252.92,107.825 2252.93,107.821 2252.94,107.816 2252.95,107.812 2252.96,107.807 2252.97,107.802 2252.98,107.798 2252.99,107.793 2253,107.789 2253.01,107.784 2253.02,107.779 2253.02,107.775 2253.03,107.77 2253.04,107.766 2253.05,107.761 2253.06,107.756 2253.07,107.752 2253.08,107.747 2253.09,107.743 2253.1,107.738 2253.11,107.733 2253.12,107.729 2253.13,107.724 2253.13,107.72 2253.14,107.715 2253.15,107.71 2253.16,107.706 2253.17,107.701 2253.18,107.697 2253.19,107.692 2253.2,107.687 2253.21,107.683 2253.22,107.678 2253.23,107.674 2253.24,107.669 2253.25,107.664 2253.25,107.66 2253.26,107.655 2253.27,107.651 2253.28,107.646 2253.29,107.641 2253.3,107.637 2253.31,107.632 2253.32,107.628 2253.33,107.623 2253.34,107.618 2253.35,107.614 2253.36,107.609 2253.36,107.605 2253.37,107.6 2253.38,107.595 2253.39,107.591 2253.4,107.586 2253.41,107.582 2253.42,107.577 2253.43,107.572 2253.44,107.568 2253.45,107.563 2253.46,107.559 2253.47,107.554 2253.47,107.549 2253.48,107.545 2253.49,107.54 2253.5,107.536 2253.51,107.531 2253.52,107.526 2253.53,107.522 2253.54,107.517 2253.55,107.513 2253.56,107.508 2253.57,107.503 2253.58,107.499 2253.59,107.494 2253.59,107.49 2253.6,107.485 2253.61,107.48 2253.62,107.476 2253.63,107.471 2253.64,107.467 2253.65,107.462 2253.66,107.458 2253.67,107.453 2253.68,107.448 2253.69,107.444 2253.7,107.439 2253.7,107.435 2253.71,107.43 2253.72,107.425 2253.73,107.421 2253.74,107.416 2253.75,107.412 2253.76,107.407 2253.77,107.402 2253.78,107.398 2253.79,107.393 2253.8,107.389 2253.81,107.384 2253.81,107.379 2253.82,107.375 2253.83,107.37 2253.84,107.366 2253.85,107.361 2253.86,107.357 2253.87,107.352 2253.88,107.347 2253.89,107.343 2253.9,107.338 2253.91,107.334 2253.92,107.329 2253.93,107.324 2253.93,107.32 2253.94,107.315 2253.95,107.311 2253.96,107.306 2253.97,107.301 2253.98,107.297 2253.99,107.292 2254,107.288 2254.01,107.283 2254.02,107.279 2254.03,107.274 2254.04,107.269 2254.04,107.265 2254.05,107.26 2254.06,107.256 2254.07,107.251 2254.08,107.246 2254.09,107.242 2254.1,107.237 2254.11,107.233 2254.12,107.228 2254.13,107.224 2254.14,107.219 2254.15,107.214 2254.15,107.21 2254.16,107.205 2254.17,107.201 2254.18,107.196 2254.19,107.191 2254.2,107.187 2254.21,107.182 2254.22,107.178 2254.23,107.173 2254.24,107.169 2254.25,107.164 2254.26,107.159 2254.27,107.155 2254.27,107.15 2254.28,107.146 2254.29,107.141 2254.3,107.136 2254.31,107.132 2254.32,107.127 2254.33,107.123 2254.34,107.118 2254.35,107.114 2254.36,107.109 2254.37,107.104 2254.38,107.1 2254.38,107.095 2254.39,107.091 2254.4,107.086 2254.41,107.081 2254.42,107.077 2254.43,107.072 2254.44,107.068 2254.45,107.063 2254.46,107.059 2254.47,107.054 2254.48,107.049 2254.49,107.045 2254.49,107.04 2254.5,107.036 2254.51,107.031 2254.52,107.027 2254.53,107.022 2254.54,107.017 2254.55,107.013 2254.56,107.008 2254.57,107.004 2254.58,106.999 2254.59,106.995 2254.6,106.99 2254.61,106.985 2254.61,106.981 2254.62,106.976 2254.63,106.972 2254.64,106.967 2254.65,106.962 2254.66,106.958 2254.67,106.953 2254.68,106.949 2254.69,106.944 2254.7,106.94 2254.71,106.935 2254.72,106.93 2254.72,106.926 2254.73,106.921 2254.74,106.917 2254.75,106.912 2254.76,106.908 2254.77,106.903 2254.78,106.898 2254.79,106.894 2254.8,106.889 2254.81,106.885 2254.82,106.88 2254.83,106.876 2254.83,106.871 2254.84,106.866 2254.85,106.862 2254.86,106.857 2254.87,106.853 2254.88,106.848 2254.89,106.844 2254.9,106.839 2254.91,106.834 2254.92,106.83 2254.93,106.825 2254.94,106.821 2254.95,106.816 2254.95,106.812 2254.96,106.807 2254.97,106.802 2254.98,106.798 2254.99,106.793 2255,106.789 2255.01,106.784 2255.02,106.78 2255.03,106.775 2255.04,106.77 2255.05,106.766 2255.06,106.761 2255.06,106.757 2255.07,106.752 2255.08,106.748 2255.09,106.743 2255.1,106.738 2255.11,106.734 2255.12,106.729 2255.13,106.725 2255.14,106.72 2255.15,106.716 2255.16,106.711 2255.17,106.706 2255.17,106.702 2255.18,106.697 2255.19,106.693 2255.2,106.688 2255.21,106.684 2255.22,106.679 2255.23,106.675 2255.24,106.67 2255.25,106.665 2255.26,106.661 2255.27,106.656 2255.28,106.652 2255.29,106.647 2255.29,106.643 2255.3,106.638 2255.31,106.633 2255.32,106.629 2255.33,106.624 2255.34,106.62 2255.35,106.615 2255.36,106.611 2255.37,106.606 2255.38,106.601 2255.39,106.597 2255.4,106.592 2255.4,106.588 2255.41,106.583 2255.42,106.579 2255.43,106.574 2255.44,106.57 2255.45,106.565 2255.46,106.56 2255.47,106.556 2255.48,106.551 2255.49,106.547 2255.5,106.542 2255.51,106.538 2255.51,106.533 2255.52,106.528 2255.53,106.524 2255.54,106.519 2255.55,106.515 2255.56,106.51 2255.57,106.506 2255.58,106.501 2255.59,106.497 2255.6,106.492 2255.61,106.487 2255.62,106.483 2255.63,106.478 2255.63,106.474 2255.64,106.469 2255.65,106.465 2255.66,106.46 2255.67,106.456 2255.68,106.451 2255.69,106.446 2255.7,106.442 2255.71,106.437 2255.72,106.433 2255.73,106.428 2255.74,106.424 2255.74,106.419 2255.75,106.415 2255.76,106.41 2255.77,106.405 2255.78,106.401 2255.79,106.396 2255.8,106.392 2255.81,106.387 2255.82,106.383 2255.83,106.378 2255.84,106.373 2255.85,106.369 2255.85,106.364 2255.86,106.36 2255.87,106.355 2255.88,106.351 2255.89,106.346 2255.9,106.342 2255.91,106.337 2255.92,106.332 2255.93,106.328 2255.94,106.323 2255.95,106.319 2255.96,106.314 2255.97,106.31 2255.97,106.305 2255.98,106.301 2255.99,106.296 2256,106.292 2256.01,106.287 2256.02,106.282 2256.03,106.278 2256.04,106.273 2256.05,106.269 2256.06,106.264 2256.07,106.26 2256.08,106.255 2256.08,106.251 2256.09,106.246 2256.1,106.241 2256.11,106.237 2256.12,106.232 2256.13,106.228 2256.14,106.223 2256.15,106.219 2256.16,106.214 2256.17,106.21 2256.18,106.205 2256.19,106.2 2256.19,106.196 2256.2,106.191 2256.21,106.187 2256.22,106.182 2256.23,106.178 2256.24,106.173 2256.25,106.169 2256.26,106.164 2256.27,106.16 2256.28,106.155 2256.29,106.15 2256.3,106.146 2256.31,106.141 2256.31,106.137 2256.32,106.132 2256.33,106.128 2256.34,106.123 2256.35,106.119 2256.36,106.114 2256.37,106.109 2256.38,106.105 2256.39,106.1 2256.4,106.096 2256.41,106.091 2256.42,106.087 2256.42,106.082 2256.43,106.078 2256.44,106.073 2256.45,106.069 2256.46,106.064 2256.47,106.059 2256.48,106.055 2256.49,106.05 2256.5,106.046 2256.51,106.041 2256.52,106.037 2256.53,106.032 2256.53,106.028 2256.54,106.023 2256.55,106.019 2256.56,106.014 2256.57,106.009 2256.58,106.005 2256.59,106 2256.6,105.996 2256.61,105.991 2256.62,105.987 2256.63,105.982 2256.64,105.978 2256.65,105.973 2256.65,105.969 2256.66,105.964 2256.67,105.959 2256.68,105.955 2256.69,105.95 2256.7,105.946 2256.71,105.941 2256.72,105.937 2256.73,105.932 2256.74,105.928 2256.75,105.923 2256.76,105.919 2256.76,105.914 2256.77,105.91 2256.78,105.905 2256.79,105.9 2256.8,105.896 2256.81,105.891 2256.82,105.887 2256.83,105.882 2256.84,105.878 2256.85,105.873 2256.86,105.869 2256.87,105.864 2256.87,105.86 2256.88,105.855 2256.89,105.851 2256.9,105.846 2256.91,105.841 2256.92,105.837 2256.93,105.832 2256.94,105.828 2256.95,105.823 2256.96,105.819 2256.97,105.814 2256.98,105.81 2256.99,105.805 2256.99,105.801 2257,105.796 2257.01,105.792 2257.02,105.787 2257.03,105.782 2257.04,105.778 2257.05,105.773 2257.06,105.769 2257.07,105.764 2257.08,105.76 2257.09,105.755 2257.1,105.751 2257.1,105.746 2257.11,105.742 2257.12,105.737 2257.13,105.733 2257.14,105.728 2257.15,105.723 2257.16,105.719 2257.17,105.714 2257.18,105.71 2257.19,105.705 2257.2,105.701 2257.21,105.696 2257.21,105.692 2257.22,105.687 2257.23,105.683 2257.24,105.678 2257.25,105.674 2257.26,105.669 2257.27,105.665 2257.28,105.66 2257.29,105.655 2257.3,105.651 2257.31,105.646 2257.32,105.642 2257.33,105.637 2257.33,105.633 2257.34,105.628 2257.35,105.624 2257.36,105.619 2257.37,105.615 2257.38,105.61 2257.39,105.606 2257.4,105.601 2257.41,105.597 2257.42,105.592 2257.43,105.588 2257.44,105.583 2257.44,105.578 2257.45,105.574 2257.46,105.569 2257.47,105.565 2257.48,105.56 2257.49,105.556 2257.5,105.551 2257.51,105.547 2257.52,105.542 2257.53,105.538 2257.54,105.533 2257.55,105.529 2257.55,105.524 2257.56,105.52 2257.57,105.515 2257.58,105.511 2257.59,105.506 2257.6,105.501 2257.61,105.497 2257.62,105.492 2257.63,105.488 2257.64,105.483 2257.65,105.479 2257.66,105.474 2257.67,105.47 2257.67,105.465 2257.68,105.461 2257.69,105.456 2257.7,105.452 2257.71,105.447 2257.72,105.443 2257.73,105.438 2257.74,105.434 2257.75,105.429 2257.76,105.424 2257.77,105.42 2257.78,105.415 2257.78,105.411 2257.79,105.406 2257.8,105.402 2257.81,105.397 2257.82,105.393 2257.83,105.388 2257.84,105.384 2257.85,105.379 2257.86,105.375 2257.87,105.37 2257.88,105.366 2257.89,105.361 2257.89,105.357 2257.9,105.352 2257.91,105.348 2257.92,105.343 2257.93,105.339 2257.94,105.334 2257.95,105.329 2257.96,105.325 2257.97,105.32 2257.98,105.316 2257.99,105.311 2258,105.307 2258.01,105.302 2258.01,105.298 2258.02,105.293 2258.03,105.289 2258.04,105.284 2258.05,105.28 2258.06,105.275 2258.07,105.271 2258.08,105.266 2258.09,105.262 2258.1,105.257 2258.11,105.253 2258.12,105.248 2258.12,105.244 2258.13,105.239 2258.14,105.235 2258.15,105.23 2258.16,105.226 2258.17,105.221 2258.18,105.216 2258.19,105.212 2258.2,105.207 2258.21,105.203 2258.22,105.198 2258.23,105.194 2258.23,105.189 2258.24,105.185 2258.25,105.18 2258.26,105.176 2258.27,105.171 2258.28,105.167 2258.29,105.162 2258.3,105.158 2258.31,105.153 2258.32,105.149 2258.33,105.144 2258.34,105.14 2258.35,105.135 2258.35,105.131 2258.36,105.126 2258.37,105.122 2258.38,105.117 2258.39,105.113 2258.4,105.108 2258.41,105.104 2258.42,105.099 2258.43,105.095 2258.44,105.09 2258.45,105.086 2258.46,105.081 2258.46,105.076 2258.47,105.072 2258.48,105.067 2258.49,105.063 2258.5,105.058 2258.51,105.054 2258.52,105.049 2258.53,105.045 2258.54,105.04 2258.55,105.036 2258.56,105.031 2258.57,105.027 2258.57,105.022 2258.58,105.018 2258.59,105.013 2258.6,105.009 2258.61,105.004 2258.62,105 2258.63,104.995 2258.64,104.991 2258.65,104.986 2258.66,104.982 2258.67,104.977 2258.68,104.973 2258.69,104.968 2258.69,104.964 2258.7,104.959 2258.71,104.955 2258.72,104.95 2258.73,104.946 2258.74,104.941 2258.75,104.937 2258.76,104.932 2258.77,104.928 2258.78,104.923 2258.79,104.919 2258.8,104.914 2258.8,104.91 2258.81,104.905 2258.82,104.901 2258.83,104.896 2258.84,104.892 2258.85,104.887 2258.86,104.882 2258.87,104.878 2258.88,104.873 2258.89,104.869 2258.9,104.864 2258.91,104.86 2258.91,104.855 2258.92,104.851 2258.93,104.846 2258.94,104.842 2258.95,104.837 2258.96,104.833 2258.97,104.828 2258.98,104.824 2258.99,104.819 2259,104.815 2259.01,104.81 2259.02,104.806 2259.03,104.801 2259.03,104.797 2259.04,104.792 2259.05,104.788 2259.06,104.783 2259.07,104.779 2259.08,104.774 2259.09,104.77 2259.1,104.765 2259.11,104.761 2259.12,104.756 2259.13,104.752 2259.14,104.747 2259.14,104.743 2259.15,104.738 2259.16,104.734 2259.17,104.729 2259.18,104.725 2259.19,104.72 2259.2,104.716 2259.21,104.711 2259.22,104.707 2259.23,104.702 2259.24,104.698 2259.25,104.693 2259.25,104.689 2259.26,104.684 2259.27,104.68 2259.28,104.675 2259.29,104.671 2259.3,104.666 2259.31,104.662 2259.32,104.657 2259.33,104.653 2259.34,104.648 2259.35,104.644 2259.36,104.639 2259.37,104.635 2259.37,104.63 2259.38,104.626 2259.39,104.621 2259.4,104.617 2259.41,104.612 2259.42,104.608 2259.43,104.603 2259.44,104.599 2259.45,104.594 2259.46,104.59 2259.47,104.585 2259.48,104.581 2259.48,104.576 2259.49,104.572 2259.5,104.567 2259.51,104.563 2259.52,104.558 2259.53,104.554 2259.54,104.549 2259.55,104.545 2259.56,104.54 2259.57,104.536 2259.58,104.531 2259.59,104.527 2259.59,104.522 2259.6,104.518 2259.61,104.513 2259.62,104.509 2259.63,104.504 2259.64,104.5 2259.65,104.495 2259.66,104.491 2259.67,104.486 2259.68,104.482 2259.69,104.477 2259.7,104.473 2259.71,104.468 2259.71,104.464 2259.72,104.459 2259.73,104.455 2259.74,104.45 2259.75,104.446 2259.76,104.441 2259.77,104.437 2259.78,104.432 2259.79,104.428 2259.8,104.423 2259.81,104.419 2259.82,104.414 2259.82,104.41 2259.83,104.405 2259.84,104.401 2259.85,104.396 2259.86,104.392 2259.87,104.387 2259.88,104.383 2259.89,104.378 2259.9,104.374 2259.91,104.37 2259.92,104.365 2259.93,104.361 2259.93,104.356 2259.94,104.352 2259.95,104.347 2259.96,104.343 2259.97,104.338 2259.98,104.334 2259.99,104.329 2260,104.325 2260.01,104.32 2260.02,104.316 2260.03,104.311 2260.04,104.307 2260.05,104.302 2260.05,104.298 2260.06,104.293 2260.07,104.289 2260.08,104.284 2260.09,104.28 2260.1,104.275 2260.11,104.271 2260.12,104.266 2260.13,104.262 2260.14,104.257 2260.15,104.253 2260.16,104.248 2260.16,104.244 2260.17,104.239 2260.18,104.235 2260.19,104.23 2260.2,104.226 2260.21,104.221 2260.22,104.217 2260.23,104.212 2260.24,104.208 2260.25,104.203 2260.26,104.199 2260.27,104.194 2260.27,104.19 2260.28,104.185 2260.29,104.181 2260.3,104.176 2260.31,104.172 2260.32,104.168 2260.33,104.163 2260.34,104.159 2260.35,104.154 2260.36,104.15 2260.37,104.145 2260.38,104.141 2260.39,104.136 2260.39,104.132 2260.4,104.127 2260.41,104.123 2260.42,104.118 2260.43,104.114 2260.44,104.109 2260.45,104.105 2260.46,104.1 2260.47,104.096 2260.48,104.091 2260.49,104.087 2260.5,104.082 2260.5,104.078 2260.51,104.073 2260.52,104.069 2260.53,104.064 2260.54,104.06 2260.55,104.055 2260.56,104.051 2260.57,104.046 2260.58,104.042 2260.59,104.037 2260.6,104.033 2260.61,104.029 2260.61,104.024 2260.62,104.02 2260.63,104.015 2260.64,104.011 2260.65,104.006 2260.66,104.002 2260.67,103.997 2260.68,103.993 2260.69,103.988 2260.7,103.984 2260.71,103.979 2260.72,103.975 2260.73,103.97 2260.73,103.966 2260.74,103.961 2260.75,103.957 2260.76,103.952 2260.77,103.948 2260.78,103.943 2260.79,103.939 2260.8,103.934 2260.81,103.93 2260.82,103.925 2260.83,103.921 2260.84,103.917 2260.84,103.912 2260.85,103.908 2260.86,103.903 2260.87,103.899 2260.88,103.894 2260.89,103.89 2260.9,103.885 2260.91,103.881 2260.92,103.876 2260.93,103.872 2260.94,103.867 2260.95,103.863 2260.95,103.858 2260.96,103.854 2260.97,103.849 2260.98,103.845 2260.99,103.84 2261,103.836 2261.01,103.831 2261.02,103.827 2261.03,103.823 2261.04,103.818 2261.05,103.814 2261.06,103.809 2261.07,103.805 2261.07,103.8 2261.08,103.796 2261.09,103.791 2261.1,103.787 2261.11,103.782 2261.12,103.778 2261.13,103.773 2261.14,103.769 2261.15,103.764 2261.16,103.76 2261.17,103.755 2261.18,103.751 2261.18,103.746 2261.19,103.742 2261.2,103.738 2261.21,103.733 2261.22,103.729 2261.23,103.724 2261.24,103.72 2261.25,103.715 2261.26,103.711 2261.27,103.706 2261.28,103.702 2261.29,103.697 2261.29,103.693 2261.3,103.688 2261.31,103.684 2261.32,103.679 2261.33,103.675 2261.34,103.67 2261.35,103.666 2261.36,103.662 2261.37,103.657 2261.38,103.653 2261.39,103.648 2261.4,103.644 2261.41,103.639 2261.41,103.635 2261.42,103.63 2261.43,103.626 2261.44,103.621 2261.45,103.617 2261.46,103.612 2261.47,103.608 2261.48,103.603 2261.49,103.599 2261.5,103.595 2261.51,103.59 2261.52,103.586 2261.52,103.581 2261.53,103.577 2261.54,103.572 2261.55,103.568 2261.56,103.563 2261.57,103.559 2261.58,103.554 2261.59,103.55 2261.6,103.545 2261.61,103.541 2261.62,103.536 2261.63,103.532 2261.63,103.528 2261.64,103.523 2261.65,103.519 2261.66,103.514 2261.67,103.51 2261.68,103.505 2261.69,103.501 2261.7,103.496 2261.71,103.492 2261.72,103.487 2261.73,103.483 2261.74,103.478 2261.75,103.474 2261.75,103.469 2261.76,103.465 2261.77,103.461 2261.78,103.456 2261.79,103.452 2261.8,103.447 2261.81,103.443 2261.82,103.438 2261.83,103.434 2261.84,103.429 2261.85,103.425 2261.86,103.42 2261.86,103.416 2261.87,103.411 2261.88,103.407 2261.89,103.403 2261.9,103.398 2261.91,103.394 2261.92,103.389 2261.93,103.385 2261.94,103.38 2261.95,103.376 2261.96,103.371 2261.97,103.367 2261.97,103.362 2261.98,103.358 2261.99,103.353 2262,103.349 2262.01,103.345 2262.02,103.34 2262.03,103.336 2262.04,103.331 2262.05,103.327 2262.06,103.322 2262.07,103.318 2262.08,103.313 2262.09,103.309 2262.09,103.304 2262.1,103.3 2262.11,103.295 2262.12,103.291 2262.13,103.287 2262.14,103.282 2262.15,103.278 2262.16,103.273 2262.17,103.269 2262.18,103.264 2262.19,103.26 2262.2,103.255 2262.2,103.251 2262.21,103.246 2262.22,103.242 2262.23,103.238 2262.24,103.233 2262.25,103.229 2262.26,103.224 2262.27,103.22 2262.28,103.215 2262.29,103.211 2262.3,103.206 2262.31,103.202 2262.31,103.197 2262.32,103.193 2262.33,103.188 2262.34,103.184 2262.35,103.18 2262.36,103.175 2262.37,103.171 2262.38,103.166 2262.39,103.162 2262.4,103.157 2262.41,103.153 2262.42,103.148 2262.43,103.144 2262.43,103.139 2262.44,103.135 2262.45,103.131 2262.46,103.126 2262.47,103.122 2262.48,103.117 2262.49,103.113 2262.5,103.108 2262.51,103.104 2262.52,103.099 2262.53,103.095 2262.54,103.091 2262.54,103.086 2262.55,103.082 2262.56,103.077 2262.57,103.073 2262.58,103.068 2262.59,103.064 2262.6,103.059 2262.61,103.055 2262.62,103.05 2262.63,103.046 2262.64,103.042 2262.65,103.037 2262.65,103.033 2262.66,103.028 2262.67,103.024 2262.68,103.019 2262.69,103.015 2262.7,103.01 2262.71,103.006 2262.72,103.001 2262.73,102.997 2262.74,102.993 2262.75,102.988 2262.76,102.984 2262.77,102.979 2262.77,102.975 2262.78,102.97 2262.79,102.966 2262.8,102.961 2262.81,102.957 2262.82,102.953 2262.83,102.948 2262.84,102.944 2262.85,102.939 2262.86,102.935 2262.87,102.93 2262.88,102.926 2262.88,102.921 2262.89,102.917 2262.9,102.913 2262.91,102.908 2262.92,102.904 2262.93,102.899 2262.94,102.895 2262.95,102.89 2262.96,102.886 2262.97,102.881 2262.98,102.877 2262.99,102.873 2262.99,102.868 2263,102.864 2263.01,102.859 2263.02,102.855 2263.03,102.85 2263.04,102.846 2263.05,102.841 2263.06,102.837 2263.07,102.833 2263.08,102.828 2263.09,102.824 2263.1,102.819 2263.11,102.815 2263.11,102.81 2263.12,102.806 2263.13,102.801 2263.14,102.797 2263.15,102.793 2263.16,102.788 2263.17,102.784 2263.18,102.779 2263.19,102.775 2263.2,102.77 2263.21,102.766 2263.22,102.761 2263.22,102.757 2263.23,102.753 2263.24,102.748 2263.25,102.744 2263.26,102.739 2263.27,102.735 2263.28,102.73 2263.29,102.726 2263.3,102.721 2263.31,102.717 2263.32,102.713 2263.33,102.708 2263.33,102.704 2263.34,102.699 2263.35,102.695 2263.36,102.69 2263.37,102.686 2263.38,102.681 2263.39,102.677 2263.4,102.673 2263.41,102.668 2263.42,102.664 2263.43,102.659 2263.44,102.655 2263.45,102.65 2263.45,102.646 2263.46,102.642 2263.47,102.637 2263.48,102.633 2263.49,102.628 2263.5,102.624 2263.51,102.619 2263.52,102.615 2263.53,102.61 2263.54,102.606 2263.55,102.602 2263.56,102.597 2263.56,102.593 2263.57,102.588 2263.58,102.584 2263.59,102.579 2263.6,102.575 2263.61,102.571 2263.62,102.566 2263.63,102.562 2263.64,102.557 2263.65,102.553 2263.66,102.548 2263.67,102.544 2263.67,102.539 2263.68,102.535 2263.69,102.531 2263.7,102.526 2263.71,102.522 2263.72,102.517 2263.73,102.513 2263.74,102.508 2263.75,102.504 2263.76,102.5 2263.77,102.495 2263.78,102.491 2263.79,102.486 2263.79,102.482 2263.8,102.477 2263.81,102.473 2263.82,102.468 2263.83,102.464 2263.84,102.46 2263.85,102.455 2263.86,102.451 2263.87,102.446 2263.88,102.442 2263.89,102.437 2263.9,102.433 2263.9,102.429 2263.91,102.424 2263.92,102.42 2263.93,102.415 2263.94,102.411 2263.95,102.406 2263.96,102.402 2263.97,102.398 2263.98,102.393 2263.99,102.389 2264,102.384 2264.01,102.38 2264.01,102.375 2264.02,102.371 2264.03,102.367 2264.04,102.362 2264.05,102.358 2264.06,102.353 2264.07,102.349 2264.08,102.344 2264.09,102.34 2264.1,102.336 2264.11,102.331 2264.12,102.327 2264.13,102.322 2264.13,102.318 2264.14,102.313 2264.15,102.309 2264.16,102.305 2264.17,102.3 2264.18,102.296 2264.19,102.291 2264.2,102.287 2264.21,102.282 2264.22,102.278 2264.23,102.274 2264.24,102.269 2264.24,102.265 2264.25,102.26 2264.26,102.256 2264.27,102.251 2264.28,102.247 2264.29,102.243 2264.3,102.238 2264.31,102.234 2264.32,102.229 2264.33,102.225 2264.34,102.22 2264.35,102.216 2264.35,102.212 2264.36,102.207 2264.37,102.203 2264.38,102.198 2264.39,102.194 2264.4,102.189 2264.41,102.185 2264.42,102.181 2264.43,102.176 2264.44,102.172 2264.45,102.167 2264.46,102.163 2264.47,102.158 2264.47,102.154 2264.48,102.15 2264.49,102.145 2264.5,102.141 2264.51,102.136 2264.52,102.132 2264.53,102.127 2264.54,102.123 2264.55,102.119 2264.56,102.114 2264.57,102.11 2264.58,102.105 2264.58,102.101 2264.59,102.097 2264.6,102.092 2264.61,102.088 2264.62,102.083 2264.63,102.079 2264.64,102.074 2264.65,102.07 2264.66,102.066 2264.67,102.061 2264.68,102.057 2264.69,102.052 2264.69,102.048 2264.7,102.043 2264.71,102.039 2264.72,102.035 2264.73,102.03 2264.74,102.026 2264.75,102.021 2264.76,102.017 2264.77,102.013 2264.78,102.008 2264.79,102.004 2264.8,101.999 2264.81,101.995 2264.81,101.99 2264.82,101.986 2264.83,101.982 2264.84,101.977 2264.85,101.973 2264.86,101.968 2264.87,101.964 2264.88,101.96 2264.89,101.955 2264.9,101.951 2264.91,101.946 2264.92,101.942 2264.92,101.937 2264.93,101.933 2264.94,101.929 2264.95,101.924 2264.96,101.92 2264.97,101.915 2264.98,101.911 2264.99,101.906 2265,101.902 2265.01,101.898 2265.02,101.893 2265.03,101.889 2265.03,101.884 2265.04,101.88 2265.05,101.876 2265.06,101.871 2265.07,101.867 2265.08,101.862 2265.09,101.858 2265.1,101.853 2265.11,101.849 2265.12,101.845 2265.13,101.84 2265.14,101.836 2265.15,101.831 2265.15,101.827 2265.16,101.823 2265.17,101.818 2265.18,101.814 2265.19,101.809 2265.2,101.805 2265.21,101.801 2265.22,101.796 2265.23,101.792 2265.24,101.787 2265.25,101.783 2265.26,101.778 2265.26,101.774 2265.27,101.77 2265.28,101.765 2265.29,101.761 2265.3,101.756 2265.31,101.752 2265.32,101.748 2265.33,101.743 2265.34,101.739 2265.35,101.734 2265.36,101.73 2265.37,101.726 2265.37,101.721 2265.38,101.717 2265.39,101.712 2265.4,101.708 2265.41,101.703 2265.42,101.699 2265.43,101.695 2265.44,101.69 2265.45,101.686 2265.46,101.681 2265.47,101.677 2265.48,101.673 2265.49,101.668 2265.49,101.664 2265.5,101.659 2265.51,101.655 2265.52,101.651 2265.53,101.646 2265.54,101.642 2265.55,101.637 2265.56,101.633 2265.57,101.628 2265.58,101.624 2265.59,101.62 2265.6,101.615 2265.6,101.611 2265.61,101.606 2265.62,101.602 2265.63,101.598 2265.64,101.593 2265.65,101.589 2265.66,101.584 2265.67,101.58 2265.68,101.576 2265.69,101.571 2265.7,101.567 2265.71,101.562 2265.71,101.558 2265.72,101.554 2265.73,101.549 2265.74,101.545 2265.75,101.54 2265.76,101.536 2265.77,101.532 2265.78,101.527 2265.79,101.523 2265.8,101.518 2265.81,101.514 2265.82,101.509 2265.83,101.505 2265.83,101.501 2265.84,101.496 2265.85,101.492 2265.86,101.487 2265.87,101.483 2265.88,101.479 2265.89,101.474 2265.9,101.47 2265.91,101.465 2265.92,101.461 2265.93,101.457 2265.94,101.452 2265.94,101.448 2265.95,101.443 2265.96,101.439 2265.97,101.435 2265.98,101.43 2265.99,101.426 2266,101.421 2266.01,101.417 2266.02,101.413 2266.03,101.408 2266.04,101.404 2266.05,101.399 2266.05,101.395 2266.06,101.391 2266.07,101.386 2266.08,101.382 2266.09,101.377 2266.1,101.373 2266.11,101.369 2266.12,101.364 2266.13,101.36 2266.14,101.355 2266.15,101.351 2266.16,101.347 2266.17,101.342 2266.17,101.338 2266.18,101.333 2266.19,101.329 2266.2,101.325 2266.21,101.32 2266.22,101.316 2266.23,101.311 2266.24,101.307 2266.25,101.303 2266.26,101.298 2266.27,101.294 2266.28,101.289 2266.28,101.285 2266.29,101.281 2266.3,101.276 2266.31,101.272 2266.32,101.267 2266.33,101.263 2266.34,101.259 2266.35,101.254 2266.36,101.25 2266.37,101.245 2266.38,101.241 2266.39,101.237 2266.39,101.232 2266.4,101.228 2266.41,101.223 2266.42,101.219 2266.43,101.215 2266.44,101.21 2266.45,101.206 2266.46,101.201 2266.47,101.197 2266.48,101.193 2266.49,101.188 2266.5,101.184 2266.51,101.179 2266.51,101.175 2266.52,101.171 2266.53,101.166 2266.54,101.162 2266.55,101.157 2266.56,101.153 2266.57,101.149 2266.58,101.144 2266.59,101.14 2266.6,101.136 2266.61,101.131 2266.62,101.127 2266.62,101.122 2266.63,101.118 2266.64,101.114 2266.65,101.109 2266.66,101.105 2266.67,101.1 2266.68,101.096 2266.69,101.092 2266.7,101.087 2266.71,101.083 2266.72,101.078 2266.73,101.074 2266.73,101.07 2266.74,101.065 2266.75,101.061 2266.76,101.056 2266.77,101.052 2266.78,101.048 2266.79,101.043 2266.8,101.039 2266.81,101.034 2266.82,101.03 2266.83,101.026 2266.84,101.021 2266.85,101.017 2266.85,101.013 2266.86,101.008 2266.87,101.004 2266.88,100.999 2266.89,100.995 2266.9,100.991 2266.91,100.986 2266.92,100.982 2266.93,100.977 2266.94,100.973 2266.95,100.969 2266.96,100.964 2266.96,100.96 2266.97,100.955 2266.98,100.951 2266.99,100.947 2267,100.942 2267.01,100.938 2267.02,100.934 2267.03,100.929 2267.04,100.925 2267.05,100.92 2267.06,100.916 2267.07,100.912 2267.07,100.907 2267.08,100.903 2267.09,100.898 2267.1,100.894 2267.11,100.89 2267.12,100.885 2267.13,100.881 2267.14,100.876 2267.15,100.872 2267.16,100.868 2267.17,100.863 2267.18,100.859 2267.19,100.855 2267.19,100.85 2267.2,100.846 2267.21,100.841 2267.22,100.837 2267.23,100.833 2267.24,100.828 2267.25,100.824 2267.26,100.819 2267.27,100.815 2267.28,100.811 2267.29,100.806 2267.3,100.802 2267.3,100.798 2267.31,100.793 2267.32,100.789 2267.33,100.784 2267.34,100.78 2267.35,100.776 2267.36,100.771 2267.37,100.767 2267.38,100.762 2267.39,100.758 2267.4,100.754 2267.41,100.749 2267.41,100.745 2267.42,100.741 2267.43,100.736 2267.44,100.732 2267.45,100.727 2267.46,100.723 2267.47,100.719 2267.48,100.714 2267.49,100.71 2267.5,100.705 2267.51,100.701 2267.52,100.697 2267.53,100.692 2267.53,100.688 2267.54,100.684 2267.55,100.679 2267.56,100.675 2267.57,100.67 2267.58,100.666 2267.59,100.662 2267.6,100.657 2267.61,100.653 2267.62,100.649 2267.63,100.644 2267.64,100.64 2267.64,100.635 2267.65,100.631 2267.66,100.627 2267.67,100.622 2267.68,100.618 2267.69,100.613 2267.7,100.609 2267.71,100.605 2267.72,100.6 2267.73,100.596 2267.74,100.592 2267.75,100.587 2267.75,100.583 2267.76,100.578 2267.77,100.574 2267.78,100.57 2267.79,100.565 2267.8,100.561 2267.81,100.557 2267.82,100.552 2267.83,100.548 2267.84,100.543 2267.85,100.539 2267.86,100.535 2267.87,100.53 2267.87,100.526 2267.88,100.522 2267.89,100.517 2267.9,100.513 2267.91,100.508 2267.92,100.504 2267.93,100.5 2267.94,100.495 2267.95,100.491 2267.96,100.487 2267.97,100.482 2267.98,100.478 2267.98,100.473 2267.99,100.469 2268,100.465 2268.01,100.46 2268.02,100.456 2268.03,100.452 2268.04,100.447 2268.05,100.443 2268.06,100.438 2268.07,100.434 2268.08,100.43 2268.09,100.425 2268.09,100.421 2268.1,100.417 2268.11,100.412 2268.12,100.408 2268.13,100.403 2268.14,100.399 2268.15,100.395 2268.16,100.39 2268.17,100.386 2268.18,100.382 2268.19,100.377 2268.2,100.373 2268.21,100.368 2268.21,100.364 2268.22,100.36 2268.23,100.355 2268.24,100.351 2268.25,100.347 2268.26,100.342 2268.27,100.338 2268.28,100.333 2268.29,100.329 2268.3,100.325 2268.31,100.32 2268.32,100.316 2268.32,100.312 2268.33,100.307 2268.34,100.303 2268.35,100.299 2268.36,100.294 2268.37,100.29 2268.38,100.285 2268.39,100.281 2268.4,100.277 2268.41,100.272 2268.42,100.268 2268.43,100.264 2268.43,100.259 2268.44,100.255 2268.45,100.25 2268.46,100.246 2268.47,100.242 2268.48,100.237 2268.49,100.233 2268.5,100.229 2268.51,100.224 2268.52,100.22 2268.53,100.215 2268.54,100.211 2268.55,100.207 2268.55,100.202 2268.56,100.198 2268.57,100.194 2268.58,100.189 2268.59,100.185 2268.6,100.181 2268.61,100.176 2268.62,100.172 2268.63,100.167 2268.64,100.163 2268.65,100.159 2268.66,100.154 2268.66,100.15 2268.67,100.146 2268.68,100.141 2268.69,100.137 2268.7,100.133 2268.71,100.128 2268.72,100.124 2268.73,100.119 2268.74,100.115 2268.75,100.111 2268.76,100.106 2268.77,100.102 2268.77,100.098 2268.78,100.093 2268.79,100.089 2268.8,100.085 2268.81,100.08 2268.82,100.076 2268.83,100.071 2268.84,100.067 2268.85,100.063 2268.86,100.058 2268.87,100.054 2268.88,100.05 2268.89,100.045 2268.89,100.041 2268.9,100.037 2268.91,100.032 2268.92,100.028 2268.93,100.023 2268.94,100.019 2268.95,100.015 2268.96,100.01 2268.97,100.006 2268.98,100.002 2268.99,99.9972 2269,99.9929 2269,99.9885 2269.01,99.9842 2269.02,99.9798 2269.03,99.9754 2269.04,99.9711 2269.05,99.9667 2269.06,99.9624 2269.07,99.958 2269.08,99.9536 2269.09,99.9493 2269.1,99.9449 2269.11,99.9406 2269.11,99.9362 2269.12,99.9318 2269.13,99.9275 2269.14,99.9231 2269.15,99.9188 2269.16,99.9144 2269.17,99.91 2269.18,99.9057 2269.19,99.9013 2269.2,99.897 2269.21,99.8926 2269.22,99.8882 2269.23,99.8839 2269.23,99.8795 2269.24,99.8752 2269.25,99.8708 2269.26,99.8665 2269.27,99.8621 2269.28,99.8577 2269.29,99.8534 2269.3,99.849 2269.31,99.8447 2269.32,99.8403 2269.33,99.8359 2269.34,99.8316 2269.34,99.8272 2269.35,99.8229 2269.36,99.8185 2269.37,99.8142 2269.38,99.8098 2269.39,99.8055 2269.4,99.8011 2269.41,99.7967 2269.42,99.7924 2269.43,99.788 2269.44,99.7837 2269.45,99.7793 2269.45,99.775 2269.46,99.7706 2269.47,99.7663 2269.48,99.7619 2269.49,99.7575 2269.5,99.7532 2269.51,99.7488 2269.52,99.7445 2269.53,99.7401 2269.54,99.7358 2269.55,99.7314 2269.56,99.7271 2269.57,99.7227 2269.57,99.7184 2269.58,99.714 2269.59,99.7096 2269.6,99.7053 2269.61,99.7009 2269.62,99.6966 2269.63,99.6922 2269.64,99.6879 2269.65,99.6835 2269.66,99.6792 2269.67,99.6748 2269.68,99.6705 2269.68,99.6661 2269.69,99.6618 2269.7,99.6574 2269.71,99.6531 2269.72,99.6487 2269.73,99.6444 2269.74,99.64 2269.75,99.6356 2269.76,99.6313 2269.77,99.6269 2269.78,99.6226 2269.79,99.6182 2269.79,99.6139 2269.8,99.6095 2269.81,99.6052 2269.82,99.6008 2269.83,99.5965 2269.84,99.5921 2269.85,99.5878 2269.86,99.5834 2269.87,99.5791 2269.88,99.5747 2269.89,99.5704 2269.9,99.566 2269.91,99.5617 2269.91,99.5573 2269.92,99.553 2269.93,99.5486 2269.94,99.5443 2269.95,99.5399 2269.96,99.5356 2269.97,99.5312 2269.98,99.5269 2269.99,99.5225 2270,99.5182 2270.01,99.5139 2270.02,99.5095 2270.02,99.5052 2270.03,99.5008 2270.04,99.4965 2270.05,99.4921 2270.06,99.4878 2270.07,99.4834 2270.08,99.4791 2270.09,99.4747 2270.1,99.4704 2270.11,99.466 2270.12,99.4617 2270.13,99.4573 2270.13,99.453 2270.14,99.4486 2270.15,99.4443 2270.16,99.44 2270.17,99.4356 2270.18,99.4313 2270.19,99.4269 2270.2,99.4226 2270.21,99.4182 2270.22,99.4139 2270.23,99.4095 2270.24,99.4052 2270.25,99.4008 2270.25,99.3965 2270.26,99.3922 2270.27,99.3878 2270.28,99.3835 2270.29,99.3791 2270.3,99.3748 2270.31,99.3704 2270.32,99.3661 2270.33,99.3617 2270.34,99.3574 2270.35,99.3531 2270.36,99.3487 2270.36,99.3444 2270.37,99.34 2270.38,99.3357 2270.39,99.3313 2270.4,99.327 2270.41,99.3227 2270.42,99.3183 2270.43,99.314 2270.44,99.3096 2270.45,99.3053 2270.46,99.3009 2270.47,99.2966 2270.48,99.2923 2270.48,99.2879 2270.49,99.2836 2270.5,99.2792 2270.51,99.2749 2270.52,99.2705 2270.53,99.2662 2270.54,99.2619 2270.55,99.2575 2270.56,99.2532 2270.57,99.2488 2270.58,99.2445 2270.59,99.2402 2270.59,99.2358 2270.6,99.2315 2270.61,99.2271 2270.62,99.2228 2270.63,99.2185 2270.64,99.2141 2270.65,99.2098 2270.66,99.2054 2270.67,99.2011 2270.68,99.1968 2270.69,99.1924 2270.7,99.1881 2270.7,99.1837 2270.71,99.1794 2270.72,99.1751 2270.73,99.1707 2270.74,99.1664 2270.75,99.162 2270.76,99.1577 2270.77,99.1534 2270.78,99.149 2270.79,99.1447 2270.8,99.1404 2270.81,99.136 2270.82,99.1317 2270.82,99.1273 2270.83,99.123 2270.84,99.1187 2270.85,99.1143 2270.86,99.11 2270.87,99.1057 2270.88,99.1013 2270.89,99.097 2270.9,99.0926 2270.91,99.0883 2270.92,99.084 2270.93,99.0796 2270.93,99.0753 2270.94,99.071 2270.95,99.0666 2270.96,99.0623 2270.97,99.058 2270.98,99.0536 2270.99,99.0493 2271,99.045 2271.01,99.0406 2271.02,99.0363 2271.03,99.032 2271.04,99.0276 2271.04,99.0233 2271.05,99.0189 2271.06,99.0146 2271.07,99.0103 2271.08,99.0059 2271.09,99.0016 2271.1,98.9973 2271.11,98.9929 2271.12,98.9886 2271.13,98.9843 2271.14,98.9799 2271.15,98.9756 2271.16,98.9713 2271.16,98.9669 2271.17,98.9626 2271.18,98.9583 2271.19,98.9539 2271.2,98.9496 2271.21,98.9453 2271.22,98.9409 2271.23,98.9366 2271.24,98.9323 2271.25,98.928 2271.26,98.9236 2271.27,98.9193 2271.27,98.915 2271.28,98.9106 2271.29,98.9063 2271.3,98.902 2271.31,98.8976 2271.32,98.8933 2271.33,98.889 2271.34,98.8846 2271.35,98.8803 2271.36,98.876 2271.37,98.8716 2271.38,98.8673 2271.38,98.863 2271.39,98.8587 2271.4,98.8543 2271.41,98.85 2271.42,98.8457 2271.43,98.8413 2271.44,98.837 2271.45,98.8327 2271.46,98.8283 2271.47,98.824 2271.48,98.8197 2271.49,98.8154 2271.5,98.811 2271.5,98.8067 2271.51,98.8024 2271.52,98.798 2271.53,98.7937 2271.54,98.7894 2271.55,98.7851 2271.56,98.7807 2271.57,98.7764 2271.58,98.7721 2271.59,98.7678 2271.6,98.7634 2271.61,98.7591 2271.61,98.7548 2271.62,98.7504 2271.63,98.7461 2271.64,98.7418 2271.65,98.7375 2271.66,98.7331 2271.67,98.7288 2271.68,98.7245 2271.69,98.7202 2271.7,98.7158 2271.71,98.7115 2271.72,98.7072 2271.72,98.7029 2271.73,98.6985 2271.74,98.6942 2271.75,98.6899 2271.76,98.6856 2271.77,98.6812 2271.78,98.6769 2271.79,98.6726 2271.8,98.6683 2271.81,98.6639 2271.82,98.6596 2271.83,98.6553 2271.84,98.651 2271.84,98.6466 2271.85,98.6423 2271.86,98.638 2271.87,98.6337 2271.88,98.6293 2271.89,98.625 2271.9,98.6207 2271.91,98.6164 2271.92,98.612 2271.93,98.6077 2271.94,98.6034 2271.95,98.5991 2271.95,98.5947 2271.96,98.5904 2271.97,98.5861 2271.98,98.5818 2271.99,98.5775 2272,98.5731 2272.01,98.5688 2272.02,98.5645 2272.03,98.5602 2272.04,98.5558 2272.05,98.5515 2272.06,98.5472 2272.06,98.5429 2272.07,98.5386 2272.08,98.5342 2272.09,98.5299 2272.1,98.5256 2272.11,98.5213 2272.12,98.517 2272.13,98.5126 2272.14,98.5083 2272.15,98.504 2272.16,98.4997 2272.17,98.4954 2272.18,98.491 2272.18,98.4867 2272.19,98.4824 2272.2,98.4781 2272.21,98.4738 2272.22,98.4694 2272.23,98.4651 2272.24,98.4608 2272.25,98.4565 2272.26,98.4522 2272.27,98.4478 2272.28,98.4435 2272.29,98.4392 2272.29,98.4349 2272.3,98.4306 2272.31,98.4262 2272.32,98.4219 2272.33,98.4176 2272.34,98.4133 2272.35,98.409 2272.36,98.4047 2272.37,98.4003 2272.38,98.396 2272.39,98.3917 2272.4,98.3874 2272.4,98.3831 2272.41,98.3788 2272.42,98.3744 2272.43,98.3701 2272.44,98.3658 2272.45,98.3615 2272.46,98.3572 2272.47,98.3529 2272.48,98.3485 2272.49,98.3442 2272.5,98.3399 2272.51,98.3356 2272.52,98.3313 2272.52,98.327 2272.53,98.3226 2272.54,98.3183 2272.55,98.314 2272.56,98.3097 2272.57,98.3054 2272.58,98.3011 2272.59,98.2968 2272.6,98.2924 2272.61,98.2881 2272.62,98.2838 2272.63,98.2795 2272.63,98.2752 2272.64,98.2709 2272.65,98.2666 2272.66,98.2622 2272.67,98.2579 2272.68,98.2536 2272.69,98.2493 2272.7,98.245 2272.71,98.2407 2272.72,98.2364 2272.73,98.232 2272.74,98.2277 2272.74,98.2234 2272.75,98.2191 2272.76,98.2148 2272.77,98.2105 2272.78,98.2062 2272.79,98.2019 2272.8,98.1975 2272.81,98.1932 2272.82,98.1889 2272.83,98.1846 2272.84,98.1803 2272.85,98.176 2272.86,98.1717 2272.86,98.1674 2272.87,98.1631 2272.88,98.1587 2272.89,98.1544 2272.9,98.1501 2272.91,98.1458 2272.92,98.1415 2272.93,98.1372 2272.94,98.1329 2272.95,98.1286 2272.96,98.1243 2272.97,98.12 2272.97,98.1156 2272.98,98.1113 2272.99,98.107 2273,98.1027 2273.01,98.0984 2273.02,98.0941 2273.03,98.0898 2273.04,98.0855 2273.05,98.0812 2273.06,98.0769 2273.07,98.0725 2273.08,98.0682 2273.08,98.0639 2273.09,98.0596 2273.1,98.0553 2273.11,98.051 2273.12,98.0467 2273.13,98.0424 2273.14,98.0381 2273.15,98.0338 2273.16,98.0295 2273.17,98.0252 2273.18,98.0209 2273.19,98.0165 2273.2,98.0122 2273.2,98.0079 2273.21,98.0036 2273.22,97.9993 2273.23,97.995 2273.24,97.9907 2273.25,97.9864 2273.26,97.9821 2273.27,97.9778 2273.28,97.9735 2273.29,97.9692 2273.3,97.9649 2273.31,97.9606 2273.31,97.9563 2273.32,97.952 2273.33,97.9476 2273.34,97.9433 2273.35,97.939 2273.36,97.9347 2273.37,97.9304 2273.38,97.9261 2273.39,97.9218 2273.4,97.9175 2273.41,97.9132 2273.42,97.9089 2273.42,97.9046 2273.43,97.9003 2273.44,97.896 2273.45,97.8917 2273.46,97.8874 2273.47,97.8831 2273.48,97.8788 2273.49,97.8745 2273.5,97.8702 2273.51,97.8659 2273.52,97.8616 2273.53,97.8573 2273.54,97.853 2273.54,97.8487 2273.55,97.8444 2273.56,97.8401 2273.57,97.8358 2273.58,97.8314 2273.59,97.8271 2273.6,97.8228 2273.61,97.8185 2273.62,97.8142 2273.63,97.8099 2273.64,97.8056 2273.65,97.8013 2273.65,97.797 2273.66,97.7927 2273.67,97.7884 2273.68,97.7841 2273.69,97.7798 2273.7,97.7755 2273.71,97.7712 2273.72,97.7669 2273.73,97.7626 2273.74,97.7583 2273.75,97.754 2273.76,97.7497 2273.76,97.7454 2273.77,97.7411 2273.78,97.7368 2273.79,97.7325 2273.8,97.7282 2273.81,97.7239 2273.82,97.7196 2273.83,97.7153 2273.84,97.711 2273.85,97.7067 2273.86,97.7024 2273.87,97.6981 2273.88,97.6938 2273.88,97.6895 2273.89,97.6852 2273.9,97.6809 2273.91,97.6766 2273.92,97.6724 2273.93,97.6681 2273.94,97.6638 2273.95,97.6595 2273.96,97.6552 2273.97,97.6509 2273.98,97.6466 2273.99,97.6423 2273.99,97.638 2274,97.6337 2274.01,97.6294 2274.02,97.6251 2274.03,97.6208 2274.04,97.6165 2274.05,97.6122 2274.06,97.6079 2274.07,97.6036 2274.08,97.5993 2274.09,97.595 2274.1,97.5907 2274.1,97.5864 2274.11,97.5821 2274.12,97.5778 2274.13,97.5735 2274.14,97.5692 2274.15,97.5649 2274.16,97.5606 2274.17,97.5563 2274.18,97.5521 2274.19,97.5478 2274.2,97.5435 2274.21,97.5392 2274.22,97.5349 2274.22,97.5306 2274.23,97.5263 2274.24,97.522 2274.25,97.5177 2274.26,97.5134 2274.27,97.5091 2274.28,97.5048 2274.29,97.5005 2274.3,97.4962 2274.31,97.4919 2274.32,97.4876 2274.33,97.4834 2274.33,97.4791 2274.34,97.4748 2274.35,97.4705 2274.36,97.4662 2274.37,97.4619 2274.38,97.4576 2274.39,97.4533 2274.4,97.449 2274.41,97.4447 2274.42,97.4404 2274.43,97.4361 2274.44,97.4318 2274.44,97.4276 2274.45,97.4233 2274.46,97.419 2274.47,97.4147 2274.48,97.4104 2274.49,97.4061 2274.5,97.4018 2274.51,97.3975 2274.52,97.3932 2274.53,97.3889 2274.54,97.3847 2274.55,97.3804 2274.56,97.3761 2274.56,97.3718 2274.57,97.3675 2274.58,97.3632 2274.59,97.3589 2274.6,97.3546 2274.61,97.3503 2274.62,97.346 2274.63,97.3418 2274.64,97.3375 2274.65,97.3332 2274.66,97.3289 2274.67,97.3246 2274.67,97.3203 2274.68,97.316 2274.69,97.3117 2274.7,97.3074 2274.71,97.3032 2274.72,97.2989 2274.73,97.2946 2274.74,97.2903 2274.75,97.286 2274.76,97.2817 2274.77,97.2774 2274.78,97.2731 2274.78,97.2689 2274.79,97.2646 2274.8,97.2603 2274.81,97.256 2274.82,97.2517 2274.83,97.2474 2274.84,97.2431 2274.85,97.2388 2274.86,97.2346 2274.87,97.2303 2274.88,97.226 2274.89,97.2217 2274.9,97.2174 2274.9,97.2131 2274.91,97.2088 2274.92,97.2046 2274.93,97.2003 2274.94,97.196 2274.95,97.1917 2274.96,97.1874 2274.97,97.1831 2274.98,97.1789 2274.99,97.1746 2275,97.1703 2275.01,97.166 2275.01,97.1617 2275.02,97.1574 2275.03,97.1531 2275.04,97.1489 2275.05,97.1446 2275.06,97.1403 2275.07,97.136 2275.08,97.1317 2275.09,97.1274 2275.1,97.1232 2275.11,97.1189 2275.12,97.1146 2275.12,97.1103 2275.13,97.106 2275.14,97.1017 2275.15,97.0975 2275.16,97.0932 2275.17,97.0889 2275.18,97.0846 2275.19,97.0803 2275.2,97.076 2275.21,97.0718 2275.22,97.0675 2275.23,97.0632 2275.24,97.0589 2275.24,97.0546 2275.25,97.0504 2275.26,97.0461 2275.27,97.0418 2275.28,97.0375 2275.29,97.0332 2275.3,97.029 2275.31,97.0247 2275.32,97.0204 2275.33,97.0161 2275.34,97.0118 2275.35,97.0076 2275.35,97.0033 2275.36,96.999 2275.37,96.9947 2275.38,96.9904 2275.39,96.9862 2275.4,96.9819 2275.41,96.9776 2275.42,96.9733 2275.43,96.969 2275.44,96.9648 2275.45,96.9605 2275.46,96.9562 2275.46,96.9519 2275.47,96.9476 2275.48,96.9434 2275.49,96.9391 2275.5,96.9348 2275.51,96.9305 2275.52,96.9262 2275.53,96.922 2275.54,96.9177 2275.55,96.9134 2275.56,96.9091 2275.57,96.9049 2275.58,96.9006 2275.58,96.8963 2275.59,96.892 2275.6,96.8877 2275.61,96.8835 2275.62,96.8792 2275.63,96.8749 2275.64,96.8706 2275.65,96.8664 2275.66,96.8621 2275.67,96.8578 2275.68,96.8535 2275.69,96.8493 2275.69,96.845 2275.7,96.8407 2275.71,96.8364 2275.72,96.8322 2275.73,96.8279 2275.74,96.8236 2275.75,96.8193 2275.76,96.8151 2275.77,96.8108 2275.78,96.8065 2275.79,96.8022 2275.8,96.798 2275.8,96.7937 2275.81,96.7894 2275.82,96.7851 2275.83,96.7809 2275.84,96.7766 2275.85,96.7723 2275.86,96.768 2275.87,96.7638 2275.88,96.7595 2275.89,96.7552 2275.9,96.7509 2275.91,96.7467 2275.92,96.7424 2275.92,96.7381 2275.93,96.7338 2275.94,96.7296 2275.95,96.7253 2275.96,96.721 2275.97,96.7168 2275.98,96.7125 2275.99,96.7082 2276,96.7039 2276.01,96.6997 2276.02,96.6954 2276.03,96.6911 2276.03,96.6868 2276.04,96.6826 2276.05,96.6783 2276.06,96.674 2276.07,96.6698 2276.08,96.6655 2276.09,96.6612 2276.1,96.6569 2276.11,96.6527 2276.12,96.6484 2276.13,96.6441 2276.14,96.6399 2276.14,96.6356 2276.15,96.6313 2276.16,96.6271 2276.17,96.6228 2276.18,96.6185 2276.19,96.6142 2276.2,96.61 2276.21,96.6057 2276.22,96.6014 2276.23,96.5972 2276.24,96.5929 2276.25,96.5886 2276.26,96.5844 2276.26,96.5801 2276.27,96.5758 2276.28,96.5715 2276.29,96.5673 2276.3,96.563 2276.31,96.5587 2276.32,96.5545 2276.33,96.5502 2276.34,96.5459 2276.35,96.5417 2276.36,96.5374 2276.37,96.5331 2276.37,96.5289 2276.38,96.5246 2276.39,96.5203 2276.4,96.5161 2276.41,96.5118 2276.42,96.5075 2276.43,96.5033 2276.44,96.499 2276.45,96.4947 2276.46,96.4905 2276.47,96.4862 2276.48,96.4819 2276.48,96.4777 2276.49,96.4734 2276.5,96.4691 2276.51,96.4649 2276.52,96.4606 2276.53,96.4563 2276.54,96.4521 2276.55,96.4478 2276.56,96.4435 2276.57,96.4393 2276.58,96.435 2276.59,96.4307 2276.6,96.4265 2276.6,96.4222 2276.61,96.4179 2276.62,96.4137 2276.63,96.4094 2276.64,96.4051 2276.65,96.4009 2276.66,96.3966 2276.67,96.3924 2276.68,96.3881 2276.69,96.3838 2276.7,96.3796 2276.71,96.3753 2276.71,96.371 2276.72,96.3668 2276.73,96.3625 2276.74,96.3582 2276.75,96.354 2276.76,96.3497 2276.77,96.3455 2276.78,96.3412 2276.79,96.3369 2276.8,96.3327 2276.81,96.3284 2276.82,96.3241 2276.82,96.3199 2276.83,96.3156 2276.84,96.3114 2276.85,96.3071 2276.86,96.3028 2276.87,96.2986 2276.88,96.2943 2276.89,96.29 2276.9,96.2858 2276.91,96.2815 2276.92,96.2773 2276.93,96.273 2276.94,96.2687 2276.94,96.2645 2276.95,96.2602 2276.96,96.256 2276.97,96.2517 2276.98,96.2474 2276.99,96.2432 2277,96.2389 2277.01,96.2347 2277.02,96.2304 2277.03,96.2261 2277.04,96.2219 2277.05,96.2176 2277.05,96.2134 2277.06,96.2091 2277.07,96.2048 2277.08,96.2006 2277.09,96.1963 2277.1,96.1921 2277.11,96.1878 2277.12,96.1835 2277.13,96.1793 2277.14,96.175 2277.15,96.1708 2277.16,96.1665 2277.16,96.1622 2277.17,96.158 2277.18,96.1537 2277.19,96.1495 2277.2,96.1452 2277.21,96.141 2277.22,96.1367 2277.23,96.1324 2277.24,96.1282 2277.25,96.1239 2277.26,96.1197 2277.27,96.1154 2277.28,96.1112 2277.28,96.1069 2277.29,96.1026 2277.3,96.0984 2277.31,96.0941 2277.32,96.0899 2277.33,96.0856 2277.34,96.0814 2277.35,96.0771 2277.36,96.0729 2277.37,96.0686 2277.38,96.0643 2277.39,96.0601 2277.39,96.0558 2277.4,96.0516 2277.41,96.0473 2277.42,96.0431 2277.43,96.0388 2277.44,96.0346 2277.45,96.0303 2277.46,96.026 2277.47,96.0218 2277.48,96.0175 2277.49,96.0133 2277.5,96.009 2277.5,96.0048 2277.51,96.0005 2277.52,95.9963 2277.53,95.992 2277.54,95.9878 2277.55,95.9835 2277.56,95.9792 2277.57,95.975 2277.58,95.9707 2277.59,95.9665 2277.6,95.9622 2277.61,95.958 2277.62,95.9537 2277.62,95.9495 2277.63,95.9452 2277.64,95.941 2277.65,95.9367 2277.66,95.9325 2277.67,95.9282 2277.68,95.924 2277.69,95.9197 2277.7,95.9155 2277.71,95.9112 2277.72,95.907 2277.73,95.9027 2277.73,95.8984 2277.74,95.8942 2277.75,95.8899 2277.76,95.8857 2277.77,95.8814 2277.78,95.8772 2277.79,95.8729 2277.8,95.8687 2277.81,95.8644 2277.82,95.8602 2277.83,95.8559 2277.84,95.8517 2277.84,95.8474 2277.85,95.8432 2277.86,95.8389 2277.87,95.8347 2277.88,95.8304 2277.89,95.8262 2277.9,95.8219 2277.91,95.8177 2277.92,95.8134 2277.93,95.8092 2277.94,95.8049 2277.95,95.8007 2277.96,95.7964 2277.96,95.7922 2277.97,95.7879 2277.98,95.7837 2277.99,95.7794 2278,95.7752 2278.01,95.771 2278.02,95.7667 2278.03,95.7625 2278.04,95.7582 2278.05,95.754 2278.06,95.7497 2278.07,95.7455 2278.07,95.7412 2278.08,95.737 2278.09,95.7327 2278.1,95.7285 2278.11,95.7242 2278.12,95.72 2278.13,95.7157 2278.14,95.7115 2278.15,95.7072 2278.16,95.703 2278.17,95.6987 2278.18,95.6945 2278.18,95.6903 2278.19,95.686 2278.2,95.6818 2278.21,95.6775 2278.22,95.6733 2278.23,95.669 2278.24,95.6648 2278.25,95.6605 2278.26,95.6563 2278.27,95.652 2278.28,95.6478 2278.29,95.6436 2278.3,95.6393 2278.3,95.6351 2278.31,95.6308 2278.32,95.6266 2278.33,95.6223 2278.34,95.6181 2278.35,95.6138 2278.36,95.6096 2278.37,95.6054 2278.38,95.6011 2278.39,95.5969 2278.4,95.5926 2278.41,95.5884 2278.41,95.5841 2278.42,95.5799 2278.43,95.5756 2278.44,95.5714 2278.45,95.5672 2278.46,95.5629 2278.47,95.5587 2278.48,95.5544 2278.49,95.5502 2278.5,95.5459 2278.51,95.5417 2278.52,95.5375 2278.52,95.5332 2278.53,95.529 2278.54,95.5247 2278.55,95.5205 2278.56,95.5163 2278.57,95.512 2278.58,95.5078 2278.59,95.5035 2278.6,95.4993 2278.61,95.495 2278.62,95.4908 2278.63,95.4866 2278.64,95.4823 2278.64,95.4781 2278.65,95.4738 2278.66,95.4696 2278.67,95.4654 2278.68,95.4611 2278.69,95.4569 2278.7,95.4526 2278.71,95.4484 2278.72,95.4442 2278.73,95.4399 2278.74,95.4357 2278.75,95.4314 2278.75,95.4272 2278.76,95.423 2278.77,95.4187 2278.78,95.4145 2278.79,95.4102 2278.8,95.406 2278.81,95.4018 2278.82,95.3975 2278.83,95.3933 2278.84,95.3891 2278.85,95.3848 2278.86,95.3806 2278.86,95.3763 2278.87,95.3721 2278.88,95.3679 2278.89,95.3636 2278.9,95.3594 2278.91,95.3551 2278.92,95.3509 2278.93,95.3467 2278.94,95.3424 2278.95,95.3382 2278.96,95.334 2278.97,95.3297 2278.98,95.3255 2278.98,95.3212 2278.99,95.317 2279,95.3128 2279.01,95.3085 2279.02,95.3043 2279.03,95.3001 2279.04,95.2958 2279.05,95.2916 2279.06,95.2874 2279.07,95.2831 2279.08,95.2789 2279.09,95.2746 2279.09,95.2704 2279.1,95.2662 2279.11,95.2619 2279.12,95.2577 2279.13,95.2535 2279.14,95.2492 2279.15,95.245 2279.16,95.2408 2279.17,95.2365 2279.18,95.2323 2279.19,95.2281 2279.2,95.2238 2279.2,95.2196 2279.21,95.2154 2279.22,95.2111 2279.23,95.2069 2279.24,95.2027 2279.25,95.1984 2279.26,95.1942 2279.27,95.19 2279.28,95.1857 2279.29,95.1815 2279.3,95.1773 2279.31,95.173 2279.32,95.1688 2279.32,95.1646 2279.33,95.1603 2279.34,95.1561 2279.35,95.1519 2279.36,95.1476 2279.37,95.1434 2279.38,95.1392 2279.39,95.1349 2279.4,95.1307 2279.41,95.1265 2279.42,95.1222 2279.43,95.118 2279.43,95.1138 2279.44,95.1095 2279.45,95.1053 2279.46,95.1011 2279.47,95.0968 2279.48,95.0926 2279.49,95.0884 2279.5,95.0842 2279.51,95.0799 2279.52,95.0757 2279.53,95.0715 2279.54,95.0672 2279.54,95.063 2279.55,95.0588 2279.56,95.0545 2279.57,95.0503 2279.58,95.0461 2279.59,95.0419 2279.6,95.0376 2279.61,95.0334 2279.62,95.0292 2279.63,95.0249 2279.64,95.0207 2279.65,95.0165 2279.66,95.0122 2279.66,95.008 2279.67,95.0038 2279.68,94.9996 2279.69,94.9953 2279.7,94.9911 2279.71,94.9869 2279.72,94.9826 2279.73,94.9784 2279.74,94.9742 2279.75,94.97 2279.76,94.9657 2279.77,94.9615 2279.77,94.9573 2279.78,94.953 2279.79,94.9488 2279.8,94.9446 2279.81,94.9404 2279.82,94.9361 2279.83,94.9319 2279.84,94.9277 2279.85,94.9235 2279.86,94.9192 2279.87,94.915 2279.88,94.9108 2279.88,94.9066 2279.89,94.9023 2279.9,94.8981 2279.91,94.8939 2279.92,94.8896 2279.93,94.8854 2279.94,94.8812 2279.95,94.877 2279.96,94.8727 2279.97,94.8685 2279.98,94.8643 2279.99,94.8601 2280,94.8558 2280,94.8516 2280.01,94.8474 2280.02,94.8432 2280.03,94.8389 2280.04,94.8347 2280.05,94.8305 2280.06,94.8263 2280.07,94.822 2280.08,94.8178 2280.09,94.8136 2280.1,94.8094 2280.11,94.8051 2280.11,94.8009 2280.12,94.7967 2280.13,94.7925 2280.14,94.7883 2280.15,94.784 2280.16,94.7798 2280.17,94.7756 2280.18,94.7714 2280.19,94.7671 2280.2,94.7629 2280.21,94.7587 2280.22,94.7545 2280.22,94.7502 2280.23,94.746 2280.24,94.7418 2280.25,94.7376 2280.26,94.7334 2280.27,94.7291 2280.28,94.7249 2280.29,94.7207 2280.3,94.7165 2280.31,94.7122 2280.32,94.708 2280.33,94.7038 2280.34,94.6996 2280.34,94.6954 2280.35,94.6911 2280.36,94.6869 2280.37,94.6827 2280.38,94.6785 2280.39,94.6743 2280.4,94.67 2280.41,94.6658 2280.42,94.6616 2280.43,94.6574 2280.44,94.6532 2280.45,94.6489 2280.45,94.6447 2280.46,94.6405 2280.47,94.6363 2280.48,94.6321 2280.49,94.6278 2280.5,94.6236 2280.51,94.6194 2280.52,94.6152 2280.53,94.611 2280.54,94.6067 2280.55,94.6025 2280.56,94.5983 2280.56,94.5941 2280.57,94.5899 2280.58,94.5857 2280.59,94.5814 2280.6,94.5772 2280.61,94.573 2280.62,94.5688 2280.63,94.5646 2280.64,94.5603 2280.65,94.5561 2280.66,94.5519 2280.67,94.5477 2280.68,94.5435 2280.68,94.5393 2280.69,94.535 2280.7,94.5308 2280.71,94.5266 2280.72,94.5224 2280.73,94.5182 2280.74,94.514 2280.75,94.5097 2280.76,94.5055 2280.77,94.5013 2280.78,94.4971 2280.79,94.4929 2280.79,94.4887 2280.8,94.4844 2280.81,94.4802 2280.82,94.476 2280.83,94.4718 2280.84,94.4676 2280.85,94.4634 2280.86,94.4591 2280.87,94.4549 2280.88,94.4507 2280.89,94.4465 2280.9,94.4423 2280.9,94.4381 2280.91,94.4339 2280.92,94.4296 2280.93,94.4254 2280.94,94.4212 2280.95,94.417 2280.96,94.4128 2280.97,94.4086 2280.98,94.4044 2280.99,94.4001 2281,94.3959 2281.01,94.3917 2281.02,94.3875 2281.02,94.3833 2281.03,94.3791 2281.04,94.3749 2281.05,94.3706 2281.06,94.3664 2281.07,94.3622 2281.08,94.358 2281.09,94.3538 2281.1,94.3496 2281.11,94.3454 2281.12,94.3412 2281.13,94.3369 2281.13,94.3327 2281.14,94.3285 2281.15,94.3243 2281.16,94.3201 2281.17,94.3159 2281.18,94.3117 2281.19,94.3075 2281.2,94.3033 2281.21,94.299 2281.22,94.2948 2281.23,94.2906 2281.24,94.2864 2281.24,94.2822 2281.25,94.278 2281.26,94.2738 2281.27,94.2696 2281.28,94.2654 2281.29,94.2611 2281.3,94.2569 2281.31,94.2527 2281.32,94.2485 2281.33,94.2443 2281.34,94.2401 2281.35,94.2359 2281.36,94.2317 2281.36,94.2275 2281.37,94.2233 2281.38,94.219 2281.39,94.2148 2281.4,94.2106 2281.41,94.2064 2281.42,94.2022 2281.43,94.198 2281.44,94.1938 2281.45,94.1896 2281.46,94.1854 2281.47,94.1812 2281.47,94.177 2281.48,94.1727 2281.49,94.1685 2281.5,94.1643 2281.51,94.1601 2281.52,94.1559 2281.53,94.1517 2281.54,94.1475 2281.55,94.1433 2281.56,94.1391 2281.57,94.1349 2281.58,94.1307 2281.58,94.1265 2281.59,94.1223 2281.6,94.118 2281.61,94.1138 2281.62,94.1096 2281.63,94.1054 2281.64,94.1012 2281.65,94.097 2281.66,94.0928 2281.67,94.0886 2281.68,94.0844 2281.69,94.0802 2281.7,94.076 2281.7,94.0718 2281.71,94.0676 2281.72,94.0634 2281.73,94.0592 2281.74,94.055 2281.75,94.0508 2281.76,94.0465 2281.77,94.0423 2281.78,94.0381 2281.79,94.0339 2281.8,94.0297 2281.81,94.0255 2281.81,94.0213 2281.82,94.0171 2281.83,94.0129 2281.84,94.0087 2281.85,94.0045 2281.86,94.0003 2281.87,93.9961 2281.88,93.9919 2281.89,93.9877 2281.9,93.9835 2281.91,93.9793 2281.92,93.9751 2281.92,93.9709 2281.93,93.9667 2281.94,93.9625 2281.95,93.9583 2281.96,93.9541 2281.97,93.9499 2281.98,93.9457 2281.99,93.9415 2282,93.9372 2282.01,93.933 2282.02,93.9288 2282.03,93.9246 2282.04,93.9204 2282.04,93.9162 2282.05,93.912 2282.06,93.9078 2282.07,93.9036 2282.08,93.8994 2282.09,93.8952 2282.1,93.891 2282.11,93.8868 2282.12,93.8826 2282.13,93.8784 2282.14,93.8742 2282.15,93.87 2282.15,93.8658 2282.16,93.8616 2282.17,93.8574 2282.18,93.8532 2282.19,93.849 2282.2,93.8448 2282.21,93.8406 2282.22,93.8364 2282.23,93.8322 2282.24,93.828 2282.25,93.8238 2282.26,93.8196 2282.26,93.8154 2282.27,93.8112 2282.28,93.807 2282.29,93.8028 2282.3,93.7986 2282.31,93.7944 2282.32,93.7902 2282.33,93.786 2282.34,93.7818 2282.35,93.7776 2282.36,93.7734 2282.37,93.7692 2282.38,93.765 2282.38,93.7608 2282.39,93.7566 2282.4,93.7524 2282.41,93.7482 2282.42,93.744 2282.43,93.7398 2282.44,93.7356 2282.45,93.7315 2282.46,93.7273 2282.47,93.7231 2282.48,93.7189 2282.49,93.7147 2282.49,93.7105 2282.5,93.7063 2282.51,93.7021 2282.52,93.6979 2282.53,93.6937 2282.54,93.6895 2282.55,93.6853 2282.56,93.6811 2282.57,93.6769 2282.58,93.6727 2282.59,93.6685 2282.6,93.6643 2282.6,93.6601 2282.61,93.6559 2282.62,93.6517 2282.63,93.6475 2282.64,93.6433 2282.65,93.6391 2282.66,93.6349 2282.67,93.6307 2282.68,93.6265 2282.69,93.6224 2282.7,93.6182 2282.71,93.614 2282.72,93.6098 2282.72,93.6056 2282.73,93.6014 2282.74,93.5972 2282.75,93.593 2282.76,93.5888 2282.77,93.5846 2282.78,93.5804 2282.79,93.5762 2282.8,93.572 2282.81,93.5678 2282.82,93.5636 2282.83,93.5594 2282.83,93.5552 2282.84,93.5511 2282.85,93.5469 2282.86,93.5427 2282.87,93.5385 2282.88,93.5343 2282.89,93.5301 2282.9,93.5259 2282.91,93.5217 2282.92,93.5175 2282.93,93.5133 2282.94,93.5091 2282.94,93.5049 2282.95,93.5007 2282.96,93.4966 2282.97,93.4924 2282.98,93.4882 2282.99,93.484 2283,93.4798 2283.01,93.4756 2283.02,93.4714 2283.03,93.4672 2283.04,93.463 2283.05,93.4588 2283.06,93.4546 2283.06,93.4504 2283.07,93.4463 2283.08,93.4421 2283.09,93.4379 2283.1,93.4337 2283.11,93.4295 2283.12,93.4253 2283.13,93.4211 2283.14,93.4169 2283.15,93.4127 2283.16,93.4085 2283.17,93.4044 2283.17,93.4002 2283.18,93.396 2283.19,93.3918 2283.2,93.3876 2283.21,93.3834 2283.22,93.3792 2283.23,93.375 2283.24,93.3708 2283.25,93.3667 2283.26,93.3625 2283.27,93.3583 2283.28,93.3541 2283.28,93.3499 2283.29,93.3457 2283.3,93.3415 2283.31,93.3373 2283.32,93.3332 2283.33,93.329 2283.34,93.3248 2283.35,93.3206 2283.36,93.3164 2283.37,93.3122 2283.38,93.308 2283.39,93.3038 2283.4,93.2997 2283.4,93.2955 2283.41,93.2913 2283.42,93.2871 2283.43,93.2829 2283.44,93.2787 2283.45,93.2745 2283.46,93.2703 2283.47,93.2662 2283.48,93.262 2283.49,93.2578 2283.5,93.2536 2283.51,93.2494 2283.51,93.2452 2283.52,93.241 2283.53,93.2369 2283.54,93.2327 2283.55,93.2285 2283.56,93.2243 2283.57,93.2201 2283.58,93.2159 2283.59,93.2117 2283.6,93.2076 2283.61,93.2034 2283.62,93.1992 2283.62,93.195 2283.63,93.1908 2283.64,93.1866 2283.65,93.1825 2283.66,93.1783 2283.67,93.1741 2283.68,93.1699 2283.69,93.1657 2283.7,93.1615 2283.71,93.1574 2283.72,93.1532 2283.73,93.149 2283.74,93.1448 2283.74,93.1406 2283.75,93.1364 2283.76,93.1323 2283.77,93.1281 2283.78,93.1239 2283.79,93.1197 2283.8,93.1155 2283.81,93.1113 2283.82,93.1072 2283.83,93.103 2283.84,93.0988 2283.85,93.0946 2283.85,93.0904 2283.86,93.0862 2283.87,93.0821 2283.88,93.0779 2283.89,93.0737 2283.9,93.0695 2283.91,93.0653 2283.92,93.0612 2283.93,93.057 2283.94,93.0528 2283.95,93.0486 2283.96,93.0444 2283.96,93.0402 2283.97,93.0361 2283.98,93.0319 2283.99,93.0277 2284,93.0235 2284.01,93.0193 2284.02,93.0152 2284.03,93.011 2284.04,93.0068 2284.05,93.0026 2284.06,92.9984 2284.07,92.9943 2284.08,92.9901 2284.08,92.9859 2284.09,92.9817 2284.1,92.9775 2284.11,92.9734 2284.12,92.9692 2284.13,92.965 2284.14,92.9608 2284.15,92.9567 2284.16,92.9525 2284.17,92.9483 2284.18,92.9441 2284.19,92.9399 2284.19,92.9358 2284.2,92.9316 2284.21,92.9274 2284.22,92.9232 2284.23,92.919 2284.24,92.9149 2284.25,92.9107 2284.26,92.9065 2284.27,92.9023 2284.28,92.8982 2284.29,92.894 2284.3,92.8898 2284.3,92.8856 2284.31,92.8814 2284.32,92.8773 2284.33,92.8731 2284.34,92.8689 2284.35,92.8647 2284.36,92.8606 2284.37,92.8564 2284.38,92.8522 2284.39,92.848 2284.4,92.8439 2284.41,92.8397 2284.42,92.8355 2284.42,92.8313 2284.43,92.8272 2284.44,92.823 2284.45,92.8188 2284.46,92.8146 2284.47,92.8105 2284.48,92.8063 2284.49,92.8021 2284.5,92.7979 2284.51,92.7938 2284.52,92.7896 2284.53,92.7854 2284.53,92.7812 2284.54,92.7771 2284.55,92.7729 2284.56,92.7687 2284.57,92.7645 2284.58,92.7604 2284.59,92.7562 2284.6,92.752 2284.61,92.7478 2284.62,92.7437 2284.63,92.7395 2284.64,92.7353 2284.64,92.7311 2284.65,92.727 2284.66,92.7228 2284.67,92.7186 2284.68,92.7144 2284.69,92.7103 2284.7,92.7061 2284.71,92.7019 2284.72,92.6978 2284.73,92.6936 2284.74,92.6894 2284.75,92.6852 2284.76,92.6811 2284.76,92.6769 2284.77,92.6727 2284.78,92.6686 2284.79,92.6644 2284.8,92.6602 2284.81,92.656 2284.82,92.6519 2284.83,92.6477 2284.84,92.6435 2284.85,92.6393 2284.86,92.6352 2284.87,92.631 2284.87,92.6268 2284.88,92.6227 2284.89,92.6185 2284.9,92.6143 2284.91,92.6102 2284.92,92.606 2284.93,92.6018 2284.94,92.5976 2284.95,92.5935 2284.96,92.5893 2284.97,92.5851 2284.98,92.581 2284.98,92.5768 2284.99,92.5726 2285,92.5685 2285.01,92.5643 2285.02,92.5601 2285.03,92.5559 2285.04,92.5518 2285.05,92.5476 2285.06,92.5434 2285.07,92.5393 2285.08,92.5351 2285.09,92.5309 2285.1,92.5268 2285.1,92.5226 2285.11,92.5184 2285.12,92.5143 2285.13,92.5101 2285.14,92.5059 2285.15,92.5018 2285.16,92.4976 2285.17,92.4934 2285.18,92.4892 2285.19,92.4851 2285.2,92.4809 2285.21,92.4767 2285.21,92.4726 2285.22,92.4684 2285.23,92.4642 2285.24,92.4601 2285.25,92.4559 2285.26,92.4517 2285.27,92.4476 2285.28,92.4434 2285.29,92.4392 2285.3,92.4351 2285.31,92.4309 2285.32,92.4267 2285.32,92.4226 2285.33,92.4184 2285.34,92.4142 2285.35,92.4101 2285.36,92.4059 2285.37,92.4017 2285.38,92.3976 2285.39,92.3934 2285.4,92.3892 2285.41,92.3851 2285.42,92.3809 2285.43,92.3768 2285.44,92.3726 2285.44,92.3684 2285.45,92.3643 2285.46,92.3601 2285.47,92.3559 2285.48,92.3518 2285.49,92.3476 2285.5,92.3434 2285.51,92.3393 2285.52,92.3351 2285.53,92.3309 2285.54,92.3268 2285.55,92.3226 2285.55,92.3185 2285.56,92.3143 2285.57,92.3101 2285.58,92.306 2285.59,92.3018 2285.6,92.2976 2285.61,92.2935 2285.62,92.2893 2285.63,92.2851 2285.64,92.281 2285.65,92.2768 2285.66,92.2727 2285.66,92.2685 2285.67,92.2643 2285.68,92.2602 2285.69,92.256 2285.7,92.2518 2285.71,92.2477 2285.72,92.2435 2285.73,92.2394 2285.74,92.2352 2285.75,92.231 2285.76,92.2269 2285.77,92.2227 2285.78,92.2186 2285.78,92.2144 2285.79,92.2102 2285.8,92.2061 2285.81,92.2019 2285.82,92.1977 2285.83,92.1936 2285.84,92.1894 2285.85,92.1853 2285.86,92.1811 2285.87,92.1769 2285.88,92.1728 2285.89,92.1686 2285.89,92.1645 2285.9,92.1603 2285.91,92.1561 2285.92,92.152 2285.93,92.1478 2285.94,92.1437 2285.95,92.1395 2285.96,92.1353 2285.97,92.1312 2285.98,92.127 2285.99,92.1229 2286,92.1187 2286,92.1145 2286.01,92.1104 2286.02,92.1062 2286.03,92.1021 2286.04,92.0979 2286.05,92.0938 2286.06,92.0896 2286.07,92.0854 2286.08,92.0813 2286.09,92.0771 2286.1,92.073 2286.11,92.0688 2286.12,92.0646 2286.12,92.0605 2286.13,92.0563 2286.14,92.0522 2286.15,92.048 2286.16,92.0439 2286.17,92.0397 2286.18,92.0355 2286.19,92.0314 2286.2,92.0272 2286.21,92.0231 2286.22,92.0189 2286.23,92.0148 2286.23,92.0106 2286.24,92.0064 2286.25,92.0023 2286.26,91.9981 2286.27,91.994 2286.28,91.9898 2286.29,91.9857 2286.3,91.9815 2286.31,91.9774 2286.32,91.9732 2286.33,91.969 2286.34,91.9649 2286.34,91.9607 2286.35,91.9566 2286.36,91.9524 2286.37,91.9483 2286.38,91.9441 2286.39,91.94 2286.4,91.9358 2286.41,91.9316 2286.42,91.9275 2286.43,91.9233 2286.44,91.9192 2286.45,91.915 2286.46,91.9109 2286.46,91.9067 2286.47,91.9026 2286.48,91.8984 2286.49,91.8943 2286.5,91.8901 2286.51,91.886 2286.52,91.8818 2286.53,91.8776 2286.54,91.8735 2286.55,91.8693 2286.56,91.8652 2286.57,91.861 2286.57,91.8569 2286.58,91.8527 2286.59,91.8486 2286.6,91.8444 2286.61,91.8403 2286.62,91.8361 2286.63,91.832 2286.64,91.8278 2286.65,91.8237 2286.66,91.8195 2286.67,91.8154 2286.68,91.8112 2286.68,91.807 2286.69,91.8029 2286.7,91.7987 2286.71,91.7946 2286.72,91.7904 2286.73,91.7863 2286.74,91.7821 2286.75,91.778 2286.76,91.7738 2286.77,91.7697 2286.78,91.7655 2286.79,91.7614 2286.8,91.7572 2286.8,91.7531 2286.81,91.7489 2286.82,91.7448 2286.83,91.7406 2286.84,91.7365 2286.85,91.7323 2286.86,91.7282 2286.87,91.724 2286.88,91.7199 2286.89,91.7157 2286.9,91.7116 2286.91,91.7074 2286.91,91.7033 2286.92,91.6991 2286.93,91.695 2286.94,91.6908 2286.95,91.6867 2286.96,91.6825 2286.97,91.6784 2286.98,91.6742 2286.99,91.6701 2287,91.6659 2287.01,91.6618 2287.02,91.6576 2287.02,91.6535 2287.03,91.6494 2287.04,91.6452 2287.05,91.6411 2287.06,91.6369 2287.07,91.6328 2287.08,91.6286 2287.09,91.6245 2287.1,91.6203 2287.11,91.6162 2287.12,91.612 2287.13,91.6079 2287.14,91.6037 2287.14,91.5996 2287.15,91.5954 2287.16,91.5913 2287.17,91.5871 2287.18,91.583 2287.19,91.5788 2287.2,91.5747 2287.21,91.5706 2287.22,91.5664 2287.23,91.5623 2287.24,91.5581 2287.25,91.554 2287.25,91.5498 2287.26,91.5457 2287.27,91.5415 2287.28,91.5374 2287.29,91.5332 2287.3,91.5291 2287.31,91.5249 2287.32,91.5208 2287.33,91.5167 2287.34,91.5125 2287.35,91.5084 2287.36,91.5042 2287.36,91.5001 2287.37,91.4959 2287.38,91.4918 2287.39,91.4876 2287.4,91.4835 2287.41,91.4794 2287.42,91.4752 2287.43,91.4711 2287.44,91.4669 2287.45,91.4628 2287.46,91.4586 2287.47,91.4545 2287.48,91.4503 2287.48,91.4462 2287.49,91.4421 2287.5,91.4379 2287.51,91.4338 2287.52,91.4296 2287.53,91.4255 2287.54,91.4213 2287.55,91.4172 2287.56,91.4131 2287.57,91.4089 2287.58,91.4048 2287.59,91.4006 2287.59,91.3965 2287.6,91.3923 2287.61,91.3882 2287.62,91.3841 2287.63,91.3799 2287.64,91.3758 2287.65,91.3716 2287.66,91.3675 2287.67,91.3634 2287.68,91.3592 2287.69,91.3551 2287.7,91.3509 2287.7,91.3468 2287.71,91.3426 2287.72,91.3385 2287.73,91.3344 2287.74,91.3302 2287.75,91.3261 2287.76,91.3219 2287.77,91.3178 2287.78,91.3137 2287.79,91.3095 2287.8,91.3054 2287.81,91.3012 2287.82,91.2971 2287.82,91.293 2287.83,91.2888 2287.84,91.2847 2287.85,91.2805 2287.86,91.2764 2287.87,91.2723 2287.88,91.2681 2287.89,91.264 2287.9,91.2598 2287.91,91.2557 2287.92,91.2516 2287.93,91.2474 2287.93,91.2433 2287.94,91.2392 2287.95,91.235 2287.96,91.2309 2287.97,91.2267 2287.98,91.2226 2287.99,91.2185 2288,91.2143 2288.01,91.2102 2288.02,91.206 2288.03,91.2019 2288.04,91.1978 2288.04,91.1936 2288.05,91.1895 2288.06,91.1854 2288.07,91.1812 2288.08,91.1771 2288.09,91.1729 2288.1,91.1688 2288.11,91.1647 2288.12,91.1605 2288.13,91.1564 2288.14,91.1523 2288.15,91.1481 2288.16,91.144 2288.16,91.1398 2288.17,91.1357 2288.18,91.1316 2288.19,91.1274 2288.2,91.1233 2288.21,91.1192 2288.22,91.115 2288.23,91.1109 2288.24,91.1068 2288.25,91.1026 2288.26,91.0985 2288.27,91.0944 2288.27,91.0902 2288.28,91.0861 2288.29,91.0819 2288.3,91.0778 2288.31,91.0737 2288.32,91.0695 2288.33,91.0654 2288.34,91.0613 2288.35,91.0571 2288.36,91.053 2288.37,91.0489 2288.38,91.0447 2288.38,91.0406 2288.39,91.0365 2288.4,91.0323 2288.41,91.0282 2288.42,91.0241 2288.43,91.0199 2288.44,91.0158 2288.45,91.0117 2288.46,91.0075 2288.47,91.0034 2288.48,90.9993 2288.49,90.9951 2288.5,90.991 2288.5,90.9869 2288.51,90.9827 2288.52,90.9786 2288.53,90.9745 2288.54,90.9703 2288.55,90.9662 2288.56,90.9621 2288.57,90.9579 2288.58,90.9538 2288.59,90.9497 2288.6,90.9455 2288.61,90.9414 2288.61,90.9373 2288.62,90.9331 2288.63,90.929 2288.64,90.9249 2288.65,90.9207 2288.66,90.9166 2288.67,90.9125 2288.68,90.9084 2288.69,90.9042 2288.7,90.9001 2288.71,90.896 2288.72,90.8918 2288.72,90.8877 2288.73,90.8836 2288.74,90.8794 2288.75,90.8753 2288.76,90.8712 2288.77,90.867 2288.78,90.8629 2288.79,90.8588 2288.8,90.8547 2288.81,90.8505 2288.82,90.8464 2288.83,90.8423 2288.84,90.8381 2288.84,90.834 2288.85,90.8299 2288.86,90.8257 2288.87,90.8216 2288.88,90.8175 2288.89,90.8134 2288.9,90.8092 2288.91,90.8051 2288.92,90.801 2288.93,90.7968 2288.94,90.7927 2288.95,90.7886 2288.95,90.7845 2288.96,90.7803 2288.97,90.7762 2288.98,90.7721 2288.99,90.7679 2289,90.7638 2289.01,90.7597 2289.02,90.7556 2289.03,90.7514 2289.04,90.7473 2289.05,90.7432 2289.06,90.7391 2289.06,90.7349 2289.07,90.7308 2289.08,90.7267 2289.09,90.7225 2289.1,90.7184 2289.11,90.7143 2289.12,90.7102 2289.13,90.706 2289.14,90.7019 2289.15,90.6978 2289.16,90.6937 2289.17,90.6895 2289.18,90.6854 2289.18,90.6813 2289.19,90.6772 2289.2,90.673 2289.21,90.6689 2289.22,90.6648 2289.23,90.6606 2289.24,90.6565 2289.25,90.6524 2289.26,90.6483 2289.27,90.6441 2289.28,90.64 2289.29,90.6359 2289.29,90.6318 2289.3,90.6276 2289.31,90.6235 2289.32,90.6194 2289.33,90.6153 2289.34,90.6111 2289.35,90.607 2289.36,90.6029 2289.37,90.5988 2289.38,90.5947 2289.39,90.5905 2289.4,90.5864 2289.4,90.5823 2289.41,90.5782 2289.42,90.574 2289.43,90.5699 2289.44,90.5658 2289.45,90.5617 2289.46,90.5575 2289.47,90.5534 2289.48,90.5493 2289.49,90.5452 2289.5,90.541 2289.51,90.5369 2289.52,90.5328 2289.52,90.5287 2289.53,90.5246 2289.54,90.5204 2289.55,90.5163 2289.56,90.5122 2289.57,90.5081 2289.58,90.5039 2289.59,90.4998 2289.6,90.4957 2289.61,90.4916 2289.62,90.4875 2289.63,90.4833 2289.63,90.4792 2289.64,90.4751 2289.65,90.471 2289.66,90.4668 2289.67,90.4627 2289.68,90.4586 2289.69,90.4545 2289.7,90.4504 2289.71,90.4462 2289.72,90.4421 2289.73,90.438 2289.74,90.4339 2289.74,90.4298 2289.75,90.4256 2289.76,90.4215 2289.77,90.4174 2289.78,90.4133 2289.79,90.4092 2289.8,90.405 2289.81,90.4009 2289.82,90.3968 2289.83,90.3927 2289.84,90.3886 2289.85,90.3844 2289.86,90.3803 2289.86,90.3762 2289.87,90.3721 2289.88,90.368 2289.89,90.3638 2289.9,90.3597 2289.91,90.3556 2289.92,90.3515 2289.93,90.3474 2289.94,90.3433 2289.95,90.3391 2289.96,90.335 2289.97,90.3309 2289.97,90.3268 2289.98,90.3227 2289.99,90.3185 2290,90.3144 2290.01,90.3103 2290.02,90.3062 2290.03,90.3021 2290.04,90.298 2290.05,90.2938 2290.06,90.2897 2290.07,90.2856 2290.08,90.2815 2290.08,90.2774 2290.09,90.2733 2290.1,90.2691 2290.11,90.265 2290.12,90.2609 2290.13,90.2568 2290.14,90.2527 2290.15,90.2486 2290.16,90.2444 2290.17,90.2403 2290.18,90.2362 2290.19,90.2321 2290.2,90.228 2290.2,90.2239 2290.21,90.2197 2290.22,90.2156 2290.23,90.2115 2290.24,90.2074 2290.25,90.2033 2290.26,90.1992 2290.27,90.195 2290.28,90.1909 2290.29,90.1868 2290.3,90.1827 2290.31,90.1786 2290.31,90.1745 2290.32,90.1704 2290.33,90.1662 2290.34,90.1621 2290.35,90.158 2290.36,90.1539 2290.37,90.1498 2290.38,90.1457 2290.39,90.1416 2290.4,90.1374 2290.41,90.1333 2290.42,90.1292 2290.42,90.1251 2290.43,90.121 2290.44,90.1169 2290.45,90.1128 2290.46,90.1086 2290.47,90.1045 2290.48,90.1004 2290.49,90.0963 2290.5,90.0922 2290.51,90.0881 2290.52,90.084 2290.53,90.0799 2290.54,90.0757 2290.54,90.0716 2290.55,90.0675 2290.56,90.0634 2290.57,90.0593 2290.58,90.0552 2290.59,90.0511 2290.6,90.047 2290.61,90.0428 2290.62,90.0387 2290.63,90.0346 2290.64,90.0305 2290.65,90.0264 2290.65,90.0223 2290.66,90.0182 2290.67,90.0141 2290.68,90.01 2290.69,90.0058 2290.7,90.0017 2290.71,89.9976 2290.72,89.9935 2290.73,89.9894 2290.74,89.9853 2290.75,89.9812 2290.76,89.9771 2290.76,89.973 2290.77,89.9689 2290.78,89.9647 2290.79,89.9606 2290.8,89.9565 2290.81,89.9524 2290.82,89.9483 2290.83,89.9442 2290.84,89.9401 2290.85,89.936 2290.86,89.9319 2290.87,89.9278 2290.88,89.9236 2290.88,89.9195 2290.89,89.9154 2290.9,89.9113 2290.91,89.9072 2290.92,89.9031 2290.93,89.899 2290.94,89.8949 2290.95,89.8908 2290.96,89.8867 2290.97,89.8826 2290.98,89.8785 2290.99,89.8743 2290.99,89.8702 2291,89.8661 2291.01,89.862 2291.02,89.8579 2291.03,89.8538 2291.04,89.8497 2291.05,89.8456 2291.06,89.8415 2291.07,89.8374 2291.08,89.8333 2291.09,89.8292 2291.1,89.8251 2291.1,89.8209 2291.11,89.8168 2291.12,89.8127 2291.13,89.8086 2291.14,89.8045 2291.15,89.8004 2291.16,89.7963 2291.17,89.7922 2291.18,89.7881 2291.19,89.784 2291.2,89.7799 2291.21,89.7758 2291.22,89.7717 2291.22,89.7676 2291.23,89.7635 2291.24,89.7594 2291.25,89.7552 2291.26,89.7511 2291.27,89.747 2291.28,89.7429 2291.29,89.7388 2291.3,89.7347 2291.31,89.7306 2291.32,89.7265 2291.33,89.7224 2291.33,89.7183 2291.34,89.7142 2291.35,89.7101 2291.36,89.706 2291.37,89.7019 2291.38,89.6978 2291.39,89.6937 2291.4,89.6896 2291.41,89.6855 2291.42,89.6814 2291.43,89.6773 2291.44,89.6732 2291.44,89.6691 2291.45,89.6649 2291.46,89.6608 2291.47,89.6567 2291.48,89.6526 2291.49,89.6485 2291.5,89.6444 2291.51,89.6403 2291.52,89.6362 2291.53,89.6321 2291.54,89.628 2291.55,89.6239 2291.56,89.6198 2291.56,89.6157 2291.57,89.6116 2291.58,89.6075 2291.59,89.6034 2291.6,89.5993 2291.61,89.5952 2291.62,89.5911 2291.63,89.587 2291.64,89.5829 2291.65,89.5788 2291.66,89.5747 2291.67,89.5706 2291.67,89.5665 2291.68,89.5624 2291.69,89.5583 2291.7,89.5542 2291.71,89.5501 2291.72,89.546 2291.73,89.5419 2291.74,89.5378 2291.75,89.5337 2291.76,89.5296 2291.77,89.5255 2291.78,89.5214 2291.78,89.5173 2291.79,89.5132 2291.8,89.5091 2291.81,89.505 2291.82,89.5009 2291.83,89.4968 2291.84,89.4927 2291.85,89.4886 2291.86,89.4845 2291.87,89.4804 2291.88,89.4763 2291.89,89.4722 2291.9,89.4681 2291.9,89.464 2291.91,89.4599 2291.92,89.4558 2291.93,89.4517 2291.94,89.4476 2291.95,89.4435 2291.96,89.4394 2291.97,89.4353 2291.98,89.4312 2291.99,89.4271 2292,89.423 2292.01,89.4189 2292.01,89.4148 2292.02,89.4107 2292.03,89.4066 2292.04,89.4025 2292.05,89.3984 2292.06,89.3943 2292.07,89.3902 2292.08,89.3861 2292.09,89.382 2292.1,89.3779 2292.11,89.3738 2292.12,89.3697 2292.12,89.3656 2292.13,89.3615 2292.14,89.3574 2292.15,89.3533 2292.16,89.3493 2292.17,89.3452 2292.18,89.3411 2292.19,89.337 2292.2,89.3329 2292.21,89.3288 2292.22,89.3247 2292.23,89.3206 2292.24,89.3165 2292.24,89.3124 2292.25,89.3083 2292.26,89.3042 2292.27,89.3001 2292.28,89.296 2292.29,89.2919 2292.3,89.2878 2292.31,89.2837 2292.32,89.2796 2292.33,89.2755 2292.34,89.2714 2292.35,89.2673 2292.35,89.2632 2292.36,89.2592 2292.37,89.2551 2292.38,89.251 2292.39,89.2469 2292.4,89.2428 2292.41,89.2387 2292.42,89.2346 2292.43,89.2305 2292.44,89.2264 2292.45,89.2223 2292.46,89.2182 2292.46,89.2141 2292.47,89.21 2292.48,89.2059 2292.49,89.2018 2292.5,89.1977 2292.51,89.1936 2292.52,89.1896 2292.53,89.1855 2292.54,89.1814 2292.55,89.1773 2292.56,89.1732 2292.57,89.1691 2292.58,89.165 2292.58,89.1609 2292.59,89.1568 2292.6,89.1527 2292.61,89.1486 2292.62,89.1445 2292.63,89.1404 2292.64,89.1364 2292.65,89.1323 2292.66,89.1282 2292.67,89.1241 2292.68,89.12 2292.69,89.1159 2292.69,89.1118 2292.7,89.1077 2292.71,89.1036 2292.72,89.0995 2292.73,89.0954 2292.74,89.0913 2292.75,89.0873 2292.76,89.0832 2292.77,89.0791 2292.78,89.075 2292.79,89.0709 2292.8,89.0668 2292.8,89.0627 2292.81,89.0586 2292.82,89.0545 2292.83,89.0504 2292.84,89.0464 2292.85,89.0423 2292.86,89.0382 2292.87,89.0341 2292.88,89.03 2292.89,89.0259 2292.9,89.0218 2292.91,89.0177 2292.92,89.0136 2292.92,89.0095 2292.93,89.0055 2292.94,89.0014 2292.95,88.9973 2292.96,88.9932 2292.97,88.9891 2292.98,88.985 2292.99,88.9809 2293,88.9768 2293.01,88.9727 2293.02,88.9687 2293.03,88.9646 2293.03,88.9605 2293.04,88.9564 2293.05,88.9523 2293.06,88.9482 2293.07,88.9441 2293.08,88.94 2293.09,88.936 2293.1,88.9319 2293.11,88.9278 2293.12,88.9237 2293.13,88.9196 2293.14,88.9155 2293.14,88.9114 2293.15,88.9073 2293.16,88.9033 2293.17,88.8992 2293.18,88.8951 2293.19,88.891 2293.2,88.8869 2293.21,88.8828 2293.22,88.8787 2293.23,88.8747 2293.24,88.8706 2293.25,88.8665 2293.26,88.8624 2293.26,88.8583 2293.27,88.8542 2293.28,88.8501 2293.29,88.8461 2293.3,88.842 2293.31,88.8379 2293.32,88.8338 2293.33,88.8297 2293.34,88.8256 2293.35,88.8215 2293.36,88.8175 2293.37,88.8134 2293.37,88.8093 2293.38,88.8052 2293.39,88.8011 2293.4,88.797 2293.41,88.7929 2293.42,88.7889 2293.43,88.7848 2293.44,88.7807 2293.45,88.7766 2293.46,88.7725 2293.47,88.7684 2293.48,88.7644 2293.48,88.7603 2293.49,88.7562 2293.5,88.7521 2293.51,88.748 2293.52,88.7439 2293.53,88.7399 2293.54,88.7358 2293.55,88.7317 2293.56,88.7276 2293.57,88.7235 2293.58,88.7194 2293.59,88.7154 2293.6,88.7113 2293.6,88.7072 2293.61,88.7031 2293.62,88.699 2293.63,88.6949 2293.64,88.6909 2293.65,88.6868 2293.66,88.6827 2293.67,88.6786 2293.68,88.6745 2293.69,88.6705 2293.7,88.6664 2293.71,88.6623 2293.71,88.6582 2293.72,88.6541 2293.73,88.65 2293.74,88.646 2293.75,88.6419 2293.76,88.6378 2293.77,88.6337 2293.78,88.6296 2293.79,88.6256 2293.8,88.6215 2293.81,88.6174 2293.82,88.6133 2293.82,88.6092 2293.83,88.6052 2293.84,88.6011 2293.85,88.597 2293.86,88.5929 2293.87,88.5888 2293.88,88.5848 2293.89,88.5807 2293.9,88.5766 2293.91,88.5725 2293.92,88.5684 2293.93,88.5644 2293.94,88.5603 2293.94,88.5562 2293.95,88.5521 2293.96,88.548 2293.97,88.544 2293.98,88.5399 2293.99,88.5358 2294,88.5317 2294.01,88.5276 2294.02,88.5236 2294.03,88.5195 2294.04,88.5154 2294.05,88.5113 2294.05,88.5073 2294.06,88.5032 2294.07,88.4991 2294.08,88.495 2294.09,88.4909 2294.1,88.4869 2294.11,88.4828 2294.12,88.4787 2294.13,88.4746 2294.14,88.4705 2294.15,88.4665 2294.16,88.4624 2294.16,88.4583 2294.17,88.4542 2294.18,88.4502 2294.19,88.4461 2294.2,88.442 2294.21,88.4379 2294.22,88.4339 2294.23,88.4298 2294.24,88.4257 2294.25,88.4216 2294.26,88.4175 2294.27,88.4135 2294.28,88.4094 2294.28,88.4053 2294.29,88.4012 2294.3,88.3972 2294.31,88.3931 2294.32,88.389 2294.33,88.3849 2294.34,88.3809 2294.35,88.3768 2294.36,88.3727 2294.37,88.3686 2294.38,88.3646 2294.39,88.3605 2294.39,88.3564 2294.4,88.3523 2294.41,88.3483 2294.42,88.3442 2294.43,88.3401 2294.44,88.336 2294.45,88.332 2294.46,88.3279 2294.47,88.3238 2294.48,88.3197 2294.49,88.3157 2294.5,88.3116 2294.5,88.3075 2294.51,88.3034 2294.52,88.2994 2294.53,88.2953 2294.54,88.2912 2294.55,88.2871 2294.56,88.2831 2294.57,88.279 2294.58,88.2749 2294.59,88.2709 2294.6,88.2668 2294.61,88.2627 2294.62,88.2586 2294.62,88.2546 2294.63,88.2505 2294.64,88.2464 2294.65,88.2423 2294.66,88.2383 2294.67,88.2342 2294.68,88.2301 2294.69,88.2261 2294.7,88.222 2294.71,88.2179 2294.72,88.2138 2294.73,88.2098 2294.73,88.2057 2294.74,88.2016 2294.75,88.1975 2294.76,88.1935 2294.77,88.1894 2294.78,88.1853 2294.79,88.1813 2294.8,88.1772 2294.81,88.1731 2294.82,88.169 2294.83,88.165 2294.84,88.1609 2294.85,88.1568 2294.85,88.1528 2294.86,88.1487 2294.87,88.1446 2294.88,88.1406 2294.89,88.1365 2294.9,88.1324 2294.91,88.1283 2294.92,88.1243 2294.93,88.1202 2294.94,88.1161 2294.95,88.1121 2294.96,88.108 2294.96,88.1039 2294.97,88.0999 2294.98,88.0958 2294.99,88.0917 2295,88.0876 2295.01,88.0836 2295.02,88.0795 2295.03,88.0754 2295.04,88.0714 2295.05,88.0673 2295.06,88.0632 2295.07,88.0592 2295.07,88.0551 2295.08,88.051 2295.09,88.047 2295.1,88.0429 2295.11,88.0388 2295.12,88.0347 2295.13,88.0307 2295.14,88.0266 2295.15,88.0225 2295.16,88.0185 2295.17,88.0144 2295.18,88.0103 2295.19,88.0063 2295.19,88.0022 2295.2,87.9981 2295.21,87.9941 2295.22,87.99 2295.23,87.9859 2295.24,87.9819 2295.25,87.9778 2295.26,87.9737 2295.27,87.9697 2295.28,87.9656 2295.29,87.9615 2295.3,87.9575 2295.3,87.9534 2295.31,87.9493 2295.32,87.9453 2295.33,87.9412 2295.34,87.9371 2295.35,87.9331 2295.36,87.929 2295.37,87.9249 2295.38,87.9209 2295.39,87.9168 2295.4,87.9127 2295.41,87.9087 2295.41,87.9046 2295.42,87.9005 2295.43,87.8965 2295.44,87.8924 2295.45,87.8883 2295.46,87.8843 2295.47,87.8802 2295.48,87.8762 2295.49,87.8721 2295.5,87.868 2295.51,87.864 2295.52,87.8599 2295.53,87.8558 2295.53,87.8518 2295.54,87.8477 2295.55,87.8436 2295.56,87.8396 2295.57,87.8355 2295.58,87.8314 2295.59,87.8274 2295.6,87.8233 2295.61,87.8193 2295.62,87.8152 2295.63,87.8111 2295.64,87.8071 2295.64,87.803 2295.65,87.7989 2295.66,87.7949 2295.67,87.7908 2295.68,87.7867 2295.69,87.7827 2295.7,87.7786 2295.71,87.7746 2295.72,87.7705 2295.73,87.7664 2295.74,87.7624 2295.75,87.7583 2295.75,87.7542 2295.76,87.7502 2295.77,87.7461 2295.78,87.7421 2295.79,87.738 2295.8,87.7339 2295.81,87.7299 2295.82,87.7258 2295.83,87.7217 2295.84,87.7177 2295.85,87.7136 2295.86,87.7096 2295.87,87.7055 2295.87,87.7014 2295.88,87.6974 2295.89,87.6933 2295.9,87.6893 2295.91,87.6852 2295.92,87.6811 2295.93,87.6771 2295.94,87.673 2295.95,87.669 2295.96,87.6649 2295.97,87.6608 2295.98,87.6568 2295.98,87.6527 2295.99,87.6487 2296,87.6446 2296.01,87.6405 2296.02,87.6365 2296.03,87.6324 2296.04,87.6284 2296.05,87.6243 2296.06,87.6202 2296.07,87.6162 2296.08,87.6121 2296.09,87.6081 2296.09,87.604 2296.1,87.5999 2296.11,87.5959 2296.12,87.5918 2296.13,87.5878 2296.14,87.5837 2296.15,87.5796 2296.16,87.5756 2296.17,87.5715 2296.18,87.5675 2296.19,87.5634 2296.2,87.5593 2296.21,87.5553 2296.21,87.5512 2296.22,87.5472 2296.23,87.5431 2296.24,87.5391 2296.25,87.535 2296.26,87.5309 2296.27,87.5269 2296.28,87.5228 2296.29,87.5188 2296.3,87.5147 2296.31,87.5107 2296.32,87.5066 2296.32,87.5025 2296.33,87.4985 2296.34,87.4944 2296.35,87.4904 2296.36,87.4863 2296.37,87.4823 2296.38,87.4782 2296.39,87.4741 2296.4,87.4701 2296.41,87.466 2296.42,87.462 2296.43,87.4579 2296.43,87.4539 2296.44,87.4498 2296.45,87.4457 2296.46,87.4417 2296.47,87.4376 2296.48,87.4336 2296.49,87.4295 2296.5,87.4255 2296.51,87.4214 2296.52,87.4174 2296.53,87.4133 2296.54,87.4092 2296.55,87.4052 2296.55,87.4011 2296.56,87.3971 2296.57,87.393 2296.58,87.389 2296.59,87.3849 2296.6,87.3809 2296.61,87.3768 2296.62,87.3728 2296.63,87.3687 2296.64,87.3646 2296.65,87.3606 2296.66,87.3565 2296.66,87.3525 2296.67,87.3484 2296.68,87.3444 2296.69,87.3403 2296.7,87.3363 2296.71,87.3322 2296.72,87.3282 2296.73,87.3241 2296.74,87.3201 2296.75,87.316 2296.76,87.312 2296.77,87.3079 2296.77,87.3038 2296.78,87.2998 2296.79,87.2957 2296.8,87.2917 2296.81,87.2876 2296.82,87.2836 2296.83,87.2795 2296.84,87.2755 2296.85,87.2714 2296.86,87.2674 2296.87,87.2633 2296.88,87.2593 2296.89,87.2552 2296.89,87.2512 2296.9,87.2471 2296.91,87.2431 2296.92,87.239 2296.93,87.235 2296.94,87.2309 2296.95,87.2269 2296.96,87.2228 2296.97,87.2188 2296.98,87.2147 2296.99,87.2106 2297,87.2066 2297,87.2025 2297.01,87.1985 2297.02,87.1944 2297.03,87.1904 2297.04,87.1863 2297.05,87.1823 2297.06,87.1782 2297.07,87.1742 2297.08,87.1701 2297.09,87.1661 2297.1,87.162 2297.11,87.158 2297.11,87.1539 2297.12,87.1499 2297.13,87.1458 2297.14,87.1418 2297.15,87.1377 2297.16,87.1337 2297.17,87.1296 2297.18,87.1256 2297.19,87.1215 2297.2,87.1175 2297.21,87.1134 2297.22,87.1094 2297.23,87.1053 2297.23,87.1013 2297.24,87.0973 2297.25,87.0932 2297.26,87.0892 2297.27,87.0851 2297.28,87.0811 2297.29,87.077 2297.3,87.073 2297.31,87.0689 2297.32,87.0649 2297.33,87.0608 2297.34,87.0568 2297.34,87.0527 2297.35,87.0487 2297.36,87.0446 2297.37,87.0406 2297.38,87.0365 2297.39,87.0325 2297.4,87.0284 2297.41,87.0244 2297.42,87.0203 2297.43,87.0163 2297.44,87.0122 2297.45,87.0082 2297.45,87.0042 2297.46,87.0001 2297.47,86.9961 2297.48,86.992 2297.49,86.988 2297.5,86.9839 2297.51,86.9799 2297.52,86.9758 2297.53,86.9718 2297.54,86.9677 2297.55,86.9637 2297.56,86.9596 2297.57,86.9556 2297.57,86.9516 2297.58,86.9475 2297.59,86.9435 2297.6,86.9394 2297.61,86.9354 2297.62,86.9313 2297.63,86.9273 2297.64,86.9232 2297.65,86.9192 2297.66,86.9151 2297.67,86.9111 2297.68,86.9071 2297.68,86.903 2297.69,86.899 2297.7,86.8949 2297.71,86.8909 2297.72,86.8868 2297.73,86.8828 2297.74,86.8787 2297.75,86.8747 2297.76,86.8707 2297.77,86.8666 2297.78,86.8626 2297.79,86.8585 2297.79,86.8545 2297.8,86.8504 2297.81,86.8464 2297.82,86.8424 2297.83,86.8383 2297.84,86.8343 2297.85,86.8302 2297.86,86.8262 2297.87,86.8221 2297.88,86.8181 2297.89,86.814 2297.9,86.81 2297.91,86.806 2297.91,86.8019 2297.92,86.7979 2297.93,86.7938 2297.94,86.7898 2297.95,86.7858 2297.96,86.7817 2297.97,86.7777 2297.98,86.7736 2297.99,86.7696 2298,86.7655 2298.01,86.7615 2298.02,86.7575 2298.02,86.7534 2298.03,86.7494 2298.04,86.7453 2298.05,86.7413 2298.06,86.7373 2298.07,86.7332 2298.08,86.7292 2298.09,86.7251 2298.1,86.7211 2298.11,86.717 2298.12,86.713 2298.13,86.709 2298.13,86.7049 2298.14,86.7009 2298.15,86.6968 2298.16,86.6928 2298.17,86.6888 2298.18,86.6847 2298.19,86.6807 2298.2,86.6766 2298.21,86.6726 2298.22,86.6686 2298.23,86.6645 2298.24,86.6605 2298.25,86.6564 2298.25,86.6524 2298.26,86.6484 2298.27,86.6443 2298.28,86.6403 2298.29,86.6362 2298.3,86.6322 2298.31,86.6282 2298.32,86.6241 2298.33,86.6201 2298.34,86.616 2298.35,86.612 2298.36,86.608 2298.36,86.6039 2298.37,86.5999 2298.38,86.5959 2298.39,86.5918 2298.4,86.5878 2298.41,86.5837 2298.42,86.5797 2298.43,86.5757 2298.44,86.5716 2298.45,86.5676 2298.46,86.5636 2298.47,86.5595 2298.47,86.5555 2298.48,86.5514 2298.49,86.5474 2298.5,86.5434 2298.51,86.5393 2298.52,86.5353 2298.53,86.5313 2298.54,86.5272 2298.55,86.5232 2298.56,86.5191 2298.57,86.5151 2298.58,86.5111 2298.59,86.507 2298.59,86.503 2298.6,86.499 2298.61,86.4949 2298.62,86.4909 2298.63,86.4869 2298.64,86.4828 2298.65,86.4788 2298.66,86.4747 2298.67,86.4707 2298.68,86.4667 2298.69,86.4626 2298.7,86.4586 2298.7,86.4546 2298.71,86.4505 2298.72,86.4465 2298.73,86.4425 2298.74,86.4384 2298.75,86.4344 2298.76,86.4304 2298.77,86.4263 2298.78,86.4223 2298.79,86.4182 2298.8,86.4142 2298.81,86.4102 2298.81,86.4061 2298.82,86.4021 2298.83,86.3981 2298.84,86.394 2298.85,86.39 2298.86,86.386 2298.87,86.3819 2298.88,86.3779 2298.89,86.3739 2298.9,86.3698 2298.91,86.3658 2298.92,86.3618 2298.93,86.3577 2298.93,86.3537 2298.94,86.3497 2298.95,86.3456 2298.96,86.3416 2298.97,86.3376 2298.98,86.3335 2298.99,86.3295 2299,86.3255 2299.01,86.3214 2299.02,86.3174 2299.03,86.3134 2299.04,86.3093 2299.04,86.3053 2299.05,86.3013 2299.06,86.2972 2299.07,86.2932 2299.08,86.2892 2299.09,86.2851 2299.1,86.2811 2299.11,86.2771 2299.12,86.2731 2299.13,86.269 2299.14,86.265 2299.15,86.261 2299.15,86.2569 2299.16,86.2529 2299.17,86.2489 2299.18,86.2448 2299.19,86.2408 2299.2,86.2368 2299.21,86.2327 2299.22,86.2287 2299.23,86.2247 2299.24,86.2206 2299.25,86.2166 2299.26,86.2126 2299.27,86.2086 2299.27,86.2045 2299.28,86.2005 2299.29,86.1965 2299.3,86.1924 2299.31,86.1884 2299.32,86.1844 2299.33,86.1803 2299.34,86.1763 2299.35,86.1723 2299.36,86.1683 2299.37,86.1642 2299.38,86.1602 2299.38,86.1562 2299.39,86.1521 2299.4,86.1481 2299.41,86.1441 2299.42,86.14 2299.43,86.136 2299.44,86.132 2299.45,86.128 2299.46,86.1239 2299.47,86.1199 2299.48,86.1159 2299.49,86.1118 2299.49,86.1078 2299.5,86.1038 2299.51,86.0998 2299.52,86.0957 2299.53,86.0917 2299.54,86.0877 2299.55,86.0836 2299.56,86.0796 2299.57,86.0756 2299.58,86.0716 2299.59,86.0675 2299.6,86.0635 2299.61,86.0595 2299.61,86.0555 2299.62,86.0514 2299.63,86.0474 2299.64,86.0434 2299.65,86.0393 2299.66,86.0353 2299.67,86.0313 2299.68,86.0273 2299.69,86.0232 2299.7,86.0192 2299.71,86.0152 2299.72,86.0112 2299.72,86.0071 2299.73,86.0031 2299.74,85.9991 2299.75,85.995 2299.76,85.991 2299.77,85.987 2299.78,85.983 2299.79,85.9789 2299.8,85.9749 2299.81,85.9709 2299.82,85.9669 2299.83,85.9628 2299.83,85.9588 2299.84,85.9548 2299.85,85.9508 2299.86,85.9467 2299.87,85.9427 2299.88,85.9387 2299.89,85.9347 2299.9,85.9306 2299.91,85.9266 2299.92,85.9226 2299.93,85.9186 2299.94,85.9145 2299.95,85.9105 2299.95,85.9065 2299.96,85.9025 2299.97,85.8984 2299.98,85.8944 2299.99,85.8904 2300,85.8864 2300.01,85.8823 2300.02,85.8783 2300.03,85.8743 2300.04,85.8703 2300.05,85.8663 2300.06,85.8622 2300.06,85.8582 2300.07,85.8542 2300.08,85.8502 2300.09,85.8461 2300.1,85.8421 2300.11,85.8381 2300.12,85.8341 2300.13,85.83 2300.14,85.826 2300.15,85.822 2300.16,85.818 2300.17,85.814 2300.17,85.8099 2300.18,85.8059 2300.19,85.8019 2300.2,85.7979 2300.21,85.7938 2300.22,85.7898 2300.23,85.7858 2300.24,85.7818 2300.25,85.7778 2300.26,85.7737 2300.27,85.7697 2300.28,85.7657 2300.29,85.7617 2300.29,85.7576 2300.3,85.7536 2300.31,85.7496 2300.32,85.7456 2300.33,85.7416 2300.34,85.7375 2300.35,85.7335 2300.36,85.7295 2300.37,85.7255 2300.38,85.7215 2300.39,85.7174 2300.4,85.7134 2300.4,85.7094 2300.41,85.7054 2300.42,85.7014 2300.43,85.6973 2300.44,85.6933 2300.45,85.6893 2300.46,85.6853 2300.47,85.6813 2300.48,85.6772 2300.49,85.6732 2300.5,85.6692 2300.51,85.6652 2300.51,85.6612 2300.52,85.6571 2300.53,85.6531 2300.54,85.6491 2300.55,85.6451 2300.56,85.6411 2300.57,85.637 2300.58,85.633 2300.59,85.629 2300.6,85.625 2300.61,85.621 2300.62,85.6169 2300.63,85.6129 2300.63,85.6089 2300.64,85.6049 2300.65,85.6009 2300.66,85.5969 2300.67,85.5928 2300.68,85.5888 2300.69,85.5848 2300.7,85.5808 2300.71,85.5768 2300.72,85.5727 2300.73,85.5687 2300.74,85.5647 2300.74,85.5607 2300.75,85.5567 2300.76,85.5527 2300.77,85.5486 2300.78,85.5446 2300.79,85.5406 2300.8,85.5366 2300.81,85.5326 2300.82,85.5286 2300.83,85.5245 2300.84,85.5205 2300.85,85.5165 2300.85,85.5125 2300.86,85.5085 2300.87,85.5045 2300.88,85.5004 2300.89,85.4964 2300.9,85.4924 2300.91,85.4884 2300.92,85.4844 2300.93,85.4804 2300.94,85.4763 2300.95,85.4723 2300.96,85.4683 2300.97,85.4643 2300.97,85.4603 2300.98,85.4563 2300.99,85.4522 2301,85.4482 2301.01,85.4442 2301.02,85.4402 2301.03,85.4362 2301.04,85.4322 2301.05,85.4282 2301.06,85.4241 2301.07,85.4201 2301.08,85.4161 2301.08,85.4121 2301.09,85.4081 2301.1,85.4041 2301.11,85.4001 2301.12,85.396 2301.13,85.392 2301.14,85.388 2301.15,85.384 2301.16,85.38 2301.17,85.376 2301.18,85.372 2301.19,85.3679 2301.19,85.3639 2301.2,85.3599 2301.21,85.3559 2301.22,85.3519 2301.23,85.3479 2301.24,85.3439 2301.25,85.3399 2301.26,85.3358 2301.27,85.3318 2301.28,85.3278 2301.29,85.3238 2301.3,85.3198 2301.31,85.3158 2301.31,85.3118 2301.32,85.3077 2301.33,85.3037 2301.34,85.2997 2301.35,85.2957 2301.36,85.2917 2301.37,85.2877 2301.38,85.2837 2301.39,85.2797 2301.4,85.2757 2301.41,85.2716 2301.42,85.2676 2301.42,85.2636 2301.43,85.2596 2301.44,85.2556 2301.45,85.2516 2301.46,85.2476 2301.47,85.2436 2301.48,85.2395 2301.49,85.2355 2301.5,85.2315 2301.51,85.2275 2301.52,85.2235 2301.53,85.2195 2301.53,85.2155 2301.54,85.2115 2301.55,85.2075 2301.56,85.2035 2301.57,85.1994 2301.58,85.1954 2301.59,85.1914 2301.6,85.1874 2301.61,85.1834 2301.62,85.1794 2301.63,85.1754 2301.64,85.1714 2301.65,85.1674 2301.65,85.1634 2301.66,85.1593 2301.67,85.1553 2301.68,85.1513 2301.69,85.1473 2301.7,85.1433 2301.71,85.1393 2301.72,85.1353 2301.73,85.1313 2301.74,85.1273 2301.75,85.1233 2301.76,85.1192 2301.76,85.1152 2301.77,85.1112 2301.78,85.1072 2301.79,85.1032 2301.8,85.0992 2301.81,85.0952 2301.82,85.0912 2301.83,85.0872 2301.84,85.0832 2301.85,85.0792 2301.86,85.0752 2301.87,85.0712 2301.87,85.0671 2301.88,85.0631 2301.89,85.0591 2301.9,85.0551 2301.91,85.0511 2301.92,85.0471 2301.93,85.0431 2301.94,85.0391 2301.95,85.0351 2301.96,85.0311 2301.97,85.0271 2301.98,85.0231 2301.99,85.0191 2301.99,85.015 2302,85.011 2302.01,85.007 2302.02,85.003 2302.03,84.999 2302.04,84.995 2302.05,84.991 2302.06,84.987 2302.07,84.983 2302.08,84.979 2302.09,84.975 2302.1,84.971 2302.1,84.967 2302.11,84.963 2302.12,84.959 2302.13,84.955 2302.14,84.951 2302.15,84.9469 2302.16,84.9429 2302.17,84.9389 2302.18,84.9349 2302.19,84.9309 2302.2,84.9269 2302.21,84.9229 2302.21,84.9189 2302.22,84.9149 2302.23,84.9109 2302.24,84.9069 2302.25,84.9029 2302.26,84.8989 2302.27,84.8949 2302.28,84.8909 2302.29,84.8869 2302.3,84.8829 2302.31,84.8789 2302.32,84.8749 2302.33,84.8709 2302.33,84.8669 2302.34,84.8629 2302.35,84.8588 2302.36,84.8548 2302.37,84.8508 2302.38,84.8468 2302.39,84.8428 2302.4,84.8388 2302.41,84.8348 2302.42,84.8308 2302.43,84.8268 2302.44,84.8228 2302.44,84.8188 2302.45,84.8148 2302.46,84.8108 2302.47,84.8068 2302.48,84.8028 2302.49,84.7988 2302.5,84.7948 2302.51,84.7908 2302.52,84.7868 2302.53,84.7828 2302.54,84.7788 2302.55,84.7748 2302.55,84.7708 2302.56,84.7668 2302.57,84.7628 2302.58,84.7588 2302.59,84.7548 2302.6,84.7508 2302.61,84.7468 2302.62,84.7428 2302.63,84.7388 2302.64,84.7348 2302.65,84.7308 2302.66,84.7268 2302.67,84.7228 2302.67,84.7188 2302.68,84.7148 2302.69,84.7108 2302.7,84.7068 2302.71,84.7028 2302.72,84.6988 2302.73,84.6948 2302.74,84.6908 2302.75,84.6868 2302.76,84.6828 2302.77,84.6788 2302.78,84.6748 2302.78,84.6708 2302.79,84.6668 2302.8,84.6628 2302.81,84.6588 2302.82,84.6548 2302.83,84.6508 2302.84,84.6468 2302.85,84.6428 2302.86,84.6388 2302.87,84.6348 2302.88,84.6308 2302.89,84.6268 2302.89,84.6228 2302.9,84.6188 2302.91,84.6148 2302.92,84.6108 2302.93,84.6068 2302.94,84.6028 2302.95,84.5988 2302.96,84.5948 2302.97,84.5908 2302.98,84.5868 2302.99,84.5828 2303,84.5788 2303.01,84.5748 2303.01,84.5708 2303.02,84.5668 2303.03,84.5628 2303.04,84.5588 2303.05,84.5548 2303.06,84.5508 2303.07,84.5468 2303.08,84.5428 2303.09,84.5388 2303.1,84.5348 2303.11,84.5308 2303.12,84.5268 2303.12,84.5228 2303.13,84.5188 2303.14,84.5148 2303.15,84.5108 2303.16,84.5068 2303.17,84.5028 2303.18,84.4988 2303.19,84.4948 2303.2,84.4908 2303.21,84.4868 2303.22,84.4829 2303.23,84.4789 2303.23,84.4749 2303.24,84.4709 2303.25,84.4669 2303.26,84.4629 2303.27,84.4589 2303.28,84.4549 2303.29,84.4509 2303.3,84.4469 2303.31,84.4429 2303.32,84.4389 2303.33,84.4349 2303.34,84.4309 2303.35,84.4269 2303.35,84.4229 2303.36,84.4189 2303.37,84.4149 2303.38,84.4109 2303.39,84.4069 2303.4,84.4029 2303.41,84.3989 2303.42,84.395 2303.43,84.391 2303.44,84.387 2303.45,84.383 2303.46,84.379 2303.46,84.375 2303.47,84.371 2303.48,84.367 2303.49,84.363 2303.5,84.359 2303.51,84.355 2303.52,84.351 2303.53,84.347 2303.54,84.343 2303.55,84.339 2303.56,84.335 2303.57,84.331 2303.57,84.3271 2303.58,84.3231 2303.59,84.3191 2303.6,84.3151 2303.61,84.3111 2303.62,84.3071 2303.63,84.3031 2303.64,84.2991 2303.65,84.2951 2303.66,84.2911 2303.67,84.2871 2303.68,84.2831 2303.69,84.2791 2303.69,84.2751 2303.7,84.2712 2303.71,84.2672 2303.72,84.2632 2303.73,84.2592 2303.74,84.2552 2303.75,84.2512 2303.76,84.2472 2303.77,84.2432 2303.78,84.2392 2303.79,84.2352 2303.8,84.2312 2303.8,84.2272 2303.81,84.2233 2303.82,84.2193 2303.83,84.2153 2303.84,84.2113 2303.85,84.2073 2303.86,84.2033 2303.87,84.1993 2303.88,84.1953 2303.89,84.1913 2303.9,84.1873 2303.91,84.1833 2303.91,84.1794 2303.92,84.1754 2303.93,84.1714 2303.94,84.1674 2303.95,84.1634 2303.96,84.1594 2303.97,84.1554 2303.98,84.1514 2303.99,84.1474 2304,84.1434 2304.01,84.1395 2304.02,84.1355 2304.03,84.1315 2304.03,84.1275 2304.04,84.1235 2304.05,84.1195 2304.06,84.1155 2304.07,84.1115 2304.08,84.1075 2304.09,84.1036 2304.1,84.0996 2304.11,84.0956 2304.12,84.0916 2304.13,84.0876 2304.14,84.0836 2304.14,84.0796 2304.15,84.0756 2304.16,84.0716 2304.17,84.0677 2304.18,84.0637 2304.19,84.0597 2304.2,84.0557 2304.21,84.0517 2304.22,84.0477 2304.23,84.0437 2304.24,84.0397 2304.25,84.0358 2304.25,84.0318 2304.26,84.0278 2304.27,84.0238 2304.28,84.0198 2304.29,84.0158 2304.3,84.0118 2304.31,84.0078 2304.32,84.0039 2304.33,83.9999 2304.34,83.9959 2304.35,83.9919 2304.36,83.9879 2304.37,83.9839 2304.37,83.9799 2304.38,83.9759 2304.39,83.972 2304.4,83.968 2304.41,83.964 2304.42,83.96 2304.43,83.956 2304.44,83.952 2304.45,83.948 2304.46,83.9441 2304.47,83.9401 2304.48,83.9361 2304.48,83.9321 2304.49,83.9281 2304.5,83.9241 2304.51,83.9201 2304.52,83.9162 2304.53,83.9122 2304.54,83.9082 2304.55,83.9042 2304.56,83.9002 2304.57,83.8962 2304.58,83.8922 2304.59,83.8883 2304.59,83.8843 2304.6,83.8803 2304.61,83.8763 2304.62,83.8723 2304.63,83.8683 2304.64,83.8644 2304.65,83.8604 2304.66,83.8564 2304.67,83.8524 2304.68,83.8484 2304.69,83.8444 2304.7,83.8404 2304.71,83.8365 2304.71,83.8325 2304.72,83.8285 2304.73,83.8245 2304.74,83.8205 2304.75,83.8165 2304.76,83.8126 2304.77,83.8086 2304.78,83.8046 2304.79,83.8006 2304.8,83.7966 2304.81,83.7926 2304.82,83.7887 2304.82,83.7847 2304.83,83.7807 2304.84,83.7767 2304.85,83.7727 2304.86,83.7687 2304.87,83.7648 2304.88,83.7608 2304.89,83.7568 2304.9,83.7528 2304.91,83.7488 2304.92,83.7449 2304.93,83.7409 2304.93,83.7369 2304.94,83.7329 2304.95,83.7289 2304.96,83.7249 2304.97,83.721 2304.98,83.717 2304.99,83.713 2305,83.709 2305.01,83.705 2305.02,83.7011 2305.03,83.6971 2305.04,83.6931 2305.05,83.6891 2305.05,83.6851 2305.06,83.6812 2305.07,83.6772 2305.08,83.6732 2305.09,83.6692 2305.1,83.6652 2305.11,83.6612 2305.12,83.6573 2305.13,83.6533 2305.14,83.6493 2305.15,83.6453 2305.16,83.6413 2305.16,83.6374 2305.17,83.6334 2305.18,83.6294 2305.19,83.6254 2305.2,83.6214 2305.21,83.6175 2305.22,83.6135 2305.23,83.6095 2305.24,83.6055 2305.25,83.6015 2305.26,83.5976 2305.27,83.5936 2305.27,83.5896 2305.28,83.5856 2305.29,83.5817 2305.3,83.5777 2305.31,83.5737 2305.32,83.5697 2305.33,83.5657 2305.34,83.5618 2305.35,83.5578 2305.36,83.5538 2305.37,83.5498 2305.38,83.5458 2305.39,83.5419 2305.39,83.5379 2305.4,83.5339 2305.41,83.5299 2305.42,83.526 2305.43,83.522 2305.44,83.518 2305.45,83.514 2305.46,83.51 2305.47,83.5061 2305.48,83.5021 2305.49,83.4981 2305.5,83.4941 2305.5,83.4902 2305.51,83.4862 2305.52,83.4822 2305.53,83.4782 2305.54,83.4742 2305.55,83.4703 2305.56,83.4663 2305.57,83.4623 2305.58,83.4583 2305.59,83.4544 2305.6,83.4504 2305.61,83.4464 2305.61,83.4424 2305.62,83.4385 2305.63,83.4345 2305.64,83.4305 2305.65,83.4265 2305.66,83.4226 2305.67,83.4186 2305.68,83.4146 2305.69,83.4106 2305.7,83.4066 2305.71,83.4027 2305.72,83.3987 2305.73,83.3947 2305.73,83.3907 2305.74,83.3868 2305.75,83.3828 2305.76,83.3788 2305.77,83.3748 2305.78,83.3709 2305.79,83.3669 2305.8,83.3629 2305.81,83.3589 2305.82,83.355 2305.83,83.351 2305.84,83.347 2305.84,83.343 2305.85,83.3391 2305.86,83.3351 2305.87,83.3311 2305.88,83.3272 2305.89,83.3232 2305.9,83.3192 2305.91,83.3152 2305.92,83.3113 2305.93,83.3073 2305.94,83.3033 2305.95,83.2993 2305.95,83.2954 2305.96,83.2914 2305.97,83.2874 2305.98,83.2834 2305.99,83.2795 2306,83.2755 2306.01,83.2715 2306.02,83.2675 2306.03,83.2636 2306.04,83.2596 2306.05,83.2556 2306.06,83.2517 2306.07,83.2477 2306.07,83.2437 2306.08,83.2397 2306.09,83.2358 2306.1,83.2318 2306.11,83.2278 2306.12,83.2238 2306.13,83.2199 2306.14,83.2159 2306.15,83.2119 2306.16,83.208 2306.17,83.204 2306.18,83.2 2306.18,83.196 2306.19,83.1921 2306.2,83.1881 2306.21,83.1841 2306.22,83.1802 2306.23,83.1762 2306.24,83.1722 2306.25,83.1682 2306.26,83.1643 2306.27,83.1603 2306.28,83.1563 2306.29,83.1524 2306.29,83.1484 2306.3,83.1444 2306.31,83.1404 2306.32,83.1365 2306.33,83.1325 2306.34,83.1285 2306.35,83.1246 2306.36,83.1206 2306.37,83.1166 2306.38,83.1127 2306.39,83.1087 2306.4,83.1047 2306.41,83.1007 2306.41,83.0968 2306.42,83.0928 2306.43,83.0888 2306.44,83.0849 2306.45,83.0809 2306.46,83.0769 2306.47,83.073 2306.48,83.069 2306.49,83.065 2306.5,83.0611 2306.51,83.0571 2306.52,83.0531 2306.52,83.0491 2306.53,83.0452 2306.54,83.0412 2306.55,83.0372 2306.56,83.0333 2306.57,83.0293 2306.58,83.0253 2306.59,83.0214 2306.6,83.0174 2306.61,83.0134 2306.62,83.0095 2306.63,83.0055 2306.63,83.0015 2306.64,82.9976 2306.65,82.9936 2306.66,82.9896 2306.67,82.9856 2306.68,82.9817 2306.69,82.9777 2306.7,82.9737 2306.71,82.9698 2306.72,82.9658 2306.73,82.9618 2306.74,82.9579 2306.75,82.9539 2306.75,82.9499 2306.76,82.946 2306.77,82.942 2306.78,82.938 2306.79,82.9341 2306.8,82.9301 2306.81,82.9261 2306.82,82.9222 2306.83,82.9182 2306.84,82.9142 2306.85,82.9103 2306.86,82.9063 2306.86,82.9023 2306.87,82.8984 2306.88,82.8944 2306.89,82.8904 2306.9,82.8865 2306.91,82.8825 2306.92,82.8785 2306.93,82.8746 2306.94,82.8706 2306.95,82.8667 2306.96,82.8627 2306.97,82.8587 2306.97,82.8548 2306.98,82.8508 2306.99,82.8468 2307,82.8429 2307.01,82.8389 2307.02,82.8349 2307.03,82.831 2307.04,82.827 2307.05,82.823 2307.06,82.8191 2307.07,82.8151 2307.08,82.8111 2307.09,82.8072 2307.09,82.8032 2307.1,82.7992 2307.11,82.7953 2307.12,82.7913 2307.13,82.7874 2307.14,82.7834 2307.15,82.7794 2307.16,82.7755 2307.17,82.7715 2307.18,82.7675 2307.19,82.7636 2307.2,82.7596 2307.2,82.7556 2307.21,82.7517 2307.22,82.7477 2307.23,82.7438 2307.24,82.7398 2307.25,82.7358 2307.26,82.7319 2307.27,82.7279 2307.28,82.7239 2307.29,82.72 2307.3,82.716 2307.31,82.7121 2307.31,82.7081 2307.32,82.7041 2307.33,82.7002 2307.34,82.6962 2307.35,82.6922 2307.36,82.6883 2307.37,82.6843 2307.38,82.6804 2307.39,82.6764 2307.4,82.6724 2307.41,82.6685 2307.42,82.6645 2307.43,82.6605 2307.43,82.6566 2307.44,82.6526 2307.45,82.6487 2307.46,82.6447 2307.47,82.6407 2307.48,82.6368 2307.49,82.6328 2307.5,82.6289 2307.51,82.6249 2307.52,82.6209 2307.53,82.617 2307.54,82.613 2307.54,82.609 2307.55,82.6051 2307.56,82.6011 2307.57,82.5972 2307.58,82.5932 2307.59,82.5892 2307.6,82.5853 2307.61,82.5813 2307.62,82.5774 2307.63,82.5734 2307.64,82.5694 2307.65,82.5655 2307.65,82.5615 2307.66,82.5576 2307.67,82.5536 2307.68,82.5496 2307.69,82.5457 2307.7,82.5417 2307.71,82.5378 2307.72,82.5338 2307.73,82.5298 2307.74,82.5259 2307.75,82.5219 2307.76,82.518 2307.77,82.514 2307.77,82.5101 2307.78,82.5061 2307.79,82.5021 2307.8,82.4982 2307.81,82.4942 2307.82,82.4903 2307.83,82.4863 2307.84,82.4823 2307.85,82.4784 2307.86,82.4744 2307.87,82.4705 2307.88,82.4665 2307.88,82.4626 2307.89,82.4586 2307.9,82.4546 2307.91,82.4507 2307.92,82.4467 2307.93,82.4428 2307.94,82.4388 2307.95,82.4348 2307.96,82.4309 2307.97,82.4269 2307.98,82.423 2307.99,82.419 2307.99,82.4151 2308,82.4111 2308.01,82.4071 2308.02,82.4032 2308.03,82.3992 2308.04,82.3953 2308.05,82.3913 2308.06,82.3874 2308.07,82.3834 2308.08,82.3794 2308.09,82.3755 2308.1,82.3715 2308.11,82.3676 2308.11,82.3636 2308.12,82.3597 2308.13,82.3557 2308.14,82.3518 2308.15,82.3478 2308.16,82.3438 2308.17,82.3399 2308.18,82.3359 2308.19,82.332 2308.2,82.328 2308.21,82.3241 2308.22,82.3201 2308.22,82.3162 2308.23,82.3122 2308.24,82.3082 2308.25,82.3043 2308.26,82.3003 2308.27,82.2964 2308.28,82.2924 2308.29,82.2885 2308.3,82.2845 2308.31,82.2806 2308.32,82.2766 2308.33,82.2727 2308.33,82.2687 2308.34,82.2647 2308.35,82.2608 2308.36,82.2568 2308.37,82.2529 2308.38,82.2489 2308.39,82.245 2308.4,82.241 2308.41,82.2371 2308.42,82.2331 2308.43,82.2292 2308.44,82.2252 2308.45,82.2212 2308.45,82.2173 2308.46,82.2133 2308.47,82.2094 2308.48,82.2054 2308.49,82.2015 2308.5,82.1975 2308.51,82.1936 2308.52,82.1896 2308.53,82.1857 2308.54,82.1817 2308.55,82.1778 2308.56,82.1738 2308.56,82.1699 2308.57,82.1659 2308.58,82.162 2308.59,82.158 2308.6,82.154 2308.61,82.1501 2308.62,82.1461 2308.63,82.1422 2308.64,82.1382 2308.65,82.1343 2308.66,82.1303 2308.67,82.1264 2308.67,82.1224 2308.68,82.1185 2308.69,82.1145 2308.7,82.1106 2308.71,82.1066 2308.72,82.1027 2308.73,82.0987 2308.74,82.0948 2308.75,82.0908 2308.76,82.0869 2308.77,82.0829 2308.78,82.079 2308.79,82.075 2308.79,82.0711 2308.8,82.0671 2308.81,82.0632 2308.82,82.0592 2308.83,82.0553 2308.84,82.0513 2308.85,82.0474 2308.86,82.0434 2308.87,82.0395 2308.88,82.0355 2308.89,82.0316 2308.9,82.0276 2308.9,82.0237 2308.91,82.0197 2308.92,82.0158 2308.93,82.0118 2308.94,82.0079 2308.95,82.0039 2308.96,82 2308.97,81.996 2308.98,81.9921 2308.99,81.9881 2309,81.9842 2309.01,81.9802 2309.01,81.9763 2309.02,81.9723 2309.03,81.9684 2309.04,81.9644 2309.05,81.9605 2309.06,81.9565 2309.07,81.9526 2309.08,81.9486 2309.09,81.9447 2309.1,81.9407 2309.11,81.9368 2309.12,81.9328 2309.13,81.9289 2309.13,81.9249 2309.14,81.921 2309.15,81.917 2309.16,81.9131 2309.17,81.9091 2309.18,81.9052 2309.19,81.9012 2309.2,81.8973 2309.21,81.8934 2309.22,81.8894 2309.23,81.8855 2309.24,81.8815 2309.24,81.8776 2309.25,81.8736 2309.26,81.8697 2309.27,81.8657 2309.28,81.8618 2309.29,81.8578 2309.3,81.8539 2309.31,81.8499 2309.32,81.846 2309.33,81.842 2309.34,81.8381 2309.35,81.8341 2309.35,81.8302 2309.36,81.8263 2309.37,81.8223 2309.38,81.8184 2309.39,81.8144 2309.4,81.8105 2309.41,81.8065 2309.42,81.8026 2309.43,81.7986 2309.44,81.7947 2309.45,81.7907 2309.46,81.7868 2309.47,81.7829 2309.47,81.7789 2309.48,81.775 2309.49,81.771 2309.5,81.7671 2309.51,81.7631 2309.52,81.7592 2309.53,81.7552 2309.54,81.7513 2309.55,81.7473 2309.56,81.7434 2309.57,81.7395 2309.58,81.7355 2309.58,81.7316 2309.59,81.7276 2309.6,81.7237 2309.61,81.7197 2309.62,81.7158 2309.63,81.7118 2309.64,81.7079 2309.65,81.704 2309.66,81.7 2309.67,81.6961 2309.68,81.6921 2309.69,81.6882 2309.69,81.6842 2309.7,81.6803 2309.71,81.6763 2309.72,81.6724 2309.73,81.6685 2309.74,81.6645 2309.75,81.6606 2309.76,81.6566 2309.77,81.6527 2309.78,81.6487 2309.79,81.6448 2309.8,81.6409 2309.81,81.6369 2309.81,81.633 2309.82,81.629 2309.83,81.6251 2309.84,81.6211 2309.85,81.6172 2309.86,81.6133 2309.87,81.6093 2309.88,81.6054 2309.89,81.6014 2309.9,81.5975 2309.91,81.5935 2309.92,81.5896 2309.92,81.5857 2309.93,81.5817 2309.94,81.5778 2309.95,81.5738 2309.96,81.5699 2309.97,81.566 2309.98,81.562 2309.99,81.5581 2310,81.5541 2310.01,81.5502 2310.02,81.5462 2310.03,81.5423 2310.03,81.5384 2310.04,81.5344 2310.05,81.5305 2310.06,81.5265 2310.07,81.5226 2310.08,81.5187 2310.09,81.5147 2310.1,81.5108 2310.11,81.5068 2310.12,81.5029 2310.13,81.499 2310.14,81.495 2310.15,81.4911 2310.15,81.4871 2310.16,81.4832 2310.17,81.4793 2310.18,81.4753 2310.19,81.4714 2310.2,81.4674 2310.21,81.4635 2310.22,81.4596 2310.23,81.4556 2310.24,81.4517 2310.25,81.4477 2310.26,81.4438 2310.26,81.4399 2310.27,81.4359 2310.28,81.432 2310.29,81.428 2310.3,81.4241 2310.31,81.4202 2310.32,81.4162 2310.33,81.4123 2310.34,81.4083 2310.35,81.4044 2310.36,81.4005 2310.37,81.3965 2310.37,81.3926 2310.38,81.3887 2310.39,81.3847 2310.4,81.3808 2310.41,81.3768 2310.42,81.3729 2310.43,81.369 2310.44,81.365 2310.45,81.3611 2310.46,81.3572 2310.47,81.3532 2310.48,81.3493 2310.49,81.3453 2310.49,81.3414 2310.5,81.3375 2310.51,81.3335 2310.52,81.3296 2310.53,81.3257 2310.54,81.3217 2310.55,81.3178 2310.56,81.3138 2310.57,81.3099 2310.58,81.306 2310.59,81.302 2310.6,81.2981 2310.6,81.2942 2310.61,81.2902 2310.62,81.2863 2310.63,81.2823 2310.64,81.2784 2310.65,81.2745 2310.66,81.2705 2310.67,81.2666 2310.68,81.2627 2310.69,81.2587 2310.7,81.2548 2310.71,81.2509 2310.71,81.2469 2310.72,81.243 2310.73,81.239 2310.74,81.2351 2310.75,81.2312 2310.76,81.2272 2310.77,81.2233 2310.78,81.2194 2310.79,81.2154 2310.8,81.2115 2310.81,81.2076 2310.82,81.2036 2310.83,81.1997 2310.83,81.1958 2310.84,81.1918 2310.85,81.1879 2310.86,81.184 2310.87,81.18 2310.88,81.1761 2310.89,81.1722 2310.9,81.1682 2310.91,81.1643 2310.92,81.1603 2310.93,81.1564 2310.94,81.1525 2310.94,81.1485 2310.95,81.1446 2310.96,81.1407 2310.97,81.1367 2310.98,81.1328 2310.99,81.1289 2311,81.1249 2311.01,81.121 2311.02,81.1171 2311.03,81.1131 2311.04,81.1092 2311.05,81.1053 2311.05,81.1013 2311.06,81.0974 2311.07,81.0935 2311.08,81.0895 2311.09,81.0856 2311.1,81.0817 2311.11,81.0777 2311.12,81.0738 2311.13,81.0699 2311.14,81.0659 2311.15,81.062 2311.16,81.0581 2311.17,81.0541 2311.17,81.0502 2311.18,81.0463 2311.19,81.0424 2311.2,81.0384 2311.21,81.0345 2311.22,81.0306 2311.23,81.0266 2311.24,81.0227 2311.25,81.0188 2311.26,81.0148 2311.27,81.0109 2311.28,81.007 2311.28,81.003 2311.29,80.9991 2311.3,80.9952 2311.31,80.9912 2311.32,80.9873 2311.33,80.9834 2311.34,80.9794 2311.35,80.9755 2311.36,80.9716 2311.37,80.9677 2311.38,80.9637 2311.39,80.9598 2311.39,80.9559 2311.4,80.9519 2311.41,80.948 2311.42,80.9441 2311.43,80.9401 2311.44,80.9362 2311.45,80.9323 2311.46,80.9283 2311.47,80.9244 2311.48,80.9205 2311.49,80.9166 2311.5,80.9126 2311.51,80.9087 2311.51,80.9048 2311.52,80.9008 2311.53,80.8969 2311.54,80.893 2311.55,80.8891 2311.56,80.8851 2311.57,80.8812 2311.58,80.8773 2311.59,80.8733 2311.6,80.8694 2311.61,80.8655 2311.62,80.8615 2311.62,80.8576 2311.63,80.8537 2311.64,80.8498 2311.65,80.8458 2311.66,80.8419 2311.67,80.838 2311.68,80.834 2311.69,80.8301 2311.7,80.8262 2311.71,80.8223 2311.72,80.8183 2311.73,80.8144 2311.73,80.8105 2311.74,80.8065 2311.75,80.8026 2311.76,80.7987 2311.77,80.7948 2311.78,80.7908 2311.79,80.7869 2311.8,80.783 2311.81,80.7791 2311.82,80.7751 2311.83,80.7712 2311.84,80.7673 2311.85,80.7633 2311.85,80.7594 2311.86,80.7555 2311.87,80.7516 2311.88,80.7476 2311.89,80.7437 2311.9,80.7398 2311.91,80.7359 2311.92,80.7319 2311.93,80.728 2311.94,80.7241 2311.95,80.7202 2311.96,80.7162 2311.96,80.7123 2311.97,80.7084 2311.98,80.7044 2311.99,80.7005 2312,80.6966 2312.01,80.6927 2312.02,80.6887 2312.03,80.6848 2312.04,80.6809 2312.05,80.677 2312.06,80.673 2312.07,80.6691 2312.07,80.6652 2312.08,80.6613 2312.09,80.6573 2312.1,80.6534 2312.11,80.6495 2312.12,80.6456 2312.13,80.6416 2312.14,80.6377 2312.15,80.6338 2312.16,80.6299 2312.17,80.6259 2312.18,80.622 2312.19,80.6181 2312.19,80.6142 2312.2,80.6102 2312.21,80.6063 2312.22,80.6024 2312.23,80.5985 2312.24,80.5945 2312.25,80.5906 2312.26,80.5867 2312.27,80.5828 2312.28,80.5788 2312.29,80.5749 2312.3,80.571 2312.3,80.5671 2312.31,80.5631 2312.32,80.5592 2312.33,80.5553 2312.34,80.5514 2312.35,80.5475 2312.36,80.5435 2312.37,80.5396 2312.38,80.5357 2312.39,80.5318 2312.4,80.5278 2312.41,80.5239 2312.41,80.52 2312.42,80.5161 2312.43,80.5121 2312.44,80.5082 2312.45,80.5043 2312.46,80.5004 2312.47,80.4965 2312.48,80.4925 2312.49,80.4886 2312.5,80.4847 2312.51,80.4808 2312.52,80.4768 2312.53,80.4729 2312.53,80.469 2312.54,80.4651 2312.55,80.4612 2312.56,80.4572 2312.57,80.4533 2312.58,80.4494 2312.59,80.4455 2312.6,80.4416 2312.61,80.4376 2312.62,80.4337 2312.63,80.4298 2312.64,80.4259 2312.64,80.4219 2312.65,80.418 2312.66,80.4141 2312.67,80.4102 2312.68,80.4063 2312.69,80.4023 2312.7,80.3984 2312.71,80.3945 2312.72,80.3906 2312.73,80.3867 2312.74,80.3827 2312.75,80.3788 2312.75,80.3749 2312.76,80.371 2312.77,80.3671 2312.78,80.3631 2312.79,80.3592 2312.8,80.3553 2312.81,80.3514 2312.82,80.3475 2312.83,80.3435 2312.84,80.3396 2312.85,80.3357 2312.86,80.3318 2312.87,80.3279 2312.87,80.3239 2312.88,80.32 2312.89,80.3161 2312.9,80.3122 2312.91,80.3083 2312.92,80.3043 2312.93,80.3004 2312.94,80.2965 2312.95,80.2926 2312.96,80.2887 2312.97,80.2847 2312.98,80.2808 2312.98,80.2769 2312.99,80.273 2313,80.2691 2313.01,80.2652 2313.02,80.2612 2313.03,80.2573 2313.04,80.2534 2313.05,80.2495 2313.06,80.2456 2313.07,80.2416 2313.08,80.2377 2313.09,80.2338 2313.09,80.2299 2313.1,80.226 2313.11,80.2221 2313.12,80.2181 2313.13,80.2142 2313.14,80.2103 2313.15,80.2064 2313.16,80.2025 2313.17,80.1986 2313.18,80.1946 2313.19,80.1907 2313.2,80.1868 2313.21,80.1829 2313.21,80.179 2313.22,80.175 2313.23,80.1711 2313.24,80.1672 2313.25,80.1633 2313.26,80.1594 2313.27,80.1555 2313.28,80.1515 2313.29,80.1476 2313.3,80.1437 2313.31,80.1398 2313.32,80.1359 2313.32,80.132 2313.33,80.1281 2313.34,80.1241 2313.35,80.1202 2313.36,80.1163 2313.37,80.1124 2313.38,80.1085 2313.39,80.1046 2313.4,80.1006 2313.41,80.0967 2313.42,80.0928 2313.43,80.0889 2313.43,80.085 2313.44,80.0811 2313.45,80.0772 2313.46,80.0732 2313.47,80.0693 2313.48,80.0654 2313.49,80.0615 2313.5,80.0576 2313.51,80.0537 2313.52,80.0497 2313.53,80.0458 2313.54,80.0419 2313.55,80.038 2313.55,80.0341 2313.56,80.0302 2313.57,80.0263 2313.58,80.0223 2313.59,80.0184 2313.6,80.0145 2313.61,80.0106 2313.62,80.0067 2313.63,80.0028 2313.64,79.9989 2313.65,79.9949 2313.66,79.991 2313.66,79.9871 2313.67,79.9832 2313.68,79.9793 2313.69,79.9754 2313.7,79.9715 2313.71,79.9676 2313.72,79.9636 2313.73,79.9597 2313.74,79.9558 2313.75,79.9519 2313.76,79.948 2313.77,79.9441 2313.77,79.9402 2313.78,79.9363 2313.79,79.9323 2313.8,79.9284 2313.81,79.9245 2313.82,79.9206 2313.83,79.9167 2313.84,79.9128 2313.85,79.9089 2313.86,79.905 2313.87,79.901 2313.88,79.8971 2313.89,79.8932 2313.89,79.8893 2313.9,79.8854 2313.91,79.8815 2313.92,79.8776 2313.93,79.8737 2313.94,79.8697 2313.95,79.8658 2313.96,79.8619 2313.97,79.858 2313.98,79.8541 2313.99,79.8502 2314,79.8463 2314,79.8424 2314.01,79.8385 2314.02,79.8345 2314.03,79.8306 2314.04,79.8267 2314.05,79.8228 2314.06,79.8189 2314.07,79.815 2314.08,79.8111 2314.09,79.8072 2314.1,79.8033 2314.11,79.7994 2314.11,79.7954 2314.12,79.7915 2314.13,79.7876 2314.14,79.7837 2314.15,79.7798 2314.16,79.7759 2314.17,79.772 2314.18,79.7681 2314.19,79.7642 2314.2,79.7603 2314.21,79.7563 2314.22,79.7524 2314.23,79.7485 2314.23,79.7446 2314.24,79.7407 2314.25,79.7368 2314.26,79.7329 2314.27,79.729 2314.28,79.7251 2314.29,79.7212 2314.3,79.7173 2314.31,79.7133 2314.32,79.7094 2314.33,79.7055 2314.34,79.7016 2314.34,79.6977 2314.35,79.6938 2314.36,79.6899 2314.37,79.686 2314.38,79.6821 2314.39,79.6782 2314.4,79.6743 2314.41,79.6704 2314.42,79.6664 2314.43,79.6625 2314.44,79.6586 2314.45,79.6547 2314.45,79.6508 2314.46,79.6469 2314.47,79.643 2314.48,79.6391 2314.49,79.6352 2314.5,79.6313 2314.51,79.6274 2314.52,79.6235 2314.53,79.6196 2314.54,79.6156 2314.55,79.6117 2314.56,79.6078 2314.57,79.6039 2314.57,79.6 2314.58,79.5961 2314.59,79.5922 2314.6,79.5883 2314.61,79.5844 2314.62,79.5805 2314.63,79.5766 2314.64,79.5727 2314.65,79.5688 2314.66,79.5649 2314.67,79.561 2314.68,79.557 2314.68,79.5531 2314.69,79.5492 2314.7,79.5453 2314.71,79.5414 2314.72,79.5375 2314.73,79.5336 2314.74,79.5297 2314.75,79.5258 2314.76,79.5219 2314.77,79.518 2314.78,79.5141 2314.79,79.5102 2314.79,79.5063 2314.8,79.5024 2314.81,79.4985 2314.82,79.4946 2314.83,79.4907 2314.84,79.4868 2314.85,79.4828 2314.86,79.4789 2314.87,79.475 2314.88,79.4711 2314.89,79.4672 2314.9,79.4633 2314.91,79.4594 2314.91,79.4555 2314.92,79.4516 2314.93,79.4477 2314.94,79.4438 2314.95,79.4399 2314.96,79.436 2314.97,79.4321 2314.98,79.4282 2314.99,79.4243 2315,79.4204 2315.01,79.4165 2315.02,79.4126 2315.02,79.4087 2315.03,79.4048 2315.04,79.4009 2315.05,79.397 2315.06,79.3931 2315.07,79.3892 2315.08,79.3852 2315.09,79.3813 2315.1,79.3774 2315.11,79.3735 2315.12,79.3696 2315.13,79.3657 2315.13,79.3618 2315.14,79.3579 2315.15,79.354 2315.16,79.3501 2315.17,79.3462 2315.18,79.3423 2315.19,79.3384 2315.2,79.3345 2315.21,79.3306 2315.22,79.3267 2315.23,79.3228 2315.24,79.3189 2315.25,79.315 2315.25,79.3111 2315.26,79.3072 2315.27,79.3033 2315.28,79.2994 2315.29,79.2955 2315.3,79.2916 2315.31,79.2877 2315.32,79.2838 2315.33,79.2799 2315.34,79.276 2315.35,79.2721 2315.36,79.2682 2315.36,79.2643 2315.37,79.2604 2315.38,79.2565 2315.39,79.2526 2315.4,79.2487 2315.41,79.2448 2315.42,79.2409 2315.43,79.237 2315.44,79.2331 2315.45,79.2292 2315.46,79.2253 2315.47,79.2214 2315.47,79.2175 2315.48,79.2136 2315.49,79.2097 2315.5,79.2058 2315.51,79.2019 2315.52,79.198 2315.53,79.1941 2315.54,79.1902 2315.55,79.1863 2315.56,79.1824 2315.57,79.1785 2315.58,79.1746 2315.59,79.1707 2315.59,79.1668 2315.6,79.1629 2315.61,79.159 2315.62,79.1551 2315.63,79.1512 2315.64,79.1473 2315.65,79.1434 2315.66,79.1395 2315.67,79.1356 2315.68,79.1317 2315.69,79.1278 2315.7,79.1239 2315.7,79.12 2315.71,79.1161 2315.72,79.1122 2315.73,79.1083 2315.74,79.1044 2315.75,79.1005 2315.76,79.0966 2315.77,79.0927 2315.78,79.0888 2315.79,79.0849 2315.8,79.081 2315.81,79.0771 2315.81,79.0732 2315.82,79.0693 2315.83,79.0654 2315.84,79.0615 2315.85,79.0576 2315.86,79.0537 2315.87,79.0498 2315.88,79.0459 2315.89,79.042 2315.9,79.0381 2315.91,79.0342 2315.92,79.0303 2315.93,79.0264 2315.93,79.0226 2315.94,79.0187 2315.95,79.0148 2315.96,79.0109 2315.97,79.007 2315.98,79.0031 2315.99,78.9992 2316,78.9953 2316.01,78.9914 2316.02,78.9875 2316.03,78.9836 2316.04,78.9797 2316.04,78.9758 2316.05,78.9719 2316.06,78.968 2316.07,78.9641 2316.08,78.9602 2316.09,78.9563 2316.1,78.9524 2316.11,78.9485 2316.12,78.9446 2316.13,78.9407 2316.14,78.9368 2316.15,78.9329 2316.15,78.929 2316.16,78.9252 2316.17,78.9213 2316.18,78.9174 2316.19,78.9135 2316.2,78.9096 2316.21,78.9057 2316.22,78.9018 2316.23,78.8979 2316.24,78.894 2316.25,78.8901 2316.26,78.8862 2316.27,78.8823 2316.27,78.8784 2316.28,78.8745 2316.29,78.8706 2316.3,78.8667 2316.31,78.8628 2316.32,78.8589 2316.33,78.855 2316.34,78.8512 2316.35,78.8473 2316.36,78.8434 2316.37,78.8395 2316.38,78.8356 2316.38,78.8317 2316.39,78.8278 2316.4,78.8239 2316.41,78.82 2316.42,78.8161 2316.43,78.8122 2316.44,78.8083 2316.45,78.8044 2316.46,78.8005 2316.47,78.7966 2316.48,78.7928 2316.49,78.7889 2316.49,78.785 2316.5,78.7811 2316.51,78.7772 2316.52,78.7733 2316.53,78.7694 2316.54,78.7655 2316.55,78.7616 2316.56,78.7577 2316.57,78.7538 2316.58,78.7499 2316.59,78.746 2316.6,78.7421 2316.61,78.7383 2316.61,78.7344 2316.62,78.7305 2316.63,78.7266 2316.64,78.7227 2316.65,78.7188 2316.66,78.7149 2316.67,78.711 2316.68,78.7071 2316.69,78.7032 2316.7,78.6993 2316.71,78.6954 2316.72,78.6916 2316.72,78.6877 2316.73,78.6838 2316.74,78.6799 2316.75,78.676 2316.76,78.6721 2316.77,78.6682 2316.78,78.6643 2316.79,78.6604 2316.8,78.6565 2316.81,78.6526 2316.82,78.6488 2316.83,78.6449 2316.83,78.641 2316.84,78.6371 2316.85,78.6332 2316.86,78.6293 2316.87,78.6254 2316.88,78.6215 2316.89,78.6176 2316.9,78.6137 2316.91,78.6099 2316.92,78.606 2316.93,78.6021 2316.94,78.5982 2316.95,78.5943 2316.95,78.5904 2316.96,78.5865 2316.97,78.5826 2316.98,78.5787 2316.99,78.5749 2317,78.571 2317.01,78.5671 2317.02,78.5632 2317.03,78.5593 2317.04,78.5554 2317.05,78.5515 2317.06,78.5476 2317.06,78.5437 2317.07,78.5399 2317.08,78.536 2317.09,78.5321 2317.1,78.5282 2317.11,78.5243 2317.12,78.5204 2317.13,78.5165 2317.14,78.5126 2317.15,78.5087 2317.16,78.5049 2317.17,78.501 2317.17,78.4971 2317.18,78.4932 2317.19,78.4893 2317.2,78.4854 2317.21,78.4815 2317.22,78.4776 2317.23,78.4738 2317.24,78.4699 2317.25,78.466 2317.26,78.4621 2317.27,78.4582 2317.28,78.4543 2317.29,78.4504 2317.29,78.4465 2317.3,78.4427 2317.31,78.4388 2317.32,78.4349 2317.33,78.431 2317.34,78.4271 2317.35,78.4232 2317.36,78.4193 2317.37,78.4154 2317.38,78.4116 2317.39,78.4077 2317.4,78.4038 2317.4,78.3999 2317.41,78.396 2317.42,78.3921 2317.43,78.3882 2317.44,78.3844 2317.45,78.3805 2317.46,78.3766 2317.47,78.3727 2317.48,78.3688 2317.49,78.3649 2317.5,78.361 2317.51,78.3572 2317.51,78.3533 2317.52,78.3494 2317.53,78.3455 2317.54,78.3416 2317.55,78.3377 2317.56,78.3338 2317.57,78.33 2317.58,78.3261 2317.59,78.3222 2317.6,78.3183 2317.61,78.3144 2317.62,78.3105 2317.63,78.3066 2317.63,78.3028 2317.64,78.2989 2317.65,78.295 2317.66,78.2911 2317.67,78.2872 2317.68,78.2833 2317.69,78.2795 2317.7,78.2756 2317.71,78.2717 2317.72,78.2678 2317.73,78.2639 2317.74,78.26 2317.74,78.2562 2317.75,78.2523 2317.76,78.2484 2317.77,78.2445 2317.78,78.2406 2317.79,78.2367 2317.8,78.2329 2317.81,78.229 2317.82,78.2251 2317.83,78.2212 2317.84,78.2173 2317.85,78.2134 2317.85,78.2096 2317.86,78.2057 2317.87,78.2018 2317.88,78.1979 2317.89,78.194 2317.9,78.1901 2317.91,78.1863 2317.92,78.1824 2317.93,78.1785 2317.94,78.1746 2317.95,78.1707 2317.96,78.1668 2317.97,78.163 2317.97,78.1591 2317.98,78.1552 2317.99,78.1513 2318,78.1474 2318.01,78.1435 2318.02,78.1397 2318.03,78.1358 2318.04,78.1319 2318.05,78.128 2318.06,78.1241 2318.07,78.1203 2318.08,78.1164 2318.08,78.1125 2318.09,78.1086 2318.1,78.1047 2318.11,78.1009 2318.12,78.097 2318.13,78.0931 2318.14,78.0892 2318.15,78.0853 2318.16,78.0814 2318.17,78.0776 2318.18,78.0737 2318.19,78.0698 2318.19,78.0659 2318.2,78.062 2318.21,78.0582 2318.22,78.0543 2318.23,78.0504 2318.24,78.0465 2318.25,78.0426 2318.26,78.0388 2318.27,78.0349 2318.28,78.031 2318.29,78.0271 2318.3,78.0232 2318.31,78.0194 2318.31,78.0155 2318.32,78.0116 2318.33,78.0077 2318.34,78.0038 2318.35,78 2318.36,77.9961 2318.37,77.9922 2318.38,77.9883 2318.39,77.9844 2318.4,77.9806 2318.41,77.9767 2318.42,77.9728 2318.42,77.9689 2318.43,77.965 2318.44,77.9612 2318.45,77.9573 2318.46,77.9534 2318.47,77.9495 2318.48,77.9457 2318.49,77.9418 2318.5,77.9379 2318.51,77.934 2318.52,77.9301 2318.53,77.9263 2318.53,77.9224 2318.54,77.9185 2318.55,77.9146 2318.56,77.9107 2318.57,77.9069 2318.58,77.903 2318.59,77.8991 2318.6,77.8952 2318.61,77.8914 2318.62,77.8875 2318.63,77.8836 2318.64,77.8797 2318.65,77.8758 2318.65,77.872 2318.66,77.8681 2318.67,77.8642 2318.68,77.8603 2318.69,77.8565 2318.7,77.8526 2318.71,77.8487 2318.72,77.8448 2318.73,77.8409 2318.74,77.8371 2318.75,77.8332 2318.76,77.8293 2318.76,77.8254 2318.77,77.8216 2318.78,77.8177 2318.79,77.8138 2318.8,77.8099 2318.81,77.8061 2318.82,77.8022 2318.83,77.7983 2318.84,77.7944 2318.85,77.7906 2318.86,77.7867 2318.87,77.7828 2318.87,77.7789 2318.88,77.7751 2318.89,77.7712 2318.9,77.7673 2318.91,77.7634 2318.92,77.7595 2318.93,77.7557 2318.94,77.7518 2318.95,77.7479 2318.96,77.744 2318.97,77.7402 2318.98,77.7363 2318.99,77.7324 2318.99,77.7285 2319,77.7247 2319.01,77.7208 2319.02,77.7169 2319.03,77.713 2319.04,77.7092 2319.05,77.7053 2319.06,77.7014 2319.07,77.6975 2319.08,77.6937 2319.09,77.6898 2319.1,77.6859 2319.1,77.682 2319.11,77.6782 2319.12,77.6743 2319.13,77.6704 2319.14,77.6666 2319.15,77.6627 2319.16,77.6588 2319.17,77.6549 2319.18,77.6511 2319.19,77.6472 2319.2,77.6433 2319.21,77.6394 2319.21,77.6356 2319.22,77.6317 2319.23,77.6278 2319.24,77.6239 2319.25,77.6201 2319.26,77.6162 2319.27,77.6123 2319.28,77.6084 2319.29,77.6046 2319.3,77.6007 2319.31,77.5968 2319.32,77.593 2319.33,77.5891 2319.33,77.5852 2319.34,77.5813 2319.35,77.5775 2319.36,77.5736 2319.37,77.5697 2319.38,77.5658 2319.39,77.562 2319.4,77.5581 2319.41,77.5542 2319.42,77.5504 2319.43,77.5465 2319.44,77.5426 2319.44,77.5387 2319.45,77.5349 2319.46,77.531 2319.47,77.5271 2319.48,77.5233 2319.49,77.5194 2319.5,77.5155 2319.51,77.5116 2319.52,77.5078 2319.53,77.5039 2319.54,77.5 2319.55,77.4962 2319.56,77.4923 2319.56,77.4884 2319.57,77.4845 2319.58,77.4807 2319.59,77.4768 2319.6,77.4729 2319.61,77.4691 2319.62,77.4652 2319.63,77.4613 2319.64,77.4574 2319.65,77.4536 2319.66,77.4497 2319.67,77.4458 2319.67,77.442 2319.68,77.4381 2319.69,77.4342 2319.7,77.4304 2319.71,77.4265 2319.72,77.4226 2319.73,77.4187 2319.74,77.4149 2319.75,77.411 2319.76,77.4071 2319.77,77.4033 2319.78,77.3994 2319.78,77.3955 2319.79,77.3917 2319.8,77.3878 2319.81,77.3839 2319.82,77.38 2319.83,77.3762 2319.84,77.3723 2319.85,77.3684 2319.86,77.3646 2319.87,77.3607 2319.88,77.3568 2319.89,77.353 2319.9,77.3491 2319.9,77.3452 2319.91,77.3414 2319.92,77.3375 2319.93,77.3336 2319.94,77.3298 2319.95,77.3259 2319.96,77.322 2319.97,77.3181 2319.98,77.3143 2319.99,77.3104 2320,77.3065 2320.01,77.3027 2320.01,77.2988 2320.02,77.2949 2320.03,77.2911 2320.04,77.2872 2320.05,77.2833 2320.06,77.2795 2320.07,77.2756 2320.08,77.2717 2320.09,77.2679 2320.1,77.264 2320.11,77.2601 2320.12,77.2563 2320.12,77.2524 2320.13,77.2485 2320.14,77.2447 2320.15,77.2408 2320.16,77.2369 2320.17,77.2331 2320.18,77.2292 2320.19,77.2253 2320.2,77.2215 2320.21,77.2176 2320.22,77.2137 2320.23,77.2099 2320.24,77.206 2320.24,77.2021 2320.25,77.1983 2320.26,77.1944 2320.27,77.1905 2320.28,77.1867 2320.29,77.1828 2320.3,77.1789 2320.31,77.1751 2320.32,77.1712 2320.33,77.1673 2320.34,77.1635 2320.35,77.1596 2320.35,77.1557 2320.36,77.1519 2320.37,77.148 2320.38,77.1441 2320.39,77.1403 2320.4,77.1364 2320.41,77.1325 2320.42,77.1287 2320.43,77.1248 2320.44,77.1209 2320.45,77.1171 2320.46,77.1132 2320.46,77.1093 2320.47,77.1055 2320.48,77.1016 2320.49,77.0978 2320.5,77.0939 2320.51,77.09 2320.52,77.0862 2320.53,77.0823 2320.54,77.0784 2320.55,77.0746 2320.56,77.0707 2320.57,77.0668 2320.58,77.063 2320.58,77.0591 2320.59,77.0552 2320.6,77.0514 2320.61,77.0475 2320.62,77.0437 2320.63,77.0398 2320.64,77.0359 2320.65,77.0321 2320.66,77.0282 2320.67,77.0243 2320.68,77.0205 2320.69,77.0166 2320.69,77.0127 2320.7,77.0089 2320.71,77.005 2320.72,77.0012 2320.73,76.9973 2320.74,76.9934 2320.75,76.9896 2320.76,76.9857 2320.77,76.9818 2320.78,76.978 2320.79,76.9741 2320.8,76.9703 2320.8,76.9664 2320.81,76.9625 2320.82,76.9587 2320.83,76.9548 2320.84,76.9509 2320.85,76.9471 2320.86,76.9432 2320.87,76.9394 2320.88,76.9355 2320.89,76.9316 2320.9,76.9278 2320.91,76.9239 2320.92,76.92 2320.92,76.9162 2320.93,76.9123 2320.94,76.9085 2320.95,76.9046 2320.96,76.9007 2320.97,76.8969 2320.98,76.893 2320.99,76.8892 2321,76.8853 2321.01,76.8814 2321.02,76.8776 2321.03,76.8737 2321.03,76.8698 2321.04,76.866 2321.05,76.8621 2321.06,76.8583 2321.07,76.8544 2321.08,76.8505 2321.09,76.8467 2321.1,76.8428 2321.11,76.839 2321.12,76.8351 2321.13,76.8312 2321.14,76.8274 2321.14,76.8235 2321.15,76.8197 2321.16,76.8158 2321.17,76.8119 2321.18,76.8081 2321.19,76.8042 2321.2,76.8004 2321.21,76.7965 2321.22,76.7926 2321.23,76.7888 2321.24,76.7849 2321.25,76.7811 2321.26,76.7772 2321.26,76.7733 2321.27,76.7695 2321.28,76.7656 2321.29,76.7618 2321.3,76.7579 2321.31,76.754 2321.32,76.7502 2321.33,76.7463 2321.34,76.7425 2321.35,76.7386 2321.36,76.7348 2321.37,76.7309 2321.37,76.727 2321.38,76.7232 2321.39,76.7193 2321.4,76.7155 2321.41,76.7116 2321.42,76.7077 2321.43,76.7039 2321.44,76.7 2321.45,76.6962 2321.46,76.6923 2321.47,76.6884 2321.48,76.6846 2321.48,76.6807 2321.49,76.6769 2321.5,76.673 2321.51,76.6692 2321.52,76.6653 2321.53,76.6614 2321.54,76.6576 2321.55,76.6537 2321.56,76.6499 2321.57,76.646 2321.58,76.6422 2321.59,76.6383 2321.6,76.6344 2321.6,76.6306 2321.61,76.6267 2321.62,76.6229 2321.63,76.619 2321.64,76.6152 2321.65,76.6113 2321.66,76.6074 2321.67,76.6036 2321.68,76.5997 2321.69,76.5959 2321.7,76.592 2321.71,76.5882 2321.71,76.5843 2321.72,76.5804 2321.73,76.5766 2321.74,76.5727 2321.75,76.5689 2321.76,76.565 2321.77,76.5612 2321.78,76.5573 2321.79,76.5535 2321.8,76.5496 2321.81,76.5457 2321.82,76.5419 2321.82,76.538 2321.83,76.5342 2321.84,76.5303 2321.85,76.5265 2321.86,76.5226 2321.87,76.5188 2321.88,76.5149 2321.89,76.511 2321.9,76.5072 2321.91,76.5033 2321.92,76.4995 2321.93,76.4956 2321.94,76.4918 2321.94,76.4879 2321.95,76.4841 2321.96,76.4802 2321.97,76.4764 2321.98,76.4725 2321.99,76.4686 2322,76.4648 2322.01,76.4609 2322.02,76.4571 2322.03,76.4532 2322.04,76.4494 2322.05,76.4455 2322.05,76.4417 2322.06,76.4378 2322.07,76.434 2322.08,76.4301 2322.09,76.4262 2322.1,76.4224 2322.11,76.4185 2322.12,76.4147 2322.13,76.4108 2322.14,76.407 2322.15,76.4031 2322.16,76.3993 2322.16,76.3954 2322.17,76.3916 2322.18,76.3877 2322.19,76.3839 2322.2,76.38 2322.21,76.3762 2322.22,76.3723 2322.23,76.3684 2322.24,76.3646 2322.25,76.3607 2322.26,76.3569 2322.27,76.353 2322.28,76.3492 2322.28,76.3453 2322.29,76.3415 2322.3,76.3376 2322.31,76.3338 2322.32,76.3299 2322.33,76.3261 2322.34,76.3222 2322.35,76.3184 2322.36,76.3145 2322.37,76.3107 2322.38,76.3068 2322.39,76.303 2322.39,76.2991 2322.4,76.2953 2322.41,76.2914 2322.42,76.2875 2322.43,76.2837 2322.44,76.2798 2322.45,76.276 2322.46,76.2721 2322.47,76.2683 2322.48,76.2644 2322.49,76.2606 2322.5,76.2567 2322.5,76.2529 2322.51,76.249 2322.52,76.2452 2322.53,76.2413 2322.54,76.2375 2322.55,76.2336 2322.56,76.2298 2322.57,76.2259 2322.58,76.2221 2322.59,76.2182 2322.6,76.2144 2322.61,76.2105 2322.62,76.2067 2322.62,76.2028 2322.63,76.199 2322.64,76.1951 2322.65,76.1913 2322.66,76.1874 2322.67,76.1836 2322.68,76.1797 2322.69,76.1759 2322.7,76.172 2322.71,76.1682 2322.72,76.1643 2322.73,76.1605 2322.73,76.1566 2322.74,76.1528 2322.75,76.1489 2322.76,76.1451 2322.77,76.1412 2322.78,76.1374 2322.79,76.1335 2322.8,76.1297 2322.81,76.1258 2322.82,76.122 2322.83,76.1181 2322.84,76.1143 2322.84,76.1104 2322.85,76.1066 2322.86,76.1027 2322.87,76.0989 2322.88,76.095 2322.89,76.0912 2322.9,76.0874 2322.91,76.0835 2322.92,76.0797 2322.93,76.0758 2322.94,76.072 2322.95,76.0681 2322.96,76.0643 2322.96,76.0604 2322.97,76.0566 2322.98,76.0527 2322.99,76.0489 2323,76.045 2323.01,76.0412 2323.02,76.0373 2323.03,76.0335 2323.04,76.0296 2323.05,76.0258 2323.06,76.0219 2323.07,76.0181 2323.07,76.0142 2323.08,76.0104 2323.09,76.0065 2323.1,76.0027 2323.11,75.9989 2323.12,75.995 2323.13,75.9912 2323.14,75.9873 2323.15,75.9835 2323.16,75.9796 2323.17,75.9758 2323.18,75.9719 2323.18,75.9681 2323.19,75.9642 2323.2,75.9604 2323.21,75.9565 2323.22,75.9527 2323.23,75.9488 2323.24,75.945 2323.25,75.9412 2323.26,75.9373 2323.27,75.9335 2323.28,75.9296 2323.29,75.9258 2323.3,75.9219 2323.3,75.9181 2323.31,75.9142 2323.32,75.9104 2323.33,75.9065 2323.34,75.9027 2323.35,75.8989 2323.36,75.895 2323.37,75.8912 2323.38,75.8873 2323.39,75.8835 2323.4,75.8796 2323.41,75.8758 2323.41,75.8719 2323.42,75.8681 2323.43,75.8642 2323.44,75.8604 2323.45,75.8566 2323.46,75.8527 2323.47,75.8489 2323.48,75.845 2323.49,75.8412 2323.5,75.8373 2323.51,75.8335 2323.52,75.8296 2323.52,75.8258 2323.53,75.822 2323.54,75.8181 2323.55,75.8143 2323.56,75.8104 2323.57,75.8066 2323.58,75.8027 2323.59,75.7989 2323.6,75.7951 2323.61,75.7912 2323.62,75.7874 2323.63,75.7835 2323.64,75.7797 2323.64,75.7758 2323.65,75.772 2323.66,75.7681 2323.67,75.7643 2323.68,75.7605 2323.69,75.7566 2323.7,75.7528 2323.71,75.7489 2323.72,75.7451 2323.73,75.7412 2323.74,75.7374 2323.75,75.7336 2323.75,75.7297 2323.76,75.7259 2323.77,75.722 2323.78,75.7182 2323.79,75.7143 2323.8,75.7105 2323.81,75.7067 2323.82,75.7028 2323.83,75.699 2323.84,75.6951 2323.85,75.6913 2323.86,75.6875 2323.86,75.6836 2323.87,75.6798 2323.88,75.6759 2323.89,75.6721 2323.9,75.6682 2323.91,75.6644 2323.92,75.6606 2323.93,75.6567 2323.94,75.6529 2323.95,75.649 2323.96,75.6452 2323.97,75.6414 2323.98,75.6375 2323.98,75.6337 2323.99,75.6298 2324,75.626 2324.01,75.6221 2324.02,75.6183 2324.03,75.6145 2324.04,75.6106 2324.05,75.6068 2324.06,75.6029 2324.07,75.5991 2324.08,75.5953 2324.09,75.5914 2324.09,75.5876 2324.1,75.5837 2324.11,75.5799 2324.12,75.5761 2324.13,75.5722 2324.14,75.5684 2324.15,75.5645 2324.16,75.5607 2324.17,75.5569 2324.18,75.553 2324.19,75.5492 2324.2,75.5453 2324.2,75.5415 2324.21,75.5377 2324.22,75.5338 2324.23,75.53 2324.24,75.5261 2324.25,75.5223 2324.26,75.5185 2324.27,75.5146 2324.28,75.5108 2324.29,75.5069 2324.3,75.5031 2324.31,75.4993 2324.32,75.4954 2324.32,75.4916 2324.33,75.4877 2324.34,75.4839 2324.35,75.4801 2324.36,75.4762 2324.37,75.4724 2324.38,75.4686 2324.39,75.4647 2324.4,75.4609 2324.41,75.457 2324.42,75.4532 2324.43,75.4494 2324.43,75.4455 2324.44,75.4417 2324.45,75.4378 2324.46,75.434 2324.47,75.4302 2324.48,75.4263 2324.49,75.4225 2324.5,75.4187 2324.51,75.4148 2324.52,75.411 2324.53,75.4071 2324.54,75.4033 2324.54,75.3995 2324.55,75.3956 2324.56,75.3918 2324.57,75.388 2324.58,75.3841 2324.59,75.3803 2324.6,75.3764 2324.61,75.3726 2324.62,75.3688 2324.63,75.3649 2324.64,75.3611 2324.65,75.3573 2324.66,75.3534 2324.66,75.3496 2324.67,75.3458 2324.68,75.3419 2324.69,75.3381 2324.7,75.3342 2324.71,75.3304 2324.72,75.3266 2324.73,75.3227 2324.74,75.3189 2324.75,75.3151 2324.76,75.3112 2324.77,75.3074 2324.77,75.3036 2324.78,75.2997 2324.79,75.2959 2324.8,75.292 2324.81,75.2882 2324.82,75.2844 2324.83,75.2805 2324.84,75.2767 2324.85,75.2729 2324.86,75.269 2324.87,75.2652 2324.88,75.2614 2324.88,75.2575 2324.89,75.2537 2324.9,75.2499 2324.91,75.246 2324.92,75.2422 2324.93,75.2383 2324.94,75.2345 2324.95,75.2307 2324.96,75.2268 2324.97,75.223 2324.98,75.2192 2324.99,75.2153 2325,75.2115 2325,75.2077 2325.01,75.2038 2325.02,75.2 2325.03,75.1962 2325.04,75.1923 2325.05,75.1885 2325.06,75.1847 2325.07,75.1808 2325.08,75.177 2325.09,75.1732 2325.1,75.1693 2325.11,75.1655 2325.11,75.1617 2325.12,75.1578 2325.13,75.154 2325.14,75.1502 2325.15,75.1463 2325.16,75.1425 2325.17,75.1387 2325.18,75.1348 2325.19,75.131 2325.2,75.1272 2325.21,75.1233 2325.22,75.1195 2325.22,75.1157 2325.23,75.1118 2325.24,75.108 2325.25,75.1042 2325.26,75.1003 2325.27,75.0965 2325.28,75.0927 2325.29,75.0888 2325.3,75.085 2325.31,75.0812 2325.32,75.0773 2325.33,75.0735 2325.34,75.0697 2325.34,75.0658 2325.35,75.062 2325.36,75.0582 2325.37,75.0543 2325.38,75.0505 2325.39,75.0467 2325.4,75.0428 2325.41,75.039 2325.42,75.0352 2325.43,75.0313 2325.44,75.0275 2325.45,75.0237 2325.45,75.0199 2325.46,75.016 2325.47,75.0122 2325.48,75.0084 2325.49,75.0045 2325.5,75.0007 2325.51,74.9969 2325.52,74.993 2325.53,74.9892 2325.54,74.9854 2325.55,74.9815 2325.56,74.9777 2325.56,74.9739 2325.57,74.97 2325.58,74.9662 2325.59,74.9624 2325.6,74.9586 2325.61,74.9547 2325.62,74.9509 2325.63,74.9471 2325.64,74.9432 2325.65,74.9394 2325.66,74.9356 2325.67,74.9317 2325.68,74.9279 2325.68,74.9241 2325.69,74.9203 2325.7,74.9164 2325.71,74.9126 2325.72,74.9088 2325.73,74.9049 2325.74,74.9011 2325.75,74.8973 2325.76,74.8934 2325.77,74.8896 2325.78,74.8858 2325.79,74.882 2325.79,74.8781 2325.8,74.8743 2325.81,74.8705 2325.82,74.8666 2325.83,74.8628 2325.84,74.859 2325.85,74.8552 2325.86,74.8513 2325.87,74.8475 2325.88,74.8437 2325.89,74.8398 2325.9,74.836 2325.9,74.8322 2325.91,74.8284 2325.92,74.8245 2325.93,74.8207 2325.94,74.8169 2325.95,74.813 2325.96,74.8092 2325.97,74.8054 2325.98,74.8016 2325.99,74.7977 2326,74.7939 2326.01,74.7901 2326.02,74.7862 2326.02,74.7824 2326.03,74.7786 2326.04,74.7748 2326.05,74.7709 2326.06,74.7671 2326.07,74.7633 2326.08,74.7594 2326.09,74.7556 2326.1,74.7518 2326.11,74.748 2326.12,74.7441 2326.13,74.7403 2326.13,74.7365 2326.14,74.7327 2326.15,74.7288 2326.16,74.725 2326.17,74.7212 2326.18,74.7173 2326.19,74.7135 2326.2,74.7097 2326.21,74.7059 2326.22,74.702 2326.23,74.6982 2326.24,74.6944 2326.24,74.6906 2326.25,74.6867 2326.26,74.6829 2326.27,74.6791 2326.28,74.6753 2326.29,74.6714 2326.3,74.6676 2326.31,74.6638 2326.32,74.66 2326.33,74.6561 2326.34,74.6523 2326.35,74.6485 2326.36,74.6447 2326.36,74.6408 2326.37,74.637 2326.38,74.6332 2326.39,74.6293 2326.4,74.6255 2326.41,74.6217 2326.42,74.6179 2326.43,74.614 2326.44,74.6102 2326.45,74.6064 2326.46,74.6026 2326.47,74.5987 2326.47,74.5949 2326.48,74.5911 2326.49,74.5873 2326.5,74.5834 2326.51,74.5796 2326.52,74.5758 2326.53,74.572 2326.54,74.5681 2326.55,74.5643 2326.56,74.5605 2326.57,74.5567 2326.58,74.5529 2326.58,74.549 2326.59,74.5452 2326.6,74.5414 2326.61,74.5376 2326.62,74.5337 2326.63,74.5299 2326.64,74.5261 2326.65,74.5223 2326.66,74.5184 2326.67,74.5146 2326.68,74.5108 2326.69,74.507 2326.7,74.5031 2326.7,74.4993 2326.71,74.4955 2326.72,74.4917 2326.73,74.4878 2326.74,74.484 2326.75,74.4802 2326.76,74.4764 2326.77,74.4726 2326.78,74.4687 2326.79,74.4649 2326.8,74.4611 2326.81,74.4573 2326.81,74.4534 2326.82,74.4496 2326.83,74.4458 2326.84,74.442 2326.85,74.4381 2326.86,74.4343 2326.87,74.4305 2326.88,74.4267 2326.89,74.4229 2326.9,74.419 2326.91,74.4152 2326.92,74.4114 2326.92,74.4076 2326.93,74.4037 2326.94,74.3999 2326.95,74.3961 2326.96,74.3923 2326.97,74.3885 2326.98,74.3846 2326.99,74.3808 2327,74.377 2327.01,74.3732 2327.02,74.3694 2327.03,74.3655 2327.04,74.3617 2327.04,74.3579 2327.05,74.3541 2327.06,74.3502 2327.07,74.3464 2327.08,74.3426 2327.09,74.3388 2327.1,74.335 2327.11,74.3311 2327.12,74.3273 2327.13,74.3235 2327.14,74.3197 2327.15,74.3159 2327.15,74.312 2327.16,74.3082 2327.17,74.3044 2327.18,74.3006 2327.19,74.2968 2327.2,74.2929 2327.21,74.2891 2327.22,74.2853 2327.23,74.2815 2327.24,74.2777 2327.25,74.2738 2327.26,74.27 2327.26,74.2662 2327.27,74.2624 2327.28,74.2586 2327.29,74.2547 2327.3,74.2509 2327.31,74.2471 2327.32,74.2433 2327.33,74.2395 2327.34,74.2356 2327.35,74.2318 2327.36,74.228 2327.37,74.2242 2327.38,74.2204 2327.38,74.2165 2327.39,74.2127 2327.4,74.2089 2327.41,74.2051 2327.42,74.2013 2327.43,74.1974 2327.44,74.1936 2327.45,74.1898 2327.46,74.186 2327.47,74.1822 2327.48,74.1784 2327.49,74.1745 2327.49,74.1707 2327.5,74.1669 2327.51,74.1631 2327.52,74.1593 2327.53,74.1554 2327.54,74.1516 2327.55,74.1478 2327.56,74.144 2327.57,74.1402 2327.58,74.1364 2327.59,74.1325 2327.6,74.1287 2327.6,74.1249 2327.61,74.1211 2327.62,74.1173 2327.63,74.1134 2327.64,74.1096 2327.65,74.1058 2327.66,74.102 2327.67,74.0982 2327.68,74.0944 2327.69,74.0905 2327.7,74.0867 2327.71,74.0829 2327.72,74.0791 2327.72,74.0753 2327.73,74.0715 2327.74,74.0676 2327.75,74.0638 2327.76,74.06 2327.77,74.0562 2327.78,74.0524 2327.79,74.0486 2327.8,74.0447 2327.81,74.0409 2327.82,74.0371 2327.83,74.0333 2327.83,74.0295 2327.84,74.0257 2327.85,74.0218 2327.86,74.018 2327.87,74.0142 2327.88,74.0104 2327.89,74.0066 2327.9,74.0028 2327.91,73.9989 2327.92,73.9951 2327.93,73.9913 2327.94,73.9875 2327.94,73.9837 2327.95,73.9799 2327.96,73.9761 2327.97,73.9722 2327.98,73.9684 2327.99,73.9646 2328,73.9608 2328.01,73.957 2328.02,73.9532 2328.03,73.9493 2328.04,73.9455 2328.05,73.9417 2328.06,73.9379 2328.06,73.9341 2328.07,73.9303 2328.08,73.9265 2328.09,73.9226 2328.1,73.9188 2328.11,73.915 2328.12,73.9112 2328.13,73.9074 2328.14,73.9036 2328.15,73.8998 2328.16,73.8959 2328.17,73.8921 2328.17,73.8883 2328.18,73.8845 2328.19,73.8807 2328.2,73.8769 2328.21,73.8731 2328.22,73.8692 2328.23,73.8654 2328.24,73.8616 2328.25,73.8578 2328.26,73.854 2328.27,73.8502 2328.28,73.8464 2328.28,73.8425 2328.29,73.8387 2328.3,73.8349 2328.31,73.8311 2328.32,73.8273 2328.33,73.8235 2328.34,73.8197 2328.35,73.8159 2328.36,73.812 2328.37,73.8082 2328.38,73.8044 2328.39,73.8006 2328.4,73.7968 2328.4,73.793 2328.41,73.7892 2328.42,73.7854 2328.43,73.7815 2328.44,73.7777 2328.45,73.7739 2328.46,73.7701 2328.47,73.7663 2328.48,73.7625 2328.49,73.7587 2328.5,73.7549 2328.51,73.751 2328.51,73.7472 2328.52,73.7434 2328.53,73.7396 2328.54,73.7358 2328.55,73.732 2328.56,73.7282 2328.57,73.7244 2328.58,73.7205 2328.59,73.7167 2328.6,73.7129 2328.61,73.7091 2328.62,73.7053 2328.62,73.7015 2328.63,73.6977 2328.64,73.6939 2328.65,73.6901 2328.66,73.6862 2328.67,73.6824 2328.68,73.6786 2328.69,73.6748 2328.7,73.671 2328.71,73.6672 2328.72,73.6634 2328.73,73.6596 2328.74,73.6558 2328.74,73.652 2328.75,73.6481 2328.76,73.6443 2328.77,73.6405 2328.78,73.6367 2328.79,73.6329 2328.8,73.6291 2328.81,73.6253 2328.82,73.6215 2328.83,73.6177 2328.84,73.6138 2328.85,73.61 2328.85,73.6062 2328.86,73.6024 2328.87,73.5986 2328.88,73.5948 2328.89,73.591 2328.9,73.5872 2328.91,73.5834 2328.92,73.5796 2328.93,73.5758 2328.94,73.5719 2328.95,73.5681 2328.96,73.5643 2328.96,73.5605 2328.97,73.5567 2328.98,73.5529 2328.99,73.5491 2329,73.5453 2329.01,73.5415 2329.02,73.5377 2329.03,73.5339 2329.04,73.53 2329.05,73.5262 2329.06,73.5224 2329.07,73.5186 2329.08,73.5148 2329.08,73.511 2329.09,73.5072 2329.1,73.5034 2329.11,73.4996 2329.12,73.4958 2329.13,73.492 2329.14,73.4882 2329.15,73.4843 2329.16,73.4805 2329.17,73.4767 2329.18,73.4729 2329.19,73.4691 2329.19,73.4653 2329.2,73.4615 2329.21,73.4577 2329.22,73.4539 2329.23,73.4501 2329.24,73.4463 2329.25,73.4425 2329.26,73.4387 2329.27,73.4348 2329.28,73.431 2329.29,73.4272 2329.3,73.4234 2329.3,73.4196 2329.31,73.4158 2329.32,73.412 2329.33,73.4082 2329.34,73.4044 2329.35,73.4006 2329.36,73.3968 2329.37,73.393 2329.38,73.3892 2329.39,73.3854 2329.4,73.3815 2329.41,73.3777 2329.42,73.3739 2329.42,73.3701 2329.43,73.3663 2329.44,73.3625 2329.45,73.3587 2329.46,73.3549 2329.47,73.3511 2329.48,73.3473 2329.49,73.3435 2329.5,73.3397 2329.51,73.3359 2329.52,73.3321 2329.53,73.3283 2329.53,73.3245 2329.54,73.3207 2329.55,73.3168 2329.56,73.313 2329.57,73.3092 2329.58,73.3054 2329.59,73.3016 2329.6,73.2978 2329.61,73.294 2329.62,73.2902 2329.63,73.2864 2329.64,73.2826 2329.64,73.2788 2329.65,73.275 2329.66,73.2712 2329.67,73.2674 2329.68,73.2636 2329.69,73.2598 2329.7,73.256 2329.71,73.2522 2329.72,73.2484 2329.73,73.2446 2329.74,73.2408 2329.75,73.2369 2329.76,73.2331 2329.76,73.2293 2329.77,73.2255 2329.78,73.2217 2329.79,73.2179 2329.8,73.2141 2329.81,73.2103 2329.82,73.2065 2329.83,73.2027 2329.84,73.1989 2329.85,73.1951 2329.86,73.1913 2329.87,73.1875 2329.87,73.1837 2329.88,73.1799 2329.89,73.1761 2329.9,73.1723 2329.91,73.1685 2329.92,73.1647 2329.93,73.1609 2329.94,73.1571 2329.95,73.1533 2329.96,73.1495 2329.97,73.1457 2329.98,73.1419 2329.98,73.1381 2329.99,73.1343 2330,73.1304 2330.01,73.1266 2330.02,73.1228 2330.03,73.119 2330.04,73.1152 2330.05,73.1114 2330.06,73.1076 2330.07,73.1038 2330.08,73.1 2330.09,73.0962 2330.1,73.0924 2330.1,73.0886 2330.11,73.0848 2330.12,73.081 2330.13,73.0772 2330.14,73.0734 2330.15,73.0696 2330.16,73.0658 2330.17,73.062 2330.18,73.0582 2330.19,73.0544 2330.2,73.0506 2330.21,73.0468 2330.21,73.043 2330.22,73.0392 2330.23,73.0354 2330.24,73.0316 2330.25,73.0278 2330.26,73.024 2330.27,73.0202 2330.28,73.0164 2330.29,73.0126 2330.3,73.0088 2330.31,73.005 2330.32,73.0012 2330.32,72.9974 2330.33,72.9936 2330.34,72.9898 2330.35,72.986 2330.36,72.9822 2330.37,72.9784 2330.38,72.9746 2330.39,72.9708 2330.4,72.967 2330.41,72.9632 2330.42,72.9594 2330.43,72.9556 2330.44,72.9518 2330.44,72.948 2330.45,72.9442 2330.46,72.9404 2330.47,72.9366 2330.48,72.9328 2330.49,72.929 2330.5,72.9252 2330.51,72.9214 2330.52,72.9176 2330.53,72.9138 2330.54,72.91 2330.55,72.9062 2330.55,72.9024 2330.56,72.8986 2330.57,72.8948 2330.58,72.891 2330.59,72.8872 2330.6,72.8834 2330.61,72.8796 2330.62,72.8758 2330.63,72.872 2330.64,72.8682 2330.65,72.8644 2330.66,72.8606 2330.66,72.8568 2330.67,72.853 2330.68,72.8492 2330.69,72.8454 2330.7,72.8416 2330.71,72.8378 2330.72,72.834 2330.73,72.8302 2330.74,72.8264 2330.75,72.8226 2330.76,72.8188 2330.77,72.815 2330.78,72.8112 2330.78,72.8074 2330.79,72.8036 2330.8,72.7998 2330.81,72.796 2330.82,72.7922 2330.83,72.7884 2330.84,72.7846 2330.85,72.7808 2330.86,72.777 2330.87,72.7732 2330.88,72.7695 2330.89,72.7657 2330.89,72.7619 2330.9,72.7581 2330.91,72.7543 2330.92,72.7505 2330.93,72.7467 2330.94,72.7429 2330.95,72.7391 2330.96,72.7353 2330.97,72.7315 2330.98,72.7277 2330.99,72.7239 2331,72.7201 2331,72.7163 2331.01,72.7125 2331.02,72.7087 2331.03,72.7049 2331.04,72.7011 2331.05,72.6973 2331.06,72.6935 2331.07,72.6897 2331.08,72.6859 2331.09,72.6821 2331.1,72.6783 2331.11,72.6745 2331.12,72.6707 2331.12,72.6669 2331.13,72.6631 2331.14,72.6594 2331.15,72.6556 2331.16,72.6518 2331.17,72.648 2331.18,72.6442 2331.19,72.6404 2331.2,72.6366 2331.21,72.6328 2331.22,72.629 2331.23,72.6252 2331.23,72.6214 2331.24,72.6176 2331.25,72.6138 2331.26,72.61 2331.27,72.6062 2331.28,72.6024 2331.29,72.5986 2331.3,72.5948 2331.31,72.591 2331.32,72.5872 2331.33,72.5835 2331.34,72.5797 2331.34,72.5759 2331.35,72.5721 2331.36,72.5683 2331.37,72.5645 2331.38,72.5607 2331.39,72.5569 2331.4,72.5531 2331.41,72.5493 2331.42,72.5455 2331.43,72.5417 2331.44,72.5379 2331.45,72.5341 2331.46,72.5303 2331.46,72.5265 2331.47,72.5227 2331.48,72.519 2331.49,72.5152 2331.5,72.5114 2331.51,72.5076 2331.52,72.5038 2331.53,72.5 2331.54,72.4962 2331.55,72.4924 2331.56,72.4886 2331.57,72.4848 2331.57,72.481 2331.58,72.4772 2331.59,72.4734 2331.6,72.4696 2331.61,72.4658 2331.62,72.4621 2331.63,72.4583 2331.64,72.4545 2331.65,72.4507 2331.66,72.4469 2331.67,72.4431 2331.68,72.4393 2331.68,72.4355 2331.69,72.4317 2331.7,72.4279 2331.71,72.4241 2331.72,72.4203 2331.73,72.4165 2331.74,72.4128 2331.75,72.409 2331.76,72.4052 2331.77,72.4014 2331.78,72.3976 2331.79,72.3938 2331.8,72.39 2331.8,72.3862 2331.81,72.3824 2331.82,72.3786 2331.83,72.3748 2331.84,72.371 2331.85,72.3673 2331.86,72.3635 2331.87,72.3597 2331.88,72.3559 2331.89,72.3521 2331.9,72.3483 2331.91,72.3445 2331.91,72.3407 2331.92,72.3369 2331.93,72.3331 2331.94,72.3293 2331.95,72.3256 2331.96,72.3218 2331.97,72.318 2331.98,72.3142 2331.99,72.3104 2332,72.3066 2332.01,72.3028 2332.02,72.299 2332.02,72.2952 2332.03,72.2914 2332.04,72.2876 2332.05,72.2839 2332.06,72.2801 2332.07,72.2763 2332.08,72.2725 2332.09,72.2687 2332.1,72.2649 2332.11,72.2611 2332.12,72.2573 2332.13,72.2535 2332.14,72.2498 2332.14,72.246 2332.15,72.2422 2332.16,72.2384 2332.17,72.2346 2332.18,72.2308 2332.19,72.227 2332.2,72.2232 2332.21,72.2194 2332.22,72.2156 2332.23,72.2119 2332.24,72.2081 2332.25,72.2043 2332.25,72.2005 2332.26,72.1967 2332.27,72.1929 2332.28,72.1891 2332.29,72.1853 2332.3,72.1815 2332.31,72.1778 2332.32,72.174 2332.33,72.1702 2332.34,72.1664 2332.35,72.1626 2332.36,72.1588 2332.36,72.155 2332.37,72.1512 2332.38,72.1475 2332.39,72.1437 2332.4,72.1399 2332.41,72.1361 2332.42,72.1323 2332.43,72.1285 2332.44,72.1247 2332.45,72.1209 2332.46,72.1171 2332.47,72.1134 2332.48,72.1096 2332.48,72.1058 2332.49,72.102 2332.5,72.0982 2332.51,72.0944 2332.52,72.0906 2332.53,72.0868 2332.54,72.0831 2332.55,72.0793 2332.56,72.0755 2332.57,72.0717 2332.58,72.0679 2332.59,72.0641 2332.59,72.0603 2332.6,72.0566 2332.61,72.0528 2332.62,72.049 2332.63,72.0452 2332.64,72.0414 2332.65,72.0376 2332.66,72.0338 2332.67,72.03 2332.68,72.0263 2332.69,72.0225 2332.7,72.0187 2332.7,72.0149 2332.71,72.0111 2332.72,72.0073 2332.73,72.0035 2332.74,71.9998 2332.75,71.996 2332.76,71.9922 2332.77,71.9884 2332.78,71.9846 2332.79,71.9808 2332.8,71.977 2332.81,71.9733 2332.82,71.9695 2332.82,71.9657 2332.83,71.9619 2332.84,71.9581 2332.85,71.9543 2332.86,71.9505 2332.87,71.9468 2332.88,71.943 2332.89,71.9392 2332.9,71.9354 2332.91,71.9316 2332.92,71.9278 2332.93,71.924 2332.93,71.9203 2332.94,71.9165 2332.95,71.9127 2332.96,71.9089 2332.97,71.9051 2332.98,71.9013 2332.99,71.8976 2333,71.8938 2333.01,71.89 2333.02,71.8862 2333.03,71.8824 2333.04,71.8786 2333.04,71.8749 2333.05,71.8711 2333.06,71.8673 2333.07,71.8635 2333.08,71.8597 2333.09,71.8559 2333.1,71.8521 2333.11,71.8484 2333.12,71.8446 2333.13,71.8408 2333.14,71.837 2333.15,71.8332 2333.16,71.8294 2333.16,71.8257 2333.17,71.8219 2333.18,71.8181 2333.19,71.8143 2333.2,71.8105 2333.21,71.8067 2333.22,71.803 2333.23,71.7992 2333.24,71.7954 2333.25,71.7916 2333.26,71.7878 2333.27,71.784 2333.27,71.7803 2333.28,71.7765 2333.29,71.7727 2333.3,71.7689 2333.31,71.7651 2333.32,71.7614 2333.33,71.7576 2333.34,71.7538 2333.35,71.75 2333.36,71.7462 2333.37,71.7424 2333.38,71.7387 2333.38,71.7349 2333.39,71.7311 2333.4,71.7273 2333.41,71.7235 2333.42,71.7197 2333.43,71.716 2333.44,71.7122 2333.45,71.7084 2333.46,71.7046 2333.47,71.7008 2333.48,71.6971 2333.49,71.6933 2333.5,71.6895 2333.5,71.6857 2333.51,71.6819 2333.52,71.6781 2333.53,71.6744 2333.54,71.6706 2333.55,71.6668 2333.56,71.663 2333.57,71.6592 2333.58,71.6555 2333.59,71.6517 2333.6,71.6479 2333.61,71.6441 2333.61,71.6403 2333.62,71.6366 2333.63,71.6328 2333.64,71.629 2333.65,71.6252 2333.66,71.6214 2333.67,71.6177 2333.68,71.6139 2333.69,71.6101 2333.7,71.6063 2333.71,71.6025 2333.72,71.5988 2333.72,71.595 2333.73,71.5912 2333.74,71.5874 2333.75,71.5836 2333.76,71.5799 2333.77,71.5761 2333.78,71.5723 2333.79,71.5685 2333.8,71.5647 2333.81,71.561 2333.82,71.5572 2333.83,71.5534 2333.84,71.5496 2333.84,71.5458 2333.85,71.5421 2333.86,71.5383 2333.87,71.5345 2333.88,71.5307 2333.89,71.5269 2333.9,71.5232 2333.91,71.5194 2333.92,71.5156 2333.93,71.5118 2333.94,71.508 2333.95,71.5043 2333.95,71.5005 2333.96,71.4967 2333.97,71.4929 2333.98,71.4892 2333.99,71.4854 2334,71.4816 2334.01,71.4778 2334.02,71.474 2334.03,71.4703 2334.04,71.4665 2334.05,71.4627 2334.06,71.4589 2334.06,71.4552 2334.07,71.4514 2334.08,71.4476 2334.09,71.4438 2334.1,71.44 2334.11,71.4363 2334.12,71.4325 2334.13,71.4287 2334.14,71.4249 2334.15,71.4211 2334.16,71.4174 2334.17,71.4136 2334.18,71.4098 2334.18,71.406 2334.19,71.4023 2334.2,71.3985 2334.21,71.3947 2334.22,71.3909 2334.23,71.3872 2334.24,71.3834 2334.25,71.3796 2334.26,71.3758 2334.27,71.372 2334.28,71.3683 2334.29,71.3645 2334.29,71.3607 2334.3,71.3569 2334.31,71.3532 2334.32,71.3494 2334.33,71.3456 2334.34,71.3418 2334.35,71.3381 2334.36,71.3343 2334.37,71.3305 2334.38,71.3267 2334.39,71.323 2334.4,71.3192 2334.4,71.3154 2334.41,71.3116 2334.42,71.3078 2334.43,71.3041 2334.44,71.3003 2334.45,71.2965 2334.46,71.2927 2334.47,71.289 2334.48,71.2852 2334.49,71.2814 2334.5,71.2776 2334.51,71.2739 2334.52,71.2701 2334.52,71.2663 2334.53,71.2625 2334.54,71.2588 2334.55,71.255 2334.56,71.2512 2334.57,71.2474 2334.58,71.2437 2334.59,71.2399 2334.6,71.2361 2334.61,71.2323 2334.62,71.2286 2334.63,71.2248 2334.63,71.221 2334.64,71.2172 2334.65,71.2135 2334.66,71.2097 2334.67,71.2059 2334.68,71.2021 2334.69,71.1984 2334.7,71.1946 2334.71,71.1908 2334.72,71.187 2334.73,71.1833 2334.74,71.1795 2334.74,71.1757 2334.75,71.1719 2334.76,71.1682 2334.77,71.1644 2334.78,71.1606 2334.79,71.1569 2334.8,71.1531 2334.81,71.1493 2334.82,71.1455 2334.83,71.1418 2334.84,71.138 2334.85,71.1342 2334.86,71.1304 2334.86,71.1267 2334.87,71.1229 2334.88,71.1191 2334.89,71.1153 2334.9,71.1116 2334.91,71.1078 2334.92,71.104 2334.93,71.1003 2334.94,71.0965 2334.95,71.0927 2334.96,71.0889 2334.97,71.0852 2334.97,71.0814 2334.98,71.0776 2334.99,71.0738 2335,71.0701 2335.01,71.0663 2335.02,71.0625 2335.03,71.0588 2335.04,71.055 2335.05,71.0512 2335.06,71.0474 2335.07,71.0437 2335.08,71.0399 2335.08,71.0361 2335.09,71.0323 2335.1,71.0286 2335.11,71.0248 2335.12,71.021 2335.13,71.0173 2335.14,71.0135 2335.15,71.0097 2335.16,71.0059 2335.17,71.0022 2335.18,70.9984 2335.19,70.9946 2335.2,70.9909 2335.2,70.9871 2335.21,70.9833 2335.22,70.9795 2335.23,70.9758 2335.24,70.972 2335.25,70.9682 2335.26,70.9645 2335.27,70.9607 2335.28,70.9569 2335.29,70.9532 2335.3,70.9494 2335.31,70.9456 2335.31,70.9418 2335.32,70.9381 2335.33,70.9343 2335.34,70.9305 2335.35,70.9268 2335.36,70.923 2335.37,70.9192 2335.38,70.9154 2335.39,70.9117 2335.4,70.9079 2335.41,70.9041 2335.42,70.9004 2335.42,70.8966 2335.43,70.8928 2335.44,70.8891 2335.45,70.8853 2335.46,70.8815 2335.47,70.8777 2335.48,70.874 2335.49,70.8702 2335.5,70.8664 2335.51,70.8627 2335.52,70.8589 2335.53,70.8551 2335.54,70.8514 2335.54,70.8476 2335.55,70.8438 2335.56,70.84 2335.57,70.8363 2335.58,70.8325 2335.59,70.8287 2335.6,70.825 2335.61,70.8212 2335.62,70.8174 2335.63,70.8137 2335.64,70.8099 2335.65,70.8061 2335.65,70.8024 2335.66,70.7986 2335.67,70.7948 2335.68,70.7911 2335.69,70.7873 2335.7,70.7835 2335.71,70.7797 2335.72,70.776 2335.73,70.7722 2335.74,70.7684 2335.75,70.7647 2335.76,70.7609 2335.76,70.7571 2335.77,70.7534 2335.78,70.7496 2335.79,70.7458 2335.8,70.7421 2335.81,70.7383 2335.82,70.7345 2335.83,70.7308 2335.84,70.727 2335.85,70.7232 2335.86,70.7195 2335.87,70.7157 2335.88,70.7119 2335.88,70.7082 2335.89,70.7044 2335.9,70.7006 2335.91,70.6969 2335.92,70.6931 2335.93,70.6893 2335.94,70.6856 2335.95,70.6818 2335.96,70.678 2335.97,70.6743 2335.98,70.6705 2335.99,70.6667 2335.99,70.663 2336,70.6592 2336.01,70.6554 2336.02,70.6517 2336.03,70.6479 2336.04,70.6441 2336.05,70.6404 2336.06,70.6366 2336.07,70.6328 2336.08,70.6291 2336.09,70.6253 2336.1,70.6215 2336.1,70.6178 2336.11,70.614 2336.12,70.6102 2336.13,70.6065 2336.14,70.6027 2336.15,70.5989 2336.16,70.5952 2336.17,70.5914 2336.18,70.5876 2336.19,70.5839 2336.2,70.5801 2336.21,70.5763 2336.22,70.5726 2336.22,70.5688 2336.23,70.565 2336.24,70.5613 2336.25,70.5575 2336.26,70.5537 2336.27,70.55 2336.28,70.5462 2336.29,70.5424 2336.3,70.5387 2336.31,70.5349 2336.32,70.5312 2336.33,70.5274 2336.33,70.5236 2336.34,70.5199 2336.35,70.5161 2336.36,70.5123 2336.37,70.5086 2336.38,70.5048 2336.39,70.501 2336.4,70.4973 2336.41,70.4935 2336.42,70.4897 2336.43,70.486 2336.44,70.4822 2336.44,70.4785 2336.45,70.4747 2336.46,70.4709 2336.47,70.4672 2336.48,70.4634 2336.49,70.4596 2336.5,70.4559 2336.51,70.4521 2336.52,70.4483 2336.53,70.4446 2336.54,70.4408 2336.55,70.437 2336.56,70.4333 2336.56,70.4295 2336.57,70.4258 2336.58,70.422 2336.59,70.4182 2336.6,70.4145 2336.61,70.4107 2336.62,70.4069 2336.63,70.4032 2336.64,70.3994 2336.65,70.3957 2336.66,70.3919 2336.67,70.3881 2336.67,70.3844 2336.68,70.3806 2336.69,70.3768 2336.7,70.3731 2336.71,70.3693 2336.72,70.3656 2336.73,70.3618 2336.74,70.358 2336.75,70.3543 2336.76,70.3505 2336.77,70.3467 2336.78,70.343 2336.78,70.3392 2336.79,70.3355 2336.8,70.3317 2336.81,70.3279 2336.82,70.3242 2336.83,70.3204 2336.84,70.3166 2336.85,70.3129 2336.86,70.3091 2336.87,70.3054 2336.88,70.3016 2336.89,70.2978 2336.9,70.2941 2336.9,70.2903 2336.91,70.2866 2336.92,70.2828 2336.93,70.279 2336.94,70.2753 2336.95,70.2715 2336.96,70.2677 2336.97,70.264 2336.98,70.2602 2336.99,70.2565 2337,70.2527 2337.01,70.2489 2337.01,70.2452 2337.02,70.2414 2337.03,70.2377 2337.04,70.2339 2337.05,70.2301 2337.06,70.2264 2337.07,70.2226 2337.08,70.2189 2337.09,70.2151 2337.1,70.2113 2337.11,70.2076 2337.12,70.2038 2337.12,70.2001 2337.13,70.1963 2337.14,70.1925 2337.15,70.1888 2337.16,70.185 2337.17,70.1813 2337.18,70.1775 2337.19,70.1737 2337.2,70.17 2337.21,70.1662 2337.22,70.1625 2337.23,70.1587 2337.24,70.1549 2337.24,70.1512 2337.25,70.1474 2337.26,70.1437 2337.27,70.1399 2337.28,70.1361 2337.29,70.1324 2337.3,70.1286 2337.31,70.1249 2337.32,70.1211 2337.33,70.1173 2337.34,70.1136 2337.35,70.1098 2337.35,70.1061 2337.36,70.1023 2337.37,70.0985 2337.38,70.0948 2337.39,70.091 2337.4,70.0873 2337.41,70.0835 2337.42,70.0798 2337.43,70.076 2337.44,70.0722 2337.45,70.0685 2337.46,70.0647 2337.46,70.061 2337.47,70.0572 2337.48,70.0534 2337.49,70.0497 2337.5,70.0459 2337.51,70.0422 2337.52,70.0384 2337.53,70.0347 2337.54,70.0309 2337.55,70.0271 2337.56,70.0234 2337.57,70.0196 2337.58,70.0159 2337.58,70.0121 2337.59,70.0084 2337.6,70.0046 2337.61,70.0008 2337.62,69.9971 2337.63,69.9933 2337.64,69.9896 2337.65,69.9858 2337.66,69.9821 2337.67,69.9783 2337.68,69.9745 2337.69,69.9708 2337.69,69.967 2337.7,69.9633 2337.71,69.9595 2337.72,69.9558 2337.73,69.952 2337.74,69.9482 2337.75,69.9445 2337.76,69.9407 2337.77,69.937 2337.78,69.9332 2337.79,69.9295 2337.8,69.9257 2337.8,69.9219 2337.81,69.9182 2337.82,69.9144 2337.83,69.9107 2337.84,69.9069 2337.85,69.9032 2337.86,69.8994 2337.87,69.8957 2337.88,69.8919 2337.89,69.8881 2337.9,69.8844 2337.91,69.8806 2337.92,69.8769 2337.92,69.8731 2337.93,69.8694 2337.94,69.8656 2337.95,69.8619 2337.96,69.8581 2337.97,69.8543 2337.98,69.8506 2337.99,69.8468 2338,69.8431 2338.01,69.8393 2338.02,69.8356 2338.03,69.8318 2338.03,69.8281 2338.04,69.8243 2338.05,69.8205 2338.06,69.8168 2338.07,69.813 2338.08,69.8093 2338.09,69.8055 2338.1,69.8018 2338.11,69.798 2338.12,69.7943 2338.13,69.7905 2338.14,69.7868 2338.14,69.783 2338.15,69.7792 2338.16,69.7755 2338.17,69.7717 2338.18,69.768 2338.19,69.7642 2338.2,69.7605 2338.21,69.7567 2338.22,69.753 2338.23,69.7492 2338.24,69.7455 2338.25,69.7417 2338.26,69.738 2338.26,69.7342 2338.27,69.7304 2338.28,69.7267 2338.29,69.7229 2338.3,69.7192 2338.31,69.7154 2338.32,69.7117 2338.33,69.7079 2338.34,69.7042 2338.35,69.7004 2338.36,69.6967 2338.37,69.6929 2338.37,69.6892 2338.38,69.6854 2338.39,69.6817 2338.4,69.6779 2338.41,69.6741 2338.42,69.6704 2338.43,69.6666 2338.44,69.6629 2338.45,69.6591 2338.46,69.6554 2338.47,69.6516 2338.48,69.6479 2338.48,69.6441 2338.49,69.6404 2338.5,69.6366 2338.51,69.6329 2338.52,69.6291 2338.53,69.6254 2338.54,69.6216 2338.55,69.6179 2338.56,69.6141 2338.57,69.6104 2338.58,69.6066 2338.59,69.6029 2338.6,69.5991 2338.6,69.5953 2338.61,69.5916 2338.62,69.5878 2338.63,69.5841 2338.64,69.5803 2338.65,69.5766 2338.66,69.5728 2338.67,69.5691 2338.68,69.5653 2338.69,69.5616 2338.7,69.5578 2338.71,69.5541 2338.71,69.5503 2338.72,69.5466 2338.73,69.5428 2338.74,69.5391 2338.75,69.5353 2338.76,69.5316 2338.77,69.5278 2338.78,69.5241 2338.79,69.5203 2338.8,69.5166 2338.81,69.5128 2338.82,69.5091 2338.82,69.5053 2338.83,69.5016 2338.84,69.4978 2338.85,69.4941 2338.86,69.4903 2338.87,69.4866 2338.88,69.4828 2338.89,69.4791 2338.9,69.4753 2338.91,69.4716 2338.92,69.4678 2338.93,69.4641 2338.94,69.4603 2338.94,69.4566 2338.95,69.4528 2338.96,69.4491 2338.97,69.4453 2338.98,69.4416 2338.99,69.4378 2339,69.4341 2339.01,69.4303 2339.02,69.4266 2339.03,69.4228 2339.04,69.4191 2339.05,69.4153 2339.05,69.4116 2339.06,69.4078 2339.07,69.4041 2339.08,69.4003 2339.09,69.3966 2339.1,69.3928 2339.11,69.3891 2339.12,69.3853 2339.13,69.3816 2339.14,69.3778 2339.15,69.3741 2339.16,69.3703 2339.16,69.3666 2339.17,69.3628 2339.18,69.3591 2339.19,69.3553 2339.2,69.3516 2339.21,69.3478 2339.22,69.3441 2339.23,69.3404 2339.24,69.3366 2339.25,69.3329 2339.26,69.3291 2339.27,69.3254 2339.28,69.3216 2339.28,69.3179 2339.29,69.3141 2339.3,69.3104 2339.31,69.3066 2339.32,69.3029 2339.33,69.2991 2339.34,69.2954 2339.35,69.2916 2339.36,69.2879 2339.37,69.2841 2339.38,69.2804 2339.39,69.2766 2339.39,69.2729 2339.4,69.2691 2339.41,69.2654 2339.42,69.2617 2339.43,69.2579 2339.44,69.2542 2339.45,69.2504 2339.46,69.2467 2339.47,69.2429 2339.48,69.2392 2339.49,69.2354 2339.5,69.2317 2339.5,69.2279 2339.51,69.2242 2339.52,69.2204 2339.53,69.2167 2339.54,69.2129 2339.55,69.2092 2339.56,69.2054 2339.57,69.2017 2339.58,69.198 2339.59,69.1942 2339.6,69.1905 2339.61,69.1867 2339.62,69.183 2339.62,69.1792 2339.63,69.1755 2339.64,69.1717 2339.65,69.168 2339.66,69.1642 2339.67,69.1605 2339.68,69.1568 2339.69,69.153 2339.7,69.1493 2339.71,69.1455 2339.72,69.1418 2339.73,69.138 2339.73,69.1343 2339.74,69.1305 2339.75,69.1268 2339.76,69.123 2339.77,69.1193 2339.78,69.1156 2339.79,69.1118 2339.8,69.1081 2339.81,69.1043 2339.82,69.1006 2339.83,69.0968 2339.84,69.0931 2339.84,69.0893 2339.85,69.0856 2339.86,69.0818 2339.87,69.0781 2339.88,69.0744 2339.89,69.0706 2339.9,69.0669 2339.91,69.0631 2339.92,69.0594 2339.93,69.0556 2339.94,69.0519 2339.95,69.0481 2339.96,69.0444 2339.96,69.0407 2339.97,69.0369 2339.98,69.0332 2339.99,69.0294 2340,69.0257 2340.01,69.0219 2340.02,69.0182 2340.03,69.0145 2340.04,69.0107 2340.05,69.007 2340.06,69.0032 2340.07,68.9995 2340.07,68.9957 2340.08,68.992 2340.09,68.9882 2340.1,68.9845 2340.11,68.9808 2340.12,68.977 2340.13,68.9733 2340.14,68.9695 2340.15,68.9658 2340.16,68.962 2340.17,68.9583 2340.18,68.9546 2340.18,68.9508 2340.19,68.9471 2340.2,68.9433 2340.21,68.9396 2340.22,68.9358 2340.23,68.9321 2340.24,68.9284 2340.25,68.9246 2340.26,68.9209 2340.27,68.9171 2340.28,68.9134 2340.29,68.9097 2340.3,68.9059 2340.3,68.9022 2340.31,68.8984 2340.32,68.8947 2340.33,68.8909 2340.34,68.8872 2340.35,68.8835 2340.36,68.8797 2340.37,68.876 2340.38,68.8722 2340.39,68.8685 2340.4,68.8647 2340.41,68.861 2340.41,68.8573 2340.42,68.8535 2340.43,68.8498 2340.44,68.846 2340.45,68.8423 2340.46,68.8386 2340.47,68.8348 2340.48,68.8311 2340.49,68.8273 2340.5,68.8236 2340.51,68.8199 2340.52,68.8161 2340.52,68.8124 2340.53,68.8086 2340.54,68.8049 2340.55,68.8011 2340.56,68.7974 2340.57,68.7937 2340.58,68.7899 2340.59,68.7862 2340.6,68.7824 2340.61,68.7787 2340.62,68.775 2340.63,68.7712 2340.64,68.7675 2340.64,68.7637 2340.65,68.76 2340.66,68.7563 2340.67,68.7525 2340.68,68.7488 2340.69,68.745 2340.7,68.7413 2340.71,68.7376 2340.72,68.7338 2340.73,68.7301 2340.74,68.7263 2340.75,68.7226 2340.75,68.7189 2340.76,68.7151 2340.77,68.7114 2340.78,68.7076 2340.79,68.7039 2340.8,68.7002 2340.81,68.6964 2340.82,68.6927 2340.83,68.6889 2340.84,68.6852 2340.85,68.6815 2340.86,68.6777 2340.86,68.674 2340.87,68.6703 2340.88,68.6665 2340.89,68.6628 2340.9,68.659 2340.91,68.6553 2340.92,68.6516 2340.93,68.6478 2340.94,68.6441 2340.95,68.6403 2340.96,68.6366 2340.97,68.6329 2340.98,68.6291 2340.98,68.6254 2340.99,68.6216 2341,68.6179 2341.01,68.6142 2341.02,68.6104 2341.03,68.6067 2341.04,68.603 2341.05,68.5992 2341.06,68.5955 2341.07,68.5917 2341.08,68.588 2341.09,68.5843 2341.09,68.5805 2341.1,68.5768 2341.11,68.5731 2341.12,68.5693 2341.13,68.5656 2341.14,68.5618 2341.15,68.5581 2341.16,68.5544 2341.17,68.5506 2341.18,68.5469 2341.19,68.5432 2341.2,68.5394 2341.2,68.5357 2341.21,68.5319 2341.22,68.5282 2341.23,68.5245 2341.24,68.5207 2341.25,68.517 2341.26,68.5133 2341.27,68.5095 2341.28,68.5058 2341.29,68.502 2341.3,68.4983 2341.31,68.4946 2341.32,68.4908 2341.32,68.4871 2341.33,68.4834 2341.34,68.4796 2341.35,68.4759 2341.36,68.4722 2341.37,68.4684 2341.38,68.4647 2341.39,68.4609 2341.4,68.4572 2341.41,68.4535 2341.42,68.4497 2341.43,68.446 2341.43,68.4423 2341.44,68.4385 2341.45,68.4348 2341.46,68.4311 2341.47,68.4273 2341.48,68.4236 2341.49,68.4199 2341.5,68.4161 2341.51,68.4124 2341.52,68.4086 2341.53,68.4049 2341.54,68.4012 2341.54,68.3974 2341.55,68.3937 2341.56,68.39 2341.57,68.3862 2341.58,68.3825 2341.59,68.3788 2341.6,68.375 2341.61,68.3713 2341.62,68.3676 2341.63,68.3638 2341.64,68.3601 2341.65,68.3564 2341.66,68.3526 2341.66,68.3489 2341.67,68.3451 2341.68,68.3414 2341.69,68.3377 2341.7,68.3339 2341.71,68.3302 2341.72,68.3265 2341.73,68.3227 2341.74,68.319 2341.75,68.3153 2341.76,68.3115 2341.77,68.3078 2341.77,68.3041 2341.78,68.3003 2341.79,68.2966 2341.8,68.2929 2341.81,68.2891 2341.82,68.2854 2341.83,68.2817 2341.84,68.2779 2341.85,68.2742 2341.86,68.2705 2341.87,68.2667 2341.88,68.263 2341.88,68.2593 2341.89,68.2555 2341.9,68.2518 2341.91,68.2481 2341.92,68.2443 2341.93,68.2406 2341.94,68.2369 2341.95,68.2331 2341.96,68.2294 2341.97,68.2257 2341.98,68.2219 2341.99,68.2182 2342,68.2145 2342,68.2107 2342.01,68.207 2342.02,68.2033 2342.03,68.1995 2342.04,68.1958 2342.05,68.1921 2342.06,68.1883 2342.07,68.1846 2342.08,68.1809 2342.09,68.1771 2342.1,68.1734 2342.11,68.1697 2342.11,68.1659 2342.12,68.1622 2342.13,68.1585 2342.14,68.1548 2342.15,68.151 2342.16,68.1473 2342.17,68.1436 2342.18,68.1398 2342.19,68.1361 2342.2,68.1324 2342.21,68.1286 2342.22,68.1249 2342.22,68.1212 2342.23,68.1174 2342.24,68.1137 2342.25,68.11 2342.26,68.1062 2342.27,68.1025 2342.28,68.0988 2342.29,68.095 2342.3,68.0913 2342.31,68.0876 2342.32,68.0839 2342.33,68.0801 2342.34,68.0764 2342.34,68.0727 2342.35,68.0689 2342.36,68.0652 2342.37,68.0615 2342.38,68.0577 2342.39,68.054 2342.4,68.0503 2342.41,68.0465 2342.42,68.0428 2342.43,68.0391 2342.44,68.0354 2342.45,68.0316 2342.45,68.0279 2342.46,68.0242 2342.47,68.0204 2342.48,68.0167 2342.49,68.013 2342.5,68.0092 2342.51,68.0055 2342.52,68.0018 2342.53,67.9981 2342.54,67.9943 2342.55,67.9906 2342.56,67.9869 2342.56,67.9831 2342.57,67.9794 2342.58,67.9757 2342.59,67.9719 2342.6,67.9682 2342.61,67.9645 2342.62,67.9608 2342.63,67.957 2342.64,67.9533 2342.65,67.9496 2342.66,67.9458 2342.67,67.9421 2342.68,67.9384 2342.68,67.9346 2342.69,67.9309 2342.7,67.9272 2342.71,67.9235 2342.72,67.9197 2342.73,67.916 2342.74,67.9123 2342.75,67.9085 2342.76,67.9048 2342.77,67.9011 2342.78,67.8974 2342.79,67.8936 2342.79,67.8899 2342.8,67.8862 2342.81,67.8824 2342.82,67.8787 2342.83,67.875 2342.84,67.8713 2342.85,67.8675 2342.86,67.8638 2342.87,67.8601 2342.88,67.8564 2342.89,67.8526 2342.9,67.8489 2342.9,67.8452 2342.91,67.8414 2342.92,67.8377 2342.93,67.834 2342.94,67.8303 2342.95,67.8265 2342.96,67.8228 2342.97,67.8191 2342.98,67.8153 2342.99,67.8116 2343,67.8079 2343.01,67.8042 2343.02,67.8004 2343.02,67.7967 2343.03,67.793 2343.04,67.7893 2343.05,67.7855 2343.06,67.7818 2343.07,67.7781 2343.08,67.7743 2343.09,67.7706 2343.1,67.7669 2343.11,67.7632 2343.12,67.7594 2343.13,67.7557 2343.13,67.752 2343.14,67.7483 2343.15,67.7445 2343.16,67.7408 2343.17,67.7371 2343.18,67.7334 2343.19,67.7296 2343.2,67.7259 2343.21,67.7222 2343.22,67.7184 2343.23,67.7147 2343.24,67.711 2343.24,67.7073 2343.25,67.7035 2343.26,67.6998 2343.27,67.6961 2343.28,67.6924 2343.29,67.6886 2343.3,67.6849 2343.31,67.6812 2343.32,67.6775 2343.33,67.6737 2343.34,67.67 2343.35,67.6663 2343.36,67.6626 2343.36,67.6588 2343.37,67.6551 2343.38,67.6514 2343.39,67.6477 2343.4,67.6439 2343.41,67.6402 2343.42,67.6365 2343.43,67.6328 2343.44,67.629 2343.45,67.6253 2343.46,67.6216 2343.47,67.6179 2343.47,67.6141 2343.48,67.6104 2343.49,67.6067 2343.5,67.603 2343.51,67.5992 2343.52,67.5955 2343.53,67.5918 2343.54,67.5881 2343.55,67.5843 2343.56,67.5806 2343.57,67.5769 2343.58,67.5732 2343.58,67.5694 2343.59,67.5657 2343.6,67.562 2343.61,67.5583 2343.62,67.5545 2343.63,67.5508 2343.64,67.5471 2343.65,67.5434 2343.66,67.5397 2343.67,67.5359 2343.68,67.5322 2343.69,67.5285 2343.7,67.5248 2343.7,67.521 2343.71,67.5173 2343.72,67.5136 2343.73,67.5099 2343.74,67.5061 2343.75,67.5024 2343.76,67.4987 2343.77,67.495 2343.78,67.4912 2343.79,67.4875 2343.8,67.4838 2343.81,67.4801 2343.81,67.4764 2343.82,67.4726 2343.83,67.4689 2343.84,67.4652 2343.85,67.4615 2343.86,67.4577 2343.87,67.454 2343.88,67.4503 2343.89,67.4466 2343.9,67.4428 2343.91,67.4391 2343.92,67.4354 2343.92,67.4317 2343.93,67.428 2343.94,67.4242 2343.95,67.4205 2343.96,67.4168 2343.97,67.4131 2343.98,67.4093 2343.99,67.4056 2344,67.4019 2344.01,67.3982 2344.02,67.3945 2344.03,67.3907 2344.04,67.387 2344.04,67.3833 2344.05,67.3796 2344.06,67.3759 2344.07,67.3721 2344.08,67.3684 2344.09,67.3647 2344.1,67.361 2344.11,67.3572 2344.12,67.3535 2344.13,67.3498 2344.14,67.3461 2344.15,67.3424 2344.15,67.3386 2344.16,67.3349 2344.17,67.3312 2344.18,67.3275 2344.19,67.3238 2344.2,67.32 2344.21,67.3163 2344.22,67.3126 2344.23,67.3089 2344.24,67.3052 2344.25,67.3014 2344.26,67.2977 2344.27,67.294 2344.27,67.2903 2344.28,67.2865 2344.29,67.2828 2344.3,67.2791 2344.31,67.2754 2344.32,67.2717 2344.33,67.2679 2344.34,67.2642 2344.35,67.2605 2344.36,67.2568 2344.37,67.2531 2344.38,67.2493 2344.38,67.2456 2344.39,67.2419 2344.4,67.2382 2344.41,67.2345 2344.42,67.2307 2344.43,67.227 2344.44,67.2233 2344.45,67.2196 2344.46,67.2159 2344.47,67.2121 2344.48,67.2084 2344.49,67.2047 2344.49,67.201 2344.5,67.1973 2344.51,67.1936 2344.52,67.1898 2344.53,67.1861 2344.54,67.1824 2344.55,67.1787 2344.56,67.175 2344.57,67.1712 2344.58,67.1675 2344.59,67.1638 2344.6,67.1601 2344.61,67.1564 2344.61,67.1526 2344.62,67.1489 2344.63,67.1452 2344.64,67.1415 2344.65,67.1378 2344.66,67.1341 2344.67,67.1303 2344.68,67.1266 2344.69,67.1229 2344.7,67.1192 2344.71,67.1155 2344.72,67.1117 2344.72,67.108 2344.73,67.1043 2344.74,67.1006 2344.75,67.0969 2344.76,67.0932 2344.77,67.0894 2344.78,67.0857 2344.79,67.082 2344.8,67.0783 2344.81,67.0746 2344.82,67.0708 2344.83,67.0671 2344.83,67.0634 2344.84,67.0597 2344.85,67.056 2344.86,67.0523 2344.87,67.0485 2344.88,67.0448 2344.89,67.0411 2344.9,67.0374 2344.91,67.0337 2344.92,67.03 2344.93,67.0262 2344.94,67.0225 2344.95,67.0188 2344.95,67.0151 2344.96,67.0114 2344.97,67.0077 2344.98,67.0039 2344.99,67.0002 2345,66.9965 2345.01,66.9928 2345.02,66.9891 2345.03,66.9854 2345.04,66.9816 2345.05,66.9779 2345.06,66.9742 2345.06,66.9705 2345.07,66.9668 2345.08,66.9631 2345.09,66.9593 2345.1,66.9556 2345.11,66.9519 2345.12,66.9482 2345.13,66.9445 2345.14,66.9408 2345.15,66.937 2345.16,66.9333 2345.17,66.9296 2345.17,66.9259 2345.18,66.9222 2345.19,66.9185 2345.2,66.9148 2345.21,66.911 2345.22,66.9073 2345.23,66.9036 2345.24,66.8999 2345.25,66.8962 2345.26,66.8925 2345.27,66.8887 2345.28,66.885 2345.29,66.8813 2345.29,66.8776 2345.3,66.8739 2345.31,66.8702 2345.32,66.8665 2345.33,66.8627 2345.34,66.859 2345.35,66.8553 2345.36,66.8516 2345.37,66.8479 2345.38,66.8442 2345.39,66.8405 2345.4,66.8367 2345.4,66.833 2345.41,66.8293 2345.42,66.8256 2345.43,66.8219 2345.44,66.8182 2345.45,66.8145 2345.46,66.8107 2345.47,66.807 2345.48,66.8033 2345.49,66.7996 2345.5,66.7959 2345.51,66.7922 2345.51,66.7885 2345.52,66.7847 2345.53,66.781 2345.54,66.7773 2345.55,66.7736 2345.56,66.7699 2345.57,66.7662 2345.58,66.7625 2345.59,66.7587 2345.6,66.755 2345.61,66.7513 2345.62,66.7476 2345.63,66.7439 2345.63,66.7402 2345.64,66.7365 2345.65,66.7328 2345.66,66.729 2345.67,66.7253 2345.68,66.7216 2345.69,66.7179 2345.7,66.7142 2345.71,66.7105 2345.72,66.7068 2345.73,66.703 2345.74,66.6993 2345.74,66.6956 2345.75,66.6919 2345.76,66.6882 2345.77,66.6845 2345.78,66.6808 2345.79,66.6771 2345.8,66.6733 2345.81,66.6696 2345.82,66.6659 2345.83,66.6622 2345.84,66.6585 2345.85,66.6548 2345.85,66.6511 2345.86,66.6474 2345.87,66.6437 2345.88,66.6399 2345.89,66.6362 2345.9,66.6325 2345.91,66.6288 2345.92,66.6251 2345.93,66.6214 2345.94,66.6177 2345.95,66.614 2345.96,66.6102 2345.97,66.6065 2345.97,66.6028 2345.98,66.5991 2345.99,66.5954 2346,66.5917 2346.01,66.588 2346.02,66.5843 2346.03,66.5806 2346.04,66.5768 2346.05,66.5731 2346.06,66.5694 2346.07,66.5657 2346.08,66.562 2346.08,66.5583 2346.09,66.5546 2346.1,66.5509 2346.11,66.5472 2346.12,66.5434 2346.13,66.5397 2346.14,66.536 2346.15,66.5323 2346.16,66.5286 2346.17,66.5249 2346.18,66.5212 2346.19,66.5175 2346.19,66.5138 2346.2,66.5101 2346.21,66.5063 2346.22,66.5026 2346.23,66.4989 2346.24,66.4952 2346.25,66.4915 2346.26,66.4878 2346.27,66.4841 2346.28,66.4804 2346.29,66.4767 2346.3,66.473 2346.31,66.4692 2346.31,66.4655 2346.32,66.4618 2346.33,66.4581 2346.34,66.4544 2346.35,66.4507 2346.36,66.447 2346.37,66.4433 2346.38,66.4396 2346.39,66.4359 2346.4,66.4321 2346.41,66.4284 2346.42,66.4247 2346.42,66.421 2346.43,66.4173 2346.44,66.4136 2346.45,66.4099 2346.46,66.4062 2346.47,66.4025 2346.48,66.3988 2346.49,66.3951 2346.5,66.3914 2346.51,66.3876 2346.52,66.3839 2346.53,66.3802 2346.53,66.3765 2346.54,66.3728 2346.55,66.3691 2346.56,66.3654 2346.57,66.3617 2346.58,66.358 2346.59,66.3543 2346.6,66.3506 2346.61,66.3468 2346.62,66.3431 2346.63,66.3394 2346.64,66.3357 2346.65,66.332 2346.65,66.3283 2346.66,66.3246 2346.67,66.3209 2346.68,66.3172 2346.69,66.3135 2346.7,66.3098 2346.71,66.3061 2346.72,66.3024 2346.73,66.2986 2346.74,66.2949 2346.75,66.2912 2346.76,66.2875 2346.76,66.2838 2346.77,66.2801 2346.78,66.2764 2346.79,66.2727 2346.8,66.269 2346.81,66.2653 2346.82,66.2616 2346.83,66.2579 2346.84,66.2542 2346.85,66.2505 2346.86,66.2467 2346.87,66.243 2346.87,66.2393 2346.88,66.2356 2346.89,66.2319 2346.9,66.2282 2346.91,66.2245 2346.92,66.2208 2346.93,66.2171 2346.94,66.2134 2346.95,66.2097 2346.96,66.206 2346.97,66.2023 2346.98,66.1986 2346.99,66.1949 2346.99,66.1912 2347,66.1874 2347.01,66.1837 2347.02,66.18 2347.03,66.1763 2347.04,66.1726 2347.05,66.1689 2347.06,66.1652 2347.07,66.1615 2347.08,66.1578 2347.09,66.1541 2347.1,66.1504 2347.1,66.1467 2347.11,66.143 2347.12,66.1393 2347.13,66.1356 2347.14,66.1319 2347.15,66.1282 2347.16,66.1245 2347.17,66.1207 2347.18,66.117 2347.19,66.1133 2347.2,66.1096 2347.21,66.1059 2347.21,66.1022 2347.22,66.0985 2347.23,66.0948 2347.24,66.0911 2347.25,66.0874 2347.26,66.0837 2347.27,66.08 2347.28,66.0763 2347.29,66.0726 2347.3,66.0689 2347.31,66.0652 2347.32,66.0615 2347.33,66.0578 2347.33,66.0541 2347.34,66.0504 2347.35,66.0467 2347.36,66.0429 2347.37,66.0392 2347.38,66.0355 2347.39,66.0318 2347.4,66.0281 2347.41,66.0244 2347.42,66.0207 2347.43,66.017 2347.44,66.0133 2347.44,66.0096 2347.45,66.0059 2347.46,66.0022 2347.47,65.9985 2347.48,65.9948 2347.49,65.9911 2347.5,65.9874 2347.51,65.9837 2347.52,65.98 2347.53,65.9763 2347.54,65.9726 2347.55,65.9689 2347.55,65.9652 2347.56,65.9615 2347.57,65.9578 2347.58,65.9541 2347.59,65.9504 2347.6,65.9467 2347.61,65.943 2347.62,65.9393 2347.63,65.9355 2347.64,65.9318 2347.65,65.9281 2347.66,65.9244 2347.67,65.9207 2347.67,65.917 2347.68,65.9133 2347.69,65.9096 2347.7,65.9059 2347.71,65.9022 2347.72,65.8985 2347.73,65.8948 2347.74,65.8911 2347.75,65.8874 2347.76,65.8837 2347.77,65.88 2347.78,65.8763 2347.78,65.8726 2347.79,65.8689 2347.8,65.8652 2347.81,65.8615 2347.82,65.8578 2347.83,65.8541 2347.84,65.8504 2347.85,65.8467 2347.86,65.843 2347.87,65.8393 2347.88,65.8356 2347.89,65.8319 2347.89,65.8282 2347.9,65.8245 2347.91,65.8208 2347.92,65.8171 2347.93,65.8134 2347.94,65.8097 2347.95,65.806 2347.96,65.8023 2347.97,65.7986 2347.98,65.7949 2347.99,65.7912 2348,65.7875 2348.01,65.7838 2348.01,65.7801 2348.02,65.7764 2348.03,65.7727 2348.04,65.769 2348.05,65.7653 2348.06,65.7616 2348.07,65.7579 2348.08,65.7542 2348.09,65.7505 2348.1,65.7468 2348.11,65.7431 2348.12,65.7394 2348.12,65.7357 2348.13,65.732 2348.14,65.7283 2348.15,65.7246 2348.16,65.7209 2348.17,65.7172 2348.18,65.7135 2348.19,65.7098 2348.2,65.7061 2348.21,65.7024 2348.22,65.6987 2348.23,65.695 2348.23,65.6913 2348.24,65.6876 2348.25,65.6839 2348.26,65.6802 2348.27,65.6765 2348.28,65.6728 2348.29,65.6691 2348.3,65.6654 2348.31,65.6617 2348.32,65.658 2348.33,65.6543 2348.34,65.6506 2348.35,65.6469 2348.35,65.6432 2348.36,65.6395 2348.37,65.6358 2348.38,65.6321 2348.39,65.6284 2348.4,65.6247 2348.41,65.621 2348.42,65.6173 2348.43,65.6136 2348.44,65.6099 2348.45,65.6062 2348.46,65.6025 2348.46,65.5988 2348.47,65.5951 2348.48,65.5914 2348.49,65.5877 2348.5,65.584 2348.51,65.5803 2348.52,65.5766 2348.53,65.5729 2348.54,65.5692 2348.55,65.5655 2348.56,65.5618 2348.57,65.5581 2348.57,65.5544 2348.58,65.5507 2348.59,65.547 2348.6,65.5433 2348.61,65.5396 2348.62,65.5359 2348.63,65.5322 2348.64,65.5285 2348.65,65.5248 2348.66,65.5211 2348.67,65.5174 2348.68,65.5137 2348.69,65.51 2348.69,65.5063 2348.7,65.5027 2348.71,65.499 2348.72,65.4953 2348.73,65.4916 2348.74,65.4879 2348.75,65.4842 2348.76,65.4805 2348.77,65.4768 2348.78,65.4731 2348.79,65.4694 2348.8,65.4657 2348.8,65.462 2348.81,65.4583 2348.82,65.4546 2348.83,65.4509 2348.84,65.4472 2348.85,65.4435 2348.86,65.4398 2348.87,65.4361 2348.88,65.4324 2348.89,65.4287 2348.9,65.425 2348.91,65.4213 2348.91,65.4176 2348.92,65.4139 2348.93,65.4102 2348.94,65.4065 2348.95,65.4028 2348.96,65.3991 2348.97,65.3955 2348.98,65.3918 2348.99,65.3881 2349,65.3844 2349.01,65.3807 2349.02,65.377 2349.03,65.3733 2349.03,65.3696 2349.04,65.3659 2349.05,65.3622 2349.06,65.3585 2349.07,65.3548 2349.08,65.3511 2349.09,65.3474 2349.1,65.3437 2349.11,65.34 2349.12,65.3363 2349.13,65.3326 2349.14,65.3289 2349.14,65.3252 2349.15,65.3215 2349.16,65.3179 2349.17,65.3142 2349.18,65.3105 2349.19,65.3068 2349.2,65.3031 2349.21,65.2994 2349.22,65.2957 2349.23,65.292 2349.24,65.2883 2349.25,65.2846 2349.25,65.2809 2349.26,65.2772 2349.27,65.2735 2349.28,65.2698 2349.29,65.2661 2349.3,65.2624 2349.31,65.2587 2349.32,65.255 2349.33,65.2514 2349.34,65.2477 2349.35,65.244 2349.36,65.2403 2349.37,65.2366 2349.37,65.2329 2349.38,65.2292 2349.39,65.2255 2349.4,65.2218 2349.41,65.2181 2349.42,65.2144 2349.43,65.2107 2349.44,65.207 2349.45,65.2033 2349.46,65.1996 2349.47,65.1959 2349.48,65.1923 2349.48,65.1886 2349.49,65.1849 2349.5,65.1812 2349.51,65.1775 2349.52,65.1738 2349.53,65.1701 2349.54,65.1664 2349.55,65.1627 2349.56,65.159 2349.57,65.1553 2349.58,65.1516 2349.59,65.1479 2349.59,65.1442 2349.6,65.1406 2349.61,65.1369 2349.62,65.1332 2349.63,65.1295 2349.64,65.1258 2349.65,65.1221 2349.66,65.1184 2349.67,65.1147 2349.68,65.111 2349.69,65.1073 2349.7,65.1036 2349.71,65.0999 2349.71,65.0962 2349.72,65.0926 2349.73,65.0889 2349.74,65.0852 2349.75,65.0815 2349.76,65.0778 2349.77,65.0741 2349.78,65.0704 2349.79,65.0667 2349.8,65.063 2349.81,65.0593 2349.82,65.0556 2349.82,65.0519 2349.83,65.0483 2349.84,65.0446 2349.85,65.0409 2349.86,65.0372 2349.87,65.0335 2349.88,65.0298 2349.89,65.0261 2349.9,65.0224 2349.91,65.0187 2349.92,65.015 2349.93,65.0113 2349.93,65.0077 2349.94,65.004 2349.95,65.0003 2349.96,64.9966 2349.97,64.9929 2349.98,64.9892 2349.99,64.9855 2350,64.9818 2350.01,64.9781 2350.02,64.9744 2350.03,64.9707 2350.04,64.9671 2350.05,64.9634 2350.05,64.9597 2350.06,64.956 2350.07,64.9523 2350.08,64.9486 2350.09,64.9449 2350.1,64.9412 2350.11,64.9375 2350.12,64.9338 2350.13,64.9302 2350.14,64.9265 2350.15,64.9228 2350.16,64.9191 2350.16,64.9154 2350.17,64.9117 2350.18,64.908 2350.19,64.9043 2350.2,64.9006 2350.21,64.8969 2350.22,64.8933 2350.23,64.8896 2350.24,64.8859 2350.25,64.8822 2350.26,64.8785 2350.27,64.8748 2350.27,64.8711 2350.28,64.8674 2350.29,64.8637 2350.3,64.8601 2350.31,64.8564 2350.32,64.8527 2350.33,64.849 2350.34,64.8453 2350.35,64.8416 2350.36,64.8379 2350.37,64.8342 2350.38,64.8305 2350.39,64.8269 2350.39,64.8232 2350.4,64.8195 2350.41,64.8158 2350.42,64.8121 2350.43,64.8084 2350.44,64.8047 2350.45,64.801 2350.46,64.7973 2350.47,64.7937 2350.48,64.79 2350.49,64.7863 2350.5,64.7826 2350.5,64.7789 2350.51,64.7752 2350.52,64.7715 2350.53,64.7678 2350.54,64.7642 2350.55,64.7605 2350.56,64.7568 2350.57,64.7531 2350.58,64.7494 2350.59,64.7457 2350.6,64.742 2350.61,64.7383 2350.61,64.7347 2350.62,64.731 2350.63,64.7273 2350.64,64.7236 2350.65,64.7199 2350.66,64.7162 2350.67,64.7125 2350.68,64.7088 2350.69,64.7052 2350.7,64.7015 2350.71,64.6978 2350.72,64.6941 2350.73,64.6904 2350.73,64.6867 2350.74,64.683 2350.75,64.6793 2350.76,64.6757 2350.77,64.672 2350.78,64.6683 2350.79,64.6646 2350.8,64.6609 2350.81,64.6572 2350.82,64.6535 2350.83,64.6499 2350.84,64.6462 2350.84,64.6425 2350.85,64.6388 2350.86,64.6351 2350.87,64.6314 2350.88,64.6277 2350.89,64.6241 2350.9,64.6204 2350.91,64.6167 2350.92,64.613 2350.93,64.6093 2350.94,64.6056 2350.95,64.6019 2350.95,64.5982 2350.96,64.5946 2350.97,64.5909 2350.98,64.5872 2350.99,64.5835 2351,64.5798 2351.01,64.5761 2351.02,64.5725 2351.03,64.5688 2351.04,64.5651 2351.05,64.5614 2351.06,64.5577 2351.07,64.554 2351.07,64.5503 2351.08,64.5467 2351.09,64.543 2351.1,64.5393 2351.11,64.5356 2351.12,64.5319 2351.13,64.5282 2351.14,64.5245 2351.15,64.5209 2351.16,64.5172 2351.17,64.5135 2351.18,64.5098 2351.18,64.5061 2351.19,64.5024 2351.2,64.4988 2351.21,64.4951 2351.22,64.4914 2351.23,64.4877 2351.24,64.484 2351.25,64.4803 2351.26,64.4766 2351.27,64.473 2351.28,64.4693 2351.29,64.4656 2351.29,64.4619 2351.3,64.4582 2351.31,64.4545 2351.32,64.4509 2351.33,64.4472 2351.34,64.4435 2351.35,64.4398 2351.36,64.4361 2351.37,64.4324 2351.38,64.4288 2351.39,64.4251 2351.4,64.4214 2351.41,64.4177 2351.41,64.414 2351.42,64.4103 2351.43,64.4067 2351.44,64.403 2351.45,64.3993 2351.46,64.3956 2351.47,64.3919 2351.48,64.3882 2351.49,64.3846 2351.5,64.3809 2351.51,64.3772 2351.52,64.3735 2351.52,64.3698 2351.53,64.3661 2351.54,64.3625 2351.55,64.3588 2351.56,64.3551 2351.57,64.3514 2351.58,64.3477 2351.59,64.344 2351.6,64.3404 2351.61,64.3367 2351.62,64.333 2351.63,64.3293 2351.63,64.3256 2351.64,64.3219 2351.65,64.3183 2351.66,64.3146 2351.67,64.3109 2351.68,64.3072 2351.69,64.3035 2351.7,64.2999 2351.71,64.2962 2351.72,64.2925 2351.73,64.2888 2351.74,64.2851 2351.75,64.2814 2351.75,64.2778 2351.76,64.2741 2351.77,64.2704 2351.78,64.2667 2351.79,64.263 2351.8,64.2594 2351.81,64.2557 2351.82,64.252 2351.83,64.2483 2351.84,64.2446 2351.85,64.241 2351.86,64.2373 2351.86,64.2336 2351.87,64.2299 2351.88,64.2262 2351.89,64.2225 2351.9,64.2189 2351.91,64.2152 2351.92,64.2115 2351.93,64.2078 2351.94,64.2041 2351.95,64.2005 2351.96,64.1968 2351.97,64.1931 2351.97,64.1894 2351.98,64.1857 2351.99,64.1821 2352,64.1784 2352.01,64.1747 2352.02,64.171 2352.03,64.1673 2352.04,64.1637 2352.05,64.16 2352.06,64.1563 2352.07,64.1526 2352.08,64.1489 2352.09,64.1453 2352.09,64.1416 2352.1,64.1379 2352.11,64.1342 2352.12,64.1305 2352.13,64.1269 2352.14,64.1232 2352.15,64.1195 2352.16,64.1158 2352.17,64.1121 2352.18,64.1085 2352.19,64.1048 2352.2,64.1011 2352.2,64.0974 2352.21,64.0937 2352.22,64.0901 2352.23,64.0864 2352.24,64.0827 2352.25,64.079 2352.26,64.0753 2352.27,64.0717 2352.28,64.068 2352.29,64.0643 2352.3,64.0606 2352.31,64.0569 2352.31,64.0533 2352.32,64.0496 2352.33,64.0459 2352.34,64.0422 2352.35,64.0386 2352.36,64.0349 2352.37,64.0312 2352.38,64.0275 2352.39,64.0238 2352.4,64.0202 2352.41,64.0165 2352.42,64.0128 2352.43,64.0091 2352.43,64.0054 2352.44,64.0018 2352.45,63.9981 2352.46,63.9944 2352.47,63.9907 2352.48,63.9871 2352.49,63.9834 2352.5,63.9797 2352.51,63.976 2352.52,63.9723 2352.53,63.9687 2352.54,63.965 2352.54,63.9613 2352.55,63.9576 2352.56,63.954 2352.57,63.9503 2352.58,63.9466 2352.59,63.9429 2352.6,63.9392 2352.61,63.9356 2352.62,63.9319 2352.63,63.9282 2352.64,63.9245 2352.65,63.9209 2352.65,63.9172 2352.66,63.9135 2352.67,63.9098 2352.68,63.9061 2352.69,63.9025 2352.7,63.8988 2352.71,63.8951 2352.72,63.8914 2352.73,63.8878 2352.74,63.8841 2352.75,63.8804 2352.76,63.8767 "/>
<path clip-path="url(#clip400)" d="M2072.29 603.982 L2322.13 603.982 L2322.13 500.302 L2072.29 500.302  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2072.29,603.982 2322.13,603.982 2322.13,500.302 2072.29,500.302 2072.29,603.982 "/>
<polyline clip-path="url(#clip400)" style="stroke:#009af9; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2082.5,552.142 2143.77,552.142 "/>
<path clip-path="url(#clip400)" d="M2153.98 534.862 L2158.65 534.862 L2158.65 565.487 L2175.48 565.487 L2175.48 569.422 L2153.98 569.422 L2153.98 534.862 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2184.09 569.422 L2170.9 534.862 L2175.78 534.862 L2186.73 563.959 L2197.7 534.862 L2202.56 534.862 L2189.39 569.422 L2184.09 569.422 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2216.68 552.779 L2216.68 560.001 L2224.81 560.001 L2224.81 562.2 L2216.68 562.2 L2216.68 569.422 L2214.25 569.422 L2214.25 562.2 L2206.13 562.2 L2206.13 560.001 L2214.25 560.001 L2214.25 552.779 L2216.68 552.779 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2241.55 569.422 L2228.35 534.862 L2233.23 534.862 L2244.18 563.959 L2255.16 534.862 L2260.02 534.862 L2246.85 569.422 L2241.55 569.422 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2275.11 533.45 Q2272.01 538.774 2270.5 543.982 Q2269 549.191 2269 554.538 Q2269 559.885 2270.5 565.14 Q2272.03 570.371 2275.11 575.672 L2271.41 575.672 Q2267.93 570.232 2266.2 564.978 Q2264.48 559.723 2264.48 554.538 Q2264.48 549.376 2266.2 544.144 Q2267.91 538.913 2271.41 533.45 L2275.11 533.45 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2287.59 536.135 L2287.59 543.496 L2296.36 543.496 L2296.36 546.806 L2287.59 546.806 L2287.59 560.88 Q2287.59 564.052 2288.44 564.954 Q2289.32 565.857 2291.98 565.857 L2296.36 565.857 L2296.36 569.422 L2291.98 569.422 Q2287.05 569.422 2285.18 567.593 Q2283.3 565.741 2283.3 560.88 L2283.3 546.806 L2280.18 546.806 L2280.18 543.496 L2283.3 543.496 L2283.3 536.135 L2287.59 536.135 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2301.29 533.45 L2304.99 533.45 Q2308.47 538.913 2310.18 544.144 Q2311.92 549.376 2311.92 554.538 Q2311.92 559.723 2310.18 564.978 Q2308.47 570.232 2304.99 575.672 L2301.29 575.672 Q2304.37 570.371 2305.87 565.14 Q2307.4 559.885 2307.4 554.538 Q2307.4 549.191 2305.87 543.982 Q2304.37 538.774 2301.29 533.45 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M235.283 1423.18 L1154.2 1423.18 L1154.2 847.244 L235.283 847.244  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip404">
    <rect x="235" y="847" width="920" height="577"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip404)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="235.283,1423.18 235.283,847.244 "/>
<polyline clip-path="url(#clip404)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="451.499,1423.18 451.499,847.244 "/>
<polyline clip-path="url(#clip404)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="667.716,1423.18 667.716,847.244 "/>
<polyline clip-path="url(#clip404)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="883.932,1423.18 883.932,847.244 "/>
<polyline clip-path="url(#clip404)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1100.15,1423.18 1100.15,847.244 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,1423.18 1154.2,1423.18 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,1423.18 235.283,1404.28 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="451.499,1423.18 451.499,1404.28 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="667.716,1423.18 667.716,1404.28 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="883.932,1423.18 883.932,1404.28 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1100.15,1423.18 1100.15,1404.28 "/>
<path clip-path="url(#clip400)" d="M187.274 1481.64 L194.913 1481.64 L194.913 1455.28 L186.603 1456.95 L186.603 1452.69 L194.866 1451.02 L199.542 1451.02 L199.542 1481.64 L207.181 1481.64 L207.181 1485.58 L187.274 1485.58 L187.274 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M230.792 1466.95 Q234.149 1467.66 236.024 1469.93 Q237.922 1472.2 237.922 1475.53 Q237.922 1480.65 234.403 1483.45 Q230.885 1486.25 224.403 1486.25 Q222.227 1486.25 219.913 1485.81 Q217.621 1485.39 215.167 1484.54 L215.167 1480.02 Q217.112 1481.16 219.426 1481.74 Q221.741 1482.32 224.264 1482.32 Q228.663 1482.32 230.954 1480.58 Q233.269 1478.84 233.269 1475.53 Q233.269 1472.48 231.116 1470.77 Q228.987 1469.03 225.167 1469.03 L221.139 1469.03 L221.139 1465.19 L225.352 1465.19 Q228.801 1465.19 230.63 1463.82 Q232.459 1462.43 232.459 1459.84 Q232.459 1457.18 230.561 1455.77 Q228.686 1454.33 225.167 1454.33 Q223.246 1454.33 221.047 1454.75 Q218.848 1455.16 216.209 1456.04 L216.209 1451.88 Q218.871 1451.14 221.186 1450.77 Q223.524 1450.39 225.584 1450.39 Q230.908 1450.39 234.01 1452.83 Q237.112 1455.23 237.112 1459.35 Q237.112 1462.22 235.468 1464.21 Q233.825 1466.18 230.792 1466.95 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M246.787 1479.7 L251.672 1479.7 L251.672 1485.58 L246.787 1485.58 L246.787 1479.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M272.435 1466.44 Q269.287 1466.44 267.435 1468.59 Q265.607 1470.74 265.607 1474.49 Q265.607 1478.22 267.435 1480.39 Q269.287 1482.55 272.435 1482.55 Q275.584 1482.55 277.412 1480.39 Q279.264 1478.22 279.264 1474.49 Q279.264 1470.74 277.412 1468.59 Q275.584 1466.44 272.435 1466.44 M281.718 1451.78 L281.718 1456.04 Q279.959 1455.21 278.153 1454.77 Q276.371 1454.33 274.611 1454.33 Q269.982 1454.33 267.528 1457.45 Q265.098 1460.58 264.75 1466.9 Q266.116 1464.89 268.176 1463.82 Q270.236 1462.73 272.713 1462.73 Q277.922 1462.73 280.931 1465.9 Q283.963 1469.05 283.963 1474.49 Q283.963 1479.82 280.815 1483.03 Q277.667 1486.25 272.435 1486.25 Q266.44 1486.25 263.269 1481.67 Q260.098 1477.06 260.098 1468.33 Q260.098 1460.14 263.986 1455.28 Q267.875 1450.39 274.426 1450.39 Q276.185 1450.39 277.968 1450.74 Q279.773 1451.09 281.718 1451.78 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M403.618 1481.64 L411.256 1481.64 L411.256 1455.28 L402.946 1456.95 L402.946 1452.69 L411.21 1451.02 L415.886 1451.02 L415.886 1481.64 L423.525 1481.64 L423.525 1485.58 L403.618 1485.58 L403.618 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M447.136 1466.95 Q450.492 1467.66 452.367 1469.93 Q454.265 1472.2 454.265 1475.53 Q454.265 1480.65 450.747 1483.45 Q447.228 1486.25 440.747 1486.25 Q438.571 1486.25 436.256 1485.81 Q433.965 1485.39 431.511 1484.54 L431.511 1480.02 Q433.455 1481.16 435.77 1481.74 Q438.085 1482.32 440.608 1482.32 Q445.006 1482.32 447.298 1480.58 Q449.613 1478.84 449.613 1475.53 Q449.613 1472.48 447.46 1470.77 Q445.33 1469.03 441.511 1469.03 L437.483 1469.03 L437.483 1465.19 L441.696 1465.19 Q445.145 1465.19 446.974 1463.82 Q448.803 1462.43 448.803 1459.84 Q448.803 1457.18 446.904 1455.77 Q445.029 1454.33 441.511 1454.33 Q439.59 1454.33 437.391 1454.75 Q435.191 1455.16 432.553 1456.04 L432.553 1451.88 Q435.215 1451.14 437.529 1450.77 Q439.867 1450.39 441.928 1450.39 Q447.252 1450.39 450.353 1452.83 Q453.455 1455.23 453.455 1459.35 Q453.455 1462.22 451.812 1464.21 Q450.168 1466.18 447.136 1466.95 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M463.131 1479.7 L468.015 1479.7 L468.015 1485.58 L463.131 1485.58 L463.131 1479.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M488.2 1469.17 Q484.867 1469.17 482.946 1470.95 Q481.048 1472.73 481.048 1475.86 Q481.048 1478.98 482.946 1480.77 Q484.867 1482.55 488.2 1482.55 Q491.534 1482.55 493.455 1480.77 Q495.376 1478.96 495.376 1475.86 Q495.376 1472.73 493.455 1470.95 Q491.557 1469.17 488.2 1469.17 M483.525 1467.18 Q480.515 1466.44 478.826 1464.38 Q477.159 1462.32 477.159 1459.35 Q477.159 1455.21 480.099 1452.8 Q483.062 1450.39 488.2 1450.39 Q493.362 1450.39 496.302 1452.8 Q499.242 1455.21 499.242 1459.35 Q499.242 1462.32 497.552 1464.38 Q495.886 1466.44 492.9 1467.18 Q496.279 1467.96 498.154 1470.26 Q500.052 1472.55 500.052 1475.86 Q500.052 1480.88 496.974 1483.57 Q493.918 1486.25 488.2 1486.25 Q482.483 1486.25 479.404 1483.57 Q476.349 1480.88 476.349 1475.86 Q476.349 1472.55 478.247 1470.26 Q480.145 1467.96 483.525 1467.18 M481.812 1459.79 Q481.812 1462.48 483.478 1463.98 Q485.168 1465.49 488.2 1465.49 Q491.21 1465.49 492.9 1463.98 Q494.612 1462.48 494.612 1459.79 Q494.612 1457.11 492.9 1455.6 Q491.21 1454.1 488.2 1454.1 Q485.168 1454.1 483.478 1455.6 Q481.812 1457.11 481.812 1459.79 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M619.788 1481.64 L627.427 1481.64 L627.427 1455.28 L619.116 1456.95 L619.116 1452.69 L627.38 1451.02 L632.056 1451.02 L632.056 1481.64 L639.695 1481.64 L639.695 1485.58 L619.788 1485.58 L619.788 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M661.987 1455.09 L650.181 1473.54 L661.987 1473.54 L661.987 1455.09 M660.76 1451.02 L666.639 1451.02 L666.639 1473.54 L671.57 1473.54 L671.57 1477.43 L666.639 1477.43 L666.639 1485.58 L661.987 1485.58 L661.987 1477.43 L646.385 1477.43 L646.385 1472.92 L660.76 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M679.301 1479.7 L684.186 1479.7 L684.186 1485.58 L679.301 1485.58 L679.301 1479.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M704.371 1454.1 Q700.76 1454.1 698.931 1457.66 Q697.125 1461.2 697.125 1468.33 Q697.125 1475.44 698.931 1479.01 Q700.76 1482.55 704.371 1482.55 Q708.005 1482.55 709.81 1479.01 Q711.639 1475.44 711.639 1468.33 Q711.639 1461.2 709.81 1457.66 Q708.005 1454.1 704.371 1454.1 M704.371 1450.39 Q710.181 1450.39 713.236 1455 Q716.315 1459.58 716.315 1468.33 Q716.315 1477.06 713.236 1481.67 Q710.181 1486.25 704.371 1486.25 Q698.56 1486.25 695.482 1481.67 Q692.426 1477.06 692.426 1468.33 Q692.426 1459.58 695.482 1455 Q698.56 1450.39 704.371 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M836.803 1481.64 L844.442 1481.64 L844.442 1455.28 L836.131 1456.95 L836.131 1452.69 L844.395 1451.02 L849.071 1451.02 L849.071 1481.64 L856.71 1481.64 L856.71 1485.58 L836.803 1485.58 L836.803 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M879.002 1455.09 L867.196 1473.54 L879.002 1473.54 L879.002 1455.09 M877.775 1451.02 L883.654 1451.02 L883.654 1473.54 L888.585 1473.54 L888.585 1477.43 L883.654 1477.43 L883.654 1485.58 L879.002 1485.58 L879.002 1477.43 L863.4 1477.43 L863.4 1472.92 L877.775 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M896.316 1479.7 L901.201 1479.7 L901.201 1485.58 L896.316 1485.58 L896.316 1479.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M915.413 1481.64 L931.733 1481.64 L931.733 1485.58 L909.788 1485.58 L909.788 1481.64 Q912.45 1478.89 917.034 1474.26 Q921.64 1469.61 922.821 1468.27 Q925.066 1465.74 925.946 1464.01 Q926.849 1462.25 926.849 1460.56 Q926.849 1457.8 924.904 1456.07 Q922.983 1454.33 919.881 1454.33 Q917.682 1454.33 915.228 1455.09 Q912.798 1455.86 910.02 1457.41 L910.02 1452.69 Q912.844 1451.55 915.298 1450.97 Q917.751 1450.39 919.788 1450.39 Q925.159 1450.39 928.353 1453.08 Q931.548 1455.77 931.548 1460.26 Q931.548 1462.39 930.737 1464.31 Q929.95 1466.2 927.844 1468.8 Q927.265 1469.47 924.163 1472.69 Q921.062 1475.88 915.413 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1051.98 1481.64 L1059.62 1481.64 L1059.62 1455.28 L1051.31 1456.95 L1051.31 1452.69 L1059.57 1451.02 L1064.25 1451.02 L1064.25 1481.64 L1071.88 1481.64 L1071.88 1485.58 L1051.98 1485.58 L1051.98 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1094.18 1455.09 L1082.37 1473.54 L1094.18 1473.54 L1094.18 1455.09 M1092.95 1451.02 L1098.83 1451.02 L1098.83 1473.54 L1103.76 1473.54 L1103.76 1477.43 L1098.83 1477.43 L1098.83 1485.58 L1094.18 1485.58 L1094.18 1477.43 L1078.57 1477.43 L1078.57 1472.92 L1092.95 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1111.49 1479.7 L1116.38 1479.7 L1116.38 1485.58 L1111.49 1485.58 L1111.49 1479.7 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1139.41 1455.09 L1127.6 1473.54 L1139.41 1473.54 L1139.41 1455.09 M1138.18 1451.02 L1144.06 1451.02 L1144.06 1473.54 L1148.99 1473.54 L1148.99 1477.43 L1144.06 1477.43 L1144.06 1485.58 L1139.41 1485.58 L1139.41 1477.43 L1123.81 1477.43 L1123.81 1472.92 L1138.18 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M564.914 1520.52 L605.114 1520.52 L605.114 1525.93 L588.244 1525.93 L588.244 1568.04 L581.783 1568.04 L581.783 1525.93 L564.914 1525.93 L564.914 1520.52 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M609.06 1532.4 L614.917 1532.4 L614.917 1568.04 L609.06 1568.04 L609.06 1532.4 M609.06 1518.52 L614.917 1518.52 L614.917 1525.93 L609.06 1525.93 L609.06 1518.52 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M654.925 1539.24 Q657.121 1535.29 660.177 1533.41 Q663.233 1531.54 667.37 1531.54 Q672.94 1531.54 675.964 1535.45 Q678.988 1539.33 678.988 1546.53 L678.988 1568.04 L673.099 1568.04 L673.099 1546.72 Q673.099 1541.59 671.285 1539.11 Q669.471 1536.63 665.747 1536.63 Q661.195 1536.63 658.554 1539.65 Q655.912 1542.68 655.912 1547.9 L655.912 1568.04 L650.024 1568.04 L650.024 1546.72 Q650.024 1541.56 648.209 1539.11 Q646.395 1536.63 642.608 1536.63 Q638.12 1536.63 635.478 1539.68 Q632.836 1542.71 632.836 1547.9 L632.836 1568.04 L626.948 1568.04 L626.948 1532.4 L632.836 1532.4 L632.836 1537.93 Q634.841 1534.66 637.642 1533.1 Q640.443 1531.54 644.295 1531.54 Q648.178 1531.54 650.883 1533.51 Q653.62 1535.48 654.925 1539.24 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M721.16 1548.76 L721.16 1551.62 L694.233 1551.62 Q694.615 1557.67 697.862 1560.85 Q701.14 1564 706.965 1564 Q710.339 1564 713.49 1563.17 Q716.673 1562.35 719.792 1560.69 L719.792 1566.23 Q716.641 1567.57 713.331 1568.27 Q710.02 1568.97 706.615 1568.97 Q698.085 1568.97 693.088 1564 Q688.122 1559.04 688.122 1550.57 Q688.122 1541.82 692.833 1536.69 Q697.575 1531.54 705.596 1531.54 Q712.79 1531.54 716.959 1536.18 Q721.16 1540.8 721.16 1548.76 M715.304 1547.04 Q715.24 1542.23 712.599 1539.37 Q709.989 1536.5 705.66 1536.5 Q700.758 1536.5 697.798 1539.27 Q694.87 1542.04 694.424 1547.07 L715.304 1547.04 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M750.952 1518.52 L764.447 1518.52 L764.447 1523.07 L756.808 1523.07 L756.808 1572.09 L764.447 1572.09 L764.447 1576.64 L750.952 1576.64 L750.952 1518.52 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M799.65 1533.45 L799.65 1538.98 Q797.167 1537.71 794.493 1537.07 Q791.82 1536.44 788.955 1536.44 Q784.595 1536.44 782.399 1537.77 Q780.234 1539.11 780.234 1541.79 Q780.234 1543.82 781.794 1545 Q783.353 1546.15 788.064 1547.2 L790.069 1547.64 Q796.308 1548.98 798.918 1551.43 Q801.559 1553.85 801.559 1558.21 Q801.559 1563.17 797.613 1566.07 Q793.698 1568.97 786.823 1568.97 Q783.958 1568.97 780.839 1568.39 Q777.752 1567.85 774.314 1566.74 L774.314 1560.69 Q777.561 1562.38 780.712 1563.24 Q783.863 1564.07 786.95 1564.07 Q791.088 1564.07 793.316 1562.66 Q795.544 1561.23 795.544 1558.65 Q795.544 1556.27 793.92 1554.99 Q792.329 1553.72 786.886 1552.54 L784.849 1552.07 Q779.407 1550.92 776.988 1548.56 Q774.569 1546.18 774.569 1542.04 Q774.569 1537.01 778.134 1534.27 Q781.698 1531.54 788.255 1531.54 Q791.501 1531.54 794.366 1532.01 Q797.231 1532.49 799.65 1533.45 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M824.571 1518.52 L824.571 1576.64 L811.076 1576.64 L811.076 1572.09 L818.683 1572.09 L818.683 1523.07 L811.076 1523.07 L811.076 1518.52 L824.571 1518.52 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip404)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="235.283,1406.88 1154.2,1406.88 "/>
<polyline clip-path="url(#clip404)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="235.283,1296.16 1154.2,1296.16 "/>
<polyline clip-path="url(#clip404)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="235.283,1185.44 1154.2,1185.44 "/>
<polyline clip-path="url(#clip404)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="235.283,1074.72 1154.2,1074.72 "/>
<polyline clip-path="url(#clip404)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="235.283,963.994 1154.2,963.994 "/>
<polyline clip-path="url(#clip404)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="235.283,853.272 1154.2,853.272 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,1423.18 235.283,847.244 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,1406.88 254.18,1406.88 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,1296.16 254.18,1296.16 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,1185.44 254.18,1185.44 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,1074.72 254.18,1074.72 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,963.994 254.18,963.994 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,853.272 254.18,853.272 "/>
<path clip-path="url(#clip400)" d="M187.338 1392.68 Q183.727 1392.68 181.899 1396.24 Q180.093 1399.78 180.093 1406.91 Q180.093 1414.02 181.899 1417.59 Q183.727 1421.13 187.338 1421.13 Q190.973 1421.13 192.778 1417.59 Q194.607 1414.02 194.607 1406.91 Q194.607 1399.78 192.778 1396.24 Q190.973 1392.68 187.338 1392.68 M187.338 1388.97 Q193.149 1388.97 196.204 1393.58 Q199.283 1398.16 199.283 1406.91 Q199.283 1415.64 196.204 1420.25 Q193.149 1424.83 187.338 1424.83 Q181.528 1424.83 178.45 1420.25 Q175.394 1415.64 175.394 1406.91 Q175.394 1398.16 178.45 1393.58 Q181.528 1388.97 187.338 1388.97 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M117.825 1309.5 L125.464 1309.5 L125.464 1283.14 L117.154 1284.8 L117.154 1280.54 L125.418 1278.88 L130.093 1278.88 L130.093 1309.5 L137.732 1309.5 L137.732 1313.44 L117.825 1313.44 L117.825 1309.5 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M157.177 1281.96 Q153.566 1281.96 151.737 1285.52 Q149.931 1289.06 149.931 1296.19 Q149.931 1303.3 151.737 1306.86 Q153.566 1310.41 157.177 1310.41 Q160.811 1310.41 162.616 1306.86 Q164.445 1303.3 164.445 1296.19 Q164.445 1289.06 162.616 1285.52 Q160.811 1281.96 157.177 1281.96 M157.177 1278.25 Q162.987 1278.25 166.042 1282.86 Q169.121 1287.44 169.121 1296.19 Q169.121 1304.92 166.042 1309.53 Q162.987 1314.11 157.177 1314.11 Q151.366 1314.11 148.288 1309.53 Q145.232 1304.92 145.232 1296.19 Q145.232 1287.44 148.288 1282.86 Q151.366 1278.25 157.177 1278.25 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M187.338 1281.96 Q183.727 1281.96 181.899 1285.52 Q180.093 1289.06 180.093 1296.19 Q180.093 1303.3 181.899 1306.86 Q183.727 1310.41 187.338 1310.41 Q190.973 1310.41 192.778 1306.86 Q194.607 1303.3 194.607 1296.19 Q194.607 1289.06 192.778 1285.52 Q190.973 1281.96 187.338 1281.96 M187.338 1278.25 Q193.149 1278.25 196.204 1282.86 Q199.283 1287.44 199.283 1296.19 Q199.283 1304.92 196.204 1309.53 Q193.149 1314.11 187.338 1314.11 Q181.528 1314.11 178.45 1309.53 Q175.394 1304.92 175.394 1296.19 Q175.394 1287.44 178.45 1282.86 Q181.528 1278.25 187.338 1278.25 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M121.043 1198.78 L137.362 1198.78 L137.362 1202.72 L115.418 1202.72 L115.418 1198.78 Q118.08 1196.03 122.663 1191.4 Q127.269 1186.74 128.45 1185.4 Q130.695 1182.88 131.575 1181.14 Q132.478 1179.38 132.478 1177.69 Q132.478 1174.94 130.533 1173.2 Q128.612 1171.47 125.51 1171.47 Q123.311 1171.47 120.857 1172.23 Q118.427 1172.99 115.649 1174.55 L115.649 1169.82 Q118.473 1168.69 120.927 1168.11 Q123.38 1167.53 125.418 1167.53 Q130.788 1167.53 133.982 1170.22 Q137.177 1172.9 137.177 1177.39 Q137.177 1179.52 136.367 1181.44 Q135.579 1183.34 133.473 1185.93 Q132.894 1186.61 129.792 1189.82 Q126.691 1193.02 121.043 1198.78 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M157.177 1171.24 Q153.566 1171.24 151.737 1174.8 Q149.931 1178.34 149.931 1185.47 Q149.931 1192.58 151.737 1196.14 Q153.566 1199.68 157.177 1199.68 Q160.811 1199.68 162.616 1196.14 Q164.445 1192.58 164.445 1185.47 Q164.445 1178.34 162.616 1174.8 Q160.811 1171.24 157.177 1171.24 M157.177 1167.53 Q162.987 1167.53 166.042 1172.14 Q169.121 1176.72 169.121 1185.47 Q169.121 1194.2 166.042 1198.8 Q162.987 1203.39 157.177 1203.39 Q151.366 1203.39 148.288 1198.8 Q145.232 1194.2 145.232 1185.47 Q145.232 1176.72 148.288 1172.14 Q151.366 1167.53 157.177 1167.53 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M187.338 1171.24 Q183.727 1171.24 181.899 1174.8 Q180.093 1178.34 180.093 1185.47 Q180.093 1192.58 181.899 1196.14 Q183.727 1199.68 187.338 1199.68 Q190.973 1199.68 192.778 1196.14 Q194.607 1192.58 194.607 1185.47 Q194.607 1178.34 192.778 1174.8 Q190.973 1171.24 187.338 1171.24 M187.338 1167.53 Q193.149 1167.53 196.204 1172.14 Q199.283 1176.72 199.283 1185.47 Q199.283 1194.2 196.204 1198.8 Q193.149 1203.39 187.338 1203.39 Q181.528 1203.39 178.45 1198.8 Q175.394 1194.2 175.394 1185.47 Q175.394 1176.72 178.45 1172.14 Q181.528 1167.53 187.338 1167.53 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M131.181 1073.36 Q134.538 1074.08 136.413 1076.35 Q138.311 1078.62 138.311 1081.95 Q138.311 1087.06 134.792 1089.87 Q131.274 1092.67 124.793 1092.67 Q122.617 1092.67 120.302 1092.23 Q118.01 1091.81 115.556 1090.95 L115.556 1086.44 Q117.501 1087.57 119.816 1088.15 Q122.13 1088.73 124.654 1088.73 Q129.052 1088.73 131.343 1087 Q133.658 1085.26 133.658 1081.95 Q133.658 1078.89 131.505 1077.18 Q129.376 1075.44 125.556 1075.44 L121.529 1075.44 L121.529 1071.6 L125.742 1071.6 Q129.191 1071.6 131.019 1070.24 Q132.848 1068.85 132.848 1066.25 Q132.848 1063.59 130.95 1062.18 Q129.075 1060.75 125.556 1060.75 Q123.635 1060.75 121.436 1061.16 Q119.237 1061.58 116.598 1062.46 L116.598 1058.29 Q119.26 1057.55 121.575 1057.18 Q123.913 1056.81 125.973 1056.81 Q131.297 1056.81 134.399 1059.24 Q137.501 1061.65 137.501 1065.77 Q137.501 1068.64 135.857 1070.63 Q134.214 1072.6 131.181 1073.36 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M157.177 1060.51 Q153.566 1060.51 151.737 1064.08 Q149.931 1067.62 149.931 1074.75 Q149.931 1081.86 151.737 1085.42 Q153.566 1088.96 157.177 1088.96 Q160.811 1088.96 162.616 1085.42 Q164.445 1081.86 164.445 1074.75 Q164.445 1067.62 162.616 1064.08 Q160.811 1060.51 157.177 1060.51 M157.177 1056.81 Q162.987 1056.81 166.042 1061.42 Q169.121 1066 169.121 1074.75 Q169.121 1083.48 166.042 1088.08 Q162.987 1092.67 157.177 1092.67 Q151.366 1092.67 148.288 1088.08 Q145.232 1083.48 145.232 1074.75 Q145.232 1066 148.288 1061.42 Q151.366 1056.81 157.177 1056.81 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M187.338 1060.51 Q183.727 1060.51 181.899 1064.08 Q180.093 1067.62 180.093 1074.75 Q180.093 1081.86 181.899 1085.42 Q183.727 1088.96 187.338 1088.96 Q190.973 1088.96 192.778 1085.42 Q194.607 1081.86 194.607 1074.75 Q194.607 1067.62 192.778 1064.08 Q190.973 1060.51 187.338 1060.51 M187.338 1056.81 Q193.149 1056.81 196.204 1061.42 Q199.283 1066 199.283 1074.75 Q199.283 1083.48 196.204 1088.08 Q193.149 1092.67 187.338 1092.67 Q181.528 1092.67 178.45 1088.08 Q175.394 1083.48 175.394 1074.75 Q175.394 1066 178.45 1061.42 Q181.528 1056.81 187.338 1056.81 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M129.862 950.788 L118.056 969.237 L129.862 969.237 L129.862 950.788 M128.635 946.714 L134.515 946.714 L134.515 969.237 L139.445 969.237 L139.445 973.126 L134.515 973.126 L134.515 981.274 L129.862 981.274 L129.862 973.126 L114.26 973.126 L114.26 968.612 L128.635 946.714 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M157.177 949.792 Q153.566 949.792 151.737 953.357 Q149.931 956.899 149.931 964.028 Q149.931 971.135 151.737 974.7 Q153.566 978.241 157.177 978.241 Q160.811 978.241 162.616 974.7 Q164.445 971.135 164.445 964.028 Q164.445 956.899 162.616 953.357 Q160.811 949.792 157.177 949.792 M157.177 946.089 Q162.987 946.089 166.042 950.695 Q169.121 955.278 169.121 964.028 Q169.121 972.755 166.042 977.362 Q162.987 981.945 157.177 981.945 Q151.366 981.945 148.288 977.362 Q145.232 972.755 145.232 964.028 Q145.232 955.278 148.288 950.695 Q151.366 946.089 157.177 946.089 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M187.338 949.792 Q183.727 949.792 181.899 953.357 Q180.093 956.899 180.093 964.028 Q180.093 971.135 181.899 974.7 Q183.727 978.241 187.338 978.241 Q190.973 978.241 192.778 974.7 Q194.607 971.135 194.607 964.028 Q194.607 956.899 192.778 953.357 Q190.973 949.792 187.338 949.792 M187.338 946.089 Q193.149 946.089 196.204 950.695 Q199.283 955.278 199.283 964.028 Q199.283 972.755 196.204 977.362 Q193.149 981.945 187.338 981.945 Q181.528 981.945 178.45 977.362 Q175.394 972.755 175.394 964.028 Q175.394 955.278 178.45 950.695 Q181.528 946.089 187.338 946.089 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M117.061 835.992 L135.417 835.992 L135.417 839.927 L121.343 839.927 L121.343 848.4 Q122.362 848.052 123.38 847.89 Q124.399 847.705 125.418 847.705 Q131.205 847.705 134.584 850.876 Q137.964 854.048 137.964 859.464 Q137.964 865.043 134.492 868.145 Q131.019 871.223 124.7 871.223 Q122.524 871.223 120.255 870.853 Q118.01 870.483 115.603 869.742 L115.603 865.043 Q117.686 866.177 119.908 866.733 Q122.13 867.288 124.607 867.288 Q128.612 867.288 130.95 865.182 Q133.288 863.075 133.288 859.464 Q133.288 855.853 130.95 853.747 Q128.612 851.64 124.607 851.64 Q122.732 851.64 120.857 852.057 Q119.006 852.474 117.061 853.353 L117.061 835.992 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M157.177 839.071 Q153.566 839.071 151.737 842.636 Q149.931 846.177 149.931 853.307 Q149.931 860.413 151.737 863.978 Q153.566 867.52 157.177 867.52 Q160.811 867.52 162.616 863.978 Q164.445 860.413 164.445 853.307 Q164.445 846.177 162.616 842.636 Q160.811 839.071 157.177 839.071 M157.177 835.367 Q162.987 835.367 166.042 839.974 Q169.121 844.557 169.121 853.307 Q169.121 862.034 166.042 866.64 Q162.987 871.223 157.177 871.223 Q151.366 871.223 148.288 866.64 Q145.232 862.034 145.232 853.307 Q145.232 844.557 148.288 839.974 Q151.366 835.367 157.177 835.367 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M187.338 839.071 Q183.727 839.071 181.899 842.636 Q180.093 846.177 180.093 853.307 Q180.093 860.413 181.899 863.978 Q183.727 867.52 187.338 867.52 Q190.973 867.52 192.778 863.978 Q194.607 860.413 194.607 853.307 Q194.607 846.177 192.778 842.636 Q190.973 839.071 187.338 839.071 M187.338 835.367 Q193.149 835.367 196.204 839.974 Q199.283 844.557 199.283 853.307 Q199.283 862.034 196.204 866.64 Q193.149 871.223 187.338 871.223 Q181.528 871.223 178.45 866.64 Q175.394 862.034 175.394 853.307 Q175.394 844.557 178.45 839.974 Q181.528 835.367 187.338 835.367 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M16.4842 1384.73 L16.4842 1357.42 L21.895 1357.42 L21.895 1378.3 L35.8996 1378.3 L35.8996 1359.46 L41.3104 1359.46 L41.3104 1378.3 L64.0042 1378.3 L64.0042 1384.73 L16.4842 1384.73 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M14.479 1347.49 L14.479 1341.64 L64.0042 1341.64 L64.0042 1347.49 L14.479 1347.49 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M32.4621 1315.57 Q32.4621 1320.28 36.1542 1323.02 Q39.8145 1325.75 46.212 1325.75 Q52.6095 1325.75 56.3017 1323.05 Q59.9619 1320.31 59.9619 1315.57 Q59.9619 1310.89 56.2698 1308.15 Q52.5777 1305.42 46.212 1305.42 Q39.8781 1305.42 36.186 1308.15 Q32.4621 1310.89 32.4621 1315.57 M27.4968 1315.57 Q27.4968 1307.93 32.4621 1303.57 Q37.4273 1299.21 46.212 1299.21 Q54.9649 1299.21 59.9619 1303.57 Q64.9272 1307.93 64.9272 1315.57 Q64.9272 1323.24 59.9619 1327.6 Q54.9649 1331.93 46.212 1331.93 Q37.4273 1331.93 32.4621 1327.6 Q27.4968 1323.24 27.4968 1315.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M28.3562 1292.91 L28.3562 1287.05 L56.1743 1279.73 L28.3562 1272.44 L28.3562 1265.53 L56.1743 1258.21 L28.3562 1250.92 L28.3562 1245.07 L64.0042 1254.39 L64.0042 1261.3 L34.7856 1268.97 L64.0042 1276.67 L64.0042 1283.58 L28.3562 1292.91 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M33.8307 1194.81 Q33.2578 1195.8 33.0032 1196.98 Q32.7167 1198.12 32.7167 1199.52 Q32.7167 1204.49 35.9632 1207.16 Q39.1779 1209.8 45.2253 1209.8 L64.0042 1209.8 L64.0042 1215.69 L28.3562 1215.69 L28.3562 1209.8 L33.8944 1209.8 Q30.6479 1207.96 29.0883 1205 Q27.4968 1202.04 27.4968 1197.8 Q27.4968 1197.2 27.5923 1196.47 Q27.656 1195.73 27.8151 1194.84 L33.8307 1194.81 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M46.0847 1172.47 Q46.0847 1179.57 47.7079 1182.3 Q49.3312 1185.04 53.2461 1185.04 Q56.3653 1185.04 58.2114 1183 Q60.0256 1180.93 60.0256 1177.4 Q60.0256 1172.53 56.5881 1169.6 Q53.1188 1166.64 47.3897 1166.64 L46.0847 1166.64 L46.0847 1172.47 M43.6657 1160.79 L64.0042 1160.79 L64.0042 1166.64 L58.5933 1166.64 Q61.8398 1168.65 63.3994 1171.64 Q64.9272 1174.63 64.9272 1178.96 Q64.9272 1184.43 61.8716 1187.68 Q58.7843 1190.9 53.6281 1190.9 Q47.6125 1190.9 44.5569 1186.89 Q41.5014 1182.84 41.5014 1174.85 L41.5014 1166.64 L40.9285 1166.64 Q36.8862 1166.64 34.6901 1169.32 Q32.4621 1171.96 32.4621 1176.76 Q32.4621 1179.82 33.1941 1182.72 Q33.9262 1185.61 35.3903 1188.29 L29.9795 1188.29 Q28.7381 1185.07 28.1334 1182.05 Q27.4968 1179.02 27.4968 1176.16 Q27.4968 1168.43 31.5072 1164.61 Q35.5176 1160.79 43.6657 1160.79 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M18.2347 1142.93 L28.3562 1142.93 L28.3562 1130.87 L32.9077 1130.87 L32.9077 1142.93 L52.2594 1142.93 Q56.6199 1142.93 57.8613 1141.75 Q59.1026 1140.54 59.1026 1136.88 L59.1026 1130.87 L64.0042 1130.87 L64.0042 1136.88 Q64.0042 1143.66 61.4897 1146.24 Q58.9434 1148.82 52.2594 1148.82 L32.9077 1148.82 L32.9077 1153.12 L28.3562 1153.12 L28.3562 1148.82 L18.2347 1148.82 L18.2347 1142.93 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M44.7161 1092.67 L47.5806 1092.67 L47.5806 1119.6 Q53.6281 1119.22 56.8109 1115.97 Q59.9619 1112.69 59.9619 1106.87 Q59.9619 1103.49 59.1344 1100.34 Q58.3069 1097.16 56.6518 1094.04 L62.1899 1094.04 Q63.5267 1097.19 64.227 1100.5 Q64.9272 1103.81 64.9272 1107.22 Q64.9272 1115.75 59.9619 1120.75 Q54.9967 1125.71 46.5303 1125.71 Q37.7774 1125.71 32.6531 1121 Q27.4968 1116.26 27.4968 1108.24 Q27.4968 1101.04 32.1438 1096.87 Q36.7589 1092.67 44.7161 1092.67 M42.9973 1098.53 Q38.1912 1098.59 35.3266 1101.24 Q32.4621 1103.84 32.4621 1108.17 Q32.4621 1113.08 35.2312 1116.04 Q38.0002 1118.96 43.0292 1119.41 L42.9973 1098.53 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M14.479 1062.88 L14.479 1049.39 L19.0304 1049.39 L19.0304 1057.03 L68.0464 1057.03 L68.0464 1049.39 L72.5979 1049.39 L72.5979 1062.88 L14.479 1062.88 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M35.1993 1009.16 Q31.2526 1006.96 29.3747 1003.9 Q27.4968 1000.85 27.4968 996.71 Q27.4968 991.14 31.4117 988.116 Q35.2948 985.093 42.4881 985.093 L64.0042 985.093 L64.0042 990.981 L42.679 990.981 Q37.5546 990.981 35.072 992.795 Q32.5894 994.609 32.5894 998.333 Q32.5894 1002.88 35.6131 1005.53 Q38.6368 1008.17 43.8567 1008.17 L64.0042 1008.17 L64.0042 1014.06 L42.679 1014.06 Q37.5228 1014.06 35.072 1015.87 Q32.5894 1017.69 32.5894 1021.47 Q32.5894 1025.96 35.6449 1028.6 Q38.6686 1031.24 43.8567 1031.24 L64.0042 1031.24 L64.0042 1037.13 L28.3562 1037.13 L28.3562 1031.24 L33.8944 1031.24 Q30.616 1029.24 29.0564 1026.44 Q27.4968 1023.64 27.4968 1019.79 Q27.4968 1015.9 29.4702 1013.2 Q31.4436 1010.46 35.1993 1009.16 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M14.479 973.412 L14.479 967.555 L64.0042 967.555 L64.0042 973.412 L14.479 973.412 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M16.4842 944.893 L16.4842 939.482 L70.0516 956.033 L70.0516 961.444 L16.4842 944.893 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M29.4065 910.614 L34.9447 910.614 Q33.6716 913.097 33.035 915.77 Q32.3984 918.444 32.3984 921.308 Q32.3984 925.669 33.7352 927.865 Q35.072 930.029 37.7456 930.029 Q39.7826 930.029 40.9603 928.47 Q42.1061 926.91 43.1565 922.2 L43.6021 920.194 Q44.9389 913.956 47.3897 911.346 Q49.8086 908.704 54.1691 908.704 Q59.1344 908.704 62.0308 912.651 Q64.9272 916.566 64.9272 923.441 Q64.9272 926.305 64.3543 929.425 Q63.8132 932.512 62.6992 935.949 L56.6518 935.949 Q58.3387 932.703 59.198 929.552 Q60.0256 926.401 60.0256 923.314 Q60.0256 919.176 58.6251 916.948 Q57.1929 914.72 54.6147 914.72 Q52.2276 914.72 50.9545 916.343 Q49.6813 917.934 48.5037 923.377 L48.0262 925.414 Q46.8804 930.857 44.5251 933.276 Q42.138 935.695 38.0002 935.695 Q32.9713 935.695 30.2341 932.13 Q27.4968 928.565 27.4968 922.009 Q27.4968 918.762 27.9743 915.897 Q28.4517 913.033 29.4065 910.614 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M14.479 885.692 L72.5979 885.692 L72.5979 899.187 L68.0464 899.187 L68.0464 891.58 L19.0304 891.58 L19.0304 899.187 L14.479 899.187 L14.479 885.692 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip404)" style="stroke:#009af9; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,1406.88 235.292,1406.88 235.301,1406.88 235.31,1406.88 235.32,1406.88 235.329,1406.88 235.338,1406.88 235.347,1406.88 235.356,1406.88 235.366,1406.88 235.375,1406.88 235.384,1406.88 235.393,1406.88 235.402,1406.88 235.412,1406.88 235.421,1406.88 235.43,1406.88 235.439,1406.88 235.448,1406.88 235.457,1406.88 235.467,1406.88 235.476,1406.88 235.485,1406.88 235.494,1406.88 235.503,1406.88 235.513,1406.88 235.522,1406.88 235.531,1406.88 235.54,1406.88 235.549,1406.88 235.559,1406.88 235.568,1406.88 235.577,1406.88 235.586,1406.88 235.595,1406.88 235.604,1406.88 235.614,1406.88 235.623,1406.88 235.632,1406.88 235.641,1406.88 235.65,1406.88 235.66,1406.88 235.669,1406.88 235.678,1406.88 235.687,1406.88 235.696,1406.88 235.706,1406.88 235.715,1406.88 235.724,1406.88 235.733,1406.88 235.742,1406.88 235.752,1406.88 235.761,1406.88 235.77,1406.88 235.779,1406.88 235.788,1406.88 235.797,1406.88 235.807,1406.88 235.816,1406.88 235.825,1406.88 235.834,1406.88 235.843,1406.88 235.853,1406.88 235.862,1406.88 235.871,1406.88 235.88,1406.88 235.889,1406.88 235.899,1406.88 235.908,1406.88 235.917,1406.88 235.926,1406.88 235.935,1406.88 235.944,1406.88 235.954,1406.88 235.963,1406.88 235.972,1406.88 235.981,1406.88 235.99,1406.88 236,1406.88 236.009,1406.88 236.018,1406.88 236.027,1406.88 236.036,1406.88 236.046,1406.88 236.055,1406.88 236.064,1406.88 236.073,1406.88 236.082,1406.88 236.092,1406.88 236.101,1406.88 236.11,1406.88 236.119,1406.88 236.128,1406.88 236.137,1406.88 236.147,1406.88 236.156,1406.88 236.165,1406.88 236.174,1406.88 236.183,1406.88 236.193,1406.88 236.202,1406.88 236.211,1406.88 236.22,1406.88 236.229,1406.88 236.239,1406.88 236.248,1406.88 236.257,1406.88 236.266,1406.88 236.275,1406.88 236.284,1406.88 236.294,1406.88 236.303,1406.88 236.312,1406.88 236.321,1406.88 236.33,1406.88 236.34,1406.88 236.349,1406.88 236.358,1406.88 236.367,1406.88 236.376,1406.88 236.386,1406.88 236.395,1406.88 236.404,1406.88 236.413,1406.88 236.422,1406.88 236.432,1406.88 236.441,1406.88 236.45,1406.88 236.459,1406.88 236.468,1406.88 236.477,1406.88 236.487,1406.88 236.496,1406.88 236.505,1406.88 236.514,1406.88 236.523,1406.88 236.533,1406.88 236.542,1406.88 236.551,1406.88 236.56,1406.88 236.569,1406.88 236.579,1406.88 236.588,1406.88 236.597,1406.88 236.606,1406.88 236.615,1406.88 236.624,1406.88 236.634,1406.88 236.643,1406.88 236.652,1406.88 236.661,1406.88 236.67,1406.88 236.68,1406.88 236.689,1406.88 236.698,1406.88 236.707,1406.88 236.716,1406.88 236.726,1406.88 236.735,1406.88 236.744,1406.88 236.753,1406.88 236.762,1406.88 236.772,1406.88 236.781,1406.88 236.79,1406.88 236.799,1406.88 236.808,1406.88 236.817,1406.88 236.827,1406.88 236.836,1406.88 236.845,1406.88 236.854,1406.88 236.863,1406.88 236.873,1406.88 236.882,1406.88 236.891,1406.88 236.9,1406.88 236.909,1406.88 236.919,1406.88 236.928,1406.88 236.937,1406.88 236.946,1406.88 236.955,1406.88 236.964,1406.88 236.974,1406.88 236.983,1406.88 236.992,1406.88 237.001,1406.88 237.01,1406.88 237.02,1406.88 237.029,1406.88 237.038,1406.88 237.047,1406.88 237.056,1406.88 237.066,1406.88 237.075,1406.88 237.084,1406.88 237.093,1406.88 237.102,1406.88 237.112,1406.88 237.121,1406.88 237.13,1406.88 237.139,1406.88 237.148,1406.88 237.157,1406.88 237.167,1406.88 237.176,1406.88 237.185,1406.88 237.194,1406.88 237.203,1406.88 237.213,1406.88 237.222,1406.88 237.231,1406.88 237.24,1406.88 237.249,1406.88 237.259,1406.88 237.268,1406.88 237.277,1406.88 237.286,1406.88 237.295,1406.88 237.304,1406.88 237.314,1406.88 237.323,1406.88 237.332,1406.88 237.341,1406.88 237.35,1406.88 237.36,1406.88 237.369,1406.88 237.378,1406.88 237.387,1406.88 237.396,1406.88 237.406,1406.88 237.415,1406.88 237.424,1406.88 237.433,1406.88 237.442,1406.88 237.452,1406.88 237.461,1406.88 237.47,1406.88 237.479,1406.88 237.488,1406.88 237.497,1406.88 237.507,1406.88 237.516,1406.88 237.525,1406.88 237.534,1406.88 237.543,1406.88 237.553,1406.88 237.562,1406.88 237.571,1406.88 237.58,1406.88 237.589,1406.88 237.599,1406.88 237.608,1406.88 237.617,1406.88 237.626,1406.88 237.635,1406.88 237.644,1406.88 237.654,1406.88 237.663,1406.88 237.672,1406.88 237.681,1406.88 237.69,1406.88 237.7,1406.88 237.709,1406.88 237.718,1406.88 237.727,1406.88 237.736,1406.88 237.746,1406.88 237.755,1406.88 237.764,1406.88 237.773,1406.88 237.782,1406.88 237.792,1406.88 237.801,1406.88 237.81,1406.88 237.819,1406.88 237.828,1406.88 237.837,1406.88 237.847,1406.88 237.856,1406.88 237.865,1406.88 237.874,1406.88 237.883,1406.88 237.893,1406.88 237.902,1406.88 237.911,1406.88 237.92,1406.88 237.929,1406.88 237.939,1406.88 237.948,1406.88 237.957,1406.88 237.966,1406.88 237.975,1406.88 237.985,1406.88 237.994,1406.88 238.003,1406.88 238.012,1406.88 238.021,1406.88 238.03,1406.88 238.04,1406.88 238.049,1406.88 238.058,1406.88 238.067,1406.88 238.076,1406.88 238.086,1406.88 238.095,1406.88 238.104,1406.88 238.113,1406.88 238.122,1406.88 238.132,1406.88 238.141,1406.88 238.15,1406.88 238.159,1406.88 238.168,1406.88 238.177,1406.88 238.187,1406.88 238.196,1406.88 238.205,1406.88 238.214,1406.88 238.223,1406.88 238.233,1406.88 238.242,1406.88 238.251,1406.88 238.26,1406.88 238.269,1406.88 238.279,1406.88 238.288,1406.88 238.297,1406.88 238.306,1406.88 238.315,1406.88 238.325,1406.88 238.334,1406.88 238.343,1406.88 238.352,1406.88 238.361,1406.88 238.37,1406.88 238.38,1406.88 238.389,1406.88 238.398,1406.88 238.407,1406.88 238.416,1406.88 238.426,1406.88 238.435,1406.88 238.444,1406.88 238.453,1406.88 238.462,1406.88 238.472,1406.88 238.481,1406.88 238.49,1406.88 238.499,1406.88 238.508,1406.88 238.517,1406.88 238.527,1406.88 238.536,1406.88 238.545,1406.88 238.554,1406.88 238.563,1406.88 238.573,1406.88 238.582,1406.88 238.591,1406.88 238.6,1406.88 238.609,1406.88 238.619,1406.88 238.628,1406.88 238.637,1406.88 238.646,1406.88 238.655,1406.88 238.665,1406.88 238.674,1406.88 238.683,1406.88 238.692,1406.88 238.701,1406.88 238.71,1406.88 238.72,1406.88 238.729,1406.88 238.738,1406.88 238.747,1406.88 238.756,1406.88 238.766,1406.88 238.775,1406.88 238.784,1406.88 238.793,1406.88 238.802,1406.88 238.812,1406.88 238.821,1406.88 238.83,1406.88 238.839,1406.88 238.848,1406.88 238.857,1406.88 238.867,1406.88 238.876,1406.88 238.885,1406.88 238.894,1406.88 238.903,1406.88 238.913,1406.88 238.922,1406.88 238.931,1406.88 238.94,1406.88 238.949,1406.88 238.959,1406.88 238.968,1406.88 238.977,1406.88 238.986,1406.88 238.995,1406.88 239.005,1406.88 239.014,1406.88 239.023,1406.88 239.032,1406.88 239.041,1406.88 239.05,1406.88 239.06,1406.88 239.069,1406.88 239.078,1406.88 239.087,1406.88 239.096,1406.88 239.106,1406.88 239.115,1406.88 239.124,1406.88 239.133,1406.88 239.142,1406.88 239.152,1406.88 239.161,1406.88 239.17,1406.88 239.179,1406.88 239.188,1406.88 239.197,1406.88 239.207,1406.88 239.216,1406.88 239.225,1406.88 239.234,1406.88 239.243,1406.88 239.253,1406.88 239.262,1406.88 239.271,1406.88 239.28,1406.88 239.289,1406.88 239.299,1406.88 239.308,1406.88 239.317,1406.88 239.326,1406.88 239.335,1406.88 239.345,1406.88 239.354,1406.88 239.363,1406.88 239.372,1406.88 239.381,1406.88 239.39,1406.88 239.4,1406.88 239.409,1406.88 239.418,1406.88 239.427,1406.88 239.436,1406.88 239.446,1406.88 239.455,1406.88 239.464,1406.88 239.473,1406.88 239.482,1406.88 239.492,1406.88 239.501,1406.88 239.51,1406.88 239.519,1406.88 239.528,1406.88 239.537,1406.88 239.547,1406.88 239.556,1406.88 239.565,1406.88 239.574,1406.88 239.583,1406.88 239.593,1406.88 239.602,1406.88 239.611,1406.88 239.62,1406.88 239.629,1406.88 239.639,1406.88 239.648,1406.88 239.657,1406.88 239.666,1406.88 239.675,1406.88 239.685,1406.88 239.694,1406.88 239.703,1406.88 239.712,1406.88 239.721,1406.88 239.73,1406.88 239.74,1406.88 239.749,1406.88 239.758,1406.88 239.767,1406.88 239.776,1406.88 239.786,1406.88 239.795,1406.88 239.804,1406.88 239.813,1406.88 239.822,1406.88 239.832,1406.88 239.841,1406.88 239.85,1406.88 239.859,1406.88 239.868,1406.88 239.877,1406.88 239.887,1406.88 239.896,1406.88 239.905,1406.88 239.914,1406.88 239.923,1406.88 239.933,1406.88 239.942,1406.88 239.951,1406.88 239.96,1406.88 239.969,1406.88 239.979,1406.88 239.988,1406.88 239.997,1406.88 240.006,1406.88 240.015,1406.88 240.025,1406.88 240.034,1406.88 240.043,1406.88 240.052,1406.88 240.061,1406.88 240.07,1406.88 240.08,1406.88 240.089,1406.88 240.098,1406.88 240.107,1406.88 240.116,1406.88 240.126,1406.88 240.135,1406.88 240.144,1406.88 240.153,1406.88 240.162,1406.88 240.172,1406.88 240.181,1406.88 240.19,1406.88 240.199,1406.88 240.208,1406.88 240.217,1406.88 240.227,1406.88 240.236,1406.88 240.245,1406.88 240.254,1406.88 240.263,1406.88 240.273,1406.88 240.282,1406.88 240.291,1406.88 240.3,1406.88 240.309,1406.88 240.319,1406.88 240.328,1406.88 240.337,1406.88 240.346,1406.88 240.355,1406.88 240.365,1406.88 240.374,1406.88 240.383,1406.88 240.392,1406.88 240.401,1406.88 240.41,1406.88 240.42,1406.88 240.429,1406.88 240.438,1406.88 240.447,1406.88 240.456,1406.88 240.466,1406.88 240.475,1406.88 240.484,1406.88 240.493,1406.88 240.502,1406.88 240.512,1406.88 240.521,1406.88 240.53,1406.88 240.539,1406.88 240.548,1406.88 240.558,1406.88 240.567,1406.88 240.576,1406.88 240.585,1406.88 240.594,1406.88 240.603,1406.88 240.613,1406.88 240.622,1406.88 240.631,1406.88 240.64,1406.88 240.649,1406.88 240.659,1406.88 240.668,1406.88 240.677,1406.88 240.686,1406.88 240.695,1406.88 240.705,1406.88 240.714,1406.88 240.723,1406.88 240.732,1406.88 240.741,1406.88 240.75,1406.88 240.76,1406.88 240.769,1406.88 240.778,1406.88 240.787,1406.88 240.796,1406.88 240.806,1406.88 240.815,1406.88 240.824,1406.88 240.833,1406.88 240.842,1406.88 240.852,1406.88 240.861,1406.88 240.87,1406.88 240.879,1406.88 240.888,1406.88 240.898,1406.88 240.907,1406.88 240.916,1406.88 240.925,1406.88 240.934,1406.88 240.943,1406.88 240.953,1406.88 240.962,1406.88 240.971,1406.88 240.98,1406.88 240.989,1406.88 240.999,1406.88 241.008,1406.88 241.017,1406.88 241.026,1406.88 241.035,1406.88 241.045,1406.88 241.054,1406.88 241.063,1406.88 241.072,1406.88 241.081,1406.88 241.09,1406.88 241.1,1406.88 241.109,1406.88 241.118,1406.88 241.127,1406.88 241.136,1406.88 241.146,1406.88 241.155,1406.88 241.164,1406.88 241.173,1406.88 241.182,1406.88 241.192,1406.88 241.201,1406.88 241.21,1406.88 241.219,1406.88 241.228,1406.88 241.238,1406.88 241.247,1406.88 241.256,1406.88 241.265,1406.88 241.274,1406.88 241.283,1406.88 241.293,1406.88 241.302,1406.88 241.311,1406.88 241.32,1406.88 241.329,1406.88 241.339,1406.88 241.348,1406.88 241.357,1406.88 241.366,1406.88 241.375,1406.88 241.385,1406.88 241.394,1406.88 241.403,1406.88 241.412,1406.88 241.421,1406.88 241.43,1406.88 241.44,1406.88 241.449,1406.88 241.458,1406.88 241.467,1406.88 241.476,1406.88 241.486,1406.88 241.495,1406.88 241.504,1406.88 241.513,1406.88 241.522,1406.88 241.532,1406.88 241.541,1406.88 241.55,1406.88 241.559,1406.88 241.568,1406.88 241.578,1406.88 241.587,1406.88 241.596,1406.88 241.605,1406.88 241.614,1406.88 241.623,1406.88 241.633,1406.88 241.642,1406.88 241.651,1406.88 241.66,1406.88 241.669,1406.88 241.679,1406.88 241.688,1406.88 241.697,1406.88 241.706,1406.88 241.715,1406.88 241.725,1406.88 241.734,1406.88 241.743,1406.88 241.752,1406.88 241.761,1406.88 241.77,1406.88 241.78,1406.88 241.789,1406.88 241.798,1406.88 241.807,1406.88 241.816,1406.88 241.826,1406.88 241.835,1406.88 241.844,1406.88 241.853,1406.88 241.862,1406.88 241.872,1406.88 241.881,1406.88 241.89,1406.88 241.899,1406.88 241.908,1406.88 241.918,1406.88 241.927,1406.88 241.936,1406.88 241.945,1406.88 241.954,1406.88 241.963,1406.88 241.973,1406.88 241.982,1406.88 241.991,1406.88 242,1406.88 242.009,1406.88 242.019,1406.88 242.028,1406.88 242.037,1406.88 242.046,1406.88 242.055,1406.88 242.065,1406.88 242.074,1406.88 242.083,1406.88 242.092,1406.88 242.101,1406.88 242.11,1406.88 242.12,1406.88 242.129,1406.88 242.138,1406.88 242.147,1406.88 242.156,1406.88 242.166,1406.88 242.175,1406.88 242.184,1406.88 242.193,1406.88 242.202,1406.88 242.212,1406.88 242.221,1406.88 242.23,1406.88 242.239,1406.88 242.248,1406.88 242.258,1406.88 242.267,1406.88 242.276,1406.88 242.285,1406.88 242.294,1406.88 242.303,1406.88 242.313,1406.88 242.322,1406.88 242.331,1406.88 242.34,1406.88 242.349,1406.88 242.359,1406.88 242.368,1406.88 242.377,1406.88 242.386,1406.88 242.395,1406.88 242.405,1406.88 242.414,1406.88 242.423,1406.88 242.432,1406.88 242.441,1406.88 242.45,1406.88 242.46,1406.88 242.469,1406.88 242.478,1406.88 242.487,1406.88 242.496,1406.88 242.506,1406.88 242.515,1406.88 242.524,1406.88 242.533,1406.88 242.542,1406.88 242.552,1406.88 242.561,1406.88 242.57,1406.88 242.579,1406.88 242.588,1406.88 242.598,1406.88 242.607,1406.88 242.616,1406.88 242.625,1406.88 242.634,1406.88 242.643,1406.88 242.653,1406.88 242.662,1406.88 242.671,1406.88 242.68,1406.88 242.689,1406.88 242.699,1406.88 242.708,1406.88 242.717,1406.88 242.726,1406.88 242.735,1406.88 242.745,1406.88 242.754,1406.88 242.763,1406.88 242.772,1406.88 242.781,1406.88 242.79,1406.88 242.8,1406.88 242.809,1406.88 242.818,1406.88 242.827,1406.88 242.836,1406.88 242.846,1406.88 242.855,1406.88 242.864,1406.88 242.873,1406.88 242.882,1406.88 242.892,1406.88 242.901,1406.88 242.91,1406.88 242.919,1406.88 242.928,1406.88 242.938,1406.88 242.947,1406.88 242.956,1406.88 242.965,1406.88 242.974,1406.88 242.983,1406.88 242.993,1406.88 243.002,1406.88 243.011,1406.88 243.02,1406.88 243.029,1406.88 243.039,1406.88 243.048,1406.88 243.057,1406.88 243.066,1406.88 243.075,1406.88 243.085,1406.88 243.094,1406.88 243.103,1406.88 243.112,1406.88 243.121,1406.88 243.131,1406.88 243.14,1406.88 243.149,1406.88 243.158,1406.88 243.167,1406.88 243.176,1406.88 243.186,1406.88 243.195,1406.88 243.204,1406.88 243.213,1406.88 243.222,1406.88 243.232,1406.88 243.241,1406.88 243.25,1406.88 243.259,1406.88 243.268,1406.88 243.278,1406.88 243.287,1406.88 243.296,1406.88 243.305,1406.88 243.314,1406.88 243.323,1406.88 243.333,1406.88 243.342,1406.88 243.351,1406.88 243.36,1406.88 243.369,1406.88 243.379,1406.88 243.388,1406.88 243.397,1406.88 243.406,1406.88 243.415,1406.88 243.425,1406.88 243.434,1406.88 243.443,1406.88 243.452,1406.88 243.461,1406.88 243.471,1406.88 243.48,1406.88 243.489,1406.88 243.498,1406.88 243.507,1406.88 243.516,1406.88 243.526,1406.88 243.535,1406.88 243.544,1406.88 243.553,1406.88 243.562,1406.88 243.572,1406.88 243.581,1406.88 243.59,1406.88 243.599,1406.88 243.608,1406.88 243.618,1406.88 243.627,1406.88 243.636,1406.88 243.645,1406.88 243.654,1406.88 243.663,1406.88 243.673,1406.88 243.682,1406.88 243.691,1406.88 243.7,1406.88 243.709,1406.88 243.719,1406.88 243.728,1406.88 243.737,1406.88 243.746,1406.88 243.755,1406.88 243.765,1406.88 243.774,1406.88 243.783,1406.88 243.792,1406.88 243.801,1406.88 243.811,1406.88 243.82,1406.88 243.829,1406.88 243.838,1406.88 243.847,1406.88 243.856,1406.88 243.866,1406.88 243.875,1406.88 243.884,1406.88 243.893,1406.88 243.902,1406.88 243.912,1406.88 243.921,1406.88 243.93,1406.88 243.939,1406.88 243.948,1406.88 243.958,1406.88 243.967,1406.88 243.976,1406.88 243.985,1406.88 243.994,1406.88 244.003,1406.88 244.013,1406.88 244.022,1406.88 244.031,1406.88 244.04,1406.88 244.049,1406.88 244.059,1406.88 244.068,1406.88 244.077,1406.88 244.086,1406.88 244.095,1406.88 244.105,1406.88 244.114,1406.88 244.123,1406.88 244.132,1406.88 244.141,1406.88 244.151,1406.88 244.16,1406.88 244.169,1406.88 244.178,1406.88 244.187,1406.88 244.196,1406.88 244.206,1406.88 244.215,1406.88 244.224,1406.88 244.233,1406.88 244.242,1406.88 244.252,1406.88 244.261,1406.88 244.27,1406.88 244.279,1406.88 244.288,1406.88 244.298,1406.88 244.307,1406.88 244.316,1406.88 244.325,1406.88 244.334,1406.88 244.343,1406.88 244.353,1406.88 244.362,1406.88 244.371,1406.88 244.38,1406.88 244.389,1406.88 244.399,1406.88 244.408,1406.88 244.417,1406.88 244.426,1406.88 244.435,1406.88 244.445,1406.88 244.454,1406.88 244.463,1406.88 244.472,1406.88 244.481,1406.88 244.491,1406.88 244.5,1406.88 244.509,1406.88 244.518,1406.88 244.527,1406.88 244.536,1406.88 244.546,1406.88 244.555,1406.88 244.564,1406.88 244.573,1406.88 244.582,1406.88 244.592,1406.88 244.601,1406.88 244.61,1406.88 244.619,1406.88 244.628,1406.88 244.638,1406.88 244.647,1406.88 244.656,1406.88 244.665,1406.88 244.674,1406.88 244.683,1406.88 244.693,1406.88 244.702,1406.88 244.711,1406.88 244.72,1406.88 244.729,1406.88 244.739,1406.88 244.748,1406.88 244.757,1406.88 244.766,1406.88 244.775,1406.88 244.785,1406.88 244.794,1406.88 244.803,1406.88 244.812,1406.88 244.821,1406.88 244.831,1406.88 244.84,1406.88 244.849,1406.88 244.858,1406.88 244.867,1406.88 244.876,1406.88 244.886,1406.88 244.895,1406.88 244.904,1406.88 244.913,1406.88 244.922,1406.88 244.932,1406.88 244.941,1406.88 244.95,1406.88 244.959,1406.88 244.968,1406.88 244.978,1406.88 244.987,1406.88 244.996,1406.88 245.005,1406.88 245.014,1406.88 245.023,1406.88 245.033,1406.88 245.042,1406.88 245.051,1406.88 245.06,1406.88 245.069,1406.88 245.079,1406.88 245.088,1406.88 245.097,1406.88 245.106,1406.88 245.115,1406.88 245.125,1406.88 245.134,1406.88 245.143,1406.88 245.152,1406.88 245.161,1406.88 245.171,1406.88 245.18,1406.88 245.189,1406.88 245.198,1406.88 245.207,1406.88 245.216,1406.88 245.226,1406.88 245.235,1406.88 245.244,1406.88 245.253,1406.88 245.262,1406.88 245.272,1406.88 245.281,1406.88 245.29,1406.88 245.299,1406.88 245.308,1406.88 245.318,1406.88 245.327,1406.88 245.336,1406.88 245.345,1406.88 245.354,1406.88 245.364,1406.88 245.373,1406.88 245.382,1406.88 245.391,1406.88 245.4,1406.88 245.409,1406.88 245.419,1406.88 245.428,1406.88 245.437,1406.88 245.446,1406.88 245.455,1406.88 245.465,1406.88 245.474,1406.88 245.483,1406.88 245.492,1406.88 245.501,1406.88 245.511,1406.88 245.52,1406.88 245.529,1406.88 245.538,1406.88 245.547,1406.88 245.556,1406.88 245.566,1406.88 245.575,1406.88 245.584,1406.88 245.593,1406.88 245.602,1406.88 245.612,1406.88 245.621,1406.88 245.63,1406.88 245.639,1406.88 245.648,1406.88 245.658,1406.88 245.667,1406.88 245.676,1406.88 245.685,1406.88 245.694,1406.88 245.704,1406.88 245.713,1406.88 245.722,1406.88 245.731,1406.88 245.74,1406.88 245.749,1406.88 245.759,1406.88 245.768,1406.88 245.777,1406.88 245.786,1406.88 245.795,1406.88 245.805,1406.88 245.814,1406.88 245.823,1406.88 245.832,1406.88 245.841,1406.88 245.851,1406.88 245.86,1406.88 245.869,1406.88 245.878,1406.88 245.887,1406.88 245.896,1406.88 245.906,1406.88 245.915,1406.88 245.924,1406.88 245.933,1406.88 245.942,1406.88 245.952,1406.88 245.961,1406.88 245.97,1406.88 245.979,1406.88 245.988,1406.88 245.998,1406.88 246.007,1406.88 246.016,1406.88 246.025,1406.88 246.034,1406.88 246.044,1406.88 246.053,1406.88 246.062,1406.88 246.071,1406.88 246.08,1406.88 246.089,1406.88 246.099,1406.88 246.108,1406.88 246.117,1406.88 246.126,1406.88 246.135,1406.88 246.145,1406.88 246.154,1406.88 246.163,1406.88 246.172,1406.88 246.181,1406.88 246.191,1406.88 246.2,1406.88 246.209,1406.88 246.218,1406.88 246.227,1406.88 246.236,1406.88 246.246,1406.88 246.255,1406.88 246.264,1406.88 246.273,1406.88 246.282,1406.88 246.292,1406.88 246.301,1406.88 246.31,1406.88 246.319,1406.88 246.328,1406.88 246.338,1406.88 246.347,1406.88 246.356,1406.88 246.365,1406.88 246.374,1406.88 246.384,1406.88 246.393,1406.88 246.402,1406.88 246.411,1406.88 246.42,1406.88 246.429,1406.88 246.439,1406.88 246.448,1406.88 246.457,1406.88 246.466,1406.88 246.475,1406.88 246.485,1406.88 246.494,1406.88 246.503,1406.88 246.512,1406.88 246.521,1406.88 246.531,1406.88 246.54,1406.88 246.549,1406.88 246.558,1406.88 246.567,1406.88 246.576,1406.88 246.586,1406.88 246.595,1406.88 246.604,1406.88 246.613,1406.88 246.622,1406.88 246.632,1406.88 246.641,1406.88 246.65,1406.88 246.659,1406.88 246.668,1406.88 246.678,1406.88 246.687,1406.88 246.696,1406.88 246.705,1406.88 246.714,1406.88 246.724,1406.88 246.733,1406.88 246.742,1406.88 246.751,1406.88 246.76,1406.88 246.769,1406.88 246.779,1406.88 246.788,1406.88 246.797,1406.88 246.806,1406.88 246.815,1406.88 246.825,1406.88 246.834,1406.88 246.843,1406.88 246.852,1406.88 246.861,1406.88 246.871,1406.88 246.88,1406.88 246.889,1406.88 246.898,1406.88 246.907,1406.88 246.916,1406.88 246.926,1406.88 246.935,1406.88 246.944,1406.88 246.953,1406.88 246.962,1406.88 246.972,1406.88 246.981,1406.88 246.99,1406.88 246.999,1406.88 247.008,1406.88 247.018,1406.88 247.027,1406.88 247.036,1406.88 247.045,1406.88 247.054,1406.88 247.064,1406.88 247.073,1406.88 247.082,1406.88 247.091,1406.88 247.1,1406.88 247.109,1406.88 247.119,1406.88 247.128,1406.88 247.137,1406.88 247.146,1406.88 247.155,1406.88 247.165,1406.88 247.174,1406.88 247.183,1406.88 247.192,1406.88 247.201,1406.88 247.211,1406.88 247.22,1406.88 247.229,1406.88 247.238,1406.88 247.247,1406.88 247.256,1406.88 247.266,1406.88 247.275,1406.88 247.284,1406.88 247.293,1406.88 247.302,1406.88 247.312,1406.88 247.321,1406.88 247.33,1406.88 247.339,1406.88 247.348,1406.88 247.358,1406.88 247.367,1406.88 247.376,1406.88 247.385,1406.88 247.394,1406.88 247.404,1406.88 247.413,1406.88 247.422,1406.88 247.431,1406.88 247.44,1406.88 247.449,1406.88 247.459,1406.88 247.468,1406.88 247.477,1406.88 247.486,1406.88 247.495,1406.88 247.505,1406.88 247.514,1406.88 247.523,1406.88 247.532,1406.88 247.541,1406.88 247.551,1406.88 247.56,1406.88 247.569,1406.88 247.578,1406.88 247.587,1406.88 247.596,1406.88 247.606,1406.88 247.615,1406.88 247.624,1406.88 247.633,1406.88 247.642,1406.88 247.652,1406.88 247.661,1406.88 247.67,1406.88 247.679,1406.88 247.688,1406.88 247.698,1406.88 247.707,1406.88 247.716,1406.88 247.725,1406.88 247.734,1406.88 247.744,1406.88 247.753,1406.88 247.762,1406.88 247.771,1406.88 247.78,1406.88 247.789,1406.88 247.799,1406.88 247.808,1406.88 247.817,1406.88 247.826,1406.88 247.835,1406.88 247.845,1406.88 247.854,1406.88 247.863,1406.88 247.872,1406.88 247.881,1406.88 247.891,1406.88 247.9,1406.88 247.909,1406.88 247.918,1406.88 247.927,1406.88 247.937,1406.88 247.946,1406.88 247.955,1406.88 247.964,1406.88 247.973,1406.88 247.982,1406.88 247.992,1406.88 248.001,1406.88 248.01,1406.88 248.019,1406.88 248.028,1406.88 248.038,1406.88 248.047,1406.88 248.056,1406.88 248.065,1406.88 248.074,1406.88 248.084,1406.88 248.093,1406.88 248.102,1406.88 248.111,1406.88 248.12,1406.88 248.129,1406.88 248.139,1406.88 248.148,1406.88 248.157,1406.88 248.166,1406.88 248.175,1406.88 248.185,1406.88 248.194,1406.88 248.203,1406.88 248.212,1406.88 248.221,1406.88 248.231,1406.88 248.24,1406.88 248.249,1406.88 248.258,1406.88 248.267,1406.88 248.277,1406.88 248.286,1406.88 248.295,1406.88 248.304,1406.88 248.313,1406.88 248.322,1406.88 248.332,1406.88 248.341,1406.88 248.35,1406.88 248.359,1406.88 248.368,1406.88 248.378,1406.88 248.387,1406.88 248.396,1406.88 248.405,1406.88 248.414,1406.88 248.424,1406.88 248.433,1406.88 248.442,1406.88 248.451,1406.88 248.46,1406.88 248.469,1406.88 248.479,1406.88 248.488,1406.88 248.497,1406.88 248.506,1406.88 248.515,1406.88 248.525,1406.88 248.534,1406.88 248.543,1406.88 248.552,1406.88 248.561,1406.88 248.571,1406.88 248.58,1406.88 248.589,1406.88 248.598,1406.88 248.607,1406.88 248.617,1406.88 248.626,1406.88 248.635,1406.88 248.644,1406.88 248.653,1406.88 248.662,1406.88 248.672,1406.88 248.681,1406.88 248.69,1406.88 248.699,1406.88 248.708,1406.88 248.718,1406.88 248.727,1406.88 248.736,1406.88 248.745,1406.88 248.754,1406.88 248.764,1406.88 248.773,1406.88 248.782,1406.88 248.791,1406.88 248.8,1406.88 248.809,1406.88 248.819,1406.88 248.828,1406.88 248.837,1406.88 248.846,1406.88 248.855,1406.88 248.865,1406.88 248.874,1406.88 248.883,1406.88 248.892,1406.88 248.901,1406.88 248.911,1406.88 248.92,1406.88 248.929,1406.88 248.938,1406.88 248.947,1406.88 248.957,1406.88 248.966,1406.88 248.975,1406.88 248.984,1406.88 248.993,1406.88 249.002,1406.88 249.012,1406.88 249.021,1406.88 249.03,1406.88 249.039,1406.88 249.048,1406.88 249.058,1406.88 249.067,1406.88 249.076,1406.88 249.085,1406.88 249.094,1406.88 249.104,1406.88 249.113,1406.88 249.122,1406.88 249.131,1406.88 249.14,1406.88 249.149,1406.88 249.159,1406.88 249.168,1406.88 249.177,1406.88 249.186,1406.88 249.195,1406.88 249.205,1406.88 249.214,1406.88 249.223,1406.88 249.232,1406.88 249.241,1406.88 249.251,1406.88 249.26,1406.88 249.269,1406.88 249.278,1406.88 249.287,1406.88 249.297,1406.88 249.306,1406.88 249.315,1406.88 249.324,1406.88 249.333,1406.88 249.342,1406.88 249.352,1406.88 249.361,1406.88 249.37,1406.88 249.379,1406.88 249.388,1406.88 249.398,1406.88 249.407,1406.88 249.416,1406.88 249.425,1406.88 249.434,1406.88 249.444,1406.88 249.453,1406.88 249.462,1406.88 249.471,1406.88 249.48,1406.88 249.489,1406.88 249.499,1406.88 249.508,1406.88 249.517,1406.88 249.526,1406.88 249.535,1406.88 249.545,1406.88 249.554,1406.88 249.563,1406.88 249.572,1406.88 249.581,1406.88 249.591,1406.88 249.6,1406.88 249.609,1406.88 249.618,1406.88 249.627,1406.88 249.637,1406.88 249.646,1406.88 249.655,1406.88 249.664,1406.88 249.673,1406.88 249.682,1406.88 249.692,1406.88 249.701,1406.88 249.71,1406.88 249.719,1406.88 249.728,1406.88 249.738,1406.88 249.747,1406.88 249.756,1406.88 249.765,1406.88 249.774,1406.88 249.784,1406.88 249.793,1406.88 249.802,1406.88 249.811,1406.88 249.82,1406.88 249.829,1406.88 249.839,1406.88 249.848,1406.88 249.857,1406.88 249.866,1406.88 249.875,1406.88 249.885,1406.88 249.894,1406.88 249.903,1406.88 249.912,1406.88 249.921,1406.88 249.931,1406.88 249.94,1406.88 249.949,1406.88 249.958,1406.88 249.967,1406.88 249.977,1406.88 249.986,1406.88 249.995,1406.88 250.004,1406.88 250.013,1406.88 250.022,1406.88 250.032,1406.88 250.041,1406.88 250.05,1406.88 250.059,1406.88 250.068,1406.88 250.078,1406.88 250.087,1406.88 250.096,1406.88 250.105,1406.88 250.114,1406.88 250.124,1406.88 250.133,1406.88 250.142,1406.88 250.151,1406.88 250.16,1406.88 250.169,1406.88 250.179,1406.88 250.188,1406.88 250.197,1406.88 250.206,1406.88 250.215,1406.88 250.225,1406.88 250.234,1406.88 250.243,1406.88 250.252,1406.88 250.261,1406.88 250.271,1406.88 250.28,1406.88 250.289,1406.88 250.298,1406.88 250.307,1406.88 250.317,1406.88 250.326,1406.88 250.335,1406.88 250.344,1406.88 250.353,1406.88 250.362,1406.88 250.372,1406.88 250.381,1406.88 250.39,1406.88 250.399,1406.88 250.408,1406.88 250.418,1406.88 250.427,1406.88 250.436,1406.88 250.445,1406.88 250.454,1406.88 250.464,1406.88 250.473,1406.88 250.482,1406.88 250.491,1406.88 250.5,1406.88 250.51,1406.88 250.519,1406.88 250.528,1406.88 250.537,1406.88 250.546,1406.88 250.555,1406.88 250.565,1406.88 250.574,1406.88 250.583,1406.88 250.592,1406.88 250.601,1406.88 250.611,1406.88 250.62,1406.88 250.629,1406.88 250.638,1406.88 250.647,1406.88 250.657,1406.88 250.666,1406.88 250.675,1406.88 250.684,1406.88 250.693,1406.88 250.702,1406.88 250.712,1406.88 250.721,1406.88 250.73,1406.88 250.739,1406.88 250.748,1406.88 250.758,1406.88 250.767,1406.88 250.776,1406.88 250.785,1406.88 250.794,1406.88 250.804,1406.88 250.813,1406.88 250.822,1406.88 250.831,1406.88 250.84,1406.88 250.85,1406.88 250.859,1406.88 250.868,1406.88 250.877,1406.88 250.886,1406.88 250.895,1406.88 250.905,1406.88 250.914,1406.88 250.923,1406.88 250.932,1406.88 250.941,1406.88 250.951,1406.88 250.96,1406.88 250.969,1406.88 250.978,1406.88 250.987,1406.88 250.997,1406.88 251.006,1406.88 251.015,1406.88 251.024,1406.88 251.033,1406.88 251.042,1406.88 251.052,1406.88 251.061,1406.88 251.07,1406.88 251.079,1406.88 251.088,1406.88 251.098,1406.88 251.107,1406.88 251.116,1406.88 251.125,1406.88 251.134,1406.88 251.144,1406.88 251.153,1406.88 251.162,1406.88 251.171,1406.88 251.18,1406.88 251.19,1406.88 251.199,1406.88 251.208,1406.88 251.217,1406.88 251.226,1406.88 251.235,1406.88 251.245,1406.88 251.254,1406.88 251.263,1406.88 251.272,1406.88 251.281,1406.88 251.291,1406.88 251.3,1406.88 251.309,1406.88 251.318,1406.88 251.327,1406.88 251.337,1406.88 251.346,1406.88 251.355,1406.88 251.364,1406.88 251.373,1406.88 251.382,1406.88 251.392,1406.88 251.401,1406.88 251.41,1406.88 251.419,1406.88 251.428,1406.88 251.438,1406.88 251.447,1406.88 251.456,1406.88 251.465,1406.88 251.474,1406.88 251.484,1406.88 251.493,1406.88 251.502,1406.88 251.511,1406.88 251.52,1406.88 251.53,1406.88 251.539,1406.88 251.548,1406.88 251.557,1406.88 251.566,1406.88 251.575,1406.88 251.585,1406.88 251.594,1406.88 251.603,1406.88 251.612,1406.88 251.621,1406.88 251.631,1406.88 251.64,1406.88 251.649,1406.88 251.658,1406.88 251.667,1406.88 251.677,1406.88 251.686,1406.88 251.695,1406.88 251.704,1406.88 251.713,1406.88 251.722,1406.88 251.732,1406.88 251.741,1406.88 251.75,1406.88 251.759,1406.88 251.768,1406.88 251.778,1406.88 251.787,1406.88 251.796,1406.88 251.805,1406.88 251.814,1406.88 251.824,1406.88 251.833,1406.88 251.842,1406.88 251.851,1406.88 251.86,1406.88 251.87,1406.88 251.879,1406.88 251.888,1406.88 251.897,1406.88 251.906,1406.88 251.915,1406.88 251.925,1406.88 251.934,1406.88 251.943,1406.88 251.952,1406.88 251.961,1406.88 251.971,1406.88 251.98,1406.88 251.989,1406.88 251.998,1406.88 252.007,1406.88 252.017,1406.88 252.026,1406.88 252.035,1406.88 252.044,1406.88 252.053,1406.88 252.062,1406.88 252.072,1406.88 252.081,1406.88 252.09,1406.88 252.099,1406.88 252.108,1406.88 252.118,1406.88 252.127,1406.88 252.136,1406.88 252.145,1406.88 252.154,1406.88 252.164,1406.88 252.173,1406.88 252.182,1406.88 252.191,1406.88 252.2,1406.88 252.21,1406.88 252.219,1406.88 252.228,1406.88 252.237,1406.88 252.246,1406.88 252.255,1406.88 252.265,1406.88 252.274,1406.88 252.283,1406.88 252.292,1406.88 252.301,1406.88 252.311,1406.88 252.32,1406.88 252.329,1406.88 252.338,1406.88 252.347,1406.88 252.357,1406.88 252.366,1406.88 252.375,1406.88 252.384,1406.88 252.393,1406.88 252.402,1406.88 252.412,1406.88 252.421,1406.88 252.43,1406.88 252.439,1406.88 252.448,1406.88 252.458,1406.88 252.467,1406.88 252.476,1406.88 252.485,1406.88 252.494,1406.88 252.504,1406.88 252.513,1406.88 252.522,1406.88 252.531,1406.88 252.54,1406.88 252.55,1406.88 252.559,1406.88 252.568,1406.88 252.577,1406.88 252.586,1406.88 252.595,1406.88 252.605,1406.88 252.614,1406.88 252.623,1406.88 252.632,1406.88 252.641,1406.88 252.651,1406.88 252.66,1406.88 252.669,1406.88 252.678,1406.88 252.687,1406.88 252.697,1406.88 252.706,1406.88 252.715,1406.88 252.724,1406.88 252.733,1406.88 252.743,1406.88 252.752,1406.88 252.761,1406.88 252.77,1406.88 252.779,1406.88 252.788,1406.88 252.798,1406.88 252.807,1406.88 252.816,1406.88 252.825,1406.88 252.834,1406.88 252.844,1406.88 252.853,1406.88 252.862,1406.88 252.871,1406.88 252.88,1406.88 252.89,1406.88 252.899,1406.88 252.908,1406.88 252.917,1406.88 252.926,1406.88 252.935,1406.88 252.945,1406.88 252.954,1406.88 252.963,1406.88 252.972,1406.88 252.981,1406.88 252.991,1406.88 253,1406.88 253.009,1406.88 253.018,1406.88 253.027,1406.88 253.037,1406.88 253.046,1406.88 253.055,1406.88 253.064,1406.88 253.073,1406.88 253.083,1406.88 253.092,1406.88 253.101,1406.88 253.11,1406.88 253.119,1406.88 253.128,1406.88 253.138,1406.88 253.147,1406.88 253.156,1406.88 253.165,1406.88 253.174,1406.88 253.184,1406.88 253.193,1406.88 253.202,1406.88 253.211,1406.88 253.22,1406.88 253.23,1406.88 253.239,1406.88 253.248,1406.88 253.257,1406.88 253.266,1406.88 253.275,1406.88 253.285,1406.88 253.294,1406.88 253.303,1406.88 253.312,1406.88 253.321,1406.88 253.331,1406.88 253.34,1406.88 253.349,1406.88 253.358,1406.88 253.367,1406.88 253.377,1406.88 253.386,1406.88 253.395,1406.88 253.404,1406.88 253.413,1406.88 253.423,1406.88 253.432,1406.88 253.441,1406.88 253.45,1406.88 253.459,1406.88 253.468,1406.88 253.478,1406.88 253.487,1406.88 253.496,1406.88 253.505,1406.88 253.514,1406.88 253.524,1406.88 253.533,1406.88 253.542,1406.88 253.551,1406.88 253.56,1406.88 253.57,1406.88 253.579,1406.88 253.588,1406.88 253.597,1406.88 253.606,1406.88 253.615,1406.88 253.625,1406.88 253.634,1406.88 253.643,1406.88 253.652,1406.88 253.661,1406.88 253.671,1406.88 253.68,1406.88 253.689,1406.88 253.698,1406.88 253.707,1406.88 253.717,1406.88 253.726,1406.88 253.735,1406.88 253.744,1406.88 253.753,1406.88 253.763,1406.88 253.772,1406.88 253.781,1406.88 253.79,1406.88 253.799,1406.88 253.808,1406.88 253.818,1406.88 253.827,1406.88 253.836,1406.88 253.845,1406.88 253.854,1406.88 253.864,1406.88 253.873,1406.88 253.882,1406.88 253.891,1406.88 253.9,1406.88 253.91,1406.88 253.919,1406.88 253.928,1406.88 253.937,1406.88 253.946,1406.88 253.955,1406.88 253.965,1406.88 253.974,1406.88 253.983,1406.88 253.992,1406.88 254.001,1406.88 254.011,1406.88 254.02,1406.88 254.029,1406.88 254.038,1406.88 254.047,1406.88 254.057,1406.88 254.066,1406.88 254.075,1406.88 254.084,1406.88 254.093,1406.88 254.103,1406.88 254.112,1406.88 254.121,1406.88 254.13,1406.88 254.139,1406.88 254.148,1406.88 254.158,1406.88 254.167,1406.88 254.176,1406.88 254.185,1406.88 254.194,1406.88 254.204,1406.88 254.213,1406.88 254.222,1406.88 254.231,1406.88 254.24,1406.88 254.25,1406.88 254.259,1406.88 254.268,1406.88 254.277,1406.88 254.286,1406.88 254.295,1406.88 254.305,1406.88 254.314,1406.88 254.323,1406.88 254.332,1406.88 254.341,1406.88 254.351,1406.88 254.36,1406.88 254.369,1406.88 254.378,1406.88 254.387,1406.88 254.397,1406.88 254.406,1406.88 254.415,1406.88 254.424,1406.88 254.433,1406.88 254.443,1406.88 254.452,1406.88 254.461,1406.88 254.47,1406.88 254.479,1406.88 254.488,1406.88 254.498,1406.88 254.507,1406.88 254.516,1406.88 254.525,1406.88 254.534,1406.88 254.544,1406.88 254.553,1406.88 254.562,1406.88 254.571,1406.88 254.58,1406.88 254.59,1406.88 254.599,1406.88 254.608,1406.88 254.617,1406.88 254.626,1406.88 254.635,1406.88 254.645,1406.88 254.654,1406.88 254.663,1406.88 254.672,1406.88 254.681,1406.88 254.691,1406.88 254.7,1406.88 254.709,1406.88 254.718,1406.88 254.727,1406.88 254.737,1406.88 254.746,1406.88 254.755,1406.88 254.764,1406.88 254.773,1406.88 254.783,1406.88 254.792,1406.88 254.801,1406.88 254.81,1406.88 254.819,1406.88 254.828,1406.88 254.838,1406.88 254.847,1406.88 254.856,1406.88 254.865,1406.88 254.874,1406.88 254.884,1406.88 254.893,1406.88 254.902,1406.88 254.911,1406.88 254.92,1406.88 254.93,1406.88 254.939,1406.88 254.948,1406.88 254.957,1406.88 254.966,1406.88 254.975,1406.88 254.985,1406.88 254.994,1406.88 255.003,1406.88 255.012,1406.88 255.021,1406.88 255.031,1406.88 255.04,1406.88 255.049,1406.88 255.058,1406.88 255.067,1406.88 255.077,1406.88 255.086,1406.88 255.095,1406.88 255.104,1406.88 255.113,1406.88 255.123,1406.88 255.132,1406.88 255.141,1406.88 255.15,1406.88 255.159,1406.88 255.168,1406.88 255.178,1406.88 255.187,1406.88 255.196,1406.88 255.205,1406.88 255.214,1406.88 255.224,1406.88 255.233,1406.88 255.242,1406.88 255.251,1406.88 255.26,1406.88 255.27,1406.88 255.279,1406.88 255.288,1406.88 255.297,1406.88 255.306,1406.88 255.316,1406.88 255.325,1406.88 255.334,1406.88 255.343,1406.88 255.352,1406.88 255.361,1406.88 255.371,1406.88 255.38,1406.88 255.389,1406.88 255.398,1406.88 255.407,1406.88 255.417,1406.88 255.426,1406.88 255.435,1406.88 255.444,1406.88 255.453,1406.88 255.463,1406.88 255.472,1406.88 255.481,1406.88 255.49,1406.88 255.499,1406.88 255.508,1406.88 255.518,1406.88 255.527,1406.88 255.536,1406.88 255.545,1406.88 255.554,1406.88 255.564,1406.88 255.573,1406.88 255.582,1406.88 255.591,1406.88 255.6,1406.88 255.61,1406.88 255.619,1406.88 255.628,1406.88 255.637,1406.88 255.646,1406.88 255.656,1406.88 255.665,1406.88 255.674,1406.88 255.683,1406.88 255.692,1406.88 255.701,1406.88 255.711,1406.88 255.72,1406.88 255.729,1406.88 255.738,1406.88 255.747,1406.88 255.757,1406.88 255.766,1406.88 255.775,1406.88 255.784,1406.88 255.793,1406.88 255.803,1406.88 255.812,1406.88 255.821,1406.88 255.83,1406.88 255.839,1406.88 255.848,1406.88 255.858,1406.88 255.867,1406.88 255.876,1406.88 255.885,1406.88 255.894,1406.88 255.904,1406.88 255.913,1406.88 255.922,1406.88 255.931,1406.88 255.94,1406.88 255.95,1406.88 255.959,1406.88 255.968,1406.88 255.977,1406.88 255.986,1406.88 255.996,1406.88 256.005,1406.88 256.014,1406.88 256.023,1406.88 256.032,1406.88 256.041,1406.88 256.051,1406.88 256.06,1406.88 256.069,1406.88 256.078,1406.88 256.087,1406.88 256.097,1406.88 256.106,1406.88 256.115,1406.88 256.124,1406.88 256.133,1406.88 256.143,1406.88 256.152,1406.88 256.161,1406.88 256.17,1406.88 256.179,1406.88 256.188,1406.88 256.198,1406.88 256.207,1406.88 256.216,1406.88 256.225,1406.88 256.234,1406.88 256.244,1406.88 256.253,1406.88 256.262,1406.88 256.271,1406.88 256.28,1406.88 256.29,1406.88 256.299,1406.88 256.308,1406.88 256.317,1406.88 256.326,1406.88 256.336,1406.88 256.345,1406.88 256.354,1406.88 256.363,1406.88 256.372,1406.88 256.381,1406.88 256.391,1406.88 256.4,1406.88 256.409,1406.88 256.418,1406.88 256.427,1406.88 256.437,1406.88 256.446,1406.88 256.455,1406.88 256.464,1406.88 256.473,1406.88 256.483,1406.88 256.492,1406.88 256.501,1406.88 256.51,1406.88 256.519,1406.88 256.528,1406.88 256.538,1406.88 256.547,1406.88 256.556,1406.88 256.565,1406.88 256.574,1406.88 256.584,1406.88 256.593,1406.88 256.602,1406.88 256.611,1406.88 256.62,1406.88 256.63,1406.88 256.639,1406.88 256.648,1406.88 256.657,1406.88 256.666,1406.88 256.676,1406.88 256.685,1406.88 256.694,1406.88 256.703,1406.88 256.712,1406.88 256.721,1406.88 256.731,1406.88 256.74,1406.88 256.749,1406.88 256.758,1406.88 256.767,1406.88 256.777,1406.88 256.786,1406.88 256.795,1406.88 256.804,1406.88 256.813,1406.88 256.823,1406.88 256.832,1406.88 256.841,1406.88 256.85,1406.88 256.859,1406.88 256.868,1406.88 256.878,1406.88 256.887,1406.88 256.896,1406.88 256.905,1406.88 256.914,1406.88 256.924,1406.88 256.933,1406.88 256.942,1406.88 256.951,1406.88 256.96,1406.88 256.97,1406.88 256.979,1406.88 256.988,1406.88 256.997,1406.88 257.006,1406.88 257.016,1406.88 257.025,1406.88 257.034,1406.88 257.043,1406.88 257.052,1406.88 257.061,1406.88 257.071,1406.88 257.08,1406.88 257.089,1406.88 257.098,1406.88 257.107,1406.88 257.117,1406.88 257.126,1406.88 257.135,1406.88 257.144,1406.88 257.153,1406.88 257.163,1406.88 257.172,1406.88 257.181,1406.88 257.19,1406.88 257.199,1406.88 257.208,1406.88 257.218,1406.88 257.227,1406.88 257.236,1406.88 257.245,1406.88 257.254,1406.88 257.264,1406.88 257.273,1406.88 257.282,1406.88 257.291,1406.88 257.3,1406.88 257.31,1406.88 257.319,1406.88 257.328,1406.88 257.337,1406.88 257.346,1406.88 257.356,1406.88 257.365,1406.88 257.374,1406.88 257.383,1406.88 257.392,1406.88 257.401,1406.88 257.411,1406.88 257.42,1406.88 257.429,1406.88 257.438,1406.88 257.447,1406.88 257.457,1406.88 257.466,1406.88 257.475,1406.88 257.484,1406.88 257.493,1406.88 257.503,1406.88 257.512,1406.88 257.521,1406.88 257.53,1406.88 257.539,1406.88 257.548,1406.88 257.558,1406.88 257.567,1406.88 257.576,1406.88 257.585,1406.88 257.594,1406.88 257.604,1406.88 257.613,1406.88 257.622,1406.88 257.631,1406.88 257.64,1406.88 257.65,1406.88 257.659,1406.88 257.668,1406.88 257.677,1406.88 257.686,1406.88 257.696,1406.88 257.705,1406.88 257.714,1406.88 257.723,1406.88 257.732,1406.88 257.741,1406.88 257.751,1406.88 257.76,1406.88 257.769,1406.88 257.778,1406.88 257.787,1406.88 257.797,1406.88 257.806,1406.88 257.815,1406.88 257.824,1406.88 257.833,1406.88 257.843,1406.88 257.852,1406.88 257.861,1406.88 257.87,1406.88 257.879,1406.88 257.889,1406.88 257.898,1406.88 257.907,1406.88 257.916,1406.88 257.925,1406.88 257.934,1406.88 257.944,1406.88 257.953,1406.88 257.962,1406.88 257.971,1406.88 257.98,1406.88 257.99,1406.88 257.999,1406.88 258.008,1406.88 258.017,1406.88 258.026,1406.88 258.036,1406.88 258.045,1406.88 258.054,1406.88 258.063,1406.88 258.072,1406.88 258.081,1406.88 258.091,1406.88 258.1,1406.88 258.109,1406.88 258.118,1406.88 258.127,1406.88 258.137,1406.88 258.146,1406.88 258.155,1406.88 258.164,1406.88 258.173,1406.88 258.183,1406.88 258.192,1406.88 258.201,1406.88 258.21,1406.88 258.219,1406.88 258.229,1406.88 258.238,1406.88 258.247,1406.88 258.256,1406.88 258.265,1406.88 258.274,1406.88 258.284,1406.88 258.293,1406.88 258.302,1406.88 258.311,1406.88 258.32,1406.88 258.33,1406.88 258.339,1406.88 258.348,1406.88 258.357,1406.88 258.366,1406.88 258.376,1406.88 258.385,1406.88 258.394,1406.88 258.403,1406.88 258.412,1406.88 258.421,1406.88 258.431,1406.88 258.44,1406.88 258.449,1406.88 258.458,1406.88 258.467,1406.88 258.477,1406.88 258.486,1406.88 258.495,1406.88 258.504,1406.88 258.513,1406.88 258.523,1406.88 258.532,1406.88 258.541,1406.88 258.55,1406.88 258.559,1406.88 258.569,1406.88 258.578,1406.88 258.587,1406.88 258.596,1406.88 258.605,1406.88 258.614,1406.88 258.624,1406.88 258.633,1406.88 258.642,1406.88 258.651,1406.88 258.66,1406.88 258.67,1406.88 258.679,1406.88 258.688,1406.88 258.697,1406.88 258.706,1406.88 258.716,1406.88 258.725,1406.88 258.734,1406.88 258.743,1406.88 258.752,1406.88 258.761,1406.88 258.771,1406.88 258.78,1406.88 258.789,1406.88 258.798,1406.88 258.807,1406.88 258.817,1406.88 258.826,1406.88 258.835,1406.88 258.844,1406.88 258.853,1406.88 258.863,1406.88 258.872,1406.88 258.881,1406.88 258.89,1406.88 258.899,1406.88 258.909,1406.88 258.918,1406.88 258.927,1406.88 258.936,1406.88 258.945,1406.88 258.954,1406.88 258.964,1406.88 258.973,1406.88 258.982,1406.88 258.991,1406.88 259,1406.88 259.01,1406.88 259.019,1406.88 259.028,1406.88 259.037,1406.88 259.046,1406.88 259.056,1406.88 259.065,1406.88 259.074,1406.88 259.083,1406.88 259.092,1406.88 259.101,1406.88 259.111,1406.88 259.12,1406.88 259.129,1406.88 259.138,1406.88 259.147,1406.88 259.157,1406.88 259.166,1406.88 259.175,1406.88 259.184,1406.88 259.193,1406.88 259.203,1406.88 259.212,1406.88 259.221,1406.88 259.23,1406.88 259.239,1406.88 259.249,1406.88 259.258,1406.88 259.267,1406.88 259.276,1406.88 259.285,1406.88 259.294,1406.88 259.304,1406.88 259.313,1406.88 259.322,1406.88 259.331,1406.88 259.34,1406.88 259.35,1406.88 259.359,1406.88 259.368,1406.88 259.377,1406.88 259.386,1406.88 259.396,1406.88 259.405,1406.88 259.414,1406.88 259.423,1406.88 259.432,1406.88 259.441,1406.88 259.451,1406.88 259.46,1406.88 259.469,1406.88 259.478,1406.88 259.487,1406.88 259.497,1406.88 259.506,1406.88 259.515,1406.88 259.524,1406.88 259.533,1406.88 259.543,1406.88 259.552,1406.88 259.561,1406.88 259.57,1406.88 259.579,1406.88 259.589,1406.88 259.598,1406.88 259.607,1406.88 259.616,1406.88 259.625,1406.88 259.634,1406.88 259.644,1406.88 259.653,1406.88 259.662,1406.88 259.671,1406.88 259.68,1406.88 259.69,1406.88 259.699,1406.88 259.708,1406.88 259.717,1406.88 259.726,1406.88 259.736,1406.88 259.745,1406.88 259.754,1406.88 259.763,1406.88 259.772,1406.88 259.781,1406.88 259.791,1406.88 259.8,1406.88 259.809,1406.88 259.818,1406.88 259.827,1406.88 259.837,1406.88 259.846,1406.88 259.855,1406.88 259.864,1406.88 259.873,1406.88 259.883,1406.88 259.892,1406.88 259.901,1406.88 259.91,1406.88 259.919,1406.88 259.929,1406.88 259.938,1406.88 259.947,1406.88 259.956,1406.88 259.965,1406.88 259.974,1406.88 259.984,1406.88 259.993,1406.88 260.002,1406.88 260.011,1406.88 260.02,1406.88 260.03,1406.88 260.039,1406.88 260.048,1406.88 260.057,1406.88 260.066,1406.88 260.076,1406.88 260.085,1406.88 260.094,1406.88 260.103,1406.88 260.112,1406.88 260.122,1406.88 260.131,1406.88 260.14,1406.88 260.149,1406.88 260.158,1406.88 260.167,1406.88 260.177,1406.88 260.186,1406.88 260.195,1406.88 260.204,1406.88 260.213,1406.88 260.223,1406.88 260.232,1406.88 260.241,1406.88 260.25,1406.88 260.259,1406.88 260.269,1406.88 260.278,1406.88 260.287,1406.88 260.296,1406.88 260.305,1406.88 260.314,1406.88 260.324,1406.88 260.333,1406.88 260.342,1406.88 260.351,1406.88 260.36,1406.88 260.37,1406.88 260.379,1406.88 260.388,1406.88 260.397,1406.88 260.406,1406.88 260.416,1406.88 260.425,1406.88 260.434,1406.88 260.443,1406.88 260.452,1406.88 260.462,1406.88 260.471,1406.88 260.48,1406.88 260.489,1406.88 260.498,1406.88 260.507,1406.88 260.517,1406.88 260.526,1406.88 260.535,1406.88 260.544,1406.88 260.553,1406.88 260.563,1406.88 260.572,1406.88 260.581,1406.88 260.59,1406.88 260.599,1406.88 260.609,1406.88 260.618,1406.88 260.627,1406.88 260.636,1406.88 260.645,1406.88 260.654,1406.88 260.664,1406.88 260.673,1406.88 260.682,1406.88 260.691,1406.88 260.7,1406.88 260.71,1406.88 260.719,1406.88 260.728,1406.88 260.737,1406.88 260.746,1406.88 260.756,1406.88 260.765,1406.88 260.774,1406.88 260.783,1406.88 260.792,1406.88 260.802,1406.88 260.811,1406.88 260.82,1406.88 260.829,1406.88 260.838,1406.88 260.847,1406.88 260.857,1406.88 260.866,1406.88 260.875,1406.88 260.884,1406.88 260.893,1406.88 260.903,1406.88 260.912,1406.88 260.921,1406.88 260.93,1406.88 260.939,1406.88 260.949,1406.88 260.958,1406.88 260.967,1406.88 260.976,1406.88 260.985,1406.88 260.994,1406.88 261.004,1406.88 261.013,1406.88 261.022,1406.88 261.031,1406.88 261.04,1406.88 261.05,1406.88 261.059,1406.88 261.068,1406.88 261.077,1406.88 261.086,1406.88 261.096,1406.88 261.105,1406.88 261.114,1406.88 261.123,1406.88 261.132,1406.88 261.142,1406.88 261.151,1406.88 261.16,1406.88 261.169,1406.88 261.178,1406.88 261.187,1406.88 261.197,1406.88 261.206,1406.88 261.215,1406.88 261.224,1406.88 261.233,1406.88 261.243,1406.88 261.252,1406.88 261.261,1406.88 261.27,1406.88 261.279,1406.88 261.289,1406.88 261.298,1406.88 261.307,1406.88 261.316,1406.88 261.325,1406.88 261.334,1406.88 261.344,1406.88 261.353,1406.88 261.362,1406.88 261.371,1406.88 261.38,1406.88 261.39,1406.88 261.399,1406.88 261.408,1406.88 261.417,1406.88 261.426,1406.88 261.436,1406.88 261.445,1406.88 261.454,1406.88 261.463,1406.88 261.472,1406.88 261.482,1406.88 261.491,1406.88 261.5,1406.88 261.509,1406.88 261.518,1406.88 261.527,1406.88 261.537,1406.88 261.546,1406.88 261.555,1406.88 261.564,1406.88 261.573,1406.88 261.583,1406.88 261.592,1406.88 261.601,1406.88 261.61,1406.88 261.619,1406.88 261.629,1406.88 261.638,1406.88 261.647,1406.88 261.656,1406.88 261.665,1406.88 261.674,1406.88 261.684,1406.88 261.693,1406.88 261.702,1406.88 261.711,1406.88 261.72,1406.88 261.73,1406.88 261.739,1406.88 261.748,1406.88 261.757,1406.88 261.766,1406.88 261.776,1406.88 261.785,1406.88 261.794,1406.88 261.803,1406.88 261.812,1406.88 261.822,1406.88 261.831,1406.88 261.84,1406.88 261.849,1406.88 261.858,1406.88 261.867,1406.88 261.877,1406.88 261.886,1406.88 261.895,1406.88 261.904,1406.88 261.913,1406.88 261.923,1406.88 261.932,1406.88 261.941,1406.88 261.95,1406.88 261.959,1406.88 261.969,1406.88 261.978,1406.88 261.987,1406.88 261.996,1406.88 262.005,1406.88 262.014,1406.88 262.024,1406.88 262.033,1406.88 262.042,1406.88 262.051,1406.88 262.06,1406.88 262.07,1406.88 262.079,1406.88 262.088,1406.88 262.097,1406.88 262.106,1406.88 262.116,1406.88 262.125,1406.88 262.134,1406.88 262.143,1406.88 262.152,1406.88 262.162,1406.88 262.171,1406.88 262.18,1406.88 262.189,1406.88 262.198,1406.88 262.207,1406.88 262.217,1406.88 262.226,1406.88 262.235,1406.88 262.244,1406.88 262.253,1406.88 262.263,1406.88 262.272,1406.88 262.281,1406.88 262.29,1406.88 262.299,1406.88 262.309,1406.88 262.318,1406.88 262.327,1406.88 262.336,1406.88 262.345,1406.88 262.354,1406.88 262.364,1406.88 262.373,1406.88 262.382,1406.88 262.391,1406.88 262.4,1406.88 262.41,1406.88 262.419,1406.88 262.428,1406.88 262.437,1406.88 262.446,1406.88 262.456,1406.88 262.465,1406.88 262.474,1406.88 262.483,1406.88 262.492,1406.88 262.502,1406.88 262.511,1406.88 262.52,1406.88 262.529,1406.88 262.538,1406.88 262.547,1406.88 262.557,1406.88 262.566,1406.88 262.575,1406.88 262.584,1406.88 262.593,1406.88 262.603,1406.88 262.612,1406.88 262.621,1406.88 262.63,1406.88 262.639,1406.88 262.649,1406.88 262.658,1406.88 262.667,1406.88 262.676,1406.88 262.685,1406.88 262.695,1406.88 262.704,1406.88 262.713,1406.88 262.722,1406.88 262.731,1406.88 262.74,1406.88 262.75,1406.88 262.759,1406.88 262.768,1406.88 262.777,1406.88 262.786,1406.88 262.796,1406.88 262.805,1406.88 262.814,1406.88 262.823,1406.88 262.832,1406.88 262.842,1406.88 262.851,1406.88 262.86,1406.88 262.869,1406.88 262.878,1406.88 262.887,1406.88 262.897,1406.88 262.906,1406.88 262.915,1406.88 262.924,1406.88 262.933,1406.88 262.943,1406.88 262.952,1406.88 262.961,1406.88 262.97,1406.88 262.979,1406.88 262.989,1406.88 262.998,1406.88 263.007,1406.88 263.016,1406.88 263.025,1406.88 263.035,1406.88 263.044,1406.88 263.053,1406.88 263.062,1406.88 263.071,1406.88 263.08,1406.88 263.09,1406.88 263.099,1406.88 263.108,1406.88 263.117,1406.88 263.126,1406.88 263.136,1406.88 263.145,1406.88 263.154,1406.88 263.163,1406.88 263.172,1406.88 263.182,1406.88 263.191,1406.88 263.2,1406.88 263.209,1406.88 263.218,1406.88 263.227,1406.88 263.237,1406.88 263.246,1406.88 263.255,1406.88 263.264,1406.88 263.273,1406.88 263.283,1406.88 263.292,1406.88 263.301,1406.88 263.31,1406.88 263.319,1406.88 263.329,1406.88 263.338,1406.88 263.347,1406.88 263.356,1406.88 263.365,1406.88 263.375,1406.88 263.384,1406.88 263.393,1406.88 263.402,1406.88 263.411,1406.88 263.42,1406.88 263.43,1406.88 263.439,1406.88 263.448,1406.88 263.457,1406.88 263.466,1406.88 263.476,1406.88 263.485,1406.88 263.494,1406.88 263.503,1406.88 263.512,1406.88 263.522,1406.88 263.531,1406.88 263.54,1406.88 263.549,1406.88 263.558,1406.88 263.567,1406.88 263.577,1406.88 263.586,1406.88 263.595,1406.88 263.604,1406.88 263.613,1406.88 263.623,1406.88 263.632,1406.88 263.641,1406.88 263.65,1406.88 263.659,1406.88 263.669,1406.88 263.678,1406.88 263.687,1406.88 263.696,1406.88 263.705,1406.88 263.715,1406.88 263.724,1406.88 263.733,1406.88 263.742,1406.88 263.751,1406.88 263.76,1406.88 263.77,1406.88 263.779,1406.88 263.788,1406.88 263.797,1406.88 263.806,1406.88 263.816,1406.88 263.825,1406.88 263.834,1406.88 263.843,1406.88 263.852,1406.88 263.862,1406.88 263.871,1406.88 263.88,1406.88 263.889,1406.88 263.898,1406.88 263.907,1406.88 263.917,1406.88 263.926,1406.88 263.935,1406.88 263.944,1406.88 263.953,1406.88 263.963,1406.88 263.972,1406.88 263.981,1406.88 263.99,1406.88 263.999,1406.88 264.009,1406.88 264.018,1406.88 264.027,1406.88 264.036,1406.88 264.045,1406.88 264.055,1406.88 264.064,1406.88 264.073,1406.88 264.082,1406.88 264.091,1406.88 264.1,1406.88 264.11,1406.88 264.119,1406.88 264.128,1406.88 264.137,1406.88 264.146,1406.88 264.156,1406.88 264.165,1406.88 264.174,1406.88 264.183,1406.88 264.192,1406.88 264.202,1406.88 264.211,1406.88 264.22,1406.88 264.229,1406.88 264.238,1406.88 264.247,1406.88 264.257,1406.88 264.266,1406.88 264.275,1406.88 264.284,1406.88 264.293,1406.88 264.303,1406.88 264.312,1406.88 264.321,1406.88 264.33,1406.88 264.339,1406.88 264.349,1406.88 264.358,1406.88 264.367,1406.88 264.376,1406.88 264.385,1406.88 264.395,1406.88 264.404,1406.88 264.413,1406.88 264.422,1406.88 264.431,1406.88 264.44,1406.88 264.45,1406.88 264.459,1406.88 264.468,1406.88 264.477,1406.88 264.486,1406.88 264.496,1406.88 264.505,1406.88 264.514,1406.88 264.523,1406.88 264.532,1406.88 264.542,1406.88 264.551,1406.88 264.56,1406.88 264.569,1406.88 264.578,1406.88 264.587,1406.88 264.597,1406.88 264.606,1406.88 264.615,1406.88 264.624,1406.88 264.633,1406.88 264.643,1406.88 264.652,1406.88 264.661,1406.88 264.67,1406.88 264.679,1406.88 264.689,1406.88 264.698,1406.88 264.707,1406.88 264.716,1406.88 264.725,1406.88 264.735,1406.88 264.744,1406.88 264.753,1406.88 264.762,1406.88 264.771,1406.88 264.78,1406.88 264.79,1406.88 264.799,1406.88 264.808,1406.88 264.817,1406.88 264.826,1406.88 264.836,1406.88 264.845,1406.88 264.854,1406.88 264.863,1406.88 264.872,1406.88 264.882,1406.88 264.891,1406.88 264.9,1406.88 264.909,1406.88 264.918,1406.88 264.927,1406.88 264.937,1406.88 264.946,1406.88 264.955,1406.88 264.964,1406.88 264.973,1406.88 264.983,1406.88 264.992,1406.88 265.001,1406.88 265.01,1406.88 265.019,1406.88 265.029,1406.88 265.038,1406.88 265.047,1406.88 265.056,1406.88 265.065,1406.88 265.075,1406.88 265.084,1406.88 265.093,1406.88 265.102,1406.88 265.111,1406.88 265.12,1406.88 265.13,1406.88 265.139,1406.88 265.148,1406.88 265.157,1406.88 265.166,1406.88 265.176,1406.88 265.185,1406.88 265.194,1406.88 265.203,1406.88 265.212,1406.88 265.222,1406.88 265.231,1406.88 265.24,1406.88 265.249,1406.88 265.258,1406.88 265.268,1406.88 265.277,1406.88 265.286,1406.88 265.295,1406.88 265.304,1406.88 265.313,1406.88 265.323,1406.88 265.332,1406.88 265.341,1406.88 265.35,1406.88 265.359,1406.88 265.369,1406.88 265.378,1406.88 265.387,1406.88 265.396,1406.88 265.405,1406.88 265.415,1406.88 265.424,1406.88 265.433,1406.88 265.442,1406.88 265.451,1406.88 265.46,1406.88 265.47,1406.88 265.479,1406.88 265.488,1406.88 265.497,1406.88 265.506,1406.88 265.516,1406.88 265.525,1406.88 265.534,1406.88 265.543,1406.88 265.552,1406.88 265.562,1406.88 265.571,1406.88 265.58,1406.88 265.589,1406.88 265.598,1406.88 265.608,1406.88 265.617,1406.88 265.626,1406.88 265.635,1406.88 265.644,1406.88 265.653,1406.88 265.663,1406.88 265.672,1406.88 265.681,1406.88 265.69,1406.88 265.699,1406.88 265.709,1406.88 265.718,1406.88 265.727,1406.88 265.736,1406.88 265.745,1406.88 265.755,1406.88 265.764,1406.88 265.773,1406.88 265.782,1406.88 265.791,1406.88 265.8,1406.88 265.81,1406.88 265.819,1406.88 265.828,1406.88 265.837,1406.88 265.846,1406.88 265.856,1406.88 265.865,1406.88 265.874,1406.88 265.883,1406.88 265.892,1406.88 265.902,1406.88 265.911,1406.88 265.92,1406.88 265.929,1406.88 265.938,1406.88 265.948,1406.88 265.957,1406.88 265.966,1406.88 265.975,1406.88 265.984,1406.88 265.993,1406.88 266.003,1406.88 266.012,1406.88 266.021,1406.88 266.03,1406.88 266.039,1406.88 266.049,1406.88 266.058,1406.88 266.067,1406.88 266.076,1406.88 266.085,1406.88 266.095,1406.88 266.104,1406.88 266.113,1406.88 266.122,1406.88 266.131,1406.88 266.14,1406.88 266.15,1406.88 266.159,1406.88 266.168,1406.88 266.177,1406.88 266.186,1406.88 266.196,1406.88 266.205,1406.88 266.214,1406.88 266.223,1406.88 266.232,1406.88 266.242,1406.88 266.251,1406.88 266.26,1406.88 266.269,1406.88 266.278,1406.88 266.288,1406.88 266.297,1406.88 266.306,1406.88 266.315,1406.88 266.324,1406.88 266.333,1406.88 266.343,1406.88 266.352,1406.88 266.361,1406.88 266.37,1406.88 266.379,1406.88 266.389,1406.88 266.398,1406.88 266.407,1406.88 266.416,1406.88 266.425,1406.88 266.435,1406.88 266.444,1406.88 266.453,1406.88 266.462,1406.88 266.471,1406.88 266.48,1406.88 266.49,1406.88 266.499,1406.88 266.508,1406.88 266.517,1406.88 266.526,1406.88 266.536,1406.88 266.545,1406.88 266.554,1406.88 266.563,1406.88 266.572,1406.88 266.582,1406.88 266.591,1406.88 266.6,1406.88 266.609,1406.88 266.618,1406.88 266.628,1406.88 266.637,1406.88 266.646,1406.88 266.655,1406.88 266.664,1406.88 266.673,1406.88 266.683,1406.88 266.692,1406.88 266.701,1406.88 266.71,1406.88 266.719,1406.88 266.729,1406.88 266.738,1406.88 266.747,1406.88 266.756,1406.88 266.765,1406.88 266.775,1406.88 266.784,1406.88 266.793,1406.88 266.802,1406.88 266.811,1406.88 266.82,1406.88 266.83,1406.88 266.839,1406.88 266.848,1406.88 266.857,1406.88 266.866,1406.88 266.876,1406.88 266.885,1406.88 266.894,1406.88 266.903,1406.88 266.912,1406.88 266.922,1406.88 266.931,1406.88 266.94,1406.88 266.949,1406.88 266.958,1406.88 266.968,1406.88 266.977,1406.88 266.986,1406.88 266.995,1406.88 267.004,1406.88 267.013,1406.88 267.023,1406.88 267.032,1406.88 267.041,1406.88 267.05,1406.88 267.059,1406.88 267.069,1406.88 267.078,1406.88 267.087,1406.88 267.096,1406.88 267.105,1406.88 267.115,1406.88 267.124,1406.88 267.133,1406.88 267.142,1406.88 267.151,1406.88 267.16,1406.88 267.17,1406.88 267.179,1406.88 267.188,1406.88 267.197,1406.88 267.206,1406.88 267.216,1406.88 267.225,1406.88 267.234,1406.88 267.243,1406.88 267.252,1406.88 267.262,1406.88 267.271,1406.88 267.28,1406.88 267.289,1406.88 267.298,1406.88 267.308,1406.88 267.317,1406.88 267.326,1406.88 267.335,1406.88 267.344,1406.88 267.353,1406.88 267.363,1406.88 267.372,1406.88 267.381,1406.88 267.39,1406.88 267.399,1406.88 267.409,1406.88 267.418,1406.88 267.427,1406.88 267.436,1406.88 267.445,1406.88 267.455,1406.88 267.464,1406.88 267.473,1406.88 267.482,1406.88 267.491,1406.88 267.501,1406.88 267.51,1406.88 267.519,1406.88 267.528,1406.88 267.537,1406.88 267.546,1406.88 267.556,1406.88 267.565,1406.88 267.574,1406.88 267.583,1406.88 267.592,1406.88 267.602,1406.88 267.611,1406.88 267.62,1406.88 267.629,1406.88 267.638,1406.88 267.648,1406.88 267.657,1406.88 267.666,1406.88 267.675,1406.88 267.684,1406.88 267.693,1406.88 267.703,1406.88 267.712,1406.88 267.721,1406.88 267.73,1406.88 267.739,1406.88 267.749,1406.88 267.758,1406.88 267.767,1406.88 267.776,1406.88 267.785,1406.88 267.795,1406.88 267.804,1406.88 267.813,1406.88 267.822,1406.88 267.831,1406.88 267.841,1406.88 267.85,1406.88 267.859,1406.88 267.868,1406.88 267.877,1406.88 267.886,1406.88 267.896,1406.88 267.905,1406.88 267.914,1406.88 267.923,1406.88 267.932,1406.88 267.942,1406.88 267.951,1406.88 267.96,1406.88 267.969,1406.88 267.978,1406.88 267.988,1406.88 267.997,1406.88 268.006,1406.88 268.015,1406.88 268.024,1406.88 268.033,1406.88 268.043,1406.88 268.052,1406.88 268.061,1406.88 268.07,1406.88 268.079,1406.88 268.089,1406.88 268.098,1406.88 268.107,1406.88 268.116,1406.88 268.125,1406.88 268.135,1406.88 268.144,1406.88 268.153,1406.88 268.162,1406.88 268.171,1406.88 268.181,1406.88 268.19,1406.88 268.199,1406.88 268.208,1406.88 268.217,1406.88 268.226,1406.88 268.236,1406.88 268.245,1406.88 268.254,1406.88 268.263,1406.88 268.272,1406.88 268.282,1406.88 268.291,1406.88 268.3,1406.88 268.309,1406.88 268.318,1406.88 268.328,1406.88 268.337,1406.88 268.346,1406.88 268.355,1406.88 268.364,1406.88 268.373,1406.88 268.383,1406.88 268.392,1406.88 268.401,1406.88 268.41,1406.88 268.419,1406.88 268.429,1406.88 268.438,1406.88 268.447,1406.88 268.456,1406.88 268.465,1406.88 268.475,1406.88 268.484,1406.88 268.493,1406.88 268.502,1406.88 268.511,1406.88 268.521,1406.88 268.53,1406.88 268.539,1406.88 268.548,1406.88 268.557,1406.88 268.566,1406.88 268.576,1406.88 268.585,1406.88 268.594,1406.88 268.603,1406.88 268.612,1406.88 268.622,1406.88 268.631,1406.88 268.64,1406.88 268.649,1406.88 268.658,1406.88 268.668,1406.88 268.677,1406.88 268.686,1406.88 268.695,1406.88 268.704,1406.88 268.713,1406.88 268.723,1406.88 268.732,1406.88 268.741,1406.88 268.75,1406.88 268.759,1406.88 268.769,1406.88 268.778,1406.88 268.787,1406.88 268.796,1406.88 268.805,1406.88 268.815,1406.88 268.824,1406.88 268.833,1406.88 268.842,1406.88 268.851,1406.88 268.861,1406.88 268.87,1406.88 268.879,1406.88 268.888,1406.88 268.897,1406.88 268.906,1406.88 268.916,1406.88 268.925,1406.88 268.934,1406.88 268.943,1406.88 268.952,1406.88 268.962,1406.88 268.971,1406.88 268.98,1406.88 268.989,1406.88 268.998,1406.88 269.008,1406.88 269.017,1406.88 269.026,1406.88 269.035,1406.88 269.044,1406.88 269.053,1406.88 269.063,1406.88 269.072,1406.88 269.081,1406.88 269.09,1406.88 269.099,1406.88 269.109,1406.88 269.118,1406.88 269.127,1406.88 269.136,1406.88 269.145,1406.88 269.155,1406.88 269.164,1406.88 269.173,1406.88 269.182,1406.88 269.191,1406.88 269.201,1406.88 269.21,1406.88 269.219,1406.88 269.228,1406.88 269.237,1406.88 269.246,1406.88 269.256,1406.88 269.265,1406.88 269.274,1406.88 269.283,1406.88 269.292,1406.88 269.302,1406.88 269.311,1406.88 269.32,1406.88 269.329,1406.88 269.338,1406.88 269.348,1406.88 269.357,1406.88 269.366,1406.88 269.375,1406.88 269.384,1406.88 269.393,1406.88 269.403,1406.88 269.412,1406.88 269.421,1406.88 269.43,1406.88 269.439,1406.88 269.449,1406.88 269.458,1406.88 269.467,1406.88 269.476,1406.88 269.485,1406.88 269.495,1406.88 269.504,1406.88 269.513,1406.88 269.522,1406.88 269.531,1406.88 269.541,1406.88 269.55,1406.88 269.559,1406.88 269.568,1406.88 269.577,1406.88 269.586,1406.88 269.596,1406.88 269.605,1406.88 269.614,1406.88 269.623,1406.88 269.632,1406.88 269.642,1406.88 269.651,1406.88 269.66,1406.88 269.669,1406.88 269.678,1406.88 269.688,1406.88 269.697,1406.88 269.706,1406.88 269.715,1406.88 269.724,1406.88 269.733,1406.88 269.743,1406.88 269.752,1406.88 269.761,1406.88 269.77,1406.88 269.779,1406.88 269.789,1406.88 269.798,1406.88 269.807,1406.88 269.816,1406.88 269.825,1406.88 269.835,1406.88 269.844,1406.88 269.853,1406.88 269.862,1406.88 269.871,1406.88 269.881,1406.88 269.89,1406.88 269.899,1406.88 269.908,1406.88 269.917,1406.88 269.926,1406.88 269.936,1406.88 269.945,1406.88 269.954,1406.88 269.963,1406.88 269.972,1406.88 269.982,1406.88 269.991,1406.88 270,1406.88 270.009,1406.88 270.018,1406.88 270.028,1406.88 270.037,1406.88 270.046,1406.88 270.055,1406.88 270.064,1406.88 270.074,1406.88 270.083,1406.88 270.092,1406.88 270.101,1406.88 270.11,1406.88 270.119,1406.88 270.129,1406.88 270.138,1406.88 270.147,1406.88 270.156,1406.88 270.165,1406.88 270.175,1406.88 270.184,1406.88 270.193,1406.88 270.202,1406.88 270.211,1406.88 270.221,1406.88 270.23,1406.88 270.239,1406.88 270.248,1406.88 270.257,1406.88 270.266,1406.88 270.276,1406.88 270.285,1406.88 270.294,1406.88 270.303,1406.88 270.312,1406.88 270.322,1406.88 270.331,1406.88 270.34,1406.88 270.349,1406.88 270.358,1406.88 270.368,1406.88 270.377,1406.88 270.386,1406.88 270.395,1406.88 270.404,1406.88 270.414,1406.88 270.423,1406.88 270.432,1406.88 270.441,1406.88 270.45,1406.88 270.459,1406.88 270.469,1406.88 270.478,1406.88 270.487,1406.88 270.496,1406.88 270.505,1406.88 270.515,1406.88 270.524,1406.88 270.533,1406.88 270.542,1406.88 270.551,1406.88 270.561,1406.88 270.57,1406.88 270.579,1406.88 270.588,1406.88 270.597,1406.88 270.606,1406.88 270.616,1406.88 270.625,1406.88 270.634,1406.88 270.643,1406.88 270.652,1406.88 270.662,1406.88 270.671,1406.88 270.68,1406.88 270.689,1406.88 270.698,1406.88 270.708,1406.88 270.717,1406.88 270.726,1406.88 270.735,1406.88 270.744,1406.88 270.754,1406.88 270.763,1406.88 270.772,1406.88 270.781,1406.88 270.79,1406.88 270.799,1406.88 270.809,1406.88 270.818,1406.88 270.827,1406.88 270.836,1406.88 270.845,1406.88 270.855,1406.88 270.864,1406.88 270.873,1406.88 270.882,1406.88 270.891,1406.88 270.901,1406.88 270.91,1406.88 270.919,1406.88 270.928,1406.88 270.937,1406.88 270.946,1406.88 270.956,1406.88 270.965,1406.88 270.974,1406.88 270.983,1406.88 270.992,1406.88 271.002,1406.88 271.011,1406.88 271.02,1406.88 271.029,1406.88 271.038,1406.88 271.048,1406.88 271.057,1406.88 271.066,1406.88 271.075,1406.88 271.084,1406.88 271.094,1406.88 271.103,1406.88 271.112,1406.88 271.121,1406.88 271.13,1406.88 271.139,1406.88 271.149,1406.88 271.158,1406.88 271.167,1406.88 271.176,1406.88 271.185,1406.88 271.195,1406.88 271.204,1406.88 271.213,1406.88 271.222,1406.88 271.231,1406.88 271.241,1406.88 271.25,1406.88 271.259,1406.88 271.268,1406.88 271.277,1406.88 271.286,1406.88 271.296,1406.88 271.305,1406.88 271.314,1406.88 271.323,1406.88 271.332,1406.88 271.342,1406.88 271.351,1406.88 271.36,1406.88 271.369,1406.88 271.378,1406.88 271.388,1406.88 271.397,1406.88 271.406,1406.88 271.415,1406.88 271.424,1406.88 271.434,1406.88 271.443,1406.88 271.452,1406.88 271.461,1406.88 271.47,1406.88 271.479,1406.88 271.489,1406.88 271.498,1406.88 271.507,1406.88 271.516,1406.88 271.525,1406.88 271.535,1406.88 271.544,1406.88 271.553,1406.88 271.562,1406.88 271.571,1406.88 271.581,1406.88 271.59,1406.88 271.599,1406.88 271.608,1406.88 271.617,1406.88 271.626,1406.88 271.636,1406.88 271.645,1406.88 271.654,1406.88 271.663,1406.88 271.672,1406.88 271.682,1406.88 271.691,1406.88 271.7,1406.88 271.709,1406.88 271.718,1406.88 271.728,1406.88 271.737,1406.88 271.746,1406.88 271.755,1406.88 271.764,1406.88 271.774,1406.88 271.783,1406.88 271.792,1406.88 271.801,1406.88 271.81,1406.88 271.819,1406.88 271.829,1406.88 271.838,1406.88 271.847,1406.88 271.856,1406.88 271.865,1406.88 271.875,1406.88 271.884,1406.88 271.893,1406.88 271.902,1406.88 271.911,1406.88 271.921,1406.88 271.93,1406.88 271.939,1406.88 271.948,1406.88 271.957,1406.88 271.966,1406.88 271.976,1406.88 271.985,1406.88 271.994,1406.88 272.003,1406.88 272.012,1406.88 272.022,1406.88 272.031,1406.88 272.04,1406.88 272.049,1406.88 272.058,1406.88 272.068,1406.88 272.077,1406.88 272.086,1406.88 272.095,1406.88 272.104,1406.88 272.114,1406.88 272.123,1406.88 272.132,1406.88 272.141,1406.88 272.15,1406.88 272.159,1406.88 272.169,1406.88 272.178,1406.88 272.187,1406.88 272.196,1406.88 272.205,1406.88 272.215,1406.88 272.224,1406.88 272.233,1406.88 272.242,1406.88 272.251,1406.88 272.261,1406.88 272.27,1406.88 272.279,1406.88 272.288,1406.88 272.297,1406.88 272.306,1406.88 272.316,1406.88 272.325,1406.88 272.334,1406.88 272.343,1406.88 272.352,1406.88 272.362,1406.88 272.371,1406.88 272.38,1406.88 272.389,1406.88 272.398,1406.88 272.408,1406.88 272.417,1406.88 272.426,1406.88 272.435,1406.88 272.444,1406.88 272.454,1406.88 272.463,1406.88 272.472,1406.88 272.481,1406.88 272.49,1406.88 272.499,1406.88 272.509,1406.88 272.518,1406.88 272.527,1406.88 272.536,1406.88 272.545,1406.88 272.555,1406.88 272.564,1406.88 272.573,1406.88 272.582,1406.88 272.591,1406.88 272.601,1406.88 272.61,1406.88 272.619,1406.88 272.628,1406.88 272.637,1406.88 272.647,1406.88 272.656,1406.88 272.665,1406.88 272.674,1406.88 272.683,1406.88 272.692,1406.88 272.702,1406.88 272.711,1406.88 272.72,1406.88 272.729,1406.88 272.738,1406.88 272.748,1406.88 272.757,1406.88 272.766,1406.88 272.775,1406.88 272.784,1406.88 272.794,1406.88 272.803,1406.88 272.812,1406.88 272.821,1406.88 272.83,1406.88 272.839,1406.88 272.849,1406.88 272.858,1406.88 272.867,1406.88 272.876,1406.88 272.885,1406.88 272.895,1406.88 272.904,1406.88 272.913,1406.88 272.922,1406.88 272.931,1406.88 272.941,1406.88 272.95,1406.88 272.959,1406.88 272.968,1406.88 272.977,1406.88 272.987,1406.88 272.996,1406.88 273.005,1406.88 273.014,1406.88 273.023,1406.88 273.032,1406.88 273.042,1406.88 273.051,1406.88 273.06,1406.88 273.069,1406.88 273.078,1406.88 273.088,1406.88 273.097,1406.88 273.106,1406.88 273.115,1406.88 273.124,1406.88 273.134,1406.88 273.143,1406.88 273.152,1406.88 273.161,1406.88 273.17,1406.88 273.179,1406.88 273.189,1406.88 273.198,1406.88 273.207,1406.88 273.216,1406.88 273.225,1406.88 273.235,1406.88 273.244,1406.88 273.253,1406.88 273.262,1406.88 273.271,1406.88 273.281,1406.88 273.29,1406.88 273.299,1406.88 273.308,1406.88 273.317,1406.88 273.327,1406.88 273.336,1406.88 273.345,1406.88 273.354,1406.88 273.363,1406.88 273.372,1406.88 273.382,1406.88 273.391,1406.88 273.4,1406.88 273.409,1406.88 273.418,1406.88 273.428,1406.88 273.437,1406.88 273.446,1406.88 273.455,1406.88 273.464,1406.88 273.474,1406.88 273.483,1406.88 273.492,1406.88 273.501,1406.88 273.51,1406.88 273.519,1406.88 273.529,1406.88 273.538,1406.88 273.547,1406.88 273.556,1406.88 273.565,1406.88 273.575,1406.88 273.584,1406.88 273.593,1406.88 273.602,1406.88 273.611,1406.88 273.621,1406.88 273.63,1406.88 273.639,1406.88 273.648,1406.88 273.657,1406.88 273.667,1406.88 273.676,1406.88 273.685,1406.88 273.694,1406.88 273.703,1406.88 273.712,1406.88 273.722,1406.88 273.731,1406.88 273.74,1406.88 273.749,1406.88 273.758,1406.88 273.768,1406.88 273.777,1406.88 273.786,1406.88 273.795,1406.88 273.804,1406.88 273.814,1406.88 273.823,1406.88 273.832,1406.88 273.841,1406.88 273.85,1406.88 273.859,1406.88 273.869,1406.88 273.878,1406.88 273.887,1406.88 273.896,1406.88 273.905,1406.88 273.915,1406.88 273.924,1406.88 273.933,1406.88 273.942,1406.88 273.951,1406.88 273.961,1406.88 273.97,1406.88 273.979,1406.88 273.988,1406.88 273.997,1406.88 274.007,1406.88 274.016,1406.88 274.025,1406.88 274.034,1406.88 274.043,1406.88 274.052,1406.88 274.062,1406.88 274.071,1406.88 274.08,1406.88 274.089,1406.88 274.098,1406.88 274.108,1406.88 274.117,1406.88 274.126,1406.88 274.135,1406.88 274.144,1406.88 274.154,1406.88 274.163,1406.88 274.172,1406.88 274.181,1406.88 274.19,1406.88 274.199,1406.88 274.209,1406.88 274.218,1406.88 274.227,1406.88 274.236,1406.88 274.245,1406.88 274.255,1406.88 274.264,1406.88 274.273,1406.88 274.282,1406.88 274.291,1406.88 274.301,1406.88 274.31,1406.88 274.319,1406.88 274.328,1406.88 274.337,1406.88 274.347,1406.88 274.356,1406.88 274.365,1406.88 274.374,1406.88 274.383,1406.88 274.392,1406.88 274.402,1406.88 274.411,1406.88 274.42,1406.88 274.429,1406.88 274.438,1406.88 274.448,1406.88 274.457,1406.88 274.466,1406.88 274.475,1406.88 274.484,1406.88 274.494,1406.88 274.503,1406.88 274.512,1406.88 274.521,1406.88 274.53,1406.88 274.539,1406.88 274.549,1406.88 274.558,1406.88 274.567,1406.88 274.576,1406.88 274.585,1406.88 274.595,1406.88 274.604,1406.88 274.613,1406.88 274.622,1406.88 274.631,1406.88 274.641,1406.88 274.65,1406.88 274.659,1406.88 274.668,1406.88 274.677,1406.88 274.687,1406.88 274.696,1406.88 274.705,1406.88 274.714,1406.88 274.723,1406.88 274.732,1406.88 274.742,1406.88 274.751,1406.88 274.76,1406.88 274.769,1406.88 274.778,1406.88 274.788,1406.88 274.797,1406.88 274.806,1406.88 274.815,1406.88 274.824,1406.88 274.834,1406.88 274.843,1406.88 274.852,1406.88 274.861,1406.88 274.87,1406.88 274.88,1406.88 274.889,1406.88 274.898,1406.88 274.907,1406.88 274.916,1406.88 274.925,1406.88 274.935,1406.88 274.944,1406.88 274.953,1406.88 274.962,1406.88 274.971,1406.88 274.981,1406.88 274.99,1406.88 274.999,1406.88 275.008,1406.88 275.017,1406.88 275.027,1406.88 275.036,1406.88 275.045,1406.88 275.054,1406.88 275.063,1406.88 275.072,1406.88 275.082,1406.88 275.091,1406.88 275.1,1406.88 275.109,1406.88 275.118,1406.88 275.128,1406.88 275.137,1406.88 275.146,1406.88 275.155,1406.88 275.164,1406.88 275.174,1406.88 275.183,1406.88 275.192,1406.88 275.201,1406.88 275.21,1406.88 275.22,1406.88 275.229,1406.88 275.238,1406.88 275.247,1406.88 275.256,1406.88 275.265,1406.88 275.275,1406.88 275.284,1406.88 275.293,1406.88 275.302,1406.88 275.311,1406.88 275.321,1406.88 275.33,1406.88 275.339,1406.88 275.348,1406.88 275.357,1406.88 275.367,1406.88 275.376,1406.88 275.385,1406.88 275.394,1406.88 275.403,1406.88 275.412,1406.88 275.422,1406.88 275.431,1406.88 275.44,1406.88 275.449,1406.88 275.458,1406.88 275.468,1406.88 275.477,1406.88 275.486,1406.88 275.495,1406.88 275.504,1406.88 275.514,1406.88 275.523,1406.88 275.532,1406.88 275.541,1406.88 275.55,1406.88 275.56,1406.88 275.569,1406.88 275.578,1406.88 275.587,1406.88 275.596,1406.88 275.605,1406.88 275.615,1406.88 275.624,1406.88 275.633,1406.88 275.642,1406.88 275.651,1406.88 275.661,1406.88 275.67,1406.88 275.679,1406.88 275.688,1406.88 275.697,1406.88 275.707,1406.88 275.716,1406.88 275.725,1406.88 275.734,1406.88 275.743,1406.88 275.752,1406.88 275.762,1406.88 275.771,1406.88 275.78,1406.88 275.789,1406.88 275.798,1406.88 275.808,1406.88 275.817,1406.88 275.826,1406.88 275.835,1406.88 275.844,1406.88 275.854,1406.88 275.863,1406.88 275.872,1406.88 275.881,1406.88 275.89,1406.88 275.9,1406.88 275.909,1406.88 275.918,1406.88 275.927,1406.88 275.936,1406.88 275.945,1406.88 275.955,1406.88 275.964,1406.88 275.973,1406.88 275.982,1406.88 275.991,1406.88 276.001,1406.88 276.01,1406.88 276.019,1406.88 276.028,1406.88 276.037,1406.88 276.047,1406.88 276.056,1406.88 276.065,1406.88 276.074,1406.88 276.083,1406.88 276.092,1406.88 276.102,1406.88 276.111,1406.88 276.12,1406.88 276.129,1406.88 276.138,1406.88 276.148,1406.88 276.157,1406.88 276.166,1406.88 276.175,1406.88 276.184,1406.88 276.194,1406.88 276.203,1406.88 276.212,1406.88 276.221,1406.88 276.23,1406.88 276.24,1406.88 276.249,1406.88 276.258,1406.88 276.267,1406.88 276.276,1406.88 276.285,1406.88 276.295,1406.88 276.304,1406.88 276.313,1406.88 276.322,1406.88 276.331,1406.88 276.341,1406.88 276.35,1406.88 276.359,1406.88 276.368,1406.88 276.377,1406.88 276.387,1406.88 276.396,1406.88 276.405,1406.88 276.414,1406.88 276.423,1406.88 276.432,1406.88 276.442,1406.88 276.451,1406.88 276.46,1406.88 276.469,1406.88 276.478,1406.88 276.488,1406.88 276.497,1406.88 276.506,1406.88 276.515,1406.88 276.524,1406.88 276.534,1406.88 276.543,1406.88 276.552,1406.88 276.561,1406.88 276.57,1406.88 276.58,1406.88 276.589,1406.88 276.598,1406.88 276.607,1406.88 276.616,1406.88 276.625,1406.88 276.635,1406.88 276.644,1406.88 276.653,1406.88 276.662,1406.88 276.671,1406.88 276.681,1406.88 276.69,1406.88 276.699,1406.88 276.708,1406.88 276.717,1406.88 276.727,1406.88 276.736,1406.88 276.745,1406.88 276.754,1406.88 276.763,1406.88 276.772,1406.88 276.782,1406.88 276.791,1406.88 276.8,1406.88 276.809,1406.88 276.818,1406.88 276.828,1406.88 276.837,1406.88 276.846,1406.88 276.855,1406.88 276.864,1406.88 276.874,1406.88 276.883,1406.88 276.892,1406.88 276.901,1406.88 276.91,1406.88 276.92,1406.88 276.929,1406.88 276.938,1406.88 276.947,1406.88 276.956,1406.88 276.965,1406.88 276.975,1406.88 276.984,1406.88 276.993,1406.88 277.002,1406.88 277.011,1406.88 277.021,1406.88 277.03,1406.88 277.039,1406.88 277.048,1406.88 277.057,1406.88 277.067,1406.88 277.076,1406.88 277.085,1406.88 277.094,1406.88 277.103,1406.88 277.112,1406.88 277.122,1406.88 277.131,1406.88 277.14,1406.88 277.149,1406.88 277.158,1406.88 277.168,1406.88 277.177,1406.88 277.186,1406.88 277.195,1406.88 277.204,1406.88 277.214,1406.88 277.223,1406.88 277.232,1406.88 277.241,1406.88 277.25,1406.88 277.26,1406.88 277.269,1406.88 277.278,1406.88 277.287,1406.88 277.296,1406.88 277.305,1406.88 277.315,1406.88 277.324,1406.88 277.333,1406.88 277.342,1406.88 277.351,1406.88 277.361,1406.88 277.37,1406.88 277.379,1406.88 277.388,1406.88 277.397,1406.88 277.407,1406.88 277.416,1406.88 277.425,1406.88 277.434,1406.88 277.443,1406.88 277.453,1406.88 277.462,1406.88 277.471,1406.88 277.48,1406.88 277.489,1406.88 277.498,1406.88 277.508,1406.88 277.517,1406.88 277.526,1406.88 277.535,1406.88 277.544,1406.88 277.554,1406.88 277.563,1406.88 277.572,1406.88 277.581,1406.88 277.59,1406.88 277.6,1406.88 277.609,1406.88 277.618,1406.88 277.627,1406.88 277.636,1406.88 277.645,1406.88 277.655,1406.88 277.664,1406.88 277.673,1406.88 277.682,1406.88 277.691,1406.88 277.701,1406.88 277.71,1406.88 277.719,1406.88 277.728,1406.88 277.737,1406.88 277.747,1406.88 277.756,1406.88 277.765,1406.88 277.774,1406.88 277.783,1406.88 277.793,1406.88 277.802,1406.88 277.811,1406.88 277.82,1406.88 277.829,1406.88 277.838,1406.88 277.848,1406.88 277.857,1406.88 277.866,1406.88 277.875,1406.88 277.884,1406.88 277.894,1406.88 277.903,1406.88 277.912,1406.88 277.921,1406.88 277.93,1406.88 277.94,1406.88 277.949,1406.88 277.958,1406.88 277.967,1406.88 277.976,1406.88 277.985,1406.88 277.995,1406.88 278.004,1406.88 278.013,1406.88 278.022,1406.88 278.031,1406.88 278.041,1406.88 278.05,1406.88 278.059,1406.88 278.068,1406.88 278.077,1406.88 278.087,1406.88 278.096,1406.88 278.105,1406.88 278.114,1406.88 278.123,1406.88 278.133,1406.88 278.142,1406.88 278.151,1406.88 278.16,1406.88 278.169,1406.88 278.178,1406.88 278.188,1406.88 278.197,1406.88 278.206,1406.88 278.215,1406.88 278.224,1406.88 278.234,1406.88 278.243,1406.88 278.252,1406.88 278.261,1406.88 278.27,1406.88 278.28,1406.88 278.289,1406.88 278.298,1406.88 278.307,1406.88 278.316,1406.88 278.325,1406.88 278.335,1406.88 278.344,1406.88 278.353,1406.88 278.362,1406.88 278.371,1406.88 278.381,1406.88 278.39,1406.88 278.399,1406.88 278.408,1406.88 278.417,1406.88 278.427,1406.88 278.436,1406.88 278.445,1406.88 278.454,1406.88 278.463,1406.88 278.473,1406.88 278.482,1406.88 278.491,1406.88 278.5,1406.88 278.509,1406.88 278.518,1406.88 278.528,1406.88 278.537,1406.88 278.546,1406.88 278.555,1406.88 278.564,1406.88 278.574,1406.88 278.583,1406.88 278.592,1406.88 278.601,1406.88 278.61,1406.88 278.62,1406.88 278.629,1406.88 278.638,1406.88 278.647,1406.88 278.656,1406.88 278.665,1406.88 278.675,1406.88 278.684,1406.88 278.693,1406.88 278.702,1406.88 278.711,1406.88 278.721,1406.88 278.73,1406.88 278.739,1406.88 278.748,1406.88 278.757,1406.88 278.767,1406.88 278.776,1406.88 278.785,1406.88 278.794,1406.88 278.803,1406.88 278.813,1406.88 278.822,1406.88 278.831,1406.88 278.84,1406.88 278.849,1406.88 278.858,1406.88 278.868,1406.88 278.877,1406.88 278.886,1406.88 278.895,1406.88 278.904,1406.88 278.914,1406.88 278.923,1406.88 278.932,1406.88 278.941,1406.88 278.95,1406.88 278.96,1406.88 278.969,1406.88 278.978,1406.88 278.987,1406.88 278.996,1406.88 279.005,1406.88 279.015,1406.88 279.024,1406.88 279.033,1406.88 279.042,1406.88 279.051,1406.88 279.061,1406.88 279.07,1406.88 279.079,1406.88 279.088,1406.88 279.097,1406.88 279.107,1406.88 279.116,1406.88 279.125,1406.88 279.134,1406.88 279.143,1406.88 279.153,1406.88 279.162,1406.88 279.171,1406.88 279.18,1406.88 279.189,1406.88 279.198,1406.88 279.208,1406.88 279.217,1406.88 279.226,1406.88 279.235,1406.88 279.244,1406.88 279.254,1406.88 279.263,1406.88 279.272,1406.88 279.281,1406.88 279.29,1406.88 279.3,1406.88 279.309,1406.88 279.318,1406.88 279.327,1406.88 279.336,1406.88 279.345,1406.88 279.355,1406.88 279.364,1406.88 279.373,1406.88 279.382,1406.88 279.391,1406.88 279.401,1406.88 279.41,1406.88 279.419,1406.88 279.428,1406.88 279.437,1406.88 279.447,1406.88 279.456,1406.88 279.465,1406.88 279.474,1406.88 279.483,1406.88 279.493,1406.88 279.502,1406.88 279.511,1406.88 279.52,1406.88 279.529,1406.88 279.538,1406.88 279.548,1406.88 279.557,1406.88 279.566,1406.88 279.575,1406.88 279.584,1406.88 279.594,1406.88 279.603,1406.88 279.612,1406.88 279.621,1406.88 279.63,1406.88 279.64,1406.88 279.649,1406.88 279.658,1406.88 279.667,1406.88 279.676,1406.88 279.685,1406.88 279.695,1406.88 279.704,1406.88 279.713,1406.88 279.722,1406.88 279.731,1406.88 279.741,1406.88 279.75,1406.88 279.759,1406.88 279.768,1406.88 279.777,1406.88 279.787,1406.88 279.796,1406.88 279.805,1406.88 279.814,1406.88 279.823,1406.88 279.833,1406.88 279.842,1406.88 279.851,1406.88 279.86,1406.88 279.869,1406.88 279.878,1406.88 279.888,1406.88 279.897,1406.88 279.906,1406.88 279.915,1406.88 279.924,1406.88 279.934,1406.88 279.943,1406.88 279.952,1406.88 279.961,1406.88 279.97,1406.88 279.98,1406.88 279.989,1406.88 279.998,1406.88 280.007,1406.88 280.016,1406.88 280.026,1406.88 280.035,1406.88 280.044,1406.88 280.053,1406.88 280.062,1406.88 280.071,1406.88 280.081,1406.88 280.09,1406.88 280.099,1406.88 280.108,1406.88 280.117,1406.88 280.127,1406.88 280.136,1406.88 280.145,1406.88 280.154,1406.88 280.163,1406.88 280.173,1406.88 280.182,1406.88 280.191,1406.88 280.2,1406.88 280.209,1406.88 280.218,1406.88 280.228,1406.88 280.237,1406.88 280.246,1406.88 280.255,1406.88 280.264,1406.88 280.274,1406.88 280.283,1406.88 280.292,1406.88 280.301,1406.88 280.31,1406.88 280.32,1406.88 280.329,1406.88 280.338,1406.88 280.347,1406.88 280.356,1406.88 280.366,1406.88 280.375,1406.88 280.384,1406.88 280.393,1406.88 280.402,1406.88 280.411,1406.88 280.421,1406.88 280.43,1406.88 280.439,1406.88 280.448,1406.88 280.457,1406.88 280.467,1406.88 280.476,1406.88 280.485,1406.88 280.494,1406.88 280.503,1406.88 280.513,1406.88 280.522,1406.88 280.531,1406.88 280.54,1406.88 280.549,1406.88 280.558,1406.88 280.568,1406.88 280.577,1406.88 280.586,1406.88 280.595,1406.88 280.604,1406.88 280.614,1406.88 280.623,1406.88 280.632,1406.88 280.641,1406.88 280.65,1406.88 280.66,1406.88 280.669,1406.88 280.678,1406.88 280.687,1406.88 280.696,1406.88 280.706,1406.88 280.715,1406.88 280.724,1406.88 280.733,1406.88 280.742,1406.88 280.751,1406.88 280.761,1406.88 280.77,1406.88 280.779,1406.88 280.788,1406.88 280.797,1406.88 280.807,1406.88 280.816,1406.88 280.825,1406.88 280.834,1406.88 280.843,1406.88 280.853,1406.88 280.862,1406.88 280.871,1406.88 280.88,1406.88 280.889,1406.88 280.898,1406.88 280.908,1406.88 280.917,1406.88 280.926,1406.88 280.935,1406.88 280.944,1406.88 280.954,1406.88 280.963,1406.88 280.972,1406.88 280.981,1406.88 280.99,1406.88 281,1406.88 281.009,1406.88 281.018,1406.88 281.027,1406.88 281.036,1406.88 281.046,1406.88 281.055,1406.88 281.064,1406.88 281.073,1406.88 281.082,1406.88 281.091,1406.88 281.101,1406.88 281.11,1406.88 281.119,1406.88 281.128,1406.88 281.137,1406.88 281.147,1406.88 281.156,1406.88 281.165,1406.88 281.174,1406.88 281.183,1406.88 281.193,1406.88 281.202,1406.88 281.211,1406.88 281.22,1406.88 281.229,1406.88 281.238,1406.88 281.248,1406.88 281.257,1406.88 281.266,1406.88 281.275,1406.88 281.284,1406.88 281.294,1406.88 281.303,1406.88 281.312,1406.88 281.321,1406.88 281.33,1406.88 281.34,1406.88 281.349,1406.88 281.358,1406.88 281.367,1406.88 281.376,1406.88 281.386,1406.88 281.395,1406.88 281.404,1406.88 281.413,1406.88 281.422,1406.88 281.431,1406.88 281.441,1406.88 281.45,1406.88 281.459,1406.88 281.468,1406.88 281.477,1406.88 281.487,1406.88 281.496,1406.88 281.505,1406.88 281.514,1406.88 281.523,1406.88 281.533,1406.88 281.542,1406.88 281.551,1406.88 281.56,1406.88 281.569,1406.88 281.578,1406.88 281.588,1406.88 281.597,1406.88 281.606,1406.88 281.615,1406.88 281.624,1406.88 281.634,1406.88 281.643,1406.88 281.652,1406.88 281.661,1406.88 281.67,1406.88 281.68,1406.88 281.689,1406.88 281.698,1406.88 281.707,1406.88 281.716,1406.88 281.726,1406.88 281.735,1406.88 281.744,1406.88 281.753,1406.88 281.762,1406.88 281.771,1406.88 281.781,1406.88 281.79,1406.88 281.799,1406.88 281.808,1406.88 281.817,1406.88 281.827,1406.88 281.836,1406.88 281.845,1406.88 281.854,1406.88 281.863,1406.88 281.873,1406.88 281.882,1406.88 281.891,1406.88 281.9,1406.88 281.909,1406.88 281.918,1406.88 281.928,1406.88 281.937,1406.88 281.946,1406.88 281.955,1406.88 281.964,1406.88 281.974,1406.88 281.983,1406.88 281.992,1406.88 282.001,1406.88 282.01,1406.88 282.02,1406.88 282.029,1406.88 282.038,1406.88 282.047,1406.88 282.056,1406.88 282.066,1406.88 282.075,1406.88 282.084,1406.88 282.093,1406.88 282.102,1406.88 282.111,1406.88 282.121,1406.88 282.13,1406.88 282.139,1406.88 282.148,1406.88 282.157,1406.88 282.167,1406.88 282.176,1406.88 282.185,1406.88 282.194,1406.88 282.203,1406.88 282.213,1406.88 282.222,1406.88 282.231,1406.88 282.24,1406.88 282.249,1406.88 282.259,1406.88 282.268,1406.88 282.277,1406.88 282.286,1406.88 282.295,1406.88 282.304,1406.88 282.314,1406.88 282.323,1406.88 282.332,1406.88 282.341,1406.88 282.35,1406.88 282.36,1406.88 282.369,1406.88 282.378,1406.88 282.387,1406.88 282.396,1406.88 282.406,1406.88 282.415,1406.88 282.424,1406.88 282.433,1406.88 282.442,1406.88 282.451,1406.88 282.461,1406.88 282.47,1406.88 282.479,1406.88 282.488,1406.88 282.497,1406.88 282.507,1406.88 282.516,1406.88 282.525,1406.88 282.534,1406.88 282.543,1406.88 282.553,1406.88 282.562,1406.88 282.571,1406.88 282.58,1406.88 282.589,1406.88 282.599,1406.88 282.608,1406.88 282.617,1406.88 282.626,1406.88 282.635,1406.88 282.644,1406.88 282.654,1406.88 282.663,1406.88 282.672,1406.88 282.681,1406.88 282.69,1406.88 282.7,1406.88 282.709,1406.88 282.718,1406.88 282.727,1406.88 282.736,1406.88 282.746,1406.88 282.755,1406.88 282.764,1406.88 282.773,1406.88 282.782,1406.88 282.791,1406.88 282.801,1406.88 282.81,1406.88 282.819,1406.88 282.828,1406.88 282.837,1406.88 282.847,1406.88 282.856,1406.88 282.865,1406.88 282.874,1406.88 282.883,1406.88 282.893,1406.88 282.902,1406.88 282.911,1406.88 282.92,1406.88 282.929,1406.88 282.939,1406.88 282.948,1406.88 282.957,1406.88 282.966,1406.88 282.975,1406.88 282.984,1406.88 282.994,1406.88 283.003,1406.88 283.012,1406.88 283.021,1406.88 283.03,1406.88 283.04,1406.88 283.049,1406.88 283.058,1406.88 283.067,1406.88 283.076,1406.88 283.086,1406.88 283.095,1406.88 283.104,1406.88 283.113,1406.88 283.122,1406.88 283.131,1406.88 283.141,1406.88 283.15,1406.88 283.159,1406.88 283.168,1406.88 283.177,1406.88 283.187,1406.88 283.196,1406.88 283.205,1406.88 283.214,1406.88 283.223,1406.88 283.233,1406.88 283.242,1406.88 283.251,1406.88 283.26,1406.88 283.269,1406.88 283.279,1406.88 283.288,1406.88 283.297,1406.88 283.306,1406.88 283.315,1406.88 283.324,1406.88 283.334,1406.88 283.343,1406.88 283.352,1406.88 283.361,1406.88 283.37,1406.88 283.38,1406.88 283.389,1406.88 283.398,1406.88 283.407,1406.88 283.416,1406.88 283.426,1406.88 283.435,1406.88 283.444,1406.88 283.453,1406.88 283.462,1406.88 283.471,1406.88 283.481,1406.88 283.49,1406.88 283.499,1406.88 283.508,1406.88 283.517,1406.88 283.527,1406.88 283.536,1406.88 283.545,1406.88 283.554,1406.88 283.563,1406.88 283.573,1406.88 283.582,1406.88 283.591,1406.88 283.6,1406.88 283.609,1406.88 283.619,1406.88 283.628,1406.88 283.637,1406.88 283.646,1406.88 283.655,1406.88 283.664,1406.88 283.674,1406.88 283.683,1406.88 283.692,1406.88 283.701,1406.88 283.71,1406.88 283.72,1406.88 283.729,1406.88 283.738,1406.88 283.747,1406.88 283.756,1406.88 283.766,1406.88 283.775,1406.88 283.784,1406.88 283.793,1406.88 283.802,1406.88 283.811,1406.88 283.821,1406.88 283.83,1406.88 283.839,1406.88 283.848,1406.88 283.857,1406.88 283.867,1406.88 283.876,1406.88 283.885,1406.88 283.894,1406.88 283.903,1406.88 283.913,1406.88 283.922,1406.88 283.931,1406.88 283.94,1406.88 283.949,1406.88 283.959,1406.88 283.968,1406.88 283.977,1406.88 283.986,1406.88 283.995,1406.88 284.004,1406.88 284.014,1406.88 284.023,1406.88 284.032,1406.88 284.041,1406.88 284.05,1406.88 284.06,1406.88 284.069,1406.88 284.078,1406.88 284.087,1406.88 284.096,1406.88 284.106,1406.88 284.115,1406.88 284.124,1406.88 284.133,1406.88 284.142,1406.88 284.151,1406.88 284.161,1406.88 284.17,1406.88 284.179,1406.88 284.188,1406.88 284.197,1406.88 284.207,1406.88 284.216,1406.88 284.225,1406.88 284.234,1406.88 284.243,1406.88 284.253,1406.88 284.262,1406.88 284.271,1406.88 284.28,1406.88 284.289,1406.88 284.299,1406.88 284.308,1406.88 284.317,1406.88 284.326,1406.88 284.335,1406.88 284.344,1406.88 284.354,1406.88 284.363,1406.88 284.372,1406.88 284.381,1406.88 284.39,1406.88 284.4,1406.88 284.409,1406.88 284.418,1406.88 284.427,1406.88 284.436,1406.88 284.446,1406.88 284.455,1406.88 284.464,1406.88 284.473,1406.88 284.482,1406.88 284.491,1406.88 284.501,1406.88 284.51,1406.88 284.519,1406.88 284.528,1406.88 284.537,1406.88 284.547,1406.88 284.556,1406.88 284.565,1406.88 284.574,1406.88 284.583,1406.88 284.593,1406.88 284.602,1406.88 284.611,1406.88 284.62,1406.88 284.629,1406.88 284.639,1406.88 284.648,1406.88 284.657,1406.88 284.666,1406.88 284.675,1406.88 284.684,1406.88 284.694,1406.88 284.703,1406.88 284.712,1406.88 284.721,1406.88 284.73,1406.88 284.74,1406.88 284.749,1406.88 284.758,1406.88 284.767,1406.88 284.776,1406.88 284.786,1406.88 284.795,1406.88 284.804,1406.88 284.813,1406.88 284.822,1406.88 284.832,1406.88 284.841,1406.88 284.85,1406.88 284.859,1406.88 284.868,1406.88 284.877,1406.88 284.887,1406.88 284.896,1406.88 284.905,1406.88 284.914,1406.88 284.923,1406.88 284.933,1406.88 284.942,1406.88 284.951,1406.88 284.96,1406.88 284.969,1406.88 284.979,1406.88 284.988,1406.88 284.997,1406.88 285.006,1406.88 285.015,1406.88 285.024,1406.88 285.034,1406.88 285.043,1406.88 285.052,1406.88 285.061,1406.88 285.07,1406.88 285.08,1406.88 285.089,1406.88 285.098,1406.88 285.107,1406.88 285.116,1406.88 285.126,1406.88 285.135,1406.88 285.144,1406.88 285.153,1406.88 285.162,1406.88 285.172,1406.88 285.181,1406.88 285.19,1406.88 285.199,1406.88 285.208,1406.88 285.217,1406.88 285.227,1406.88 285.236,1406.88 285.245,1406.88 285.254,1406.88 285.263,1406.88 285.273,1406.88 285.282,1406.88 285.291,1406.88 285.3,1406.88 285.309,1406.88 285.319,1406.88 285.328,1406.88 285.337,1406.88 285.346,1406.88 285.355,1406.88 285.364,1406.88 285.374,1406.88 285.383,1406.88 285.392,1406.88 285.401,1406.88 285.41,1406.88 285.42,1406.88 285.429,1406.88 285.438,1406.88 285.447,1406.88 285.456,1406.88 285.466,1406.88 285.475,1406.88 285.484,1406.88 285.493,1406.88 285.502,1406.88 285.512,1406.88 285.521,1406.88 285.53,1406.88 285.539,1406.88 285.548,1406.88 285.557,1406.88 285.567,1406.88 285.576,1406.88 285.585,1406.88 285.594,1406.88 285.603,1406.88 285.613,1406.88 285.622,1406.88 285.631,1406.88 285.64,1406.88 285.649,1406.88 285.659,1406.88 285.668,1406.88 285.677,1406.88 285.686,1406.88 285.695,1406.88 285.704,1406.88 285.714,1406.88 285.723,1406.88 285.732,1406.88 285.741,1406.88 285.75,1406.88 285.76,1406.88 285.769,1406.88 285.778,1406.88 285.787,1406.88 285.796,1406.88 285.806,1406.88 285.815,1406.88 285.824,1406.88 285.833,1406.88 285.842,1406.88 285.852,1406.88 285.861,1406.88 285.87,1406.88 285.879,1406.88 285.888,1406.88 285.897,1406.88 285.907,1406.88 285.916,1406.88 285.925,1406.88 285.934,1406.88 285.943,1406.88 285.953,1406.88 285.962,1406.88 285.971,1406.88 285.98,1406.88 285.989,1406.88 285.999,1406.88 286.008,1406.88 286.017,1406.88 286.026,1406.88 286.035,1406.88 286.044,1406.88 286.054,1406.88 286.063,1406.88 286.072,1406.88 286.081,1406.88 286.09,1406.88 286.1,1406.88 286.109,1406.88 286.118,1406.88 286.127,1406.88 286.136,1406.88 286.146,1406.88 286.155,1406.88 286.164,1406.88 286.173,1406.88 286.182,1406.88 286.192,1406.88 286.201,1406.88 286.21,1406.88 286.219,1406.88 286.228,1406.88 286.237,1406.88 286.247,1406.88 286.256,1406.88 286.265,1406.88 286.274,1406.88 286.283,1406.88 286.293,1406.88 286.302,1406.88 286.311,1406.88 286.32,1406.88 286.329,1406.88 286.339,1406.88 286.348,1406.88 286.357,1406.88 286.366,1406.88 286.375,1406.88 286.384,1406.88 286.394,1406.88 286.403,1406.88 286.412,1406.88 286.421,1406.88 286.43,1406.88 286.44,1406.88 286.449,1406.88 286.458,1406.88 286.467,1406.88 286.476,1406.88 286.486,1406.88 286.495,1406.88 286.504,1406.88 286.513,1406.88 286.522,1406.88 286.532,1406.88 286.541,1406.88 286.55,1406.88 286.559,1406.88 286.568,1406.88 286.577,1406.88 286.587,1406.88 286.596,1406.88 286.605,1406.88 286.614,1406.88 286.623,1406.88 286.633,1406.88 286.642,1406.88 286.651,1406.88 286.66,1406.88 286.669,1406.88 286.679,1406.88 286.688,1406.88 286.697,1406.88 286.706,1406.88 286.715,1406.88 286.724,1406.88 286.734,1406.88 286.743,1406.88 286.752,1406.88 286.761,1406.88 286.77,1406.88 286.78,1406.88 286.789,1406.88 286.798,1406.88 286.807,1406.88 286.816,1406.88 286.826,1406.88 286.835,1406.88 286.844,1406.88 286.853,1406.88 286.862,1406.88 286.872,1406.88 286.881,1406.88 286.89,1406.88 286.899,1406.88 286.908,1406.88 286.917,1406.88 286.927,1406.88 286.936,1406.88 286.945,1406.88 286.954,1406.88 286.963,1406.88 286.973,1406.88 286.982,1406.88 286.991,1406.88 287,1406.88 287.009,1406.88 287.019,1406.88 287.028,1406.88 287.037,1406.88 287.046,1406.88 287.055,1406.88 287.064,1406.88 287.074,1406.88 287.083,1406.88 287.092,1406.88 287.101,1406.88 287.11,1406.88 287.12,1406.88 287.129,1406.88 287.138,1406.88 287.147,1406.88 287.156,1406.88 287.166,1406.88 287.175,1406.88 287.184,1406.88 287.193,1406.88 287.202,1406.88 287.212,1406.88 287.221,1406.88 287.23,1406.88 287.239,1406.88 287.248,1406.88 287.257,1406.88 287.267,1406.88 287.276,1406.88 287.285,1406.88 287.294,1406.88 287.303,1406.88 287.313,1406.88 287.322,1406.88 287.331,1406.88 287.34,1406.88 287.349,1406.88 287.359,1406.88 287.368,1406.88 287.377,1406.88 287.386,1406.88 287.395,1406.88 287.405,1406.88 287.414,1406.88 287.423,1406.88 287.432,1406.88 287.441,1406.88 287.45,1406.88 287.46,1406.88 287.469,1406.88 287.478,1406.88 287.487,1406.88 287.496,1406.88 287.506,1406.88 287.515,1406.88 287.524,1406.88 287.533,1406.88 287.542,1406.88 287.552,1406.88 287.561,1406.88 287.57,1406.88 287.579,1406.88 287.588,1406.88 287.597,1406.88 287.607,1406.88 287.616,1406.88 287.625,1406.88 287.634,1406.88 287.643,1406.88 287.653,1406.88 287.662,1406.88 287.671,1406.88 287.68,1406.88 287.689,1406.88 287.699,1406.88 287.708,1406.88 287.717,1406.88 287.726,1406.88 287.735,1406.88 287.745,1406.88 287.754,1406.88 287.763,1406.88 287.772,1406.88 287.781,1406.88 287.79,1406.88 287.8,1406.88 287.809,1406.88 287.818,1406.88 287.827,1406.88 287.836,1406.88 287.846,1406.88 287.855,1406.88 287.864,1406.88 287.873,1406.88 287.882,1406.88 287.892,1406.88 287.901,1406.88 287.91,1406.88 287.919,1406.88 287.928,1406.88 287.937,1406.88 287.947,1406.88 287.956,1406.88 287.965,1406.88 287.974,1406.88 287.983,1406.88 287.993,1406.88 288.002,1406.88 288.011,1406.88 288.02,1406.88 288.029,1406.88 288.039,1406.88 288.048,1406.88 288.057,1406.88 288.066,1406.88 288.075,1406.88 288.085,1406.88 288.094,1406.88 288.103,1406.88 288.112,1406.88 288.121,1406.88 288.13,1406.88 288.14,1406.88 288.149,1406.88 288.158,1406.88 288.167,1406.88 288.176,1406.88 288.186,1406.88 288.195,1406.88 288.204,1406.88 288.213,1406.88 288.222,1406.88 288.232,1406.88 288.241,1406.88 288.25,1406.88 288.259,1406.88 288.268,1406.88 288.277,1406.88 288.287,1406.88 288.296,1406.88 288.305,1406.88 288.314,1406.88 288.323,1406.88 288.333,1406.88 288.342,1406.88 288.351,1406.88 288.36,1406.88 288.369,1406.88 288.379,1406.88 288.388,1406.88 288.397,1406.88 288.406,1406.88 288.415,1406.88 288.425,1406.88 288.434,1406.88 288.443,1406.88 288.452,1406.88 288.461,1406.88 288.47,1406.88 288.48,1406.88 288.489,1406.88 288.498,1406.88 288.507,1406.88 288.516,1406.88 288.526,1406.88 288.535,1406.88 288.544,1406.88 288.553,1406.88 288.562,1406.88 288.572,1406.88 288.581,1406.88 288.59,1406.88 288.599,1406.88 288.608,1406.88 288.617,1406.88 288.627,1406.88 288.636,1406.88 288.645,1406.88 288.654,1406.88 288.663,1406.88 288.673,1406.88 288.682,1406.88 288.691,1406.88 288.7,1406.88 288.709,1406.88 288.719,1406.88 288.728,1406.88 288.737,1406.88 288.746,1406.88 288.755,1406.88 288.765,1406.88 288.774,1406.88 288.783,1406.88 288.792,1406.88 288.801,1406.88 288.81,1406.88 288.82,1406.88 288.829,1406.88 288.838,1406.88 288.847,1406.88 288.856,1406.88 288.866,1406.88 288.875,1406.88 288.884,1406.88 288.893,1406.88 288.902,1406.88 288.912,1406.88 288.921,1406.88 288.93,1406.88 288.939,1406.88 288.948,1406.88 288.957,1406.88 288.967,1406.88 288.976,1406.88 288.985,1406.88 288.994,1406.88 289.003,1406.88 289.013,1406.88 289.022,1406.88 289.031,1406.88 289.04,1406.88 289.049,1406.88 289.059,1406.88 289.068,1406.88 289.077,1406.88 289.086,1406.88 289.095,1406.88 289.105,1406.88 289.114,1406.88 289.123,1406.88 289.132,1406.88 289.141,1406.88 289.15,1406.88 289.16,1406.88 289.169,1406.88 289.178,1406.88 289.187,1406.88 289.196,1406.88 289.206,1406.88 289.215,1406.88 289.224,1406.88 289.233,1406.88 289.242,1406.88 289.252,1406.88 289.261,1406.88 289.27,1406.88 289.279,1406.88 289.288,1406.88 289.297,1406.88 289.307,1406.88 289.316,1406.88 289.325,1406.88 289.334,1406.88 289.343,1406.88 289.353,1406.88 289.362,1406.88 289.371,1406.88 289.38,1406.88 289.389,1406.88 289.399,1406.88 289.408,1406.88 289.417,1406.88 289.426,1406.88 289.435,1406.88 289.445,1406.88 289.454,1406.88 289.463,1406.88 289.472,1406.88 289.481,1406.88 289.49,1406.88 289.5,1406.88 289.509,1406.88 289.518,1406.88 289.527,1406.88 289.536,1406.88 289.546,1406.88 289.555,1406.88 289.564,1406.88 289.573,1406.88 289.582,1406.88 289.592,1406.88 289.601,1406.88 289.61,1406.88 289.619,1406.88 289.628,1406.88 289.638,1406.88 289.647,1406.88 289.656,1406.88 289.665,1406.88 289.674,1406.88 289.683,1406.88 289.693,1406.88 289.702,1406.88 289.711,1406.88 289.72,1406.88 289.729,1406.88 289.739,1406.88 289.748,1406.88 289.757,1406.88 289.766,1406.88 289.775,1406.88 289.785,1406.88 289.794,1406.88 289.803,1406.88 289.812,1406.88 289.821,1406.88 289.83,1406.88 289.84,1406.88 289.849,1406.88 289.858,1406.88 289.867,1406.88 289.876,1406.88 289.886,1406.88 289.895,1406.88 289.904,1406.88 289.913,1406.88 289.922,1406.88 289.932,1406.88 289.941,1406.88 289.95,1406.88 289.959,1406.88 289.968,1406.88 289.978,1406.88 289.987,1406.88 289.996,1406.88 290.005,1406.88 290.014,1406.88 290.023,1406.88 290.033,1406.88 290.042,1406.88 290.051,1406.88 290.06,1406.88 290.069,1406.88 290.079,1406.88 290.088,1406.88 290.097,1406.88 290.106,1406.88 290.115,1406.88 290.125,1406.88 290.134,1406.88 290.143,1406.88 290.152,1406.88 290.161,1406.88 290.17,1406.88 290.18,1406.88 290.189,1406.88 290.198,1406.88 290.207,1406.88 290.216,1406.88 290.226,1406.88 290.235,1406.88 290.244,1406.88 290.253,1406.88 290.262,1406.88 290.272,1406.88 290.281,1406.88 290.29,1406.88 290.299,1406.88 290.308,1406.88 290.318,1406.88 290.327,1406.88 290.336,1406.88 290.345,1406.88 290.354,1406.88 290.363,1406.88 290.373,1406.88 290.382,1406.88 290.391,1406.88 290.4,1406.88 290.409,1406.88 290.419,1406.88 290.428,1406.88 290.437,1406.88 290.446,1406.88 290.455,1406.88 290.465,1406.88 290.474,1406.88 290.483,1406.88 290.492,1406.88 290.501,1406.88 290.51,1406.88 290.52,1406.88 290.529,1406.88 290.538,1406.88 290.547,1406.88 290.556,1406.88 290.566,1406.88 290.575,1406.88 290.584,1406.88 290.593,1406.88 290.602,1406.88 290.612,1406.88 290.621,1406.88 290.63,1406.88 290.639,1406.88 290.648,1406.88 290.658,1406.88 290.667,1406.88 290.676,1406.88 290.685,1406.88 290.694,1406.88 290.703,1406.88 290.713,1406.88 290.722,1406.88 290.731,1406.88 290.74,1406.88 290.749,1406.88 290.759,1406.88 290.768,1406.88 290.777,1406.88 290.786,1406.88 290.795,1406.88 290.805,1406.88 290.814,1406.88 290.823,1406.88 290.832,1406.88 290.841,1406.88 290.85,1406.88 290.86,1406.88 290.869,1406.88 290.878,1406.88 290.887,1406.88 290.896,1406.88 290.906,1406.88 290.915,1406.88 290.924,1406.88 290.933,1406.88 290.942,1406.88 290.952,1406.88 290.961,1406.88 290.97,1406.88 290.979,1406.88 290.988,1406.88 290.998,1406.88 291.007,1406.88 291.016,1406.88 291.025,1406.88 291.034,1406.88 291.043,1406.88 291.053,1406.88 291.062,1406.88 291.071,1406.88 291.08,1406.88 291.089,1406.88 291.099,1406.88 291.108,1406.88 291.117,1406.88 291.126,1406.88 291.135,1406.88 291.145,1406.88 291.154,1406.88 291.163,1406.88 291.172,1406.88 291.181,1406.88 291.19,1406.88 291.2,1406.88 291.209,1406.88 291.218,1406.88 291.227,1406.88 291.236,1406.88 291.246,1406.88 291.255,1406.88 291.264,1406.88 291.273,1406.88 291.282,1406.88 291.292,1406.88 291.301,1406.88 291.31,1406.88 291.319,1406.88 291.328,1406.88 291.338,1406.88 291.347,1406.88 291.356,1406.88 291.365,1406.88 291.374,1406.88 291.383,1406.88 291.393,1406.88 291.402,1406.88 291.411,1406.88 291.42,1406.88 291.429,1406.88 291.439,1406.88 291.448,1406.88 291.457,1406.88 291.466,1406.88 291.475,1406.88 291.485,1406.88 291.494,1406.88 291.503,1406.88 291.512,1406.88 291.521,1406.88 291.53,1406.88 291.54,1406.88 291.549,1406.88 291.558,1406.88 291.567,1406.88 291.576,1406.88 291.586,1406.88 291.595,1406.88 291.604,1406.88 291.613,1406.88 291.622,1406.88 291.632,1406.88 291.641,1406.88 291.65,1406.88 291.659,1406.88 291.668,1406.88 291.678,1406.88 291.687,1406.88 291.696,1406.88 291.705,1406.88 291.714,1406.88 291.723,1406.88 291.733,1406.88 291.742,1406.88 291.751,1406.88 291.76,1406.88 291.769,1406.88 291.779,1406.88 291.788,1406.88 291.797,1406.88 291.806,1406.88 291.815,1406.88 291.825,1406.88 291.834,1406.88 291.843,1406.88 291.852,1406.88 291.861,1406.88 291.87,1406.88 291.88,1406.88 291.889,1406.88 291.898,1406.88 291.907,1406.88 291.916,1406.88 291.926,1406.88 291.935,1406.88 291.944,1406.88 291.953,1406.88 291.962,1406.88 291.972,1406.88 291.981,1406.88 291.99,1406.88 291.999,1406.88 292.008,1406.88 292.018,1406.88 292.027,1406.88 292.036,1406.88 292.045,1406.88 292.054,1406.88 292.063,1406.88 292.073,1406.88 292.082,1406.88 292.091,1406.88 292.1,1406.88 292.109,1406.88 292.119,1406.88 292.128,1406.88 292.137,1406.88 292.146,1406.88 292.155,1406.88 292.165,1406.88 292.174,1406.88 292.183,1406.88 292.192,1406.88 292.201,1406.88 292.211,1406.88 292.22,1406.88 292.229,1406.88 292.238,1406.88 292.247,1406.88 292.256,1406.88 292.266,1406.88 292.275,1406.88 292.284,1406.88 292.293,1406.88 292.302,1406.88 292.312,1406.88 292.321,1406.88 292.33,1406.88 292.339,1406.88 292.348,1406.88 292.358,1406.88 292.367,1406.88 292.376,1406.88 292.385,1406.88 292.394,1406.88 292.403,1406.88 292.413,1406.88 292.422,1406.88 292.431,1406.88 292.44,1406.88 292.449,1406.88 292.459,1406.88 292.468,1406.88 292.477,1406.88 292.486,1406.88 292.495,1406.88 292.505,1406.88 292.514,1406.88 292.523,1406.88 292.532,1406.88 292.541,1406.88 292.551,1406.88 292.56,1406.88 292.569,1406.88 292.578,1406.88 292.587,1406.88 292.596,1406.88 292.606,1406.88 292.615,1406.88 292.624,1406.88 292.633,1406.88 292.642,1406.88 292.652,1406.88 292.661,1406.88 292.67,1406.88 292.679,1406.88 292.688,1406.88 292.698,1406.88 292.707,1406.88 292.716,1406.88 292.725,1406.88 292.734,1406.88 292.743,1406.88 292.753,1406.88 292.762,1406.88 292.771,1406.88 292.78,1406.88 292.789,1406.88 292.799,1406.88 292.808,1406.88 292.817,1406.88 292.826,1406.88 292.835,1406.88 292.845,1406.88 292.854,1406.88 292.863,1406.88 292.872,1406.88 292.881,1406.88 292.891,1406.88 292.9,1406.88 292.909,1406.88 292.918,1406.88 292.927,1406.88 292.936,1406.88 292.946,1406.88 292.955,1406.88 292.964,1406.88 292.973,1406.88 292.982,1406.88 292.992,1406.88 293.001,1406.88 293.01,1406.88 293.019,1406.88 293.028,1406.88 293.038,1406.88 293.047,1406.88 293.056,1406.88 293.065,1406.88 293.074,1406.88 293.083,1406.88 293.093,1406.88 293.102,1406.88 293.111,1406.88 293.12,1406.88 293.129,1406.88 293.139,1406.88 293.148,1406.88 293.157,1406.88 293.166,1406.88 293.175,1406.88 293.185,1406.88 293.194,1406.88 293.203,1406.88 293.212,1406.88 293.221,1406.88 293.231,1406.88 293.24,1406.88 293.249,1406.88 293.258,1406.88 293.267,1406.88 293.276,1406.88 293.286,1406.88 293.295,1406.88 293.304,1406.88 293.313,1406.88 293.322,1406.88 293.332,1406.88 293.341,1406.88 293.35,1406.88 293.359,1406.88 293.368,1406.88 293.378,1406.88 293.387,1406.88 293.396,1406.88 293.405,1406.88 293.414,1406.88 293.423,1406.88 293.433,1406.88 293.442,1406.88 293.451,1406.88 293.46,1406.88 293.469,1406.88 293.479,1406.88 293.488,1406.88 293.497,1406.88 293.506,1406.88 293.515,1406.88 293.525,1406.88 293.534,1406.88 293.543,1406.88 293.552,1406.88 293.561,1406.88 293.571,1406.88 293.58,1406.88 293.589,1406.88 293.598,1406.88 293.607,1406.88 293.616,1406.88 293.626,1406.88 293.635,1406.88 293.644,1406.88 293.653,1406.88 293.662,1406.88 293.672,1406.88 293.681,1406.88 293.69,1406.88 293.699,1406.88 293.708,1406.88 293.718,1406.88 293.727,1406.88 293.736,1406.88 293.745,1406.88 293.754,1406.88 293.763,1406.88 293.773,1406.88 293.782,1406.88 293.791,1406.88 293.8,1406.88 293.809,1406.88 293.819,1406.88 293.828,1406.88 293.837,1406.88 293.846,1406.88 293.855,1406.88 293.865,1406.88 293.874,1406.88 293.883,1406.88 293.892,1406.88 293.901,1406.88 293.911,1406.88 293.92,1406.88 293.929,1406.88 293.938,1406.88 293.947,1406.88 293.956,1406.88 293.966,1406.88 293.975,1406.88 293.984,1406.88 293.993,1406.88 294.002,1406.88 294.012,1406.88 294.021,1406.88 294.03,1406.88 294.039,1406.88 294.048,1406.88 294.058,1406.88 294.067,1406.88 294.076,1406.88 294.085,1406.88 294.094,1406.88 294.103,1406.88 294.113,1406.88 294.122,1406.88 294.131,1406.88 294.14,1406.88 294.149,1406.88 294.159,1406.88 294.168,1406.88 294.177,1406.88 294.186,1406.88 294.195,1406.88 294.205,1406.88 294.214,1406.88 294.223,1406.88 294.232,1406.88 294.241,1406.88 294.251,1406.88 294.26,1406.88 294.269,1406.88 294.278,1406.88 294.287,1406.88 294.296,1406.88 294.306,1406.88 294.315,1406.88 294.324,1406.88 294.333,1406.88 294.342,1406.88 294.352,1406.88 294.361,1406.88 294.37,1406.88 294.379,1406.88 294.388,1406.88 294.398,1406.88 294.407,1406.88 294.416,1406.88 294.425,1406.88 294.434,1406.88 294.443,1406.88 294.453,1406.88 294.462,1406.88 294.471,1406.88 294.48,1406.88 294.489,1406.88 294.499,1406.88 294.508,1406.88 294.517,1406.88 294.526,1406.88 294.535,1406.88 294.545,1406.88 294.554,1406.88 294.563,1406.88 294.572,1406.88 294.581,1406.88 294.591,1406.88 294.6,1406.88 294.609,1406.88 294.618,1406.88 294.627,1406.88 294.636,1406.88 294.646,1406.88 294.655,1406.88 294.664,1406.88 294.673,1406.88 294.682,1406.88 294.692,1406.88 294.701,1406.88 294.71,1406.88 294.719,1406.88 294.728,1406.88 294.738,1406.88 294.747,1406.88 294.756,1406.88 294.765,1406.88 294.774,1406.88 294.784,1406.88 294.793,1406.88 294.802,1406.88 294.811,1406.88 294.82,1406.88 294.829,1406.88 294.839,1406.88 294.848,1406.88 294.857,1406.88 294.866,1406.88 294.875,1406.88 294.885,1406.88 294.894,1406.88 294.903,1406.88 294.912,1406.88 294.921,1406.88 294.931,1406.88 294.94,1406.88 294.949,1406.88 294.958,1406.88 294.967,1406.88 294.976,1406.88 294.986,1406.88 294.995,1406.88 295.004,1406.88 295.013,1406.88 295.022,1406.88 295.032,1406.88 295.041,1406.88 295.05,1406.88 295.059,1406.88 295.068,1406.88 295.078,1406.88 295.087,1406.88 295.096,1406.88 295.105,1406.88 295.114,1406.88 295.124,1406.88 295.133,1406.88 295.142,1406.88 295.151,1406.88 295.16,1406.88 295.169,1406.88 295.179,1406.88 295.188,1406.88 295.197,1406.88 295.206,1406.88 295.215,1406.88 295.225,1406.88 295.234,1406.88 295.243,1406.88 295.252,1406.88 295.261,1406.88 295.271,1406.88 295.28,1406.88 295.289,1406.88 295.298,1406.88 295.307,1406.88 295.316,1406.88 295.326,1406.88 295.335,1406.88 295.344,1406.88 295.353,1406.88 295.362,1406.88 295.372,1406.88 295.381,1406.88 295.39,1406.88 295.399,1406.88 295.408,1406.88 295.418,1406.88 295.427,1406.88 295.436,1406.88 295.445,1406.88 295.454,1406.88 295.464,1406.88 295.473,1406.88 295.482,1406.88 295.491,1406.88 295.5,1406.88 295.509,1406.88 295.519,1406.88 295.528,1406.88 295.537,1406.88 295.546,1406.88 295.555,1406.88 295.565,1406.88 295.574,1406.88 295.583,1406.88 295.592,1406.88 295.601,1406.88 295.611,1406.88 295.62,1406.88 295.629,1406.88 295.638,1406.88 295.647,1406.88 295.656,1406.88 295.666,1406.88 295.675,1406.88 295.684,1406.88 295.693,1406.88 295.702,1406.88 295.712,1406.88 295.721,1406.88 295.73,1406.88 295.739,1406.88 295.748,1406.88 295.758,1406.88 295.767,1406.88 295.776,1406.88 295.785,1406.88 295.794,1406.88 295.804,1406.88 295.813,1406.88 295.822,1406.88 295.831,1406.88 295.84,1406.88 295.849,1406.88 295.859,1406.88 295.868,1406.88 295.877,1406.88 295.886,1406.88 295.895,1406.88 295.905,1406.88 295.914,1406.88 295.923,1406.88 295.932,1406.88 295.941,1406.88 295.951,1406.88 295.96,1406.88 295.969,1406.88 295.978,1406.88 295.987,1406.88 295.996,1406.88 296.006,1406.88 296.015,1406.88 296.024,1406.88 296.033,1406.88 296.042,1406.88 296.052,1406.88 296.061,1406.88 296.07,1406.88 296.079,1406.88 296.088,1406.88 296.098,1406.88 296.107,1406.88 296.116,1406.88 296.125,1406.88 296.134,1406.88 296.144,1406.88 296.153,1406.88 296.162,1406.88 296.171,1406.88 296.18,1406.88 296.189,1406.88 296.199,1406.88 296.208,1406.88 296.217,1406.88 296.226,1406.88 296.235,1406.88 296.245,1406.88 296.254,1406.88 296.263,1406.88 296.272,1406.88 296.281,1406.88 296.291,1406.88 296.3,1406.88 296.309,1406.88 296.318,1406.88 296.327,1406.88 296.336,1406.88 296.346,1406.88 296.355,1406.88 296.364,1406.88 296.373,1406.88 296.382,1406.88 296.392,1406.88 296.401,1406.88 296.41,1406.88 296.419,1406.88 296.428,1406.88 296.438,1406.88 296.447,1406.88 296.456,1406.88 296.465,1406.88 296.474,1406.88 296.484,1406.88 296.493,1406.88 296.502,1406.88 296.511,1406.88 296.52,1406.88 296.529,1406.88 296.539,1406.88 296.548,1406.88 296.557,1406.88 296.566,1406.88 296.575,1406.88 296.585,1406.88 296.594,1406.88 296.603,1406.88 296.612,1406.88 296.621,1406.88 296.631,1406.88 296.64,1406.88 296.649,1406.88 296.658,1406.88 296.667,1406.88 296.676,1406.88 296.686,1406.88 296.695,1406.88 296.704,1406.88 296.713,1406.88 296.722,1406.88 296.732,1406.88 296.741,1406.88 296.75,1406.88 296.759,1406.88 296.768,1406.88 296.778,1406.88 296.787,1406.88 296.796,1406.88 296.805,1406.88 296.814,1406.88 296.824,1406.88 296.833,1406.88 296.842,1406.88 296.851,1406.88 296.86,1406.88 296.869,1406.88 296.879,1406.88 296.888,1406.88 296.897,1406.88 296.906,1406.88 296.915,1406.88 296.925,1406.88 296.934,1406.88 296.943,1406.88 296.952,1406.88 296.961,1406.88 296.971,1406.88 296.98,1406.88 296.989,1406.88 296.998,1406.88 297.007,1406.88 297.017,1406.88 297.026,1406.88 297.035,1406.88 297.044,1406.88 297.053,1406.88 297.062,1406.88 297.072,1406.88 297.081,1406.88 297.09,1406.88 297.099,1406.88 297.108,1406.88 297.118,1406.88 297.127,1406.88 297.136,1406.88 297.145,1406.88 297.154,1406.88 297.164,1406.88 297.173,1406.88 297.182,1406.88 297.191,1406.88 297.2,1406.88 297.209,1406.88 297.219,1406.88 297.228,1406.88 297.237,1406.88 297.246,1406.88 297.255,1406.88 297.265,1406.88 297.274,1406.88 297.283,1406.88 297.292,1406.88 297.301,1406.88 297.311,1406.88 297.32,1406.88 297.329,1406.88 297.338,1406.88 297.347,1406.88 297.357,1406.88 297.366,1406.88 297.375,1406.88 297.384,1406.88 297.393,1406.88 297.402,1406.88 297.412,1406.88 297.421,1406.88 297.43,1406.88 297.439,1406.88 297.448,1406.88 297.458,1406.88 297.467,1406.88 297.476,1406.88 297.485,1406.88 297.494,1406.88 297.504,1406.88 297.513,1406.88 297.522,1406.88 297.531,1406.88 297.54,1406.88 297.549,1406.88 297.559,1406.88 297.568,1406.88 297.577,1406.88 297.586,1406.88 297.595,1406.88 297.605,1406.88 297.614,1406.88 297.623,1406.88 297.632,1406.88 297.641,1406.88 297.651,1406.88 297.66,1406.88 297.669,1406.88 297.678,1406.88 297.687,1406.88 297.697,1406.88 297.706,1406.88 297.715,1406.88 297.724,1406.88 297.733,1406.88 297.742,1406.88 297.752,1406.88 297.761,1406.88 297.77,1406.88 297.779,1406.88 297.788,1406.88 297.798,1406.88 297.807,1406.88 297.816,1406.88 297.825,1406.88 297.834,1406.88 297.844,1406.88 297.853,1406.88 297.862,1406.88 297.871,1406.88 297.88,1406.88 297.889,1406.88 297.899,1406.88 297.908,1406.88 297.917,1406.88 297.926,1406.88 297.935,1406.88 297.945,1406.88 297.954,1406.88 297.963,1406.88 297.972,1406.88 297.981,1406.88 297.991,1406.88 298,1406.88 298.009,1406.88 298.018,1406.88 298.027,1406.88 298.037,1406.88 298.046,1406.88 298.055,1406.88 298.064,1406.88 298.073,1406.88 298.082,1406.88 298.092,1406.88 298.101,1406.88 298.11,1406.88 298.119,1406.88 298.128,1406.88 298.138,1406.88 298.147,1406.88 298.156,1406.88 298.165,1406.88 298.174,1406.88 298.184,1406.88 298.193,1406.88 298.202,1406.88 298.211,1406.88 298.22,1406.88 298.229,1406.88 298.239,1406.88 298.248,1406.88 298.257,1406.88 298.266,1406.88 298.275,1406.88 298.285,1406.88 298.294,1406.88 298.303,1406.88 298.312,1406.88 298.321,1406.88 298.331,1406.88 298.34,1406.88 298.349,1406.88 298.358,1406.88 298.367,1406.88 298.377,1406.88 298.386,1406.88 298.395,1406.88 298.404,1406.88 298.413,1406.88 298.422,1406.88 298.432,1406.88 298.441,1406.88 298.45,1406.88 298.459,1406.88 298.468,1406.88 298.478,1406.88 298.487,1406.88 298.496,1406.88 298.505,1406.88 298.514,1406.88 298.524,1406.88 298.533,1406.88 298.542,1406.88 298.551,1406.88 298.56,1406.88 298.569,1406.88 298.579,1406.88 298.588,1406.88 298.597,1406.88 298.606,1406.88 298.615,1406.88 298.625,1406.88 298.634,1406.88 298.643,1406.88 298.652,1406.88 298.661,1406.88 298.671,1406.88 298.68,1406.88 298.689,1406.88 298.698,1406.88 298.707,1406.88 298.717,1406.88 298.726,1406.88 298.735,1406.88 298.744,1406.88 298.753,1406.88 298.762,1406.88 298.772,1406.88 298.781,1406.88 298.79,1406.88 298.799,1406.88 298.808,1406.88 298.818,1406.88 298.827,1406.88 298.836,1406.88 298.845,1406.88 298.854,1406.88 298.864,1406.88 298.873,1406.88 298.882,1406.88 298.891,1406.88 298.9,1406.88 298.909,1406.88 298.919,1406.88 298.928,1406.88 298.937,1406.88 298.946,1406.88 298.955,1406.88 298.965,1406.88 298.974,1406.88 298.983,1406.88 298.992,1406.88 299.001,1406.88 299.011,1406.88 299.02,1406.88 299.029,1406.88 299.038,1406.88 299.047,1406.88 299.057,1406.88 299.066,1406.88 299.075,1406.88 299.084,1406.88 299.093,1406.88 299.102,1406.88 299.112,1406.88 299.121,1406.88 299.13,1406.88 299.139,1406.88 299.148,1406.88 299.158,1406.88 299.167,1406.88 299.176,1406.88 299.185,1406.88 299.194,1406.88 299.204,1406.88 299.213,1406.88 299.222,1406.88 299.231,1406.88 299.24,1406.88 299.249,1406.88 299.259,1406.88 299.268,1406.88 299.277,1406.88 299.286,1406.88 299.295,1406.88 299.305,1406.88 299.314,1406.88 299.323,1406.88 299.332,1406.88 299.341,1406.88 299.351,1406.88 299.36,1406.88 299.369,1406.88 299.378,1406.88 299.387,1406.88 299.397,1406.88 299.406,1406.88 299.415,1406.88 299.424,1406.88 299.433,1406.88 299.442,1406.88 299.452,1406.88 299.461,1406.88 299.47,1406.88 299.479,1406.88 299.488,1406.88 299.498,1406.88 299.507,1406.88 299.516,1406.88 299.525,1406.88 299.534,1406.88 299.544,1406.88 299.553,1406.88 299.562,1406.88 299.571,1406.88 299.58,1406.88 299.59,1406.88 299.599,1406.88 299.608,1406.88 299.617,1406.88 299.626,1406.88 299.635,1406.88 299.645,1406.88 299.654,1406.88 299.663,1406.88 299.672,1406.88 299.681,1406.88 299.691,1406.88 299.7,1406.88 299.709,1406.88 299.718,1406.88 299.727,1406.88 299.737,1406.88 299.746,1406.88 299.755,1406.88 299.764,1406.88 299.773,1406.88 299.782,1406.88 299.792,1406.88 299.801,1406.88 299.81,1406.88 299.819,1406.88 299.828,1406.88 299.838,1406.88 299.847,1406.88 299.856,1406.88 299.865,1406.88 299.874,1406.88 299.884,1406.88 299.893,1406.88 299.902,1406.88 299.911,1406.88 299.92,1406.88 299.93,1406.88 299.939,1406.88 299.948,1406.88 299.957,1406.88 299.966,1406.88 299.975,1406.88 299.985,1406.88 299.994,1406.88 300.003,1406.88 300.012,1406.88 300.021,1406.88 300.031,1406.88 300.04,1406.88 300.049,1406.88 300.058,1406.88 300.067,1406.88 300.077,1406.88 300.086,1406.88 300.095,1406.88 300.104,1406.88 300.113,1406.88 300.122,1406.88 300.132,1406.88 300.141,1406.88 300.15,1406.88 300.159,1406.88 300.168,1406.88 300.178,1406.88 300.187,1406.88 300.196,1406.88 300.205,1406.88 300.214,1406.88 300.224,1406.88 300.233,1406.88 300.242,1406.88 300.251,1406.88 300.26,1406.88 300.27,1406.88 300.279,1406.88 300.288,1406.88 300.297,1406.88 300.306,1406.88 300.315,1406.88 300.325,1406.88 300.334,1406.88 300.343,1406.88 300.352,1406.88 300.361,1406.88 300.371,1406.88 300.38,1406.88 300.389,1406.88 300.398,1406.88 300.407,1406.88 300.417,1406.88 300.426,1406.88 300.435,1406.88 300.444,1406.88 300.453,1406.88 300.462,1406.88 300.472,1406.88 300.481,1406.88 300.49,1406.88 300.499,1406.88 300.508,1406.88 300.518,1406.88 300.527,1406.88 300.536,1406.88 300.545,1406.88 300.554,1406.88 300.564,1406.88 300.573,1406.88 300.582,1406.88 300.591,1406.88 300.6,1406.88 300.61,1406.88 300.619,1406.88 300.628,1406.88 300.637,1406.88 300.646,1406.88 300.655,1406.88 300.665,1406.88 300.674,1406.88 300.683,1406.88 300.692,1406.88 300.701,1406.88 300.711,1406.88 300.72,1406.88 300.729,1406.88 300.738,1406.88 300.747,1406.88 300.757,1406.88 300.766,1406.88 300.775,1406.88 300.784,1406.88 300.793,1406.88 300.802,1406.88 300.812,1406.88 300.821,1406.88 300.83,1406.88 300.839,1406.88 300.848,1406.88 300.858,1406.88 300.867,1406.88 300.876,1406.88 300.885,1406.88 300.894,1406.88 300.904,1406.88 300.913,1406.88 300.922,1406.88 300.931,1406.88 300.94,1406.88 300.95,1406.88 300.959,1406.88 300.968,1406.88 300.977,1406.88 300.986,1406.88 300.995,1406.88 301.005,1406.88 301.014,1406.88 301.023,1406.88 301.032,1406.88 301.041,1406.88 301.051,1406.88 301.06,1406.88 301.069,1406.88 301.078,1406.88 301.087,1406.88 301.097,1406.88 301.106,1406.88 301.115,1406.88 301.124,1406.88 301.133,1406.88 301.142,1406.88 301.152,1406.88 301.161,1406.88 301.17,1406.88 301.179,1406.88 301.188,1406.88 301.198,1406.88 301.207,1406.88 301.216,1406.88 301.225,1406.88 301.234,1406.88 301.244,1406.88 301.253,1406.88 301.262,1406.88 301.271,1406.88 301.28,1406.88 301.29,1406.88 301.299,1406.88 301.308,1406.88 301.317,1406.88 301.326,1406.88 301.335,1406.88 301.345,1406.88 301.354,1406.88 301.363,1406.88 301.372,1406.88 301.381,1406.88 301.391,1406.88 301.4,1406.88 301.409,1406.88 301.418,1406.88 301.427,1406.88 301.437,1406.88 301.446,1406.88 301.455,1406.88 301.464,1406.88 301.473,1406.88 301.482,1406.88 301.492,1406.88 301.501,1406.88 301.51,1406.88 301.519,1406.88 301.528,1406.88 301.538,1406.88 301.547,1406.88 301.556,1406.88 301.565,1406.88 301.574,1406.88 301.584,1406.88 301.593,1406.88 301.602,1406.88 301.611,1406.88 301.62,1406.88 301.63,1406.88 301.639,1406.88 301.648,1406.88 301.657,1406.88 301.666,1406.88 301.675,1406.88 301.685,1406.88 301.694,1406.88 301.703,1406.88 301.712,1406.88 301.721,1406.88 301.731,1406.88 301.74,1406.88 301.749,1406.88 301.758,1406.88 301.767,1406.88 301.777,1406.88 301.786,1406.88 301.795,1406.88 301.804,1406.88 301.813,1406.88 301.822,1406.88 301.832,1406.88 301.841,1406.88 301.85,1406.88 301.859,1406.88 301.868,1406.88 301.878,1406.88 301.887,1406.88 301.896,1406.88 301.905,1406.88 301.914,1406.88 301.924,1406.88 301.933,1406.88 301.942,1406.88 301.951,1406.88 301.96,1406.88 301.97,1406.88 301.979,1406.88 301.988,1406.88 301.997,1406.88 302.006,1406.88 302.015,1406.88 302.025,1406.88 302.034,1406.88 302.043,1406.88 302.052,1406.88 302.061,1406.88 302.071,1406.88 302.08,1406.88 302.089,1406.88 302.098,1406.88 302.107,1406.88 302.117,1406.88 302.126,1406.88 302.135,1406.88 302.144,1406.88 302.153,1406.88 302.163,1406.88 302.172,1406.88 302.181,1406.88 302.19,1406.88 302.199,1406.88 302.208,1406.88 302.218,1406.88 302.227,1406.88 302.236,1406.88 302.245,1406.88 302.254,1406.88 302.264,1406.88 302.273,1406.88 302.282,1406.88 302.291,1406.88 302.3,1406.88 302.31,1406.88 302.319,1406.88 302.328,1406.88 302.337,1406.88 302.346,1406.88 302.355,1406.88 302.365,1406.88 302.374,1406.88 302.383,1406.88 302.392,1406.88 302.401,1406.88 302.411,1406.88 302.42,1406.88 302.429,1406.88 302.438,1406.88 302.447,1406.88 302.457,1406.88 302.466,1406.88 302.475,1406.88 302.484,1406.88 302.493,1406.88 302.503,1406.88 302.512,1406.88 302.521,1406.88 302.53,1406.88 302.539,1406.88 302.548,1406.88 302.558,1406.88 302.567,1406.88 302.576,1406.88 302.585,1406.88 302.594,1406.88 302.604,1406.88 302.613,1406.88 302.622,1406.88 302.631,1406.88 302.64,1406.88 302.65,1406.88 302.659,1406.88 302.668,1406.88 302.677,1406.88 302.686,1406.88 302.695,1406.88 302.705,1406.88 302.714,1406.88 302.723,1406.88 302.732,1406.88 302.741,1406.88 302.751,1406.88 302.76,1406.88 302.769,1406.88 302.778,1406.88 302.787,1406.88 302.797,1406.88 302.806,1406.88 302.815,1406.88 302.824,1406.88 302.833,1406.88 302.843,1406.88 302.852,1406.88 302.861,1406.88 302.87,1406.88 302.879,1406.88 302.888,1406.88 302.898,1406.88 302.907,1406.88 302.916,1406.88 302.925,1406.88 302.934,1406.88 302.944,1406.88 302.953,1406.88 302.962,1406.88 302.971,1406.88 302.98,1406.88 302.99,1406.88 302.999,1406.88 303.008,1406.88 303.017,1406.88 303.026,1406.88 303.035,1406.88 303.045,1406.88 303.054,1406.88 303.063,1406.88 303.072,1406.88 303.081,1406.88 303.091,1406.88 303.1,1406.88 303.109,1406.88 303.118,1406.88 303.127,1406.88 303.137,1406.88 303.146,1406.88 303.155,1406.88 303.164,1406.88 303.173,1406.88 303.183,1406.88 303.192,1406.88 303.201,1406.88 303.21,1406.88 303.219,1406.88 303.228,1406.88 303.238,1406.88 303.247,1406.88 303.256,1406.88 303.265,1406.88 303.274,1406.88 303.284,1406.88 303.293,1406.88 303.302,1406.88 303.311,1406.88 303.32,1406.88 303.33,1406.88 303.339,1406.88 303.348,1406.88 303.357,1406.88 303.366,1406.88 303.375,1406.88 303.385,1406.88 303.394,1406.88 303.403,1406.88 303.412,1406.88 303.421,1406.88 303.431,1406.88 303.44,1406.88 303.449,1406.88 303.458,1406.88 303.467,1406.88 303.477,1406.88 303.486,1406.88 303.495,1406.88 303.504,1406.88 303.513,1406.88 303.523,1406.88 303.532,1406.88 303.541,1406.88 303.55,1406.88 303.559,1406.88 303.568,1406.88 303.578,1406.88 303.587,1406.88 303.596,1406.88 303.605,1406.88 303.614,1406.88 303.624,1406.88 303.633,1406.88 303.642,1406.88 303.651,1406.88 303.66,1406.88 303.67,1406.88 303.679,1406.88 303.688,1406.88 303.697,1406.88 303.706,1406.88 303.715,1406.88 303.725,1406.88 303.734,1406.88 303.743,1406.88 303.752,1406.88 303.761,1406.88 303.771,1406.88 303.78,1406.88 303.789,1406.88 303.798,1406.88 303.807,1406.88 303.817,1406.88 303.826,1406.88 303.835,1406.88 303.844,1406.88 303.853,1406.88 303.863,1406.88 303.872,1406.88 303.881,1406.88 303.89,1406.88 303.899,1406.88 303.908,1406.88 303.918,1406.88 303.927,1406.88 303.936,1406.88 303.945,1406.88 303.954,1406.88 303.964,1406.88 303.973,1406.88 303.982,1406.88 303.991,1406.88 304,1406.88 304.01,1406.88 304.019,1406.88 304.028,1406.88 304.037,1406.88 304.046,1406.88 304.055,1406.88 304.065,1406.88 304.074,1406.88 304.083,1406.88 304.092,1406.88 304.101,1406.88 304.111,1406.88 304.12,1406.88 304.129,1406.88 304.138,1406.88 304.147,1406.88 304.157,1406.88 304.166,1406.88 304.175,1406.88 304.184,1406.88 304.193,1406.88 304.203,1406.88 304.212,1406.88 304.221,1406.88 304.23,1406.88 304.239,1406.88 304.248,1406.88 304.258,1406.88 304.267,1406.88 304.276,1406.88 304.285,1406.88 304.294,1406.88 304.304,1406.88 304.313,1406.88 304.322,1406.88 304.331,1406.88 304.34,1406.88 304.35,1406.88 304.359,1406.88 304.368,1406.88 304.377,1406.88 304.386,1406.88 304.395,1406.88 304.405,1406.88 304.414,1406.88 304.423,1406.88 304.432,1406.88 304.441,1406.88 304.451,1406.88 304.46,1406.88 304.469,1406.88 304.478,1406.88 304.487,1406.88 304.497,1406.88 304.506,1406.88 304.515,1406.88 304.524,1406.88 304.533,1406.88 304.543,1406.88 304.552,1406.88 304.561,1406.88 304.57,1406.88 304.579,1406.88 304.588,1406.88 304.598,1406.88 304.607,1406.88 304.616,1406.88 304.625,1406.88 304.634,1406.88 304.644,1406.88 304.653,1406.88 304.662,1406.88 304.671,1406.88 304.68,1406.88 304.69,1406.88 304.699,1406.88 304.708,1406.88 304.717,1406.88 304.726,1406.88 304.736,1406.88 304.745,1406.88 304.754,1406.88 304.763,1406.88 304.772,1406.88 304.781,1406.88 304.791,1406.88 304.8,1406.88 304.809,1406.88 304.818,1406.88 304.827,1406.88 304.837,1406.88 304.846,1406.88 304.855,1406.88 304.864,1406.88 304.873,1406.88 304.883,1406.88 304.892,1406.88 304.901,1406.88 304.91,1406.88 304.919,1406.88 304.928,1406.88 304.938,1406.88 304.947,1406.88 304.956,1406.88 304.965,1406.88 304.974,1406.88 304.984,1406.88 304.993,1406.88 305.002,1406.88 305.011,1406.88 305.02,1406.88 305.03,1406.88 305.039,1406.88 305.048,1406.88 305.057,1406.88 305.066,1406.88 305.076,1406.88 305.085,1406.88 305.094,1406.88 305.103,1406.88 305.112,1406.88 305.121,1406.88 305.131,1406.88 305.14,1406.88 305.149,1406.88 305.158,1406.88 305.167,1406.88 305.177,1406.88 305.186,1406.88 305.195,1406.88 305.204,1406.88 305.213,1406.88 305.223,1406.88 305.232,1406.88 305.241,1406.88 305.25,1406.88 305.259,1406.88 305.268,1406.88 305.278,1406.88 305.287,1406.88 305.296,1406.88 305.305,1406.88 305.314,1406.88 305.324,1406.88 305.333,1406.88 305.342,1406.88 305.351,1406.88 305.36,1406.88 305.37,1406.88 305.379,1406.88 305.388,1406.88 305.397,1406.88 305.406,1406.88 305.416,1406.88 305.425,1406.88 305.434,1406.88 305.443,1406.88 305.452,1406.88 305.461,1406.88 305.471,1406.88 305.48,1406.88 305.489,1406.88 305.498,1406.88 305.507,1406.88 305.517,1406.88 305.526,1406.88 305.535,1406.88 305.544,1406.88 305.553,1406.88 305.563,1406.88 305.572,1406.88 305.581,1406.88 305.59,1406.88 305.599,1406.88 305.608,1406.88 305.618,1406.88 305.627,1406.88 305.636,1406.88 305.645,1406.88 305.654,1406.88 305.664,1406.88 305.673,1406.88 305.682,1406.88 305.691,1406.88 305.7,1406.88 305.71,1406.88 305.719,1406.88 305.728,1406.88 305.737,1406.88 305.746,1406.88 305.756,1406.88 305.765,1406.88 305.774,1406.88 305.783,1406.88 305.792,1406.88 305.801,1406.88 305.811,1406.88 305.82,1406.88 305.829,1406.88 305.838,1406.88 305.847,1406.88 305.857,1406.88 305.866,1406.88 305.875,1406.88 305.884,1406.88 305.893,1406.88 305.903,1406.88 305.912,1406.88 305.921,1406.88 305.93,1406.88 305.939,1406.88 305.948,1406.88 305.958,1406.88 305.967,1406.88 305.976,1406.88 305.985,1406.88 305.994,1406.88 306.004,1406.88 306.013,1406.88 306.022,1406.88 306.031,1406.88 306.04,1406.88 306.05,1406.88 306.059,1406.88 306.068,1406.88 306.077,1406.88 306.086,1406.88 306.096,1406.88 306.105,1406.88 306.114,1406.88 306.123,1406.88 306.132,1406.88 306.141,1406.88 306.151,1406.88 306.16,1406.88 306.169,1406.88 306.178,1406.88 306.187,1406.88 306.197,1406.88 306.206,1406.88 306.215,1406.88 306.224,1406.88 306.233,1406.88 306.243,1406.88 306.252,1406.88 306.261,1406.88 306.27,1406.88 306.279,1406.88 306.288,1406.88 306.298,1406.88 306.307,1406.88 306.316,1406.88 306.325,1406.88 306.334,1406.88 306.344,1406.88 306.353,1406.88 306.362,1406.88 306.371,1406.88 306.38,1406.88 306.39,1406.88 306.399,1406.88 306.408,1406.88 306.417,1406.88 306.426,1406.88 306.436,1406.88 306.445,1406.88 306.454,1406.88 306.463,1406.88 306.472,1406.88 306.481,1406.88 306.491,1406.88 306.5,1406.88 306.509,1406.88 306.518,1406.88 306.527,1406.88 306.537,1406.88 306.546,1406.88 306.555,1406.88 306.564,1406.88 306.573,1406.88 306.583,1406.88 306.592,1406.88 306.601,1406.88 306.61,1406.88 306.619,1406.88 306.628,1406.88 306.638,1406.88 306.647,1406.88 306.656,1406.88 306.665,1406.88 306.674,1406.88 306.684,1406.88 306.693,1406.88 306.702,1406.88 306.711,1406.88 306.72,1406.88 306.73,1406.88 306.739,1406.88 306.748,1406.88 306.757,1406.88 306.766,1406.88 306.776,1406.88 306.785,1406.88 306.794,1406.88 306.803,1406.88 306.812,1406.88 306.821,1406.88 306.831,1406.88 306.84,1406.88 306.849,1406.88 306.858,1406.88 306.867,1406.88 306.877,1406.88 306.886,1406.88 306.895,1406.88 306.904,1406.88 306.913,1406.88 306.923,1406.88 306.932,1406.88 306.941,1406.88 306.95,1406.88 306.959,1406.88 306.969,1406.88 306.978,1406.88 306.987,1406.88 306.996,1406.88 307.005,1406.88 307.014,1406.88 307.024,1406.88 307.033,1406.88 307.042,1406.88 307.051,1406.88 307.06,1406.88 307.07,1406.88 307.079,1406.88 307.088,1406.88 307.097,1406.88 307.106,1406.88 307.116,1406.88 307.125,1406.88 307.134,1406.88 307.143,1406.88 307.152,1406.88 307.161,1406.88 307.171,1406.88 307.18,1406.88 307.189,1406.88 307.198,1406.88 307.207,1406.88 307.217,1406.88 307.226,1406.88 307.235,1406.88 307.244,1406.88 307.253,1406.88 307.263,1406.88 307.272,1406.88 307.281,1406.88 307.29,1406.88 307.299,1406.88 307.309,1406.88 307.318,1406.88 307.327,1406.88 307.336,1406.88 307.345,1406.88 307.354,1406.88 307.364,1406.88 307.373,1406.88 307.382,1406.88 307.391,1406.88 307.4,1406.88 307.41,1406.88 307.419,1406.88 307.428,1406.88 307.437,1406.88 307.446,1406.88 307.456,1406.88 307.465,1406.88 307.474,1406.88 307.483,1406.88 307.492,1406.88 307.501,1406.88 307.511,1406.88 307.52,1406.88 307.529,1406.88 307.538,1406.88 307.547,1406.88 307.557,1406.88 307.566,1406.88 307.575,1406.88 307.584,1406.88 307.593,1406.88 307.603,1406.88 307.612,1406.88 307.621,1406.88 307.63,1406.88 307.639,1406.88 307.649,1406.88 307.658,1406.88 307.667,1406.88 307.676,1406.88 307.685,1406.88 307.694,1406.88 307.704,1406.88 307.713,1406.88 307.722,1406.88 307.731,1406.88 307.74,1406.88 307.75,1406.88 307.759,1406.88 307.768,1406.88 307.777,1406.88 307.786,1406.88 307.796,1406.88 307.805,1406.88 307.814,1406.88 307.823,1406.88 307.832,1406.88 307.841,1406.88 307.851,1406.88 307.86,1406.88 307.869,1406.88 307.878,1406.88 307.887,1406.88 307.897,1406.88 307.906,1406.88 307.915,1406.88 307.924,1406.88 307.933,1406.88 307.943,1406.88 307.952,1406.88 307.961,1406.88 307.97,1406.88 307.979,1406.88 307.989,1406.88 307.998,1406.88 308.007,1406.88 308.016,1406.88 308.025,1406.88 308.034,1406.88 308.044,1406.88 308.053,1406.88 308.062,1406.88 308.071,1406.88 308.08,1406.88 308.09,1406.88 308.099,1406.88 308.108,1406.88 308.117,1406.88 308.126,1406.88 308.136,1406.88 308.145,1406.88 308.154,1406.88 308.163,1406.88 308.172,1406.88 308.181,1406.88 308.191,1406.88 308.2,1406.88 308.209,1406.88 308.218,1406.88 308.227,1406.88 308.237,1406.88 308.246,1406.88 308.255,1406.88 308.264,1406.88 308.273,1406.88 308.283,1406.88 308.292,1406.88 308.301,1406.88 308.31,1406.88 308.319,1406.88 308.329,1406.88 308.338,1406.88 308.347,1406.88 308.356,1406.88 308.365,1406.88 308.374,1406.88 308.384,1406.88 308.393,1406.88 308.402,1406.88 308.411,1406.88 308.42,1406.88 308.43,1406.88 308.439,1406.88 308.448,1406.88 308.457,1406.88 308.466,1406.88 308.476,1406.88 308.485,1406.88 308.494,1406.88 308.503,1406.88 308.512,1406.88 308.521,1406.88 308.531,1406.88 308.54,1406.88 308.549,1406.88 308.558,1406.88 308.567,1406.88 308.577,1406.88 308.586,1406.88 308.595,1406.88 308.604,1406.88 308.613,1406.88 308.623,1406.88 308.632,1406.88 308.641,1406.88 308.65,1406.88 308.659,1406.88 308.669,1406.88 308.678,1406.88 308.687,1406.88 308.696,1406.88 308.705,1406.88 308.714,1406.88 308.724,1406.88 308.733,1406.88 308.742,1406.88 308.751,1406.88 308.76,1406.88 308.77,1406.88 308.779,1406.88 308.788,1406.88 308.797,1406.88 308.806,1406.88 308.816,1406.88 308.825,1406.88 308.834,1406.88 308.843,1406.88 308.852,1406.88 308.861,1406.88 308.871,1406.88 308.88,1406.88 308.889,1406.88 308.898,1406.88 308.907,1406.88 308.917,1406.88 308.926,1406.88 308.935,1406.88 308.944,1406.88 308.953,1406.88 308.963,1406.88 308.972,1406.88 308.981,1406.88 308.99,1406.88 308.999,1406.88 309.009,1406.88 309.018,1406.88 309.027,1406.88 309.036,1406.88 309.045,1406.88 309.054,1406.88 309.064,1406.88 309.073,1406.88 309.082,1406.88 309.091,1406.88 309.1,1406.88 309.11,1406.88 309.119,1406.88 309.128,1406.88 309.137,1406.88 309.146,1406.88 309.156,1406.88 309.165,1406.88 309.174,1406.88 309.183,1406.88 309.192,1406.88 309.201,1406.88 309.211,1406.88 309.22,1406.88 309.229,1406.88 309.238,1406.88 309.247,1406.88 309.257,1406.88 309.266,1406.88 309.275,1406.88 309.284,1406.88 309.293,1406.88 309.303,1406.88 309.312,1406.88 309.321,1406.88 309.33,1406.88 309.339,1406.88 309.349,1406.88 309.358,1406.88 309.367,1406.88 309.376,1406.88 309.385,1406.88 309.394,1406.88 309.404,1406.88 309.413,1406.88 309.422,1406.88 309.431,1406.88 309.44,1406.88 309.45,1406.88 309.459,1406.88 309.468,1406.88 309.477,1406.88 309.486,1406.88 309.496,1406.88 309.505,1406.88 309.514,1406.88 309.523,1406.88 309.532,1406.88 309.542,1406.88 309.551,1406.88 309.56,1406.88 309.569,1406.88 309.578,1406.88 309.587,1406.88 309.597,1406.88 309.606,1406.88 309.615,1406.88 309.624,1406.88 309.633,1406.88 309.643,1406.88 309.652,1406.88 309.661,1406.88 309.67,1406.88 309.679,1406.88 309.689,1406.88 309.698,1406.88 309.707,1406.88 309.716,1406.88 309.725,1406.88 309.734,1406.88 309.744,1406.88 309.753,1406.88 309.762,1406.88 309.771,1406.88 309.78,1406.88 309.79,1406.88 309.799,1406.88 309.808,1406.88 309.817,1406.88 309.826,1406.88 309.836,1406.88 309.845,1406.88 309.854,1406.88 309.863,1406.88 309.872,1406.88 309.882,1406.88 309.891,1406.88 309.9,1406.88 309.909,1406.88 309.918,1406.88 309.927,1406.88 309.937,1406.88 309.946,1406.88 309.955,1406.88 309.964,1406.88 309.973,1406.88 309.983,1406.88 309.992,1406.88 310.001,1406.88 310.01,1406.88 310.019,1406.88 310.029,1406.88 310.038,1406.88 310.047,1406.88 310.056,1406.88 310.065,1406.88 310.074,1406.88 310.084,1406.88 310.093,1406.88 310.102,1406.88 310.111,1406.88 310.12,1406.88 310.13,1406.88 310.139,1406.88 310.148,1406.88 310.157,1406.88 310.166,1406.88 310.176,1406.88 310.185,1406.88 310.194,1406.88 310.203,1406.88 310.212,1406.88 310.222,1406.88 310.231,1406.88 310.24,1406.88 310.249,1406.88 310.258,1406.88 310.267,1406.88 310.277,1406.88 310.286,1406.88 310.295,1406.88 310.304,1406.88 310.313,1406.88 310.323,1406.88 310.332,1406.88 310.341,1406.88 310.35,1406.88 310.359,1406.88 310.369,1406.88 310.378,1406.88 310.387,1406.88 310.396,1406.88 310.405,1406.88 310.414,1406.88 310.424,1406.88 310.433,1406.88 310.442,1406.88 310.451,1406.88 310.46,1406.88 310.47,1406.88 310.479,1406.88 310.488,1406.88 310.497,1406.88 310.506,1406.88 310.516,1406.88 310.525,1406.88 310.534,1406.88 310.543,1406.88 310.552,1406.88 310.562,1406.88 310.571,1406.88 310.58,1406.88 310.589,1406.88 310.598,1406.88 310.607,1406.88 310.617,1406.88 310.626,1406.88 310.635,1406.88 310.644,1406.88 310.653,1406.88 310.663,1406.88 310.672,1406.88 310.681,1406.88 310.69,1406.88 310.699,1406.88 310.709,1406.88 310.718,1406.88 310.727,1406.88 310.736,1406.88 310.745,1406.88 310.754,1406.88 310.764,1406.88 310.773,1406.88 310.782,1406.88 310.791,1406.88 310.8,1406.88 310.81,1406.88 310.819,1406.88 310.828,1406.88 310.837,1406.88 310.846,1406.88 310.856,1406.88 310.865,1406.88 310.874,1406.88 310.883,1406.88 310.892,1406.88 310.902,1406.88 310.911,1406.88 310.92,1406.88 310.929,1406.88 310.938,1406.88 310.947,1406.88 310.957,1406.88 310.966,1406.88 310.975,1406.88 310.984,1406.88 310.993,1406.88 311.003,1406.88 311.012,1406.88 311.021,1406.88 311.03,1406.88 311.039,1406.88 311.049,1406.88 311.058,1406.88 311.067,1406.88 311.076,1406.88 311.085,1406.88 311.094,1406.88 311.104,1406.88 311.113,1406.88 311.122,1406.88 311.131,1406.88 311.14,1406.88 311.15,1406.88 311.159,1406.88 311.168,1406.88 311.177,1406.88 311.186,1406.88 311.196,1406.88 311.205,1406.88 311.214,1406.88 311.223,1406.88 311.232,1406.88 311.242,1406.88 311.251,1406.88 311.26,1406.88 311.269,1406.88 311.278,1406.88 311.287,1406.88 311.297,1406.88 311.306,1406.88 311.315,1406.88 311.324,1406.88 311.333,1406.88 311.343,1406.88 311.352,1406.88 311.361,1406.88 311.37,1406.88 311.379,1406.88 311.389,1406.88 311.398,1406.88 311.407,1406.88 311.416,1406.88 311.425,1406.88 311.434,1406.88 311.444,1406.88 311.453,1406.88 311.462,1406.88 311.471,1406.88 311.48,1406.88 311.49,1406.88 311.499,1406.88 311.508,1406.88 311.517,1406.88 311.526,1406.88 311.536,1406.88 311.545,1406.88 311.554,1406.88 311.563,1406.88 311.572,1406.88 311.582,1406.88 311.591,1406.88 311.6,1406.88 311.609,1406.88 311.618,1406.88 311.627,1406.88 311.637,1406.88 311.646,1406.88 311.655,1406.88 311.664,1406.88 311.673,1406.88 311.683,1406.88 311.692,1406.88 311.701,1406.88 311.71,1406.88 311.719,1406.88 311.729,1406.88 311.738,1406.88 311.747,1406.88 311.756,1406.88 311.765,1406.88 311.774,1406.88 311.784,1406.88 311.793,1406.88 311.802,1406.88 311.811,1406.88 311.82,1406.88 311.83,1406.88 311.839,1406.88 311.848,1406.88 311.857,1406.88 311.866,1406.88 311.876,1406.88 311.885,1406.88 311.894,1406.88 311.903,1406.88 311.912,1406.88 311.922,1406.88 311.931,1406.88 311.94,1406.88 311.949,1406.88 311.958,1406.88 311.967,1406.88 311.977,1406.88 311.986,1406.88 311.995,1406.88 312.004,1406.88 312.013,1406.88 312.023,1406.88 312.032,1406.88 312.041,1406.88 312.05,1406.88 312.059,1406.88 312.069,1406.88 312.078,1406.88 312.087,1406.88 312.096,1406.88 312.105,1406.88 312.115,1406.88 312.124,1406.88 312.133,1406.88 312.142,1406.88 312.151,1406.88 312.16,1406.88 312.17,1406.88 312.179,1406.88 312.188,1406.88 312.197,1406.88 312.206,1406.88 312.216,1406.88 312.225,1406.88 312.234,1406.88 312.243,1406.88 312.252,1406.88 312.262,1406.88 312.271,1406.88 312.28,1406.88 312.289,1406.88 312.298,1406.88 312.307,1406.88 312.317,1406.88 312.326,1406.88 312.335,1406.88 312.344,1406.88 312.353,1406.88 312.363,1406.88 312.372,1406.88 312.381,1406.88 312.39,1406.88 312.399,1406.88 312.409,1406.88 312.418,1406.88 312.427,1406.88 312.436,1406.88 312.445,1406.88 312.455,1406.88 312.464,1406.88 312.473,1406.88 312.482,1406.88 312.491,1406.88 312.5,1406.88 312.51,1406.88 312.519,1406.88 312.528,1406.88 312.537,1406.88 312.546,1406.88 312.556,1406.88 312.565,1406.88 312.574,1406.88 312.583,1406.88 312.592,1406.88 312.602,1406.88 312.611,1406.88 312.62,1406.88 312.629,1406.88 312.638,1406.88 312.647,1406.88 312.657,1406.88 312.666,1406.88 312.675,1406.88 312.684,1406.88 312.693,1406.88 312.703,1406.88 312.712,1406.88 312.721,1406.88 312.73,1406.88 312.739,1406.88 312.749,1406.88 312.758,1406.88 312.767,1406.88 312.776,1406.88 312.785,1406.88 312.795,1406.88 312.804,1406.88 312.813,1406.88 312.822,1406.88 312.831,1406.88 312.84,1406.88 312.85,1406.88 312.859,1406.88 312.868,1406.88 312.877,1406.88 312.886,1406.88 312.896,1406.88 312.905,1406.88 312.914,1406.88 312.923,1406.88 312.932,1406.88 312.942,1406.88 312.951,1406.88 312.96,1406.88 312.969,1406.88 312.978,1406.88 312.987,1406.88 312.997,1406.88 313.006,1406.88 313.015,1406.88 313.024,1406.88 313.033,1406.88 313.043,1406.88 313.052,1406.88 313.061,1406.88 313.07,1406.88 313.079,1406.88 313.089,1406.88 313.098,1406.88 313.107,1406.88 313.116,1406.88 313.125,1406.88 313.135,1406.88 313.144,1406.88 313.153,1406.88 313.162,1406.88 313.171,1406.88 313.18,1406.88 313.19,1406.88 313.199,1406.88 313.208,1406.88 313.217,1406.88 313.226,1406.88 313.236,1406.88 313.245,1406.88 313.254,1406.88 313.263,1406.88 313.272,1406.88 313.282,1406.88 313.291,1406.88 313.3,1406.88 313.309,1406.88 313.318,1406.88 313.327,1406.88 313.337,1406.88 313.346,1406.88 313.355,1406.88 313.364,1406.88 313.373,1406.88 313.383,1406.88 313.392,1406.88 313.401,1406.88 313.41,1406.88 313.419,1406.88 313.429,1406.88 313.438,1406.88 313.447,1406.88 313.456,1406.88 313.465,1406.88 313.475,1406.88 313.484,1406.88 313.493,1406.88 313.502,1406.88 313.511,1406.88 313.52,1406.88 313.53,1406.88 313.539,1406.88 313.548,1406.88 313.557,1406.88 313.566,1406.88 313.576,1406.88 313.585,1406.88 313.594,1406.88 313.603,1406.88 313.612,1406.88 313.622,1406.88 313.631,1406.88 313.64,1406.88 313.649,1406.88 313.658,1406.88 313.667,1406.88 313.677,1406.88 313.686,1406.88 313.695,1406.88 313.704,1406.88 313.713,1406.88 313.723,1406.88 313.732,1406.88 313.741,1406.88 313.75,1406.88 313.759,1406.88 313.769,1406.88 313.778,1406.88 313.787,1406.88 313.796,1406.88 313.805,1406.88 313.815,1406.88 313.824,1406.88 313.833,1406.88 313.842,1406.88 313.851,1406.88 313.86,1406.88 313.87,1406.88 313.879,1406.88 313.888,1406.88 313.897,1406.88 313.906,1406.88 313.916,1406.88 313.925,1406.88 313.934,1406.88 313.943,1406.88 313.952,1406.88 313.962,1406.88 313.971,1406.88 313.98,1406.88 313.989,1406.88 313.998,1406.88 314.007,1406.88 314.017,1406.88 314.026,1406.88 314.035,1406.88 314.044,1406.88 314.053,1406.88 314.063,1406.88 314.072,1406.88 314.081,1406.88 314.09,1406.88 314.099,1406.88 314.109,1406.88 314.118,1406.88 314.127,1406.88 314.136,1406.88 314.145,1406.88 314.155,1406.88 314.164,1406.88 314.173,1406.88 314.182,1406.88 314.191,1406.88 314.2,1406.88 314.21,1406.88 314.219,1406.88 314.228,1406.88 314.237,1406.88 314.246,1406.88 314.256,1406.88 314.265,1406.88 314.274,1406.88 314.283,1406.88 314.292,1406.88 314.302,1406.88 314.311,1406.88 314.32,1406.88 314.329,1406.88 314.338,1406.88 314.348,1406.88 314.357,1406.88 314.366,1406.88 314.375,1406.88 314.384,1406.88 314.393,1406.88 314.403,1406.88 314.412,1406.88 314.421,1406.88 314.43,1406.88 314.439,1406.88 314.449,1406.88 314.458,1406.88 314.467,1406.88 314.476,1406.88 314.485,1406.88 314.495,1406.88 314.504,1406.88 314.513,1406.88 314.522,1406.88 314.531,1406.88 314.54,1406.88 314.55,1406.88 314.559,1406.88 314.568,1406.88 314.577,1406.88 314.586,1406.88 314.596,1406.88 314.605,1406.88 314.614,1406.88 314.623,1406.88 314.632,1406.88 314.642,1406.88 314.651,1406.88 314.66,1406.88 314.669,1406.88 314.678,1406.88 314.688,1406.88 314.697,1406.88 314.706,1406.88 314.715,1406.88 314.724,1406.88 314.733,1406.88 314.743,1406.88 314.752,1406.88 314.761,1406.88 314.77,1406.88 314.779,1406.88 314.789,1406.88 314.798,1406.88 314.807,1406.88 314.816,1406.88 314.825,1406.88 314.835,1406.88 314.844,1406.88 314.853,1406.88 314.862,1406.88 314.871,1406.88 314.88,1406.88 314.89,1406.88 314.899,1406.88 314.908,1406.88 314.917,1406.88 314.926,1406.88 314.936,1406.88 314.945,1406.88 314.954,1406.88 314.963,1406.88 314.972,1406.88 314.982,1406.88 314.991,1406.88 315,1406.88 315.009,1406.88 315.018,1406.88 315.028,1406.88 315.037,1406.88 315.046,1406.88 315.055,1406.88 315.064,1406.88 315.073,1406.88 315.083,1406.88 315.092,1406.88 315.101,1406.88 315.11,1406.88 315.119,1406.88 315.129,1406.88 315.138,1406.88 315.147,1406.88 315.156,1406.88 315.165,1406.88 315.175,1406.88 315.184,1406.88 315.193,1406.88 315.202,1406.88 315.211,1406.88 315.22,1406.88 315.23,1406.88 315.239,1406.88 315.248,1406.88 315.257,1406.88 315.266,1406.88 315.276,1406.88 315.285,1406.88 315.294,1406.88 315.303,1406.88 315.312,1406.88 315.322,1406.88 315.331,1406.88 315.34,1406.88 315.349,1406.88 315.358,1406.88 315.368,1406.88 315.377,1406.88 315.386,1406.88 315.395,1406.88 315.404,1406.88 315.413,1406.88 315.423,1406.88 315.432,1406.88 315.441,1406.88 315.45,1406.88 315.459,1406.88 315.469,1406.88 315.478,1406.88 315.487,1406.88 315.496,1406.88 315.505,1406.88 315.515,1406.88 315.524,1406.88 315.533,1406.88 315.542,1406.88 315.551,1406.88 315.56,1406.88 315.57,1406.88 315.579,1406.88 315.588,1406.88 315.597,1406.88 315.606,1406.88 315.616,1406.88 315.625,1406.88 315.634,1406.88 315.643,1406.88 315.652,1406.88 315.662,1406.88 315.671,1406.88 315.68,1406.88 315.689,1406.88 315.698,1406.88 315.708,1406.88 315.717,1406.88 315.726,1406.88 315.735,1406.88 315.744,1406.88 315.753,1406.88 315.763,1406.88 315.772,1406.88 315.781,1406.88 315.79,1406.88 315.799,1406.88 315.809,1406.88 315.818,1406.88 315.827,1406.88 315.836,1406.88 315.845,1406.88 315.855,1406.88 315.864,1406.88 315.873,1406.88 315.882,1406.88 315.891,1406.88 315.9,1406.88 315.91,1406.88 315.919,1406.88 315.928,1406.88 315.937,1406.88 315.946,1406.88 315.956,1406.88 315.965,1406.88 315.974,1406.88 315.983,1406.88 315.992,1406.88 316.002,1406.88 316.011,1406.88 316.02,1406.88 316.029,1406.88 316.038,1406.88 316.048,1406.88 316.057,1406.88 316.066,1406.88 316.075,1406.88 316.084,1406.88 316.093,1406.88 316.103,1406.88 316.112,1406.88 316.121,1406.88 316.13,1406.88 316.139,1406.88 316.149,1406.88 316.158,1406.88 316.167,1406.88 316.176,1406.88 316.185,1406.88 316.195,1406.88 316.204,1406.88 316.213,1406.88 316.222,1406.88 316.231,1406.88 316.24,1406.88 316.25,1406.88 316.259,1406.88 316.268,1406.88 316.277,1406.88 316.286,1406.88 316.296,1406.88 316.305,1406.88 316.314,1406.88 316.323,1406.88 316.332,1406.88 316.342,1406.88 316.351,1406.88 316.36,1406.88 316.369,1406.88 316.378,1406.88 316.388,1406.88 316.397,1406.88 316.406,1406.88 316.415,1406.88 316.424,1406.88 316.433,1406.88 316.443,1406.88 316.452,1406.88 316.461,1406.88 316.47,1406.88 316.479,1406.88 316.489,1406.88 316.498,1406.88 316.507,1406.88 316.516,1406.88 316.525,1406.88 316.535,1406.88 316.544,1406.88 316.553,1406.88 316.562,1406.88 316.571,1406.88 316.58,1406.88 316.59,1406.88 316.599,1406.88 316.608,1406.88 316.617,1406.88 316.626,1406.88 316.636,1406.88 316.645,1406.88 316.654,1406.88 316.663,1406.88 316.672,1406.88 316.682,1406.88 316.691,1406.88 316.7,1406.88 316.709,1406.88 316.718,1406.88 316.728,1406.88 316.737,1406.88 316.746,1406.88 316.755,1406.88 316.764,1406.88 316.773,1406.88 316.783,1406.88 316.792,1406.88 316.801,1406.88 316.81,1406.88 316.819,1406.88 316.829,1406.88 316.838,1406.88 316.847,1406.88 316.856,1406.88 316.865,1406.88 316.875,1406.88 316.884,1406.88 316.893,1406.88 316.902,1406.88 316.911,1406.88 316.921,1406.88 316.93,1406.88 316.939,1406.88 316.948,1406.88 316.957,1406.88 316.966,1406.88 316.976,1406.88 316.985,1406.88 316.994,1406.88 317.003,1406.88 317.012,1406.88 317.022,1406.88 317.031,1406.88 317.04,1406.88 317.049,1406.88 317.058,1406.88 317.068,1406.88 317.077,1406.88 317.086,1406.88 317.095,1406.88 317.104,1406.88 317.113,1406.88 317.123,1406.88 317.132,1406.88 317.141,1406.88 317.15,1406.88 317.159,1406.88 317.169,1406.88 317.178,1406.88 317.187,1406.88 317.196,1406.88 317.205,1406.88 317.215,1406.88 317.224,1406.88 317.233,1406.88 317.242,1406.88 317.251,1406.88 317.261,1406.88 317.27,1406.88 317.279,1406.88 317.288,1406.88 317.297,1406.88 317.306,1406.88 317.316,1406.88 317.325,1406.88 317.334,1406.88 317.343,1406.88 317.352,1406.88 317.362,1406.88 317.371,1406.88 317.38,1406.88 317.389,1406.88 317.398,1406.88 317.408,1406.88 317.417,1406.88 317.426,1406.88 317.435,1406.88 317.444,1406.88 317.453,1406.88 317.463,1406.88 317.472,1406.88 317.481,1406.88 317.49,1406.88 317.499,1406.88 317.509,1406.88 317.518,1406.88 317.527,1406.88 317.536,1406.88 317.545,1406.88 317.555,1406.88 317.564,1406.88 317.573,1406.88 317.582,1406.88 317.591,1406.88 317.601,1406.88 317.61,1406.88 317.619,1406.88 317.628,1406.88 317.637,1406.88 317.646,1406.88 317.656,1406.88 317.665,1406.88 317.674,1406.88 317.683,1406.88 317.692,1406.88 317.702,1406.88 317.711,1406.88 317.72,1406.88 317.729,1406.88 317.738,1406.88 317.748,1406.88 317.757,1406.88 317.766,1406.88 317.775,1406.88 317.784,1406.88 317.793,1406.88 317.803,1406.88 317.812,1406.88 317.821,1406.88 317.83,1406.88 317.839,1406.88 317.849,1406.88 317.858,1406.88 317.867,1406.88 317.876,1406.88 317.885,1406.88 317.895,1406.88 317.904,1406.88 317.913,1406.88 317.922,1406.88 317.931,1406.88 317.941,1406.88 317.95,1406.88 317.959,1406.88 317.968,1406.88 317.977,1406.88 317.986,1406.88 317.996,1406.88 318.005,1406.88 318.014,1406.88 318.023,1406.88 318.032,1406.88 318.042,1406.88 318.051,1406.88 318.06,1406.88 318.069,1406.88 318.078,1406.88 318.088,1406.88 318.097,1406.88 318.106,1406.88 318.115,1406.88 318.124,1406.88 318.133,1406.88 318.143,1406.88 318.152,1406.88 318.161,1406.88 318.17,1406.88 318.179,1406.88 318.189,1406.88 318.198,1406.88 318.207,1406.88 318.216,1406.88 318.225,1406.88 318.235,1406.88 318.244,1406.88 318.253,1406.88 318.262,1406.88 318.271,1406.88 318.281,1406.88 318.29,1406.88 318.299,1406.88 318.308,1406.88 318.317,1406.88 318.326,1406.88 318.336,1406.88 318.345,1406.88 318.354,1406.88 318.363,1406.88 318.372,1406.88 318.382,1406.88 318.391,1406.88 318.4,1406.88 318.409,1406.88 318.418,1406.88 318.428,1406.88 318.437,1406.88 318.446,1406.88 318.455,1406.88 318.464,1406.88 318.473,1406.88 318.483,1406.88 318.492,1406.88 318.501,1406.88 318.51,1406.88 318.519,1406.88 318.529,1406.88 318.538,1406.88 318.547,1406.88 318.556,1406.88 318.565,1406.88 318.575,1406.88 318.584,1406.88 318.593,1406.88 318.602,1406.88 318.611,1406.88 318.621,1406.88 318.63,1406.88 318.639,1406.88 318.648,1406.88 318.657,1406.88 318.666,1406.88 318.676,1406.88 318.685,1406.88 318.694,1406.88 318.703,1406.88 318.712,1406.88 318.722,1406.88 318.731,1406.88 318.74,1406.88 318.749,1406.88 318.758,1406.88 318.768,1406.88 318.777,1406.88 318.786,1406.88 318.795,1406.88 318.804,1406.88 318.813,1406.88 318.823,1406.88 318.832,1406.88 318.841,1406.88 318.85,1406.88 318.859,1406.88 318.869,1406.88 318.878,1406.88 318.887,1406.88 318.896,1406.88 318.905,1406.88 318.915,1406.88 318.924,1406.88 318.933,1406.88 318.942,1406.88 318.951,1406.88 318.961,1406.88 318.97,1406.88 318.979,1406.88 318.988,1406.88 318.997,1406.88 319.006,1406.88 319.016,1406.88 319.025,1406.88 319.034,1406.88 319.043,1406.88 319.052,1406.88 319.062,1406.88 319.071,1406.88 319.08,1406.88 319.089,1406.88 319.098,1406.88 319.108,1406.88 319.117,1406.88 319.126,1406.88 319.135,1406.88 319.144,1406.88 319.153,1406.88 319.163,1406.88 319.172,1406.88 319.181,1406.88 319.19,1406.88 319.199,1406.88 319.209,1406.88 319.218,1406.88 319.227,1406.88 319.236,1406.88 319.245,1406.88 319.255,1406.88 319.264,1406.88 319.273,1406.88 319.282,1406.88 319.291,1406.88 319.301,1406.88 319.31,1406.88 319.319,1406.88 319.328,1406.88 319.337,1406.88 319.346,1406.88 319.356,1406.88 319.365,1406.88 319.374,1406.88 319.383,1406.88 319.392,1406.88 319.402,1406.88 319.411,1406.88 319.42,1406.88 319.429,1406.88 319.438,1406.88 319.448,1406.88 319.457,1406.88 319.466,1406.88 319.475,1406.88 319.484,1406.88 319.494,1406.88 319.503,1406.88 319.512,1406.88 319.521,1406.88 319.53,1406.88 319.539,1406.88 319.549,1406.88 319.558,1406.88 319.567,1406.88 319.576,1406.88 319.585,1406.88 319.595,1406.88 319.604,1406.88 319.613,1406.88 319.622,1406.88 319.631,1406.88 319.641,1406.88 319.65,1406.88 319.659,1406.88 319.668,1406.88 319.677,1406.88 319.686,1406.88 319.696,1406.88 319.705,1406.88 319.714,1406.88 319.723,1406.88 319.732,1406.88 319.742,1406.88 319.751,1406.88 319.76,1406.88 319.769,1406.88 319.778,1406.88 319.788,1406.88 319.797,1406.88 319.806,1406.88 319.815,1406.88 319.824,1406.88 319.834,1406.88 319.843,1406.88 319.852,1406.88 319.861,1406.88 319.87,1406.88 319.879,1406.88 319.889,1406.88 319.898,1406.88 319.907,1406.88 319.916,1406.88 319.925,1406.88 319.935,1406.88 319.944,1406.88 319.953,1406.88 319.962,1406.88 319.971,1406.88 319.981,1406.88 319.99,1406.88 319.999,1406.88 320.008,1406.88 320.017,1406.88 320.026,1406.88 320.036,1406.88 320.045,1406.88 320.054,1406.88 320.063,1406.88 320.072,1406.88 320.082,1406.88 320.091,1406.88 320.1,1406.88 320.109,1406.88 320.118,1406.88 320.128,1406.88 320.137,1406.88 320.146,1406.88 320.155,1406.88 320.164,1406.88 320.174,1406.88 320.183,1406.88 320.192,1406.88 320.201,1406.88 320.21,1406.88 320.219,1406.88 320.229,1406.88 320.238,1406.88 320.247,1406.88 320.256,1406.88 320.265,1406.88 320.275,1406.88 320.284,1406.88 320.293,1406.88 320.302,1406.88 320.311,1406.88 320.321,1406.88 320.33,1406.88 320.339,1406.88 320.348,1406.88 320.357,1406.88 320.366,1406.88 320.376,1406.88 320.385,1406.88 320.394,1406.88 320.403,1406.88 320.412,1406.88 320.422,1406.88 320.431,1406.88 320.44,1406.88 320.449,1406.88 320.458,1406.88 320.468,1406.88 320.477,1406.88 320.486,1406.88 320.495,1406.88 320.504,1406.88 320.514,1406.88 320.523,1406.88 320.532,1406.88 320.541,1406.88 320.55,1406.88 320.559,1406.88 320.569,1406.88 320.578,1406.88 320.587,1406.88 320.596,1406.88 320.605,1406.88 320.615,1406.88 320.624,1406.88 320.633,1406.88 320.642,1406.88 320.651,1406.88 320.661,1406.88 320.67,1406.88 320.679,1406.88 320.688,1406.88 320.697,1406.88 320.706,1406.88 320.716,1406.88 320.725,1406.88 320.734,1406.88 320.743,1406.88 320.752,1406.88 320.762,1406.88 320.771,1406.88 320.78,1406.88 320.789,1406.88 320.798,1406.88 320.808,1406.88 320.817,1406.88 320.826,1406.88 320.835,1406.88 320.844,1406.88 320.854,1406.88 320.863,1406.88 320.872,1406.88 320.881,1406.88 320.89,1406.88 320.899,1406.88 320.909,1406.88 320.918,1406.88 320.927,1406.88 320.936,1406.88 320.945,1406.88 320.955,1406.88 320.964,1406.88 320.973,1406.88 320.982,1406.88 320.991,1406.88 321.001,1406.88 321.01,1406.88 321.019,1406.88 321.028,1406.88 321.037,1406.88 321.046,1406.88 321.056,1406.88 321.065,1406.88 321.074,1406.88 321.083,1406.88 321.092,1406.88 321.102,1406.88 321.111,1406.88 321.12,1406.88 321.129,1406.88 321.138,1406.88 321.148,1406.88 321.157,1406.88 321.166,1406.88 321.175,1406.88 321.184,1406.88 321.194,1406.88 321.203,1406.88 321.212,1406.88 321.221,1406.88 321.23,1406.88 321.239,1406.88 321.249,1406.88 321.258,1406.88 321.267,1406.88 321.276,1406.88 321.285,1406.88 321.295,1406.88 321.304,1406.88 321.313,1406.88 321.322,1406.88 321.331,1406.88 321.341,1406.88 321.35,1406.88 321.359,1406.88 321.368,1406.88 321.377,1406.88 321.386,1406.88 321.396,1406.88 321.405,1406.88 321.414,1406.88 321.423,1406.88 321.432,1406.88 321.442,1406.88 321.451,1406.88 321.46,1406.88 321.469,1406.88 321.478,1406.88 321.488,1406.88 321.497,1406.88 321.506,1406.88 321.515,1406.88 321.524,1406.88 321.534,1406.88 321.543,1406.88 321.552,1406.88 321.561,1406.88 321.57,1406.88 321.579,1406.88 321.589,1406.88 321.598,1406.88 321.607,1406.88 321.616,1406.88 321.625,1406.88 321.635,1406.88 321.644,1406.88 321.653,1406.88 321.662,1406.88 321.671,1406.88 321.681,1406.88 321.69,1406.88 321.699,1406.88 321.708,1406.88 321.717,1406.88 321.727,1406.88 321.736,1406.88 321.745,1406.88 321.754,1406.88 321.763,1406.88 321.772,1406.88 321.782,1406.88 321.791,1406.88 321.8,1406.88 321.809,1406.88 321.818,1406.88 321.828,1406.88 321.837,1406.88 321.846,1406.88 321.855,1406.88 321.864,1406.88 321.874,1406.88 321.883,1406.88 321.892,1406.88 321.901,1406.88 321.91,1406.88 321.919,1406.88 321.929,1406.88 321.938,1406.88 321.947,1406.88 321.956,1406.88 321.965,1406.88 321.975,1406.88 321.984,1406.88 321.993,1406.88 322.002,1406.88 322.011,1406.88 322.021,1406.88 322.03,1406.88 322.039,1406.88 322.048,1406.88 322.057,1406.88 322.067,1406.88 322.076,1406.88 322.085,1406.88 322.094,1406.88 322.103,1406.88 322.112,1406.88 322.122,1406.88 322.131,1406.88 322.14,1406.88 322.149,1406.88 322.158,1406.88 322.168,1406.88 322.177,1406.88 322.186,1406.88 322.195,1406.88 322.204,1406.88 322.214,1406.88 322.223,1406.88 322.232,1406.88 322.241,1406.88 322.25,1406.88 322.259,1406.88 322.269,1406.88 322.278,1406.88 322.287,1406.88 322.296,1406.88 322.305,1406.88 322.315,1406.88 322.324,1406.88 322.333,1406.88 322.342,1406.88 322.351,1406.88 322.361,1406.88 322.37,1406.88 322.379,1406.88 322.388,1406.88 322.397,1406.88 322.407,1406.88 322.416,1406.88 322.425,1406.88 322.434,1406.88 322.443,1406.88 322.452,1406.88 322.462,1406.88 322.471,1406.88 322.48,1406.88 322.489,1406.88 322.498,1406.88 322.508,1406.88 322.517,1406.88 322.526,1406.88 322.535,1406.88 322.544,1406.88 322.554,1406.88 322.563,1406.88 322.572,1406.88 322.581,1406.88 322.59,1406.88 322.599,1406.88 322.609,1406.88 322.618,1406.88 322.627,1406.88 322.636,1406.88 322.645,1406.88 322.655,1406.88 322.664,1406.88 322.673,1406.88 322.682,1406.88 322.691,1406.88 322.701,1406.88 322.71,1406.88 322.719,1406.88 322.728,1406.88 322.737,1406.88 322.747,1406.88 322.756,1406.88 322.765,1406.88 322.774,1406.88 322.783,1406.88 322.792,1406.88 322.802,1406.88 322.811,1406.88 322.82,1406.88 322.829,1406.88 322.838,1406.88 322.848,1406.88 322.857,1406.88 322.866,1406.88 322.875,1406.88 322.884,1406.88 322.894,1406.88 322.903,1406.88 322.912,1406.88 322.921,1406.88 322.93,1406.88 322.939,1406.88 322.949,1406.88 322.958,1406.88 322.967,1406.88 322.976,1406.88 322.985,1406.88 322.995,1406.88 323.004,1406.88 323.013,1406.88 323.022,1406.88 323.031,1406.88 323.041,1406.88 323.05,1406.88 323.059,1406.88 323.068,1406.88 323.077,1406.88 323.087,1406.88 323.096,1406.88 323.105,1406.88 323.114,1406.88 323.123,1406.88 323.132,1406.88 323.142,1406.88 323.151,1406.88 323.16,1406.88 323.169,1406.88 323.178,1406.88 323.188,1406.88 323.197,1406.88 323.206,1406.88 323.215,1406.88 323.224,1406.88 323.234,1406.88 323.243,1406.88 323.252,1406.88 323.261,1406.88 323.27,1406.88 323.279,1406.88 323.289,1406.88 323.298,1406.88 323.307,1406.88 323.316,1406.88 323.325,1406.88 323.335,1406.88 323.344,1406.88 323.353,1406.88 323.362,1406.88 323.371,1406.88 323.381,1406.88 323.39,1406.88 323.399,1406.88 323.408,1406.88 323.417,1406.88 323.427,1406.88 323.436,1406.88 323.445,1406.88 323.454,1406.88 323.463,1406.88 323.472,1406.88 323.482,1406.88 323.491,1406.88 323.5,1406.88 323.509,1406.88 323.518,1406.88 323.528,1406.88 323.537,1406.88 323.546,1406.88 323.555,1406.88 323.564,1406.88 323.574,1406.88 323.583,1406.88 323.592,1406.88 323.601,1406.88 323.61,1406.88 323.619,1406.88 323.629,1406.88 323.638,1406.88 323.647,1406.88 323.656,1406.88 323.665,1406.88 323.675,1406.88 323.684,1406.88 323.693,1406.88 323.702,1406.88 323.711,1406.88 323.721,1406.88 323.73,1406.88 323.739,1406.88 323.748,1406.88 323.757,1406.88 323.767,1406.88 323.776,1406.88 323.785,1406.88 323.794,1406.88 323.803,1406.88 323.812,1406.88 323.822,1406.88 323.831,1406.88 323.84,1406.88 323.849,1406.88 323.858,1406.88 323.868,1406.88 323.877,1406.88 323.886,1406.88 323.895,1406.88 323.904,1406.88 323.914,1406.88 323.923,1406.88 323.932,1406.88 323.941,1406.88 323.95,1406.88 323.959,1406.88 323.969,1406.88 323.978,1406.88 323.987,1406.88 323.996,1406.88 324.005,1406.88 324.015,1406.88 324.024,1406.88 324.033,1406.88 324.042,1406.88 324.051,1406.88 324.061,1406.88 324.07,1406.88 324.079,1406.88 324.088,1406.88 324.097,1406.88 324.107,1406.88 324.116,1406.88 324.125,1406.88 324.134,1406.88 324.143,1406.88 324.152,1406.88 324.162,1406.88 324.171,1406.88 324.18,1406.88 324.189,1406.88 324.198,1406.88 324.208,1406.88 324.217,1406.88 324.226,1406.88 324.235,1406.88 324.244,1406.88 324.254,1406.88 324.263,1406.88 324.272,1406.88 324.281,1406.88 324.29,1406.88 324.3,1406.88 324.309,1406.88 324.318,1406.88 324.327,1406.88 324.336,1406.88 324.345,1406.88 324.355,1406.88 324.364,1406.88 324.373,1406.88 324.382,1406.88 324.391,1406.88 324.401,1406.88 324.41,1406.88 324.419,1406.88 324.428,1406.88 324.437,1406.88 324.447,1406.88 324.456,1406.88 324.465,1406.88 324.474,1406.88 324.483,1406.88 324.492,1406.88 324.502,1406.88 324.511,1406.88 324.52,1406.88 324.529,1406.88 324.538,1406.88 324.548,1406.88 324.557,1406.88 324.566,1406.88 324.575,1406.88 324.584,1406.88 324.594,1406.88 324.603,1406.88 324.612,1406.88 324.621,1406.88 324.63,1406.88 324.64,1406.88 324.649,1406.88 324.658,1406.88 324.667,1406.88 324.676,1406.88 324.685,1406.88 324.695,1406.88 324.704,1406.88 324.713,1406.88 324.722,1406.88 324.731,1406.88 324.741,1406.88 324.75,1406.88 324.759,1406.88 324.768,1406.88 324.777,1406.88 324.787,1406.88 324.796,1406.88 324.805,1406.88 324.814,1406.88 324.823,1406.88 324.832,1406.88 324.842,1406.88 324.851,1406.88 324.86,1406.88 324.869,1406.88 324.878,1406.88 324.888,1406.88 324.897,1406.88 324.906,1406.88 324.915,1406.88 324.924,1406.88 324.934,1406.88 324.943,1406.88 324.952,1406.88 324.961,1406.88 324.97,1406.88 324.98,1406.88 324.989,1406.88 324.998,1406.88 325.007,1406.88 325.016,1406.88 325.025,1406.88 325.035,1406.88 325.044,1406.88 325.053,1406.88 325.062,1406.88 325.071,1406.88 325.081,1406.88 325.09,1406.88 325.099,1406.88 325.108,1406.88 325.117,1406.88 325.127,1406.88 325.136,1406.88 325.145,1406.88 325.154,1406.88 325.163,1406.88 325.172,1406.88 325.182,1406.88 325.191,1406.88 325.2,1406.88 325.209,1406.88 325.218,1406.88 325.228,1406.88 325.237,1406.88 325.246,1406.88 325.255,1406.88 325.264,1406.88 325.274,1406.88 325.283,1406.88 325.292,1406.88 325.301,1406.88 325.31,1406.88 325.32,1406.88 325.329,1406.88 325.338,1406.88 325.347,1406.88 325.356,1406.88 325.365,1406.88 325.375,1406.88 325.384,1406.88 325.393,1406.88 325.402,1406.88 325.411,1406.88 325.421,1406.88 325.43,1406.88 325.439,1406.88 325.448,1406.88 325.457,1406.88 325.467,1406.88 325.476,1406.88 325.485,1406.88 325.494,1406.88 325.503,1406.88 325.512,1406.88 325.522,1406.88 325.531,1406.88 325.54,1406.88 325.549,1406.88 325.558,1406.88 325.568,1406.88 325.577,1406.88 325.586,1406.88 325.595,1406.88 325.604,1406.88 325.614,1406.88 325.623,1406.88 325.632,1406.88 325.641,1406.88 325.65,1406.88 325.66,1406.88 325.669,1406.88 325.678,1406.88 325.687,1406.88 325.696,1406.88 325.705,1406.88 325.715,1406.88 325.724,1406.88 325.733,1406.88 325.742,1406.88 325.751,1406.88 325.761,1406.88 325.77,1406.88 325.779,1406.88 325.788,1406.88 325.797,1406.88 325.807,1406.88 325.816,1406.88 325.825,1406.88 325.834,1406.88 325.843,1406.88 325.852,1406.88 325.862,1406.88 325.871,1406.88 325.88,1406.88 325.889,1406.88 325.898,1406.88 325.908,1406.88 325.917,1406.88 325.926,1406.88 325.935,1406.88 325.944,1406.88 325.954,1406.88 325.963,1406.88 325.972,1406.88 325.981,1406.88 325.99,1406.88 326,1406.88 326.009,1406.88 326.018,1406.88 326.027,1406.88 326.036,1406.88 326.045,1406.88 326.055,1406.88 326.064,1406.88 326.073,1406.88 326.082,1406.88 326.091,1406.88 326.101,1406.88 326.11,1406.88 326.119,1406.88 326.128,1406.88 326.137,1406.88 326.147,1406.88 326.156,1406.88 326.165,1406.88 326.174,1406.88 326.183,1406.88 326.192,1406.88 326.202,1406.88 326.211,1406.88 326.22,1406.88 326.229,1406.88 326.238,1406.88 326.248,1406.88 326.257,1406.88 326.266,1406.88 326.275,1406.88 326.284,1406.88 326.294,1406.88 326.303,1406.88 326.312,1406.88 326.321,1406.88 326.33,1406.88 326.34,1406.88 326.349,1406.88 326.358,1406.88 326.367,1406.88 326.376,1406.88 326.385,1406.88 326.395,1406.88 326.404,1406.88 326.413,1406.88 326.422,1406.88 326.431,1406.88 326.441,1406.88 326.45,1406.88 326.459,1406.88 326.468,1406.88 326.477,1406.88 326.487,1406.88 326.496,1406.88 326.505,1406.88 326.514,1406.88 326.523,1406.88 326.532,1406.88 326.542,1406.88 326.551,1406.88 326.56,1406.88 326.569,1406.88 326.578,1406.88 326.588,1406.88 326.597,1406.88 326.606,1406.88 326.615,1406.88 326.624,1406.88 326.634,1406.88 326.643,1406.88 326.652,1406.88 326.661,1406.88 326.67,1406.88 326.68,1406.88 326.689,1406.88 326.698,1406.88 326.707,1406.88 326.716,1406.88 326.725,1406.88 326.735,1406.88 326.744,1406.88 326.753,1406.88 326.762,1406.88 326.771,1406.88 326.781,1406.88 326.79,1406.88 326.799,1406.88 326.808,1406.88 326.817,1406.88 326.827,1406.88 326.836,1406.88 326.845,1406.88 326.854,1406.88 326.863,1406.88 326.873,1406.88 326.882,1406.88 326.891,1406.88 326.9,1406.88 326.909,1406.88 326.918,1406.88 326.928,1406.88 326.937,1406.88 326.946,1406.88 326.955,1406.88 326.964,1406.88 326.974,1406.88 326.983,1406.88 326.992,1406.88 327.001,1406.88 327.01,1406.88 327.02,1406.88 327.029,1406.88 327.038,1406.88 327.047,1406.88 327.056,1406.88 327.065,1406.88 327.075,1406.88 327.084,1406.88 327.093,1406.88 327.102,1406.88 327.111,1406.88 327.121,1406.88 327.13,1406.88 327.139,1406.88 327.148,1406.88 327.157,1406.88 327.167,1406.88 327.176,1406.88 327.185,1406.88 327.194,1406.88 327.203,1406.88 327.213,1406.88 327.222,1406.88 327.231,1406.88 327.24,1406.88 327.249,1406.88 327.258,1406.88 327.268,1406.88 327.277,1406.88 327.286,1406.88 327.295,1406.88 327.304,1406.88 327.314,1406.88 327.323,1406.88 327.332,1406.88 327.341,1406.88 327.35,1406.88 327.36,1406.88 327.369,1406.88 327.378,1406.88 327.387,1406.88 327.396,1406.88 327.405,1406.88 327.415,1406.88 327.424,1406.88 327.433,1406.88 327.442,1406.88 327.451,1406.88 327.461,1406.88 327.47,1406.88 327.479,1406.88 327.488,1406.88 327.497,1406.88 327.507,1406.88 327.516,1406.88 327.525,1406.88 327.534,1406.88 327.543,1406.88 327.553,1406.88 327.562,1406.88 327.571,1406.88 327.58,1406.88 327.589,1406.88 327.598,1406.88 327.608,1406.88 327.617,1406.88 327.626,1406.88 327.635,1406.88 327.644,1406.88 327.654,1406.88 327.663,1406.88 327.672,1406.88 327.681,1406.88 327.69,1406.88 327.7,1406.88 327.709,1406.88 327.718,1406.88 327.727,1406.88 327.736,1406.88 327.745,1406.88 327.755,1406.88 327.764,1406.88 327.773,1406.88 327.782,1406.88 327.791,1406.88 327.801,1406.88 327.81,1406.88 327.819,1406.88 327.828,1406.88 327.837,1406.88 327.847,1406.88 327.856,1406.88 327.865,1406.88 327.874,1406.88 327.883,1406.88 327.893,1406.88 327.902,1406.88 327.911,1406.88 327.92,1406.88 327.929,1406.88 327.938,1406.88 327.948,1406.88 327.957,1406.88 327.966,1406.88 327.975,1406.88 327.984,1406.88 327.994,1406.88 328.003,1406.88 328.012,1406.88 328.021,1406.88 328.03,1406.88 328.04,1406.88 328.049,1406.88 328.058,1406.88 328.067,1406.88 328.076,1406.88 328.085,1406.88 328.095,1406.88 328.104,1406.88 328.113,1406.88 328.122,1406.88 328.131,1406.88 328.141,1406.88 328.15,1406.88 328.159,1406.88 328.168,1406.88 328.177,1406.88 328.187,1406.88 328.196,1406.88 328.205,1406.88 328.214,1406.88 328.223,1406.88 328.233,1406.88 328.242,1406.88 328.251,1406.88 328.26,1406.88 328.269,1406.88 328.278,1406.88 328.288,1406.88 328.297,1406.88 328.306,1406.88 328.315,1406.88 328.324,1406.88 328.334,1406.88 328.343,1406.88 328.352,1406.88 328.361,1406.88 328.37,1406.88 328.38,1406.88 328.389,1406.88 328.398,1406.88 328.407,1406.88 328.416,1406.88 328.425,1406.88 328.435,1406.88 328.444,1406.88 328.453,1406.88 328.462,1406.88 328.471,1406.88 328.481,1406.88 328.49,1406.88 328.499,1406.88 328.508,1406.88 328.517,1406.88 328.527,1406.88 328.536,1406.88 328.545,1406.88 328.554,1406.88 328.563,1406.88 328.573,1406.88 328.582,1406.88 328.591,1406.88 328.6,1406.88 328.609,1406.88 328.618,1406.88 328.628,1406.88 328.637,1406.88 328.646,1406.88 328.655,1406.88 328.664,1406.88 328.674,1406.88 328.683,1406.88 328.692,1406.88 328.701,1406.88 328.71,1406.88 328.72,1406.88 328.729,1406.88 328.738,1406.88 328.747,1406.88 328.756,1406.88 328.765,1406.88 328.775,1406.88 328.784,1406.88 328.793,1406.88 328.802,1406.88 328.811,1406.88 328.821,1406.88 328.83,1406.88 328.839,1406.88 328.848,1406.88 328.857,1406.88 328.867,1406.88 328.876,1406.88 328.885,1406.88 328.894,1406.88 328.903,1406.88 328.913,1406.88 328.922,1406.88 328.931,1406.88 328.94,1406.88 328.949,1406.88 328.958,1406.88 328.968,1406.88 328.977,1406.88 328.986,1406.88 328.995,1406.88 329.004,1406.88 329.014,1406.88 329.023,1406.88 329.032,1406.88 329.041,1406.88 329.05,1406.88 329.06,1406.88 329.069,1406.88 329.078,1406.88 329.087,1406.88 329.096,1406.88 329.106,1406.88 329.115,1406.88 329.124,1406.88 329.133,1406.88 329.142,1406.88 329.151,1406.88 329.161,1406.88 329.17,1406.88 329.179,1406.88 329.188,1406.88 329.197,1406.88 329.207,1406.88 329.216,1406.88 329.225,1406.88 329.234,1406.88 329.243,1406.88 329.253,1406.88 329.262,1406.88 329.271,1406.88 329.28,1406.88 329.289,1406.88 329.298,1406.88 329.308,1406.88 329.317,1406.88 329.326,1406.88 329.335,1406.88 329.344,1406.88 329.354,1406.88 329.363,1406.88 329.372,1406.88 329.381,1406.88 329.39,1406.88 329.4,1406.88 329.409,1406.88 329.418,1406.88 329.427,1406.88 329.436,1406.88 329.446,1406.88 329.455,1406.88 329.464,1406.88 329.473,1406.88 329.482,1406.88 329.491,1406.88 329.501,1406.88 329.51,1406.88 329.519,1406.88 329.528,1406.88 329.537,1406.88 329.547,1406.88 329.556,1406.88 329.565,1406.88 329.574,1406.88 329.583,1406.88 329.593,1406.88 329.602,1406.88 329.611,1406.88 329.62,1406.88 329.629,1406.88 329.638,1406.88 329.648,1406.88 329.657,1406.88 329.666,1406.88 329.675,1406.88 329.684,1406.88 329.694,1406.88 329.703,1406.88 329.712,1406.88 329.721,1406.88 329.73,1406.88 329.74,1406.88 329.749,1406.88 329.758,1406.88 329.767,1406.88 329.776,1406.88 329.786,1406.88 329.795,1406.88 329.804,1406.88 329.813,1406.88 329.822,1406.88 329.831,1406.88 329.841,1406.88 329.85,1406.88 329.859,1406.88 329.868,1406.88 329.877,1406.88 329.887,1406.88 329.896,1406.88 329.905,1406.88 329.914,1406.88 329.923,1406.88 329.933,1406.88 329.942,1406.88 329.951,1406.88 329.96,1406.88 329.969,1406.88 329.978,1406.88 329.988,1406.88 329.997,1406.88 330.006,1406.88 330.015,1406.88 330.024,1406.88 330.034,1406.88 330.043,1406.88 330.052,1406.88 330.061,1406.88 330.07,1406.88 330.08,1406.88 330.089,1406.88 330.098,1406.88 330.107,1406.88 330.116,1406.88 330.126,1406.88 330.135,1406.88 330.144,1406.88 330.153,1406.88 330.162,1406.88 330.171,1406.88 330.181,1406.88 330.19,1406.88 330.199,1406.88 330.208,1406.88 330.217,1406.88 330.227,1406.88 330.236,1406.88 330.245,1406.88 330.254,1406.88 330.263,1406.88 330.273,1406.88 330.282,1406.88 330.291,1406.88 330.3,1406.88 330.309,1406.88 330.318,1406.88 330.328,1406.88 330.337,1406.88 330.346,1406.88 330.355,1406.88 330.364,1406.88 330.374,1406.88 330.383,1406.88 330.392,1406.88 330.401,1406.88 330.41,1406.88 330.42,1406.88 330.429,1406.88 330.438,1406.88 330.447,1406.88 330.456,1406.88 330.466,1406.88 330.475,1406.88 330.484,1406.88 330.493,1406.88 330.502,1406.88 330.511,1406.88 330.521,1406.88 330.53,1406.88 330.539,1406.88 330.548,1406.88 330.557,1406.88 330.567,1406.88 330.576,1406.88 330.585,1406.88 330.594,1406.88 330.603,1406.88 330.613,1406.88 330.622,1406.88 330.631,1406.88 330.64,1406.88 330.649,1406.88 330.658,1406.88 330.668,1406.88 330.677,1406.88 330.686,1406.88 330.695,1406.88 330.704,1406.88 330.714,1406.88 330.723,1406.88 330.732,1406.88 330.741,1406.88 330.75,1406.88 330.76,1406.88 330.769,1406.88 330.778,1406.88 330.787,1406.88 330.796,1406.88 330.806,1406.88 330.815,1406.88 330.824,1406.88 330.833,1406.88 330.842,1406.88 330.851,1406.88 330.861,1406.88 330.87,1406.88 330.879,1406.88 330.888,1406.88 330.897,1406.88 330.907,1406.88 330.916,1406.88 330.925,1406.88 330.934,1406.88 330.943,1406.88 330.953,1406.81 330.962,1406.53 330.971,1406.25 330.98,1405.96 330.989,1405.68 330.998,1405.4 331.008,1405.12 331.017,1404.83 331.026,1404.55 331.035,1404.27 331.044,1403.98 331.054,1403.7 331.063,1403.42 331.072,1403.14 331.081,1402.86 331.09,1402.57 331.1,1402.29 331.109,1402.01 331.118,1401.73 331.127,1401.45 331.136,1401.16 331.146,1400.88 331.155,1400.6 331.164,1400.32 331.173,1400.04 331.182,1399.76 331.191,1399.48 331.201,1399.2 331.21,1398.92 331.219,1398.64 331.228,1398.36 331.237,1398.08 331.247,1397.8 331.256,1397.52 331.265,1397.24 331.274,1396.96 331.283,1396.68 331.293,1396.4 331.302,1396.12 331.311,1395.84 331.32,1395.56 331.329,1395.28 331.338,1395 331.348,1394.72 331.357,1394.44 331.366,1394.16 331.375,1393.88 331.384,1393.61 331.394,1393.33 331.403,1393.05 331.412,1392.77 331.421,1392.49 331.43,1392.21 331.44,1391.94 331.449,1391.66 331.458,1391.38 331.467,1391.1 331.476,1390.83 331.486,1390.55 331.495,1390.27 331.504,1389.99 331.513,1389.72 331.522,1389.44 331.531,1389.16 331.541,1388.89 331.55,1388.61 331.559,1388.33 331.568,1388.06 331.577,1387.78 331.587,1387.5 331.596,1387.23 331.605,1386.95 331.614,1386.68 331.623,1386.4 331.633,1386.12 331.642,1385.85 331.651,1385.57 331.66,1385.3 331.669,1385.02 331.679,1384.75 331.688,1384.47 331.697,1384.2 331.706,1383.92 331.715,1383.65 331.724,1383.37 331.734,1383.1 331.743,1382.82 331.752,1382.55 331.761,1382.27 331.77,1382 331.78,1381.73 331.789,1381.45 331.798,1381.18 331.807,1380.91 331.816,1380.63 331.826,1380.36 331.835,1380.08 331.844,1379.81 331.853,1379.54 331.862,1379.26 331.871,1378.99 331.881,1378.72 331.89,1378.45 331.899,1378.17 331.908,1377.9 331.917,1377.63 331.927,1377.36 331.936,1377.08 331.945,1376.81 331.954,1376.54 331.963,1376.27 331.973,1376 331.982,1375.72 331.991,1375.45 332,1375.18 332.009,1374.91 332.019,1374.64 332.028,1374.37 332.037,1374.1 332.046,1373.82 332.055,1373.55 332.064,1373.28 332.074,1373.01 332.083,1372.74 332.092,1372.47 332.101,1372.2 332.11,1371.93 332.12,1371.66 332.129,1371.39 332.138,1371.12 332.147,1370.85 332.156,1370.58 332.166,1370.31 332.175,1370.04 332.184,1369.77 332.193,1369.5 332.202,1369.23 332.211,1368.96 332.221,1368.69 332.23,1368.43 332.239,1368.16 332.248,1367.89 332.257,1367.62 332.267,1367.35 332.276,1367.08 332.285,1366.81 332.294,1366.55 332.303,1366.28 332.313,1366.01 332.322,1365.74 332.331,1365.47 332.34,1365.21 332.349,1364.94 332.359,1364.67 332.368,1364.4 332.377,1364.14 332.386,1363.87 332.395,1363.6 332.404,1363.34 332.414,1363.07 332.423,1362.8 332.432,1362.54 332.441,1362.27 332.45,1362 332.46,1361.74 332.469,1361.47 332.478,1361.2 332.487,1360.94 332.496,1360.67 332.506,1360.41 332.515,1360.14 332.524,1359.87 332.533,1359.61 332.542,1359.34 332.551,1359.08 332.561,1358.81 332.57,1358.55 332.579,1358.28 332.588,1358.02 332.597,1357.75 332.607,1357.49 332.616,1357.22 332.625,1356.96 332.634,1356.69 332.643,1356.43 332.653,1356.17 332.662,1355.9 332.671,1355.64 332.68,1355.37 332.689,1355.11 332.699,1354.85 332.708,1354.58 332.717,1354.32 332.726,1354.06 332.735,1353.79 332.744,1353.53 332.754,1353.27 332.763,1353 332.772,1352.74 332.781,1352.48 332.79,1352.21 332.8,1351.95 332.809,1351.69 332.818,1351.43 332.827,1351.16 332.836,1350.9 332.846,1350.64 332.855,1350.38 332.864,1350.12 332.873,1349.86 332.882,1349.59 332.891,1349.33 332.901,1349.07 332.91,1348.81 332.919,1348.55 332.928,1348.29 332.937,1348.03 332.947,1347.76 332.956,1347.5 332.965,1347.24 332.974,1346.98 332.983,1346.72 332.993,1346.46 333.002,1346.2 333.011,1345.94 333.02,1345.68 333.029,1345.42 333.039,1345.16 333.048,1344.9 333.057,1344.64 333.066,1344.38 333.075,1344.12 333.084,1343.86 333.094,1343.6 333.103,1343.34 333.112,1343.08 333.121,1342.83 333.13,1342.57 333.14,1342.31 333.149,1342.05 333.158,1341.79 333.167,1341.53 333.176,1341.27 333.186,1341.02 333.195,1340.76 333.204,1340.5 333.213,1340.24 333.222,1339.98 333.231,1339.72 333.241,1339.47 333.25,1339.21 333.259,1338.95 333.268,1338.69 333.277,1338.44 333.287,1338.18 333.296,1337.92 333.305,1337.67 333.314,1337.41 333.323,1337.15 333.333,1336.9 333.342,1336.64 333.351,1336.38 333.36,1336.13 333.369,1335.87 333.379,1335.61 333.388,1335.36 333.397,1335.1 333.406,1334.85 333.415,1334.59 333.424,1334.33 333.434,1334.08 333.443,1333.82 333.452,1333.57 333.461,1333.31 333.47,1333.06 333.48,1332.8 333.489,1332.55 333.498,1332.29 333.507,1332.04 333.516,1331.78 333.526,1331.53 333.535,1331.27 333.544,1331.02 333.553,1330.76 333.562,1330.51 333.571,1330.26 333.581,1330 333.59,1329.75 333.599,1329.49 333.608,1329.24 333.617,1328.99 333.627,1328.73 333.636,1328.48 333.645,1328.23 333.654,1327.97 333.663,1327.72 333.673,1327.47 333.682,1327.21 333.691,1326.96 333.7,1326.71 333.709,1326.46 333.719,1326.2 333.728,1325.95 333.737,1325.7 333.746,1325.45 333.755,1325.19 333.764,1324.94 333.774,1324.69 333.783,1324.44 333.792,1324.19 333.801,1323.93 333.81,1323.68 333.82,1323.43 333.829,1323.18 333.838,1322.93 333.847,1322.68 333.856,1322.43 333.866,1322.18 333.875,1321.93 333.884,1321.67 333.893,1321.42 333.902,1321.17 333.911,1320.92 333.921,1320.67 333.93,1320.42 333.939,1320.17 333.948,1319.92 333.957,1319.67 333.967,1319.42 333.976,1319.17 333.985,1318.92 333.994,1318.67 334.003,1318.42 334.013,1318.17 334.022,1317.92 334.031,1317.68 334.04,1317.43 334.049,1317.18 334.059,1316.93 334.068,1316.68 334.077,1316.43 334.086,1316.18 334.095,1315.93 334.104,1315.69 334.114,1315.44 334.123,1315.19 334.132,1314.94 334.141,1314.69 334.15,1314.45 334.16,1314.2 334.169,1313.95 334.178,1313.7 334.187,1313.45 334.196,1313.21 334.206,1312.96 334.215,1312.71 334.224,1312.47 334.233,1312.22 334.242,1311.97 334.252,1311.72 334.261,1311.48 334.27,1311.23 334.279,1310.98 334.288,1310.74 334.297,1310.49 334.307,1310.25 334.316,1310 334.325,1309.75 334.334,1309.51 334.343,1309.26 334.353,1309.02 334.362,1308.77 334.371,1308.52 334.38,1308.28 334.389,1308.03 334.399,1307.79 334.408,1307.54 334.417,1307.3 334.426,1307.05 334.435,1306.81 334.444,1306.56 334.454,1306.32 334.463,1306.07 334.472,1305.83 334.481,1305.59 334.49,1305.34 334.5,1305.1 334.509,1304.85 334.518,1304.61 334.527,1304.37 334.536,1304.12 334.546,1303.88 334.555,1303.63 334.564,1303.39 334.573,1303.15 334.582,1302.9 334.592,1302.66 334.601,1302.42 334.61,1302.17 334.619,1301.93 334.628,1301.69 334.637,1301.45 334.647,1301.2 334.656,1300.96 334.665,1300.72 334.674,1300.48 334.683,1300.23 334.693,1299.99 334.702,1299.75 334.711,1299.51 334.72,1299.27 334.729,1299.02 334.739,1298.78 334.748,1298.54 334.757,1298.3 334.766,1298.06 334.775,1297.82 334.784,1297.57 334.794,1297.33 334.803,1297.09 334.812,1296.85 334.821,1296.61 334.83,1296.37 334.84,1296.13 334.849,1295.89 334.858,1295.65 334.867,1295.41 334.876,1295.17 334.886,1294.93 334.895,1294.69 334.904,1294.45 334.913,1294.21 334.922,1293.97 334.932,1293.73 334.941,1293.49 334.95,1293.25 334.959,1293.01 334.968,1292.77 334.977,1292.53 334.987,1292.29 334.996,1292.05 335.005,1291.81 335.014,1291.58 335.023,1291.34 335.033,1291.1 335.042,1290.86 335.051,1290.62 335.06,1290.38 335.069,1290.14 335.079,1289.91 335.088,1289.67 335.097,1289.43 335.106,1289.19 335.115,1288.96 335.124,1288.72 335.134,1288.48 335.143,1288.24 335.152,1288 335.161,1287.77 335.17,1287.53 335.18,1287.29 335.189,1287.06 335.198,1286.82 335.207,1286.58 335.216,1286.35 335.226,1286.11 335.235,1285.87 335.244,1285.64 335.253,1285.4 335.262,1285.16 335.272,1284.93 335.281,1284.69 335.29,1284.46 335.299,1284.22 335.308,1283.98 335.317,1283.75 335.327,1283.51 335.336,1283.28 335.345,1283.04 335.354,1282.81 335.363,1282.57 335.373,1282.34 335.382,1282.1 335.391,1281.87 335.4,1281.63 335.409,1281.4 335.419,1281.16 335.428,1280.93 335.437,1280.69 335.446,1280.46 335.455,1280.22 335.464,1279.99 335.474,1279.76 335.483,1279.52 335.492,1279.29 335.501,1279.05 335.51,1278.82 335.52,1278.59 335.529,1278.35 335.538,1278.12 335.547,1277.89 335.556,1277.65 335.566,1277.42 335.575,1277.19 335.584,1276.95 335.593,1276.72 335.602,1276.49 335.612,1276.26 335.621,1276.02 335.63,1275.79 335.639,1275.56 335.648,1275.33 335.657,1275.09 335.667,1274.86 335.676,1274.63 335.685,1274.4 335.694,1274.17 335.703,1273.93 335.713,1273.7 335.722,1273.47 335.731,1273.24 335.74,1273.01 335.749,1272.78 335.759,1272.55 335.768,1272.32 335.777,1272.08 335.786,1271.85 335.795,1271.62 335.804,1271.39 335.814,1271.16 335.823,1270.93 335.832,1270.7 335.841,1270.47 335.85,1270.24 335.86,1270.01 335.869,1269.78 335.878,1269.55 335.887,1269.32 335.896,1269.09 335.906,1268.86 335.915,1268.63 335.924,1268.4 335.933,1268.17 335.942,1267.94 335.952,1267.71 335.961,1267.48 335.97,1267.26 335.979,1267.03 335.988,1266.8 335.997,1266.57 336.007,1266.34 336.016,1266.11 336.025,1265.88 336.034,1265.65 336.043,1265.43 336.053,1265.2 336.062,1264.97 336.071,1264.74 336.08,1264.51 336.089,1264.29 336.099,1264.06 336.108,1263.83 336.117,1263.6 336.126,1263.38 336.135,1263.15 336.144,1262.92 336.154,1262.69 336.163,1262.47 336.172,1262.24 336.181,1262.01 336.19,1261.79 336.2,1261.56 336.209,1261.33 336.218,1261.11 336.227,1260.88 336.236,1260.65 336.246,1260.43 336.255,1260.2 336.264,1259.98 336.273,1259.75 336.282,1259.52 336.292,1259.3 336.301,1259.07 336.31,1258.85 336.319,1258.62 336.328,1258.4 336.337,1258.17 336.347,1257.95 336.356,1257.72 336.365,1257.49 336.374,1257.27 336.383,1257.05 336.393,1256.82 336.402,1256.6 336.411,1256.37 336.42,1256.15 336.429,1255.92 336.439,1255.7 336.448,1255.47 336.457,1255.25 336.466,1255.03 336.475,1254.8 336.485,1254.58 336.494,1254.35 336.503,1254.13 336.512,1253.91 336.521,1253.68 336.53,1253.46 336.54,1253.24 336.549,1253.01 336.558,1252.79 336.567,1252.57 336.576,1252.34 336.586,1252.12 336.595,1251.9 336.604,1251.68 336.613,1251.45 336.622,1251.23 336.632,1251.01 336.641,1250.79 336.65,1250.56 336.659,1250.34 336.668,1250.12 336.677,1249.9 336.687,1249.68 336.696,1249.45 336.705,1249.23 336.714,1249.01 336.723,1248.79 336.733,1248.57 336.742,1248.35 336.751,1248.13 336.76,1247.9 336.769,1247.68 336.779,1247.46 336.788,1247.24 336.797,1247.02 336.806,1246.8 336.815,1246.58 336.825,1246.36 336.834,1246.14 336.843,1245.92 336.852,1245.7 336.861,1245.48 336.87,1245.26 336.88,1245.04 336.889,1244.82 336.898,1244.6 336.907,1244.38 336.916,1244.16 336.926,1243.94 336.935,1243.72 336.944,1243.5 336.953,1243.28 336.962,1243.06 336.972,1242.84 336.981,1242.62 336.99,1242.41 336.999,1242.19 337.008,1241.97 337.017,1241.75 337.027,1241.53 337.036,1241.31 337.045,1241.09 337.054,1240.88 337.063,1240.66 337.073,1240.44 337.082,1240.22 337.091,1240 337.1,1239.79 337.109,1239.57 337.119,1239.35 337.128,1239.13 337.137,1238.92 337.146,1238.7 337.155,1238.48 337.165,1238.26 337.174,1238.05 337.183,1237.83 337.192,1237.61 337.201,1237.4 337.21,1237.18 337.22,1236.96 337.229,1236.75 337.238,1236.53 337.247,1236.31 337.256,1236.1 337.266,1235.88 337.275,1235.66 337.284,1235.45 337.293,1235.23 337.302,1235.02 337.312,1234.8 337.321,1234.59 337.33,1234.37 337.339,1234.15 337.348,1233.94 337.357,1233.72 337.367,1233.51 337.376,1233.29 337.385,1233.08 337.394,1232.86 337.403,1232.65 337.413,1232.43 337.422,1232.22 337.431,1232 337.44,1231.79 337.449,1231.58 337.459,1231.36 337.468,1231.15 337.477,1230.93 337.486,1230.72 337.495,1230.51 337.505,1230.29 337.514,1230.08 337.523,1229.86 337.532,1229.65 337.541,1229.44 337.55,1229.22 337.56,1229.01 337.569,1228.8 337.578,1228.58 337.587,1228.37 337.596,1228.16 337.606,1227.94 337.615,1227.73 337.624,1227.52 337.633,1227.31 337.642,1227.09 337.652,1226.88 337.661,1226.67 337.67,1226.46 337.679,1226.24 337.688,1226.03 337.697,1225.82 337.707,1225.61 337.716,1225.4 337.725,1225.19 337.734,1224.97 337.743,1224.76 337.753,1224.55 337.762,1224.34 337.771,1224.13 337.78,1223.92 337.789,1223.71 337.799,1223.49 337.808,1223.28 337.817,1223.07 337.826,1222.86 337.835,1222.65 337.845,1222.44 337.854,1222.23 337.863,1222.02 337.872,1221.81 337.881,1221.6 337.89,1221.39 337.9,1221.18 337.909,1220.97 337.918,1220.76 337.927,1220.55 337.936,1220.34 337.946,1220.13 337.955,1219.92 337.964,1219.71 337.973,1219.5 337.982,1219.29 337.992,1219.08 338.001,1218.87 338.01,1218.66 338.019,1218.46 338.028,1218.25 338.037,1218.04 338.047,1217.83 338.056,1217.62 338.065,1217.41 338.074,1217.2 338.083,1217 338.093,1216.79 338.102,1216.58 338.111,1216.37 338.12,1216.16 338.129,1215.96 338.139,1215.75 338.148,1215.54 338.157,1215.33 338.166,1215.12 338.175,1214.92 338.185,1214.71 338.194,1214.5 338.203,1214.3 338.212,1214.09 338.221,1213.88 338.23,1213.67 338.24,1213.47 338.249,1213.26 338.258,1213.05 338.267,1212.85 338.276,1212.64 338.286,1212.43 338.295,1212.23 338.304,1212.02 338.313,1211.82 338.322,1211.61 338.332,1211.4 338.341,1211.2 338.35,1210.99 338.359,1210.79 338.368,1210.58 338.377,1210.38 338.387,1210.17 338.396,1209.96 338.405,1209.76 338.414,1209.55 338.423,1209.35 338.433,1209.14 338.442,1208.94 338.451,1208.73 338.46,1208.53 338.469,1208.32 338.479,1208.12 338.488,1207.92 338.497,1207.71 338.506,1207.51 338.515,1207.3 338.525,1207.1 338.534,1206.89 338.543,1206.69 338.552,1206.49 338.561,1206.28 338.57,1206.08 338.58,1205.87 338.589,1205.67 338.598,1205.47 338.607,1205.26 338.616,1205.06 338.626,1204.86 338.635,1204.65 338.644,1204.45 338.653,1204.25 338.662,1204.05 338.672,1203.84 338.681,1203.64 338.69,1203.44 338.699,1203.23 338.708,1203.03 338.717,1202.83 338.727,1202.63 338.736,1202.43 338.745,1202.22 338.754,1202.02 338.763,1201.82 338.773,1201.62 338.782,1201.42 338.791,1201.21 338.8,1201.01 338.809,1200.81 338.819,1200.61 338.828,1200.41 338.837,1200.21 338.846,1200.01 338.855,1199.8 338.865,1199.6 338.874,1199.4 338.883,1199.2 338.892,1199 338.901,1198.8 338.91,1198.6 338.92,1198.4 338.929,1198.2 338.938,1198 338.947,1197.8 338.956,1197.6 338.966,1197.4 338.975,1197.2 338.984,1197 338.993,1196.8 339.002,1196.6 339.012,1196.4 339.021,1196.2 339.03,1196 339.039,1195.8 339.048,1195.6 339.058,1195.4 339.067,1195.2 339.076,1195 339.085,1194.81 339.094,1194.61 339.103,1194.41 339.113,1194.21 339.122,1194.01 339.131,1193.81 339.14,1193.61 339.149,1193.41 339.159,1193.22 339.168,1193.02 339.177,1192.82 339.186,1192.62 339.195,1192.42 339.205,1192.23 339.214,1192.03 339.223,1191.83 339.232,1191.63 339.241,1191.44 339.25,1191.24 339.26,1191.04 339.269,1190.84 339.278,1190.65 339.287,1190.45 339.296,1190.25 339.306,1190.05 339.315,1189.86 339.324,1189.66 339.333,1189.46 339.342,1189.27 339.352,1189.07 339.361,1188.88 339.37,1188.68 339.379,1188.48 339.388,1188.29 339.398,1188.09 339.407,1187.89 339.416,1187.7 339.425,1187.5 339.434,1187.31 339.443,1187.11 339.453,1186.92 339.462,1186.72 339.471,1186.52 339.48,1186.33 339.489,1186.13 339.499,1185.94 339.508,1185.74 339.517,1185.55 339.526,1185.35 339.535,1185.16 339.545,1184.96 339.554,1184.77 339.563,1184.57 339.572,1184.38 339.581,1184.19 339.59,1183.99 339.6,1183.8 339.609,1183.6 339.618,1183.41 339.627,1183.21 339.636,1183.02 339.646,1182.83 339.655,1182.63 339.664,1182.44 339.673,1182.25 339.682,1182.05 339.692,1181.86 339.701,1181.67 339.71,1181.47 339.719,1181.28 339.728,1181.09 339.738,1180.89 339.747,1180.7 339.756,1180.51 339.765,1180.31 339.774,1180.12 339.783,1179.93 339.793,1179.74 339.802,1179.54 339.811,1179.35 339.82,1179.16 339.829,1178.97 339.839,1178.77 339.848,1178.58 339.857,1178.39 339.866,1178.2 339.875,1178.01 339.885,1177.82 339.894,1177.62 339.903,1177.43 339.912,1177.24 339.921,1177.05 339.93,1176.86 339.94,1176.67 339.949,1176.48 339.958,1176.28 339.967,1176.09 339.976,1175.9 339.986,1175.71 339.995,1175.52 340.004,1175.33 340.013,1175.14 340.022,1174.95 340.032,1174.76 340.041,1174.57 340.05,1174.38 340.059,1174.19 340.068,1174 340.078,1173.81 340.087,1173.62 340.096,1173.43 340.105,1173.24 340.114,1173.05 340.123,1172.86 340.133,1172.67 340.142,1172.48 340.151,1172.29 340.16,1172.1 340.169,1171.91 340.179,1171.72 340.188,1171.54 340.197,1171.35 340.206,1171.16 340.215,1170.97 340.225,1170.78 340.234,1170.59 340.243,1170.4 340.252,1170.21 340.261,1170.03 340.27,1169.84 340.28,1169.65 340.289,1169.46 340.298,1169.27 340.307,1169.09 340.316,1168.9 340.326,1168.71 340.335,1168.52 340.344,1168.33 340.353,1168.15 340.362,1167.96 340.372,1167.77 340.381,1167.58 340.39,1167.4 340.399,1167.21 340.408,1167.02 340.418,1166.84 340.427,1166.65 340.436,1166.46 340.445,1166.28 340.454,1166.09 340.463,1165.9 340.473,1165.72 340.482,1165.53 340.491,1165.34 340.5,1165.16 340.509,1164.97 340.519,1164.79 340.528,1164.6 340.537,1164.41 340.546,1164.23 340.555,1164.04 340.565,1163.86 340.574,1163.67 340.583,1163.48 340.592,1163.3 340.601,1163.11 340.61,1162.93 340.62,1162.74 340.629,1162.56 340.638,1162.37 340.647,1162.19 340.656,1162 340.666,1161.82 340.675,1161.63 340.684,1161.45 340.693,1161.27 340.702,1161.08 340.712,1160.9 340.721,1160.71 340.73,1160.53 340.739,1160.34 340.748,1160.16 340.758,1159.98 340.767,1159.79 340.776,1159.61 340.785,1159.42 340.794,1159.24 340.803,1159.06 340.813,1158.87 340.822,1158.69 340.831,1158.51 340.84,1158.32 340.849,1158.14 340.859,1157.96 340.868,1157.77 340.877,1157.59 340.886,1157.41 340.895,1157.23 340.905,1157.04 340.914,1156.86 340.923,1156.68 340.932,1156.5 340.941,1156.31 340.95,1156.13 340.96,1155.95 340.969,1155.77 340.978,1155.58 340.987,1155.4 340.996,1155.22 341.006,1155.04 341.015,1154.86 341.024,1154.67 341.033,1154.49 341.042,1154.31 341.052,1154.13 341.061,1153.95 341.07,1153.77 341.079,1153.59 341.088,1153.41 341.098,1153.22 341.107,1153.04 341.116,1152.86 341.125,1152.68 341.134,1152.5 341.143,1152.32 341.153,1152.14 341.162,1151.96 341.171,1151.78 341.18,1151.6 341.189,1151.42 341.199,1151.24 341.208,1151.06 341.217,1150.88 341.226,1150.7 341.235,1150.52 341.245,1150.34 341.254,1150.16 341.263,1149.98 341.272,1149.8 341.281,1149.62 341.29,1149.44 341.3,1149.26 341.309,1149.08 341.318,1148.9 341.327,1148.72 341.336,1148.55 341.346,1148.37 341.355,1148.19 341.364,1148.01 341.373,1147.83 341.382,1147.65 341.392,1147.47 341.401,1147.3 341.41,1147.12 341.419,1146.94 341.428,1146.76 341.438,1146.58 341.447,1146.4 341.456,1146.23 341.465,1146.05 341.474,1145.87 341.483,1145.69 341.493,1145.52 341.502,1145.34 341.511,1145.16 341.52,1144.98 341.529,1144.81 341.539,1144.63 341.548,1144.45 341.557,1144.27 341.566,1144.1 341.575,1143.92 341.585,1143.74 341.594,1143.57 341.603,1143.39 341.612,1143.21 341.621,1143.04 341.631,1142.86 341.64,1142.68 341.649,1142.51 341.658,1142.33 341.667,1142.15 341.676,1141.98 341.686,1141.8 341.695,1141.63 341.704,1141.45 341.713,1141.28 341.722,1141.1 341.732,1140.92 341.741,1140.75 341.75,1140.57 341.759,1140.4 341.768,1140.22 341.778,1140.05 341.787,1139.87 341.796,1139.7 341.805,1139.52 341.814,1139.35 341.823,1139.17 341.833,1139 341.842,1138.82 341.851,1138.65 341.86,1138.47 341.869,1138.3 341.879,1138.13 341.888,1137.95 341.897,1137.78 341.906,1137.6 341.915,1137.43 341.925,1137.25 341.934,1137.08 341.943,1136.91 341.952,1136.73 341.961,1136.56 341.971,1136.39 341.98,1136.21 341.989,1136.04 341.998,1135.87 342.007,1135.69 342.016,1135.52 342.026,1135.35 342.035,1135.17 342.044,1135 342.053,1134.83 342.062,1134.65 342.072,1134.48 342.081,1134.31 342.09,1134.14 342.099,1133.96 342.108,1133.79 342.118,1133.62 342.127,1133.45 342.136,1133.27 342.145,1133.1 342.154,1132.93 342.163,1132.76 342.173,1132.59 342.182,1132.41 342.191,1132.24 342.2,1132.07 342.209,1131.9 342.219,1131.73 342.228,1131.56 342.237,1131.39 342.246,1131.21 342.255,1131.04 342.265,1130.87 342.274,1130.7 342.283,1130.53 342.292,1130.36 342.301,1130.19 342.311,1130.02 342.32,1129.85 342.329,1129.68 342.338,1129.51 342.347,1129.33 342.356,1129.16 342.366,1128.99 342.375,1128.82 342.384,1128.65 342.393,1128.48 342.402,1128.31 342.412,1128.14 342.421,1127.97 342.43,1127.8 342.439,1127.63 342.448,1127.47 342.458,1127.3 342.467,1127.13 342.476,1126.96 342.485,1126.79 342.494,1126.62 342.503,1126.45 342.513,1126.28 342.522,1126.11 342.531,1125.94 342.54,1125.77 342.549,1125.6 342.559,1125.44 342.568,1125.27 342.577,1125.1 342.586,1124.93 342.595,1124.76 342.605,1124.59 342.614,1124.43 342.623,1124.26 342.632,1124.09 342.641,1123.92 342.651,1123.75 342.66,1123.59 342.669,1123.42 342.678,1123.25 342.687,1123.08 342.696,1122.91 342.706,1122.75 342.715,1122.58 342.724,1122.41 342.733,1122.25 342.742,1122.08 342.752,1121.91 342.761,1121.74 342.77,1121.58 342.779,1121.41 342.788,1121.24 342.798,1121.08 342.807,1120.91 342.816,1120.74 342.825,1120.58 342.834,1120.41 342.843,1120.24 342.853,1120.08 342.862,1119.91 342.871,1119.75 342.88,1119.58 342.889,1119.41 342.899,1119.25 342.908,1119.08 342.917,1118.92 342.926,1118.75 342.935,1118.58 342.945,1118.42 342.954,1118.25 342.963,1118.09 342.972,1117.92 342.981,1117.76 342.991,1117.59 343,1117.43 343.009,1117.26 343.018,1117.1 343.027,1116.93 343.036,1116.77 343.046,1116.6 343.055,1116.44 343.064,1116.27 343.073,1116.11 343.082,1115.95 343.092,1115.78 343.101,1115.62 343.11,1115.45 343.119,1115.29 343.128,1115.12 343.138,1114.96 343.147,1114.8 343.156,1114.63 343.165,1114.47 343.174,1114.31 343.183,1114.14 343.193,1113.98 343.202,1113.81 343.211,1113.65 343.22,1113.49 343.229,1113.32 343.239,1113.16 343.248,1113 343.257,1112.84 343.266,1112.67 343.275,1112.51 343.285,1112.35 343.294,1112.18 343.303,1112.02 343.312,1111.86 343.321,1111.7 343.331,1111.53 343.34,1111.37 343.349,1111.21 343.358,1111.05 343.367,1110.89 343.376,1110.72 343.386,1110.56 343.395,1110.4 343.404,1110.24 343.413,1110.08 343.422,1109.91 343.432,1109.75 343.441,1109.59 343.45,1109.43 343.459,1109.27 343.468,1109.11 343.478,1108.95 343.487,1108.78 343.496,1108.62 343.505,1108.46 343.514,1108.3 343.523,1108.14 343.533,1107.98 343.542,1107.82 343.551,1107.66 343.56,1107.5 343.569,1107.34 343.579,1107.18 343.588,1107.02 343.597,1106.86 343.606,1106.7 343.615,1106.54 343.625,1106.38 343.634,1106.22 343.643,1106.06 343.652,1105.9 343.661,1105.74 343.671,1105.58 343.68,1105.42 343.689,1105.26 343.698,1105.1 343.707,1104.94 343.716,1104.78 343.726,1104.62 343.735,1104.46 343.744,1104.3 343.753,1104.14 343.762,1103.98 343.772,1103.83 343.781,1103.67 343.79,1103.51 343.799,1103.35 343.808,1103.19 343.818,1103.03 343.827,1102.87 343.836,1102.72 343.845,1102.56 343.854,1102.4 343.864,1102.24 343.873,1102.08 343.882,1101.93 343.891,1101.77 343.9,1101.61 343.909,1101.45 343.919,1101.29 343.928,1101.14 343.937,1100.98 343.946,1100.82 343.955,1100.66 343.965,1100.51 343.974,1100.35 343.983,1100.19 343.992,1100.03 344.001,1099.88 344.011,1099.72 344.02,1099.56 344.029,1099.41 344.038,1099.25 344.047,1099.09 344.056,1098.94 344.066,1098.78 344.075,1098.62 344.084,1098.47 344.093,1098.31 344.102,1098.15 344.112,1098 344.121,1097.84 344.13,1097.69 344.139,1097.53 344.148,1097.37 344.158,1097.22 344.167,1097.06 344.176,1096.91 344.185,1096.75 344.194,1096.6 344.204,1096.44 344.213,1096.29 344.222,1096.13 344.231,1095.97 344.24,1095.82 344.249,1095.66 344.259,1095.51 344.268,1095.35 344.277,1095.2 344.286,1095.04 344.295,1094.89 344.305,1094.74 344.314,1094.58 344.323,1094.43 344.332,1094.27 344.341,1094.12 344.351,1093.96 344.36,1093.81 344.369,1093.65 344.378,1093.5 344.387,1093.35 344.396,1093.19 344.406,1093.04 344.415,1092.88 344.424,1092.73 344.433,1092.58 344.442,1092.42 344.452,1092.27 344.461,1092.12 344.47,1091.96 344.479,1091.81 344.488,1091.66 344.498,1091.5 344.507,1091.35 344.516,1091.2 344.525,1091.04 344.534,1090.89 344.544,1090.74 344.553,1090.59 344.562,1090.43 344.571,1090.28 344.58,1090.13 344.589,1089.98 344.599,1089.82 344.608,1089.67 344.617,1089.52 344.626,1089.37 344.635,1089.21 344.645,1089.06 344.654,1088.91 344.663,1088.76 344.672,1088.61 344.681,1088.45 344.691,1088.3 344.7,1088.15 344.709,1088 344.718,1087.85 344.727,1087.7 344.736,1087.55 344.746,1087.39 344.755,1087.24 344.764,1087.09 344.773,1086.94 344.782,1086.79 344.792,1086.64 344.801,1086.49 344.81,1086.34 344.819,1086.19 344.828,1086.04 344.838,1085.89 344.847,1085.74 344.856,1085.58 344.865,1085.43 344.874,1085.28 344.884,1085.13 344.893,1084.98 344.902,1084.83 344.911,1084.68 344.92,1084.53 344.929,1084.38 344.939,1084.23 344.948,1084.08 344.957,1083.93 344.966,1083.79 344.975,1083.64 344.985,1083.49 344.994,1083.34 345.003,1083.19 345.012,1083.04 345.021,1082.89 345.031,1082.74 345.04,1082.59 345.049,1082.44 345.058,1082.29 345.067,1082.14 345.076,1082 345.086,1081.85 345.095,1081.7 345.104,1081.55 345.113,1081.4 345.122,1081.25 345.132,1081.1 345.141,1080.96 345.15,1080.81 345.159,1080.66 345.168,1080.51 345.178,1080.36 345.187,1080.22 345.196,1080.07 345.205,1079.92 345.214,1079.77 345.224,1079.63 345.233,1079.48 345.242,1079.33 345.251,1079.18 345.26,1079.04 345.269,1078.89 345.279,1078.74 345.288,1078.59 345.297,1078.45 345.306,1078.3 345.315,1078.15 345.325,1078.01 345.334,1077.86 345.343,1077.71 345.352,1077.57 345.361,1077.42 345.371,1077.27 345.38,1077.13 345.389,1076.98 345.398,1076.83 345.407,1076.69 345.416,1076.54 345.426,1076.4 345.435,1076.25 345.444,1076.1 345.453,1075.96 345.462,1075.81 345.472,1075.67 345.481,1075.52 345.49,1075.37 345.499,1075.23 345.508,1075.08 345.518,1074.94 345.527,1074.79 345.536,1074.65 345.545,1074.5 345.554,1074.36 345.564,1074.21 345.573,1074.07 345.582,1073.92 345.591,1073.78 345.6,1073.63 345.609,1073.49 345.619,1073.34 345.628,1073.2 345.637,1073.05 345.646,1072.91 345.655,1072.77 345.665,1072.62 345.674,1072.48 345.683,1072.33 345.692,1072.19 345.701,1072.04 345.711,1071.9 345.72,1071.76 345.729,1071.61 345.738,1071.47 345.747,1071.33 345.756,1071.18 345.766,1071.04 345.775,1070.89 345.784,1070.75 345.793,1070.61 345.802,1070.46 345.812,1070.32 345.821,1070.18 345.83,1070.04 345.839,1069.89 345.848,1069.75 345.858,1069.61 345.867,1069.46 345.876,1069.32 345.885,1069.18 345.894,1069.04 345.904,1068.89 345.913,1068.75 345.922,1068.61 345.931,1068.47 345.94,1068.32 345.949,1068.18 345.959,1068.04 345.968,1067.9 345.977,1067.76 345.986,1067.61 345.995,1067.47 346.005,1067.33 346.014,1067.19 346.023,1067.05 346.032,1066.9 346.041,1066.76 346.051,1066.62 346.06,1066.48 346.069,1066.34 346.078,1066.2 346.087,1066.06 346.096,1065.92 346.106,1065.77 346.115,1065.63 346.124,1065.49 346.133,1065.35 346.142,1065.21 346.152,1065.07 346.161,1064.93 346.17,1064.79 346.179,1064.65 346.188,1064.51 346.198,1064.37 346.207,1064.23 346.216,1064.09 346.225,1063.95 346.234,1063.81 346.244,1063.67 346.253,1063.53 346.262,1063.39 346.271,1063.25 346.28,1063.11 346.289,1062.97 346.299,1062.83 346.308,1062.69 346.317,1062.55 346.326,1062.41 346.335,1062.27 346.345,1062.13 346.354,1061.99 346.363,1061.85 346.372,1061.71 346.381,1061.57 346.391,1061.44 346.4,1061.3 346.409,1061.16 346.418,1061.02 346.427,1060.88 346.437,1060.74 346.446,1060.6 346.455,1060.46 346.464,1060.33 346.473,1060.19 346.482,1060.05 346.492,1059.91 346.501,1059.77 346.51,1059.64 346.519,1059.5 346.528,1059.36 346.538,1059.22 346.547,1059.08 346.556,1058.95 346.565,1058.81 346.574,1058.67 346.584,1058.53 346.593,1058.4 346.602,1058.26 346.611,1058.12 346.62,1057.98 346.629,1057.85 346.639,1057.71 346.648,1057.57 346.657,1057.44 346.666,1057.3 346.675,1057.16 346.685,1057.02 346.694,1056.89 346.703,1056.75 346.712,1056.61 346.721,1056.48 346.731,1056.34 346.74,1056.2 346.749,1056.07 346.758,1055.93 346.767,1055.8 346.777,1055.66 346.786,1055.52 346.795,1055.39 346.804,1055.25 346.813,1055.12 346.822,1054.98 346.832,1054.84 346.841,1054.71 346.85,1054.57 346.859,1054.44 346.868,1054.3 346.878,1054.17 346.887,1054.03 346.896,1053.9 346.905,1053.76 346.914,1053.63 346.924,1053.49 346.933,1053.36 346.942,1053.22 346.951,1053.09 346.96,1052.95 346.969,1052.82 346.979,1052.68 346.988,1052.55 346.997,1052.41 347.006,1052.28 347.015,1052.14 347.025,1052.01 347.034,1051.87 347.043,1051.74 347.052,1051.61 347.061,1051.47 347.071,1051.34 347.08,1051.2 347.089,1051.07 347.098,1050.94 347.107,1050.8 347.117,1050.67 347.126,1050.53 347.135,1050.4 347.144,1050.27 347.153,1050.13 347.162,1050 347.172,1049.87 347.181,1049.73 347.19,1049.6 347.199,1049.47 347.208,1049.33 347.218,1049.2 347.227,1049.07 347.236,1048.94 347.245,1048.8 347.254,1048.67 347.264,1048.54 347.273,1048.4 347.282,1048.27 347.291,1048.14 347.3,1048.01 347.309,1047.87 347.319,1047.74 347.328,1047.61 347.337,1047.48 347.346,1047.35 347.355,1047.21 347.365,1047.08 347.374,1046.95 347.383,1046.82 347.392,1046.69 347.401,1046.55 347.411,1046.42 347.42,1046.29 347.429,1046.16 347.438,1046.03 347.447,1045.9 347.457,1045.77 347.466,1045.63 347.475,1045.5 347.484,1045.37 347.493,1045.24 347.502,1045.11 347.512,1044.98 347.521,1044.85 347.53,1044.72 347.539,1044.59 347.548,1044.46 347.558,1044.33 347.567,1044.19 347.576,1044.06 347.585,1043.93 347.594,1043.8 347.604,1043.67 347.613,1043.54 347.622,1043.41 347.631,1043.28 347.64,1043.15 347.649,1043.02 347.659,1042.89 347.668,1042.76 347.677,1042.63 347.686,1042.5 347.695,1042.37 347.705,1042.24 347.714,1042.11 347.723,1041.98 347.732,1041.86 347.741,1041.73 347.751,1041.6 347.76,1041.47 347.769,1041.34 347.778,1041.21 347.787,1041.08 347.797,1040.95 347.806,1040.82 347.815,1040.69 347.824,1040.57 347.833,1040.44 347.842,1040.31 347.852,1040.18 347.861,1040.05 347.87,1039.92 347.879,1039.79 347.888,1039.67 347.898,1039.54 347.907,1039.41 347.916,1039.28 347.925,1039.15 347.934,1039.02 347.944,1038.9 347.953,1038.77 347.962,1038.64 347.971,1038.51 347.98,1038.39 347.989,1038.26 347.999,1038.13 348.008,1038 348.017,1037.88 348.026,1037.75 348.035,1037.62 348.045,1037.49 348.054,1037.37 348.063,1037.24 348.072,1037.11 348.081,1036.99 348.091,1036.86 348.1,1036.73 348.109,1036.6 348.118,1036.48 348.127,1036.35 348.137,1036.22 348.146,1036.1 348.155,1035.97 348.164,1035.85 348.173,1035.72 348.182,1035.59 348.192,1035.47 348.201,1035.34 348.21,1035.21 348.219,1035.09 348.228,1034.96 348.238,1034.84 348.247,1034.71 348.256,1034.58 348.265,1034.46 348.274,1034.33 348.284,1034.21 348.293,1034.08 348.302,1033.96 348.311,1033.83 348.32,1033.71 348.329,1033.58 348.339,1033.46 348.348,1033.33 348.357,1033.21 348.366,1033.08 348.375,1032.96 348.385,1032.83 348.394,1032.71 348.403,1032.58 348.412,1032.46 348.421,1032.33 348.431,1032.21 348.44,1032.08 348.449,1031.96 348.458,1031.83 348.467,1031.71 348.477,1031.58 348.486,1031.46 348.495,1031.34 348.504,1031.21 348.513,1031.09 348.522,1030.96 348.532,1030.84 348.541,1030.72 348.55,1030.59 348.559,1030.47 348.568,1030.35 348.578,1030.22 348.587,1030.1 348.596,1029.97 348.605,1029.85 348.614,1029.73 348.624,1029.6 348.633,1029.48 348.642,1029.36 348.651,1029.23 348.66,1029.11 348.669,1028.99 348.679,1028.87 348.688,1028.74 348.697,1028.62 348.706,1028.5 348.715,1028.37 348.725,1028.25 348.734,1028.13 348.743,1028.01 348.752,1027.88 348.761,1027.76 348.771,1027.64 348.78,1027.52 348.789,1027.4 348.798,1027.27 348.807,1027.15 348.817,1027.03 348.826,1026.91 348.835,1026.79 348.844,1026.66 348.853,1026.54 348.862,1026.42 348.872,1026.3 348.881,1026.18 348.89,1026.06 348.899,1025.93 348.908,1025.81 348.918,1025.69 348.927,1025.57 348.936,1025.45 348.945,1025.33 348.954,1025.21 348.964,1025.09 348.973,1024.97 348.982,1024.84 348.991,1024.72 349,1024.6 349.01,1024.48 349.019,1024.36 349.028,1024.24 349.037,1024.12 349.046,1024 349.055,1023.88 349.065,1023.76 349.074,1023.64 349.083,1023.52 349.092,1023.4 349.101,1023.28 349.111,1023.16 349.12,1023.04 349.129,1022.92 349.138,1022.8 349.147,1022.68 349.157,1022.56 349.166,1022.44 349.175,1022.32 349.184,1022.2 349.193,1022.08 349.202,1021.96 349.212,1021.84 349.221,1021.72 349.23,1021.6 349.239,1021.48 349.248,1021.37 349.258,1021.25 349.267,1021.13 349.276,1021.01 349.285,1020.89 349.294,1020.77 349.304,1020.65 349.313,1020.53 349.322,1020.41 349.331,1020.3 349.34,1020.18 349.35,1020.06 349.359,1019.94 349.368,1019.82 349.377,1019.7 349.386,1019.59 349.395,1019.47 349.405,1019.35 349.414,1019.23 349.423,1019.11 349.432,1019 349.441,1018.88 349.451,1018.76 349.46,1018.64 349.469,1018.52 349.478,1018.41 349.487,1018.29 349.497,1018.17 349.506,1018.05 349.515,1017.94 349.524,1017.82 349.533,1017.7 349.542,1017.59 349.552,1017.47 349.561,1017.35 349.57,1017.23 349.579,1017.12 349.588,1017 349.598,1016.88 349.607,1016.77 349.616,1016.65 349.625,1016.53 349.634,1016.42 349.644,1016.3 349.653,1016.18 349.662,1016.07 349.671,1015.95 349.68,1015.83 349.69,1015.72 349.699,1015.6 349.708,1015.49 349.717,1015.37 349.726,1015.25 349.735,1015.14 349.745,1015.02 349.754,1014.91 349.763,1014.79 349.772,1014.68 349.781,1014.56 349.791,1014.44 349.8,1014.33 349.809,1014.21 349.818,1014.1 349.827,1013.98 349.837,1013.87 349.846,1013.75 349.855,1013.64 349.864,1013.52 349.873,1013.41 349.882,1013.29 349.892,1013.18 349.901,1013.06 349.91,1012.95 349.919,1012.83 349.928,1012.72 349.938,1012.6 349.947,1012.49 349.956,1012.37 349.965,1012.26 349.974,1012.15 349.984,1012.03 349.993,1011.92 350.002,1011.8 350.011,1011.69 350.02,1011.57 350.03,1011.46 350.039,1011.35 350.048,1011.23 350.057,1011.12 350.066,1011 350.075,1010.89 350.085,1010.78 350.094,1010.66 350.103,1010.55 350.112,1010.44 350.121,1010.32 350.131,1010.21 350.14,1010.1 350.149,1009.98 350.158,1009.87 350.167,1009.76 350.177,1009.64 350.186,1009.53 350.195,1009.42 350.204,1009.31 350.213,1009.19 350.222,1009.08 350.232,1008.97 350.241,1008.85 350.25,1008.74 350.259,1008.63 350.268,1008.52 350.278,1008.4 350.287,1008.29 350.296,1008.18 350.305,1008.07 350.314,1007.95 350.324,1007.84 350.333,1007.73 350.342,1007.62 350.351,1007.51 350.36,1007.39 350.37,1007.28 350.379,1007.17 350.388,1007.06 350.397,1006.95 350.406,1006.84 350.415,1006.72 350.425,1006.61 350.434,1006.5 350.443,1006.39 350.452,1006.28 350.461,1006.17 350.471,1006.06 350.48,1005.95 350.489,1005.83 350.498,1005.72 350.507,1005.61 350.517,1005.5 350.526,1005.39 350.535,1005.28 350.544,1005.17 350.553,1005.06 350.562,1004.95 350.572,1004.84 350.581,1004.73 350.59,1004.62 350.599,1004.51 350.608,1004.4 350.618,1004.29 350.627,1004.18 350.636,1004.06 350.645,1003.95 350.654,1003.84 350.664,1003.73 350.673,1003.62 350.682,1003.51 350.691,1003.41 350.7,1003.3 350.71,1003.19 350.719,1003.08 350.728,1002.97 350.737,1002.86 350.746,1002.75 350.755,1002.64 350.765,1002.53 350.774,1002.42 350.783,1002.31 350.792,1002.2 350.801,1002.09 350.811,1001.98 350.82,1001.87 350.829,1001.76 350.838,1001.66 350.847,1001.55 350.857,1001.44 350.866,1001.33 350.875,1001.22 350.884,1001.11 350.893,1001 350.902,1000.9 350.912,1000.79 350.921,1000.68 350.93,1000.57 350.939,1000.46 350.948,1000.35 350.958,1000.25 350.967,1000.14 350.976,1000.03 350.985,999.922 350.994,999.814 351.004,999.706 351.013,999.598 351.022,999.49 351.031,999.383 351.04,999.275 351.05,999.167 351.059,999.06 351.068,998.952 351.077,998.845 351.086,998.738 351.095,998.63 351.105,998.523 351.114,998.416 351.123,998.309 351.132,998.202 351.141,998.095 351.151,997.988 351.16,997.881 351.169,997.774 351.178,997.667 351.187,997.561 351.197,997.454 351.206,997.347 351.215,997.241 351.224,997.134 351.233,997.028 351.243,996.921 351.252,996.815 351.261,996.709 351.27,996.603 351.279,996.497 351.288,996.39 351.298,996.284 351.307,996.178 351.316,996.072 351.325,995.967 351.334,995.861 351.344,995.755 351.353,995.649 351.362,995.544 351.371,995.438 351.38,995.333 351.39,995.227 351.399,995.122 351.408,995.016 351.417,994.911 351.426,994.806 351.435,994.701 351.445,994.595 351.454,994.49 351.463,994.385 351.472,994.28 351.481,994.175 351.491,994.071 351.5,993.966 351.509,993.861 351.518,993.756 351.527,993.652 351.537,993.547 351.546,993.443 351.555,993.338 351.564,993.234 351.573,993.129 351.583,993.025 351.592,992.921 351.601,992.817 351.61,992.713 351.619,992.609 351.628,992.505 351.638,992.401 351.647,992.297 351.656,992.193 351.665,992.089 351.674,991.985 351.684,991.882 351.693,991.778 351.702,991.674 351.711,991.571 351.72,991.467 351.73,991.364 351.739,991.261 351.748,991.157 351.757,991.054 351.766,990.951 351.775,990.848 351.785,990.745 351.794,990.642 351.803,990.539 351.812,990.436 351.821,990.333 351.831,990.23 351.84,990.128 351.849,990.025 351.858,989.922 351.867,989.82 351.877,989.717 351.886,989.615 351.895,989.512 351.904,989.41 351.913,989.308 351.923,989.206 351.932,989.103 351.941,989.001 351.95,988.899 351.959,988.797 351.968,988.695 351.978,988.593 351.987,988.491 351.996,988.39 352.005,988.288 352.014,988.186 352.024,988.085 352.033,987.983 352.042,987.882 352.051,987.78 352.06,987.679 352.07,987.577 352.079,987.476 352.088,987.375 352.097,987.274 352.106,987.172 352.115,987.071 352.125,986.97 352.134,986.869 352.143,986.769 352.152,986.668 352.161,986.567 352.171,986.466 352.18,986.365 352.189,986.265 352.198,986.164 352.207,986.064 352.217,985.963 352.226,985.863 352.235,985.762 352.244,985.662 352.253,985.562 352.263,985.462 352.272,985.362 352.281,985.261 352.29,985.161 352.299,985.061 352.308,984.962 352.318,984.862 352.327,984.762 352.336,984.662 352.345,984.562 352.354,984.463 352.364,984.363 352.373,984.264 352.382,984.164 352.391,984.065 352.4,983.965 352.41,983.866 352.419,983.767 352.428,983.667 352.437,983.568 352.446,983.469 352.455,983.37 352.465,983.271 352.474,983.172 352.483,983.073 352.492,982.974 352.501,982.876 352.511,982.777 352.52,982.678 352.529,982.58 352.538,982.481 352.547,982.383 352.557,982.284 352.566,982.186 352.575,982.087 352.584,981.989 352.593,981.891 352.603,981.793 352.612,981.695 352.621,981.596 352.63,981.498 352.639,981.4 352.648,981.303 352.658,981.205 352.667,981.107 352.676,981.009 352.685,980.911 352.694,980.814 352.704,980.716 352.713,980.619 352.722,980.521 352.731,980.424 352.74,980.326 352.75,980.229 352.759,980.132 352.768,980.035 352.777,979.937 352.786,979.84 352.795,979.743 352.805,979.646 352.814,979.549 352.823,979.452 352.832,979.356 352.841,979.259 352.851,979.162 352.86,979.065 352.869,978.969 352.878,978.872 352.887,978.776 352.897,978.679 352.906,978.583 352.915,978.486 352.924,978.39 352.933,978.294 352.943,978.198 352.952,978.101 352.961,978.005 352.97,977.909 352.979,977.813 352.988,977.717 352.998,977.622 353.007,977.526 353.016,977.43 353.025,977.334 353.034,977.239 353.044,977.143 353.053,977.047 353.062,976.952 353.071,976.856 353.08,976.761 353.09,976.666 353.099,976.57 353.108,976.475 353.117,976.38 353.126,976.285 353.135,976.19 353.145,976.095 353.154,976 353.163,975.905 353.172,975.81 353.181,975.715 353.191,975.62 353.2,975.526 353.209,975.431 353.218,975.336 353.227,975.242 353.237,975.147 353.246,975.053 353.255,974.958 353.264,974.864 353.273,974.77 353.283,974.676 353.292,974.581 353.301,974.487 353.31,974.393 353.319,974.299 353.328,974.205 353.338,974.111 353.347,974.017 353.356,973.924 353.365,973.83 353.374,973.736 353.384,973.642 353.393,973.549 353.402,973.455 353.411,973.362 353.42,973.268 353.43,973.175 353.439,973.082 353.448,972.988 353.457,972.895 353.466,972.802 353.475,972.709 353.485,972.616 353.494,972.523 353.503,972.43 353.512,972.337 353.521,972.244 353.531,972.151 353.54,972.058 353.549,971.966 353.558,971.873 353.567,971.78 353.577,971.688 353.586,971.595 353.595,971.503 353.604,971.41 353.613,971.318 353.623,971.226 353.632,971.133 353.641,971.041 353.65,970.949 353.659,970.857 353.668,970.765 353.678,970.673 353.687,970.581 353.696,970.489 353.705,970.397 353.714,970.306 353.724,970.214 353.733,970.122 353.742,970.031 353.751,969.939 353.76,969.847 353.77,969.756 353.779,969.665 353.788,969.573 353.797,969.482 353.806,969.391 353.816,969.299 353.825,969.208 353.834,969.117 353.843,969.026 353.852,968.935 353.861,968.844 353.871,968.753 353.88,968.662 353.889,968.572 353.898,968.481 353.907,968.39 353.917,968.3 353.926,968.209 353.935,968.118 353.944,968.028 353.953,967.938 353.963,967.847 353.972,967.757 353.981,967.667 353.99,967.576 353.999,967.486 354.008,967.396 354.018,967.306 354.027,967.216 354.036,967.126 354.045,967.036 354.054,966.946 354.064,966.856 354.073,966.767 354.082,966.677 354.091,966.587 354.1,966.498 354.11,966.408 354.119,966.319 354.128,966.229 354.137,966.14 354.146,966.05 354.156,965.961 354.165,965.872 354.174,965.783 354.183,965.693 354.192,965.604 354.201,965.515 354.211,965.426 354.22,965.337 354.229,965.248 354.238,965.16 354.247,965.071 354.257,964.982 354.266,964.893 354.275,964.805 354.284,964.716 354.293,964.628 354.303,964.539 354.312,964.451 354.321,964.362 354.33,964.274 354.339,964.186 354.348,964.097 354.358,964.009 354.367,963.921 354.376,963.833 354.385,963.745 354.394,963.657 354.404,963.569 354.413,963.481 354.422,963.393 354.431,963.306 354.44,963.218 354.45,963.13 354.459,963.042 354.468,962.955 354.477,962.867 354.486,962.78 354.496,962.692 354.505,962.605 354.514,962.518 354.523,962.43 354.532,962.343 354.541,962.256 354.551,962.169 354.56,962.082 354.569,961.995 354.578,961.908 354.587,961.821 354.597,961.734 354.606,961.647 354.615,961.56 354.624,961.474 354.633,961.387 354.643,961.3 354.652,961.214 354.661,961.127 354.67,961.041 354.679,960.954 354.688,960.868 354.698,960.782 354.707,960.696 354.716,960.609 354.725,960.523 354.734,960.437 354.744,960.351 354.753,960.265 354.762,960.179 354.771,960.093 354.78,960.007 354.79,959.921 354.799,959.836 354.808,959.75 354.817,959.664 354.826,959.579 354.836,959.493 354.845,959.407 354.854,959.322 354.863,959.237 354.872,959.151 354.881,959.066 354.891,958.981 354.9,958.895 354.909,958.81 354.918,958.725 354.927,958.64 354.937,958.555 354.946,958.47 354.955,958.385 354.964,958.3 354.973,958.215 354.983,958.131 354.992,958.046 355.001,957.961 355.01,957.877 355.019,957.792 355.028,957.707 355.038,957.623 355.047,957.539 355.056,957.454 355.065,957.37 355.074,957.286 355.084,957.201 355.093,957.117 355.102,957.033 355.111,956.949 355.12,956.865 355.13,956.781 355.139,956.697 355.148,956.613 355.157,956.529 355.166,956.446 355.176,956.362 355.185,956.278 355.194,956.194 355.203,956.111 355.212,956.027 355.221,955.944 355.231,955.86 355.24,955.777 355.249,955.694 355.258,955.61 355.267,955.527 355.277,955.444 355.286,955.361 355.295,955.278 355.304,955.195 355.313,955.112 355.323,955.029 355.332,954.946 355.341,954.863 355.35,954.78 355.359,954.697 355.368,954.615 355.378,954.532 355.387,954.449 355.396,954.367 355.405,954.284 355.414,954.202 355.424,954.119 355.433,954.037 355.442,953.955 355.451,953.872 355.46,953.79 355.47,953.708 355.479,953.626 355.488,953.544 355.497,953.462 355.506,953.38 355.516,953.298 355.525,953.216 355.534,953.134 355.543,953.052 355.552,952.971 355.561,952.889 355.571,952.807 355.58,952.726 355.589,952.644 355.598,952.563 355.607,952.481 355.617,952.4 355.626,952.319 355.635,952.237 355.644,952.156 355.653,952.075 355.663,951.994 355.672,951.913 355.681,951.832 355.69,951.751 355.699,951.67 355.708,951.589 355.718,951.508 355.727,951.427 355.736,951.346 355.745,951.265 355.754,951.185 355.764,951.104 355.773,951.024 355.782,950.943 355.791,950.863 355.8,950.782 355.81,950.702 355.819,950.621 355.828,950.541 355.837,950.461 355.846,950.381 355.856,950.301 355.865,950.221 355.874,950.14 355.883,950.06 355.892,949.981 355.901,949.901 355.911,949.821 355.92,949.741 355.929,949.661 355.938,949.582 355.947,949.502 355.957,949.422 355.966,949.343 355.975,949.263 355.984,949.184 355.993,949.104 356.003,949.025 356.012,948.946 356.021,948.866 356.03,948.787 356.039,948.708 356.048,948.629 356.058,948.55 356.067,948.471 356.076,948.392 356.085,948.313 356.094,948.234 356.104,948.155 356.113,948.076 356.122,947.997 356.131,947.919 356.14,947.84 356.15,947.761 356.159,947.683 356.168,947.604 356.177,947.526 356.186,947.447 356.196,947.369 356.205,947.291 356.214,947.212 356.223,947.134 356.232,947.056 356.241,946.978 356.251,946.9 356.26,946.822 356.269,946.744 356.278,946.666 356.287,946.588 356.297,946.51 356.306,946.432 356.315,946.354 356.324,946.277 356.333,946.199 356.343,946.122 356.352,946.044 356.361,945.966 356.37,945.889 356.379,945.812 356.389,945.734 356.398,945.657 356.407,945.579 356.416,945.502 356.425,945.425 356.434,945.348 356.444,945.271 356.453,945.194 356.462,945.117 356.471,945.04 356.48,944.963 356.49,944.886 356.499,944.809 356.508,944.732 356.517,944.656 356.526,944.579 356.536,944.502 356.545,944.426 356.554,944.349 356.563,944.273 356.572,944.196 356.581,944.12 356.591,944.044 356.6,943.967 356.609,943.891 356.618,943.815 356.627,943.739 356.637,943.663 356.646,943.586 356.655,943.51 356.664,943.434 356.673,943.359 356.683,943.283 356.692,943.207 356.701,943.131 356.71,943.055 356.719,942.98 356.729,942.904 356.738,942.828 356.747,942.753 356.756,942.677 356.765,942.602 356.774,942.526 356.784,942.451 356.793,942.376 356.802,942.3 356.811,942.225 356.82,942.15 356.83,942.075 356.839,942 356.848,941.925 356.857,941.85 356.866,941.775 356.876,941.7 356.885,941.625 356.894,941.55 356.903,941.475 356.912,941.401 356.921,941.326 356.931,941.251 356.94,941.177 356.949,941.102 356.958,941.028 356.967,940.953 356.977,940.879 356.986,940.804 356.995,940.73 357.004,940.656 357.013,940.582 357.023,940.508 357.032,940.433 357.041,940.359 357.05,940.285 357.059,940.211 357.069,940.137 357.078,940.063 357.087,939.99 357.096,939.916 357.105,939.842 357.114,939.768 357.124,939.695 357.133,939.621 357.142,939.547 357.151,939.474 357.16,939.4 357.17,939.327 357.179,939.254 357.188,939.18 357.197,939.107 357.206,939.034 357.216,938.961 357.225,938.887 357.234,938.814 357.243,938.741 357.252,938.668 357.261,938.595 357.271,938.522 357.28,938.449 357.289,938.376 357.298,938.304 357.307,938.231 357.317,938.158 357.326,938.086 357.335,938.013 357.344,937.94 357.353,937.868 357.363,937.795 357.372,937.723 357.381,937.651 357.39,937.578 357.399,937.506 357.409,937.434 357.418,937.361 357.427,937.289 357.436,937.217 357.445,937.145 357.454,937.073 357.464,937.001 357.473,936.929 357.482,936.857 357.491,936.785 357.5,936.714 357.51,936.642 357.519,936.57 357.528,936.498 357.537,936.427 357.546,936.355 357.556,936.284 357.565,936.212 357.574,936.141 357.583,936.069 357.592,935.998 357.601,935.927 357.611,935.855 357.62,935.784 357.629,935.713 357.638,935.642 357.647,935.571 357.657,935.5 357.666,935.429 357.675,935.358 357.684,935.287 357.693,935.216 357.703,935.145 357.712,935.075 357.721,935.004 357.73,934.933 357.739,934.863 357.749,934.792 357.758,934.721 357.767,934.651 357.776,934.58 357.785,934.51 357.794,934.44 357.804,934.369 357.813,934.299 357.822,934.229 357.831,934.159 357.84,934.089 357.85,934.018 357.859,933.948 357.868,933.878 357.877,933.808 357.886,933.738 357.896,933.669 357.905,933.599 357.914,933.529 357.923,933.459 357.932,933.39 357.941,933.32 357.951,933.25 357.96,933.181 357.969,933.111 357.978,933.042 357.987,932.972 357.997,932.903 358.006,932.834 358.015,932.764 358.024,932.695 358.033,932.626 358.043,932.557 358.052,932.488 358.061,932.418 358.07,932.349 358.079,932.28 358.089,932.211 358.098,932.143 358.107,932.074 358.116,932.005 358.125,931.936 358.134,931.867 358.144,931.799 358.153,931.73 358.162,931.662 358.171,931.593 358.18,931.524 358.19,931.456 358.199,931.388 358.208,931.319 358.217,931.251 358.226,931.183 358.236,931.114 358.245,931.046 358.254,930.978 358.263,930.91 358.272,930.842 358.281,930.774 358.291,930.706 358.3,930.638 358.309,930.57 358.318,930.502 358.327,930.434 358.337,930.367 358.346,930.299 358.355,930.231 358.364,930.164 358.373,930.096 358.383,930.029 358.392,929.961 358.401,929.894 358.41,929.826 358.419,929.759 358.429,929.691 358.438,929.624 358.447,929.557 358.456,929.49 358.465,929.423 358.474,929.356 358.484,929.288 358.493,929.221 358.502,929.154 358.511,929.088 358.52,929.021 358.53,928.954 358.539,928.887 358.548,928.82 358.557,928.754 358.566,928.687 358.576,928.62 358.585,928.554 358.594,928.487 358.603,928.421 358.612,928.354 358.621,928.288 358.631,928.221 358.64,928.155 358.649,928.089 358.658,928.023 358.667,927.956 358.677,927.89 358.686,927.824 358.695,927.758 358.704,927.692 358.713,927.626 358.723,927.56 358.732,927.494 358.741,927.428 358.75,927.363 358.759,927.297 358.769,927.231 358.778,927.166 358.787,927.1 358.796,927.034 358.805,926.969 358.814,926.903 358.824,926.838 358.833,926.772 358.842,926.707 358.851,926.642 358.86,926.576 358.87,926.511 358.879,926.446 358.888,926.381 358.897,926.316 358.906,926.251 358.916,926.186 358.925,926.121 358.934,926.056 358.943,925.991 358.952,925.926 358.962,925.861 358.971,925.796 358.98,925.732 358.989,925.667 358.998,925.602 359.007,925.538 359.017,925.473 359.026,925.409 359.035,925.344 359.044,925.28 359.053,925.215 359.063,925.151 359.072,925.087 359.081,925.022 359.09,924.958 359.099,924.894 359.109,924.83 359.118,924.766 359.127,924.702 359.136,924.638 359.145,924.574 359.154,924.51 359.164,924.446 359.173,924.382 359.182,924.318 359.191,924.255 359.2,924.191 359.21,924.127 359.219,924.064 359.228,924 359.237,923.936 359.246,923.873 359.256,923.809 359.265,923.746 359.274,923.683 359.283,923.619 359.292,923.556 359.302,923.493 359.311,923.43 359.32,923.366 359.329,923.303 359.338,923.24 359.347,923.177 359.357,923.114 359.366,923.051 359.375,922.988 359.384,922.925 359.393,922.863 359.403,922.8 359.412,922.737 359.421,922.674 359.43,922.612 359.439,922.549 359.449,922.487 359.458,922.424 359.467,922.362 359.476,922.299 359.485,922.237 359.494,922.174 359.504,922.112 359.513,922.05 359.522,921.988 359.531,921.925 359.54,921.863 359.55,921.801 359.559,921.739 359.568,921.677 359.577,921.615 359.586,921.553 359.596,921.491 359.605,921.429 359.614,921.367 359.623,921.306 359.632,921.244 359.642,921.182 359.651,921.121 359.66,921.059 359.669,920.997 359.678,920.936 359.687,920.874 359.697,920.813 359.706,920.752 359.715,920.69 359.724,920.629 359.733,920.568 359.743,920.506 359.752,920.445 359.761,920.384 359.77,920.323 359.779,920.262 359.789,920.201 359.798,920.14 359.807,920.079 359.816,920.018 359.825,919.957 359.834,919.896 359.844,919.836 359.853,919.775 359.862,919.714 359.871,919.653 359.88,919.593 359.89,919.532 359.899,919.472 359.908,919.411 359.917,919.351 359.926,919.29 359.936,919.23 359.945,919.17 359.954,919.109 359.963,919.049 359.972,918.989 359.982,918.929 359.991,918.869 360,918.809 360.009,918.748 360.018,918.688 360.027,918.629 360.037,918.569 360.046,918.509 360.055,918.449 360.064,918.389 360.073,918.329 360.083,918.27 360.092,918.21 360.101,918.15 360.11,918.091 360.119,918.031 360.129,917.972 360.138,917.912 360.147,917.853 360.156,917.793 360.165,917.734 360.174,917.675 360.184,917.616 360.193,917.556 360.202,917.497 360.211,917.438 360.22,917.379 360.23,917.32 360.239,917.261 360.248,917.202 360.257,917.143 360.266,917.084 360.276,917.025 360.285,916.966 360.294,916.908 360.303,916.849 360.312,916.79 360.322,916.731 360.331,916.673 360.34,916.614 360.349,916.556 360.358,916.497 360.367,916.439 360.377,916.38 360.386,916.322 360.395,916.264 360.404,916.205 360.413,916.147 360.423,916.089 360.432,916.031 360.441,915.973 360.45,915.915 360.459,915.857 360.469,915.799 360.478,915.741 360.487,915.683 360.496,915.625 360.505,915.567 360.514,915.509 360.524,915.451 360.533,915.394 360.542,915.336 360.551,915.278 360.56,915.221 360.57,915.163 360.579,915.106 360.588,915.048 360.597,914.991 360.606,914.933 360.616,914.876 360.625,914.819 360.634,914.761 360.643,914.704 360.652,914.647 360.662,914.59 360.671,914.533 360.68,914.475 360.689,914.418 360.698,914.361 360.707,914.304 360.717,914.248 360.726,914.191 360.735,914.134 360.744,914.077 360.753,914.02 360.763,913.964 360.772,913.907 360.781,913.85 360.79,913.794 360.799,913.737 360.809,913.681 360.818,913.624 360.827,913.568 360.836,913.511 360.845,913.455 360.854,913.398 360.864,913.342 360.873,913.286 360.882,913.23 360.891,913.174 360.9,913.117 360.91,913.061 360.919,913.005 360.928,912.949 360.937,912.893 360.946,912.837 360.956,912.782 360.965,912.726 360.974,912.67 360.983,912.614 360.992,912.558 361.002,912.503 361.011,912.447 361.02,912.391 361.029,912.336 361.038,912.28 361.047,912.225 361.057,912.169 361.066,912.114 361.075,912.059 361.084,912.003 361.093,911.948 361.103,911.893 361.112,911.837 361.121,911.782 361.13,911.727 361.139,911.672 361.149,911.617 361.158,911.562 361.167,911.507 361.176,911.452 361.185,911.397 361.195,911.342 361.204,911.287 361.213,911.233 361.222,911.178 361.231,911.123 361.24,911.069 361.25,911.014 361.259,910.959 361.268,910.905 361.277,910.85 361.286,910.796 361.296,910.741 361.305,910.687 361.314,910.633 361.323,910.578 361.332,910.524 361.342,910.47 361.351,910.416 361.36,910.361 361.369,910.307 361.378,910.253 361.387,910.199 361.397,910.145 361.406,910.091 361.415,910.037 361.424,909.983 361.433,909.93 361.443,909.876 361.452,909.822 361.461,909.768 361.47,909.714 361.479,909.661 361.489,909.607 361.498,909.554 361.507,909.5 361.516,909.447 361.525,909.393 361.535,909.34 361.544,909.286 361.553,909.233 361.562,909.18 361.571,909.126 361.58,909.073 361.59,909.02 361.599,908.967 361.608,908.914 361.617,908.861 361.626,908.808 361.636,908.755 361.645,908.702 361.654,908.649 361.663,908.596 361.672,908.543 361.682,908.49 361.691,908.437 361.7,908.385 361.709,908.332 361.718,908.279 361.727,908.227 361.737,908.174 361.746,908.122 361.755,908.069 361.764,908.017 361.773,907.964 361.783,907.912 361.792,907.86 361.801,907.807 361.81,907.755 361.819,907.703 361.829,907.651 361.838,907.598 361.847,907.546 361.856,907.494 361.865,907.442 361.875,907.39 361.884,907.338 361.893,907.286 361.902,907.234 361.911,907.182 361.92,907.131 361.93,907.079 361.939,907.027 361.948,906.975 361.957,906.924 361.966,906.872 361.976,906.821 361.985,906.769 361.994,906.718 362.003,906.666 362.012,906.615 362.022,906.563 362.031,906.512 362.04,906.461 362.049,906.409 362.058,906.358 362.067,906.307 362.077,906.256 362.086,906.205 362.095,906.153 362.104,906.102 362.113,906.051 362.123,906 362.132,905.95 362.141,905.899 362.15,905.848 362.159,905.797 362.169,905.746 362.178,905.695 362.187,905.645 362.196,905.594 362.205,905.543 362.215,905.493 362.224,905.442 362.233,905.392 362.242,905.341 362.251,905.291 362.26,905.24 362.27,905.19 362.279,905.14 362.288,905.089 362.297,905.039 362.306,904.989 362.316,904.939 362.325,904.889 362.334,904.838 362.343,904.788 362.352,904.738 362.362,904.688 362.371,904.638 362.38,904.588 362.389,904.539 362.398,904.489 362.407,904.439 362.417,904.389 362.426,904.339 362.435,904.29 362.444,904.24 362.453,904.19 362.463,904.141 362.472,904.091 362.481,904.042 362.49,903.992 362.499,903.943 362.509,903.893 362.518,903.844 362.527,903.795 362.536,903.745 362.545,903.696 362.555,903.647 362.564,903.598 362.573,903.549 362.582,903.5 362.591,903.45 362.6,903.401 362.61,903.352 362.619,903.303 362.628,903.255 362.637,903.206 362.646,903.157 362.656,903.108 362.665,903.059 362.674,903.011 362.683,902.962 362.692,902.913 362.702,902.865 362.711,902.816 362.72,902.767 362.729,902.719 362.738,902.67 362.747,902.622 362.757,902.574 362.766,902.525 362.775,902.477 362.784,902.429 362.793,902.38 362.803,902.332 362.812,902.284 362.821,902.236 362.83,902.188 362.839,902.14 362.849,902.092 362.858,902.044 362.867,901.996 362.876,901.948 362.885,901.9 362.895,901.852 362.904,901.804 362.913,901.756 362.922,901.709 362.931,901.661 362.94,901.613 362.95,901.566 362.959,901.518 362.968,901.471 362.977,901.423 362.986,901.376 362.996,901.328 363.005,901.281 363.014,901.233 363.023,901.186 363.032,901.139 363.042,901.091 363.051,901.044 363.06,900.997 363.069,900.95 363.078,900.903 363.087,900.856 363.097,900.809 363.106,900.762 363.115,900.715 363.124,900.668 363.133,900.621 363.143,900.574 363.152,900.527 363.161,900.48 363.17,900.434 363.179,900.387 363.189,900.34 363.198,900.293 363.207,900.247 363.216,900.2 363.225,900.154 363.235,900.107 363.244,900.061 363.253,900.014 363.262,899.968 363.271,899.922 363.28,899.875 363.29,899.829 363.299,899.783 363.308,899.737 363.317,899.69 363.326,899.644 363.336,899.598 363.345,899.552 363.354,899.506 363.363,899.46 363.372,899.414 363.382,899.368 363.391,899.322 363.4,899.276 363.409,899.231 363.418,899.185 363.427,899.139 363.437,899.093 363.446,899.048 363.455,899.002 363.464,898.956 363.473,898.911 363.483,898.865 363.492,898.82 363.501,898.774 363.51,898.729 363.519,898.684 363.529,898.638 363.538,898.593 363.547,898.548 363.556,898.502 363.565,898.457 363.575,898.412 363.584,898.367 363.593,898.322 363.602,898.277 363.611,898.232 363.62,898.187 363.63,898.142 363.639,898.097 363.648,898.052 363.657,898.007 363.666,897.962 363.676,897.917 363.685,897.873 363.694,897.828 363.703,897.783 363.712,897.739 363.722,897.694 363.731,897.649 363.74,897.605 363.749,897.56 363.758,897.516 363.768,897.472 363.777,897.427 363.786,897.383 363.795,897.338 363.804,897.294 363.813,897.25 363.823,897.206 363.832,897.162 363.841,897.117 363.85,897.073 363.859,897.029 363.869,896.985 363.878,896.941 363.887,896.897 363.896,896.853 363.905,896.809 363.915,896.766 363.924,896.722 363.933,896.678 363.942,896.634 363.951,896.59 363.96,896.547 363.97,896.503 363.979,896.459 363.988,896.416 363.997,896.372 364.006,896.329 364.016,896.285 364.025,896.242 364.034,896.199 364.043,896.155 364.052,896.112 364.062,896.069 364.071,896.025 364.08,895.982 364.089,895.939 364.098,895.896 364.108,895.853 364.117,895.809 364.126,895.766 364.135,895.723 364.144,895.68 364.153,895.637 364.163,895.595 364.172,895.552 364.181,895.509 364.19,895.466 364.199,895.423 364.209,895.38 364.218,895.338 364.227,895.295 364.236,895.252 364.245,895.21 364.255,895.167 364.264,895.125 364.273,895.082 364.282,895.04 364.291,894.997 364.3,894.955 364.31,894.913 364.319,894.87 364.328,894.828 364.337,894.786 364.346,894.743 364.356,894.701 364.365,894.659 364.374,894.617 364.383,894.575 364.392,894.533 364.402,894.491 364.411,894.449 364.42,894.407 364.429,894.365 364.438,894.323 364.448,894.281 364.457,894.239 364.466,894.198 364.475,894.156 364.484,894.114 364.493,894.073 364.503,894.031 364.512,893.989 364.521,893.948 364.53,893.906 364.539,893.865 364.549,893.823 364.558,893.782 364.567,893.74 364.576,893.699 364.585,893.658 364.595,893.616 364.604,893.575 364.613,893.534 364.622,893.493 364.631,893.452 364.64,893.411 364.65,893.369 364.659,893.328 364.668,893.287 364.677,893.246 364.686,893.205 364.696,893.165 364.705,893.124 364.714,893.083 364.723,893.042 364.732,893.001 364.742,892.96 364.751,892.92 364.76,892.879 364.769,892.838 364.778,892.798 364.788,892.757 364.797,892.717 364.806,892.676 364.815,892.636 364.824,892.595 364.833,892.555 364.843,892.514 364.852,892.474 364.861,892.434 364.87,892.394 364.879,892.353 364.889,892.313 364.898,892.273 364.907,892.233 364.916,892.193 364.925,892.153 364.935,892.113 364.944,892.073 364.953,892.033 364.962,891.993 364.971,891.953 364.98,891.913 364.99,891.873 364.999,891.833 365.008,891.794 365.017,891.754 365.026,891.714 365.036,891.674 365.045,891.635 365.054,891.595 365.063,891.556 365.072,891.516 365.082,891.477 365.091,891.437 365.1,891.398 365.109,891.358 365.118,891.319 365.128,891.28 365.137,891.24 365.146,891.201 365.155,891.162 365.164,891.123 365.173,891.083 365.183,891.044 365.192,891.005 365.201,890.966 365.21,890.927 365.219,890.888 365.229,890.849 365.238,890.81 365.247,890.771 365.256,890.733 365.265,890.694 365.275,890.655 365.284,890.616 365.293,890.577 365.302,890.539 365.311,890.5 365.32,890.461 365.33,890.423 365.339,890.384 365.348,890.346 365.357,890.307 365.366,890.269 365.376,890.23 365.385,890.192 365.394,890.154 365.403,890.115 365.412,890.077 365.422,890.039 365.431,890 365.44,889.962 365.449,889.924 365.458,889.886 365.468,889.848 365.477,889.81 365.486,889.772 365.495,889.734 365.504,889.696 365.513,889.658 365.523,889.62 365.532,889.582 365.541,889.544 365.55,889.506 365.559,889.469 365.569,889.431 365.578,889.393 365.587,889.356 365.596,889.318 365.605,889.28 365.615,889.243 365.624,889.205 365.633,889.168 365.642,889.13 365.651,889.093 365.66,889.055 365.67,889.018 365.679,888.981 365.688,888.943 365.697,888.906 365.706,888.869 365.716,888.832 365.725,888.794 365.734,888.757 365.743,888.72 365.752,888.683 365.762,888.646 365.771,888.609 365.78,888.572 365.789,888.535 365.798,888.498 365.808,888.461 365.817,888.425 365.826,888.388 365.835,888.351 365.844,888.314 365.853,888.277 365.863,888.241 365.872,888.204 365.881,888.167 365.89,888.131 365.899,888.094 365.909,888.058 365.918,888.021 365.927,887.985 365.936,887.948 365.945,887.912 365.955,887.876 365.964,887.839 365.973,887.803 365.982,887.767 365.991,887.73 366,887.694 366.01,887.658 366.019,887.622 366.028,887.586 366.037,887.55 366.046,887.514 366.056,887.478 366.065,887.442 366.074,887.406 366.083,887.37 366.092,887.334 366.102,887.298 366.111,887.262 366.12,887.227 366.129,887.191 366.138,887.155 366.148,887.119 366.157,887.084 366.166,887.048 366.175,887.013 366.184,886.977 366.193,886.941 366.203,886.906 366.212,886.871 366.221,886.835 366.23,886.8 366.239,886.764 366.249,886.729 366.258,886.694 366.267,886.658 366.276,886.623 366.285,886.588 366.295,886.553 366.304,886.518 366.313,886.483 366.322,886.447 366.331,886.412 366.341,886.377 366.35,886.342 366.359,886.307 366.368,886.273 366.377,886.238 366.386,886.203 366.396,886.168 366.405,886.133 366.414,886.098 366.423,886.064 366.432,886.029 366.442,885.994 366.451,885.96 366.46,885.925 366.469,885.891 366.478,885.856 366.488,885.821 366.497,885.787 366.506,885.753 366.515,885.718 366.524,885.684 366.533,885.649 366.543,885.615 366.552,885.581 366.561,885.547 366.57,885.512 366.579,885.478 366.589,885.444 366.598,885.41 366.607,885.376 366.616,885.342 366.625,885.308 366.635,885.274 366.644,885.24 366.653,885.206 366.662,885.172 366.671,885.138 366.681,885.104 366.69,885.07 366.699,885.037 366.708,885.003 366.717,884.969 366.726,884.935 366.736,884.902 366.745,884.868 366.754,884.834 366.763,884.801 366.772,884.767 366.782,884.734 366.791,884.7 366.8,884.667 366.809,884.634 366.818,884.6 366.828,884.567 366.837,884.534 366.846,884.5 366.855,884.467 366.864,884.434 366.873,884.401 366.883,884.367 366.892,884.334 366.901,884.301 366.91,884.268 366.919,884.235 366.929,884.202 366.938,884.169 366.947,884.136 366.956,884.103 366.965,884.07 366.975,884.038 366.984,884.005 366.993,883.972 367.002,883.939 367.011,883.907 367.021,883.874 367.03,883.841 367.039,883.809 367.048,883.776 367.057,883.743 367.066,883.711 367.076,883.678 367.085,883.646 367.094,883.613 367.103,883.581 367.112,883.549 367.122,883.516 367.131,883.484 367.14,883.452 367.149,883.419 367.158,883.387 367.168,883.355 367.177,883.323 367.186,883.291 367.195,883.259 367.204,883.227 367.213,883.194 367.223,883.162 367.232,883.131 367.241,883.099 367.25,883.067 367.259,883.035 367.269,883.003 367.278,882.971 367.287,882.939 367.296,882.907 367.305,882.876 367.315,882.844 367.324,882.812 367.333,882.781 367.342,882.749 367.351,882.718 367.361,882.686 367.37,882.654 367.379,882.623 367.388,882.592 367.397,882.56 367.406,882.529 367.416,882.497 367.425,882.466 367.434,882.435 367.443,882.403 367.452,882.372 367.462,882.341 367.471,882.31 367.48,882.279 367.489,882.247 367.498,882.216 367.508,882.185 367.517,882.154 367.526,882.123 367.535,882.092 367.544,882.061 367.553,882.03 367.563,882 367.572,881.969 367.581,881.938 367.59,881.907 367.599,881.876 367.609,881.846 367.618,881.815 367.627,881.784 367.636,881.754 367.645,881.723 367.655,881.692 367.664,881.662 367.673,881.631 367.682,881.601 367.691,881.57 367.701,881.54 367.71,881.51 367.719,881.479 367.728,881.449 367.737,881.419 367.746,881.388 367.756,881.358 367.765,881.328 367.774,881.298 367.783,881.267 367.792,881.237 367.802,881.207 367.811,881.177 367.82,881.147 367.829,881.117 367.838,881.087 367.848,881.057 367.857,881.027 367.866,880.997 367.875,880.967 367.884,880.938 367.893,880.908 367.903,880.878 367.912,880.848 367.921,880.819 367.93,880.789 367.939,880.759 367.949,880.73 367.958,880.7 367.967,880.671 367.976,880.641 367.985,880.611 367.995,880.582 368.004,880.553 368.013,880.523 368.022,880.494 368.031,880.464 368.041,880.435 368.05,880.406 368.059,880.377 368.068,880.347 368.077,880.318 368.086,880.289 368.096,880.26 368.105,880.231 368.114,880.202 368.123,880.173 368.132,880.143 368.142,880.114 368.151,880.086 368.16,880.057 368.169,880.028 368.178,879.999 368.188,879.97 368.197,879.941 368.206,879.912 368.215,879.884 368.224,879.855 368.233,879.826 368.243,879.797 368.252,879.769 368.261,879.74 368.27,879.712 368.279,879.683 368.289,879.655 368.298,879.626 368.307,879.598 368.316,879.569 368.325,879.541 368.335,879.512 368.344,879.484 368.353,879.456 368.362,879.427 368.371,879.399 368.381,879.371 368.39,879.343 368.399,879.314 368.408,879.286 368.417,879.258 368.426,879.23 368.436,879.202 368.445,879.174 368.454,879.146 368.463,879.118 368.472,879.09 368.482,879.062 368.491,879.034 368.5,879.006 368.509,878.979 368.518,878.951 368.528,878.923 368.537,878.895 368.546,878.868 368.555,878.84 368.564,878.812 368.574,878.785 368.583,878.757 368.592,878.73 368.601,878.702 368.61,878.675 368.619,878.647 368.629,878.62 368.638,878.592 368.647,878.565 368.656,878.537 368.665,878.51 368.675,878.483 368.684,878.455 368.693,878.428 368.702,878.401 368.711,878.374 368.721,878.347 368.73,878.32 368.739,878.292 368.748,878.265 368.757,878.238 368.766,878.211 368.776,878.184 368.785,878.157 368.794,878.13 368.803,878.104 368.812,878.077 368.822,878.05 368.831,878.023 368.84,877.996 368.849,877.969 368.858,877.943 368.868,877.916 368.877,877.889 368.886,877.863 368.895,877.836 368.904,877.81 368.914,877.783 368.923,877.756 368.932,877.73 368.941,877.703 368.95,877.677 368.959,877.651 368.969,877.624 368.978,877.598 368.987,877.572 368.996,877.545 369.005,877.519 369.015,877.493 369.024,877.467 369.033,877.44 369.042,877.414 369.051,877.388 369.061,877.362 369.07,877.336 369.079,877.31 369.088,877.284 369.097,877.258 369.106,877.232 369.116,877.206 369.125,877.18 369.134,877.154 369.143,877.128 369.152,877.103 369.162,877.077 369.171,877.051 369.18,877.025 369.189,877 369.198,876.974 369.208,876.948 369.217,876.923 369.226,876.897 369.235,876.871 369.244,876.846 369.254,876.82 369.263,876.795 369.272,876.77 369.281,876.744 369.29,876.719 369.299,876.693 369.309,876.668 369.318,876.643 369.327,876.617 369.336,876.592 369.345,876.567 369.355,876.542 369.364,876.517 369.373,876.491 369.382,876.466 369.391,876.441 369.401,876.416 369.41,876.391 369.419,876.366 369.428,876.341 369.437,876.316 369.446,876.291 369.456,876.266 369.465,876.242 369.474,876.217 369.483,876.192 369.492,876.167 369.502,876.142 369.511,876.118 369.52,876.093 369.529,876.068 369.538,876.044 369.548,876.019 369.557,875.995 369.566,875.97 369.575,875.945 369.584,875.921 369.594,875.896 369.603,875.872 369.612,875.848 369.621,875.823 369.63,875.799 369.639,875.775 369.649,875.75 369.658,875.726 369.667,875.702 369.676,875.677 369.685,875.653 369.695,875.629 369.704,875.605 369.713,875.581 369.722,875.557 369.731,875.533 369.741,875.509 369.75,875.485 369.759,875.461 369.768,875.437 369.777,875.413 369.786,875.389 369.796,875.365 369.805,875.341 369.814,875.317 369.823,875.294 369.832,875.27 369.842,875.246 369.851,875.223 369.86,875.199 369.869,875.175 369.878,875.152 369.888,875.128 369.897,875.104 369.906,875.081 369.915,875.057 369.924,875.034 369.934,875.011 369.943,874.987 369.952,874.964 369.961,874.94 369.97,874.917 369.979,874.894 369.989,874.87 369.998,874.847 370.007,874.824 370.016,874.801 370.025,874.778 370.035,874.754 370.044,874.731 370.053,874.708 370.062,874.685 370.071,874.662 370.081,874.639 370.09,874.616 370.099,874.593 370.108,874.57 370.117,874.547 370.126,874.524 370.136,874.502 370.145,874.479 370.154,874.456 370.163,874.433 370.172,874.41 370.182,874.388 370.191,874.365 370.2,874.342 370.209,874.32 370.218,874.297 370.228,874.275 370.237,874.252 370.246,874.229 370.255,874.207 370.264,874.184 370.274,874.162 370.283,874.14 370.292,874.117 370.301,874.095 370.31,874.073 370.319,874.05 370.329,874.028 370.338,874.006 370.347,873.983 370.356,873.961 370.365,873.939 370.375,873.917 370.384,873.895 370.393,873.873 370.402,873.851 370.411,873.829 370.421,873.807 370.43,873.785 370.439,873.763 370.448,873.741 370.457,873.719 370.466,873.697 370.476,873.675 370.485,873.653 370.494,873.631 370.503,873.61 370.512,873.588 370.522,873.566 370.531,873.544 370.54,873.523 370.549,873.501 370.558,873.48 370.568,873.458 370.577,873.436 370.586,873.415 370.595,873.393 370.604,873.372 370.614,873.35 370.623,873.329 370.632,873.308 370.641,873.286 370.65,873.265 370.659,873.244 370.669,873.222 370.678,873.201 370.687,873.18 370.696,873.159 370.705,873.137 370.715,873.116 370.724,873.095 370.733,873.074 370.742,873.053 370.751,873.032 370.761,873.011 370.77,872.99 370.779,872.969 370.788,872.948 370.797,872.927 370.806,872.906 370.816,872.885 370.825,872.864 370.834,872.844 370.843,872.823 370.852,872.802 370.862,872.781 370.871,872.76 370.88,872.74 370.889,872.719 370.898,872.699 370.908,872.678 370.917,872.657 370.926,872.637 370.935,872.616 370.944,872.596 370.954,872.575 370.963,872.555 370.972,872.534 370.981,872.514 370.99,872.494 370.999,872.473 371.009,872.453 371.018,872.433 371.027,872.412 371.036,872.392 371.045,872.372 371.055,872.352 371.064,872.332 371.073,872.311 371.082,872.291 371.091,872.271 371.101,872.251 371.11,872.231 371.119,872.211 371.128,872.191 371.137,872.171 371.147,872.151 371.156,872.131 371.165,872.111 371.174,872.092 371.183,872.072 371.192,872.052 371.202,872.032 371.211,872.012 371.22,871.993 371.229,871.973 371.238,871.953 371.248,871.934 371.257,871.914 371.266,871.895 371.275,871.875 371.284,871.855 371.294,871.836 371.303,871.816 371.312,871.797 371.321,871.778 371.33,871.758 371.339,871.739 371.349,871.719 371.358,871.7 371.367,871.681 371.376,871.661 371.385,871.642 371.395,871.623 371.404,871.604 371.413,871.585 371.422,871.565 371.431,871.546 371.441,871.527 371.45,871.508 371.459,871.489 371.468,871.47 371.477,871.451 371.487,871.432 371.496,871.413 371.505,871.394 371.514,871.375 371.523,871.356 371.532,871.338 371.542,871.319 371.551,871.3 371.56,871.281 371.569,871.262 371.578,871.244 371.588,871.225 371.597,871.206 371.606,871.188 371.615,871.169 371.624,871.15 371.634,871.132 371.643,871.113 371.652,871.095 371.661,871.076 371.67,871.058 371.679,871.039 371.689,871.021 371.698,871.003 371.707,870.984 371.716,870.966 371.725,870.948 371.735,870.929 371.744,870.911 371.753,870.893 371.762,870.875 371.771,870.856 371.781,870.838 371.79,870.82 371.799,870.802 371.808,870.784 371.817,870.766 371.827,870.748 371.836,870.73 371.845,870.712 371.854,870.694 371.863,870.676 371.872,870.658 371.882,870.64 371.891,870.622 371.9,870.604 371.909,870.587 371.918,870.569 371.928,870.551 371.937,870.533 371.946,870.516 371.955,870.498 371.964,870.48 371.974,870.463 371.983,870.445 371.992,870.427 372.001,870.41 372.01,870.392 372.019,870.375 372.029,870.357 372.038,870.34 372.047,870.322 372.056,870.305 372.065,870.288 372.075,870.27 372.084,870.253 372.093,870.236 372.102,870.218 372.111,870.201 372.121,870.184 372.13,870.167 372.139,870.149 372.148,870.132 372.157,870.115 372.167,870.098 372.176,870.081 372.185,870.064 372.194,870.047 372.203,870.03 372.212,870.013 372.222,869.996 372.231,869.979 372.24,869.962 372.249,869.945 372.258,869.928 372.268,869.911 372.277,869.895 372.286,869.878 372.295,869.861 372.304,869.844 372.314,869.828 372.323,869.811 372.332,869.794 372.341,869.778 372.35,869.761 372.359,869.744 372.369,869.728 372.378,869.711 372.387,869.695 372.396,869.678 372.405,869.662 372.415,869.645 372.424,869.629 372.433,869.613 372.442,869.596 372.451,869.58 372.461,869.564 372.47,869.547 372.479,869.531 372.488,869.515 372.497,869.499 372.507,869.482 372.516,869.466 372.525,869.45 372.534,869.434 372.543,869.418 372.552,869.402 372.562,869.386 372.571,869.37 372.58,869.354 372.589,869.338 372.598,869.322 372.608,869.306 372.617,869.29 372.626,869.274 372.635,869.258 372.644,869.242 372.654,869.226 372.663,869.211 372.672,869.195 372.681,869.179 372.69,869.163 372.699,869.148 372.709,869.132 372.718,869.116 372.727,869.101 372.736,869.085 372.745,869.07 372.755,869.054 372.764,869.039 372.773,869.023 372.782,869.008 372.791,868.992 372.801,868.977 372.81,868.961 372.819,868.946 372.828,868.931 372.837,868.915 372.847,868.9 372.856,868.885 372.865,868.869 372.874,868.854 372.883,868.839 372.892,868.824 372.902,868.809 372.911,868.794 372.92,868.778 372.929,868.763 372.938,868.748 372.948,868.733 372.957,868.718 372.966,868.703 372.975,868.688 372.984,868.673 372.994,868.658 373.003,868.644 373.012,868.629 373.021,868.614 373.03,868.599 373.039,868.584 373.049,868.569 373.058,868.555 373.067,868.54 373.076,868.525 373.085,868.511 373.095,868.496 373.104,868.481 373.113,868.467 373.122,868.452 373.131,868.438 373.141,868.423 373.15,868.408 373.159,868.394 373.168,868.38 373.177,868.365 373.187,868.351 373.196,868.336 373.205,868.322 373.214,868.308 373.223,868.293 373.232,868.279 373.242,868.265 373.251,868.25 373.26,868.236 373.269,868.222 373.278,868.208 373.288,868.194 373.297,868.18 373.306,868.165 373.315,868.151 373.324,868.137 373.334,868.123 373.343,868.109 373.352,868.095 373.361,868.081 373.37,868.067 373.379,868.053 373.389,868.039 373.398,868.026 373.407,868.012 373.416,867.998 373.425,867.984 373.435,867.97 373.444,867.957 373.453,867.943 373.462,867.929 373.471,867.915 373.481,867.902 373.49,867.888 373.499,867.875 373.508,867.861 373.517,867.847 373.527,867.834 373.536,867.82 373.545,867.807 373.554,867.793 373.563,867.78 373.572,867.766 373.582,867.753 373.591,867.74 373.6,867.726 373.609,867.713 373.618,867.7 373.628,867.686 373.637,867.673 373.646,867.66 373.655,867.647 373.664,867.633 373.674,867.62 373.683,867.607 373.692,867.594 373.701,867.581 373.71,867.568 373.72,867.555 373.729,867.542 373.738,867.529 373.747,867.516 373.756,867.503 373.765,867.49 373.775,867.477 373.784,867.464 373.793,867.451 373.802,867.438 373.811,867.425 373.821,867.413 373.83,867.4 373.839,867.387 373.848,867.374 373.857,867.362 373.867,867.349 373.876,867.336 373.885,867.324 373.894,867.311 373.903,867.298 373.912,867.286 373.922,867.273 373.931,867.261 373.94,867.248 373.949,867.236 373.958,867.223 373.968,867.211 373.977,867.198 373.986,867.186 373.995,867.174 374.004,867.161 374.014,867.149 374.023,867.137 374.032,867.124 374.041,867.112 374.05,867.1 374.06,867.088 374.069,867.076 374.078,867.063 374.087,867.051 374.096,867.039 374.105,867.027 374.115,867.015 374.124,867.003 374.133,866.991 374.142,866.979 374.151,866.967 374.161,866.955 374.17,866.943 374.179,866.931 374.188,866.919 374.197,866.907 374.207,866.896 374.216,866.884 374.225,866.872 374.234,866.86 374.243,866.848 374.252,866.837 374.262,866.825 374.271,866.813 374.28,866.802 374.289,866.79 374.298,866.778 374.308,866.767 374.317,866.755 374.326,866.744 374.335,866.732 374.344,866.721 374.354,866.709 374.363,866.698 374.372,866.686 374.381,866.675 374.39,866.663 374.4,866.652 374.409,866.641 374.418,866.629 374.427,866.618 374.436,866.607 374.445,866.595 374.455,866.584 374.464,866.573 374.473,866.562 374.482,866.551 374.491,866.539 374.501,866.528 374.51,866.517 374.519,866.506 374.528,866.495 374.537,866.484 374.547,866.473 374.556,866.462 374.565,866.451 374.574,866.44 374.583,866.429 374.592,866.418 374.602,866.407 374.611,866.397 374.62,866.386 374.629,866.375 374.638,866.364 374.648,866.353 374.657,866.343 374.666,866.332 374.675,866.321 374.684,866.311 374.694,866.3 374.703,866.289 374.712,866.279 374.721,866.268 374.73,866.257 374.74,866.247 374.749,866.236 374.758,866.226 374.767,866.215 374.776,866.205 374.785,866.195 374.795,866.184 374.804,866.174 374.813,866.163 374.822,866.153 374.831,866.143 374.841,866.132 374.85,866.122 374.859,866.112 374.868,866.102 374.877,866.091 374.887,866.081 374.896,866.071 374.905,866.061 374.914,866.051 374.923,866.041 374.932,866.031 374.942,866.02 374.951,866.01 374.96,866 374.969,865.99 374.978,865.98 374.988,865.97 374.997,865.961 375.006,865.951 375.015,865.941 375.024,865.931 375.034,865.921 375.043,865.911 375.052,865.901 375.061,865.892 375.07,865.882 375.08,865.872 375.089,865.862 375.098,865.853 375.107,865.843 375.116,865.833 375.125,865.824 375.135,865.814 375.144,865.805 375.153,865.795 375.162,865.786 375.171,865.776 375.181,865.766 375.19,865.757 375.199,865.748 375.208,865.738 375.217,865.729 375.227,865.719 375.236,865.71 375.245,865.701 375.254,865.691 375.263,865.682 375.272,865.673 375.282,865.663 375.291,865.654 375.3,865.645 375.309,865.636 375.318,865.627 375.328,865.617 375.337,865.608 375.346,865.599 375.355,865.59 375.364,865.581 375.374,865.572 375.383,865.563 375.392,865.554 375.401,865.545 375.41,865.536 375.42,865.527 375.429,865.518 375.438,865.509 375.447,865.5 375.456,865.492 375.465,865.483 375.475,865.474 375.484,865.465 375.493,865.456 375.502,865.448 375.511,865.439 375.521,865.43 375.53,865.422 375.539,865.413 375.548,865.404 375.557,865.396 375.567,865.387 375.576,865.378 375.585,865.37 375.594,865.361 375.603,865.353 375.612,865.344 375.622,865.336 375.631,865.327 375.64,865.319 375.649,865.311 375.658,865.302 375.668,865.294 375.677,865.286 375.686,865.277 375.695,865.269 375.704,865.261 375.714,865.252 375.723,865.244 375.732,865.236 375.741,865.228 375.75,865.22 375.76,865.211 375.769,865.203 375.778,865.195 375.787,865.187 375.796,865.179 375.805,865.171 375.815,865.163 375.824,865.155 375.833,865.147 375.842,865.139 375.851,865.131 375.861,865.123 375.87,865.115 375.879,865.107 375.888,865.1 375.897,865.092 375.907,865.084 375.916,865.076 375.925,865.068 375.934,865.061 375.943,865.053 375.953,865.045 375.962,865.037 375.971,865.03 375.98,865.022 375.989,865.015 375.998,865.007 376.008,864.999 376.017,864.992 376.026,864.984 376.035,864.977 376.044,864.969 376.054,864.962 376.063,864.954 376.072,864.947 376.081,864.939 376.09,864.932 376.1,864.925 376.109,864.917 376.118,864.91 376.127,864.903 376.136,864.895 376.145,864.888 376.155,864.881 376.164,864.874 376.173,864.866 376.182,864.859 376.191,864.852 376.201,864.845 376.21,864.838 376.219,864.831 376.228,864.824 376.237,864.816 376.247,864.809 376.256,864.802 376.265,864.795 376.274,864.788 376.283,864.781 376.293,864.774 376.302,864.768 376.311,864.761 376.32,864.754 376.329,864.747 376.338,864.74 376.348,864.733 376.357,864.726 376.366,864.72 376.375,864.713 376.384,864.706 376.394,864.699 376.403,864.693 376.412,864.686 376.421,864.679 376.43,864.673 376.44,864.666 376.449,864.66 376.458,864.653 376.467,864.646 376.476,864.64 376.485,864.633 376.495,864.627 376.504,864.62 376.513,864.614 376.522,864.608 376.531,864.601 376.541,864.595 376.55,864.588 376.559,864.582 376.568,864.576 376.577,864.569 376.587,864.563 376.596,864.557 376.605,864.551 376.614,864.544 376.623,864.538 376.633,864.532 376.642,864.526 376.651,864.52 376.66,864.514 376.669,864.507 376.678,864.501 376.688,864.495 376.697,864.489 376.706,864.483 376.715,864.477 376.724,864.471 376.734,864.465 376.743,864.459 376.752,864.453 376.761,864.447 376.77,864.442 376.78,864.436 376.789,864.43 376.798,864.424 376.807,864.418 376.816,864.412 376.825,864.407 376.835,864.401 376.844,864.395 376.853,864.39 376.862,864.384 376.871,864.378 376.881,864.373 376.89,864.367 376.899,864.361 376.908,864.356 376.917,864.35 376.927,864.345 376.936,864.339 376.945,864.334 376.954,864.328 376.963,864.323 376.973,864.317 376.982,864.312 376.991,864.306 377,864.301 377.009,864.296 377.018,864.29 377.028,864.285 377.037,864.28 377.046,864.274 377.055,864.269 377.064,864.264 377.074,864.259 377.083,864.253 377.092,864.248 377.101,864.243 377.11,864.238 377.12,864.233 377.129,864.228 377.138,864.223 377.147,864.218 377.156,864.212 377.165,864.207 377.175,864.202 377.184,864.197 377.193,864.192 377.202,864.188 377.211,864.183 377.221,864.178 377.23,864.173 377.239,864.168 377.248,864.163 377.257,864.158 377.267,864.153 377.276,864.149 377.285,864.144 377.294,864.139 377.303,864.134 377.313,864.13 377.322,864.125 377.331,864.12 377.34,864.116 377.349,864.111 377.358,864.106 377.368,864.102 377.377,864.097 377.386,864.093 377.395,864.088 377.404,864.084 377.414,864.079 377.423,864.075 377.432,864.07 377.441,864.066 377.45,864.061 377.46,864.057 377.469,864.053 377.478,864.048 377.487,864.044 377.496,864.039 377.505,864.035 377.515,864.031 377.524,864.027 377.533,864.022 377.542,864.018 377.551,864.014 377.561,864.01 377.57,864.006 377.579,864.001 377.588,863.997 377.597,863.993 377.607,863.989 377.616,863.985 377.625,863.981 377.634,863.977 377.643,863.973 377.653,863.969 377.662,863.965 377.671,863.961 377.68,863.957 377.689,863.953 377.698,863.949 377.708,863.945 377.717,863.942 377.726,863.938 377.735,863.934 377.744,863.93 377.754,863.926 377.763,863.923 377.772,863.919 377.781,863.915 377.79,863.911 377.8,863.908 377.809,863.904 377.818,863.9 377.827,863.897 377.836,863.893 377.845,863.89 377.855,863.886 377.864,863.882 377.873,863.879 377.882,863.875 377.891,863.872 377.901,863.868 377.91,863.865 377.919,863.861 377.928,863.858 377.937,863.855 377.947,863.851 377.956,863.848 377.965,863.845 377.974,863.841 377.983,863.838 377.993,863.835 378.002,863.831 378.011,863.828 378.02,863.825 378.029,863.822 378.038,863.819 378.048,863.815 378.057,863.812 378.066,863.809 378.075,863.806 378.084,863.803 378.094,863.8 378.103,863.797 378.112,863.794 378.121,863.791 378.13,863.788 378.14,863.785 378.149,863.782 378.158,863.779 378.167,863.776 378.176,863.773 378.185,863.77 378.195,863.767 378.204,863.764 378.213,863.761 378.222,863.759 378.231,863.756 378.241,863.753 378.25,863.75 378.259,863.748 378.268,863.745 378.277,863.742 378.287,863.739 378.296,863.737 378.305,863.734 378.314,863.732 378.323,863.729 378.333,863.726 378.342,863.724 378.351,863.721 378.36,863.719 378.369,863.716 378.378,863.714 378.388,863.711 378.397,863.709 378.406,863.706 378.415,863.704 378.424,863.701 378.434,863.699 378.443,863.697 378.452,863.694 378.461,863.692 378.47,863.69 378.48,863.687 378.489,863.685 378.498,863.683 378.507,863.681 378.516,863.678 378.526,863.676 378.535,863.674 378.544,863.672 378.553,863.67 378.562,863.668 378.571,863.666 378.581,863.663 378.59,863.661 378.599,863.659 378.608,863.657 378.617,863.655 378.627,863.653 378.636,863.651 378.645,863.649 378.654,863.647 378.663,863.645 378.673,863.644 378.682,863.642 378.691,863.64 378.7,863.638 378.709,863.636 378.718,863.634 378.728,863.633 378.737,863.631 378.746,863.629 378.755,863.627 378.764,863.626 378.774,863.624 378.783,863.622 378.792,863.62 378.801,863.619 378.81,863.617 378.82,863.616 378.829,863.614 378.838,863.612 378.847,863.611 378.856,863.609 378.866,863.608 378.875,863.606 378.884,863.605 378.893,863.603 378.902,863.602 378.911,863.6 378.921,863.599 378.93,863.598 378.939,863.596 378.948,863.595 378.957,863.594 378.967,863.592 378.976,863.591 378.985,863.59 378.994,863.588 379.003,863.587 379.013,863.586 379.022,863.585 379.031,863.584 379.04,863.582 379.049,863.581 379.058,863.58 379.068,863.579 379.077,863.578 379.086,863.577 379.095,863.576 379.104,863.575 379.114,863.574 379.123,863.573 379.132,863.572 379.141,863.571 379.15,863.57 379.16,863.569 379.169,863.568 379.178,863.567 379.187,863.566 379.196,863.565 379.206,863.564 379.215,863.563 379.224,863.563 379.233,863.562 379.242,863.561 379.251,863.56 379.261,863.559 379.27,863.559 379.279,863.558 379.288,863.557 379.297,863.557 379.307,863.556 379.316,863.555 379.325,863.555 379.334,863.554 379.343,863.554 379.353,863.553 379.362,863.552 379.371,863.552 379.38,863.551 379.389,863.551 379.398,863.55 379.408,863.55 379.417,863.55 379.426,863.549 379.435,863.549 379.444,863.548 379.454,863.548 379.463,863.548 379.472,863.547 379.481,863.547 379.49,863.547 379.5,863.546 379.509,863.546 379.518,863.546 379.527,863.546 379.536,863.545 379.546,863.545 379.555,863.545 379.564,863.545 379.573,863.545 379.582,863.545 379.591,863.544 379.601,863.544 379.61,863.544 379.619,863.544 379.628,863.544 379.637,863.544 379.647,863.544 379.656,863.544 379.665,863.544 379.674,863.544 379.683,863.544 379.693,863.544 379.702,863.545 379.711,863.545 379.72,863.545 379.729,863.545 379.738,863.545 379.748,863.545 379.757,863.545 379.766,863.546 379.775,863.546 379.784,863.546 379.794,863.546 379.803,863.547 379.812,863.547 379.821,863.547 379.83,863.548 379.84,863.548 379.849,863.549 379.858,863.549 379.867,863.549 379.876,863.55 379.886,863.55 379.895,863.551 379.904,863.551 379.913,863.552 379.922,863.552 379.931,863.553 379.941,863.553 379.95,863.554 379.959,863.554 379.968,863.555 379.977,863.556 379.987,863.556 379.996,863.557 380.005,863.558 380.014,863.558 380.023,863.559 380.033,863.56 380.042,863.56 380.051,863.561 380.06,863.562 380.069,863.563 380.078,863.564 380.088,863.564 380.097,863.565 380.106,863.566 380.115,863.567 380.124,863.568 380.134,863.569 380.143,863.57 380.152,863.571 380.161,863.572 380.17,863.573 380.18,863.574 380.189,863.575 380.198,863.576 380.207,863.577 380.216,863.578 380.226,863.579 380.235,863.58 380.244,863.581 380.253,863.582 380.262,863.583 380.271,863.585 380.281,863.586 380.29,863.587 380.299,863.588 380.308,863.589 380.317,863.591 380.327,863.592 380.336,863.593 380.345,863.595 380.354,863.596 380.363,863.597 380.373,863.599 380.382,863.6 380.391,863.601 380.4,863.603 380.409,863.604 380.418,863.606 380.428,863.607 380.437,863.609 380.446,863.61 380.455,863.612 380.464,863.613 380.474,863.615 380.483,863.616 380.492,863.618 380.501,863.619 380.51,863.621 380.52,863.623 380.529,863.624 380.538,863.626 380.547,863.628 380.556,863.629 380.566,863.631 380.575,863.633 380.584,863.634 380.593,863.636 380.602,863.638 380.611,863.64 380.621,863.642 380.63,863.643 380.639,863.645 380.648,863.647 380.657,863.649 380.667,863.651 380.676,863.653 380.685,863.655 380.694,863.657 380.703,863.659 380.713,863.661 380.722,863.663 380.731,863.665 380.74,863.667 380.749,863.669 380.758,863.671 380.768,863.673 380.777,863.675 380.786,863.677 380.795,863.679 380.804,863.681 380.814,863.683 380.823,863.686 380.832,863.688 380.841,863.69 380.85,863.692 380.86,863.694 380.869,863.697 380.878,863.699 380.887,863.701 380.896,863.704 380.906,863.706 380.915,863.708 380.924,863.711 380.933,863.713 380.942,863.715 380.951,863.718 380.961,863.72 380.97,863.723 380.979,863.725 380.988,863.728 380.997,863.73 381.007,863.733 381.016,863.735 381.025,863.738 381.034,863.74 381.043,863.743 381.053,863.745 381.062,863.748 381.071,863.751 381.08,863.753 381.089,863.756 381.099,863.758 381.108,863.761 381.117,863.764 381.126,863.767 381.135,863.769 381.144,863.772 381.154,863.775 381.163,863.778 381.172,863.78 381.181,863.783 381.19,863.786 381.2,863.789 381.209,863.792 381.218,863.795 381.227,863.798 381.236,863.8 381.246,863.803 381.255,863.806 381.264,863.809 381.273,863.812 381.282,863.815 381.291,863.818 381.301,863.821 381.31,863.824 381.319,863.827 381.328,863.83 381.337,863.834 381.347,863.837 381.356,863.84 381.365,863.843 381.374,863.846 381.383,863.849 381.393,863.852 381.402,863.856 381.411,863.859 381.42,863.862 381.429,863.865 381.439,863.869 381.448,863.872 381.457,863.875 381.466,863.878 381.475,863.882 381.484,863.885 381.494,863.888 381.503,863.892 381.512,863.895 381.521,863.899 381.53,863.902 381.54,863.906 381.549,863.909 381.558,863.912 381.567,863.916 381.576,863.919 381.586,863.923 381.595,863.926 381.604,863.93 381.613,863.934 381.622,863.937 381.631,863.941 381.641,863.944 381.65,863.948 381.659,863.952 381.668,863.955 381.677,863.959 381.687,863.963 381.696,863.966 381.705,863.97 381.714,863.974 381.723,863.978 381.733,863.981 381.742,863.985 381.751,863.989 381.76,863.993 381.769,863.997 381.779,864.001 381.788,864.004 381.797,864.008 381.806,864.012 381.815,864.016 381.824,864.02 381.834,864.024 381.843,864.028 381.852,864.032 381.861,864.036 381.87,864.04 381.88,864.044 381.889,864.048 381.898,864.052 381.907,864.056 381.916,864.06 381.926,864.064 381.935,864.068 381.944,864.073 381.953,864.077 381.962,864.081 381.971,864.085 381.981,864.089 381.99,864.093 381.999,864.098 382.008,864.102 382.017,864.106 382.027,864.111 382.036,864.115 382.045,864.119 382.054,864.123 382.063,864.128 382.073,864.132 382.082,864.136 382.091,864.141 382.1,864.145 382.109,864.15 382.119,864.154 382.128,864.159 382.137,864.163 382.146,864.167 382.155,864.172 382.164,864.176 382.174,864.181 382.183,864.186 382.192,864.19 382.201,864.195 382.21,864.199 382.22,864.204 382.229,864.208 382.238,864.213 382.247,864.218 382.256,864.222 382.266,864.227 382.275,864.232 382.284,864.237 382.293,864.241 382.302,864.246 382.311,864.251 382.321,864.255 382.33,864.26 382.339,864.265 382.348,864.27 382.357,864.275 382.367,864.28 382.376,864.284 382.385,864.289 382.394,864.294 382.403,864.299 382.413,864.304 382.422,864.309 382.431,864.314 382.44,864.319 382.449,864.324 382.459,864.329 382.468,864.334 382.477,864.339 382.486,864.344 382.495,864.349 382.504,864.354 382.514,864.359 382.523,864.364 382.532,864.369 382.541,864.375 382.55,864.38 382.56,864.385 382.569,864.39 382.578,864.395 382.587,864.4 382.596,864.406 382.606,864.411 382.615,864.416 382.624,864.421 382.633,864.427 382.642,864.432 382.651,864.437 382.661,864.443 382.67,864.448 382.679,864.453 382.688,864.459 382.697,864.464 382.707,864.47 382.716,864.475 382.725,864.48 382.734,864.486 382.743,864.491 382.753,864.497 382.762,864.502 382.771,864.508 382.78,864.513 382.789,864.519 382.799,864.524 382.808,864.53 382.817,864.536 382.826,864.541 382.835,864.547 382.844,864.552 382.854,864.558 382.863,864.564 382.872,864.569 382.881,864.575 382.89,864.581 382.9,864.587 382.909,864.592 382.918,864.598 382.927,864.604 382.936,864.61 382.946,864.615 382.955,864.621 382.964,864.627 382.973,864.633 382.982,864.639 382.991,864.645 383.001,864.65 383.01,864.656 383.019,864.662 383.028,864.668 383.037,864.674 383.047,864.68 383.056,864.686 383.065,864.692 383.074,864.698 383.083,864.704 383.093,864.71 383.102,864.716 383.111,864.722 383.12,864.728 383.129,864.734 383.139,864.741 383.148,864.747 383.157,864.753 383.166,864.759 383.175,864.765 383.184,864.771 383.194,864.777 383.203,864.784 383.212,864.79 383.221,864.796 383.23,864.802 383.24,864.809 383.249,864.815 383.258,864.821 383.267,864.828 383.276,864.834 383.286,864.84 383.295,864.847 383.304,864.853 383.313,864.859 383.322,864.866 383.332,864.872 383.341,864.879 383.35,864.885 383.359,864.891 383.368,864.898 383.377,864.904 383.387,864.911 383.396,864.917 383.405,864.924 383.414,864.93 383.423,864.937 383.433,864.944 383.442,864.95 383.451,864.957 383.46,864.963 383.469,864.97 383.479,864.977 383.488,864.983 383.497,864.99 383.506,864.997 383.515,865.003 383.524,865.01 383.534,865.017 383.543,865.024 383.552,865.03 383.561,865.037 383.57,865.044 383.58,865.051 383.589,865.058 383.598,865.064 383.607,865.071 383.616,865.078 383.626,865.085 383.635,865.092 383.644,865.099 383.653,865.106 383.662,865.113 383.672,865.12 383.681,865.126 383.69,865.133 383.699,865.14 383.708,865.147 383.717,865.154 383.727,865.161 383.736,865.169 383.745,865.176 383.754,865.183 383.763,865.19 383.773,865.197 383.782,865.204 383.791,865.211 383.8,865.218 383.809,865.225 383.819,865.233 383.828,865.24 383.837,865.247 383.846,865.254 383.855,865.261 383.864,865.269 383.874,865.276 383.883,865.283 383.892,865.29 383.901,865.298 383.91,865.305 383.92,865.312 383.929,865.32 383.938,865.327 383.947,865.335 383.956,865.342 383.966,865.349 383.975,865.357 383.984,865.364 383.993,865.372 384.002,865.379 384.012,865.387 384.021,865.394 384.03,865.401 384.039,865.409 384.048,865.417 384.057,865.424 384.067,865.432 384.076,865.439 384.085,865.447 384.094,865.454 384.103,865.462 384.113,865.47 384.122,865.477 384.131,865.485 384.14,865.493 384.149,865.5 384.159,865.508 384.168,865.516 384.177,865.523 384.186,865.531 384.195,865.539 384.204,865.547 384.214,865.554 384.223,865.562 384.232,865.57 384.241,865.578 384.25,865.586 384.26,865.593 384.269,865.601 384.278,865.609 384.287,865.617 384.296,865.625 384.306,865.633 384.315,865.641 384.324,865.649 384.333,865.657 384.342,865.665 384.352,865.673 384.361,865.681 384.37,865.689 384.379,865.697 384.388,865.705 384.397,865.713 384.407,865.721 384.416,865.729 384.425,865.737 384.434,865.745 384.443,865.753 384.453,865.761 384.462,865.77 384.471,865.778 384.48,865.786 384.489,865.794 384.499,865.802 384.508,865.811 384.517,865.819 384.526,865.827 384.535,865.835 384.544,865.844 384.554,865.852 384.563,865.86 384.572,865.868 384.581,865.877 384.59,865.885 384.6,865.893 384.609,865.902 384.618,865.91 384.627,865.919 384.636,865.927 384.646,865.935 384.655,865.944 384.664,865.952 384.673,865.961 384.682,865.969 384.692,865.978 384.701,865.986 384.71,865.995 384.719,866.003 384.728,866.012 384.737,866.02 384.747,866.029 384.756,866.038 384.765,866.046 384.774,866.055 384.783,866.063 384.793,866.072 384.802,866.081 384.811,866.089 384.82,866.098 384.829,866.107 384.839,866.115 384.848,866.124 384.857,866.133 384.866,866.142 384.875,866.15 384.884,866.159 384.894,866.168 384.903,866.177 384.912,866.186 384.921,866.194 384.93,866.203 384.94,866.212 384.949,866.221 384.958,866.23 384.967,866.239 384.976,866.248 384.986,866.257 384.995,866.266 385.004,866.274 385.013,866.283 385.022,866.292 385.032,866.301 385.041,866.31 385.05,866.319 385.059,866.328 385.068,866.338 385.077,866.347 385.087,866.356 385.096,866.365 385.105,866.374 385.114,866.383 385.123,866.392 385.133,866.401 385.142,866.41 385.151,866.419 385.16,866.429 385.169,866.438 385.179,866.447 385.188,866.456 385.197,866.465 385.206,866.475 385.215,866.484 385.224,866.493 385.234,866.503 385.243,866.512 385.252,866.521 385.261,866.53 385.27,866.54 385.28,866.549 385.289,866.558 385.298,866.568 385.307,866.577 385.316,866.587 385.326,866.596 385.335,866.605 385.344,866.615 385.353,866.624 385.362,866.634 385.372,866.643 385.381,866.653 385.39,866.662 385.399,866.672 385.408,866.681 385.417,866.691 385.427,866.7 385.436,866.71 385.445,866.72 385.454,866.729 385.463,866.739 385.473,866.748 385.482,866.758 385.491,866.768 385.5,866.777 385.509,866.787 385.519,866.797 385.528,866.806 385.537,866.816 385.546,866.826 385.555,866.836 385.564,866.845 385.574,866.855 385.583,866.865 385.592,866.875 385.601,866.884 385.61,866.894 385.62,866.904 385.629,866.914 385.638,866.924 385.647,866.934 385.656,866.943 385.666,866.953 385.675,866.963 385.684,866.973 385.693,866.983 385.702,866.993 385.712,867.003 385.721,867.013 385.73,867.023 385.739,867.033 385.748,867.043 385.757,867.053 385.767,867.063 385.776,867.073 385.785,867.083 385.794,867.093 385.803,867.103 385.813,867.113 385.822,867.123 385.831,867.134 385.84,867.144 385.849,867.154 385.859,867.164 385.868,867.174 385.877,867.184 385.886,867.195 385.895,867.205 385.905,867.215 385.914,867.225 385.923,867.235 385.932,867.246 385.941,867.256 385.95,867.266 385.96,867.277 385.969,867.287 385.978,867.297 385.987,867.308 385.996,867.318 386.006,867.328 386.015,867.339 386.024,867.349 386.033,867.359 386.042,867.37 386.052,867.38 386.061,867.391 386.07,867.401 386.079,867.412 386.088,867.422 386.097,867.433 386.107,867.443 386.116,867.454 386.125,867.464 386.134,867.475 386.143,867.485 386.153,867.496 386.162,867.506 386.171,867.517 386.18,867.528 386.189,867.538 386.199,867.549 386.208,867.559 386.217,867.57 386.226,867.581 386.235,867.591 386.245,867.602 386.254,867.613 386.263,867.624 386.272,867.634 386.281,867.645 386.29,867.656 386.3,867.666 386.309,867.677 386.318,867.688 386.327,867.699 386.336,867.71 386.346,867.72 386.355,867.731 386.364,867.742 386.373,867.753 386.382,867.764 386.392,867.775 386.401,867.786 386.41,867.797 386.419,867.808 386.428,867.818 386.437,867.829 386.447,867.84 386.456,867.851 386.465,867.862 386.474,867.873 386.483,867.884 386.493,867.895 386.502,867.906 386.511,867.917 386.52,867.929 386.529,867.94 386.539,867.951 386.548,867.962 386.557,867.973 386.566,867.984 386.575,867.995 386.585,868.006 386.594,868.017 386.603,868.029 386.612,868.04 386.621,868.051 386.63,868.062 386.64,868.073 386.649,868.085 386.658,868.096 386.667,868.107 386.676,868.118 386.686,868.13 386.695,868.141 386.704,868.152 386.713,868.164 386.722,868.175 386.732,868.186 386.741,868.198 386.75,868.209 386.759,868.22 386.768,868.232 386.777,868.243 386.787,868.255 386.796,868.266 386.805,868.277 386.814,868.289 386.823,868.3 386.833,868.312 386.842,868.323 386.851,868.335 386.86,868.346 386.869,868.358 386.879,868.369 386.888,868.381 386.897,868.392 386.906,868.404 386.915,868.416 386.925,868.427 386.934,868.439 386.943,868.45 386.952,868.462 386.961,868.474 386.97,868.485 386.98,868.497 386.989,868.509 386.998,868.52 387.007,868.532 387.016,868.544 387.026,868.556 387.035,868.567 387.044,868.579 387.053,868.591 387.062,868.603 387.072,868.614 387.081,868.626 387.09,868.638 387.099,868.65 387.108,868.662 387.117,868.673 387.127,868.685 387.136,868.697 387.145,868.709 387.154,868.721 387.163,868.733 387.173,868.745 387.182,868.757 387.191,868.769 387.2,868.781 387.209,868.793 387.219,868.804 387.228,868.816 387.237,868.828 387.246,868.84 387.255,868.853 387.265,868.865 387.274,868.877 387.283,868.889 387.292,868.901 387.301,868.913 387.31,868.925 387.32,868.937 387.329,868.949 387.338,868.961 387.347,868.973 387.356,868.986 387.366,868.998 387.375,869.01 387.384,869.022 387.393,869.034 387.402,869.046 387.412,869.059 387.421,869.071 387.43,869.083 387.439,869.095 387.448,869.108 387.457,869.12 387.467,869.132 387.476,869.145 387.485,869.157 387.494,869.169 387.503,869.182 387.513,869.194 387.522,869.206 387.531,869.219 387.54,869.231 387.549,869.243 387.559,869.256 387.568,869.268 387.577,869.281 387.586,869.293 387.595,869.306 387.605,869.318 387.614,869.331 387.623,869.343 387.632,869.356 387.641,869.368 387.65,869.381 387.66,869.393 387.669,869.406 387.678,869.418 387.687,869.431 387.696,869.443 387.706,869.456 387.715,869.469 387.724,869.481 387.733,869.494 387.742,869.506 387.752,869.519 387.761,869.532 387.77,869.544 387.779,869.557 387.788,869.57 387.797,869.582 387.807,869.595 387.816,869.608 387.825,869.621 387.834,869.633 387.843,869.646 387.853,869.659 387.862,869.672 387.871,869.685 387.88,869.697 387.889,869.71 387.899,869.723 387.908,869.736 387.917,869.749 387.926,869.762 387.935,869.774 387.945,869.787 387.954,869.8 387.963,869.813 387.972,869.826 387.981,869.839 387.99,869.852 388,869.865 388.009,869.878 388.018,869.891 388.027,869.904 388.036,869.917 388.046,869.93 388.055,869.943 388.064,869.956 388.073,869.969 388.082,869.982 388.092,869.995 388.101,870.008 388.11,870.021 388.119,870.034 388.128,870.048 388.137,870.061 388.147,870.074 388.156,870.087 388.165,870.1 388.174,870.113 388.183,870.126 388.193,870.14 388.202,870.153 388.211,870.166 388.22,870.179 388.229,870.193 388.239,870.206 388.248,870.219 388.257,870.232 388.266,870.246 388.275,870.259 388.285,870.272 388.294,870.286 388.303,870.299 388.312,870.312 388.321,870.326 388.33,870.339 388.34,870.352 388.349,870.366 388.358,870.379 388.367,870.392 388.376,870.406 388.386,870.419 388.395,870.433 388.404,870.446 388.413,870.46 388.422,870.473 388.432,870.487 388.441,870.5 388.45,870.514 388.459,870.527 388.468,870.541 388.478,870.554 388.487,870.568 388.496,870.581 388.505,870.595 388.514,870.608 388.523,870.622 388.533,870.636 388.542,870.649 388.551,870.663 388.56,870.677 388.569,870.69 388.579,870.704 388.588,870.718 388.597,870.731 388.606,870.745 388.615,870.759 388.625,870.772 388.634,870.786 388.643,870.8 388.652,870.814 388.661,870.827 388.67,870.841 388.68,870.855 388.689,870.869 388.698,870.882 388.707,870.896 388.716,870.91 388.726,870.924 388.735,870.938 388.744,870.952 388.753,870.965 388.762,870.979 388.772,870.993 388.781,871.007 388.79,871.021 388.799,871.035 388.808,871.049 388.818,871.063 388.827,871.077 388.836,871.091 388.845,871.105 388.854,871.119 388.863,871.133 388.873,871.147 388.882,871.161 388.891,871.175 388.9,871.189 388.909,871.203 388.919,871.217 388.928,871.231 388.937,871.245 388.946,871.259 388.955,871.273 388.965,871.287 388.974,871.302 388.983,871.316 388.992,871.33 389.001,871.344 389.01,871.358 389.02,871.372 389.029,871.387 389.038,871.401 389.047,871.415 389.056,871.429 389.066,871.443 389.075,871.458 389.084,871.472 389.093,871.486 389.102,871.5 389.112,871.515 389.121,871.529 389.13,871.543 389.139,871.558 389.148,871.572 389.158,871.586 389.167,871.601 389.176,871.615 389.185,871.629 389.194,871.644 389.203,871.658 389.213,871.673 389.222,871.687 389.231,871.701 389.24,871.716 389.249,871.73 389.259,871.745 389.268,871.759 389.277,871.774 389.286,871.788 389.295,871.803 389.305,871.817 389.314,871.832 389.323,871.846 389.332,871.861 389.341,871.875 389.35,871.89 389.36,871.904 389.369,871.919 389.378,871.934 389.387,871.948 389.396,871.963 389.406,871.977 389.415,871.992 389.424,872.007 389.433,872.021 389.442,872.036 389.452,872.051 389.461,872.065 389.47,872.08 389.479,872.095 389.488,872.109 389.498,872.124 389.507,872.139 389.516,872.154 389.525,872.168 389.534,872.183 389.543,872.198 389.553,872.213 389.562,872.228 389.571,872.242 389.58,872.257 389.589,872.272 389.599,872.287 389.608,872.302 389.617,872.317 389.626,872.331 389.635,872.346 389.645,872.361 389.654,872.376 389.663,872.391 389.672,872.406 389.681,872.421 389.69,872.436 389.7,872.451 389.709,872.466 389.718,872.481 389.727,872.496 389.736,872.511 389.746,872.526 389.755,872.541 389.764,872.556 389.773,872.571 389.782,872.586 389.792,872.601 389.801,872.616 389.81,872.631 389.819,872.646 389.828,872.661 389.838,872.676 389.847,872.691 389.856,872.707 389.865,872.722 389.874,872.737 389.883,872.752 389.893,872.767 389.902,872.782 389.911,872.798 389.92,872.813 389.929,872.828 389.939,872.843 389.948,872.858 389.957,872.874 389.966,872.889 389.975,872.904 389.985,872.919 389.994,872.935 390.003,872.95 390.012,872.965 390.021,872.981 390.03,872.996 390.04,873.011 390.049,873.027 390.058,873.042 390.067,873.057 390.076,873.073 390.086,873.088 390.095,873.103 390.104,873.119 390.113,873.134 390.122,873.15 390.132,873.165 390.141,873.181 390.15,873.196 390.159,873.211 390.168,873.227 390.178,873.242 390.187,873.258 390.196,873.273 390.205,873.289 390.214,873.304 390.223,873.32 390.233,873.336 390.242,873.351 390.251,873.367 390.26,873.382 390.269,873.398 390.279,873.413 390.288,873.429 390.297,873.445 390.306,873.46 390.315,873.476 390.325,873.491 390.334,873.507 390.343,873.523 390.352,873.538 390.361,873.554 390.37,873.57 390.38,873.586 390.389,873.601 390.398,873.617 390.407,873.633 390.416,873.648 390.426,873.664 390.435,873.68 390.444,873.696 390.453,873.711 390.462,873.727 390.472,873.743 390.481,873.759 390.49,873.775 390.499,873.791 390.508,873.806 390.518,873.822 390.527,873.838 390.536,873.854 390.545,873.87 390.554,873.886 390.563,873.902 390.573,873.917 390.582,873.933 390.591,873.949 390.6,873.965 390.609,873.981 390.619,873.997 390.628,874.013 390.637,874.029 390.646,874.045 390.655,874.061 390.665,874.077 390.674,874.093 390.683,874.109 390.692,874.125 390.701,874.141 390.711,874.157 390.72,874.173 390.729,874.189 390.738,874.205 390.747,874.222 390.756,874.238 390.766,874.254 390.775,874.27 390.784,874.286 390.793,874.302 390.802,874.318 390.812,874.334 390.821,874.351 390.83,874.367 390.839,874.383 390.848,874.399 390.858,874.415 390.867,874.432 390.876,874.448 390.885,874.464 390.894,874.48 390.903,874.497 390.913,874.513 390.922,874.529 390.931,874.545 390.94,874.562 390.949,874.578 390.959,874.594 390.968,874.611 390.977,874.627 390.986,874.643 390.995,874.66 391.005,874.676 391.014,874.692 391.023,874.709 391.032,874.725 391.041,874.742 391.051,874.758 391.06,874.774 391.069,874.791 391.078,874.807 391.087,874.824 391.096,874.84 391.106,874.857 391.115,874.873 391.124,874.89 391.133,874.906 391.142,874.923 391.152,874.939 391.161,874.956 391.17,874.972 391.179,874.989 391.188,875.005 391.198,875.022 391.207,875.038 391.216,875.055 391.225,875.071 391.234,875.088 391.243,875.105 391.253,875.121 391.262,875.138 391.271,875.155 391.28,875.171 391.289,875.188 391.299,875.204 391.308,875.221 391.317,875.238 391.326,875.254 391.335,875.271 391.345,875.288 391.354,875.305 391.363,875.321 391.372,875.338 391.381,875.355 391.391,875.372 391.4,875.388 391.409,875.405 391.418,875.422 391.427,875.439 391.436,875.455 391.446,875.472 391.455,875.489 391.464,875.506 391.473,875.523 391.482,875.54 391.492,875.556 391.501,875.573 391.51,875.59 391.519,875.607 391.528,875.624 391.538,875.641 391.547,875.658 391.556,875.675 391.565,875.692 391.574,875.709 391.583,875.726 391.593,875.743 391.602,875.759 391.611,875.776 391.62,875.793 391.629,875.81 391.639,875.827 391.648,875.844 391.657,875.861 391.666,875.878 391.675,875.896 391.685,875.913 391.694,875.93 391.703,875.947 391.712,875.964 391.721,875.981 391.731,875.998 391.74,876.015 391.749,876.032 391.758,876.049 391.767,876.066 391.776,876.084 391.786,876.101 391.795,876.118 391.804,876.135 391.813,876.152 391.822,876.169 391.832,876.187 391.841,876.204 391.85,876.221 391.859,876.238 391.868,876.255 391.878,876.273 391.887,876.29 391.896,876.307 391.905,876.324 391.914,876.342 391.923,876.359 391.933,876.376 391.942,876.394 391.951,876.411 391.96,876.428 391.969,876.446 391.979,876.463 391.988,876.48 391.997,876.498 392.006,876.515 392.015,876.532 392.025,876.55 392.034,876.567 392.043,876.585 392.052,876.602 392.061,876.619 392.071,876.637 392.08,876.654 392.089,876.672 392.098,876.689 392.107,876.707 392.116,876.724 392.126,876.742 392.135,876.759 392.144,876.777 392.153,876.794 392.162,876.812 392.172,876.829 392.181,876.847 392.19,876.864 392.199,876.882 392.208,876.899 392.218,876.917 392.227,876.934 392.236,876.952 392.245,876.97 392.254,876.987 392.263,877.005 392.273,877.022 392.282,877.04 392.291,877.058 392.3,877.075 392.309,877.093 392.319,877.111 392.328,877.128 392.337,877.146 392.346,877.164 392.355,877.181 392.365,877.199 392.374,877.217 392.383,877.235 392.392,877.252 392.401,877.27 392.411,877.288 392.42,877.306 392.429,877.323 392.438,877.341 392.447,877.359 392.456,877.377 392.466,877.395 392.475,877.412 392.484,877.43 392.493,877.448 392.502,877.466 392.512,877.484 392.521,877.502 392.53,877.52 392.539,877.537 392.548,877.555 392.558,877.573 392.567,877.591 392.576,877.609 392.585,877.627 392.594,877.645 392.603,877.663 392.613,877.681 392.622,877.699 392.631,877.717 392.64,877.735 392.649,877.753 392.659,877.771 392.668,877.789 392.677,877.807 392.686,877.825 392.695,877.843 392.705,877.861 392.714,877.879 392.723,877.897 392.732,877.915 392.741,877.933 392.751,877.951 392.76,877.969 392.769,877.987 392.778,878.005 392.787,878.023 392.796,878.041 392.806,878.06 392.815,878.078 392.824,878.096 392.833,878.114 392.842,878.132 392.852,878.15 392.861,878.169 392.87,878.187 392.879,878.205 392.888,878.223 392.898,878.241 392.907,878.26 392.916,878.278 392.925,878.296 392.934,878.314 392.943,878.332 392.953,878.351 392.962,878.369 392.971,878.387 392.98,878.406 392.989,878.424 392.999,878.442 393.008,878.461 393.017,878.479 393.026,878.497 393.035,878.515 393.045,878.534 393.054,878.552 393.063,878.571 393.072,878.589 393.081,878.607 393.091,878.626 393.1,878.644 393.109,878.663 393.118,878.681 393.127,878.699 393.136,878.718 393.146,878.736 393.155,878.755 393.164,878.773 393.173,878.792 393.182,878.81 393.192,878.829 393.201,878.847 393.21,878.866 393.219,878.884 393.228,878.903 393.238,878.921 393.247,878.94 393.256,878.958 393.265,878.977 393.274,878.995 393.284,879.014 393.293,879.032 393.302,879.051 393.311,879.07 393.32,879.088 393.329,879.107 393.339,879.125 393.348,879.144 393.357,879.163 393.366,879.181 393.375,879.2 393.385,879.219 393.394,879.237 393.403,879.256 393.412,879.275 393.421,879.293 393.431,879.312 393.44,879.331 393.449,879.349 393.458,879.368 393.467,879.387 393.476,879.406 393.486,879.424 393.495,879.443 393.504,879.462 393.513,879.481 393.522,879.499 393.532,879.518 393.541,879.537 393.55,879.556 393.559,879.575 393.568,879.593 393.578,879.612 393.587,879.631 393.596,879.65 393.605,879.669 393.614,879.688 393.624,879.706 393.633,879.725 393.642,879.744 393.651,879.763 393.66,879.782 393.669,879.801 393.679,879.82 393.688,879.839 393.697,879.858 393.706,879.877 393.715,879.896 393.725,879.915 393.734,879.933 393.743,879.952 393.752,879.971 393.761,879.99 393.771,880.009 393.78,880.028 393.789,880.047 393.798,880.066 393.807,880.085 393.816,880.105 393.826,880.124 393.835,880.143 393.844,880.162 393.853,880.181 393.862,880.2 393.872,880.219 393.881,880.238 393.89,880.257 393.899,880.276 393.908,880.295 393.918,880.314 393.927,880.334 393.936,880.353 393.945,880.372 393.954,880.391 393.964,880.41 393.973,880.429 393.982,880.449 393.991,880.468 394,880.487 394.009,880.506 394.019,880.525 394.028,880.545 394.037,880.564 394.046,880.583 394.055,880.602 394.065,880.622 394.074,880.641 394.083,880.66 394.092,880.679 394.101,880.699 394.111,880.718 394.12,880.737 394.129,880.757 394.138,880.776 394.147,880.795 394.156,880.814 394.166,880.834 394.175,880.853 394.184,880.873 394.193,880.892 394.202,880.911 394.212,880.931 394.221,880.95 394.23,880.969 394.239,880.989 394.248,881.008 394.258,881.028 394.267,881.047 394.276,881.066 394.285,881.086 394.294,881.105 394.304,881.125 394.313,881.144 394.322,881.164 394.331,881.183 394.34,881.203 394.349,881.222 394.359,881.242 394.368,881.261 394.377,881.281 394.386,881.3 394.395,881.32 394.405,881.339 394.414,881.359 394.423,881.378 394.432,881.398 394.441,881.418 394.451,881.437 394.46,881.457 394.469,881.476 394.478,881.496 394.487,881.516 394.496,881.535 394.506,881.555 394.515,881.574 394.524,881.594 394.533,881.614 394.542,881.633 394.552,881.653 394.561,881.673 394.57,881.692 394.579,881.712 394.588,881.732 394.598,881.751 394.607,881.771 394.616,881.791 394.625,881.811 394.634,881.83 394.644,881.85 394.653,881.87 394.662,881.89 394.671,881.909 394.68,881.929 394.689,881.949 394.699,881.969 394.708,881.988 394.717,882.008 394.726,882.028 394.735,882.048 394.745,882.068 394.754,882.088 394.763,882.107 394.772,882.127 394.781,882.147 394.791,882.167 394.8,882.187 394.809,882.207 394.818,882.227 394.827,882.246 394.836,882.266 394.846,882.286 394.855,882.306 394.864,882.326 394.873,882.346 394.882,882.366 394.892,882.386 394.901,882.406 394.91,882.426 394.919,882.446 394.928,882.466 394.938,882.486 394.947,882.506 394.956,882.526 394.965,882.546 394.974,882.566 394.984,882.586 394.993,882.606 395.002,882.626 395.011,882.646 395.02,882.666 395.029,882.686 395.039,882.706 395.048,882.726 395.057,882.746 395.066,882.766 395.075,882.786 395.085,882.806 395.094,882.827 395.103,882.847 395.112,882.867 395.121,882.887 395.131,882.907 395.14,882.927 395.149,882.947 395.158,882.967 395.167,882.988 395.176,883.008 395.186,883.028 395.195,883.048 395.204,883.068 395.213,883.089 395.222,883.109 395.232,883.129 395.241,883.149 395.25,883.169 395.259,883.19 395.268,883.21 395.278,883.23 395.287,883.25 395.296,883.271 395.305,883.291 395.314,883.311 395.324,883.332 395.333,883.352 395.342,883.372 395.351,883.393 395.36,883.413 395.369,883.433 395.379,883.453 395.388,883.474 395.397,883.494 395.406,883.515 395.415,883.535 395.425,883.555 395.434,883.576 395.443,883.596 395.452,883.616 395.461,883.637 395.471,883.657 395.48,883.678 395.489,883.698 395.498,883.718 395.507,883.739 395.516,883.759 395.526,883.78 395.535,883.8 395.544,883.821 395.553,883.841 395.562,883.862 395.572,883.882 395.581,883.903 395.59,883.923 395.599,883.944 395.608,883.964 395.618,883.985 395.627,884.005 395.636,884.026 395.645,884.046 395.654,884.067 395.664,884.087 395.673,884.108 395.682,884.129 395.691,884.149 395.7,884.17 395.709,884.19 395.719,884.211 395.728,884.231 395.737,884.252 395.746,884.273 395.755,884.293 395.765,884.314 395.774,884.335 395.783,884.355 395.792,884.376 395.801,884.397 395.811,884.417 395.82,884.438 395.829,884.459 395.838,884.479 395.847,884.5 395.857,884.521 395.866,884.541 395.875,884.562 395.884,884.583 395.893,884.604 395.902,884.624 395.912,884.645 395.921,884.666 395.93,884.687 395.939,884.707 395.948,884.728 395.958,884.749 395.967,884.77 395.976,884.79 395.985,884.811 395.994,884.832 396.004,884.853 396.013,884.874 396.022,884.895 396.031,884.915 396.04,884.936 396.049,884.957 396.059,884.978 396.068,884.999 396.077,885.02 396.086,885.041 396.095,885.061 396.105,885.082 396.114,885.103 396.123,885.124 396.132,885.145 396.141,885.166 396.151,885.187 396.16,885.208 396.169,885.229 396.178,885.25 396.187,885.271 396.197,885.292 396.206,885.313 396.215,885.334 396.224,885.355 396.233,885.376 396.242,885.397 396.252,885.418 396.261,885.439 396.27,885.46 396.279,885.481 396.288,885.502 396.298,885.523 396.307,885.544 396.316,885.565 396.325,885.586 396.334,885.607 396.344,885.628 396.353,885.649 396.362,885.67 396.371,885.691 396.38,885.712 396.389,885.733 396.399,885.755 396.408,885.776 396.417,885.797 396.426,885.818 396.435,885.839 396.445,885.86 396.454,885.881 396.463,885.903 396.472,885.924 396.481,885.945 396.491,885.966 396.5,885.987 396.509,886.008 396.518,886.03 396.527,886.051 396.537,886.072 396.546,886.093 396.555,886.114 396.564,886.136 396.573,886.157 396.582,886.178 396.592,886.199 396.601,886.221 396.61,886.242 396.619,886.263 396.628,886.285 396.638,886.306 396.647,886.327 396.656,886.348 396.665,886.37 396.674,886.391 396.684,886.412 396.693,886.434 396.702,886.455 396.711,886.476 396.72,886.498 396.729,886.519 396.739,886.54 396.748,886.562 396.757,886.583 396.766,886.605 396.775,886.626 396.785,886.647 396.794,886.669 396.803,886.69 396.812,886.712 396.821,886.733 396.831,886.754 396.84,886.776 396.849,886.797 396.858,886.819 396.867,886.84 396.877,886.862 396.886,886.883 396.895,886.905 396.904,886.926 396.913,886.947 396.922,886.969 396.932,886.99 396.941,887.012 396.95,887.033 396.959,887.055 396.968,887.077 396.978,887.098 396.987,887.12 396.996,887.141 397.005,887.163 397.014,887.184 397.024,887.206 397.033,887.227 397.042,887.249 397.051,887.271 397.06,887.292 397.069,887.314 397.079,887.335 397.088,887.357 397.097,887.379 397.106,887.4 397.115,887.422 397.125,887.443 397.134,887.465 397.143,887.487 397.152,887.508 397.161,887.53 397.171,887.552 397.18,887.573 397.189,887.595 397.198,887.617 397.207,887.638 397.217,887.66 397.226,887.682 397.235,887.704 397.244,887.725 397.253,887.747 397.262,887.769 397.272,887.79 397.281,887.812 397.29,887.834 397.299,887.856 397.308,887.877 397.318,887.899 397.327,887.921 397.336,887.943 397.345,887.965 397.354,887.986 397.364,888.008 397.373,888.03 397.382,888.052 397.391,888.074 397.4,888.095 397.409,888.117 397.419,888.139 397.428,888.161 397.437,888.183 397.446,888.205 397.455,888.227 397.465,888.248 397.474,888.27 397.483,888.292 397.492,888.314 397.501,888.336 397.511,888.358 397.52,888.38 397.529,888.402 397.538,888.424 397.547,888.446 397.557,888.467 397.566,888.489 397.575,888.511 397.584,888.533 397.593,888.555 397.602,888.577 397.612,888.599 397.621,888.621 397.63,888.643 397.639,888.665 397.648,888.687 397.658,888.709 397.667,888.731 397.676,888.753 397.685,888.775 397.694,888.797 397.704,888.819 397.713,888.841 397.722,888.863 397.731,888.885 397.74,888.907 397.749,888.929 397.759,888.952 397.768,888.974 397.777,888.996 397.786,889.018 397.795,889.04 397.805,889.062 397.814,889.084 397.823,889.106 397.832,889.128 397.841,889.15 397.851,889.173 397.86,889.195 397.869,889.217 397.878,889.239 397.887,889.261 397.897,889.283 397.906,889.305 397.915,889.328 397.924,889.35 397.933,889.372 397.942,889.394 397.952,889.416 397.961,889.439 397.97,889.461 397.979,889.483 397.988,889.505 397.998,889.527 398.007,889.55 398.016,889.572 398.025,889.594 398.034,889.616 398.044,889.639 398.053,889.661 398.062,889.683 398.071,889.706 398.08,889.728 398.09,889.75 398.099,889.772 398.108,889.795 398.117,889.817 398.126,889.839 398.135,889.862 398.145,889.884 398.154,889.906 398.163,889.929 398.172,889.951 398.181,889.973 398.191,889.996 398.2,890.018 398.209,890.04 398.218,890.063 398.227,890.085 398.237,890.108 398.246,890.13 398.255,890.152 398.264,890.175 398.273,890.197 398.282,890.22 398.292,890.242 398.301,890.264 398.31,890.287 398.319,890.309 398.328,890.332 398.338,890.354 398.347,890.377 398.356,890.399 398.365,890.422 398.374,890.444 398.384,890.467 398.393,890.489 398.402,890.512 398.411,890.534 398.42,890.557 398.43,890.579 398.439,890.602 398.448,890.624 398.457,890.647 398.466,890.669 398.475,890.692 398.485,890.714 398.494,890.737 398.503,890.759 398.512,890.782 398.521,890.804 398.531,890.827 398.54,890.85 398.549,890.872 398.558,890.895 398.567,890.917 398.577,890.94 398.586,890.963 398.595,890.985 398.604,891.008 398.613,891.03 398.622,891.053 398.632,891.076 398.641,891.098 398.65,891.121 398.659,891.144 398.668,891.166 398.678,891.189 398.687,891.212 398.696,891.234 398.705,891.257 398.714,891.28 398.724,891.302 398.733,891.325 398.742,891.348 398.751,891.371 398.76,891.393 398.77,891.416 398.779,891.439 398.788,891.461 398.797,891.484 398.806,891.507 398.815,891.53 398.825,891.552 398.834,891.575 398.843,891.598 398.852,891.621 398.861,891.644 398.871,891.666 398.88,891.689 398.889,891.712 398.898,891.735 398.907,891.758 398.917,891.78 398.926,891.803 398.935,891.826 398.944,891.849 398.953,891.872 398.962,891.895 398.972,891.917 398.981,891.94 398.99,891.963 398.999,891.986 399.008,892.009 399.018,892.032 399.027,892.055 399.036,892.078 399.045,892.1 399.054,892.123 399.064,892.146 399.073,892.169 399.082,892.192 399.091,892.215 399.1,892.238 399.11,892.261 399.119,892.284 399.128,892.307 399.137,892.33 399.146,892.353 399.155,892.376 399.165,892.399 399.174,892.422 399.183,892.445 399.192,892.468 399.201,892.491 399.211,892.514 399.22,892.537 399.229,892.56 399.238,892.583 399.247,892.606 399.257,892.629 399.266,892.652 399.275,892.675 399.284,892.698 399.293,892.721 399.302,892.744 399.312,892.767 399.321,892.79 399.33,892.813 399.339,892.836 399.348,892.859 399.358,892.882 399.367,892.905 399.376,892.928 399.385,892.951 399.394,892.975 399.404,892.998 399.413,893.021 399.422,893.044 399.431,893.067 399.44,893.09 399.45,893.113 399.459,893.137 399.468,893.16 399.477,893.183 399.486,893.206 399.495,893.229 399.505,893.252 399.514,893.276 399.523,893.299 399.532,893.322 399.541,893.345 399.551,893.368 399.56,893.391 399.569,893.415 399.578,893.438 399.587,893.461 399.597,893.484 399.606,893.508 399.615,893.531 399.624,893.554 399.633,893.577 399.642,893.601 399.652,893.624 399.661,893.647 399.67,893.67 399.679,893.694 399.688,893.717 399.698,893.74 399.707,893.764 399.716,893.787 399.725,893.81 399.734,893.833 399.744,893.857 399.753,893.88 399.762,893.903 399.771,893.927 399.78,893.95 399.79,893.973 399.799,893.997 399.808,894.02 399.817,894.043 399.826,894.067 399.835,894.09 399.845,894.114 399.854,894.137 399.863,894.16 399.872,894.184 399.881,894.207 399.891,894.23 399.9,894.254 399.909,894.277 399.918,894.301 399.927,894.324 399.937,894.348 399.946,894.371 399.955,894.394 399.964,894.418 399.973,894.441 399.982,894.465 399.992,894.488 400.001,894.512 400.01,894.535 400.019,894.559 400.028,894.582 400.038,894.606 400.047,894.629 400.056,894.653 400.065,894.676 400.074,894.7 400.084,894.723 400.093,894.747 400.102,894.77 400.111,894.794 400.12,894.817 400.13,894.841 400.139,894.864 400.148,894.888 400.157,894.911 400.166,894.935 400.175,894.958 400.185,894.982 400.194,895.006 400.203,895.029 400.212,895.053 400.221,895.076 400.231,895.1 400.24,895.124 400.249,895.147 400.258,895.171 400.267,895.194 400.277,895.218 400.286,895.242 400.295,895.265 400.304,895.289 400.313,895.312 400.322,895.336 400.332,895.36 400.341,895.383 400.35,895.407 400.359,895.431 400.368,895.454 400.378,895.478 400.387,895.502 400.396,895.525 400.405,895.549 400.414,895.573 400.424,895.597 400.433,895.62 400.442,895.644 400.451,895.668 400.46,895.691 400.47,895.715 400.479,895.739 400.488,895.763 400.497,895.786 400.506,895.81 400.515,895.834 400.525,895.858 400.534,895.881 400.543,895.905 400.552,895.929 400.561,895.953 400.571,895.976 400.58,896 400.589,896.024 400.598,896.048 400.607,896.072 400.617,896.095 400.626,896.119 400.635,896.143 400.644,896.167 400.653,896.191 400.663,896.215 400.672,896.238 400.681,896.262 400.69,896.286 400.699,896.31 400.708,896.334 400.718,896.358 400.727,896.381 400.736,896.405 400.745,896.429 400.754,896.453 400.764,896.477 400.773,896.501 400.782,896.525 400.791,896.549 400.8,896.573 400.81,896.597 400.819,896.62 400.828,896.644 400.837,896.668 400.846,896.692 400.855,896.716 400.865,896.74 400.874,896.764 400.883,896.788 400.892,896.812 400.901,896.836 400.911,896.86 400.92,896.884 400.929,896.908 400.938,896.932 400.947,896.956 400.957,896.98 400.966,897.004 400.975,897.028 400.984,897.052 400.993,897.076 401.003,897.1 401.012,897.124 401.021,897.148 401.03,897.172 401.039,897.196 401.048,897.22 401.058,897.244 401.067,897.268 401.076,897.292 401.085,897.316 401.094,897.34 401.104,897.364 401.113,897.388 401.122,897.412 401.131,897.436 401.14,897.461 401.15,897.485 401.159,897.509 401.168,897.533 401.177,897.557 401.186,897.581 401.195,897.605 401.205,897.629 401.214,897.653 401.223,897.678 401.232,897.702 401.241,897.726 401.251,897.75 401.26,897.774 401.269,897.798 401.278,897.822 401.287,897.847 401.297,897.871 401.306,897.895 401.315,897.919 401.324,897.943 401.333,897.968 401.343,897.992 401.352,898.016 401.361,898.04 401.37,898.064 401.379,898.089 401.388,898.113 401.398,898.137 401.407,898.161 401.416,898.185 401.425,898.21 401.434,898.234 401.444,898.258 401.453,898.282 401.462,898.307 401.471,898.331 401.48,898.355 401.49,898.379 401.499,898.404 401.508,898.428 401.517,898.452 401.526,898.477 401.535,898.501 401.545,898.525 401.554,898.549 401.563,898.574 401.572,898.598 401.581,898.622 401.591,898.647 401.6,898.671 401.609,898.695 401.618,898.72 401.627,898.744 401.637,898.768 401.646,898.793 401.655,898.817 401.664,898.841 401.673,898.866 401.683,898.89 401.692,898.914 401.701,898.939 401.71,898.963 401.719,898.988 401.728,899.012 401.738,899.036 401.747,899.061 401.756,899.085 401.765,899.11 401.774,899.134 401.784,899.158 401.793,899.183 401.802,899.207 401.811,899.232 401.82,899.256 401.83,899.281 401.839,899.305 401.848,899.329 401.857,899.354 401.866,899.378 401.875,899.403 401.885,899.427 401.894,899.452 401.903,899.476 401.912,899.501 401.921,899.525 401.931,899.55 401.94,899.574 401.949,899.599 401.958,899.623 401.967,899.648 401.977,899.672 401.986,899.697 401.995,899.721 402.004,899.746 402.013,899.77 402.023,899.795 402.032,899.819 402.041,899.844 402.05,899.868 402.059,899.893 402.068,899.918 402.078,899.942 402.087,899.967 402.096,899.991 402.105,900.016 402.114,900.04 402.124,900.065 402.133,900.09 402.142,900.114 402.151,900.139 402.16,900.163 402.17,900.188 402.179,900.213 402.188,900.237 402.197,900.262 402.206,900.286 402.215,900.311 402.225,900.336 402.234,900.36 402.243,900.385 402.252,900.41 402.261,900.434 402.271,900.459 402.28,900.484 402.289,900.508 402.298,900.533 402.307,900.558 402.317,900.582 402.326,900.607 402.335,900.632 402.344,900.656 402.353,900.681 402.363,900.706 402.372,900.73 402.381,900.755 402.39,900.78 402.399,900.805 402.408,900.829 402.418,900.854 402.427,900.879 402.436,900.903 402.445,900.928 402.454,900.953 402.464,900.978 402.473,901.002 402.482,901.027 402.491,901.052 402.5,901.077 402.51,901.102 402.519,901.126 402.528,901.151 402.537,901.176 402.546,901.201 402.555,901.225 402.565,901.25 402.574,901.275 402.583,901.3 402.592,901.325 402.601,901.349 402.611,901.374 402.62,901.399 402.629,901.424 402.638,901.449 402.647,901.474 402.657,901.498 402.666,901.523 402.675,901.548 402.684,901.573 402.693,901.598 402.703,901.623 402.712,901.647 402.721,901.672 402.73,901.697 402.739,901.722 402.748,901.747 402.758,901.772 402.767,901.797 402.776,901.822 402.785,901.847 402.794,901.871 402.804,901.896 402.813,901.921 402.822,901.946 402.831,901.971 402.84,901.996 402.85,902.021 402.859,902.046 402.868,902.071 402.877,902.096 402.886,902.121 402.895,902.146 402.905,902.171 402.914,902.196 402.923,902.22 402.932,902.245 402.941,902.27 402.951,902.295 402.96,902.32 402.969,902.345 402.978,902.37 402.987,902.395 402.997,902.42 403.006,902.445 403.015,902.47 403.024,902.495 403.033,902.52 403.043,902.545 403.052,902.57 403.061,902.595 403.07,902.62 403.079,902.645 403.088,902.67 403.098,902.696 403.107,902.721 403.116,902.746 403.125,902.771 403.134,902.796 403.144,902.821 403.153,902.846 403.162,902.871 403.171,902.896 403.18,902.921 403.19,902.946 403.199,902.971 403.208,902.996 403.217,903.021 403.226,903.046 403.236,903.072 403.245,903.097 403.254,903.122 403.263,903.147 403.272,903.172 403.281,903.197 403.291,903.222 403.3,903.247 403.309,903.273 403.318,903.298 403.327,903.323 403.337,903.348 403.346,903.373 403.355,903.398 403.364,903.423 403.373,903.449 403.383,903.474 403.392,903.499 403.401,903.524 403.41,903.549 403.419,903.574 403.428,903.6 403.438,903.625 403.447,903.65 403.456,903.675 403.465,903.7 403.474,903.726 403.484,903.751 403.493,903.776 403.502,903.801 403.511,903.826 403.52,903.852 403.53,903.877 403.539,903.902 403.548,903.927 403.557,903.953 403.566,903.978 403.576,904.003 403.585,904.028 403.594,904.054 403.603,904.079 403.612,904.104 403.621,904.129 403.631,904.155 403.64,904.18 403.649,904.205 403.658,904.231 403.667,904.256 403.677,904.281 403.686,904.306 403.695,904.332 403.704,904.357 403.713,904.382 403.723,904.408 403.732,904.433 403.741,904.458 403.75,904.484 403.759,904.509 403.768,904.534 403.778,904.56 403.787,904.585 403.796,904.61 403.805,904.636 403.814,904.661 403.824,904.686 403.833,904.712 403.842,904.737 403.851,904.762 403.86,904.788 403.87,904.813 403.879,904.838 403.888,904.864 403.897,904.889 403.906,904.915 403.916,904.94 403.925,904.965 403.934,904.991 403.943,905.016 403.952,905.042 403.961,905.067 403.971,905.092 403.98,905.118 403.989,905.143 403.998,905.169 404.007,905.194 404.017,905.22 404.026,905.245 404.035,905.27 404.044,905.296 404.053,905.321 404.063,905.347 404.072,905.372 404.081,905.398 404.09,905.423 404.099,905.449 404.108,905.474 404.118,905.5 404.127,905.525 404.136,905.551 404.145,905.576 404.154,905.602 404.164,905.627 404.173,905.653 404.182,905.678 404.191,905.704 404.2,905.729 404.21,905.755 404.219,905.78 404.228,905.806 404.237,905.831 404.246,905.857 404.256,905.882 404.265,905.908 404.274,905.933 404.283,905.959 404.292,905.984 404.301,906.01 404.311,906.036 404.32,906.061 404.329,906.087 404.338,906.112 404.347,906.138 404.357,906.163 404.366,906.189 404.375,906.215 404.384,906.24 404.393,906.266 404.403,906.291 404.412,906.317 404.421,906.342 404.43,906.368 404.439,906.394 404.448,906.419 404.458,906.445 404.467,906.471 404.476,906.496 404.485,906.522 404.494,906.547 404.504,906.573 404.513,906.599 404.522,906.624 404.531,906.65 404.54,906.676 404.55,906.701 404.559,906.727 404.568,906.753 404.577,906.778 404.586,906.804 404.596,906.83 404.605,906.855 404.614,906.881 404.623,906.907 404.632,906.932 404.641,906.958 404.651,906.984 404.66,907.009 404.669,907.035 404.678,907.061 404.687,907.086 404.697,907.112 404.706,907.138 404.715,907.164 404.724,907.189 404.733,907.215 404.743,907.241 404.752,907.267 404.761,907.292 404.77,907.318 404.779,907.344 404.788,907.369 404.798,907.395 404.807,907.421 404.816,907.447 404.825,907.472 404.834,907.498 404.844,907.524 404.853,907.55 404.862,907.576 404.871,907.601 404.88,907.627 404.89,907.653 404.899,907.679 404.908,907.704 404.917,907.73 404.926,907.756 404.936,907.782 404.945,907.808 404.954,907.833 404.963,907.859 404.972,907.885 404.981,907.911 404.991,907.937 405,907.963 405.009,907.988 405.018,908.014 405.027,908.04 405.037,908.066 405.046,908.092 405.055,908.118 405.064,908.143 405.073,908.169 405.083,908.195 405.092,908.221 405.101,908.247 405.11,908.273 405.119,908.299 405.128,908.325 405.138,908.35 405.147,908.376 405.156,908.402 405.165,908.428 405.174,908.454 405.184,908.48 405.193,908.506 405.202,908.532 405.211,908.558 405.22,908.583 405.23,908.609 405.239,908.635 405.248,908.661 405.257,908.687 405.266,908.713 405.276,908.739 405.285,908.765 405.294,908.791 405.303,908.817 405.312,908.843 405.321,908.869 405.331,908.895 405.34,908.921 405.349,908.947 405.358,908.973 405.367,908.998 405.377,909.024 405.386,909.05 405.395,909.076 405.404,909.102 405.413,909.128 405.423,909.154 405.432,909.18 405.441,909.206 405.45,909.232 405.459,909.258 405.469,909.284 405.478,909.31 405.487,909.336 405.496,909.362 405.505,909.388 405.514,909.414 405.524,909.44 405.533,909.466 405.542,909.492 405.551,909.518 405.56,909.545 405.57,909.571 405.579,909.597 405.588,909.623 405.597,909.649 405.606,909.675 405.616,909.701 405.625,909.727 405.634,909.753 405.643,909.779 405.652,909.805 405.661,909.831 405.671,909.857 405.68,909.883 405.689,909.909 405.698,909.935 405.707,909.962 405.717,909.988 405.726,910.014 405.735,910.04 405.744,910.066 405.753,910.092 405.763,910.118 405.772,910.144 405.781,910.17 405.79,910.196 405.799,910.223 405.809,910.249 405.818,910.275 405.827,910.301 405.836,910.327 405.845,910.353 405.854,910.379 405.864,910.405 405.873,910.432 405.882,910.458 405.891,910.484 405.9,910.51 405.91,910.536 405.919,910.562 405.928,910.589 405.937,910.615 405.946,910.641 405.956,910.667 405.965,910.693 405.974,910.719 405.983,910.746 405.992,910.772 406.001,910.798 406.011,910.824 406.02,910.85 406.029,910.877 406.038,910.903 406.047,910.929 406.057,910.955 406.066,910.981 406.075,911.008 406.084,911.034 406.093,911.06 406.103,911.086 406.112,911.113 406.121,911.139 406.13,911.165 406.139,911.191 406.149,911.218 406.158,911.244 406.167,911.27 406.176,911.296 406.185,911.322 406.194,911.349 406.204,911.375 406.213,911.401 406.222,911.428 406.231,911.454 406.24,911.48 406.25,911.506 406.259,911.533 406.268,911.559 406.277,911.585 406.286,911.612 406.296,911.638 406.305,911.664 406.314,911.69 406.323,911.717 406.332,911.743 406.341,911.769 406.351,911.796 406.36,911.822 406.369,911.848 406.378,911.875 406.387,911.901 406.397,911.927 406.406,911.954 406.415,911.98 406.424,912.006 406.433,912.033 406.443,912.059 406.452,912.085 406.461,912.112 406.47,912.138 406.479,912.164 406.489,912.191 406.498,912.217 406.507,912.243 406.516,912.27 406.525,912.296 406.534,912.322 406.544,912.349 406.553,912.375 406.562,912.402 406.571,912.428 406.58,912.454 406.59,912.481 406.599,912.507 406.608,912.534 406.617,912.56 406.626,912.586 406.636,912.613 406.645,912.639 406.654,912.666 406.663,912.692 406.672,912.718 406.681,912.745 406.691,912.771 406.7,912.798 406.709,912.824 406.718,912.851 406.727,912.877 406.737,912.903 406.746,912.93 406.755,912.956 406.764,912.983 406.773,913.009 406.783,913.036 406.792,913.062 406.801,913.089 406.81,913.115 406.819,913.141 406.829,913.168 406.838,913.194 406.847,913.221 406.856,913.247 406.865,913.274 406.874,913.3 406.884,913.327 406.893,913.353 406.902,913.38 406.911,913.406 406.92,913.433 406.93,913.459 406.939,913.486 406.948,913.512 406.957,913.539 406.966,913.565 406.976,913.592 406.985,913.618 406.994,913.645 407.003,913.671 407.012,913.698 407.021,913.724 407.031,913.751 407.04,913.777 407.049,913.804 407.058,913.831 407.067,913.857 407.077,913.884 407.086,913.91 407.095,913.937 407.104,913.963 407.113,913.99 407.123,914.016 407.132,914.043 407.141,914.07 407.15,914.096 407.159,914.123 407.169,914.149 407.178,914.176 407.187,914.202 407.196,914.229 407.205,914.256 407.214,914.282 407.224,914.309 407.233,914.335 407.242,914.362 407.251,914.389 407.26,914.415 407.27,914.442 407.279,914.468 407.288,914.495 407.297,914.522 407.306,914.548 407.316,914.575 407.325,914.601 407.334,914.628 407.343,914.655 407.352,914.681 407.361,914.708 407.371,914.735 407.38,914.761 407.389,914.788 407.398,914.815 407.407,914.841 407.417,914.868 407.426,914.895 407.435,914.921 407.444,914.948 407.453,914.974 407.463,915.001 407.472,915.028 407.481,915.054 407.49,915.081 407.499,915.108 407.509,915.135 407.518,915.161 407.527,915.188 407.536,915.215 407.545,915.241 407.554,915.268 407.564,915.295 407.573,915.321 407.582,915.348 407.591,915.375 407.6,915.401 407.61,915.428 407.619,915.455 407.628,915.482 407.637,915.508 407.646,915.535 407.656,915.562 407.665,915.588 407.674,915.615 407.683,915.642 407.692,915.669 407.701,915.695 407.711,915.722 407.72,915.749 407.729,915.776 407.738,915.802 407.747,915.829 407.757,915.856 407.766,915.883 407.775,915.909 407.784,915.936 407.793,915.963 407.803,915.99 407.812,916.016 407.821,916.043 407.83,916.07 407.839,916.097 407.849,916.124 407.858,916.15 407.867,916.177 407.876,916.204 407.885,916.231 407.894,916.257 407.904,916.284 407.913,916.311 407.922,916.338 407.931,916.365 407.94,916.391 407.95,916.418 407.959,916.445 407.968,916.472 407.977,916.499 407.986,916.526 407.996,916.552 408.005,916.579 408.014,916.606 408.023,916.633 408.032,916.66 408.042,916.686 408.051,916.713 408.06,916.74 408.069,916.767 408.078,916.794 408.087,916.821 408.097,916.848 408.106,916.874 408.115,916.901 408.124,916.928 408.133,916.955 408.143,916.982 408.152,917.009 408.161,917.036 408.17,917.062 408.179,917.089 408.189,917.116 408.198,917.143 408.207,917.17 408.216,917.197 408.225,917.224 408.234,917.251 408.244,917.277 408.253,917.304 408.262,917.331 408.271,917.358 408.28,917.385 408.29,917.412 408.299,917.439 408.308,917.466 408.317,917.493 408.326,917.52 408.336,917.547 408.345,917.573 408.354,917.6 408.363,917.627 408.372,917.654 408.382,917.681 408.391,917.708 408.4,917.735 408.409,917.762 408.418,917.789 408.427,917.816 408.437,917.843 408.446,917.87 408.455,917.897 408.464,917.924 408.473,917.951 408.483,917.978 408.492,918.004 408.501,918.031 408.51,918.058 408.519,918.085 408.529,918.112 408.538,918.139 408.547,918.166 408.556,918.193 408.565,918.22 408.574,918.247 408.584,918.274 408.593,918.301 408.602,918.328 408.611,918.355 408.62,918.382 408.63,918.409 408.639,918.436 408.648,918.463 408.657,918.49 408.666,918.517 408.676,918.544 408.685,918.571 408.694,918.598 408.703,918.625 408.712,918.652 408.722,918.679 408.731,918.706 408.74,918.733 408.749,918.76 408.758,918.787 408.767,918.814 408.777,918.841 408.786,918.868 408.795,918.896 408.804,918.923 408.813,918.95 408.823,918.977 408.832,919.004 408.841,919.031 408.85,919.058 408.859,919.085 408.869,919.112 408.878,919.139 408.887,919.166 408.896,919.193 408.905,919.22 408.914,919.247 408.924,919.274 408.933,919.301 408.942,919.328 408.951,919.356 408.96,919.383 408.97,919.41 408.979,919.437 408.988,919.464 408.997,919.491 409.006,919.518 409.016,919.545 409.025,919.572 409.034,919.599 409.043,919.626 409.052,919.654 409.062,919.681 409.071,919.708 409.08,919.735 409.089,919.762 409.098,919.789 409.107,919.816 409.117,919.843 409.126,919.871 409.135,919.898 409.144,919.925 409.153,919.952 409.163,919.979 409.172,920.006 409.181,920.033 409.19,920.06 409.199,920.088 409.209,920.115 409.218,920.142 409.227,920.169 409.236,920.196 409.245,920.223 409.254,920.251 409.264,920.278 409.273,920.305 409.282,920.332 409.291,920.359 409.3,920.386 409.31,920.413 409.319,920.441 409.328,920.468 409.337,920.495 409.346,920.522 409.356,920.549 409.365,920.577 409.374,920.604 409.383,920.631 409.392,920.658 409.402,920.685 409.411,920.713 409.42,920.74 409.429,920.767 409.438,920.794 409.447,920.821 409.457,920.849 409.466,920.876 409.475,920.903 409.484,920.93 409.493,920.957 409.503,920.985 409.512,921.012 409.521,921.039 409.53,921.066 409.539,921.093 409.549,921.121 409.558,921.148 409.567,921.175 409.576,921.202 409.585,921.23 409.594,921.257 409.604,921.284 409.613,921.311 409.622,921.339 409.631,921.366 409.64,921.393 409.65,921.42 409.659,921.448 409.668,921.475 409.677,921.502 409.686,921.529 409.696,921.557 409.705,921.584 409.714,921.611 409.723,921.638 409.732,921.666 409.742,921.693 409.751,921.72 409.76,921.748 409.769,921.775 409.778,921.802 409.787,921.829 409.797,921.857 409.806,921.884 409.815,921.911 409.824,921.939 409.833,921.966 409.843,921.993 409.852,922.021 409.861,922.048 409.87,922.075 409.879,922.102 409.889,922.13 409.898,922.157 409.907,922.184 409.916,922.212 409.925,922.239 409.934,922.266 409.944,922.294 409.953,922.321 409.962,922.348 409.971,922.376 409.98,922.403 409.99,922.43 409.999,922.458 410.008,922.485 410.017,922.512 410.026,922.54 410.036,922.567 410.045,922.594 410.054,922.622 410.063,922.649 410.072,922.676 410.082,922.704 410.091,922.731 410.1,922.758 410.109,922.786 410.118,922.813 410.127,922.841 410.137,922.868 410.146,922.895 410.155,922.923 410.164,922.95 410.173,922.977 410.183,923.005 410.192,923.032 410.201,923.059 410.21,923.087 410.219,923.114 410.229,923.142 410.238,923.169 410.247,923.196 410.256,923.224 410.265,923.251 410.274,923.279 410.284,923.306 410.293,923.333 410.302,923.361 410.311,923.388 410.32,923.416 410.33,923.443 410.339,923.47 410.348,923.498 410.357,923.525 410.366,923.553 410.376,923.58 410.385,923.608 410.394,923.635 410.403,923.662 410.412,923.69 410.422,923.717 410.431,923.745 410.44,923.772 410.449,923.8 410.458,923.827 410.467,923.854 410.477,923.882 410.486,923.909 410.495,923.937 410.504,923.964 410.513,923.992 410.523,924.019 410.532,924.047 410.541,924.074 410.55,924.101 410.559,924.129 410.569,924.156 410.578,924.184 410.587,924.211 410.596,924.239 410.605,924.266 410.615,924.294 410.624,924.321 410.633,924.349 410.642,924.376 410.651,924.404 410.66,924.431 410.67,924.459 410.679,924.486 410.688,924.514 410.697,924.541 410.706,924.568 410.716,924.596 410.725,924.623 410.734,924.651 410.743,924.678 410.752,924.706 410.762,924.733 410.771,924.761 410.78,924.788 410.789,924.816 410.798,924.843 410.807,924.871 410.817,924.899 410.826,924.926 410.835,924.954 410.844,924.981 410.853,925.009 410.863,925.036 410.872,925.064 410.881,925.091 410.89,925.119 410.899,925.146 410.909,925.174 410.918,925.201 410.927,925.229 410.936,925.256 410.945,925.284 410.955,925.311 410.964,925.339 410.973,925.367 410.982,925.394 410.991,925.422 411,925.449 411.01,925.477 411.019,925.504 411.028,925.532 411.037,925.559 411.046,925.587 411.056,925.614 411.065,925.642 411.074,925.67 411.083,925.697 411.092,925.725 411.102,925.752 411.111,925.78 411.12,925.807 411.129,925.835 411.138,925.863 411.147,925.89 411.157,925.918 411.166,925.945 411.175,925.973 411.184,926.001 411.193,926.028 411.203,926.056 411.212,926.083 411.221,926.111 411.23,926.139 411.239,926.166 411.249,926.194 411.258,926.221 411.267,926.249 411.276,926.277 411.285,926.304 411.295,926.332 411.304,926.359 411.313,926.387 411.322,926.415 411.331,926.442 411.34,926.47 411.35,926.497 411.359,926.525 411.368,926.553 411.377,926.58 411.386,926.608 411.396,926.636 411.405,926.663 411.414,926.691 411.423,926.718 411.432,926.746 411.442,926.774 411.451,926.801 411.46,926.829 411.469,926.857 411.478,926.884 411.487,926.912 411.497,926.94 411.506,926.967 411.515,926.995 411.524,927.023 411.533,927.05 411.543,927.078 411.552,927.105 411.561,927.133 411.57,927.161 411.579,927.188 411.589,927.216 411.598,927.244 411.607,927.271 411.616,927.299 411.625,927.327 411.635,927.354 411.644,927.382 411.653,927.41 411.662,927.437 411.671,927.465 411.68,927.493 411.69,927.521 411.699,927.548 411.708,927.576 411.717,927.604 411.726,927.631 411.736,927.659 411.745,927.687 411.754,927.714 411.763,927.742 411.772,927.77 411.782,927.797 411.791,927.825 411.8,927.853 411.809,927.881 411.818,927.908 411.827,927.936 411.837,927.964 411.846,927.991 411.855,928.019 411.864,928.047 411.873,928.075 411.883,928.102 411.892,928.13 411.901,928.158 411.91,928.185 411.919,928.213 411.929,928.241 411.938,928.269 411.947,928.296 411.956,928.324 411.965,928.352 411.975,928.38 411.984,928.407 411.993,928.435 412.002,928.463 412.011,928.49 412.02,928.518 412.03,928.546 412.039,928.574 412.048,928.601 412.057,928.629 412.066,928.657 412.076,928.685 412.085,928.712 412.094,928.74 412.103,928.768 412.112,928.796 412.122,928.824 412.131,928.851 412.14,928.879 412.149,928.907 412.158,928.935 412.167,928.962 412.177,928.99 412.186,929.018 412.195,929.046 412.204,929.073 412.213,929.101 412.223,929.129 412.232,929.157 412.241,929.185 412.25,929.212 412.259,929.24 412.269,929.268 412.278,929.296 412.287,929.323 412.296,929.351 412.305,929.379 412.315,929.407 412.324,929.435 412.333,929.462 412.342,929.49 412.351,929.518 412.36,929.546 412.37,929.574 412.379,929.601 412.388,929.629 412.397,929.657 412.406,929.685 412.416,929.713 412.425,929.74 412.434,929.768 412.443,929.796 412.452,929.824 412.462,929.852 412.471,929.88 412.48,929.907 412.489,929.935 412.498,929.963 412.507,929.991 412.517,930.019 412.526,930.047 412.535,930.074 412.544,930.102 412.553,930.13 412.563,930.158 412.572,930.186 412.581,930.214 412.59,930.241 412.599,930.269 412.609,930.297 412.618,930.325 412.627,930.353 412.636,930.381 412.645,930.408 412.655,930.436 412.664,930.464 412.673,930.492 412.682,930.52 412.691,930.548 412.7,930.576 412.71,930.603 412.719,930.631 412.728,930.659 412.737,930.687 412.746,930.715 412.756,930.743 412.765,930.771 412.774,930.798 412.783,930.826 412.792,930.854 412.802,930.882 412.811,930.91 412.82,930.938 412.829,930.966 412.838,930.994 412.847,931.021 412.857,931.049 412.866,931.077 412.875,931.105 412.884,931.133 412.893,931.161 412.903,931.189 412.912,931.217 412.921,931.245 412.93,931.272 412.939,931.3 412.949,931.328 412.958,931.356 412.967,931.384 412.976,931.412 412.985,931.44 412.995,931.468 413.004,931.496 413.013,931.524 413.022,931.551 413.031,931.579 413.04,931.607 413.05,931.635 413.059,931.663 413.068,931.691 413.077,931.719 413.086,931.747 413.096,931.775 413.105,931.803 413.114,931.831 413.123,931.859 413.132,931.886 413.142,931.914 413.151,931.942 413.16,931.97 413.169,931.998 413.178,932.026 413.188,932.054 413.197,932.082 413.206,932.11 413.215,932.138 413.224,932.166 413.233,932.194 413.243,932.222 413.252,932.25 413.261,932.278 413.27,932.305 413.279,932.333 413.289,932.361 413.298,932.389 413.307,932.417 413.316,932.445 413.325,932.473 413.335,932.501 413.344,932.529 413.353,932.557 413.362,932.585 413.371,932.613 413.38,932.641 413.39,932.669 413.399,932.697 413.408,932.725 413.417,932.753 413.426,932.781 413.436,932.809 413.445,932.837 413.454,932.865 413.463,932.893 413.472,932.921 413.482,932.949 413.491,932.977 413.5,933.005 413.509,933.032 413.518,933.06 413.528,933.088 413.537,933.116 413.546,933.144 413.555,933.172 413.564,933.2 413.573,933.228 413.583,933.256 413.592,933.284 413.601,933.312 413.61,933.34 413.619,933.368 413.629,933.396 413.638,933.424 413.647,933.452 413.656,933.48 413.665,933.508 413.675,933.536 413.684,933.564 413.693,933.592 413.702,933.62 413.711,933.648 413.72,933.676 413.73,933.704 413.739,933.732 413.748,933.76 413.757,933.788 413.766,933.816 413.776,933.844 413.785,933.872 413.794,933.9 413.803,933.928 413.812,933.957 413.822,933.985 413.831,934.013 413.84,934.041 413.849,934.069 413.858,934.097 413.868,934.125 413.877,934.153 413.886,934.181 413.895,934.209 413.904,934.237 413.913,934.265 413.923,934.293 413.932,934.321 413.941,934.349 413.95,934.377 413.959,934.405 413.969,934.433 413.978,934.461 413.987,934.489 413.996,934.517 414.005,934.545 414.015,934.573 414.024,934.601 414.033,934.629 414.042,934.657 414.051,934.685 414.06,934.714 414.07,934.742 414.079,934.77 414.088,934.798 414.097,934.826 414.106,934.854 414.116,934.882 414.125,934.91 414.134,934.938 414.143,934.966 414.152,934.994 414.162,935.022 414.171,935.05 414.18,935.078 414.189,935.106 414.198,935.134 414.208,935.163 414.217,935.191 414.226,935.219 414.235,935.247 414.244,935.275 414.253,935.303 414.263,935.331 414.272,935.359 414.281,935.387 414.29,935.415 414.299,935.443 414.309,935.471 414.318,935.499 414.327,935.528 414.336,935.556 414.345,935.584 414.355,935.612 414.364,935.64 414.373,935.668 414.382,935.696 414.391,935.724 414.4,935.752 414.41,935.78 414.419,935.808 414.428,935.837 414.437,935.865 414.446,935.893 414.456,935.921 414.465,935.949 414.474,935.977 414.483,936.005 414.492,936.033 414.502,936.061 414.511,936.09 414.52,936.118 414.529,936.146 414.538,936.174 414.548,936.202 414.557,936.23 414.566,936.258 414.575,936.286 414.584,936.314 414.593,936.343 414.603,936.371 414.612,936.399 414.621,936.427 414.63,936.455 414.639,936.483 414.649,936.511 414.658,936.539 414.667,936.568 414.676,936.596 414.685,936.624 414.695,936.652 414.704,936.68 414.713,936.708 414.722,936.736 414.731,936.764 414.74,936.793 414.75,936.821 414.759,936.849 414.768,936.877 414.777,936.905 414.786,936.933 414.796,936.961 414.805,936.99 414.814,937.018 414.823,937.046 414.832,937.074 414.842,937.102 414.851,937.13 414.86,937.158 414.869,937.187 414.878,937.215 414.888,937.243 414.897,937.271 414.906,937.299 414.915,937.327 414.924,937.356 414.933,937.384 414.943,937.412 414.952,937.44 414.961,937.468 414.97,937.496 414.979,937.524 414.989,937.553 414.998,937.581 415.007,937.609 415.016,937.637 415.025,937.665 415.035,937.693 415.044,937.722 415.053,937.75 415.062,937.778 415.071,937.806 415.08,937.834 415.09,937.862 415.099,937.891 415.108,937.919 415.117,937.947 415.126,937.975 415.136,938.003 415.145,938.032 415.154,938.06 415.163,938.088 415.172,938.116 415.182,938.144 415.191,938.172 415.2,938.201 415.209,938.229 415.218,938.257 415.228,938.285 415.237,938.313 415.246,938.342 415.255,938.37 415.264,938.398 415.273,938.426 415.283,938.454 415.292,938.483 415.301,938.511 415.31,938.539 415.319,938.567 415.329,938.595 415.338,938.624 415.347,938.652 415.356,938.68 415.365,938.708 415.375,938.736 415.384,938.765 415.393,938.793 415.402,938.821 415.411,938.849 415.421,938.877 415.43,938.906 415.439,938.934 415.448,938.962 415.457,938.99 415.466,939.018 415.476,939.047 415.485,939.075 415.494,939.103 415.503,939.131 415.512,939.16 415.522,939.188 415.531,939.216 415.54,939.244 415.549,939.272 415.558,939.301 415.568,939.329 415.577,939.357 415.586,939.385 415.595,939.414 415.604,939.442 415.613,939.47 415.623,939.498 415.632,939.526 415.641,939.555 415.65,939.583 415.659,939.611 415.669,939.639 415.678,939.668 415.687,939.696 415.696,939.724 415.705,939.752 415.715,939.781 415.724,939.809 415.733,939.837 415.742,939.865 415.751,939.893 415.761,939.922 415.77,939.95 415.779,939.978 415.788,940.006 415.797,940.035 415.806,940.063 415.816,940.091 415.825,940.119 415.834,940.148 415.843,940.176 415.852,940.204 415.862,940.232 415.871,940.261 415.88,940.289 415.889,940.317 415.898,940.345 415.908,940.374 415.917,940.402 415.926,940.43 415.935,940.458 415.944,940.487 415.953,940.515 415.963,940.543 415.972,940.571 415.981,940.6 415.99,940.628 415.999,940.656 416.009,940.685 416.018,940.713 416.027,940.741 416.036,940.769 416.045,940.798 416.055,940.826 416.064,940.854 416.073,940.882 416.082,940.911 416.091,940.939 416.101,940.967 416.11,940.995 416.119,941.024 416.128,941.052 416.137,941.08 416.146,941.109 416.156,941.137 416.165,941.165 416.174,941.193 416.183,941.222 416.192,941.25 416.202,941.278 416.211,941.307 416.22,941.335 416.229,941.363 416.238,941.391 416.248,941.42 416.257,941.448 416.266,941.476 416.275,941.504 416.284,941.533 416.293,941.561 416.303,941.589 416.312,941.618 416.321,941.646 416.33,941.674 416.339,941.703 416.349,941.731 416.358,941.759 416.367,941.787 416.376,941.816 416.385,941.844 416.395,941.872 416.404,941.901 416.413,941.929 416.422,941.957 416.431,941.985 416.441,942.014 416.45,942.042 416.459,942.07 416.468,942.099 416.477,942.127 416.486,942.155 416.496,942.184 416.505,942.212 416.514,942.24 416.523,942.268 416.532,942.297 416.542,942.325 416.551,942.353 416.56,942.382 416.569,942.41 416.578,942.438 416.588,942.467 416.597,942.495 416.606,942.523 416.615,942.552 416.624,942.58 416.633,942.608 416.643,942.637 416.652,942.665 416.661,942.693 416.67,942.721 416.679,942.75 416.689,942.778 416.698,942.806 416.707,942.835 416.716,942.863 416.725,942.891 416.735,942.92 416.744,942.948 416.753,942.976 416.762,943.005 416.771,943.033 416.781,943.061 416.79,943.09 416.799,943.118 416.808,943.146 416.817,943.175 416.826,943.203 416.836,943.231 416.845,943.26 416.854,943.288 416.863,943.316 416.872,943.345 416.882,943.373 416.891,943.401 416.9,943.43 416.909,943.458 416.918,943.486 416.928,943.515 416.937,943.543 416.946,943.571 416.955,943.6 416.964,943.628 416.973,943.656 416.983,943.685 416.992,943.713 417.001,943.741 417.01,943.77 417.019,943.798 417.029,943.826 417.038,943.855 417.047,943.883 417.056,943.911 417.065,943.94 417.075,943.968 417.084,943.996 417.093,944.025 417.102,944.053 417.111,944.081 417.121,944.11 417.13,944.138 417.139,944.166 417.148,944.195 417.157,944.223 417.166,944.252 417.176,944.28 417.185,944.308 417.194,944.337 417.203,944.365 417.212,944.393 417.222,944.422 417.231,944.45 417.24,944.478 417.249,944.507 417.258,944.535 417.268,944.563 417.277,944.592 417.286,944.62 417.295,944.648 417.304,944.677 417.313,944.705 417.323,944.734 417.332,944.762 417.341,944.79 417.35,944.819 417.359,944.847 417.369,944.875 417.378,944.904 417.387,944.932 417.396,944.96 417.405,944.989 417.415,945.017 417.424,945.046 417.433,945.074 417.442,945.102 417.451,945.131 417.461,945.159 417.47,945.187 417.479,945.216 417.488,945.244 417.497,945.273 417.506,945.301 417.516,945.329 417.525,945.358 417.534,945.386 417.543,945.414 417.552,945.443 417.562,945.471 417.571,945.5 417.58,945.528 417.589,945.556 417.598,945.585 417.608,945.613 417.617,945.641 417.626,945.67 417.635,945.698 417.644,945.727 417.653,945.755 417.663,945.783 417.672,945.812 417.681,945.84 417.69,945.868 417.699,945.897 417.709,945.925 417.718,945.954 417.727,945.982 417.736,946.01 417.745,946.039 417.755,946.067 417.764,946.096 417.773,946.124 417.782,946.152 417.791,946.181 417.801,946.209 417.81,946.237 417.819,946.266 417.828,946.294 417.837,946.323 417.846,946.351 417.856,946.379 417.865,946.408 417.874,946.436 417.883,946.465 417.892,946.493 417.902,946.521 417.911,946.55 417.92,946.578 417.929,946.607 417.938,946.635 417.948,946.663 417.957,946.692 417.966,946.72 417.975,946.749 417.984,946.777 417.994,946.805 418.003,946.834 418.012,946.862 418.021,946.891 418.03,946.919 418.039,946.947 418.049,946.976 418.058,947.004 418.067,947.033 418.076,947.061 418.085,947.089 418.095,947.118 418.104,947.146 418.113,947.175 418.122,947.203 418.131,947.231 418.141,947.26 418.15,947.288 418.159,947.317 418.168,947.345 418.177,947.373 418.186,947.402 418.196,947.43 418.205,947.459 418.214,947.487 418.223,947.515 418.232,947.544 418.242,947.572 418.251,947.601 418.26,947.629 418.269,947.657 418.278,947.686 418.288,947.714 418.297,947.743 418.306,947.771 418.315,947.8 418.324,947.828 418.334,947.856 418.343,947.885 418.352,947.913 418.361,947.942 418.37,947.97 418.379,947.998 418.389,948.027 418.398,948.055 418.407,948.084 418.416,948.112 418.425,948.141 418.435,948.169 418.444,948.197 418.453,948.226 418.462,948.254 418.471,948.283 418.481,948.311 418.49,948.339 418.499,948.368 418.508,948.396 418.517,948.425 418.526,948.453 418.536,948.482 418.545,948.51 418.554,948.538 418.563,948.567 418.572,948.595 418.582,948.624 418.591,948.652 418.6,948.681 418.609,948.709 418.618,948.737 418.628,948.766 418.637,948.794 418.646,948.823 418.655,948.851 418.664,948.88 418.674,948.908 418.683,948.936 418.692,948.965 418.701,948.993 418.71,949.022 418.719,949.05 418.729,949.079 418.738,949.107 418.747,949.135 418.756,949.164 418.765,949.192 418.775,949.221 418.784,949.249 418.793,949.278 418.802,949.306 418.811,949.334 418.821,949.363 418.83,949.391 418.839,949.42 418.848,949.448 418.857,949.477 418.866,949.505 418.876,949.533 418.885,949.562 418.894,949.59 418.903,949.619 418.912,949.647 418.922,949.676 418.931,949.704 418.94,949.733 418.949,949.761 418.958,949.789 418.968,949.818 418.977,949.846 418.986,949.875 418.995,949.903 419.004,949.932 419.014,949.96 419.023,949.988 419.032,950.017 419.041,950.045 419.05,950.074 419.059,950.102 419.069,950.131 419.078,950.159 419.087,950.188 419.096,950.216 419.105,950.244 419.115,950.273 419.124,950.301 419.133,950.33 419.142,950.358 419.151,950.387 419.161,950.415 419.17,950.444 419.179,950.472 419.188,950.5 419.197,950.529 419.206,950.557 419.216,950.586 419.225,950.614 419.234,950.643 419.243,950.671 419.252,950.7 419.262,950.728 419.271,950.756 419.28,950.785 419.289,950.813 419.298,950.842 419.308,950.87 419.317,950.899 419.326,950.927 419.335,950.956 419.344,950.984 419.354,951.012 419.363,951.041 419.372,951.069 419.381,951.098 419.39,951.126 419.399,951.155 419.409,951.183 419.418,951.212 419.427,951.24 419.436,951.269 419.445,951.297 419.455,951.325 419.464,951.354 419.473,951.382 419.482,951.411 419.491,951.439 419.501,951.468 419.51,951.496 419.519,951.525 419.528,951.553 419.537,951.582 419.546,951.61 419.556,951.638 419.565,951.667 419.574,951.695 419.583,951.724 419.592,951.752 419.602,951.781 419.611,951.809 419.62,951.838 419.629,951.866 419.638,951.895 419.648,951.923 419.657,951.951 419.666,951.98 419.675,952.008 419.684,952.037 419.694,952.065 419.703,952.094 419.712,952.122 419.721,952.151 419.73,952.179 419.739,952.208 419.749,952.236 419.758,952.264 419.767,952.293 419.776,952.321 419.785,952.35 419.795,952.378 419.804,952.407 419.813,952.435 419.822,952.464 419.831,952.492 419.841,952.521 419.85,952.549 419.859,952.578 419.868,952.606 419.877,952.634 419.886,952.663 419.896,952.691 419.905,952.72 419.914,952.748 419.923,952.777 419.932,952.805 419.942,952.834 419.951,952.862 419.96,952.891 419.969,952.919 419.978,952.948 419.988,952.976 419.997,953.004 420.006,953.033 420.015,953.061 420.024,953.09 420.034,953.118 420.043,953.147 420.052,953.175 420.061,953.204 420.07,953.232 420.079,953.261 420.089,953.289 420.098,953.318 420.107,953.346 420.116,953.374 420.125,953.403 420.135,953.431 420.144,953.46 420.153,953.488 420.162,953.517 420.171,953.545 420.181,953.574 420.19,953.602 420.199,953.631 420.208,953.659 420.217,953.688 420.226,953.716 420.236,953.745 420.245,953.773 420.254,953.801 420.263,953.83 420.272,953.858 420.282,953.887 420.291,953.915 420.3,953.944 420.309,953.972 420.318,954.001 420.328,954.029 420.337,954.058 420.346,954.086 420.355,954.115 420.364,954.143 420.374,954.172 420.383,954.2 420.392,954.228 420.401,954.257 420.41,954.285 420.419,954.314 420.429,954.342 420.438,954.371 420.447,954.399 420.456,954.428 420.465,954.456 420.475,954.485 420.484,954.513 420.493,954.542 420.502,954.57 420.511,954.599 420.521,954.627 420.53,954.655 420.539,954.684 420.548,954.712 420.557,954.741 420.567,954.769 420.576,954.798 420.585,954.826 420.594,954.855 420.603,954.883 420.612,954.912 420.622,954.94 420.631,954.969 420.64,954.997 420.649,955.026 420.658,955.054 420.668,955.082 420.677,955.111 420.686,955.139 420.695,955.168 420.704,955.196 420.714,955.225 420.723,955.253 420.732,955.282 420.741,955.31 420.75,955.339 420.759,955.367 420.769,955.396 420.778,955.424 420.787,955.453 420.796,955.481 420.805,955.51 420.815,955.538 420.824,955.566 420.833,955.595 420.842,955.623 420.851,955.652 420.861,955.68 420.87,955.709 420.879,955.737 420.888,955.766 420.897,955.794 420.907,955.823 420.916,955.851 420.925,955.88 420.934,955.908 420.943,955.937 420.952,955.965 420.962,955.994 420.971,956.022 420.98,956.05 420.989,956.079 420.998,956.107 421.008,956.136 421.017,956.164 421.026,956.193 421.035,956.221 421.044,956.25 421.054,956.278 421.063,956.307 421.072,956.335 421.081,956.364 421.09,956.392 421.099,956.421 421.109,956.449 421.118,956.477 421.127,956.506 421.136,956.534 421.145,956.563 421.155,956.591 421.164,956.62 421.173,956.648 421.182,956.677 421.191,956.705 421.201,956.734 421.21,956.762 421.219,956.791 421.228,956.819 421.237,956.848 421.247,956.876 421.256,956.905 421.265,956.933 421.274,956.961 421.283,956.99 421.292,957.018 421.302,957.047 421.311,957.075 421.32,957.104 421.329,957.132 421.338,957.161 421.348,957.189 421.357,957.218 421.366,957.246 421.375,957.275 421.384,957.303 421.394,957.332 421.403,957.36 421.412,957.388 421.421,957.417 421.43,957.445 421.439,957.474 421.449,957.502 421.458,957.531 421.467,957.559 421.476,957.588 421.485,957.616 421.495,957.645 421.504,957.673 421.513,957.702 421.522,957.73 421.531,957.759 421.541,957.787 421.55,957.816 421.559,957.844 421.568,957.872 421.577,957.901 421.587,957.929 421.596,957.958 421.605,957.986 421.614,958.015 421.623,958.043 421.632,958.072 421.642,958.1 421.651,958.129 421.66,958.157 421.669,958.186 421.678,958.214 421.688,958.243 421.697,958.271 421.706,958.299 421.715,958.328 421.724,958.356 421.734,958.385 421.743,958.413 421.752,958.442 421.761,958.47 421.77,958.499 421.779,958.527 421.789,958.556 421.798,958.584 421.807,958.613 421.816,958.641 421.825,958.669 421.835,958.698 421.844,958.726 421.853,958.755 421.862,958.783 421.871,958.812 421.881,958.84 421.89,958.869 421.899,958.897 421.908,958.926 421.917,958.954 421.927,958.983 421.936,959.011 421.945,959.039 421.954,959.068 421.963,959.096 421.972,959.125 421.982,959.153 421.991,959.182 422,959.21 422.009,959.239 422.018,959.267 422.028,959.296 422.037,959.324 422.046,959.353 422.055,959.381 422.064,959.409 422.074,959.438 422.083,959.466 422.092,959.495 422.101,959.523 422.11,959.552 422.119,959.58 422.129,959.609 422.138,959.637 422.147,959.666 422.156,959.694 422.165,959.723 422.175,959.751 422.184,959.779 422.193,959.808 422.202,959.836 422.211,959.865 422.221,959.893 422.23,959.922 422.239,959.95 422.248,959.979 422.257,960.007 422.267,960.036 422.276,960.064 422.285,960.092 422.294,960.121 422.303,960.149 422.312,960.178 422.322,960.206 422.331,960.235 422.34,960.263 422.349,960.292 422.358,960.32 422.368,960.349 422.377,960.377 422.386,960.405 422.395,960.434 422.404,960.462 422.414,960.491 422.423,960.519 422.432,960.548 422.441,960.576 422.45,960.605 422.459,960.633 422.469,960.662 422.478,960.69 422.487,960.718 422.496,960.747 422.505,960.775 422.515,960.804 422.524,960.832 422.533,960.861 422.542,960.889 422.551,960.918 422.561,960.946 422.57,960.975 422.579,961.003 422.588,961.031 422.597,961.06 422.607,961.088 422.616,961.117 422.625,961.145 422.634,961.174 422.643,961.202 422.652,961.231 422.662,961.259 422.671,961.287 422.68,961.316 422.689,961.344 422.698,961.373 422.708,961.401 422.717,961.43 422.726,961.458 422.735,961.487 422.744,961.515 422.754,961.543 422.763,961.572 422.772,961.6 422.781,961.629 422.79,961.657 422.8,961.686 422.809,961.714 422.818,961.743 422.827,961.771 422.836,961.799 422.845,961.828 422.855,961.856 422.864,961.885 422.873,961.913 422.882,961.942 422.891,961.97 422.901,961.999 422.91,962.027 422.919,962.055 422.928,962.084 422.937,962.112 422.947,962.141 422.956,962.169 422.965,962.198 422.974,962.226 422.983,962.255 422.992,962.283 423.002,962.311 423.011,962.34 423.02,962.368 423.029,962.397 423.038,962.425 423.048,962.454 423.057,962.482 423.066,962.51 423.075,962.539 423.084,962.567 423.094,962.596 423.103,962.624 423.112,962.653 423.121,962.681 423.13,962.71 423.14,962.738 423.149,962.766 423.158,962.795 423.167,962.823 423.176,962.852 423.185,962.88 423.195,962.909 423.204,962.937 423.213,962.965 423.222,962.994 423.231,963.022 423.241,963.051 423.25,963.079 423.259,963.108 423.268,963.136 423.277,963.164 423.287,963.193 423.296,963.221 423.305,963.25 423.314,963.278 423.323,963.307 423.332,963.335 423.342,963.363 423.351,963.392 423.36,963.42 423.369,963.449 423.378,963.477 423.388,963.506 423.397,963.534 423.406,963.562 423.415,963.591 423.424,963.619 423.434,963.648 423.443,963.676 423.452,963.705 423.461,963.733 423.47,963.761 423.48,963.79 423.489,963.818 423.498,963.847 423.507,963.875 423.516,963.903 423.525,963.932 423.535,963.96 423.544,963.989 423.553,964.017 423.562,964.046 423.571,964.074 423.581,964.102 423.59,964.131 423.599,964.159 423.608,964.188 423.617,964.216 423.627,964.245 423.636,964.273 423.645,964.301 423.654,964.33 423.663,964.358 423.672,964.387 423.682,964.415 423.691,964.443 423.7,964.472 423.709,964.5 423.718,964.529 423.728,964.557 423.737,964.585 423.746,964.614 423.755,964.642 423.764,964.671 423.774,964.699 423.783,964.728 423.792,964.756 423.801,964.784 423.81,964.813 423.82,964.841 423.829,964.87 423.838,964.898 423.847,964.926 423.856,964.955 423.865,964.983 423.875,965.012 423.884,965.04 423.893,965.068 423.902,965.097 423.911,965.125 423.921,965.154 423.93,965.182 423.939,965.21 423.948,965.239 423.957,965.267 423.967,965.296 423.976,965.324 423.985,965.352 423.994,965.381 424.003,965.409 424.012,965.438 424.022,965.466 424.031,965.494 424.04,965.523 424.049,965.551 424.058,965.58 424.068,965.608 424.077,965.636 424.086,965.665 424.095,965.693 424.104,965.722 424.114,965.75 424.123,965.778 424.132,965.807 424.141,965.835 424.15,965.864 424.16,965.892 424.169,965.92 424.178,965.949 424.187,965.977 424.196,966.006 424.205,966.034 424.215,966.062 424.224,966.091 424.233,966.119 424.242,966.148 424.251,966.176 424.261,966.204 424.27,966.233 424.279,966.261 424.288,966.29 424.297,966.318 424.307,966.346 424.316,966.375 424.325,966.403 424.334,966.431 424.343,966.46 424.352,966.488 424.362,966.517 424.371,966.545 424.38,966.573 424.389,966.602 424.398,966.63 424.408,966.659 424.417,966.687 424.426,966.715 424.435,966.744 424.444,966.772 424.454,966.8 424.463,966.829 424.472,966.857 424.481,966.886 424.49,966.914 424.5,966.942 424.509,966.971 424.518,966.999 424.527,967.027 424.536,967.056 424.545,967.084 424.555,967.113 424.564,967.141 424.573,967.169 424.582,967.198 424.591,967.226 424.601,967.254 424.61,967.283 424.619,967.311 424.628,967.34 424.637,967.368 424.647,967.396 424.656,967.425 424.665,967.453 424.674,967.481 424.683,967.51 424.692,967.538 424.702,967.567 424.711,967.595 424.72,967.623 424.729,967.652 424.738,967.68 424.748,967.708 424.757,967.737 424.766,967.765 424.775,967.793 424.784,967.822 424.794,967.85 424.803,967.879 424.812,967.907 424.821,967.935 424.83,967.964 424.84,967.992 424.849,968.02 424.858,968.049 424.867,968.077 424.876,968.105 424.885,968.134 424.895,968.162 424.904,968.191 424.913,968.219 424.922,968.247 424.931,968.276 424.941,968.304 424.95,968.332 424.959,968.361 424.968,968.389 424.977,968.417 424.987,968.446 424.996,968.474 425.005,968.502 425.014,968.531 425.023,968.559 425.032,968.587 425.042,968.616 425.051,968.644 425.06,968.673 425.069,968.701 425.078,968.729 425.088,968.758 425.097,968.786 425.106,968.814 425.115,968.843 425.124,968.871 425.134,968.899 425.143,968.928 425.152,968.956 425.161,968.984 425.17,969.013 425.18,969.041 425.189,969.069 425.198,969.098 425.207,969.126 425.216,969.154 425.225,969.183 425.235,969.211 425.244,969.239 425.253,969.268 425.262,969.296 425.271,969.324 425.281,969.353 425.29,969.381 425.299,969.409 425.308,969.438 425.317,969.466 425.327,969.494 425.336,969.523 425.345,969.551 425.354,969.579 425.363,969.608 425.373,969.636 425.382,969.664 425.391,969.693 425.4,969.721 425.409,969.749 425.418,969.778 425.428,969.806 425.437,969.834 425.446,969.863 425.455,969.891 425.464,969.919 425.474,969.948 425.483,969.976 425.492,970.004 425.501,970.033 425.51,970.061 425.52,970.089 425.529,970.118 425.538,970.146 425.547,970.174 425.556,970.203 425.565,970.231 425.575,970.259 425.584,970.288 425.593,970.316 425.602,970.344 425.611,970.372 425.621,970.401 425.63,970.429 425.639,970.457 425.648,970.486 425.657,970.514 425.667,970.542 425.676,970.571 425.685,970.599 425.694,970.627 425.703,970.656 425.713,970.684 425.722,970.712 425.731,970.741 425.74,970.769 425.749,970.797 425.758,970.825 425.768,970.854 425.777,970.882 425.786,970.91 425.795,970.939 425.804,970.967 425.814,970.995 425.823,971.024 425.832,971.052 425.841,971.08 425.85,971.108 425.86,971.137 425.869,971.165 425.878,971.193 425.887,971.222 425.896,971.25 425.905,971.278 425.915,971.307 425.924,971.335 425.933,971.363 425.942,971.391 425.951,971.42 425.961,971.448 425.97,971.476 425.979,971.505 425.988,971.533 425.997,971.561 426.007,971.589 426.016,971.618 426.025,971.646 426.034,971.674 426.043,971.703 426.053,971.731 426.062,971.759 426.071,971.787 426.08,971.816 426.089,971.844 426.098,971.872 426.108,971.901 426.117,971.929 426.126,971.957 426.135,971.985 426.144,972.014 426.154,972.042 426.163,972.07 426.172,972.099 426.181,972.127 426.19,972.155 426.2,972.183 426.209,972.212 426.218,972.24 426.227,972.268 426.236,972.296 426.245,972.325 426.255,972.353 426.264,972.381 426.273,972.41 426.282,972.438 426.291,972.466 426.301,972.494 426.31,972.523 426.319,972.551 426.328,972.579 426.337,972.607 426.347,972.636 426.356,972.664 426.365,972.692 426.374,972.721 426.383,972.749 426.393,972.777 426.402,972.805 426.411,972.834 426.42,972.862 426.429,972.89 426.438,972.918 426.448,972.947 426.457,972.975 426.466,973.003 426.475,973.031 426.484,973.06 426.494,973.088 426.503,973.116 426.512,973.144 426.521,973.173 426.53,973.201 426.54,973.229 426.549,973.257 426.558,973.286 426.567,973.314 426.576,973.342 426.585,973.37 426.595,973.399 426.604,973.427 426.613,973.455 426.622,973.483 426.631,973.512 426.641,973.54 426.65,973.568 426.659,973.596 426.668,973.625 426.677,973.653 426.687,973.681 426.696,973.709 426.705,973.738 426.714,973.766 426.723,973.794 426.733,973.822 426.742,973.851 426.751,973.879 426.76,973.907 426.769,973.935 426.778,973.963 426.788,973.992 426.797,974.02 426.806,974.048 426.815,974.076 426.824,974.105 426.834,974.133 426.843,974.161 426.852,974.189 426.861,974.218 426.87,974.246 426.88,974.274 426.889,974.302 426.898,974.33 426.907,974.359 426.916,974.387 426.925,974.415 426.935,974.443 426.944,974.472 426.953,974.5 426.962,974.528 426.971,974.556 426.981,974.584 426.99,974.613 426.999,974.641 427.008,974.669 427.017,974.697 427.027,974.726 427.036,974.754 427.045,974.782 427.054,974.81 427.063,974.838 427.073,974.867 427.082,974.895 427.091,974.923 427.1,974.951 427.109,974.979 427.118,975.008 427.128,975.036 427.137,975.064 427.146,975.092 427.155,975.12 427.164,975.149 427.174,975.177 427.183,975.205 427.192,975.233 427.201,975.261 427.21,975.29 427.22,975.318 427.229,975.346 427.238,975.374 427.247,975.402 427.256,975.431 427.265,975.459 427.275,975.487 427.284,975.515 427.293,975.543 427.302,975.572 427.311,975.6 427.321,975.628 427.33,975.656 427.339,975.684 427.348,975.713 427.357,975.741 427.367,975.769 427.376,975.797 427.385,975.825 427.394,975.853 427.403,975.882 427.413,975.91 427.422,975.938 427.431,975.966 427.44,975.994 427.449,976.023 427.458,976.051 427.468,976.079 427.477,976.107 427.486,976.135 427.495,976.163 427.504,976.192 427.514,976.22 427.523,976.248 427.532,976.276 427.541,976.304 427.55,976.332 427.56,976.361 427.569,976.389 427.578,976.417 427.587,976.445 427.596,976.473 427.605,976.502 427.615,976.53 427.624,976.558 427.633,976.586 427.642,976.614 427.651,976.642 427.661,976.67 427.67,976.699 427.679,976.727 427.688,976.755 427.697,976.783 427.707,976.811 427.716,976.839 427.725,976.868 427.734,976.896 427.743,976.924 427.753,976.952 427.762,976.98 427.771,977.008 427.78,977.037 427.789,977.065 427.798,977.093 427.808,977.121 427.817,977.149 427.826,977.177 427.835,977.205 427.844,977.234 427.854,977.262 427.863,977.29 427.872,977.318 427.881,977.346 427.89,977.374 427.9,977.402 427.909,977.431 427.918,977.459 427.927,977.487 427.936,977.515 427.946,977.543 427.955,977.571 427.964,977.599 427.973,977.628 427.982,977.656 427.991,977.684 428.001,977.712 428.01,977.74 428.019,977.768 428.028,977.796 428.037,977.824 428.047,977.853 428.056,977.881 428.065,977.909 428.074,977.937 428.083,977.965 428.093,977.993 428.102,978.021 428.111,978.049 428.12,978.078 428.129,978.106 428.138,978.134 428.148,978.162 428.157,978.19 428.166,978.218 428.175,978.246 428.184,978.274 428.194,978.302 428.203,978.331 428.212,978.359 428.221,978.387 428.23,978.415 428.24,978.443 428.249,978.471 428.258,978.499 428.267,978.527 428.276,978.555 428.286,978.584 428.295,978.612 428.304,978.64 428.313,978.668 428.322,978.696 428.331,978.724 428.341,978.752 428.35,978.78 428.359,978.808 428.368,978.837 428.377,978.865 428.387,978.893 428.396,978.921 428.405,978.949 428.414,978.977 428.423,979.005 428.433,979.033 428.442,979.061 428.451,979.089 428.46,979.117 428.469,979.146 428.478,979.174 428.488,979.202 428.497,979.23 428.506,979.258 428.515,979.286 428.524,979.314 428.534,979.342 428.543,979.37 428.552,979.398 428.561,979.426 428.57,979.454 428.58,979.483 428.589,979.511 428.598,979.539 428.607,979.567 428.616,979.595 428.626,979.623 428.635,979.651 428.644,979.679 428.653,979.707 428.662,979.735 428.671,979.763 428.681,979.791 428.69,979.819 428.699,979.847 428.708,979.876 428.717,979.904 428.727,979.932 428.736,979.96 428.745,979.988 428.754,980.016 428.763,980.044 428.773,980.072 428.782,980.1 428.791,980.128 428.8,980.156 428.809,980.184 428.818,980.212 428.828,980.24 428.837,980.268 428.846,980.296 428.855,980.324 428.864,980.353 428.874,980.381 428.883,980.409 428.892,980.437 428.901,980.465 428.91,980.493 428.92,980.521 428.929,980.549 428.938,980.577 428.947,980.605 428.956,980.633 428.966,980.661 428.975,980.689 428.984,980.717 428.993,980.745 429.002,980.773 429.011,980.801 429.021,980.829 429.03,980.857 429.039,980.885 429.048,980.913 429.057,980.941 429.067,980.969 429.076,980.997 429.085,981.025 429.094,981.053 429.103,981.082 429.113,981.11 429.122,981.138 429.131,981.166 429.14,981.194 429.149,981.222 429.158,981.25 429.168,981.278 429.177,981.306 429.186,981.334 429.195,981.362 429.204,981.39 429.214,981.418 429.223,981.446 429.232,981.474 429.241,981.502 429.25,981.53 429.26,981.558 429.269,981.586 429.278,981.614 429.287,981.642 429.296,981.67 429.306,981.698 429.315,981.726 429.324,981.754 429.333,981.782 429.342,981.81 429.351,981.838 429.361,981.866 429.37,981.894 429.379,981.922 429.388,981.95 429.397,981.978 429.407,982.006 429.416,982.034 429.425,982.062 429.434,982.09 429.443,982.118 429.453,982.146 429.462,982.174 429.471,982.202 429.48,982.23 429.489,982.258 429.498,982.286 429.508,982.314 429.517,982.342 429.526,982.37 429.535,982.398 429.544,982.426 429.554,982.454 429.563,982.482 429.572,982.51 429.581,982.538 429.59,982.566 429.6,982.594 429.609,982.622 429.618,982.65 429.627,982.678 429.636,982.705 429.646,982.733 429.655,982.761 429.664,982.789 429.673,982.817 429.682,982.845 429.691,982.873 429.701,982.901 429.71,982.929 429.719,982.957 429.728,982.985 429.737,983.013 429.747,983.041 429.756,983.069 429.765,983.097 429.774,983.125 429.783,983.153 429.793,983.181 429.802,983.209 429.811,983.237 429.82,983.265 429.829,983.293 429.838,983.321 429.848,983.349 429.857,983.377 429.866,983.404 429.875,983.432 429.884,983.46 429.894,983.488 429.903,983.516 429.912,983.544 429.921,983.572 429.93,983.6 429.94,983.628 429.949,983.656 429.958,983.684 429.967,983.712 429.976,983.74 429.986,983.768 429.995,983.796 430.004,983.824 430.013,983.851 430.022,983.879 430.031,983.907 430.041,983.935 430.05,983.963 430.059,983.991 430.068,984.019 430.077,984.047 430.087,984.075 430.096,984.103 430.105,984.131 430.114,984.159 430.123,984.187 430.133,984.215 430.142,984.242 430.151,984.27 430.16,984.298 430.169,984.326 430.179,984.354 430.188,984.382 430.197,984.41 430.206,984.438 430.215,984.466 430.224,984.494 430.234,984.522 430.243,984.549 430.252,984.577 430.261,984.605 430.27,984.633 430.28,984.661 430.289,984.689 430.298,984.717 430.307,984.745 430.316,984.773 430.326,984.801 430.335,984.828 430.344,984.856 430.353,984.884 430.362,984.912 430.371,984.94 430.381,984.968 430.39,984.996 430.399,985.024 430.408,985.052 430.417,985.079 430.427,985.107 430.436,985.135 430.445,985.163 430.454,985.191 430.463,985.219 430.473,985.247 430.482,985.275 430.491,985.303 430.5,985.33 430.509,985.358 430.519,985.386 430.528,985.414 430.537,985.442 430.546,985.47 430.555,985.498 430.564,985.526 430.574,985.553 430.583,985.581 430.592,985.609 430.601,985.637 430.61,985.665 430.62,985.693 430.629,985.721 430.638,985.748 430.647,985.776 430.656,985.804 430.666,985.832 430.675,985.86 430.684,985.888 430.693,985.916 430.702,985.943 430.711,985.971 430.721,985.999 430.73,986.027 430.739,986.055 430.748,986.083 430.757,986.111 430.767,986.138 430.776,986.166 430.785,986.194 430.794,986.222 430.803,986.25 430.813,986.278 430.822,986.305 430.831,986.333 430.84,986.361 430.849,986.389 430.859,986.417 430.868,986.445 430.877,986.472 430.886,986.5 430.895,986.528 430.904,986.556 430.914,986.584 430.923,986.612 430.932,986.639 430.941,986.667 430.95,986.695 430.96,986.723 430.969,986.751 430.978,986.779 430.987,986.806 430.996,986.834 431.006,986.862 431.015,986.89 431.024,986.918 431.033,986.945 431.042,986.973 431.051,987.001 431.061,987.029 431.07,987.057 431.079,987.085 431.088,987.112 431.097,987.14 431.107,987.168 431.116,987.196 431.125,987.224 431.134,987.251 431.143,987.279 431.153,987.307 431.162,987.335 431.171,987.363 431.18,987.39 431.189,987.418 431.199,987.446 431.208,987.474 431.217,987.502 431.226,987.529 431.235,987.557 431.244,987.585 431.254,987.613 431.263,987.641 431.272,987.668 431.281,987.696 431.29,987.724 431.3,987.752 431.309,987.779 431.318,987.807 431.327,987.835 431.336,987.863 431.346,987.891 431.355,987.918 431.364,987.946 431.373,987.974 431.382,988.002 431.391,988.029 431.401,988.057 431.41,988.085 431.419,988.113 431.428,988.141 431.437,988.168 431.447,988.196 431.456,988.224 431.465,988.252 431.474,988.279 431.483,988.307 431.493,988.335 431.502,988.363 431.511,988.39 431.52,988.418 431.529,988.446 431.539,988.474 431.548,988.501 431.557,988.529 431.566,988.557 431.575,988.585 431.584,988.612 431.594,988.64 431.603,988.668 431.612,988.696 431.621,988.723 431.63,988.751 431.64,988.779 431.649,988.807 431.658,988.834 431.667,988.862 431.676,988.89 431.686,988.918 431.695,988.945 431.704,988.973 431.713,989.001 431.722,989.029 431.731,989.056 431.741,989.084 431.75,989.112 431.759,989.139 431.768,989.167 431.777,989.195 431.787,989.223 431.796,989.25 431.805,989.278 431.814,989.306 431.823,989.334 431.833,989.361 431.842,989.389 431.851,989.417 431.86,989.444 431.869,989.472 431.879,989.5 431.888,989.528 431.897,989.555 431.906,989.583 431.915,989.611 431.924,989.638 431.934,989.666 431.943,989.694 431.952,989.721 431.961,989.749 431.97,989.777 431.98,989.805 431.989,989.832 431.998,989.86 432.007,989.888 432.016,989.915 432.026,989.943 432.035,989.971 432.044,989.998 432.053,990.026 432.062,990.054 432.071,990.082 432.081,990.109 432.09,990.137 432.099,990.165 432.108,990.192 432.117,990.22 432.127,990.248 432.136,990.275 432.145,990.303 432.154,990.331 432.163,990.358 432.173,990.386 432.182,990.414 432.191,990.441 432.2,990.469 432.209,990.497 432.219,990.524 432.228,990.552 432.237,990.58 432.246,990.607 432.255,990.635 432.264,990.663 432.274,990.69 432.283,990.718 432.292,990.746 432.301,990.773 432.31,990.801 432.32,990.829 432.329,990.856 432.338,990.884 432.347,990.912 432.356,990.939 432.366,990.967 432.375,990.995 432.384,991.022 432.393,991.05 432.402,991.078 432.411,991.105 432.421,991.133 432.43,991.16 432.439,991.188 432.448,991.216 432.457,991.243 432.467,991.271 432.476,991.299 432.485,991.326 432.494,991.354 432.503,991.382 432.513,991.409 432.522,991.437 432.531,991.464 432.54,991.492 432.549,991.52 432.559,991.547 432.568,991.575 432.577,991.603 432.586,991.63 432.595,991.658 432.604,991.685 432.614,991.713 432.623,991.741 432.632,991.768 432.641,991.796 432.65,991.824 432.66,991.851 432.669,991.879 432.678,991.906 432.687,991.934 432.696,991.962 432.706,991.989 432.715,992.017 432.724,992.044 432.733,992.072 432.742,992.1 432.752,992.127 432.761,992.155 432.77,992.182 432.779,992.21 432.788,992.238 432.797,992.265 432.807,992.293 432.816,992.32 432.825,992.348 432.834,992.376 432.843,992.403 432.853,992.431 432.862,992.458 432.871,992.486 432.88,992.514 432.889,992.541 432.899,992.569 432.908,992.596 432.917,992.624 432.926,992.651 432.935,992.679 432.944,992.707 432.954,992.734 432.963,992.762 432.972,992.789 432.981,992.817 432.99,992.844 433,992.872 433.009,992.9 433.018,992.927 433.027,992.955 433.036,992.982 433.046,993.01 433.055,993.037 433.064,993.065 433.073,993.093 433.082,993.12 433.092,993.148 433.101,993.175 433.11,993.203 433.119,993.23 433.128,993.258 433.137,993.285 433.147,993.313 433.156,993.34 433.165,993.368 433.174,993.396 433.183,993.423 433.193,993.451 433.202,993.478 433.211,993.506 433.22,993.533 433.229,993.561 433.239,993.588 433.248,993.616 433.257,993.643 433.266,993.671 433.275,993.698 433.284,993.726 433.294,993.754 433.303,993.781 433.312,993.809 433.321,993.836 433.33,993.864 433.34,993.891 433.349,993.919 433.358,993.946 433.367,993.974 433.376,994.001 433.386,994.029 433.395,994.056 433.404,994.084 433.413,994.111 433.422,994.139 433.432,994.166 433.441,994.194 433.45,994.221 433.459,994.249 433.468,994.276 433.477,994.304 433.487,994.331 433.496,994.359 433.505,994.386 433.514,994.414 433.523,994.441 433.533,994.469 433.542,994.496 433.551,994.524 433.56,994.551 433.569,994.579 433.579,994.606 433.588,994.634 433.597,994.661 433.606,994.689 433.615,994.716 433.624,994.744 433.634,994.771 433.643,994.799 433.652,994.826 433.661,994.854 433.67,994.881 433.68,994.909 433.689,994.936 433.698,994.964 433.707,994.991 433.716,995.019 433.726,995.046 433.735,995.073 433.744,995.101 433.753,995.128 433.762,995.156 433.772,995.183 433.781,995.211 433.79,995.238 433.799,995.266 433.808,995.293 433.817,995.321 433.827,995.348 433.836,995.376 433.845,995.403 433.854,995.43 433.863,995.458 433.873,995.485 433.882,995.513 433.891,995.54 433.9,995.568 433.909,995.595 433.919,995.623 433.928,995.65 433.937,995.677 433.946,995.705 433.955,995.732 433.964,995.76 433.974,995.787 433.983,995.815 433.992,995.842 434.001,995.869 434.01,995.897 434.02,995.924 434.029,995.952 434.038,995.979 434.047,996.007 434.056,996.034 434.066,996.061 434.075,996.089 434.084,996.116 434.093,996.144 434.102,996.171 434.112,996.199 434.121,996.226 434.13,996.253 434.139,996.281 434.148,996.308 434.157,996.336 434.167,996.363 434.176,996.39 434.185,996.418 434.194,996.445 434.203,996.473 434.213,996.5 434.222,996.527 434.231,996.555 434.24,996.582 434.249,996.61 434.259,996.637 434.268,996.664 434.277,996.692 434.286,996.719 434.295,996.747 434.304,996.774 434.314,996.801 434.323,996.829 434.332,996.856 434.341,996.883 434.35,996.911 434.36,996.938 434.369,996.966 434.378,996.993 434.387,997.02 434.396,997.048 434.406,997.075 434.415,997.103 434.424,997.13 434.433,997.157 434.442,997.185 434.452,997.212 434.461,997.239 434.47,997.267 434.479,997.294 434.488,997.321 434.497,997.349 434.507,997.376 434.516,997.404 434.525,997.431 434.534,997.458 434.543,997.486 434.553,997.513 434.562,997.54 434.571,997.568 434.58,997.595 434.589,997.622 434.599,997.65 434.608,997.677 434.617,997.704 434.626,997.732 434.635,997.759 434.644,997.786 434.654,997.814 434.663,997.841 434.672,997.868 434.681,997.896 434.69,997.923 434.7,997.95 434.709,997.978 434.718,998.005 434.727,998.032 434.736,998.06 434.746,998.087 434.755,998.114 434.764,998.142 434.773,998.169 434.782,998.196 434.792,998.224 434.801,998.251 434.81,998.278 434.819,998.306 434.828,998.333 434.837,998.36 434.847,998.387 434.856,998.415 434.865,998.442 434.874,998.469 434.883,998.497 434.893,998.524 434.902,998.551 434.911,998.579 434.92,998.606 434.929,998.633 434.939,998.661 434.948,998.688 434.957,998.715 434.966,998.742 434.975,998.77 434.984,998.797 434.994,998.824 435.003,998.852 435.012,998.879 435.021,998.906 435.03,998.933 435.04,998.961 435.049,998.988 435.058,999.015 435.067,999.043 435.076,999.07 435.086,999.097 435.095,999.124 435.104,999.152 435.113,999.179 435.122,999.206 435.132,999.233 435.141,999.261 435.15,999.288 435.159,999.315 435.168,999.342 435.177,999.37 435.187,999.397 435.196,999.424 435.205,999.452 435.214,999.479 435.223,999.506 435.233,999.533 435.242,999.561 435.251,999.588 435.26,999.615 435.269,999.642 435.279,999.67 435.288,999.697 435.297,999.724 435.306,999.751 435.315,999.778 435.325,999.806 435.334,999.833 435.343,999.86 435.352,999.887 435.361,999.915 435.37,999.942 435.38,999.969 435.389,999.996 435.398,1000.02 435.407,1000.05 435.416,1000.08 435.426,1000.11 435.435,1000.13 435.444,1000.16 435.453,1000.19 435.462,1000.21 435.472,1000.24 435.481,1000.27 435.49,1000.3 435.499,1000.32 435.508,1000.35 435.517,1000.38 435.527,1000.4 435.536,1000.43 435.545,1000.46 435.554,1000.49 435.563,1000.51 435.573,1000.54 435.582,1000.57 435.591,1000.6 435.6,1000.62 435.609,1000.65 435.619,1000.68 435.628,1000.7 435.637,1000.73 435.646,1000.76 435.655,1000.79 435.665,1000.81 435.674,1000.84 435.683,1000.87 435.692,1000.89 435.701,1000.92 435.71,1000.95 435.72,1000.98 435.729,1001 435.738,1001.03 435.747,1001.06 435.756,1001.08 435.766,1001.11 435.775,1001.14 435.784,1001.17 435.793,1001.19 435.802,1001.22 435.812,1001.25 435.821,1001.27 435.83,1001.3 435.839,1001.33 435.848,1001.36 435.857,1001.38 435.867,1001.41 435.876,1001.44 435.885,1001.46 435.894,1001.49 435.903,1001.52 435.913,1001.55 435.922,1001.57 435.931,1001.6 435.94,1001.63 435.949,1001.65 435.959,1001.68 435.968,1001.71 435.977,1001.74 435.986,1001.76 435.995,1001.79 436.005,1001.82 436.014,1001.84 436.023,1001.87 436.032,1001.9 436.041,1001.93 436.05,1001.95 436.06,1001.98 436.069,1002.01 436.078,1002.03 436.087,1002.06 436.096,1002.09 436.106,1002.12 436.115,1002.14 436.124,1002.17 436.133,1002.2 436.142,1002.22 436.152,1002.25 436.161,1002.28 436.17,1002.31 436.179,1002.33 436.188,1002.36 436.197,1002.39 436.207,1002.41 436.216,1002.44 436.225,1002.47 436.234,1002.5 436.243,1002.52 436.253,1002.55 436.262,1002.58 436.271,1002.6 436.28,1002.63 436.289,1002.66 436.299,1002.69 436.308,1002.71 436.317,1002.74 436.326,1002.77 436.335,1002.79 436.345,1002.82 436.354,1002.85 436.363,1002.87 436.372,1002.9 436.381,1002.93 436.39,1002.96 436.4,1002.98 436.409,1003.01 436.418,1003.04 436.427,1003.06 436.436,1003.09 436.446,1003.12 436.455,1003.15 436.464,1003.17 436.473,1003.2 436.482,1003.23 436.492,1003.25 436.501,1003.28 436.51,1003.31 436.519,1003.33 436.528,1003.36 436.537,1003.39 436.547,1003.42 436.556,1003.44 436.565,1003.47 436.574,1003.5 436.583,1003.52 436.593,1003.55 436.602,1003.58 436.611,1003.61 436.62,1003.63 436.629,1003.66 436.639,1003.69 436.648,1003.71 436.657,1003.74 436.666,1003.77 436.675,1003.79 436.685,1003.82 436.694,1003.85 436.703,1003.88 436.712,1003.9 436.721,1003.93 436.73,1003.96 436.74,1003.98 436.749,1004.01 436.758,1004.04 436.767,1004.06 436.776,1004.09 436.786,1004.12 436.795,1004.15 436.804,1004.17 436.813,1004.2 436.822,1004.23 436.832,1004.25 436.841,1004.28 436.85,1004.31 436.859,1004.33 436.868,1004.36 436.877,1004.39 436.887,1004.42 436.896,1004.44 436.905,1004.47 436.914,1004.5 436.923,1004.52 436.933,1004.55 436.942,1004.58 436.951,1004.6 436.96,1004.63 436.969,1004.66 436.979,1004.69 436.988,1004.71 436.997,1004.74 437.006,1004.77 437.015,1004.79 437.025,1004.82 437.034,1004.85 437.043,1004.87 437.052,1004.9 437.061,1004.93 437.07,1004.96 437.08,1004.98 437.089,1005.01 437.098,1005.04 437.107,1005.06 437.116,1005.09 437.126,1005.12 437.135,1005.14 437.144,1005.17 437.153,1005.2 437.162,1005.23 437.172,1005.25 437.181,1005.28 437.19,1005.31 437.199,1005.33 437.208,1005.36 437.217,1005.39 437.227,1005.41 437.236,1005.44 437.245,1005.47 437.254,1005.49 437.263,1005.52 437.273,1005.55 437.282,1005.58 437.291,1005.6 437.3,1005.63 437.309,1005.66 437.319,1005.68 437.328,1005.71 437.337,1005.74 437.346,1005.76 437.355,1005.79 437.365,1005.82 437.374,1005.84 437.383,1005.87 437.392,1005.9 437.401,1005.93 437.41,1005.95 437.42,1005.98 437.429,1006.01 437.438,1006.03 437.447,1006.06 437.456,1006.09 437.466,1006.11 437.475,1006.14 437.484,1006.17 437.493,1006.19 437.502,1006.22 437.512,1006.25 437.521,1006.28 437.53,1006.3 437.539,1006.33 437.548,1006.36 437.558,1006.38 437.567,1006.41 437.576,1006.44 437.585,1006.46 437.594,1006.49 437.603,1006.52 437.613,1006.54 437.622,1006.57 437.631,1006.6 437.64,1006.62 437.649,1006.65 437.659,1006.68 437.668,1006.71 437.677,1006.73 437.686,1006.76 437.695,1006.79 437.705,1006.81 437.714,1006.84 437.723,1006.87 437.732,1006.89 437.741,1006.92 437.75,1006.95 437.76,1006.97 437.769,1007 437.778,1007.03 437.787,1007.05 437.796,1007.08 437.806,1007.11 437.815,1007.14 437.824,1007.16 437.833,1007.19 437.842,1007.22 437.852,1007.24 437.861,1007.27 437.87,1007.3 437.879,1007.32 437.888,1007.35 437.898,1007.38 437.907,1007.4 437.916,1007.43 437.925,1007.46 437.934,1007.48 437.943,1007.51 437.953,1007.54 437.962,1007.56 437.971,1007.59 437.98,1007.62 437.989,1007.65 437.999,1007.67 438.008,1007.7 438.017,1007.73 438.026,1007.75 438.035,1007.78 438.045,1007.81 438.054,1007.83 438.063,1007.86 438.072,1007.89 438.081,1007.91 438.09,1007.94 438.1,1007.97 438.109,1007.99 438.118,1008.02 438.127,1008.05 438.136,1008.07 438.146,1008.1 438.155,1008.13 438.164,1008.15 438.173,1008.18 438.182,1008.21 438.192,1008.23 438.201,1008.26 438.21,1008.29 438.219,1008.32 438.228,1008.34 438.238,1008.37 438.247,1008.4 438.256,1008.42 438.265,1008.45 438.274,1008.48 438.283,1008.5 438.293,1008.53 438.302,1008.56 438.311,1008.58 438.32,1008.61 438.329,1008.64 438.339,1008.66 438.348,1008.69 438.357,1008.72 438.366,1008.74 438.375,1008.77 438.385,1008.8 438.394,1008.82 438.403,1008.85 438.412,1008.88 438.421,1008.9 438.43,1008.93 438.44,1008.96 438.449,1008.98 438.458,1009.01 438.467,1009.04 438.476,1009.06 438.486,1009.09 438.495,1009.12 438.504,1009.14 438.513,1009.17 438.522,1009.2 438.532,1009.22 438.541,1009.25 438.55,1009.28 438.559,1009.3 438.568,1009.33 438.578,1009.36 438.587,1009.39 438.596,1009.41 438.605,1009.44 438.614,1009.47 438.623,1009.49 438.633,1009.52 438.642,1009.55 438.651,1009.57 438.66,1009.6 438.669,1009.63 438.679,1009.65 438.688,1009.68 438.697,1009.71 438.706,1009.73 438.715,1009.76 438.725,1009.79 438.734,1009.81 438.743,1009.84 438.752,1009.87 438.761,1009.89 438.77,1009.92 438.78,1009.95 438.789,1009.97 438.798,1010 438.807,1010.03 438.816,1010.05 438.826,1010.08 438.835,1010.11 438.844,1010.13 438.853,1010.16 438.862,1010.19 438.872,1010.21 438.881,1010.24 438.89,1010.27 438.899,1010.29 438.908,1010.32 438.918,1010.35 438.927,1010.37 438.936,1010.4 438.945,1010.43 438.954,1010.45 438.963,1010.48 438.973,1010.51 438.982,1010.53 438.991,1010.56 439,1010.59 439.009,1010.61 439.019,1010.64 439.028,1010.67 439.037,1010.69 439.046,1010.72 439.055,1010.75 439.065,1010.77 439.074,1010.8 439.083,1010.83 439.092,1010.85 439.101,1010.88 439.11,1010.91 439.12,1010.93 439.129,1010.96 439.138,1010.99 439.147,1011.01 439.156,1011.04 439.166,1011.07 439.175,1011.09 439.184,1011.12 439.193,1011.15 439.202,1011.17 439.212,1011.2 439.221,1011.23 439.23,1011.25 439.239,1011.28 439.248,1011.3 439.258,1011.33 439.267,1011.36 439.276,1011.38 439.285,1011.41 439.294,1011.44 439.303,1011.46 439.313,1011.49 439.322,1011.52 439.331,1011.54 439.34,1011.57 439.349,1011.6 439.359,1011.62 439.368,1011.65 439.377,1011.68 439.386,1011.7 439.395,1011.73 439.405,1011.76 439.414,1011.78 439.423,1011.81 439.432,1011.84 439.441,1011.86 439.45,1011.89 439.46,1011.92 439.469,1011.94 439.478,1011.97 439.487,1012 439.496,1012.02 439.506,1012.05 439.515,1012.08 439.524,1012.1 439.533,1012.13 439.542,1012.16 439.552,1012.18 439.561,1012.21 439.57,1012.24 439.579,1012.26 439.588,1012.29 439.598,1012.31 439.607,1012.34 439.616,1012.37 439.625,1012.39 439.634,1012.42 439.643,1012.45 439.653,1012.47 439.662,1012.5 439.671,1012.53 439.68,1012.55 439.689,1012.58 439.699,1012.61 439.708,1012.63 439.717,1012.66 439.726,1012.69 439.735,1012.71 439.745,1012.74 439.754,1012.77 439.763,1012.79 439.772,1012.82 439.781,1012.85 439.79,1012.87 439.8,1012.9 439.809,1012.93 439.818,1012.95 439.827,1012.98 439.836,1013 439.846,1013.03 439.855,1013.06 439.864,1013.08 439.873,1013.11 439.882,1013.14 439.892,1013.16 439.901,1013.19 439.91,1013.22 439.919,1013.24 439.928,1013.27 439.938,1013.3 439.947,1013.32 439.956,1013.35 439.965,1013.38 439.974,1013.4 439.983,1013.43 439.993,1013.46 440.002,1013.48 440.011,1013.51 440.02,1013.53 440.029,1013.56 440.039,1013.59 440.048,1013.61 440.057,1013.64 440.066,1013.67 440.075,1013.69 440.085,1013.72 440.094,1013.75 440.103,1013.77 440.112,1013.8 440.121,1013.83 440.131,1013.85 440.14,1013.88 440.149,1013.9 440.158,1013.93 440.167,1013.96 440.176,1013.98 440.186,1014.01 440.195,1014.04 440.204,1014.06 440.213,1014.09 440.222,1014.12 440.232,1014.14 440.241,1014.17 440.25,1014.2 440.259,1014.22 440.268,1014.25 440.278,1014.28 440.287,1014.3 440.296,1014.33 440.305,1014.35 440.314,1014.38 440.323,1014.41 440.333,1014.43 440.342,1014.46 440.351,1014.49 440.36,1014.51 440.369,1014.54 440.379,1014.57 440.388,1014.59 440.397,1014.62 440.406,1014.65 440.415,1014.67 440.425,1014.7 440.434,1014.72 440.443,1014.75 440.452,1014.78 440.461,1014.8 440.471,1014.83 440.48,1014.86 440.489,1014.88 440.498,1014.91 440.507,1014.94 440.516,1014.96 440.526,1014.99 440.535,1015.01 440.544,1015.04 440.553,1015.07 440.562,1015.09 440.572,1015.12 440.581,1015.15 440.59,1015.17 440.599,1015.2 440.608,1015.23 440.618,1015.25 440.627,1015.28 440.636,1015.3 440.645,1015.33 440.654,1015.36 440.663,1015.38 440.673,1015.41 440.682,1015.44 440.691,1015.46 440.7,1015.49 440.709,1015.52 440.719,1015.54 440.728,1015.57 440.737,1015.59 440.746,1015.62 440.755,1015.65 440.765,1015.67 440.774,1015.7 440.783,1015.73 440.792,1015.75 440.801,1015.78 440.811,1015.81 440.82,1015.83 440.829,1015.86 440.838,1015.88 440.847,1015.91 440.856,1015.94 440.866,1015.96 440.875,1015.99 440.884,1016.02 440.893,1016.04 440.902,1016.07 440.912,1016.09 440.921,1016.12 440.93,1016.15 440.939,1016.17 440.948,1016.2 440.958,1016.23 440.967,1016.25 440.976,1016.28 440.985,1016.31 440.994,1016.33 441.003,1016.36 441.013,1016.38 441.022,1016.41 441.031,1016.44 441.04,1016.46 441.049,1016.49 441.059,1016.52 441.068,1016.54 441.077,1016.57 441.086,1016.59 441.095,1016.62 441.105,1016.65 441.114,1016.67 441.123,1016.7 441.132,1016.73 441.141,1016.75 441.151,1016.78 441.16,1016.8 441.169,1016.83 441.178,1016.86 441.187,1016.88 441.196,1016.91 441.206,1016.94 441.215,1016.96 441.224,1016.99 441.233,1017.02 441.242,1017.04 441.252,1017.07 441.261,1017.09 441.27,1017.12 441.279,1017.15 441.288,1017.17 441.298,1017.2 441.307,1017.23 441.316,1017.25 441.325,1017.28 441.334,1017.3 441.343,1017.33 441.353,1017.36 441.362,1017.38 441.371,1017.41 441.38,1017.44 441.389,1017.46 441.399,1017.49 441.408,1017.51 441.417,1017.54 441.426,1017.57 441.435,1017.59 441.445,1017.62 441.454,1017.64 441.463,1017.67 441.472,1017.7 441.481,1017.72 441.491,1017.75 441.5,1017.78 441.509,1017.8 441.518,1017.83 441.527,1017.85 441.536,1017.88 441.546,1017.91 441.555,1017.93 441.564,1017.96 441.573,1017.99 441.582,1018.01 441.592,1018.04 441.601,1018.06 441.61,1018.09 441.619,1018.12 441.628,1018.14 441.638,1018.17 441.647,1018.2 441.656,1018.22 441.665,1018.25 441.674,1018.27 441.683,1018.3 441.693,1018.33 441.702,1018.35 441.711,1018.38 441.72,1018.4 441.729,1018.43 441.739,1018.46 441.748,1018.48 441.757,1018.51 441.766,1018.54 441.775,1018.56 441.785,1018.59 441.794,1018.61 441.803,1018.64 441.812,1018.67 441.821,1018.69 441.831,1018.72 441.84,1018.74 441.849,1018.77 441.858,1018.8 441.867,1018.82 441.876,1018.85 441.886,1018.88 441.895,1018.9 441.904,1018.93 441.913,1018.95 441.922,1018.98 441.932,1019.01 441.941,1019.03 441.95,1019.06 441.959,1019.08 441.968,1019.11 441.978,1019.14 441.987,1019.16 441.996,1019.19 442.005,1019.22 442.014,1019.24 442.023,1019.27 442.033,1019.29 442.042,1019.32 442.051,1019.35 442.06,1019.37 442.069,1019.4 442.079,1019.42 442.088,1019.45 442.097,1019.48 442.106,1019.5 442.115,1019.53 442.125,1019.55 442.134,1019.58 442.143,1019.61 442.152,1019.63 442.161,1019.66 442.171,1019.69 442.18,1019.71 442.189,1019.74 442.198,1019.76 442.207,1019.79 442.216,1019.82 442.226,1019.84 442.235,1019.87 442.244,1019.89 442.253,1019.92 442.262,1019.95 442.272,1019.97 442.281,1020 442.29,1020.02 442.299,1020.05 442.308,1020.08 442.318,1020.1 442.327,1020.13 442.336,1020.15 442.345,1020.18 442.354,1020.21 442.363,1020.23 442.373,1020.26 442.382,1020.28 442.391,1020.31 442.4,1020.34 442.409,1020.36 442.419,1020.39 442.428,1020.42 442.437,1020.44 442.446,1020.47 442.455,1020.49 442.465,1020.52 442.474,1020.55 442.483,1020.57 442.492,1020.6 442.501,1020.62 442.511,1020.65 442.52,1020.68 442.529,1020.7 442.538,1020.73 442.547,1020.75 442.556,1020.78 442.566,1020.81 442.575,1020.83 442.584,1020.86 442.593,1020.88 442.602,1020.91 442.612,1020.94 442.621,1020.96 442.63,1020.99 442.639,1021.01 442.648,1021.04 442.658,1021.07 442.667,1021.09 442.676,1021.12 442.685,1021.14 442.694,1021.17 442.704,1021.2 442.713,1021.22 442.722,1021.25 442.731,1021.27 442.74,1021.3 442.749,1021.33 442.759,1021.35 442.768,1021.38 442.777,1021.4 442.786,1021.43 442.795,1021.46 442.805,1021.48 442.814,1021.51 442.823,1021.53 442.832,1021.56 442.841,1021.59 442.851,1021.61 442.86,1021.64 442.869,1021.66 442.878,1021.69 442.887,1021.72 442.896,1021.74 442.906,1021.77 442.915,1021.79 442.924,1021.82 442.933,1021.84 442.942,1021.87 442.952,1021.9 442.961,1021.92 442.97,1021.95 442.979,1021.97 442.988,1022 442.998,1022.03 443.007,1022.05 443.016,1022.08 443.025,1022.1 443.034,1022.13 443.044,1022.16 443.053,1022.18 443.062,1022.21 443.071,1022.23 443.08,1022.26 443.089,1022.29 443.099,1022.31 443.108,1022.34 443.117,1022.36 443.126,1022.39 443.135,1022.42 443.145,1022.44 443.154,1022.47 443.163,1022.49 443.172,1022.52 443.181,1022.54 443.191,1022.57 443.2,1022.6 443.209,1022.62 443.218,1022.65 443.227,1022.67 443.236,1022.7 443.246,1022.73 443.255,1022.75 443.264,1022.78 443.273,1022.8 443.282,1022.83 443.292,1022.86 443.301,1022.88 443.31,1022.91 443.319,1022.93 443.328,1022.96 443.338,1022.99 443.347,1023.01 443.356,1023.04 443.365,1023.06 443.374,1023.09 443.384,1023.11 443.393,1023.14 443.402,1023.17 443.411,1023.19 443.42,1023.22 443.429,1023.24 443.439,1023.27 443.448,1023.3 443.457,1023.32 443.466,1023.35 443.475,1023.37 443.485,1023.4 443.494,1023.42 443.503,1023.45 443.512,1023.48 443.521,1023.5 443.531,1023.53 443.54,1023.55 443.549,1023.58 443.558,1023.61 443.567,1023.63 443.576,1023.66 443.586,1023.68 443.595,1023.71 443.604,1023.73 443.613,1023.76 443.622,1023.79 443.632,1023.81 443.641,1023.84 443.65,1023.86 443.659,1023.89 443.668,1023.92 443.678,1023.94 443.687,1023.97 443.696,1023.99 443.705,1024.02 443.714,1024.04 443.724,1024.07 443.733,1024.1 443.742,1024.12 443.751,1024.15 443.76,1024.17 443.769,1024.2 443.779,1024.23 443.788,1024.25 443.797,1024.28 443.806,1024.3 443.815,1024.33 443.825,1024.35 443.834,1024.38 443.843,1024.41 443.852,1024.43 443.861,1024.46 443.871,1024.48 443.88,1024.51 443.889,1024.53 443.898,1024.56 443.907,1024.59 443.916,1024.61 443.926,1024.64 443.935,1024.66 443.944,1024.69 443.953,1024.71 443.962,1024.74 443.972,1024.77 443.981,1024.79 443.99,1024.82 443.999,1024.84 444.008,1024.87 444.018,1024.9 444.027,1024.92 444.036,1024.95 444.045,1024.97 444.054,1025 444.064,1025.02 444.073,1025.05 444.082,1025.08 444.091,1025.1 444.1,1025.13 444.109,1025.15 444.119,1025.18 444.128,1025.2 444.137,1025.23 444.146,1025.26 444.155,1025.28 444.165,1025.31 444.174,1025.33 444.183,1025.36 444.192,1025.38 444.201,1025.41 444.211,1025.44 444.22,1025.46 444.229,1025.49 444.238,1025.51 444.247,1025.54 444.256,1025.56 444.266,1025.59 444.275,1025.62 444.284,1025.64 444.293,1025.67 444.302,1025.69 444.312,1025.72 444.321,1025.74 444.33,1025.77 444.339,1025.8 444.348,1025.82 444.358,1025.85 444.367,1025.87 444.376,1025.9 444.385,1025.92 444.394,1025.95 444.404,1025.98 444.413,1026 444.422,1026.03 444.431,1026.05 444.44,1026.08 444.449,1026.1 444.459,1026.13 444.468,1026.15 444.477,1026.18 444.486,1026.21 444.495,1026.23 444.505,1026.26 444.514,1026.28 444.523,1026.31 444.532,1026.33 444.541,1026.36 444.551,1026.39 444.56,1026.41 444.569,1026.44 444.578,1026.46 444.587,1026.49 444.596,1026.51 444.606,1026.54 444.615,1026.57 444.624,1026.59 444.633,1026.62 444.642,1026.64 444.652,1026.67 444.661,1026.69 444.67,1026.72 444.679,1026.74 444.688,1026.77 444.698,1026.8 444.707,1026.82 444.716,1026.85 444.725,1026.87 444.734,1026.9 444.744,1026.92 444.753,1026.95 444.762,1026.98 444.771,1027 444.78,1027.03 444.789,1027.05 444.799,1027.08 444.808,1027.1 444.817,1027.13 444.826,1027.15 444.835,1027.18 444.845,1027.21 444.854,1027.23 444.863,1027.26 444.872,1027.28 444.881,1027.31 444.891,1027.33 444.9,1027.36 444.909,1027.38 444.918,1027.41 444.927,1027.44 444.937,1027.46 444.946,1027.49 444.955,1027.51 444.964,1027.54 444.973,1027.56 444.982,1027.59 444.992,1027.61 445.001,1027.64 445.01,1027.67 445.019,1027.69 445.028,1027.72 445.038,1027.74 445.047,1027.77 445.056,1027.79 445.065,1027.82 445.074,1027.84 445.084,1027.87 445.093,1027.9 445.102,1027.92 445.111,1027.95 445.12,1027.97 445.129,1028 445.139,1028.02 445.148,1028.05 445.157,1028.07 445.166,1028.1 445.175,1028.13 445.185,1028.15 445.194,1028.18 445.203,1028.2 445.212,1028.23 445.221,1028.25 445.231,1028.28 445.24,1028.3 445.249,1028.33 445.258,1028.36 445.267,1028.38 445.277,1028.41 445.286,1028.43 445.295,1028.46 445.304,1028.48 445.313,1028.51 445.322,1028.53 445.332,1028.56 445.341,1028.58 445.35,1028.61 445.359,1028.64 445.368,1028.66 445.378,1028.69 445.387,1028.71 445.396,1028.74 445.405,1028.76 445.414,1028.79 445.424,1028.81 445.433,1028.84 445.442,1028.87 445.451,1028.89 445.46,1028.92 445.469,1028.94 445.479,1028.97 445.488,1028.99 445.497,1029.02 445.506,1029.04 445.515,1029.07 445.525,1029.09 445.534,1029.12 445.543,1029.15 445.552,1029.17 445.561,1029.2 445.571,1029.22 445.58,1029.25 445.589,1029.27 445.598,1029.3 445.607,1029.32 445.617,1029.35 445.626,1029.37 445.635,1029.4 445.644,1029.43 445.653,1029.45 445.662,1029.48 445.672,1029.5 445.681,1029.53 445.69,1029.55 445.699,1029.58 445.708,1029.6 445.718,1029.63 445.727,1029.65 445.736,1029.68 445.745,1029.71 445.754,1029.73 445.764,1029.76 445.773,1029.78 445.782,1029.81 445.791,1029.83 445.8,1029.86 445.809,1029.88 445.819,1029.91 445.828,1029.93 445.837,1029.96 445.846,1029.98 445.855,1030.01 445.865,1030.04 445.874,1030.06 445.883,1030.09 445.892,1030.11 445.901,1030.14 445.911,1030.16 445.92,1030.19 445.929,1030.21 445.938,1030.24 445.947,1030.26 445.957,1030.29 445.966,1030.31 445.975,1030.34 445.984,1030.37 445.993,1030.39 446.002,1030.42 446.012,1030.44 446.021,1030.47 446.03,1030.49 446.039,1030.52 446.048,1030.54 446.058,1030.57 446.067,1030.59 446.076,1030.62 446.085,1030.64 446.094,1030.67 446.104,1030.7 446.113,1030.72 446.122,1030.75 446.131,1030.77 446.14,1030.8 446.149,1030.82 446.159,1030.85 446.168,1030.87 446.177,1030.9 446.186,1030.92 446.195,1030.95 446.205,1030.97 446.214,1031 446.223,1031.02 446.232,1031.05 446.241,1031.08 446.251,1031.1 446.26,1031.13 446.269,1031.15 446.278,1031.18 446.287,1031.2 446.297,1031.23 446.306,1031.25 446.315,1031.28 446.324,1031.3 446.333,1031.33 446.342,1031.35 446.352,1031.38 446.361,1031.4 446.37,1031.43 446.379,1031.45 446.388,1031.48 446.398,1031.51 446.407,1031.53 446.416,1031.56 446.425,1031.58 446.434,1031.61 446.444,1031.63 446.453,1031.66 446.462,1031.68 446.471,1031.71 446.48,1031.73 446.489,1031.76 446.499,1031.78 446.508,1031.81 446.517,1031.83 446.526,1031.86 446.535,1031.88 446.545,1031.91 446.554,1031.93 446.563,1031.96 446.572,1031.99 446.581,1032.01 446.591,1032.04 446.6,1032.06 446.609,1032.09 446.618,1032.11 446.627,1032.14 446.637,1032.16 446.646,1032.19 446.655,1032.21 446.664,1032.24 446.673,1032.26 446.682,1032.29 446.692,1032.31 446.701,1032.34 446.71,1032.36 446.719,1032.39 446.728,1032.41 446.738,1032.44 446.747,1032.47 446.756,1032.49 446.765,1032.52 446.774,1032.54 446.784,1032.57 446.793,1032.59 446.802,1032.62 446.811,1032.64 446.82,1032.67 446.829,1032.69 446.839,1032.72 446.848,1032.74 446.857,1032.77 446.866,1032.79 446.875,1032.82 446.885,1032.84 446.894,1032.87 446.903,1032.89 446.912,1032.92 446.921,1032.94 446.931,1032.97 446.94,1032.99 446.949,1033.02 446.958,1033.04 446.967,1033.07 446.977,1033.1 446.986,1033.12 446.995,1033.15 447.004,1033.17 447.013,1033.2 447.022,1033.22 447.032,1033.25 447.041,1033.27 447.05,1033.3 447.059,1033.32 447.068,1033.35 447.078,1033.37 447.087,1033.4 447.096,1033.42 447.105,1033.45 447.114,1033.47 447.124,1033.5 447.133,1033.52 447.142,1033.55 447.151,1033.57 447.16,1033.6 447.169,1033.62 447.179,1033.65 447.188,1033.67 447.197,1033.7 447.206,1033.72 447.215,1033.75 447.225,1033.77 447.234,1033.8 447.243,1033.82 447.252,1033.85 447.261,1033.87 447.271,1033.9 447.28,1033.92 447.289,1033.95 447.298,1033.98 447.307,1034 447.317,1034.03 447.326,1034.05 447.335,1034.08 447.344,1034.1 447.353,1034.13 447.362,1034.15 447.372,1034.18 447.381,1034.2 447.39,1034.23 447.399,1034.25 447.408,1034.28 447.418,1034.3 447.427,1034.33 447.436,1034.35 447.445,1034.38 447.454,1034.4 447.464,1034.43 447.473,1034.45 447.482,1034.48 447.491,1034.5 447.5,1034.53 447.51,1034.55 447.519,1034.58 447.528,1034.6 447.537,1034.63 447.546,1034.65 447.555,1034.68 447.565,1034.7 447.574,1034.73 447.583,1034.75 447.592,1034.78 447.601,1034.8 447.611,1034.83 447.62,1034.85 447.629,1034.88 447.638,1034.9 447.647,1034.93 447.657,1034.95 447.666,1034.98 447.675,1035 447.684,1035.03 447.693,1035.05 447.702,1035.08 447.712,1035.1 447.721,1035.13 447.73,1035.15 447.739,1035.18 447.748,1035.2 447.758,1035.23 447.767,1035.25 447.776,1035.28 447.785,1035.3 447.794,1035.33 447.804,1035.35 447.813,1035.38 447.822,1035.4 447.831,1035.43 447.84,1035.45 447.85,1035.48 447.859,1035.5 447.868,1035.53 447.877,1035.55 447.886,1035.58 447.895,1035.6 447.905,1035.63 447.914,1035.65 447.923,1035.68 447.932,1035.7 447.941,1035.73 447.951,1035.75 447.96,1035.78 447.969,1035.8 447.978,1035.83 447.987,1035.85 447.997,1035.88 448.006,1035.9 448.015,1035.93 448.024,1035.95 448.033,1035.98 448.042,1036 448.052,1036.03 448.061,1036.05 448.07,1036.08 448.079,1036.1 448.088,1036.13 448.098,1036.15 448.107,1036.18 448.116,1036.2 448.125,1036.23 448.134,1036.25 448.144,1036.28 448.153,1036.3 448.162,1036.33 448.171,1036.35 448.18,1036.38 448.19,1036.4 448.199,1036.43 448.208,1036.45 448.217,1036.48 448.226,1036.5 448.235,1036.53 448.245,1036.55 448.254,1036.58 448.263,1036.6 448.272,1036.63 448.281,1036.65 448.291,1036.68 448.3,1036.7 448.309,1036.73 448.318,1036.75 448.327,1036.78 448.337,1036.8 448.346,1036.83 448.355,1036.85 448.364,1036.88 448.373,1036.9 448.382,1036.93 448.392,1036.95 448.401,1036.98 448.41,1037 448.419,1037.03 448.428,1037.05 448.438,1037.08 448.447,1037.1 448.456,1037.13 448.465,1037.15 448.474,1037.18 448.484,1037.2 448.493,1037.22 448.502,1037.25 448.511,1037.27 448.52,1037.3 448.53,1037.32 448.539,1037.35 448.548,1037.37 448.557,1037.4 448.566,1037.42 448.575,1037.45 448.585,1037.47 448.594,1037.5 448.603,1037.52 448.612,1037.55 448.621,1037.57 448.631,1037.6 448.64,1037.62 448.649,1037.65 448.658,1037.67 448.667,1037.7 448.677,1037.72 448.686,1037.75 448.695,1037.77 448.704,1037.8 448.713,1037.82 448.722,1037.85 448.732,1037.87 448.741,1037.9 448.75,1037.92 448.759,1037.95 448.768,1037.97 448.778,1038 448.787,1038.02 448.796,1038.04 448.805,1038.07 448.814,1038.09 448.824,1038.12 448.833,1038.14 448.842,1038.17 448.851,1038.19 448.86,1038.22 448.87,1038.24 448.879,1038.27 448.888,1038.29 448.897,1038.32 448.906,1038.34 448.915,1038.37 448.925,1038.39 448.934,1038.42 448.943,1038.44 448.952,1038.47 448.961,1038.49 448.971,1038.52 448.98,1038.54 448.989,1038.57 448.998,1038.59 449.007,1038.62 449.017,1038.64 449.026,1038.66 449.035,1038.69 449.044,1038.71 449.053,1038.74 449.062,1038.76 449.072,1038.79 449.081,1038.81 449.09,1038.84 449.099,1038.86 449.108,1038.89 449.118,1038.91 449.127,1038.94 449.136,1038.96 449.145,1038.99 449.154,1039.01 449.164,1039.04 449.173,1039.06 449.182,1039.09 449.191,1039.11 449.2,1039.14 449.21,1039.16 449.219,1039.18 449.228,1039.21 449.237,1039.23 449.246,1039.26 449.255,1039.28 449.265,1039.31 449.274,1039.33 449.283,1039.36 449.292,1039.38 449.301,1039.41 449.311,1039.43 449.32,1039.46 449.329,1039.48 449.338,1039.51 449.347,1039.53 449.357,1039.56 449.366,1039.58 449.375,1039.6 449.384,1039.63 449.393,1039.65 449.402,1039.68 449.412,1039.7 449.421,1039.73 449.43,1039.75 449.439,1039.78 449.448,1039.8 449.458,1039.83 449.467,1039.85 449.476,1039.88 449.485,1039.9 449.494,1039.93 449.504,1039.95 449.513,1039.98 449.522,1040 449.531,1040.02 449.54,1040.05 449.55,1040.07 449.559,1040.1 449.568,1040.12 449.577,1040.15 449.586,1040.17 449.595,1040.2 449.605,1040.22 449.614,1040.25 449.623,1040.27 449.632,1040.3 449.641,1040.32 449.651,1040.34 449.66,1040.37 449.669,1040.39 449.678,1040.42 449.687,1040.44 449.697,1040.47 449.706,1040.49 449.715,1040.52 449.724,1040.54 449.733,1040.57 449.742,1040.59 449.752,1040.62 449.761,1040.64 449.77,1040.67 449.779,1040.69 449.788,1040.71 449.798,1040.74 449.807,1040.76 449.816,1040.79 449.825,1040.81 449.834,1040.84 449.844,1040.86 449.853,1040.89 449.862,1040.91 449.871,1040.94 449.88,1040.96 449.89,1040.99 449.899,1041.01 449.908,1041.03 449.917,1041.06 449.926,1041.08 449.935,1041.11 449.945,1041.13 449.954,1041.16 449.963,1041.18 449.972,1041.21 449.981,1041.23 449.991,1041.26 450,1041.28 450.009,1041.3 450.018,1041.33 450.027,1041.35 450.037,1041.38 450.046,1041.4 450.055,1041.43 450.064,1041.45 450.073,1041.48 450.083,1041.5 450.092,1041.53 450.101,1041.55 450.11,1041.57 450.119,1041.6 450.128,1041.62 450.138,1041.65 450.147,1041.67 450.156,1041.7 450.165,1041.72 450.174,1041.75 450.184,1041.77 450.193,1041.8 450.202,1041.82 450.211,1041.84 450.22,1041.87 450.23,1041.89 450.239,1041.92 450.248,1041.94 450.257,1041.97 450.266,1041.99 450.275,1042.02 450.285,1042.04 450.294,1042.07 450.303,1042.09 450.312,1042.11 450.321,1042.14 450.331,1042.16 450.34,1042.19 450.349,1042.21 450.358,1042.24 450.367,1042.26 450.377,1042.29 450.386,1042.31 450.395,1042.34 450.404,1042.36 450.413,1042.38 450.423,1042.41 450.432,1042.43 450.441,1042.46 450.45,1042.48 450.459,1042.51 450.468,1042.53 450.478,1042.56 450.487,1042.58 450.496,1042.6 450.505,1042.63 450.514,1042.65 450.524,1042.68 450.533,1042.7 450.542,1042.73 450.551,1042.75 450.56,1042.78 450.57,1042.8 450.579,1042.82 450.588,1042.85 450.597,1042.87 450.606,1042.9 450.615,1042.92 450.625,1042.95 450.634,1042.97 450.643,1043 450.652,1043.02 450.661,1043.04 450.671,1043.07 450.68,1043.09 450.689,1043.12 450.698,1043.14 450.707,1043.17 450.717,1043.19 450.726,1043.22 450.735,1043.24 450.744,1043.26 450.753,1043.29 450.763,1043.31 450.772,1043.34 450.781,1043.36 450.79,1043.39 450.799,1043.41 450.808,1043.44 450.818,1043.46 450.827,1043.48 450.836,1043.51 450.845,1043.53 450.854,1043.56 450.864,1043.58 450.873,1043.61 450.882,1043.63 450.891,1043.66 450.9,1043.68 450.91,1043.7 450.919,1043.73 450.928,1043.75 450.937,1043.78 450.946,1043.8 450.955,1043.83 450.965,1043.85 450.974,1043.87 450.983,1043.9 450.992,1043.92 451.001,1043.95 451.011,1043.97 451.02,1044 451.029,1044.02 451.038,1044.05 451.047,1044.07 451.057,1044.09 451.066,1044.12 451.075,1044.14 451.084,1044.17 451.093,1044.19 451.103,1044.22 451.112,1044.24 451.121,1044.26 451.13,1044.29 451.139,1044.31 451.148,1044.34 451.158,1044.36 451.167,1044.39 451.176,1044.41 451.185,1044.44 451.194,1044.46 451.204,1044.48 451.213,1044.51 451.222,1044.53 451.231,1044.56 451.24,1044.58 451.25,1044.61 451.259,1044.63 451.268,1044.65 451.277,1044.68 451.286,1044.7 451.295,1044.73 451.305,1044.75 451.314,1044.78 451.323,1044.8 451.332,1044.82 451.341,1044.85 451.351,1044.87 451.36,1044.9 451.369,1044.92 451.378,1044.95 451.387,1044.97 451.397,1044.99 451.406,1045.02 451.415,1045.04 451.424,1045.07 451.433,1045.09 451.443,1045.12 451.452,1045.14 451.461,1045.16 451.47,1045.19 451.479,1045.21 451.488,1045.24 451.498,1045.26 451.507,1045.29 451.516,1045.31 451.525,1045.33 451.534,1045.36 451.544,1045.38 451.553,1045.41 451.562,1045.43 451.571,1045.46 451.58,1045.48 451.59,1045.5 451.599,1045.53 451.608,1045.55 451.617,1045.58 451.626,1045.6 451.635,1045.63 451.645,1045.65 451.654,1045.67 451.663,1045.7 451.672,1045.72 451.681,1045.75 451.691,1045.77 451.7,1045.79 451.709,1045.82 451.718,1045.84 451.727,1045.87 451.737,1045.89 451.746,1045.92 451.755,1045.94 451.764,1045.96 451.773,1045.99 451.783,1046.01 451.792,1046.04 451.801,1046.06 451.81,1046.09 451.819,1046.11 451.828,1046.13 451.838,1046.16 451.847,1046.18 451.856,1046.21 451.865,1046.23 451.874,1046.26 451.884,1046.28 451.893,1046.3 451.902,1046.33 451.911,1046.35 451.92,1046.38 451.93,1046.4 451.939,1046.42 451.948,1046.45 451.957,1046.47 451.966,1046.5 451.975,1046.52 451.985,1046.55 451.994,1046.57 452.003,1046.59 452.012,1046.62 452.021,1046.64 452.031,1046.67 452.04,1046.69 452.049,1046.71 452.058,1046.74 452.067,1046.76 452.077,1046.79 452.086,1046.81 452.095,1046.84 452.104,1046.86 452.113,1046.88 452.123,1046.91 452.132,1046.93 452.141,1046.96 452.15,1046.98 452.159,1047 452.168,1047.03 452.178,1047.05 452.187,1047.08 452.196,1047.1 452.205,1047.12 452.214,1047.15 452.224,1047.17 452.233,1047.2 452.242,1047.22 452.251,1047.25 452.26,1047.27 452.27,1047.29 452.279,1047.32 452.288,1047.34 452.297,1047.37 452.306,1047.39 452.316,1047.41 452.325,1047.44 452.334,1047.46 452.343,1047.49 452.352,1047.51 452.361,1047.53 452.371,1047.56 452.38,1047.58 452.389,1047.61 452.398,1047.63 452.407,1047.66 452.417,1047.68 452.426,1047.7 452.435,1047.73 452.444,1047.75 452.453,1047.78 452.463,1047.8 452.472,1047.82 452.481,1047.85 452.49,1047.87 452.499,1047.9 452.508,1047.92 452.518,1047.94 452.527,1047.97 452.536,1047.99 452.545,1048.02 452.554,1048.04 452.564,1048.06 452.573,1048.09 452.582,1048.11 452.591,1048.14 452.6,1048.16 452.61,1048.18 452.619,1048.21 452.628,1048.23 452.637,1048.26 452.646,1048.28 452.656,1048.3 452.665,1048.33 452.674,1048.35 452.683,1048.38 452.692,1048.4 452.701,1048.43 452.711,1048.45 452.72,1048.47 452.729,1048.5 452.738,1048.52 452.747,1048.55 452.757,1048.57 452.766,1048.59 452.775,1048.62 452.784,1048.64 452.793,1048.67 452.803,1048.69 452.812,1048.71 452.821,1048.74 452.83,1048.76 452.839,1048.79 452.848,1048.81 452.858,1048.83 452.867,1048.86 452.876,1048.88 452.885,1048.91 452.894,1048.93 452.904,1048.95 452.913,1048.98 452.922,1049 452.931,1049.03 452.94,1049.05 452.95,1049.07 452.959,1049.1 452.968,1049.12 452.977,1049.15 452.986,1049.17 452.996,1049.19 453.005,1049.22 453.014,1049.24 453.023,1049.26 453.032,1049.29 453.041,1049.31 453.051,1049.34 453.06,1049.36 453.069,1049.38 453.078,1049.41 453.087,1049.43 453.097,1049.46 453.106,1049.48 453.115,1049.5 453.124,1049.53 453.133,1049.55 453.143,1049.58 453.152,1049.6 453.161,1049.62 453.17,1049.65 453.179,1049.67 453.188,1049.7 453.198,1049.72 453.207,1049.74 453.216,1049.77 453.225,1049.79 453.234,1049.82 453.244,1049.84 453.253,1049.86 453.262,1049.89 453.271,1049.91 453.28,1049.94 453.29,1049.96 453.299,1049.98 453.308,1050.01 453.317,1050.03 453.326,1050.05 453.336,1050.08 453.345,1050.1 453.354,1050.13 453.363,1050.15 453.372,1050.17 453.381,1050.2 453.391,1050.22 453.4,1050.25 453.409,1050.27 453.418,1050.29 453.427,1050.32 453.437,1050.34 453.446,1050.37 453.455,1050.39 453.464,1050.41 453.473,1050.44 453.483,1050.46 453.492,1050.48 453.501,1050.51 453.51,1050.53 453.519,1050.56 453.528,1050.58 453.538,1050.6 453.547,1050.63 453.556,1050.65 453.565,1050.68 453.574,1050.7 453.584,1050.72 453.593,1050.75 453.602,1050.77 453.611,1050.79 453.62,1050.82 453.63,1050.84 453.639,1050.87 453.648,1050.89 453.657,1050.91 453.666,1050.94 453.676,1050.96 453.685,1050.99 453.694,1051.01 453.703,1051.03 453.712,1051.06 453.721,1051.08 453.731,1051.1 453.74,1051.13 453.749,1051.15 453.758,1051.18 453.767,1051.2 453.777,1051.22 453.786,1051.25 453.795,1051.27 453.804,1051.29 453.813,1051.32 453.823,1051.34 453.832,1051.37 453.841,1051.39 453.85,1051.41 453.859,1051.44 453.868,1051.46 453.878,1051.49 453.887,1051.51 453.896,1051.53 453.905,1051.56 453.914,1051.58 453.924,1051.6 453.933,1051.63 453.942,1051.65 453.951,1051.68 453.96,1051.7 453.97,1051.72 453.979,1051.75 453.988,1051.77 453.997,1051.79 454.006,1051.82 454.016,1051.84 454.025,1051.87 454.034,1051.89 454.043,1051.91 454.052,1051.94 454.061,1051.96 454.071,1051.98 454.08,1052.01 454.089,1052.03 454.098,1052.06 454.107,1052.08 454.117,1052.1 454.126,1052.13 454.135,1052.15 454.144,1052.17 454.153,1052.2 454.163,1052.22 454.172,1052.25 454.181,1052.27 454.19,1052.29 454.199,1052.32 454.208,1052.34 454.218,1052.36 454.227,1052.39 454.236,1052.41 454.245,1052.43 454.254,1052.46 454.264,1052.48 454.273,1052.51 454.282,1052.53 454.291,1052.55 454.3,1052.58 454.31,1052.6 454.319,1052.62 454.328,1052.65 454.337,1052.67 454.346,1052.7 454.356,1052.72 454.365,1052.74 454.374,1052.77 454.383,1052.79 454.392,1052.81 454.401,1052.84 454.411,1052.86 454.42,1052.89 454.429,1052.91 454.438,1052.93 454.447,1052.96 454.457,1052.98 454.466,1053 454.475,1053.03 454.484,1053.05 454.493,1053.07 454.503,1053.1 454.512,1053.12 454.521,1053.15 454.53,1053.17 454.539,1053.19 454.548,1053.22 454.558,1053.24 454.567,1053.26 454.576,1053.29 454.585,1053.31 454.594,1053.33 454.604,1053.36 454.613,1053.38 454.622,1053.41 454.631,1053.43 454.64,1053.45 454.65,1053.48 454.659,1053.5 454.668,1053.52 454.677,1053.55 454.686,1053.57 454.696,1053.59 454.705,1053.62 454.714,1053.64 454.723,1053.67 454.732,1053.69 454.741,1053.71 454.751,1053.74 454.76,1053.76 454.769,1053.78 454.778,1053.81 454.787,1053.83 454.797,1053.85 454.806,1053.88 454.815,1053.9 454.824,1053.92 454.833,1053.95 454.843,1053.97 454.852,1054 454.861,1054.02 454.87,1054.04 454.879,1054.07 454.889,1054.09 454.898,1054.11 454.907,1054.14 454.916,1054.16 454.925,1054.18 454.934,1054.21 454.944,1054.23 454.953,1054.26 454.962,1054.28 454.971,1054.3 454.98,1054.33 454.99,1054.35 454.999,1054.37 455.008,1054.4 455.017,1054.42 455.026,1054.44 455.036,1054.47 455.045,1054.49 455.054,1054.51 455.063,1054.54 455.072,1054.56 455.081,1054.58 455.091,1054.61 455.1,1054.63 455.109,1054.66 455.118,1054.68 455.127,1054.7 455.137,1054.73 455.146,1054.75 455.155,1054.77 455.164,1054.8 455.173,1054.82 455.183,1054.84 455.192,1054.87 455.201,1054.89 455.21,1054.91 455.219,1054.94 455.229,1054.96 455.238,1054.98 455.247,1055.01 455.256,1055.03 455.265,1055.06 455.274,1055.08 455.284,1055.1 455.293,1055.13 455.302,1055.15 455.311,1055.17 455.32,1055.2 455.33,1055.22 455.339,1055.24 455.348,1055.27 455.357,1055.29 455.366,1055.31 455.376,1055.34 455.385,1055.36 455.394,1055.38 455.403,1055.41 455.412,1055.43 455.421,1055.45 455.431,1055.48 455.44,1055.5 455.449,1055.52 455.458,1055.55 455.467,1055.57 455.477,1055.6 455.486,1055.62 455.495,1055.64 455.504,1055.67 455.513,1055.69 455.523,1055.71 455.532,1055.74 455.541,1055.76 455.55,1055.78 455.559,1055.81 455.569,1055.83 455.578,1055.85 455.587,1055.88 455.596,1055.9 455.605,1055.92 455.614,1055.95 455.624,1055.97 455.633,1055.99 455.642,1056.02 455.651,1056.04 455.66,1056.06 455.67,1056.09 455.679,1056.11 455.688,1056.13 455.697,1056.16 455.706,1056.18 455.716,1056.2 455.725,1056.23 455.734,1056.25 455.743,1056.27 455.752,1056.3 455.761,1056.32 455.771,1056.34 455.78,1056.37 455.789,1056.39 455.798,1056.41 455.807,1056.44 455.817,1056.46 455.826,1056.49 455.835,1056.51 455.844,1056.53 455.853,1056.56 455.863,1056.58 455.872,1056.6 455.881,1056.63 455.89,1056.65 455.899,1056.67 455.909,1056.7 455.918,1056.72 455.927,1056.74 455.936,1056.77 455.945,1056.79 455.954,1056.81 455.964,1056.84 455.973,1056.86 455.982,1056.88 455.991,1056.91 456,1056.93 456.01,1056.95 456.019,1056.98 456.028,1057 456.037,1057.02 456.046,1057.05 456.056,1057.07 456.065,1057.09 456.074,1057.12 456.083,1057.14 456.092,1057.16 456.101,1057.19 456.111,1057.21 456.12,1057.23 456.129,1057.26 456.138,1057.28 456.147,1057.3 456.157,1057.33 456.166,1057.35 456.175,1057.37 456.184,1057.4 456.193,1057.42 456.203,1057.44 456.212,1057.47 456.221,1057.49 456.23,1057.51 456.239,1057.54 456.249,1057.56 456.258,1057.58 456.267,1057.61 456.276,1057.63 456.285,1057.65 456.294,1057.68 456.304,1057.7 456.313,1057.72 456.322,1057.74 456.331,1057.77 456.34,1057.79 456.35,1057.81 456.359,1057.84 456.368,1057.86 456.377,1057.88 456.386,1057.91 456.396,1057.93 456.405,1057.95 456.414,1057.98 456.423,1058 456.432,1058.02 456.441,1058.05 456.451,1058.07 456.46,1058.09 456.469,1058.12 456.478,1058.14 456.487,1058.16 456.497,1058.19 456.506,1058.21 456.515,1058.23 456.524,1058.26 456.533,1058.28 456.543,1058.3 456.552,1058.33 456.561,1058.35 456.57,1058.37 456.579,1058.4 456.589,1058.42 456.598,1058.44 456.607,1058.47 456.616,1058.49 456.625,1058.51 456.634,1058.54 456.644,1058.56 456.653,1058.58 456.662,1058.61 456.671,1058.63 456.68,1058.65 456.69,1058.67 456.699,1058.7 456.708,1058.72 456.717,1058.74 456.726,1058.77 456.736,1058.79 456.745,1058.81 456.754,1058.84 456.763,1058.86 456.772,1058.88 456.781,1058.91 456.791,1058.93 456.8,1058.95 456.809,1058.98 456.818,1059 456.827,1059.02 456.837,1059.05 456.846,1059.07 456.855,1059.09 456.864,1059.12 456.873,1059.14 456.883,1059.16 456.892,1059.18 456.901,1059.21 456.91,1059.23 456.919,1059.25 456.929,1059.28 456.938,1059.3 456.947,1059.32 456.956,1059.35 456.965,1059.37 456.974,1059.39 456.984,1059.42 456.993,1059.44 457.002,1059.46 457.011,1059.49 457.02,1059.51 457.03,1059.53 457.039,1059.56 457.048,1059.58 457.057,1059.6 457.066,1059.62 457.076,1059.65 457.085,1059.67 457.094,1059.69 457.103,1059.72 457.112,1059.74 457.121,1059.76 457.131,1059.79 457.14,1059.81 457.149,1059.83 457.158,1059.86 457.167,1059.88 457.177,1059.9 457.186,1059.92 457.195,1059.95 457.204,1059.97 457.213,1059.99 457.223,1060.02 457.232,1060.04 457.241,1060.06 457.25,1060.09 457.259,1060.11 457.269,1060.13 457.278,1060.16 457.287,1060.18 457.296,1060.2 457.305,1060.23 457.314,1060.25 457.324,1060.27 457.333,1060.29 457.342,1060.32 457.351,1060.34 457.36,1060.36 457.37,1060.39 457.379,1060.41 457.388,1060.43 457.397,1060.46 457.406,1060.48 457.416,1060.5 457.425,1060.52 457.434,1060.55 457.443,1060.57 457.452,1060.59 457.462,1060.62 457.471,1060.64 457.48,1060.66 457.489,1060.69 457.498,1060.71 457.507,1060.73 457.517,1060.76 457.526,1060.78 457.535,1060.8 457.544,1060.82 457.553,1060.85 457.563,1060.87 457.572,1060.89 457.581,1060.92 457.59,1060.94 457.599,1060.96 457.609,1060.99 457.618,1061.01 457.627,1061.03 457.636,1061.05 457.645,1061.08 457.654,1061.1 457.664,1061.12 457.673,1061.15 457.682,1061.17 457.691,1061.19 457.7,1061.22 457.71,1061.24 457.719,1061.26 457.728,1061.28 457.737,1061.31 457.746,1061.33 457.756,1061.35 457.765,1061.38 457.774,1061.4 457.783,1061.42 457.792,1061.45 457.802,1061.47 457.811,1061.49 457.82,1061.51 457.829,1061.54 457.838,1061.56 457.847,1061.58 457.857,1061.61 457.866,1061.63 457.875,1061.65 457.884,1061.68 457.893,1061.7 457.903,1061.72 457.912,1061.74 457.921,1061.77 457.93,1061.79 457.939,1061.81 457.949,1061.84 457.958,1061.86 457.967,1061.88 457.976,1061.9 457.985,1061.93 457.994,1061.95 458.004,1061.97 458.013,1062 458.022,1062.02 458.031,1062.04 458.04,1062.07 458.05,1062.09 458.059,1062.11 458.068,1062.13 458.077,1062.16 458.086,1062.18 458.096,1062.2 458.105,1062.23 458.114,1062.25 458.123,1062.27 458.132,1062.29 458.142,1062.32 458.151,1062.34 458.16,1062.36 458.169,1062.39 458.178,1062.41 458.187,1062.43 458.197,1062.45 458.206,1062.48 458.215,1062.5 458.224,1062.52 458.233,1062.55 458.243,1062.57 458.252,1062.59 458.261,1062.61 458.27,1062.64 458.279,1062.66 458.289,1062.68 458.298,1062.71 458.307,1062.73 458.316,1062.75 458.325,1062.78 458.334,1062.8 458.344,1062.82 458.353,1062.84 458.362,1062.87 458.371,1062.89 458.38,1062.91 458.39,1062.94 458.399,1062.96 458.408,1062.98 458.417,1063 458.426,1063.03 458.436,1063.05 458.445,1063.07 458.454,1063.09 458.463,1063.12 458.472,1063.14 458.482,1063.16 458.491,1063.19 458.5,1063.21 458.509,1063.23 458.518,1063.25 458.527,1063.28 458.537,1063.3 458.546,1063.32 458.555,1063.35 458.564,1063.37 458.573,1063.39 458.583,1063.41 458.592,1063.44 458.601,1063.46 458.61,1063.48 458.619,1063.51 458.629,1063.53 458.638,1063.55 458.647,1063.57 458.656,1063.6 458.665,1063.62 458.674,1063.64 458.684,1063.67 458.693,1063.69 458.702,1063.71 458.711,1063.73 458.72,1063.76 458.73,1063.78 458.739,1063.8 458.748,1063.82 458.757,1063.85 458.766,1063.87 458.776,1063.89 458.785,1063.92 458.794,1063.94 458.803,1063.96 458.812,1063.98 458.822,1064.01 458.831,1064.03 458.84,1064.05 458.849,1064.08 458.858,1064.1 458.867,1064.12 458.877,1064.14 458.886,1064.17 458.895,1064.19 458.904,1064.21 458.913,1064.23 458.923,1064.26 458.932,1064.28 458.941,1064.3 458.95,1064.33 458.959,1064.35 458.969,1064.37 458.978,1064.39 458.987,1064.42 458.996,1064.44 459.005,1064.46 459.014,1064.48 459.024,1064.51 459.033,1064.53 459.042,1064.55 459.051,1064.58 459.06,1064.6 459.07,1064.62 459.079,1064.64 459.088,1064.67 459.097,1064.69 459.106,1064.71 459.116,1064.73 459.125,1064.76 459.134,1064.78 459.143,1064.8 459.152,1064.83 459.162,1064.85 459.171,1064.87 459.18,1064.89 459.189,1064.92 459.198,1064.94 459.207,1064.96 459.217,1064.98 459.226,1065.01 459.235,1065.03 459.244,1065.05 459.253,1065.07 459.263,1065.1 459.272,1065.12 459.281,1065.14 459.29,1065.17 459.299,1065.19 459.309,1065.21 459.318,1065.23 459.327,1065.26 459.336,1065.28 459.345,1065.3 459.354,1065.32 459.364,1065.35 459.373,1065.37 459.382,1065.39 459.391,1065.41 459.4,1065.44 459.41,1065.46 459.419,1065.48 459.428,1065.51 459.437,1065.53 459.446,1065.55 459.456,1065.57 459.465,1065.6 459.474,1065.62 459.483,1065.64 459.492,1065.66 459.502,1065.69 459.511,1065.71 459.52,1065.73 459.529,1065.75 459.538,1065.78 459.547,1065.8 459.557,1065.82 459.566,1065.84 459.575,1065.87 459.584,1065.89 459.593,1065.91 459.603,1065.94 459.612,1065.96 459.621,1065.98 459.63,1066 459.639,1066.03 459.649,1066.05 459.658,1066.07 459.667,1066.09 459.676,1066.12 459.685,1066.14 459.695,1066.16 459.704,1066.18 459.713,1066.21 459.722,1066.23 459.731,1066.25 459.74,1066.27 459.75,1066.3 459.759,1066.32 459.768,1066.34 459.777,1066.36 459.786,1066.39 459.796,1066.41 459.805,1066.43 459.814,1066.45 459.823,1066.48 459.832,1066.5 459.842,1066.52 459.851,1066.54 459.86,1066.57 459.869,1066.59 459.878,1066.61 459.887,1066.63 459.897,1066.66 459.906,1066.68 459.915,1066.7 459.924,1066.72 459.933,1066.75 459.943,1066.77 459.952,1066.79 459.961,1066.82 459.97,1066.84 459.979,1066.86 459.989,1066.88 459.998,1066.91 460.007,1066.93 460.016,1066.95 460.025,1066.97 460.035,1067 460.044,1067.02 460.053,1067.04 460.062,1067.06 460.071,1067.09 460.08,1067.11 460.09,1067.13 460.099,1067.15 460.108,1067.18 460.117,1067.2 460.126,1067.22 460.136,1067.24 460.145,1067.27 460.154,1067.29 460.163,1067.31 460.172,1067.33 460.182,1067.36 460.191,1067.38 460.2,1067.4 460.209,1067.42 460.218,1067.45 460.227,1067.47 460.237,1067.49 460.246,1067.51 460.255,1067.54 460.264,1067.56 460.273,1067.58 460.283,1067.6 460.292,1067.62 460.301,1067.65 460.31,1067.67 460.319,1067.69 460.329,1067.71 460.338,1067.74 460.347,1067.76 460.356,1067.78 460.365,1067.8 460.375,1067.83 460.384,1067.85 460.393,1067.87 460.402,1067.89 460.411,1067.92 460.42,1067.94 460.43,1067.96 460.439,1067.98 460.448,1068.01 460.457,1068.03 460.466,1068.05 460.476,1068.07 460.485,1068.1 460.494,1068.12 460.503,1068.14 460.512,1068.16 460.522,1068.19 460.531,1068.21 460.54,1068.23 460.549,1068.25 460.558,1068.28 460.567,1068.3 460.577,1068.32 460.586,1068.34 460.595,1068.37 460.604,1068.39 460.613,1068.41 460.623,1068.43 460.632,1068.45 460.641,1068.48 460.65,1068.5 460.659,1068.52 460.669,1068.54 460.678,1068.57 460.687,1068.59 460.696,1068.61 460.705,1068.63 460.715,1068.66 460.724,1068.68 460.733,1068.7 460.742,1068.72 460.751,1068.75 460.76,1068.77 460.77,1068.79 460.779,1068.81 460.788,1068.83 460.797,1068.86 460.806,1068.88 460.816,1068.9 460.825,1068.92 460.834,1068.95 460.843,1068.97 460.852,1068.99 460.862,1069.01 460.871,1069.04 460.88,1069.06 460.889,1069.08 460.898,1069.1 460.907,1069.13 460.917,1069.15 460.926,1069.17 460.935,1069.19 460.944,1069.21 460.953,1069.24 460.963,1069.26 460.972,1069.28 460.981,1069.3 460.99,1069.33 460.999,1069.35 461.009,1069.37 461.018,1069.39 461.027,1069.42 461.036,1069.44 461.045,1069.46 461.055,1069.48 461.064,1069.5 461.073,1069.53 461.082,1069.55 461.091,1069.57 461.1,1069.59 461.11,1069.62 461.119,1069.64 461.128,1069.66 461.137,1069.68 461.146,1069.71 461.156,1069.73 461.165,1069.75 461.174,1069.77 461.183,1069.79 461.192,1069.82 461.202,1069.84 461.211,1069.86 461.22,1069.88 461.229,1069.91 461.238,1069.93 461.247,1069.95 461.257,1069.97 461.266,1069.99 461.275,1070.02 461.284,1070.04 461.293,1070.06 461.303,1070.08 461.312,1070.11 461.321,1070.13 461.33,1070.15 461.339,1070.17 461.349,1070.2 461.358,1070.22 461.367,1070.24 461.376,1070.26 461.385,1070.28 461.395,1070.31 461.404,1070.33 461.413,1070.35 461.422,1070.37 461.431,1070.4 461.44,1070.42 461.45,1070.44 461.459,1070.46 461.468,1070.48 461.477,1070.51 461.486,1070.53 461.496,1070.55 461.505,1070.57 461.514,1070.6 461.523,1070.62 461.532,1070.64 461.542,1070.66 461.551,1070.68 461.56,1070.71 461.569,1070.73 461.578,1070.75 461.587,1070.77 461.597,1070.79 461.606,1070.82 461.615,1070.84 461.624,1070.86 461.633,1070.88 461.643,1070.91 461.652,1070.93 461.661,1070.95 461.67,1070.97 461.679,1070.99 461.689,1071.02 461.698,1071.04 461.707,1071.06 461.716,1071.08 461.725,1071.11 461.735,1071.13 461.744,1071.15 461.753,1071.17 461.762,1071.19 461.771,1071.22 461.78,1071.24 461.79,1071.26 461.799,1071.28 461.808,1071.3 461.817,1071.33 461.826,1071.35 461.836,1071.37 461.845,1071.39 461.854,1071.42 461.863,1071.44 461.872,1071.46 461.882,1071.48 461.891,1071.5 461.9,1071.53 461.909,1071.55 461.918,1071.57 461.927,1071.59 461.937,1071.61 461.946,1071.64 461.955,1071.66 461.964,1071.68 461.973,1071.7 461.983,1071.73 461.992,1071.75 462.001,1071.77 462.01,1071.79 462.019,1071.81 462.029,1071.84 462.038,1071.86 462.047,1071.88 462.056,1071.9 462.065,1071.92 462.075,1071.95 462.084,1071.97 462.093,1071.99 462.102,1072.01 462.111,1072.03 462.12,1072.06 462.13,1072.08 462.139,1072.1 462.148,1072.12 462.157,1072.15 462.166,1072.17 462.176,1072.19 462.185,1072.21 462.194,1072.23 462.203,1072.26 462.212,1072.28 462.222,1072.3 462.231,1072.32 462.24,1072.34 462.249,1072.37 462.258,1072.39 462.268,1072.41 462.277,1072.43 462.286,1072.45 462.295,1072.48 462.304,1072.5 462.313,1072.52 462.323,1072.54 462.332,1072.56 462.341,1072.59 462.35,1072.61 462.359,1072.63 462.369,1072.65 462.378,1072.67 462.387,1072.7 462.396,1072.72 462.405,1072.74 462.415,1072.76 462.424,1072.78 462.433,1072.81 462.442,1072.83 462.451,1072.85 462.46,1072.87 462.47,1072.89 462.479,1072.92 462.488,1072.94 462.497,1072.96 462.506,1072.98 462.516,1073 462.525,1073.03 462.534,1073.05 462.543,1073.07 462.552,1073.09 462.562,1073.11 462.571,1073.14 462.58,1073.16 462.589,1073.18 462.598,1073.2 462.608,1073.22 462.617,1073.25 462.626,1073.27 462.635,1073.29 462.644,1073.31 462.653,1073.33 462.663,1073.36 462.672,1073.38 462.681,1073.4 462.69,1073.42 462.699,1073.44 462.709,1073.47 462.718,1073.49 462.727,1073.51 462.736,1073.53 462.745,1073.55 462.755,1073.58 462.764,1073.6 462.773,1073.62 462.782,1073.64 462.791,1073.66 462.8,1073.69 462.81,1073.71 462.819,1073.73 462.828,1073.75 462.837,1073.77 462.846,1073.8 462.856,1073.82 462.865,1073.84 462.874,1073.86 462.883,1073.88 462.892,1073.9 462.902,1073.93 462.911,1073.95 462.92,1073.97 462.929,1073.99 462.938,1074.01 462.948,1074.04 462.957,1074.06 462.966,1074.08 462.975,1074.1 462.984,1074.12 462.993,1074.15 463.003,1074.17 463.012,1074.19 463.021,1074.21 463.03,1074.23 463.039,1074.26 463.049,1074.28 463.058,1074.3 463.067,1074.32 463.076,1074.34 463.085,1074.36 463.095,1074.39 463.104,1074.41 463.113,1074.43 463.122,1074.45 463.131,1074.47 463.14,1074.5 463.15,1074.52 463.159,1074.54 463.168,1074.56 463.177,1074.58 463.186,1074.61 463.196,1074.63 463.205,1074.65 463.214,1074.67 463.223,1074.69 463.232,1074.71 463.242,1074.74 463.251,1074.76 463.26,1074.78 463.269,1074.8 463.278,1074.82 463.288,1074.85 463.297,1074.87 463.306,1074.89 463.315,1074.91 463.324,1074.93 463.333,1074.96 463.343,1074.98 463.352,1075 463.361,1075.02 463.37,1075.04 463.379,1075.06 463.389,1075.09 463.398,1075.11 463.407,1075.13 463.416,1075.15 463.425,1075.17 463.435,1075.2 463.444,1075.22 463.453,1075.24 463.462,1075.26 463.471,1075.28 463.48,1075.3 463.49,1075.33 463.499,1075.35 463.508,1075.37 463.517,1075.39 463.526,1075.41 463.536,1075.43 463.545,1075.46 463.554,1075.48 463.563,1075.5 463.572,1075.52 463.582,1075.54 463.591,1075.57 463.6,1075.59 463.609,1075.61 463.618,1075.63 463.628,1075.65 463.637,1075.67 463.646,1075.7 463.655,1075.72 463.664,1075.74 463.673,1075.76 463.683,1075.78 463.692,1075.81 463.701,1075.83 463.71,1075.85 463.719,1075.87 463.729,1075.89 463.738,1075.91 463.747,1075.94 463.756,1075.96 463.765,1075.98 463.775,1076 463.784,1076.02 463.793,1076.04 463.802,1076.07 463.811,1076.09 463.82,1076.11 463.83,1076.13 463.839,1076.15 463.848,1076.17 463.857,1076.2 463.866,1076.22 463.876,1076.24 463.885,1076.26 463.894,1076.28 463.903,1076.31 463.912,1076.33 463.922,1076.35 463.931,1076.37 463.94,1076.39 463.949,1076.41 463.958,1076.44 463.968,1076.46 463.977,1076.48 463.986,1076.5 463.995,1076.52 464.004,1076.54 464.013,1076.57 464.023,1076.59 464.032,1076.61 464.041,1076.63 464.05,1076.65 464.059,1076.67 464.069,1076.7 464.078,1076.72 464.087,1076.74 464.096,1076.76 464.105,1076.78 464.115,1076.8 464.124,1076.83 464.133,1076.85 464.142,1076.87 464.151,1076.89 464.16,1076.91 464.17,1076.93 464.179,1076.96 464.188,1076.98 464.197,1077 464.206,1077.02 464.216,1077.04 464.225,1077.06 464.234,1077.09 464.243,1077.11 464.252,1077.13 464.262,1077.15 464.271,1077.17 464.28,1077.19 464.289,1077.22 464.298,1077.24 464.308,1077.26 464.317,1077.28 464.326,1077.3 464.335,1077.32 464.344,1077.35 464.353,1077.37 464.363,1077.39 464.372,1077.41 464.381,1077.43 464.39,1077.45 464.399,1077.47 464.409,1077.5 464.418,1077.52 464.427,1077.54 464.436,1077.56 464.445,1077.58 464.455,1077.6 464.464,1077.63 464.473,1077.65 464.482,1077.67 464.491,1077.69 464.5,1077.71 464.51,1077.73 464.519,1077.76 464.528,1077.78 464.537,1077.8 464.546,1077.82 464.556,1077.84 464.565,1077.86 464.574,1077.89 464.583,1077.91 464.592,1077.93 464.602,1077.95 464.611,1077.97 464.62,1077.99 464.629,1078.01 464.638,1078.04 464.648,1078.06 464.657,1078.08 464.666,1078.1 464.675,1078.12 464.684,1078.14 464.693,1078.17 464.703,1078.19 464.712,1078.21 464.721,1078.23 464.73,1078.25 464.739,1078.27 464.749,1078.29 464.758,1078.32 464.767,1078.34 464.776,1078.36 464.785,1078.38 464.795,1078.4 464.804,1078.42 464.813,1078.45 464.822,1078.47 464.831,1078.49 464.841,1078.51 464.85,1078.53 464.859,1078.55 464.868,1078.57 464.877,1078.6 464.886,1078.62 464.896,1078.64 464.905,1078.66 464.914,1078.68 464.923,1078.7 464.932,1078.73 464.942,1078.75 464.951,1078.77 464.96,1078.79 464.969,1078.81 464.978,1078.83 464.988,1078.85 464.997,1078.88 465.006,1078.9 465.015,1078.92 465.024,1078.94 465.033,1078.96 465.043,1078.98 465.052,1079 465.061,1079.03 465.07,1079.05 465.079,1079.07 465.089,1079.09 465.098,1079.11 465.107,1079.13 465.116,1079.16 465.125,1079.18 465.135,1079.2 465.144,1079.22 465.153,1079.24 465.162,1079.26 465.171,1079.28 465.181,1079.31 465.19,1079.33 465.199,1079.35 465.208,1079.37 465.217,1079.39 465.226,1079.41 465.236,1079.43 465.245,1079.46 465.254,1079.48 465.263,1079.5 465.272,1079.52 465.282,1079.54 465.291,1079.56 465.3,1079.58 465.309,1079.61 465.318,1079.63 465.328,1079.65 465.337,1079.67 465.346,1079.69 465.355,1079.71 465.364,1079.73 465.373,1079.76 465.383,1079.78 465.392,1079.8 465.401,1079.82 465.41,1079.84 465.419,1079.86 465.429,1079.88 465.438,1079.91 465.447,1079.93 465.456,1079.95 465.465,1079.97 465.475,1079.99 465.484,1080.01 465.493,1080.03 465.502,1080.06 465.511,1080.08 465.521,1080.1 465.53,1080.12 465.539,1080.14 465.548,1080.16 465.557,1080.18 465.566,1080.2 465.576,1080.23 465.585,1080.25 465.594,1080.27 465.603,1080.29 465.612,1080.31 465.622,1080.33 465.631,1080.35 465.64,1080.38 465.649,1080.4 465.658,1080.42 465.668,1080.44 465.677,1080.46 465.686,1080.48 465.695,1080.5 465.704,1080.53 465.713,1080.55 465.723,1080.57 465.732,1080.59 465.741,1080.61 465.75,1080.63 465.759,1080.65 465.769,1080.67 465.778,1080.7 465.787,1080.72 465.796,1080.74 465.805,1080.76 465.815,1080.78 465.824,1080.8 465.833,1080.82 465.842,1080.85 465.851,1080.87 465.861,1080.89 465.87,1080.91 465.879,1080.93 465.888,1080.95 465.897,1080.97 465.906,1080.99 465.916,1081.02 465.925,1081.04 465.934,1081.06 465.943,1081.08 465.952,1081.1 465.962,1081.12 465.971,1081.14 465.98,1081.16 465.989,1081.19 465.998,1081.21 466.008,1081.23 466.017,1081.25 466.026,1081.27 466.035,1081.29 466.044,1081.31 466.053,1081.34 466.063,1081.36 466.072,1081.38 466.081,1081.4 466.09,1081.42 466.099,1081.44 466.109,1081.46 466.118,1081.48 466.127,1081.51 466.136,1081.53 466.145,1081.55 466.155,1081.57 466.164,1081.59 466.173,1081.61 466.182,1081.63 466.191,1081.65 466.201,1081.68 466.21,1081.7 466.219,1081.72 466.228,1081.74 466.237,1081.76 466.246,1081.78 466.256,1081.8 466.265,1081.82 466.274,1081.85 466.283,1081.87 466.292,1081.89 466.302,1081.91 466.311,1081.93 466.32,1081.95 466.329,1081.97 466.338,1081.99 466.348,1082.01 466.357,1082.04 466.366,1082.06 466.375,1082.08 466.384,1082.1 466.393,1082.12 466.403,1082.14 466.412,1082.16 466.421,1082.18 466.43,1082.21 466.439,1082.23 466.449,1082.25 466.458,1082.27 466.467,1082.29 466.476,1082.31 466.485,1082.33 466.495,1082.35 466.504,1082.38 466.513,1082.4 466.522,1082.42 466.531,1082.44 466.541,1082.46 466.55,1082.48 466.559,1082.5 466.568,1082.52 466.577,1082.54 466.586,1082.57 466.596,1082.59 466.605,1082.61 466.614,1082.63 466.623,1082.65 466.632,1082.67 466.642,1082.69 466.651,1082.71 466.66,1082.74 466.669,1082.76 466.678,1082.78 466.688,1082.8 466.697,1082.82 466.706,1082.84 466.715,1082.86 466.724,1082.88 466.733,1082.9 466.743,1082.93 466.752,1082.95 466.761,1082.97 466.77,1082.99 466.779,1083.01 466.789,1083.03 466.798,1083.05 466.807,1083.07 466.816,1083.09 466.825,1083.12 466.835,1083.14 466.844,1083.16 466.853,1083.18 466.862,1083.2 466.871,1083.22 466.881,1083.24 466.89,1083.26 466.899,1083.28 466.908,1083.31 466.917,1083.33 466.926,1083.35 466.936,1083.37 466.945,1083.39 466.954,1083.41 466.963,1083.43 466.972,1083.45 466.982,1083.47 466.991,1083.5 467,1083.52 467.009,1083.54 467.018,1083.56 467.028,1083.58 467.037,1083.6 467.046,1083.62 467.055,1083.64 467.064,1083.66 467.074,1083.69 467.083,1083.71 467.092,1083.73 467.101,1083.75 467.11,1083.77 467.119,1083.79 467.129,1083.81 467.138,1083.83 467.147,1083.85 467.156,1083.87 467.165,1083.9 467.175,1083.92 467.184,1083.94 467.193,1083.96 467.202,1083.98 467.211,1084 467.221,1084.02 467.23,1084.04 467.239,1084.06 467.248,1084.09 467.257,1084.11 467.266,1084.13 467.276,1084.15 467.285,1084.17 467.294,1084.19 467.303,1084.21 467.312,1084.23 467.322,1084.25 467.331,1084.27 467.34,1084.3 467.349,1084.32 467.358,1084.34 467.368,1084.36 467.377,1084.38 467.386,1084.4 467.395,1084.42 467.404,1084.44 467.414,1084.46 467.423,1084.48 467.432,1084.51 467.441,1084.53 467.45,1084.55 467.459,1084.57 467.469,1084.59 467.478,1084.61 467.487,1084.63 467.496,1084.65 467.505,1084.67 467.515,1084.69 467.524,1084.72 467.533,1084.74 467.542,1084.76 467.551,1084.78 467.561,1084.8 467.57,1084.82 467.579,1084.84 467.588,1084.86 467.597,1084.88 467.606,1084.9 467.616,1084.93 467.625,1084.95 467.634,1084.97 467.643,1084.99 467.652,1085.01 467.662,1085.03 467.671,1085.05 467.68,1085.07 467.689,1085.09 467.698,1085.11 467.708,1085.13 467.717,1085.16 467.726,1085.18 467.735,1085.2 467.744,1085.22 467.754,1085.24 467.763,1085.26 467.772,1085.28 467.781,1085.3 467.79,1085.32 467.799,1085.34 467.809,1085.36 467.818,1085.39 467.827,1085.41 467.836,1085.43 467.845,1085.45 467.855,1085.47 467.864,1085.49 467.873,1085.51 467.882,1085.53 467.891,1085.55 467.901,1085.57 467.91,1085.59 467.919,1085.62 467.928,1085.64 467.937,1085.66 467.946,1085.68 467.956,1085.7 467.965,1085.72 467.974,1085.74 467.983,1085.76 467.992,1085.78 468.002,1085.8 468.011,1085.82 468.02,1085.85 468.029,1085.87 468.038,1085.89 468.048,1085.91 468.057,1085.93 468.066,1085.95 468.075,1085.97 468.084,1085.99 468.094,1086.01 468.103,1086.03 468.112,1086.05 468.121,1086.08 468.13,1086.1 468.139,1086.12 468.149,1086.14 468.158,1086.16 468.167,1086.18 468.176,1086.2 468.185,1086.22 468.195,1086.24 468.204,1086.26 468.213,1086.28 468.222,1086.3 468.231,1086.33 468.241,1086.35 468.25,1086.37 468.259,1086.39 468.268,1086.41 468.277,1086.43 468.286,1086.45 468.296,1086.47 468.305,1086.49 468.314,1086.51 468.323,1086.53 468.332,1086.55 468.342,1086.58 468.351,1086.6 468.36,1086.62 468.369,1086.64 468.378,1086.66 468.388,1086.68 468.397,1086.7 468.406,1086.72 468.415,1086.74 468.424,1086.76 468.434,1086.78 468.443,1086.8 468.452,1086.82 468.461,1086.85 468.47,1086.87 468.479,1086.89 468.489,1086.91 468.498,1086.93 468.507,1086.95 468.516,1086.97 468.525,1086.99 468.535,1087.01 468.544,1087.03 468.553,1087.05 468.562,1087.07 468.571,1087.1 468.581,1087.12 468.59,1087.14 468.599,1087.16 468.608,1087.18 468.617,1087.2 468.626,1087.22 468.636,1087.24 468.645,1087.26 468.654,1087.28 468.663,1087.3 468.672,1087.32 468.682,1087.34 468.691,1087.36 468.7,1087.39 468.709,1087.41 468.718,1087.43 468.728,1087.45 468.737,1087.47 468.746,1087.49 468.755,1087.51 468.764,1087.53 468.774,1087.55 468.783,1087.57 468.792,1087.59 468.801,1087.61 468.81,1087.63 468.819,1087.66 468.829,1087.68 468.838,1087.7 468.847,1087.72 468.856,1087.74 468.865,1087.76 468.875,1087.78 468.884,1087.8 468.893,1087.82 468.902,1087.84 468.911,1087.86 468.921,1087.88 468.93,1087.9 468.939,1087.92 468.948,1087.94 468.957,1087.97 468.966,1087.99 468.976,1088.01 468.985,1088.03 468.994,1088.05 469.003,1088.07 469.012,1088.09 469.022,1088.11 469.031,1088.13 469.04,1088.15 469.049,1088.17 469.058,1088.19 469.068,1088.21 469.077,1088.23 469.086,1088.26 469.095,1088.28 469.104,1088.3 469.114,1088.32 469.123,1088.34 469.132,1088.36 469.141,1088.38 469.15,1088.4 469.159,1088.42 469.169,1088.44 469.178,1088.46 469.187,1088.48 469.196,1088.5 469.205,1088.52 469.215,1088.54 469.224,1088.56 469.233,1088.59 469.242,1088.61 469.251,1088.63 469.261,1088.65 469.27,1088.67 469.279,1088.69 469.288,1088.71 469.297,1088.73 469.306,1088.75 469.316,1088.77 469.325,1088.79 469.334,1088.81 469.343,1088.83 469.352,1088.85 469.362,1088.87 469.371,1088.89 469.38,1088.92 469.389,1088.94 469.398,1088.96 469.408,1088.98 469.417,1089 469.426,1089.02 469.435,1089.04 469.444,1089.06 469.454,1089.08 469.463,1089.1 469.472,1089.12 469.481,1089.14 469.49,1089.16 469.499,1089.18 469.509,1089.2 469.518,1089.22 469.527,1089.24 469.536,1089.27 469.545,1089.29 469.555,1089.31 469.564,1089.33 469.573,1089.35 469.582,1089.37 469.591,1089.39 469.601,1089.41 469.61,1089.43 469.619,1089.45 469.628,1089.47 469.637,1089.49 469.647,1089.51 469.656,1089.53 469.665,1089.55 469.674,1089.57 469.683,1089.59 469.692,1089.61 469.702,1089.64 469.711,1089.66 469.72,1089.68 469.729,1089.7 469.738,1089.72 469.748,1089.74 469.757,1089.76 469.766,1089.78 469.775,1089.8 469.784,1089.82 469.794,1089.84 469.803,1089.86 469.812,1089.88 469.821,1089.9 469.83,1089.92 469.839,1089.94 469.849,1089.96 469.858,1089.98 469.867,1090 469.876,1090.03 469.885,1090.05 469.895,1090.07 469.904,1090.09 469.913,1090.11 469.922,1090.13 469.931,1090.15 469.941,1090.17 469.95,1090.19 469.959,1090.21 469.968,1090.23 469.977,1090.25 469.987,1090.27 469.996,1090.29 470.005,1090.31 470.014,1090.33 470.023,1090.35 470.032,1090.37 470.042,1090.39 470.051,1090.41 470.06,1090.44 470.069,1090.46 470.078,1090.48 470.088,1090.5 470.097,1090.52 470.106,1090.54 470.115,1090.56 470.124,1090.58 470.134,1090.6 470.143,1090.62 470.152,1090.64 470.161,1090.66 470.17,1090.68 470.179,1090.7 470.189,1090.72 470.198,1090.74 470.207,1090.76 470.216,1090.78 470.225,1090.8 470.235,1090.82 470.244,1090.84 470.253,1090.86 470.262,1090.89 470.271,1090.91 470.281,1090.93 470.29,1090.95 470.299,1090.97 470.308,1090.99 470.317,1091.01 470.327,1091.03 470.336,1091.05 470.345,1091.07 470.354,1091.09 470.363,1091.11 470.372,1091.13 470.382,1091.15 470.391,1091.17 470.4,1091.19 470.409,1091.21 470.418,1091.23 470.428,1091.25 470.437,1091.27 470.446,1091.29 470.455,1091.31 470.464,1091.33 470.474,1091.35 470.483,1091.37 470.492,1091.4 470.501,1091.42 470.51,1091.44 470.519,1091.46 470.529,1091.48 470.538,1091.5 470.547,1091.52 470.556,1091.54 470.565,1091.56 470.575,1091.58 470.584,1091.6 470.593,1091.62 470.602,1091.64 470.611,1091.66 470.621,1091.68 470.63,1091.7 470.639,1091.72 470.648,1091.74 470.657,1091.76 470.667,1091.78 470.676,1091.8 470.685,1091.82 470.694,1091.84 470.703,1091.86 470.712,1091.88 470.722,1091.9 470.731,1091.92 470.74,1091.95 470.749,1091.97 470.758,1091.99 470.768,1092.01 470.777,1092.03 470.786,1092.05 470.795,1092.07 470.804,1092.09 470.814,1092.11 470.823,1092.13 470.832,1092.15 470.841,1092.17 470.85,1092.19 470.859,1092.21 470.869,1092.23 470.878,1092.25 470.887,1092.27 470.896,1092.29 470.905,1092.31 470.915,1092.33 470.924,1092.35 470.933,1092.37 470.942,1092.39 470.951,1092.41 470.961,1092.43 470.97,1092.45 470.979,1092.47 470.988,1092.49 470.997,1092.51 471.007,1092.53 471.016,1092.55 471.025,1092.57 471.034,1092.59 471.043,1092.62 471.052,1092.64 471.062,1092.66 471.071,1092.68 471.08,1092.7 471.089,1092.72 471.098,1092.74 471.108,1092.76 471.117,1092.78 471.126,1092.8 471.135,1092.82 471.144,1092.84 471.154,1092.86 471.163,1092.88 471.172,1092.9 471.181,1092.92 471.19,1092.94 471.199,1092.96 471.209,1092.98 471.218,1093 471.227,1093.02 471.236,1093.04 471.245,1093.06 471.255,1093.08 471.264,1093.1 471.273,1093.12 471.282,1093.14 471.291,1093.16 471.301,1093.18 471.31,1093.2 471.319,1093.22 471.328,1093.24 471.337,1093.26 471.347,1093.28 471.356,1093.3 471.365,1093.32 471.374,1093.34 471.383,1093.36 471.392,1093.38 471.402,1093.4 471.411,1093.42 471.42,1093.44 471.429,1093.47 471.438,1093.49 471.448,1093.51 471.457,1093.53 471.466,1093.55 471.475,1093.57 471.484,1093.59 471.494,1093.61 471.503,1093.63 471.512,1093.65 471.521,1093.67 471.53,1093.69 471.539,1093.71 471.549,1093.73 471.558,1093.75 471.567,1093.77 471.576,1093.79 471.585,1093.81 471.595,1093.83 471.604,1093.85 471.613,1093.87 471.622,1093.89 471.631,1093.91 471.641,1093.93 471.65,1093.95 471.659,1093.97 471.668,1093.99 471.677,1094.01 471.687,1094.03 471.696,1094.05 471.705,1094.07 471.714,1094.09 471.723,1094.11 471.732,1094.13 471.742,1094.15 471.751,1094.17 471.76,1094.19 471.769,1094.21 471.778,1094.23 471.788,1094.25 471.797,1094.27 471.806,1094.29 471.815,1094.31 471.824,1094.33 471.834,1094.35 471.843,1094.37 471.852,1094.39 471.861,1094.41 471.87,1094.43 471.879,1094.45 471.889,1094.47 471.898,1094.49 471.907,1094.51 471.916,1094.53 471.925,1094.55 471.935,1094.57 471.944,1094.59 471.953,1094.61 471.962,1094.63 471.971,1094.65 471.981,1094.67 471.99,1094.69 471.999,1094.71 472.008,1094.73 472.017,1094.75 472.027,1094.77 472.036,1094.79 472.045,1094.81 472.054,1094.83 472.063,1094.85 472.072,1094.87 472.082,1094.89 472.091,1094.91 472.1,1094.93 472.109,1094.95 472.118,1094.97 472.128,1094.99 472.137,1095.01 472.146,1095.04 472.155,1095.06 472.164,1095.08 472.174,1095.1 472.183,1095.12 472.192,1095.14 472.201,1095.16 472.21,1095.18 472.22,1095.2 472.229,1095.22 472.238,1095.24 472.247,1095.26 472.256,1095.28 472.265,1095.3 472.275,1095.32 472.284,1095.34 472.293,1095.36 472.302,1095.38 472.311,1095.4 472.321,1095.42 472.33,1095.44 472.339,1095.46 472.348,1095.48 472.357,1095.5 472.367,1095.52 472.376,1095.54 472.385,1095.56 472.394,1095.58 472.403,1095.6 472.412,1095.62 472.422,1095.64 472.431,1095.66 472.44,1095.68 472.449,1095.7 472.458,1095.72 472.468,1095.74 472.477,1095.76 472.486,1095.78 472.495,1095.8 472.504,1095.82 472.514,1095.84 472.523,1095.86 472.532,1095.88 472.541,1095.9 472.55,1095.92 472.56,1095.94 472.569,1095.96 472.578,1095.98 472.587,1096 472.596,1096.02 472.605,1096.04 472.615,1096.06 472.624,1096.08 472.633,1096.1 472.642,1096.12 472.651,1096.14 472.661,1096.16 472.67,1096.18 472.679,1096.2 472.688,1096.22 472.697,1096.24 472.707,1096.26 472.716,1096.28 472.725,1096.3 472.734,1096.31 472.743,1096.33 472.752,1096.35 472.762,1096.37 472.771,1096.39 472.78,1096.41 472.789,1096.43 472.798,1096.45 472.808,1096.47 472.817,1096.49 472.826,1096.51 472.835,1096.53 472.844,1096.55 472.854,1096.57 472.863,1096.59 472.872,1096.61 472.881,1096.63 472.89,1096.65 472.9,1096.67 472.909,1096.69 472.918,1096.71 472.927,1096.73 472.936,1096.75 472.945,1096.77 472.955,1096.79 472.964,1096.81 472.973,1096.83 472.982,1096.85 472.991,1096.87 473.001,1096.89 473.01,1096.91 473.019,1096.93 473.028,1096.95 473.037,1096.97 473.047,1096.99 473.056,1097.01 473.065,1097.03 473.074,1097.05 473.083,1097.07 473.092,1097.09 473.102,1097.11 473.111,1097.13 473.12,1097.15 473.129,1097.17 473.138,1097.19 473.148,1097.21 473.157,1097.23 473.166,1097.25 473.175,1097.27 473.184,1097.29 473.194,1097.31 473.203,1097.33 473.212,1097.35 473.221,1097.37 473.23,1097.39 473.24,1097.41 473.249,1097.43 473.258,1097.45 473.267,1097.47 473.276,1097.49 473.285,1097.51 473.295,1097.53 473.304,1097.55 473.313,1097.57 473.322,1097.59 473.331,1097.61 473.341,1097.63 473.35,1097.65 473.359,1097.67 473.368,1097.69 473.377,1097.71 473.387,1097.73 473.396,1097.75 473.405,1097.77 473.414,1097.79 473.423,1097.81 473.432,1097.83 473.442,1097.85 473.451,1097.86 473.46,1097.88 473.469,1097.9 473.478,1097.92 473.488,1097.94 473.497,1097.96 473.506,1097.98 473.515,1098 473.524,1098.02 473.534,1098.04 473.543,1098.06 473.552,1098.08 473.561,1098.1 473.57,1098.12 473.58,1098.14 473.589,1098.16 473.598,1098.18 473.607,1098.2 473.616,1098.22 473.625,1098.24 473.635,1098.26 473.644,1098.28 473.653,1098.3 473.662,1098.32 473.671,1098.34 473.681,1098.36 473.69,1098.38 473.699,1098.4 473.708,1098.42 473.717,1098.44 473.727,1098.46 473.736,1098.48 473.745,1098.5 473.754,1098.52 473.763,1098.54 473.772,1098.56 473.782,1098.58 473.791,1098.6 473.8,1098.62 473.809,1098.64 473.818,1098.66 473.828,1098.68 473.837,1098.7 473.846,1098.71 473.855,1098.73 473.864,1098.75 473.874,1098.77 473.883,1098.79 473.892,1098.81 473.901,1098.83 473.91,1098.85 473.92,1098.87 473.929,1098.89 473.938,1098.91 473.947,1098.93 473.956,1098.95 473.965,1098.97 473.975,1098.99 473.984,1099.01 473.993,1099.03 474.002,1099.05 474.011,1099.07 474.021,1099.09 474.03,1099.11 474.039,1099.13 474.048,1099.15 474.057,1099.17 474.067,1099.19 474.076,1099.21 474.085,1099.23 474.094,1099.25 474.103,1099.27 474.112,1099.29 474.122,1099.31 474.131,1099.33 474.14,1099.35 474.149,1099.36 474.158,1099.38 474.168,1099.4 474.177,1099.42 474.186,1099.44 474.195,1099.46 474.204,1099.48 474.214,1099.5 474.223,1099.52 474.232,1099.54 474.241,1099.56 474.25,1099.58 474.26,1099.6 474.269,1099.62 474.278,1099.64 474.287,1099.66 474.296,1099.68 474.305,1099.7 474.315,1099.72 474.324,1099.74 474.333,1099.76 474.342,1099.78 474.351,1099.8 474.361,1099.82 474.37,1099.84 474.379,1099.86 474.388,1099.88 474.397,1099.9 474.407,1099.91 474.416,1099.93 474.425,1099.95 474.434,1099.97 474.443,1099.99 474.452,1100.01 474.462,1100.03 474.471,1100.05 474.48,1100.07 474.489,1100.09 474.498,1100.11 474.508,1100.13 474.517,1100.15 474.526,1100.17 474.535,1100.19 474.544,1100.21 474.554,1100.23 474.563,1100.25 474.572,1100.27 474.581,1100.29 474.59,1100.31 474.6,1100.33 474.609,1100.35 474.618,1100.37 474.627,1100.39 474.636,1100.4 474.645,1100.42 474.655,1100.44 474.664,1100.46 474.673,1100.48 474.682,1100.5 474.691,1100.52 474.701,1100.54 474.71,1100.56 474.719,1100.58 474.728,1100.6 474.737,1100.62 474.747,1100.64 474.756,1100.66 474.765,1100.68 474.774,1100.7 474.783,1100.72 474.793,1100.74 474.802,1100.76 474.811,1100.78 474.82,1100.8 474.829,1100.82 474.838,1100.83 474.848,1100.85 474.857,1100.87 474.866,1100.89 474.875,1100.91 474.884,1100.93 474.894,1100.95 474.903,1100.97 474.912,1100.99 474.921,1101.01 474.93,1101.03 474.94,1101.05 474.949,1101.07 474.958,1101.09 474.967,1101.11 474.976,1101.13 474.985,1101.15 474.995,1101.17 475.004,1101.19 475.013,1101.21 475.022,1101.23 475.031,1101.24 475.041,1101.26 475.05,1101.28 475.059,1101.3 475.068,1101.32 475.077,1101.34 475.087,1101.36 475.096,1101.38 475.105,1101.4 475.114,1101.42 475.123,1101.44 475.133,1101.46 475.142,1101.48 475.151,1101.5 475.16,1101.52 475.169,1101.54 475.178,1101.56 475.188,1101.58 475.197,1101.6 475.206,1101.61 475.215,1101.63 475.224,1101.65 475.234,1101.67 475.243,1101.69 475.252,1101.71 475.261,1101.73 475.27,1101.75 475.28,1101.77 475.289,1101.79 475.298,1101.81 475.307,1101.83 475.316,1101.85 475.325,1101.87 475.335,1101.89 475.344,1101.91 475.353,1101.93 475.362,1101.95 475.371,1101.96 475.381,1101.98 475.39,1102 475.399,1102.02 475.408,1102.04 475.417,1102.06 475.427,1102.08 475.436,1102.1 475.445,1102.12 475.454,1102.14 475.463,1102.16 475.473,1102.18 475.482,1102.2 475.491,1102.22 475.5,1102.24 475.509,1102.26 475.518,1102.28 475.528,1102.29 475.537,1102.31 475.546,1102.33 475.555,1102.35 475.564,1102.37 475.574,1102.39 475.583,1102.41 475.592,1102.43 475.601,1102.45 475.61,1102.47 475.62,1102.49 475.629,1102.51 475.638,1102.53 475.647,1102.55 475.656,1102.57 475.665,1102.59 475.675,1102.6 475.684,1102.62 475.693,1102.64 475.702,1102.66 475.711,1102.68 475.721,1102.7 475.73,1102.72 475.739,1102.74 475.748,1102.76 475.757,1102.78 475.767,1102.8 475.776,1102.82 475.785,1102.84 475.794,1102.86 475.803,1102.88 475.813,1102.9 475.822,1102.91 475.831,1102.93 475.84,1102.95 475.849,1102.97 475.858,1102.99 475.868,1103.01 475.877,1103.03 475.886,1103.05 475.895,1103.07 475.904,1103.09 475.914,1103.11 475.923,1103.13 475.932,1103.15 475.941,1103.17 475.95,1103.19 475.96,1103.2 475.969,1103.22 475.978,1103.24 475.987,1103.26 475.996,1103.28 476.005,1103.3 476.015,1103.32 476.024,1103.34 476.033,1103.36 476.042,1103.38 476.051,1103.4 476.061,1103.42 476.07,1103.44 476.079,1103.46 476.088,1103.47 476.097,1103.49 476.107,1103.51 476.116,1103.53 476.125,1103.55 476.134,1103.57 476.143,1103.59 476.153,1103.61 476.162,1103.63 476.171,1103.65 476.18,1103.67 476.189,1103.69 476.198,1103.71 476.208,1103.73 476.217,1103.74 476.226,1103.76 476.235,1103.78 476.244,1103.8 476.254,1103.82 476.263,1103.84 476.272,1103.86 476.281,1103.88 476.29,1103.9 476.3,1103.92 476.309,1103.94 476.318,1103.96 476.327,1103.98 476.336,1104 476.345,1104.01 476.355,1104.03 476.364,1104.05 476.373,1104.07 476.382,1104.09 476.391,1104.11 476.401,1104.13 476.41,1104.15 476.419,1104.17 476.428,1104.19 476.437,1104.21 476.447,1104.23 476.456,1104.25 476.465,1104.26 476.474,1104.28 476.483,1104.3 476.493,1104.32 476.502,1104.34 476.511,1104.36 476.52,1104.38 476.529,1104.4 476.538,1104.42 476.548,1104.44 476.557,1104.46 476.566,1104.48 476.575,1104.49 476.584,1104.51 476.594,1104.53 476.603,1104.55 476.612,1104.57 476.621,1104.59 476.63,1104.61 476.64,1104.63 476.649,1104.65 476.658,1104.67 476.667,1104.69 476.676,1104.71 476.685,1104.73 476.695,1104.74 476.704,1104.76 476.713,1104.78 476.722,1104.8 476.731,1104.82 476.741,1104.84 476.75,1104.86 476.759,1104.88 476.768,1104.9 476.777,1104.92 476.787,1104.94 476.796,1104.96 476.805,1104.97 476.814,1104.99 476.823,1105.01 476.833,1105.03 476.842,1105.05 476.851,1105.07 476.86,1105.09 476.869,1105.11 476.878,1105.13 476.888,1105.15 476.897,1105.17 476.906,1105.18 476.915,1105.2 476.924,1105.22 476.934,1105.24 476.943,1105.26 476.952,1105.28 476.961,1105.3 476.97,1105.32 476.98,1105.34 476.989,1105.36 476.998,1105.38 477.007,1105.4 477.016,1105.41 477.026,1105.43 477.035,1105.45 477.044,1105.47 477.053,1105.49 477.062,1105.51 477.071,1105.53 477.081,1105.55 477.09,1105.57 477.099,1105.59 477.108,1105.61 477.117,1105.62 477.127,1105.64 477.136,1105.66 477.145,1105.68 477.154,1105.7 477.163,1105.72 477.173,1105.74 477.182,1105.76 477.191,1105.78 477.2,1105.8 477.209,1105.82 477.218,1105.83 477.228,1105.85 477.237,1105.87 477.246,1105.89 477.255,1105.91 477.264,1105.93 477.274,1105.95 477.283,1105.97 477.292,1105.99 477.301,1106.01 477.31,1106.03 477.32,1106.04 477.329,1106.06 477.338,1106.08 477.347,1106.1 477.356,1106.12 477.366,1106.14 477.375,1106.16 477.384,1106.18 477.393,1106.2 477.402,1106.22 477.411,1106.23 477.421,1106.25 477.43,1106.27 477.439,1106.29 477.448,1106.31 477.457,1106.33 477.467,1106.35 477.476,1106.37 477.485,1106.39 477.494,1106.41 477.503,1106.43 477.513,1106.44 477.522,1106.46 477.531,1106.48 477.54,1106.5 477.549,1106.52 477.558,1106.54 477.568,1106.56 477.577,1106.58 477.586,1106.6 477.595,1106.62 477.604,1106.63 477.614,1106.65 477.623,1106.67 477.632,1106.69 477.641,1106.71 477.65,1106.73 477.66,1106.75 477.669,1106.77 477.678,1106.79 477.687,1106.81 477.696,1106.82 477.706,1106.84 477.715,1106.86 477.724,1106.88 477.733,1106.9 477.742,1106.92 477.751,1106.94 477.761,1106.96 477.77,1106.98 477.779,1107 477.788,1107.01 477.797,1107.03 477.807,1107.05 477.816,1107.07 477.825,1107.09 477.834,1107.11 477.843,1107.13 477.853,1107.15 477.862,1107.17 477.871,1107.18 477.88,1107.2 477.889,1107.22 477.898,1107.24 477.908,1107.26 477.917,1107.28 477.926,1107.3 477.935,1107.32 477.944,1107.34 477.954,1107.36 477.963,1107.37 477.972,1107.39 477.981,1107.41 477.99,1107.43 478,1107.45 478.009,1107.47 478.018,1107.49 478.027,1107.51 478.036,1107.53 478.046,1107.54 478.055,1107.56 478.064,1107.58 478.073,1107.6 478.082,1107.62 478.091,1107.64 478.101,1107.66 478.11,1107.68 478.119,1107.7 478.128,1107.71 478.137,1107.73 478.147,1107.75 478.156,1107.77 478.165,1107.79 478.174,1107.81 478.183,1107.83 478.193,1107.85 478.202,1107.87 478.211,1107.88 478.22,1107.9 478.229,1107.92 478.238,1107.94 478.248,1107.96 478.257,1107.98 478.266,1108 478.275,1108.02 478.284,1108.04 478.294,1108.05 478.303,1108.07 478.312,1108.09 478.321,1108.11 478.33,1108.13 478.34,1108.15 478.349,1108.17 478.358,1108.19 478.367,1108.21 478.376,1108.22 478.386,1108.24 478.395,1108.26 478.404,1108.28 478.413,1108.3 478.422,1108.32 478.431,1108.34 478.441,1108.36 478.45,1108.38 478.459,1108.39 478.468,1108.41 478.477,1108.43 478.487,1108.45 478.496,1108.47 478.505,1108.49 478.514,1108.51 478.523,1108.53 478.533,1108.55 478.542,1108.56 478.551,1108.58 478.56,1108.6 478.569,1108.62 478.578,1108.64 478.588,1108.66 478.597,1108.68 478.606,1108.7 478.615,1108.71 478.624,1108.73 478.634,1108.75 478.643,1108.77 478.652,1108.79 478.661,1108.81 478.67,1108.83 478.68,1108.85 478.689,1108.86 478.698,1108.88 478.707,1108.9 478.716,1108.92 478.726,1108.94 478.735,1108.96 478.744,1108.98 478.753,1109 478.762,1109.02 478.771,1109.03 478.781,1109.05 478.79,1109.07 478.799,1109.09 478.808,1109.11 478.817,1109.13 478.827,1109.15 478.836,1109.17 478.845,1109.18 478.854,1109.2 478.863,1109.22 478.873,1109.24 478.882,1109.26 478.891,1109.28 478.9,1109.3 478.909,1109.32 478.918,1109.33 478.928,1109.35 478.937,1109.37 478.946,1109.39 478.955,1109.41 478.964,1109.43 478.974,1109.45 478.983,1109.47 478.992,1109.48 479.001,1109.5 479.01,1109.52 479.02,1109.54 479.029,1109.56 479.038,1109.58 479.047,1109.6 479.056,1109.62 479.066,1109.63 479.075,1109.65 479.084,1109.67 479.093,1109.69 479.102,1109.71 479.111,1109.73 479.121,1109.75 479.13,1109.77 479.139,1109.78 479.148,1109.8 479.157,1109.82 479.167,1109.84 479.176,1109.86 479.185,1109.88 479.194,1109.9 479.203,1109.92 479.213,1109.93 479.222,1109.95 479.231,1109.97 479.24,1109.99 479.249,1110.01 479.258,1110.03 479.268,1110.05 479.277,1110.06 479.286,1110.08 479.295,1110.1 479.304,1110.12 479.314,1110.14 479.323,1110.16 479.332,1110.18 479.341,1110.2 479.35,1110.21 479.36,1110.23 479.369,1110.25 479.378,1110.27 479.387,1110.29 479.396,1110.31 479.406,1110.33 479.415,1110.34 479.424,1110.36 479.433,1110.38 479.442,1110.4 479.451,1110.42 479.461,1110.44 479.47,1110.46 479.479,1110.48 479.488,1110.49 479.497,1110.51 479.507,1110.53 479.516,1110.55 479.525,1110.57 479.534,1110.59 479.543,1110.61 479.553,1110.62 479.562,1110.64 479.571,1110.66 479.58,1110.68 479.589,1110.7 479.599,1110.72 479.608,1110.74 479.617,1110.76 479.626,1110.77 479.635,1110.79 479.644,1110.81 479.654,1110.83 479.663,1110.85 479.672,1110.87 479.681,1110.89 479.69,1110.9 479.7,1110.92 479.709,1110.94 479.718,1110.96 479.727,1110.98 479.736,1111 479.746,1111.02 479.755,1111.03 479.764,1111.05 479.773,1111.07 479.782,1111.09 479.791,1111.11 479.801,1111.13 479.81,1111.15 479.819,1111.16 479.828,1111.18 479.837,1111.2 479.847,1111.22 479.856,1111.24 479.865,1111.26 479.874,1111.28 479.883,1111.29 479.893,1111.31 479.902,1111.33 479.911,1111.35 479.92,1111.37 479.929,1111.39 479.939,1111.41 479.948,1111.42 479.957,1111.44 479.966,1111.46 479.975,1111.48 479.984,1111.5 479.994,1111.52 480.003,1111.54 480.012,1111.55 480.021,1111.57 480.03,1111.59 480.04,1111.61 480.049,1111.63 480.058,1111.65 480.067,1111.67 480.076,1111.68 480.086,1111.7 480.095,1111.72 480.104,1111.74 480.113,1111.76 480.122,1111.78 480.131,1111.8 480.141,1111.81 480.15,1111.83 480.159,1111.85 480.168,1111.87 480.177,1111.89 480.187,1111.91 480.196,1111.93 480.205,1111.94 480.214,1111.96 480.223,1111.98 480.233,1112 480.242,1112.02 480.251,1112.04 480.26,1112.05 480.269,1112.07 480.279,1112.09 480.288,1112.11 480.297,1112.13 480.306,1112.15 480.315,1112.17 480.324,1112.18 480.334,1112.2 480.343,1112.22 480.352,1112.24 480.361,1112.26 480.37,1112.28 480.38,1112.3 480.389,1112.31 480.398,1112.33 480.407,1112.35 480.416,1112.37 480.426,1112.39 480.435,1112.41 480.444,1112.42 480.453,1112.44 480.462,1112.46 480.471,1112.48 480.481,1112.5 480.49,1112.52 480.499,1112.54 480.508,1112.55 480.517,1112.57 480.527,1112.59 480.536,1112.61 480.545,1112.63 480.554,1112.65 480.563,1112.66 480.573,1112.68 480.582,1112.7 480.591,1112.72 480.6,1112.74 480.609,1112.76 480.619,1112.78 480.628,1112.79 480.637,1112.81 480.646,1112.83 480.655,1112.85 480.664,1112.87 480.674,1112.89 480.683,1112.9 480.692,1112.92 480.701,1112.94 480.71,1112.96 480.72,1112.98 480.729,1113 480.738,1113.01 480.747,1113.03 480.756,1113.05 480.766,1113.07 480.775,1113.09 480.784,1113.11 480.793,1113.13 480.802,1113.14 480.811,1113.16 480.821,1113.18 480.83,1113.2 480.839,1113.22 480.848,1113.24 480.857,1113.25 480.867,1113.27 480.876,1113.29 480.885,1113.31 480.894,1113.33 480.903,1113.35 480.913,1113.36 480.922,1113.38 480.931,1113.4 480.94,1113.42 480.949,1113.44 480.959,1113.46 480.968,1113.47 480.977,1113.49 480.986,1113.51 480.995,1113.53 481.004,1113.55 481.014,1113.57 481.023,1113.59 481.032,1113.6 481.041,1113.62 481.05,1113.64 481.06,1113.66 481.069,1113.68 481.078,1113.7 481.087,1113.71 481.096,1113.73 481.106,1113.75 481.115,1113.77 481.124,1113.79 481.133,1113.81 481.142,1113.82 481.151,1113.84 481.161,1113.86 481.17,1113.88 481.179,1113.9 481.188,1113.92 481.197,1113.93 481.207,1113.95 481.216,1113.97 481.225,1113.99 481.234,1114.01 481.243,1114.03 481.253,1114.04 481.262,1114.06 481.271,1114.08 481.28,1114.1 481.289,1114.12 481.299,1114.14 481.308,1114.15 481.317,1114.17 481.326,1114.19 481.335,1114.21 481.344,1114.23 481.354,1114.25 481.363,1114.26 481.372,1114.28 481.381,1114.3 481.39,1114.32 481.4,1114.34 481.409,1114.36 481.418,1114.37 481.427,1114.39 481.436,1114.41 481.446,1114.43 481.455,1114.45 481.464,1114.46 481.473,1114.48 481.482,1114.5 481.491,1114.52 481.501,1114.54 481.51,1114.56 481.519,1114.57 481.528,1114.59 481.537,1114.61 481.547,1114.63 481.556,1114.65 481.565,1114.67 481.574,1114.68 481.583,1114.7 481.593,1114.72 481.602,1114.74 481.611,1114.76 481.62,1114.78 481.629,1114.79 481.639,1114.81 481.648,1114.83 481.657,1114.85 481.666,1114.87 481.675,1114.89 481.684,1114.9 481.694,1114.92 481.703,1114.94 481.712,1114.96 481.721,1114.98 481.73,1114.99 481.74,1115.01 481.749,1115.03 481.758,1115.05 481.767,1115.07 481.776,1115.09 481.786,1115.1 481.795,1115.12 481.804,1115.14 481.813,1115.16 481.822,1115.18 481.831,1115.2 481.841,1115.21 481.85,1115.23 481.859,1115.25 481.868,1115.27 481.877,1115.29 481.887,1115.3 481.896,1115.32 481.905,1115.34 481.914,1115.36 481.923,1115.38 481.933,1115.4 481.942,1115.41 481.951,1115.43 481.96,1115.45 481.969,1115.47 481.979,1115.49 481.988,1115.5 481.997,1115.52 482.006,1115.54 482.015,1115.56 482.024,1115.58 482.034,1115.6 482.043,1115.61 482.052,1115.63 482.061,1115.65 482.07,1115.67 482.08,1115.69 482.089,1115.7 482.098,1115.72 482.107,1115.74 482.116,1115.76 482.126,1115.78 482.135,1115.8 482.144,1115.81 482.153,1115.83 482.162,1115.85 482.172,1115.87 482.181,1115.89 482.19,1115.9 482.199,1115.92 482.208,1115.94 482.217,1115.96 482.227,1115.98 482.236,1116 482.245,1116.01 482.254,1116.03 482.263,1116.05 482.273,1116.07 482.282,1116.09 482.291,1116.1 482.3,1116.12 482.309,1116.14 482.319,1116.16 482.328,1116.18 482.337,1116.19 482.346,1116.21 482.355,1116.23 482.364,1116.25 482.374,1116.27 482.383,1116.29 482.392,1116.3 482.401,1116.32 482.41,1116.34 482.42,1116.36 482.429,1116.38 482.438,1116.39 482.447,1116.41 482.456,1116.43 482.466,1116.45 482.475,1116.47 482.484,1116.48 482.493,1116.5 482.502,1116.52 482.512,1116.54 482.521,1116.56 482.53,1116.58 482.539,1116.59 482.548,1116.61 482.557,1116.63 482.567,1116.65 482.576,1116.67 482.585,1116.68 482.594,1116.7 482.603,1116.72 482.613,1116.74 482.622,1116.76 482.631,1116.77 482.64,1116.79 482.649,1116.81 482.659,1116.83 482.668,1116.85 482.677,1116.86 482.686,1116.88 482.695,1116.9 482.704,1116.92 482.714,1116.94 482.723,1116.95 482.732,1116.97 482.741,1116.99 482.75,1117.01 482.76,1117.03 482.769,1117.04 482.778,1117.06 482.787,1117.08 482.796,1117.1 482.806,1117.12 482.815,1117.14 482.824,1117.15 482.833,1117.17 482.842,1117.19 482.852,1117.21 482.861,1117.23 482.87,1117.24 482.879,1117.26 482.888,1117.28 482.897,1117.3 482.907,1117.32 482.916,1117.33 482.925,1117.35 482.934,1117.37 482.943,1117.39 482.953,1117.41 482.962,1117.42 482.971,1117.44 482.98,1117.46 482.989,1117.48 482.999,1117.5 483.008,1117.51 483.017,1117.53 483.026,1117.55 483.035,1117.57 483.044,1117.59 483.054,1117.6 483.063,1117.62 483.072,1117.64 483.081,1117.66 483.09,1117.68 483.1,1117.69 483.109,1117.71 483.118,1117.73 483.127,1117.75 483.136,1117.77 483.146,1117.78 483.155,1117.8 483.164,1117.82 483.173,1117.84 483.182,1117.86 483.192,1117.87 483.201,1117.89 483.21,1117.91 483.219,1117.93 483.228,1117.95 483.237,1117.96 483.247,1117.98 483.256,1118 483.265,1118.02 483.274,1118.04 483.283,1118.05 483.293,1118.07 483.302,1118.09 483.311,1118.11 483.32,1118.13 483.329,1118.14 483.339,1118.16 483.348,1118.18 483.357,1118.2 483.366,1118.21 483.375,1118.23 483.384,1118.25 483.394,1118.27 483.403,1118.29 483.412,1118.3 483.421,1118.32 483.43,1118.34 483.44,1118.36 483.449,1118.38 483.458,1118.39 483.467,1118.41 483.476,1118.43 483.486,1118.45 483.495,1118.47 483.504,1118.48 483.513,1118.5 483.522,1118.52 483.532,1118.54 483.541,1118.56 483.55,1118.57 483.559,1118.59 483.568,1118.61 483.577,1118.63 483.587,1118.64 483.596,1118.66 483.605,1118.68 483.614,1118.7 483.623,1118.72 483.633,1118.73 483.642,1118.75 483.651,1118.77 483.66,1118.79 483.669,1118.81 483.679,1118.82 483.688,1118.84 483.697,1118.86 483.706,1118.88 483.715,1118.9 483.724,1118.91 483.734,1118.93 483.743,1118.95 483.752,1118.97 483.761,1118.98 483.77,1119 483.78,1119.02 483.789,1119.04 483.798,1119.06 483.807,1119.07 483.816,1119.09 483.826,1119.11 483.835,1119.13 483.844,1119.15 483.853,1119.16 483.862,1119.18 483.872,1119.2 483.881,1119.22 483.89,1119.23 483.899,1119.25 483.908,1119.27 483.917,1119.29 483.927,1119.31 483.936,1119.32 483.945,1119.34 483.954,1119.36 483.963,1119.38 483.973,1119.4 483.982,1119.41 483.991,1119.43 484,1119.45 484.009,1119.47 484.019,1119.48 484.028,1119.5 484.037,1119.52 484.046,1119.54 484.055,1119.56 484.064,1119.57 484.074,1119.59 484.083,1119.61 484.092,1119.63 484.101,1119.64 484.11,1119.66 484.12,1119.68 484.129,1119.7 484.138,1119.72 484.147,1119.73 484.156,1119.75 484.166,1119.77 484.175,1119.79 484.184,1119.81 484.193,1119.82 484.202,1119.84 484.212,1119.86 484.221,1119.88 484.23,1119.89 484.239,1119.91 484.248,1119.93 484.257,1119.95 484.267,1119.97 484.276,1119.98 484.285,1120 484.294,1120.02 484.303,1120.04 484.313,1120.05 484.322,1120.07 484.331,1120.09 484.34,1120.11 484.349,1120.13 484.359,1120.14 484.368,1120.16 484.377,1120.18 484.386,1120.2 484.395,1120.21 484.405,1120.23 484.414,1120.25 484.423,1120.27 484.432,1120.29 484.441,1120.3 484.45,1120.32 484.46,1120.34 484.469,1120.36 484.478,1120.37 484.487,1120.39 484.496,1120.41 484.506,1120.43 484.515,1120.44 484.524,1120.46 484.533,1120.48 484.542,1120.5 484.552,1120.52 484.561,1120.53 484.57,1120.55 484.579,1120.57 484.588,1120.59 484.597,1120.6 484.607,1120.62 484.616,1120.64 484.625,1120.66 484.634,1120.68 484.643,1120.69 484.653,1120.71 484.662,1120.73 484.671,1120.75 484.68,1120.76 484.689,1120.78 484.699,1120.8 484.708,1120.82 484.717,1120.83 484.726,1120.85 484.735,1120.87 484.745,1120.89 484.754,1120.91 484.763,1120.92 484.772,1120.94 484.781,1120.96 484.79,1120.98 484.8,1120.99 484.809,1121.01 484.818,1121.03 484.827,1121.05 484.836,1121.06 484.846,1121.08 484.855,1121.1 484.864,1121.12 484.873,1121.14 484.882,1121.15 484.892,1121.17 484.901,1121.19 484.91,1121.21 484.919,1121.22 484.928,1121.24 484.937,1121.26 484.947,1121.28 484.956,1121.29 484.965,1121.31 484.974,1121.33 484.983,1121.35 484.993,1121.36 485.002,1121.38 485.011,1121.4 485.02,1121.42 485.029,1121.44 485.039,1121.45 485.048,1121.47 485.057,1121.49 485.066,1121.51 485.075,1121.52 485.085,1121.54 485.094,1121.56 485.103,1121.58 485.112,1121.59 485.121,1121.61 485.13,1121.63 485.14,1121.65 485.149,1121.66 485.158,1121.68 485.167,1121.7 485.176,1121.72 485.186,1121.74 485.195,1121.75 485.204,1121.77 485.213,1121.79 485.222,1121.81 485.232,1121.82 485.241,1121.84 485.25,1121.86 485.259,1121.88 485.268,1121.89 485.277,1121.91 485.287,1121.93 485.296,1121.95 485.305,1121.96 485.314,1121.98 485.323,1122 485.333,1122.02 485.342,1122.03 485.351,1122.05 485.36,1122.07 485.369,1122.09 485.379,1122.1 485.388,1122.12 485.397,1122.14 485.406,1122.16 485.415,1122.18 485.425,1122.19 485.434,1122.21 485.443,1122.23 485.452,1122.25 485.461,1122.26 485.47,1122.28 485.48,1122.3 485.489,1122.32 485.498,1122.33 485.507,1122.35 485.516,1122.37 485.526,1122.39 485.535,1122.4 485.544,1122.42 485.553,1122.44 485.562,1122.46 485.572,1122.47 485.581,1122.49 485.59,1122.51 485.599,1122.53 485.608,1122.54 485.617,1122.56 485.627,1122.58 485.636,1122.6 485.645,1122.61 485.654,1122.63 485.663,1122.65 485.673,1122.67 485.682,1122.68 485.691,1122.7 485.7,1122.72 485.709,1122.74 485.719,1122.75 485.728,1122.77 485.737,1122.79 485.746,1122.81 485.755,1122.82 485.765,1122.84 485.774,1122.86 485.783,1122.88 485.792,1122.89 485.801,1122.91 485.81,1122.93 485.82,1122.95 485.829,1122.96 485.838,1122.98 485.847,1123 485.856,1123.02 485.866,1123.03 485.875,1123.05 485.884,1123.07 485.893,1123.09 485.902,1123.1 485.912,1123.12 485.921,1123.14 485.93,1123.16 485.939,1123.17 485.948,1123.19 485.957,1123.21 485.967,1123.23 485.976,1123.24 485.985,1123.26 485.994,1123.28 486.003,1123.3 486.013,1123.31 486.022,1123.33 486.031,1123.35 486.04,1123.37 486.049,1123.38 486.059,1123.4 486.068,1123.42 486.077,1123.44 486.086,1123.45 486.095,1123.47 486.105,1123.49 486.114,1123.51 486.123,1123.52 486.132,1123.54 486.141,1123.56 486.15,1123.58 486.16,1123.59 486.169,1123.61 486.178,1123.63 486.187,1123.65 486.196,1123.66 486.206,1123.68 486.215,1123.7 486.224,1123.72 486.233,1123.73 486.242,1123.75 486.252,1123.77 486.261,1123.79 486.27,1123.8 486.279,1123.82 486.288,1123.84 486.297,1123.86 486.307,1123.87 486.316,1123.89 486.325,1123.91 486.334,1123.93 486.343,1123.94 486.353,1123.96 486.362,1123.98 486.371,1123.99 486.38,1124.01 486.389,1124.03 486.399,1124.05 486.408,1124.06 486.417,1124.08 486.426,1124.1 486.435,1124.12 486.445,1124.13 486.454,1124.15 486.463,1124.17 486.472,1124.19 486.481,1124.2 486.49,1124.22 486.5,1124.24 486.509,1124.26 486.518,1124.27 486.527,1124.29 486.536,1124.31 486.546,1124.33 486.555,1124.34 486.564,1124.36 486.573,1124.38 486.582,1124.39 486.592,1124.41 486.601,1124.43 486.61,1124.45 486.619,1124.46 486.628,1124.48 486.637,1124.5 486.647,1124.52 486.656,1124.53 486.665,1124.55 486.674,1124.57 486.683,1124.59 486.693,1124.6 486.702,1124.62 486.711,1124.64 486.72,1124.66 486.729,1124.67 486.739,1124.69 486.748,1124.71 486.757,1124.72 486.766,1124.74 486.775,1124.76 486.785,1124.78 486.794,1124.79 486.803,1124.81 486.812,1124.83 486.821,1124.85 486.83,1124.86 486.84,1124.88 486.849,1124.9 486.858,1124.92 486.867,1124.93 486.876,1124.95 486.886,1124.97 486.895,1124.98 486.904,1125 486.913,1125.02 486.922,1125.04 486.932,1125.05 486.941,1125.07 486.95,1125.09 486.959,1125.11 486.968,1125.12 486.978,1125.14 486.987,1125.16 486.996,1125.17 487.005,1125.19 487.014,1125.21 487.023,1125.23 487.033,1125.24 487.042,1125.26 487.051,1125.28 487.06,1125.3 487.069,1125.31 487.079,1125.33 487.088,1125.35 487.097,1125.37 487.106,1125.38 487.115,1125.4 487.125,1125.42 487.134,1125.43 487.143,1125.45 487.152,1125.47 487.161,1125.49 487.17,1125.5 487.18,1125.52 487.189,1125.54 487.198,1125.56 487.207,1125.57 487.216,1125.59 487.226,1125.61 487.235,1125.62 487.244,1125.64 487.253,1125.66 487.262,1125.68 487.272,1125.69 487.281,1125.71 487.29,1125.73 487.299,1125.75 487.308,1125.76 487.318,1125.78 487.327,1125.8 487.336,1125.81 487.345,1125.83 487.354,1125.85 487.363,1125.87 487.373,1125.88 487.382,1125.9 487.391,1125.92 487.4,1125.93 487.409,1125.95 487.419,1125.97 487.428,1125.99 487.437,1126 487.446,1126.02 487.455,1126.04 487.465,1126.06 487.474,1126.07 487.483,1126.09 487.492,1126.11 487.501,1126.12 487.51,1126.14 487.52,1126.16 487.529,1126.18 487.538,1126.19 487.547,1126.21 487.556,1126.23 487.566,1126.24 487.575,1126.26 487.584,1126.28 487.593,1126.3 487.602,1126.31 487.612,1126.33 487.621,1126.35 487.63,1126.36 487.639,1126.38 487.648,1126.4 487.658,1126.42 487.667,1126.43 487.676,1126.45 487.685,1126.47 487.694,1126.49 487.703,1126.5 487.713,1126.52 487.722,1126.54 487.731,1126.55 487.74,1126.57 487.749,1126.59 487.759,1126.61 487.768,1126.62 487.777,1126.64 487.786,1126.66 487.795,1126.67 487.805,1126.69 487.814,1126.71 487.823,1126.73 487.832,1126.74 487.841,1126.76 487.85,1126.78 487.86,1126.79 487.869,1126.81 487.878,1126.83 487.887,1126.85 487.896,1126.86 487.906,1126.88 487.915,1126.9 487.924,1126.91 487.933,1126.93 487.942,1126.95 487.952,1126.97 487.961,1126.98 487.97,1127 487.979,1127.02 487.988,1127.03 487.998,1127.05 488.007,1127.07 488.016,1127.09 488.025,1127.1 488.034,1127.12 488.043,1127.14 488.053,1127.15 488.062,1127.17 488.071,1127.19 488.08,1127.21 488.089,1127.22 488.099,1127.24 488.108,1127.26 488.117,1127.27 488.126,1127.29 488.135,1127.31 488.145,1127.33 488.154,1127.34 488.163,1127.36 488.172,1127.38 488.181,1127.39 488.19,1127.41 488.2,1127.43 488.209,1127.44 488.218,1127.46 488.227,1127.48 488.236,1127.5 488.246,1127.51 488.255,1127.53 488.264,1127.55 488.273,1127.56 488.282,1127.58 488.292,1127.6 488.301,1127.62 488.31,1127.63 488.319,1127.65 488.328,1127.67 488.338,1127.68 488.347,1127.7 488.356,1127.72 488.365,1127.74 488.374,1127.75 488.383,1127.77 488.393,1127.79 488.402,1127.8 488.411,1127.82 488.42,1127.84 488.429,1127.85 488.439,1127.87 488.448,1127.89 488.457,1127.91 488.466,1127.92 488.475,1127.94 488.485,1127.96 488.494,1127.97 488.503,1127.99 488.512,1128.01 488.521,1128.03 488.53,1128.04 488.54,1128.06 488.549,1128.08 488.558,1128.09 488.567,1128.11 488.576,1128.13 488.586,1128.14 488.595,1128.16 488.604,1128.18 488.613,1128.2 488.622,1128.21 488.632,1128.23 488.641,1128.25 488.65,1128.26 488.659,1128.28 488.668,1128.3 488.678,1128.31 488.687,1128.33 488.696,1128.35 488.705,1128.37 488.714,1128.38 488.723,1128.4 488.733,1128.42 488.742,1128.43 488.751,1128.45 488.76,1128.47 488.769,1128.48 488.779,1128.5 488.788,1128.52 488.797,1128.54 488.806,1128.55 488.815,1128.57 488.825,1128.59 488.834,1128.6 488.843,1128.62 488.852,1128.64 488.861,1128.65 488.87,1128.67 488.88,1128.69 488.889,1128.71 488.898,1128.72 488.907,1128.74 488.916,1128.76 488.926,1128.77 488.935,1128.79 488.944,1128.81 488.953,1128.82 488.962,1128.84 488.972,1128.86 488.981,1128.88 488.99,1128.89 488.999,1128.91 489.008,1128.93 489.018,1128.94 489.027,1128.96 489.036,1128.98 489.045,1128.99 489.054,1129.01 489.063,1129.03 489.073,1129.04 489.082,1129.06 489.091,1129.08 489.1,1129.1 489.109,1129.11 489.119,1129.13 489.128,1129.15 489.137,1129.16 489.146,1129.18 489.155,1129.2 489.165,1129.21 489.174,1129.23 489.183,1129.25 489.192,1129.26 489.201,1129.28 489.21,1129.3 489.22,1129.32 489.229,1129.33 489.238,1129.35 489.247,1129.37 489.256,1129.38 489.266,1129.4 489.275,1129.42 489.284,1129.43 489.293,1129.45 489.302,1129.47 489.312,1129.48 489.321,1129.5 489.33,1129.52 489.339,1129.54 489.348,1129.55 489.358,1129.57 489.367,1129.59 489.376,1129.6 489.385,1129.62 489.394,1129.64 489.403,1129.65 489.413,1129.67 489.422,1129.69 489.431,1129.7 489.44,1129.72 489.449,1129.74 489.459,1129.76 489.468,1129.77 489.477,1129.79 489.486,1129.81 489.495,1129.82 489.505,1129.84 489.514,1129.86 489.523,1129.87 489.532,1129.89 489.541,1129.91 489.551,1129.92 489.56,1129.94 489.569,1129.96 489.578,1129.97 489.587,1129.99 489.596,1130.01 489.606,1130.03 489.615,1130.04 489.624,1130.06 489.633,1130.08 489.642,1130.09 489.652,1130.11 489.661,1130.13 489.67,1130.14 489.679,1130.16 489.688,1130.18 489.698,1130.19 489.707,1130.21 489.716,1130.23 489.725,1130.24 489.734,1130.26 489.743,1130.28 489.753,1130.29 489.762,1130.31 489.771,1130.33 489.78,1130.34 489.789,1130.36 489.799,1130.38 489.808,1130.4 489.817,1130.41 489.826,1130.43 489.835,1130.45 489.845,1130.46 489.854,1130.48 489.863,1130.5 489.872,1130.51 489.881,1130.53 489.891,1130.55 489.9,1130.56 489.909,1130.58 489.918,1130.6 489.927,1130.61 489.936,1130.63 489.946,1130.65 489.955,1130.66 489.964,1130.68 489.973,1130.7 489.982,1130.71 489.992,1130.73 490.001,1130.75 490.01,1130.77 490.019,1130.78 490.028,1130.8 490.038,1130.82 490.047,1130.83 490.056,1130.85 490.065,1130.87 490.074,1130.88 490.083,1130.9 490.093,1130.92 490.102,1130.93 490.111,1130.95 490.12,1130.97 490.129,1130.98 490.139,1131 490.148,1131.02 490.157,1131.03 490.166,1131.05 490.175,1131.07 490.185,1131.08 490.194,1131.1 490.203,1131.12 490.212,1131.13 490.221,1131.15 490.231,1131.17 490.24,1131.18 490.249,1131.2 490.258,1131.22 490.267,1131.23 490.276,1131.25 490.286,1131.27 490.295,1131.28 490.304,1131.3 490.313,1131.32 490.322,1131.34 490.332,1131.35 490.341,1131.37 490.35,1131.39 490.359,1131.4 490.368,1131.42 490.378,1131.44 490.387,1131.45 490.396,1131.47 490.405,1131.49 490.414,1131.5 490.423,1131.52 490.433,1131.54 490.442,1131.55 490.451,1131.57 490.46,1131.59 490.469,1131.6 490.479,1131.62 490.488,1131.64 490.497,1131.65 490.506,1131.67 490.515,1131.69 490.525,1131.7 490.534,1131.72 490.543,1131.74 490.552,1131.75 490.561,1131.77 490.571,1131.79 490.58,1131.8 490.589,1131.82 490.598,1131.84 490.607,1131.85 490.616,1131.87 490.626,1131.89 490.635,1131.9 490.644,1131.92 490.653,1131.94 490.662,1131.95 490.672,1131.97 490.681,1131.99 490.69,1132 490.699,1132.02 490.708,1132.04 490.718,1132.05 490.727,1132.07 490.736,1132.09 490.745,1132.1 490.754,1132.12 490.763,1132.14 490.773,1132.15 490.782,1132.17 490.791,1132.19 490.8,1132.2 490.809,1132.22 490.819,1132.24 490.828,1132.25 490.837,1132.27 490.846,1132.29 490.855,1132.3 490.865,1132.32 490.874,1132.34 490.883,1132.35 490.892,1132.37 490.901,1132.39 490.911,1132.4 490.92,1132.42 490.929,1132.44 490.938,1132.45 490.947,1132.47 490.956,1132.49 490.966,1132.5 490.975,1132.52 490.984,1132.54 490.993,1132.55 491.002,1132.57 491.012,1132.59 491.021,1132.6 491.03,1132.62 491.039,1132.64 491.048,1132.65 491.058,1132.67 491.067,1132.69 491.076,1132.7 491.085,1132.72 491.094,1132.74 491.103,1132.75 491.113,1132.77 491.122,1132.79 491.131,1132.8 491.14,1132.82 491.149,1132.83 491.159,1132.85 491.168,1132.87 491.177,1132.88 491.186,1132.9 491.195,1132.92 491.205,1132.93 491.214,1132.95 491.223,1132.97 491.232,1132.98 491.241,1133 491.251,1133.02 491.26,1133.03 491.269,1133.05 491.278,1133.07 491.287,1133.08 491.296,1133.1 491.306,1133.12 491.315,1133.13 491.324,1133.15 491.333,1133.17 491.342,1133.18 491.352,1133.2 491.361,1133.22 491.37,1133.23 491.379,1133.25 491.388,1133.27 491.398,1133.28 491.407,1133.3 491.416,1133.32 491.425,1133.33 491.434,1133.35 491.443,1133.37 491.453,1133.38 491.462,1133.4 491.471,1133.41 491.48,1133.43 491.489,1133.45 491.499,1133.46 491.508,1133.48 491.517,1133.5 491.526,1133.51 491.535,1133.53 491.545,1133.55 491.554,1133.56 491.563,1133.58 491.572,1133.6 491.581,1133.61 491.591,1133.63 491.6,1133.65 491.609,1133.66 491.618,1133.68 491.627,1133.7 491.636,1133.71 491.646,1133.73 491.655,1133.75 491.664,1133.76 491.673,1133.78 491.682,1133.79 491.692,1133.81 491.701,1133.83 491.71,1133.84 491.719,1133.86 491.728,1133.88 491.738,1133.89 491.747,1133.91 491.756,1133.93 491.765,1133.94 491.774,1133.96 491.784,1133.98 491.793,1133.99 491.802,1134.01 491.811,1134.03 491.82,1134.04 491.829,1134.06 491.839,1134.08 491.848,1134.09 491.857,1134.11 491.866,1134.12 491.875,1134.14 491.885,1134.16 491.894,1134.17 491.903,1134.19 491.912,1134.21 491.921,1134.22 491.931,1134.24 491.94,1134.26 491.949,1134.27 491.958,1134.29 491.967,1134.31 491.976,1134.32 491.986,1134.34 491.995,1134.36 492.004,1134.37 492.013,1134.39 492.022,1134.4 492.032,1134.42 492.041,1134.44 492.05,1134.45 492.059,1134.47 492.068,1134.49 492.078,1134.5 492.087,1134.52 492.096,1134.54 492.105,1134.55 492.114,1134.57 492.124,1134.59 492.133,1134.6 492.142,1134.62 492.151,1134.63 492.16,1134.65 492.169,1134.67 492.179,1134.68 492.188,1134.7 492.197,1134.72 492.206,1134.73 492.215,1134.75 492.225,1134.77 492.234,1134.78 492.243,1134.8 492.252,1134.82 492.261,1134.83 492.271,1134.85 492.28,1134.86 492.289,1134.88 492.298,1134.9 492.307,1134.91 492.316,1134.93 492.326,1134.95 492.335,1134.96 492.344,1134.98 492.353,1135 492.362,1135.01 492.372,1135.03 492.381,1135.05 492.39,1135.06 492.399,1135.08 492.408,1135.09 492.418,1135.11 492.427,1135.13 492.436,1135.14 492.445,1135.16 492.454,1135.18 492.464,1135.19 492.473,1135.21 492.482,1135.23 492.491,1135.24 492.5,1135.26 492.509,1135.27 492.519,1135.29 492.528,1135.31 492.537,1135.32 492.546,1135.34 492.555,1135.36 492.565,1135.37 492.574,1135.39 492.583,1135.41 492.592,1135.42 492.601,1135.44 492.611,1135.45 492.62,1135.47 492.629,1135.49 492.638,1135.5 492.647,1135.52 492.656,1135.54 492.666,1135.55 492.675,1135.57 492.684,1135.59 492.693,1135.6 492.702,1135.62 492.712,1135.63 492.721,1135.65 492.73,1135.67 492.739,1135.68 492.748,1135.7 492.758,1135.72 492.767,1135.73 492.776,1135.75 492.785,1135.77 492.794,1135.78 492.804,1135.8 492.813,1135.81 492.822,1135.83 492.831,1135.85 492.84,1135.86 492.849,1135.88 492.859,1135.9 492.868,1135.91 492.877,1135.93 492.886,1135.94 492.895,1135.96 492.905,1135.98 492.914,1135.99 492.923,1136.01 492.932,1136.03 492.941,1136.04 492.951,1136.06 492.96,1136.07 492.969,1136.09 492.978,1136.11 492.987,1136.12 492.996,1136.14 493.006,1136.16 493.015,1136.17 493.024,1136.19 493.033,1136.21 493.042,1136.22 493.052,1136.24 493.061,1136.25 493.07,1136.27 493.079,1136.29 493.088,1136.3 493.098,1136.32 493.107,1136.34 493.116,1136.35 493.125,1136.37 493.134,1136.38 493.144,1136.4 493.153,1136.42 493.162,1136.43 493.171,1136.45 493.18,1136.47 493.189,1136.48 493.199,1136.5 493.208,1136.51 493.217,1136.53 493.226,1136.55 493.235,1136.56 493.245,1136.58 493.254,1136.6 493.263,1136.61 493.272,1136.63 493.281,1136.64 493.291,1136.66 493.3,1136.68 493.309,1136.69 493.318,1136.71 493.327,1136.73 493.336,1136.74 493.346,1136.76 493.355,1136.77 493.364,1136.79 493.373,1136.81 493.382,1136.82 493.392,1136.84 493.401,1136.86 493.41,1136.87 493.419,1136.89 493.428,1136.9 493.438,1136.92 493.447,1136.94 493.456,1136.95 493.465,1136.97 493.474,1136.99 493.484,1137 493.493,1137.02 493.502,1137.03 493.511,1137.05 493.52,1137.07 493.529,1137.08 493.539,1137.1 493.548,1137.12 493.557,1137.13 493.566,1137.15 493.575,1137.16 493.585,1137.18 493.594,1137.2 493.603,1137.21 493.612,1137.23 493.621,1137.24 493.631,1137.26 493.64,1137.28 493.649,1137.29 493.658,1137.31 493.667,1137.33 493.676,1137.34 493.686,1137.36 493.695,1137.37 493.704,1137.39 493.713,1137.41 493.722,1137.42 493.732,1137.44 493.741,1137.45 493.75,1137.47 493.759,1137.49 493.768,1137.5 493.778,1137.52 493.787,1137.54 493.796,1137.55 493.805,1137.57 493.814,1137.58 493.824,1137.6 493.833,1137.62 493.842,1137.63 493.851,1137.65 493.86,1137.67 493.869,1137.68 493.879,1137.7 493.888,1137.71 493.897,1137.73 493.906,1137.75 493.915,1137.76 493.925,1137.78 493.934,1137.79 493.943,1137.81 493.952,1137.83 493.961,1137.84 493.971,1137.86 493.98,1137.87 493.989,1137.89 493.998,1137.91 494.007,1137.92 494.016,1137.94 494.026,1137.96 494.035,1137.97 494.044,1137.99 494.053,1138 494.062,1138.02 494.072,1138.04 494.081,1138.05 494.09,1138.07 494.099,1138.08 494.108,1138.1 494.118,1138.12 494.127,1138.13 494.136,1138.15 494.145,1138.17 494.154,1138.18 494.164,1138.2 494.173,1138.21 494.182,1138.23 494.191,1138.25 494.2,1138.26 494.209,1138.28 494.219,1138.29 494.228,1138.31 494.237,1138.33 494.246,1138.34 494.255,1138.36 494.265,1138.37 494.274,1138.39 494.283,1138.41 494.292,1138.42 494.301,1138.44 494.311,1138.45 494.32,1138.47 494.329,1138.49 494.338,1138.5 494.347,1138.52 494.357,1138.54 494.366,1138.55 494.375,1138.57 494.384,1138.58 494.393,1138.6 494.402,1138.62 494.412,1138.63 494.421,1138.65 494.43,1138.66 494.439,1138.68 494.448,1138.7 494.458,1138.71 494.467,1138.73 494.476,1138.74 494.485,1138.76 494.494,1138.78 494.504,1138.79 494.513,1138.81 494.522,1138.82 494.531,1138.84 494.54,1138.86 494.549,1138.87 494.559,1138.89 494.568,1138.9 494.577,1138.92 494.586,1138.94 494.595,1138.95 494.605,1138.97 494.614,1138.98 494.623,1139 494.632,1139.02 494.641,1139.03 494.651,1139.05 494.66,1139.06 494.669,1139.08 494.678,1139.1 494.687,1139.11 494.697,1139.13 494.706,1139.14 494.715,1139.16 494.724,1139.18 494.733,1139.19 494.742,1139.21 494.752,1139.22 494.761,1139.24 494.77,1139.26 494.779,1139.27 494.788,1139.29 494.798,1139.3 494.807,1139.32 494.816,1139.34 494.825,1139.35 494.834,1139.37 494.844,1139.38 494.853,1139.4 494.862,1139.42 494.871,1139.43 494.88,1139.45 494.889,1139.46 494.899,1139.48 494.908,1139.5 494.917,1139.51 494.926,1139.53 494.935,1139.54 494.945,1139.56 494.954,1139.58 494.963,1139.59 494.972,1139.61 494.981,1139.62 494.991,1139.64 495,1139.66 495.009,1139.67 495.018,1139.69 495.027,1139.7 495.037,1139.72 495.046,1139.74 495.055,1139.75 495.064,1139.77 495.073,1139.78 495.082,1139.8 495.092,1139.82 495.101,1139.83 495.11,1139.85 495.119,1139.86 495.128,1139.88 495.138,1139.9 495.147,1139.91 495.156,1139.93 495.165,1139.94 495.174,1139.96 495.184,1139.98 495.193,1139.99 495.202,1140.01 495.211,1140.02 495.22,1140.04 495.229,1140.06 495.239,1140.07 495.248,1140.09 495.257,1140.1 495.266,1140.12 495.275,1140.14 495.285,1140.15 495.294,1140.17 495.303,1140.18 495.312,1140.2 495.321,1140.21 495.331,1140.23 495.34,1140.25 495.349,1140.26 495.358,1140.28 495.367,1140.29 495.377,1140.31 495.386,1140.33 495.395,1140.34 495.404,1140.36 495.413,1140.37 495.422,1140.39 495.432,1140.41 495.441,1140.42 495.45,1140.44 495.459,1140.45 495.468,1140.47 495.478,1140.49 495.487,1140.5 495.496,1140.52 495.505,1140.53 495.514,1140.55 495.524,1140.56 495.533,1140.58 495.542,1140.6 495.551,1140.61 495.56,1140.63 495.569,1140.64 495.579,1140.66 495.588,1140.68 495.597,1140.69 495.606,1140.71 495.615,1140.72 495.625,1140.74 495.634,1140.76 495.643,1140.77 495.652,1140.79 495.661,1140.8 495.671,1140.82 495.68,1140.83 495.689,1140.85 495.698,1140.87 495.707,1140.88 495.717,1140.9 495.726,1140.91 495.735,1140.93 495.744,1140.95 495.753,1140.96 495.762,1140.98 495.772,1140.99 495.781,1141.01 495.79,1141.02 495.799,1141.04 495.808,1141.06 495.818,1141.07 495.827,1141.09 495.836,1141.1 495.845,1141.12 495.854,1141.14 495.864,1141.15 495.873,1141.17 495.882,1141.18 495.891,1141.2 495.9,1141.21 495.909,1141.23 495.919,1141.25 495.928,1141.26 495.937,1141.28 495.946,1141.29 495.955,1141.31 495.965,1141.33 495.974,1141.34 495.983,1141.36 495.992,1141.37 496.001,1141.39 496.011,1141.4 496.02,1141.42 496.029,1141.44 496.038,1141.45 496.047,1141.47 496.057,1141.48 496.066,1141.5 496.075,1141.52 496.084,1141.53 496.093,1141.55 496.102,1141.56 496.112,1141.58 496.121,1141.59 496.13,1141.61 496.139,1141.63 496.148,1141.64 496.158,1141.66 496.167,1141.67 496.176,1141.69 496.185,1141.7 496.194,1141.72 496.204,1141.74 496.213,1141.75 496.222,1141.77 496.231,1141.78 496.24,1141.8 496.249,1141.81 496.259,1141.83 496.268,1141.85 496.277,1141.86 496.286,1141.88 496.295,1141.89 496.305,1141.91 496.314,1141.93 496.323,1141.94 496.332,1141.96 496.341,1141.97 496.351,1141.99 496.36,1142 496.369,1142.02 496.378,1142.04 496.387,1142.05 496.397,1142.07 496.406,1142.08 496.415,1142.1 496.424,1142.11 496.433,1142.13 496.442,1142.15 496.452,1142.16 496.461,1142.18 496.47,1142.19 496.479,1142.21 496.488,1142.22 496.498,1142.24 496.507,1142.26 496.516,1142.27 496.525,1142.29 496.534,1142.3 496.544,1142.32 496.553,1142.33 496.562,1142.35 496.571,1142.37 496.58,1142.38 496.589,1142.4 496.599,1142.41 496.608,1142.43 496.617,1142.44 496.626,1142.46 496.635,1142.48 496.645,1142.49 496.654,1142.51 496.663,1142.52 496.672,1142.54 496.681,1142.55 496.691,1142.57 496.7,1142.59 496.709,1142.6 496.718,1142.62 496.727,1142.63 496.737,1142.65 496.746,1142.66 496.755,1142.68 496.764,1142.7 496.773,1142.71 496.782,1142.73 496.792,1142.74 496.801,1142.76 496.81,1142.77 496.819,1142.79 496.828,1142.81 496.838,1142.82 496.847,1142.84 496.856,1142.85 496.865,1142.87 496.874,1142.88 496.884,1142.9 496.893,1142.92 496.902,1142.93 496.911,1142.95 496.92,1142.96 496.93,1142.98 496.939,1142.99 496.948,1143.01 496.957,1143.03 496.966,1143.04 496.975,1143.06 496.985,1143.07 496.994,1143.09 497.003,1143.1 497.012,1143.12 497.021,1143.13 497.031,1143.15 497.04,1143.17 497.049,1143.18 497.058,1143.2 497.067,1143.21 497.077,1143.23 497.086,1143.24 497.095,1143.26 497.104,1143.28 497.113,1143.29 497.122,1143.31 497.132,1143.32 497.141,1143.34 497.15,1143.35 497.159,1143.37 497.168,1143.38 497.178,1143.4 497.187,1143.42 497.196,1143.43 497.205,1143.45 497.214,1143.46 497.224,1143.48 497.233,1143.49 497.242,1143.51 497.251,1143.53 497.26,1143.54 497.27,1143.56 497.279,1143.57 497.288,1143.59 497.297,1143.6 497.306,1143.62 497.315,1143.63 497.325,1143.65 497.334,1143.67 497.343,1143.68 497.352,1143.7 497.361,1143.71 497.371,1143.73 497.38,1143.74 497.389,1143.76 497.398,1143.78 497.407,1143.79 497.417,1143.81 497.426,1143.82 497.435,1143.84 497.444,1143.85 497.453,1143.87 497.462,1143.88 497.472,1143.9 497.481,1143.92 497.49,1143.93 497.499,1143.95 497.508,1143.96 497.518,1143.98 497.527,1143.99 497.536,1144.01 497.545,1144.02 497.554,1144.04 497.564,1144.06 497.573,1144.07 497.582,1144.09 497.591,1144.1 497.6,1144.12 497.61,1144.13 497.619,1144.15 497.628,1144.16 497.637,1144.18 497.646,1144.2 497.655,1144.21 497.665,1144.23 497.674,1144.24 497.683,1144.26 497.692,1144.27 497.701,1144.29 497.711,1144.3 497.72,1144.32 497.729,1144.34 497.738,1144.35 497.747,1144.37 497.757,1144.38 497.766,1144.4 497.775,1144.41 497.784,1144.43 497.793,1144.44 497.802,1144.46 497.812,1144.48 497.821,1144.49 497.83,1144.51 497.839,1144.52 497.848,1144.54 497.858,1144.55 497.867,1144.57 497.876,1144.58 497.885,1144.6 497.894,1144.61 497.904,1144.63 497.913,1144.65 497.922,1144.66 497.931,1144.68 497.94,1144.69 497.95,1144.71 497.959,1144.72 497.968,1144.74 497.977,1144.75 497.986,1144.77 497.995,1144.79 498.005,1144.8 498.014,1144.82 498.023,1144.83 498.032,1144.85 498.041,1144.86 498.051,1144.88 498.06,1144.89 498.069,1144.91 498.078,1144.92 498.087,1144.94 498.097,1144.96 498.106,1144.97 498.115,1144.99 498.124,1145 498.133,1145.02 498.142,1145.03 498.152,1145.05 498.161,1145.06 498.17,1145.08 498.179,1145.1 498.188,1145.11 498.198,1145.13 498.207,1145.14 498.216,1145.16 498.225,1145.17 498.234,1145.19 498.244,1145.2 498.253,1145.22 498.262,1145.23 498.271,1145.25 498.28,1145.27 498.29,1145.28 498.299,1145.3 498.308,1145.31 498.317,1145.33 498.326,1145.34 498.335,1145.36 498.345,1145.37 498.354,1145.39 498.363,1145.4 498.372,1145.42 498.381,1145.44 498.391,1145.45 498.4,1145.47 498.409,1145.48 498.418,1145.5 498.427,1145.51 498.437,1145.53 498.446,1145.54 498.455,1145.56 498.464,1145.57 498.473,1145.59 498.482,1145.61 498.492,1145.62 498.501,1145.64 498.51,1145.65 498.519,1145.67 498.528,1145.68 498.538,1145.7 498.547,1145.71 498.556,1145.73 498.565,1145.74 498.574,1145.76 498.584,1145.77 498.593,1145.79 498.602,1145.81 498.611,1145.82 498.62,1145.84 498.63,1145.85 498.639,1145.87 498.648,1145.88 498.657,1145.9 498.666,1145.91 498.675,1145.93 498.685,1145.94 498.694,1145.96 498.703,1145.97 498.712,1145.99 498.721,1146.01 498.731,1146.02 498.74,1146.04 498.749,1146.05 498.758,1146.07 498.767,1146.08 498.777,1146.1 498.786,1146.11 498.795,1146.13 498.804,1146.14 498.813,1146.16 498.822,1146.17 498.832,1146.19 498.841,1146.21 498.85,1146.22 498.859,1146.24 498.868,1146.25 498.878,1146.27 498.887,1146.28 498.896,1146.3 498.905,1146.31 498.914,1146.33 498.924,1146.34 498.933,1146.36 498.942,1146.37 498.951,1146.39 498.96,1146.41 498.97,1146.42 498.979,1146.44 498.988,1146.45 498.997,1146.47 499.006,1146.48 499.015,1146.5 499.025,1146.51 499.034,1146.53 499.043,1146.54 499.052,1146.56 499.061,1146.57 499.071,1146.59 499.08,1146.6 499.089,1146.62 499.098,1146.64 499.107,1146.65 499.117,1146.67 499.126,1146.68 499.135,1146.7 499.144,1146.71 499.153,1146.73 499.163,1146.74 499.172,1146.76 499.181,1146.77 499.19,1146.79 499.199,1146.8 499.208,1146.82 499.218,1146.83 499.227,1146.85 499.236,1146.87 499.245,1146.88 499.254,1146.9 499.264,1146.91 499.273,1146.93 499.282,1146.94 499.291,1146.96 499.3,1146.97 499.31,1146.99 499.319,1147 499.328,1147.02 499.337,1147.03 499.346,1147.05 499.355,1147.06 499.365,1147.08 499.374,1147.09 499.383,1147.11 499.392,1147.13 499.401,1147.14 499.411,1147.16 499.42,1147.17 499.429,1147.19 499.438,1147.2 499.447,1147.22 499.457,1147.23 499.466,1147.25 499.475,1147.26 499.484,1147.28 499.493,1147.29 499.503,1147.31 499.512,1147.32 499.521,1147.34 499.53,1147.35 499.539,1147.37 499.548,1147.38 499.558,1147.4 499.567,1147.42 499.576,1147.43 499.585,1147.45 499.594,1147.46 499.604,1147.48 499.613,1147.49 499.622,1147.51 499.631,1147.52 499.64,1147.54 499.65,1147.55 499.659,1147.57 499.668,1147.58 499.677,1147.6 499.686,1147.61 499.695,1147.63 499.705,1147.64 499.714,1147.66 499.723,1147.67 499.732,1147.69 499.741,1147.7 499.751,1147.72 499.76,1147.74 499.769,1147.75 499.778,1147.77 499.787,1147.78 499.797,1147.8 499.806,1147.81 499.815,1147.83 499.824,1147.84 499.833,1147.86 499.843,1147.87 499.852,1147.89 499.861,1147.9 499.87,1147.92 499.879,1147.93 499.888,1147.95 499.898,1147.96 499.907,1147.98 499.916,1147.99 499.925,1148.01 499.934,1148.02 499.944,1148.04 499.953,1148.05 499.962,1148.07 499.971,1148.09 499.98,1148.1 499.99,1148.12 499.999,1148.13 500.008,1148.15 500.017,1148.16 500.026,1148.18 500.035,1148.19 500.045,1148.21 500.054,1148.22 500.063,1148.24 500.072,1148.25 500.081,1148.27 500.091,1148.28 500.1,1148.3 500.109,1148.31 500.118,1148.33 500.127,1148.34 500.137,1148.36 500.146,1148.37 500.155,1148.39 500.164,1148.4 500.173,1148.42 500.183,1148.43 500.192,1148.45 500.201,1148.46 500.21,1148.48 500.219,1148.5 500.228,1148.51 500.238,1148.53 500.247,1148.54 500.256,1148.56 500.265,1148.57 500.274,1148.59 500.284,1148.6 500.293,1148.62 500.302,1148.63 500.311,1148.65 500.32,1148.66 500.33,1148.68 500.339,1148.69 500.348,1148.71 500.357,1148.72 500.366,1148.74 500.375,1148.75 500.385,1148.77 500.394,1148.78 500.403,1148.8 500.412,1148.81 500.421,1148.83 500.431,1148.84 500.44,1148.86 500.449,1148.87 500.458,1148.89 500.467,1148.9 500.477,1148.92 500.486,1148.93 500.495,1148.95 500.504,1148.96 500.513,1148.98 500.523,1148.99 500.532,1149.01 500.541,1149.02 500.55,1149.04 500.559,1149.06 500.568,1149.07 500.578,1149.09 500.587,1149.1 500.596,1149.12 500.605,1149.13 500.614,1149.15 500.624,1149.16 500.633,1149.18 500.642,1149.19 500.651,1149.21 500.66,1149.22 500.67,1149.24 500.679,1149.25 500.688,1149.27 500.697,1149.28 500.706,1149.3 500.715,1149.31 500.725,1149.33 500.734,1149.34 500.743,1149.36 500.752,1149.37 500.761,1149.39 500.771,1149.4 500.78,1149.42 500.789,1149.43 500.798,1149.45 500.807,1149.46 500.817,1149.48 500.826,1149.49 500.835,1149.51 500.844,1149.52 500.853,1149.54 500.863,1149.55 500.872,1149.57 500.881,1149.58 500.89,1149.6 500.899,1149.61 500.908,1149.63 500.918,1149.64 500.927,1149.66 500.936,1149.67 500.945,1149.69 500.954,1149.7 500.964,1149.72 500.973,1149.73 500.982,1149.75 500.991,1149.76 501,1149.78 501.01,1149.79 501.019,1149.81 501.028,1149.82 501.037,1149.84 501.046,1149.85 501.055,1149.87 501.065,1149.88 501.074,1149.9 501.083,1149.91 501.092,1149.93 501.101,1149.94 501.111,1149.96 501.12,1149.97 501.129,1149.99 501.138,1150 501.147,1150.02 501.157,1150.03 501.166,1150.05 501.175,1150.06 501.184,1150.08 501.193,1150.09 501.203,1150.11 501.212,1150.12 501.221,1150.14 501.23,1150.15 501.239,1150.17 501.248,1150.18 501.258,1150.2 501.267,1150.21 501.276,1150.23 501.285,1150.24 501.294,1150.26 501.304,1150.27 501.313,1150.29 501.322,1150.3 501.331,1150.32 501.34,1150.33 501.35,1150.35 501.359,1150.36 501.368,1150.38 501.377,1150.39 501.386,1150.41 501.395,1150.42 501.405,1150.44 501.414,1150.45 501.423,1150.47 501.432,1150.48 501.441,1150.5 501.451,1150.51 501.46,1150.53 501.469,1150.54 501.478,1150.56 501.487,1150.57 501.497,1150.59 501.506,1150.6 501.515,1150.62 501.524,1150.63 501.533,1150.65 501.543,1150.66 501.552,1150.68 501.561,1150.69 501.57,1150.71 501.579,1150.72 501.588,1150.74 501.598,1150.75 501.607,1150.77 501.616,1150.78 501.625,1150.8 501.634,1150.81 501.644,1150.83 501.653,1150.84 501.662,1150.86 501.671,1150.87 501.68,1150.89 501.69,1150.9 501.699,1150.92 501.708,1150.93 501.717,1150.95 501.726,1150.96 501.736,1150.98 501.745,1150.99 501.754,1151.01 501.763,1151.02 501.772,1151.04 501.781,1151.05 501.791,1151.07 501.8,1151.08 501.809,1151.1 501.818,1151.11 501.827,1151.13 501.837,1151.14 501.846,1151.16 501.855,1151.17 501.864,1151.19 501.873,1151.2 501.883,1151.22 501.892,1151.23 501.901,1151.25 501.91,1151.26 501.919,1151.28 501.928,1151.29 501.938,1151.31 501.947,1151.32 501.956,1151.34 501.965,1151.35 501.974,1151.37 501.984,1151.38 501.993,1151.4 502.002,1151.41 502.011,1151.43 502.02,1151.44 502.03,1151.46 502.039,1151.47 502.048,1151.48 502.057,1151.5 502.066,1151.51 502.076,1151.53 502.085,1151.54 502.094,1151.56 502.103,1151.57 502.112,1151.59 502.121,1151.6 502.131,1151.62 502.14,1151.63 502.149,1151.65 502.158,1151.66 502.167,1151.68 502.177,1151.69 502.186,1151.71 502.195,1151.72 502.204,1151.74 502.213,1151.75 502.223,1151.77 502.232,1151.78 502.241,1151.8 502.25,1151.81 502.259,1151.83 502.268,1151.84 502.278,1151.86 502.287,1151.87 502.296,1151.89 502.305,1151.9 502.314,1151.92 502.324,1151.93 502.333,1151.95 502.342,1151.96 502.351,1151.98 502.36,1151.99 502.37,1152.01 502.379,1152.02 502.388,1152.03 502.397,1152.05 502.406,1152.06 502.416,1152.08 502.425,1152.09 502.434,1152.11 502.443,1152.12 502.452,1152.14 502.461,1152.15 502.471,1152.17 502.48,1152.18 502.489,1152.2 502.498,1152.21 502.507,1152.23 502.517,1152.24 502.526,1152.26 502.535,1152.27 502.544,1152.29 502.553,1152.3 502.563,1152.32 502.572,1152.33 502.581,1152.35 502.59,1152.36 502.599,1152.38 502.608,1152.39 502.618,1152.41 502.627,1152.42 502.636,1152.44 502.645,1152.45 502.654,1152.46 502.664,1152.48 502.673,1152.49 502.682,1152.51 502.691,1152.52 502.7,1152.54 502.71,1152.55 502.719,1152.57 502.728,1152.58 502.737,1152.6 502.746,1152.61 502.756,1152.63 502.765,1152.64 502.774,1152.66 502.783,1152.67 502.792,1152.69 502.801,1152.7 502.811,1152.72 502.82,1152.73 502.829,1152.75 502.838,1152.76 502.847,1152.78 502.857,1152.79 502.866,1152.8 502.875,1152.82 502.884,1152.83 502.893,1152.85 502.903,1152.86 502.912,1152.88 502.921,1152.89 502.93,1152.91 502.939,1152.92 502.948,1152.94 502.958,1152.95 502.967,1152.97 502.976,1152.98 502.985,1153 502.994,1153.01 503.004,1153.03 503.013,1153.04 503.022,1153.06 503.031,1153.07 503.04,1153.08 503.05,1153.1 503.059,1153.11 503.068,1153.13 503.077,1153.14 503.086,1153.16 503.096,1153.17 503.105,1153.19 503.114,1153.2 503.123,1153.22 503.132,1153.23 503.141,1153.25 503.151,1153.26 503.16,1153.28 503.169,1153.29 503.178,1153.31 503.187,1153.32 503.197,1153.34 503.206,1153.35 503.215,1153.36 503.224,1153.38 503.233,1153.39 503.243,1153.41 503.252,1153.42 503.261,1153.44 503.27,1153.45 503.279,1153.47 503.288,1153.48 503.298,1153.5 503.307,1153.51 503.316,1153.53 503.325,1153.54 503.334,1153.56 503.344,1153.57 503.353,1153.59 503.362,1153.6 503.371,1153.61 503.38,1153.63 503.39,1153.64 503.399,1153.66 503.408,1153.67 503.417,1153.69 503.426,1153.7 503.436,1153.72 503.445,1153.73 503.454,1153.75 503.463,1153.76 503.472,1153.78 503.481,1153.79 503.491,1153.81 503.5,1153.82 503.509,1153.84 503.518,1153.85 503.527,1153.86 503.537,1153.88 503.546,1153.89 503.555,1153.91 503.564,1153.92 503.573,1153.94 503.583,1153.95 503.592,1153.97 503.601,1153.98 503.61,1154 503.619,1154.01 503.628,1154.03 503.638,1154.04 503.647,1154.06 503.656,1154.07 503.665,1154.08 503.674,1154.1 503.684,1154.11 503.693,1154.13 503.702,1154.14 503.711,1154.16 503.72,1154.17 503.73,1154.19 503.739,1154.2 503.748,1154.22 503.757,1154.23 503.766,1154.25 503.776,1154.26 503.785,1154.27 503.794,1154.29 503.803,1154.3 503.812,1154.32 503.821,1154.33 503.831,1154.35 503.84,1154.36 503.849,1154.38 503.858,1154.39 503.867,1154.41 503.877,1154.42 503.886,1154.44 503.895,1154.45 503.904,1154.46 503.913,1154.48 503.923,1154.49 503.932,1154.51 503.941,1154.52 503.95,1154.54 503.959,1154.55 503.968,1154.57 503.978,1154.58 503.987,1154.6 503.996,1154.61 504.005,1154.63 504.014,1154.64 504.024,1154.65 504.033,1154.67 504.042,1154.68 504.051,1154.7 504.06,1154.71 504.07,1154.73 504.079,1154.74 504.088,1154.76 504.097,1154.77 504.106,1154.79 504.116,1154.8 504.125,1154.82 504.134,1154.83 504.143,1154.84 504.152,1154.86 504.161,1154.87 504.171,1154.89 504.18,1154.9 504.189,1154.92 504.198,1154.93 504.207,1154.95 504.217,1154.96 504.226,1154.98 504.235,1154.99 504.244,1155 504.253,1155.02 504.263,1155.03 504.272,1155.05 504.281,1155.06 504.29,1155.08 504.299,1155.09 504.309,1155.11 504.318,1155.12 504.327,1155.14 504.336,1155.15 504.345,1155.17 504.354,1155.18 504.364,1155.19 504.373,1155.21 504.382,1155.22 504.391,1155.24 504.4,1155.25 504.41,1155.27 504.419,1155.28 504.428,1155.3 504.437,1155.31 504.446,1155.33 504.456,1155.34 504.465,1155.35 504.474,1155.37 504.483,1155.38 504.492,1155.4 504.501,1155.41 504.511,1155.43 504.52,1155.44 504.529,1155.46 504.538,1155.47 504.547,1155.48 504.557,1155.5 504.566,1155.51 504.575,1155.53 504.584,1155.54 504.593,1155.56 504.603,1155.57 504.612,1155.59 504.621,1155.6 504.63,1155.62 504.639,1155.63 504.649,1155.64 504.658,1155.66 504.667,1155.67 504.676,1155.69 504.685,1155.7 504.694,1155.72 504.704,1155.73 504.713,1155.75 504.722,1155.76 504.731,1155.78 504.74,1155.79 504.75,1155.8 504.759,1155.82 504.768,1155.83 504.777,1155.85 504.786,1155.86 504.796,1155.88 504.805,1155.89 504.814,1155.91 504.823,1155.92 504.832,1155.93 504.841,1155.95 504.851,1155.96 504.86,1155.98 504.869,1155.99 504.878,1156.01 504.887,1156.02 504.897,1156.04 504.906,1156.05 504.915,1156.06 504.924,1156.08 504.933,1156.09 504.943,1156.11 504.952,1156.12 504.961,1156.14 504.97,1156.15 504.979,1156.17 504.989,1156.18 504.998,1156.2 505.007,1156.21 505.016,1156.22 505.025,1156.24 505.034,1156.25 505.044,1156.27 505.053,1156.28 505.062,1156.3 505.071,1156.31 505.08,1156.33 505.09,1156.34 505.099,1156.35 505.108,1156.37 505.117,1156.38 505.126,1156.4 505.136,1156.41 505.145,1156.43 505.154,1156.44 505.163,1156.46 505.172,1156.47 505.181,1156.48 505.191,1156.5 505.2,1156.51 505.209,1156.53 505.218,1156.54 505.227,1156.56 505.237,1156.57 505.246,1156.59 505.255,1156.6 505.264,1156.61 505.273,1156.63 505.283,1156.64 505.292,1156.66 505.301,1156.67 505.31,1156.69 505.319,1156.7 505.329,1156.71 505.338,1156.73 505.347,1156.74 505.356,1156.76 505.365,1156.77 505.374,1156.79 505.384,1156.8 505.393,1156.82 505.402,1156.83 505.411,1156.84 505.42,1156.86 505.43,1156.87 505.439,1156.89 505.448,1156.9 505.457,1156.92 505.466,1156.93 505.476,1156.95 505.485,1156.96 505.494,1156.97 505.503,1156.99 505.512,1157 505.521,1157.02 505.531,1157.03 505.54,1157.05 505.549,1157.06 505.558,1157.07 505.567,1157.09 505.577,1157.1 505.586,1157.12 505.595,1157.13 505.604,1157.15 505.613,1157.16 505.623,1157.18 505.632,1157.19 505.641,1157.2 505.65,1157.22 505.659,1157.23 505.669,1157.25 505.678,1157.26 505.687,1157.28 505.696,1157.29 505.705,1157.3 505.714,1157.32 505.724,1157.33 505.733,1157.35 505.742,1157.36 505.751,1157.38 505.76,1157.39 505.77,1157.41 505.779,1157.42 505.788,1157.43 505.797,1157.45 505.806,1157.46 505.816,1157.48 505.825,1157.49 505.834,1157.51 505.843,1157.52 505.852,1157.53 505.861,1157.55 505.871,1157.56 505.88,1157.58 505.889,1157.59 505.898,1157.61 505.907,1157.62 505.917,1157.63 505.926,1157.65 505.935,1157.66 505.944,1157.68 505.953,1157.69 505.963,1157.71 505.972,1157.72 505.981,1157.73 505.99,1157.75 505.999,1157.76 506.009,1157.78 506.018,1157.79 506.027,1157.81 506.036,1157.82 506.045,1157.84 506.054,1157.85 506.064,1157.86 506.073,1157.88 506.082,1157.89 506.091,1157.91 506.1,1157.92 506.11,1157.94 506.119,1157.95 506.128,1157.96 506.137,1157.98 506.146,1157.99 506.156,1158.01 506.165,1158.02 506.174,1158.04 506.183,1158.05 506.192,1158.06 506.201,1158.08 506.211,1158.09 506.22,1158.11 506.229,1158.12 506.238,1158.14 506.247,1158.15 506.257,1158.16 506.266,1158.18 506.275,1158.19 506.284,1158.21 506.293,1158.22 506.303,1158.24 506.312,1158.25 506.321,1158.26 506.33,1158.28 506.339,1158.29 506.349,1158.31 506.358,1158.32 506.367,1158.34 506.376,1158.35 506.385,1158.36 506.394,1158.38 506.404,1158.39 506.413,1158.41 506.422,1158.42 506.431,1158.44 506.44,1158.45 506.45,1158.46 506.459,1158.48 506.468,1158.49 506.477,1158.51 506.486,1158.52 506.496,1158.53 506.505,1158.55 506.514,1158.56 506.523,1158.58 506.532,1158.59 506.542,1158.61 506.551,1158.62 506.56,1158.63 506.569,1158.65 506.578,1158.66 506.587,1158.68 506.597,1158.69 506.606,1158.71 506.615,1158.72 506.624,1158.73 506.633,1158.75 506.643,1158.76 506.652,1158.78 506.661,1158.79 506.67,1158.81 506.679,1158.82 506.689,1158.83 506.698,1158.85 506.707,1158.86 506.716,1158.88 506.725,1158.89 506.734,1158.91 506.744,1158.92 506.753,1158.93 506.762,1158.95 506.771,1158.96 506.78,1158.98 506.79,1158.99 506.799,1159 506.808,1159.02 506.817,1159.03 506.826,1159.05 506.836,1159.06 506.845,1159.08 506.854,1159.09 506.863,1159.1 506.872,1159.12 506.882,1159.13 506.891,1159.15 506.9,1159.16 506.909,1159.17 506.918,1159.19 506.927,1159.2 506.937,1159.22 506.946,1159.23 506.955,1159.25 506.964,1159.26 506.973,1159.27 506.983,1159.29 506.992,1159.3 507.001,1159.32 507.01,1159.33 507.019,1159.35 507.029,1159.36 507.038,1159.37 507.047,1159.39 507.056,1159.4 507.065,1159.42 507.074,1159.43 507.084,1159.44 507.093,1159.46 507.102,1159.47 507.111,1159.49 507.12,1159.5 507.13,1159.52 507.139,1159.53 507.148,1159.54 507.157,1159.56 507.166,1159.57 507.176,1159.59 507.185,1159.6 507.194,1159.61 507.203,1159.63 507.212,1159.64 507.222,1159.66 507.231,1159.67 507.24,1159.68 507.249,1159.7 507.258,1159.71 507.267,1159.73 507.277,1159.74 507.286,1159.76 507.295,1159.77 507.304,1159.78 507.313,1159.8 507.323,1159.81 507.332,1159.83 507.341,1159.84 507.35,1159.85 507.359,1159.87 507.369,1159.88 507.378,1159.9 507.387,1159.91 507.396,1159.93 507.405,1159.94 507.414,1159.95 507.424,1159.97 507.433,1159.98 507.442,1160 507.451,1160.01 507.46,1160.02 507.47,1160.04 507.479,1160.05 507.488,1160.07 507.497,1160.08 507.506,1160.09 507.516,1160.11 507.525,1160.12 507.534,1160.14 507.543,1160.15 507.552,1160.17 507.562,1160.18 507.571,1160.19 507.58,1160.21 507.589,1160.22 507.598,1160.24 507.607,1160.25 507.617,1160.26 507.626,1160.28 507.635,1160.29 507.644,1160.31 507.653,1160.32 507.663,1160.33 507.672,1160.35 507.681,1160.36 507.69,1160.38 507.699,1160.39 507.709,1160.4 507.718,1160.42 507.727,1160.43 507.736,1160.45 507.745,1160.46 507.754,1160.48 507.764,1160.49 507.773,1160.5 507.782,1160.52 507.791,1160.53 507.8,1160.55 507.81,1160.56 507.819,1160.57 507.828,1160.59 507.837,1160.6 507.846,1160.62 507.856,1160.63 507.865,1160.64 507.874,1160.66 507.883,1160.67 507.892,1160.69 507.902,1160.7 507.911,1160.71 507.92,1160.73 507.929,1160.74 507.938,1160.76 507.947,1160.77 507.957,1160.78 507.966,1160.8 507.975,1160.81 507.984,1160.83 507.993,1160.84 508.003,1160.85 508.012,1160.87 508.021,1160.88 508.03,1160.9 508.039,1160.91 508.049,1160.92 508.058,1160.94 508.067,1160.95 508.076,1160.97 508.085,1160.98 508.094,1161 508.104,1161.01 508.113,1161.02 508.122,1161.04 508.131,1161.05 508.14,1161.07 508.15,1161.08 508.159,1161.09 508.168,1161.11 508.177,1161.12 508.186,1161.14 508.196,1161.15 508.205,1161.16 508.214,1161.18 508.223,1161.19 508.232,1161.21 508.242,1161.22 508.251,1161.23 508.26,1161.25 508.269,1161.26 508.278,1161.28 508.287,1161.29 508.297,1161.3 508.306,1161.32 508.315,1161.33 508.324,1161.35 508.333,1161.36 508.343,1161.37 508.352,1161.39 508.361,1161.4 508.37,1161.42 508.379,1161.43 508.389,1161.44 508.398,1161.46 508.407,1161.47 508.416,1161.49 508.425,1161.5 508.434,1161.51 508.444,1161.53 508.453,1161.54 508.462,1161.56 508.471,1161.57 508.48,1161.58 508.49,1161.6 508.499,1161.61 508.508,1161.63 508.517,1161.64 508.526,1161.65 508.536,1161.67 508.545,1161.68 508.554,1161.69 508.563,1161.71 508.572,1161.72 508.582,1161.74 508.591,1161.75 508.6,1161.76 508.609,1161.78 508.618,1161.79 508.627,1161.81 508.637,1161.82 508.646,1161.83 508.655,1161.85 508.664,1161.86 508.673,1161.88 508.683,1161.89 508.692,1161.9 508.701,1161.92 508.71,1161.93 508.719,1161.95 508.729,1161.96 508.738,1161.97 508.747,1161.99 508.756,1162 508.765,1162.02 508.774,1162.03 508.784,1162.04 508.793,1162.06 508.802,1162.07 508.811,1162.09 508.82,1162.1 508.83,1162.11 508.839,1162.13 508.848,1162.14 508.857,1162.16 508.866,1162.17 508.876,1162.18 508.885,1162.2 508.894,1162.21 508.903,1162.22 508.912,1162.24 508.922,1162.25 508.931,1162.27 508.94,1162.28 508.949,1162.29 508.958,1162.31 508.967,1162.32 508.977,1162.34 508.986,1162.35 508.995,1162.36 509.004,1162.38 509.013,1162.39 509.023,1162.41 509.032,1162.42 509.041,1162.43 509.05,1162.45 509.059,1162.46 509.069,1162.48 509.078,1162.49 509.087,1162.5 509.096,1162.52 509.105,1162.53 509.115,1162.54 509.124,1162.56 509.133,1162.57 509.142,1162.59 509.151,1162.6 509.16,1162.61 509.17,1162.63 509.179,1162.64 509.188,1162.66 509.197,1162.67 509.206,1162.68 509.216,1162.7 509.225,1162.71 509.234,1162.73 509.243,1162.74 509.252,1162.75 509.262,1162.77 509.271,1162.78 509.28,1162.79 509.289,1162.81 509.298,1162.82 509.307,1162.84 509.317,1162.85 509.326,1162.86 509.335,1162.88 509.344,1162.89 509.353,1162.91 509.363,1162.92 509.372,1162.93 509.381,1162.95 509.39,1162.96 509.399,1162.97 509.409,1162.99 509.418,1163 509.427,1163.02 509.436,1163.03 509.445,1163.04 509.455,1163.06 509.464,1163.07 509.473,1163.09 509.482,1163.1 509.491,1163.11 509.5,1163.13 509.51,1163.14 509.519,1163.15 509.528,1163.17 509.537,1163.18 509.546,1163.2 509.556,1163.21 509.565,1163.22 509.574,1163.24 509.583,1163.25 509.592,1163.27 509.602,1163.28 509.611,1163.29 509.62,1163.31 509.629,1163.32 509.638,1163.33 509.647,1163.35 509.657,1163.36 509.666,1163.38 509.675,1163.39 509.684,1163.4 509.693,1163.42 509.703,1163.43 509.712,1163.44 509.721,1163.46 509.73,1163.47 509.739,1163.49 509.749,1163.5 509.758,1163.51 509.767,1163.53 509.776,1163.54 509.785,1163.56 509.795,1163.57 509.804,1163.58 509.813,1163.6 509.822,1163.61 509.831,1163.62 509.84,1163.64 509.85,1163.65 509.859,1163.67 509.868,1163.68 509.877,1163.69 509.886,1163.71 509.896,1163.72 509.905,1163.73 509.914,1163.75 509.923,1163.76 509.932,1163.78 509.942,1163.79 509.951,1163.8 509.96,1163.82 509.969,1163.83 509.978,1163.84 509.987,1163.86 509.997,1163.87 510.006,1163.89 510.015,1163.9 510.024,1163.91 510.033,1163.93 510.043,1163.94 510.052,1163.95 510.061,1163.97 510.07,1163.98 510.079,1164 510.089,1164.01 510.098,1164.02 510.107,1164.04 510.116,1164.05 510.125,1164.06 510.135,1164.08 510.144,1164.09 510.153,1164.11 510.162,1164.12 510.171,1164.13 510.18,1164.15 510.19,1164.16 510.199,1164.17 510.208,1164.19 510.217,1164.2 510.226,1164.22 510.236,1164.23 510.245,1164.24 510.254,1164.26 510.263,1164.27 510.272,1164.28 510.282,1164.3 510.291,1164.31 510.3,1164.33 510.309,1164.34 510.318,1164.35 510.327,1164.37 510.337,1164.38 510.346,1164.39 510.355,1164.41 510.364,1164.42 510.373,1164.44 510.383,1164.45 510.392,1164.46 510.401,1164.48 510.41,1164.49 510.419,1164.5 510.429,1164.52 510.438,1164.53 510.447,1164.55 510.456,1164.56 510.465,1164.57 510.475,1164.59 510.484,1164.6 510.493,1164.61 510.502,1164.63 510.511,1164.64 510.52,1164.66 510.53,1164.67 510.539,1164.68 510.548,1164.7 510.557,1164.71 510.566,1164.72 510.576,1164.74 510.585,1164.75 510.594,1164.76 510.603,1164.78 510.612,1164.79 510.622,1164.81 510.631,1164.82 510.64,1164.83 510.649,1164.85 510.658,1164.86 510.667,1164.87 510.677,1164.89 510.686,1164.9 510.695,1164.92 510.704,1164.93 510.713,1164.94 510.723,1164.96 510.732,1164.97 510.741,1164.98 510.75,1165 510.759,1165.01 510.769,1165.02 510.778,1165.04 510.787,1165.05 510.796,1165.07 510.805,1165.08 510.815,1165.09 510.824,1165.11 510.833,1165.12 510.842,1165.13 510.851,1165.15 510.86,1165.16 510.87,1165.17 510.879,1165.19 510.888,1165.2 510.897,1165.22 510.906,1165.23 510.916,1165.24 510.925,1165.26 510.934,1165.27 510.943,1165.28 510.952,1165.3 510.962,1165.31 510.971,1165.33 510.98,1165.34 510.989,1165.35 510.998,1165.37 511.007,1165.38 511.017,1165.39 511.026,1165.41 511.035,1165.42 511.044,1165.43 511.053,1165.45 511.063,1165.46 511.072,1165.48 511.081,1165.49 511.09,1165.5 511.099,1165.52 511.109,1165.53 511.118,1165.54 511.127,1165.56 511.136,1165.57 511.145,1165.58 511.155,1165.6 511.164,1165.61 511.173,1165.62 511.182,1165.64 511.191,1165.65 511.2,1165.67 511.21,1165.68 511.219,1165.69 511.228,1165.71 511.237,1165.72 511.246,1165.73 511.256,1165.75 511.265,1165.76 511.274,1165.77 511.283,1165.79 511.292,1165.8 511.302,1165.82 511.311,1165.83 511.32,1165.84 511.329,1165.86 511.338,1165.87 511.347,1165.88 511.357,1165.9 511.366,1165.91 511.375,1165.92 511.384,1165.94 511.393,1165.95 511.403,1165.96 511.412,1165.98 511.421,1165.99 511.43,1166.01 511.439,1166.02 511.449,1166.03 511.458,1166.05 511.467,1166.06 511.476,1166.07 511.485,1166.09 511.495,1166.1 511.504,1166.11 511.513,1166.13 511.522,1166.14 511.531,1166.15 511.54,1166.17 511.55,1166.18 511.559,1166.2 511.568,1166.21 511.577,1166.22 511.586,1166.24 511.596,1166.25 511.605,1166.26 511.614,1166.28 511.623,1166.29 511.632,1166.3 511.642,1166.32 511.651,1166.33 511.66,1166.34 511.669,1166.36 511.678,1166.37 511.688,1166.39 511.697,1166.4 511.706,1166.41 511.715,1166.43 511.724,1166.44 511.733,1166.45 511.743,1166.47 511.752,1166.48 511.761,1166.49 511.77,1166.51 511.779,1166.52 511.789,1166.53 511.798,1166.55 511.807,1166.56 511.816,1166.57 511.825,1166.59 511.835,1166.6 511.844,1166.62 511.853,1166.63 511.862,1166.64 511.871,1166.66 511.88,1166.67 511.89,1166.68 511.899,1166.7 511.908,1166.71 511.917,1166.72 511.926,1166.74 511.936,1166.75 511.945,1166.76 511.954,1166.78 511.963,1166.79 511.972,1166.8 511.982,1166.82 511.991,1166.83 512,1166.85 512.009,1166.86 512.018,1166.87 512.028,1166.89 512.037,1166.9 512.046,1166.91 512.055,1166.93 512.064,1166.94 512.073,1166.95 512.083,1166.97 512.092,1166.98 512.101,1166.99 512.11,1167.01 512.119,1167.02 512.129,1167.03 512.138,1167.05 512.147,1167.06 512.156,1167.07 512.165,1167.09 512.175,1167.1 512.184,1167.12 512.193,1167.13 512.202,1167.14 512.211,1167.16 512.22,1167.17 512.23,1167.18 512.239,1167.2 512.248,1167.21 512.257,1167.22 512.266,1167.24 512.276,1167.25 512.285,1167.26 512.294,1167.28 512.303,1167.29 512.312,1167.3 512.322,1167.32 512.331,1167.33 512.34,1167.34 512.349,1167.36 512.358,1167.37 512.368,1167.38 512.377,1167.4 512.386,1167.41 512.395,1167.42 512.404,1167.44 512.413,1167.45 512.423,1167.47 512.432,1167.48 512.441,1167.49 512.45,1167.51 512.459,1167.52 512.469,1167.53 512.478,1167.55 512.487,1167.56 512.496,1167.57 512.505,1167.59 512.515,1167.6 512.524,1167.61 512.533,1167.63 512.542,1167.64 512.551,1167.65 512.56,1167.67 512.57,1167.68 512.579,1167.69 512.588,1167.71 512.597,1167.72 512.606,1167.73 512.616,1167.75 512.625,1167.76 512.634,1167.77 512.643,1167.79 512.652,1167.8 512.662,1167.81 512.671,1167.83 512.68,1167.84 512.689,1167.85 512.698,1167.87 512.708,1167.88 512.717,1167.9 512.726,1167.91 512.735,1167.92 512.744,1167.94 512.753,1167.95 512.763,1167.96 512.772,1167.98 512.781,1167.99 512.79,1168 512.799,1168.02 512.809,1168.03 512.818,1168.04 512.827,1168.06 512.836,1168.07 512.845,1168.08 512.855,1168.1 512.864,1168.11 512.873,1168.12 512.882,1168.14 512.891,1168.15 512.9,1168.16 512.91,1168.18 512.919,1168.19 512.928,1168.2 512.937,1168.22 512.946,1168.23 512.956,1168.24 512.965,1168.26 512.974,1168.27 512.983,1168.28 512.992,1168.3 513.002,1168.31 513.011,1168.32 513.02,1168.34 513.029,1168.35 513.038,1168.36 513.048,1168.38 513.057,1168.39 513.066,1168.4 513.075,1168.42 513.084,1168.43 513.093,1168.44 513.103,1168.46 513.112,1168.47 513.121,1168.48 513.13,1168.5 513.139,1168.51 513.149,1168.52 513.158,1168.54 513.167,1168.55 513.176,1168.56 513.185,1168.58 513.195,1168.59 513.204,1168.6 513.213,1168.62 513.222,1168.63 513.231,1168.64 513.24,1168.66 513.25,1168.67 513.259,1168.68 513.268,1168.7 513.277,1168.71 513.286,1168.72 513.296,1168.74 513.305,1168.75 513.314,1168.76 513.323,1168.78 513.332,1168.79 513.342,1168.8 513.351,1168.82 513.36,1168.83 513.369,1168.84 513.378,1168.86 513.388,1168.87 513.397,1168.88 513.406,1168.9 513.415,1168.91 513.424,1168.92 513.433,1168.94 513.443,1168.95 513.452,1168.96 513.461,1168.98 513.47,1168.99 513.479,1169 513.489,1169.02 513.498,1169.03 513.507,1169.04 513.516,1169.06 513.525,1169.07 513.535,1169.08 513.544,1169.1 513.553,1169.11 513.562,1169.12 513.571,1169.14 513.58,1169.15 513.59,1169.16 513.599,1169.18 513.608,1169.19 513.617,1169.2 513.626,1169.22 513.636,1169.23 513.645,1169.24 513.654,1169.26 513.663,1169.27 513.672,1169.28 513.682,1169.3 513.691,1169.31 513.7,1169.32 513.709,1169.34 513.718,1169.35 513.728,1169.36 513.737,1169.38 513.746,1169.39 513.755,1169.4 513.764,1169.42 513.773,1169.43 513.783,1169.44 513.792,1169.46 513.801,1169.47 513.81,1169.48 513.819,1169.5 513.829,1169.51 513.838,1169.52 513.847,1169.54 513.856,1169.55 513.865,1169.56 513.875,1169.58 513.884,1169.59 513.893,1169.6 513.902,1169.62 513.911,1169.63 513.921,1169.64 513.93,1169.66 513.939,1169.67 513.948,1169.68 513.957,1169.7 513.966,1169.71 513.976,1169.72 513.985,1169.73 513.994,1169.75 514.003,1169.76 514.012,1169.77 514.022,1169.79 514.031,1169.8 514.04,1169.81 514.049,1169.83 514.058,1169.84 514.068,1169.85 514.077,1169.87 514.086,1169.88 514.095,1169.89 514.104,1169.91 514.113,1169.92 514.123,1169.93 514.132,1169.95 514.141,1169.96 514.15,1169.97 514.159,1169.99 514.169,1170 514.178,1170.01 514.187,1170.03 514.196,1170.04 514.205,1170.05 514.215,1170.07 514.224,1170.08 514.233,1170.09 514.242,1170.11 514.251,1170.12 514.261,1170.13 514.27,1170.14 514.279,1170.16 514.288,1170.17 514.297,1170.18 514.306,1170.2 514.316,1170.21 514.325,1170.22 514.334,1170.24 514.343,1170.25 514.352,1170.26 514.362,1170.28 514.371,1170.29 514.38,1170.3 514.389,1170.32 514.398,1170.33 514.408,1170.34 514.417,1170.36 514.426,1170.37 514.435,1170.38 514.444,1170.4 514.453,1170.41 514.463,1170.42 514.472,1170.44 514.481,1170.45 514.49,1170.46 514.499,1170.47 514.509,1170.49 514.518,1170.5 514.527,1170.51 514.536,1170.53 514.545,1170.54 514.555,1170.55 514.564,1170.57 514.573,1170.58 514.582,1170.59 514.591,1170.61 514.601,1170.62 514.61,1170.63 514.619,1170.65 514.628,1170.66 514.637,1170.67 514.646,1170.69 514.656,1170.7 514.665,1170.71 514.674,1170.73 514.683,1170.74 514.692,1170.75 514.702,1170.76 514.711,1170.78 514.72,1170.79 514.729,1170.8 514.738,1170.82 514.748,1170.83 514.757,1170.84 514.766,1170.86 514.775,1170.87 514.784,1170.88 514.793,1170.9 514.803,1170.91 514.812,1170.92 514.821,1170.94 514.83,1170.95 514.839,1170.96 514.849,1170.98 514.858,1170.99 514.867,1171 514.876,1171.01 514.885,1171.03 514.895,1171.04 514.904,1171.05 514.913,1171.07 514.922,1171.08 514.931,1171.09 514.941,1171.11 514.95,1171.12 514.959,1171.13 514.968,1171.15 514.977,1171.16 514.986,1171.17 514.996,1171.19 515.005,1171.2 515.014,1171.21 515.023,1171.22 515.032,1171.24 515.042,1171.25 515.051,1171.26 515.06,1171.28 515.069,1171.29 515.078,1171.3 515.088,1171.32 515.097,1171.33 515.106,1171.34 515.115,1171.36 515.124,1171.37 515.133,1171.38 515.143,1171.4 515.152,1171.41 515.161,1171.42 515.17,1171.43 515.179,1171.45 515.189,1171.46 515.198,1171.47 515.207,1171.49 515.216,1171.5 515.225,1171.51 515.235,1171.53 515.244,1171.54 515.253,1171.55 515.262,1171.57 515.271,1171.58 515.281,1171.59 515.29,1171.6 515.299,1171.62 515.308,1171.63 515.317,1171.64 515.326,1171.66 515.336,1171.67 515.345,1171.68 515.354,1171.7 515.363,1171.71 515.372,1171.72 515.382,1171.74 515.391,1171.75 515.4,1171.76 515.409,1171.77 515.418,1171.79 515.428,1171.8 515.437,1171.81 515.446,1171.83 515.455,1171.84 515.464,1171.85 515.473,1171.87 515.483,1171.88 515.492,1171.89 515.501,1171.91 515.51,1171.92 515.519,1171.93 515.529,1171.94 515.538,1171.96 515.547,1171.97 515.556,1171.98 515.565,1172 515.575,1172.01 515.584,1172.02 515.593,1172.04 515.602,1172.05 515.611,1172.06 515.621,1172.07 515.63,1172.09 515.639,1172.1 515.648,1172.11 515.657,1172.13 515.666,1172.14 515.676,1172.15 515.685,1172.17 515.694,1172.18 515.703,1172.19 515.712,1172.21 515.722,1172.22 515.731,1172.23 515.74,1172.24 515.749,1172.26 515.758,1172.27 515.768,1172.28 515.777,1172.3 515.786,1172.31 515.795,1172.32 515.804,1172.34 515.813,1172.35 515.823,1172.36 515.832,1172.37 515.841,1172.39 515.85,1172.4 515.859,1172.41 515.869,1172.43 515.878,1172.44 515.887,1172.45 515.896,1172.47 515.905,1172.48 515.915,1172.49 515.924,1172.5 515.933,1172.52 515.942,1172.53 515.951,1172.54 515.961,1172.56 515.97,1172.57 515.979,1172.58 515.988,1172.6 515.997,1172.61 516.006,1172.62 516.016,1172.63 516.025,1172.65 516.034,1172.66 516.043,1172.67 516.052,1172.69 516.062,1172.7 516.071,1172.71 516.08,1172.73 516.089,1172.74 516.098,1172.75 516.108,1172.76 516.117,1172.78 516.126,1172.79 516.135,1172.8 516.144,1172.82 516.153,1172.83 516.163,1172.84 516.172,1172.86 516.181,1172.87 516.19,1172.88 516.199,1172.89 516.209,1172.91 516.218,1172.92 516.227,1172.93 516.236,1172.95 516.245,1172.96 516.255,1172.97 516.264,1172.99 516.273,1173 516.282,1173.01 516.291,1173.02 516.301,1173.04 516.31,1173.05 516.319,1173.06 516.328,1173.08 516.337,1173.09 516.346,1173.1 516.356,1173.11 516.365,1173.13 516.374,1173.14 516.383,1173.15 516.392,1173.17 516.402,1173.18 516.411,1173.19 516.42,1173.21 516.429,1173.22 516.438,1173.23 516.448,1173.24 516.457,1173.26 516.466,1173.27 516.475,1173.28 516.484,1173.3 516.494,1173.31 516.503,1173.32 516.512,1173.33 516.521,1173.35 516.53,1173.36 516.539,1173.37 516.549,1173.39 516.558,1173.4 516.567,1173.41 516.576,1173.43 516.585,1173.44 516.595,1173.45 516.604,1173.46 516.613,1173.48 516.622,1173.49 516.631,1173.5 516.641,1173.52 516.65,1173.53 516.659,1173.54 516.668,1173.55 516.677,1173.57 516.686,1173.58 516.696,1173.59 516.705,1173.61 516.714,1173.62 516.723,1173.63 516.732,1173.64 516.742,1173.66 516.751,1173.67 516.76,1173.68 516.769,1173.7 516.778,1173.71 516.788,1173.72 516.797,1173.74 516.806,1173.75 516.815,1173.76 516.824,1173.77 516.834,1173.79 516.843,1173.8 516.852,1173.81 516.861,1173.83 516.87,1173.84 516.879,1173.85 516.889,1173.86 516.898,1173.88 516.907,1173.89 516.916,1173.9 516.925,1173.92 516.935,1173.93 516.944,1173.94 516.953,1173.95 516.962,1173.97 516.971,1173.98 516.981,1173.99 516.99,1174.01 516.999,1174.02 517.008,1174.03 517.017,1174.04 517.026,1174.06 517.036,1174.07 517.045,1174.08 517.054,1174.1 517.063,1174.11 517.072,1174.12 517.082,1174.13 517.091,1174.15 517.1,1174.16 517.109,1174.17 517.118,1174.19 517.128,1174.2 517.137,1174.21 517.146,1174.22 517.155,1174.24 517.164,1174.25 517.174,1174.26 517.183,1174.28 517.192,1174.29 517.201,1174.3 517.21,1174.31 517.219,1174.33 517.229,1174.34 517.238,1174.35 517.247,1174.37 517.256,1174.38 517.265,1174.39 517.275,1174.4 517.284,1174.42 517.293,1174.43 517.302,1174.44 517.311,1174.46 517.321,1174.47 517.33,1174.48 517.339,1174.49 517.348,1174.51 517.357,1174.52 517.366,1174.53 517.376,1174.55 517.385,1174.56 517.394,1174.57 517.403,1174.58 517.412,1174.6 517.422,1174.61 517.431,1174.62 517.44,1174.64 517.449,1174.65 517.458,1174.66 517.468,1174.67 517.477,1174.69 517.486,1174.7 517.495,1174.71 517.504,1174.72 517.514,1174.74 517.523,1174.75 517.532,1174.76 517.541,1174.78 517.55,1174.79 517.559,1174.8 517.569,1174.81 517.578,1174.83 517.587,1174.84 517.596,1174.85 517.605,1174.87 517.615,1174.88 517.624,1174.89 517.633,1174.9 517.642,1174.92 517.651,1174.93 517.661,1174.94 517.67,1174.96 517.679,1174.97 517.688,1174.98 517.697,1174.99 517.706,1175.01 517.716,1175.02 517.725,1175.03 517.734,1175.04 517.743,1175.06 517.752,1175.07 517.762,1175.08 517.771,1175.1 517.78,1175.11 517.789,1175.12 517.798,1175.13 517.808,1175.15 517.817,1175.16 517.826,1175.17 517.835,1175.19 517.844,1175.2 517.854,1175.21 517.863,1175.22 517.872,1175.24 517.881,1175.25 517.89,1175.26 517.899,1175.27 517.909,1175.29 517.918,1175.3 517.927,1175.31 517.936,1175.33 517.945,1175.34 517.955,1175.35 517.964,1175.36 517.973,1175.38 517.982,1175.39 517.991,1175.4 518.001,1175.42 518.01,1175.43 518.019,1175.44 518.028,1175.45 518.037,1175.47 518.046,1175.48 518.056,1175.49 518.065,1175.5 518.074,1175.52 518.083,1175.53 518.092,1175.54 518.102,1175.56 518.111,1175.57 518.12,1175.58 518.129,1175.59 518.138,1175.61 518.148,1175.62 518.157,1175.63 518.166,1175.64 518.175,1175.66 518.184,1175.67 518.194,1175.68 518.203,1175.7 518.212,1175.71 518.221,1175.72 518.23,1175.73 518.239,1175.75 518.249,1175.76 518.258,1175.77 518.267,1175.78 518.276,1175.8 518.285,1175.81 518.295,1175.82 518.304,1175.84 518.313,1175.85 518.322,1175.86 518.331,1175.87 518.341,1175.89 518.35,1175.9 518.359,1175.91 518.368,1175.92 518.377,1175.94 518.386,1175.95 518.396,1175.96 518.405,1175.98 518.414,1175.99 518.423,1176 518.432,1176.01 518.442,1176.03 518.451,1176.04 518.46,1176.05 518.469,1176.06 518.478,1176.08 518.488,1176.09 518.497,1176.1 518.506,1176.11 518.515,1176.13 518.524,1176.14 518.534,1176.15 518.543,1176.17 518.552,1176.18 518.561,1176.19 518.57,1176.2 518.579,1176.22 518.589,1176.23 518.598,1176.24 518.607,1176.25 518.616,1176.27 518.625,1176.28 518.635,1176.29 518.644,1176.31 518.653,1176.32 518.662,1176.33 518.671,1176.34 518.681,1176.36 518.69,1176.37 518.699,1176.38 518.708,1176.39 518.717,1176.41 518.726,1176.42 518.736,1176.43 518.745,1176.44 518.754,1176.46 518.763,1176.47 518.772,1176.48 518.782,1176.5 518.791,1176.51 518.8,1176.52 518.809,1176.53 518.818,1176.55 518.828,1176.56 518.837,1176.57 518.846,1176.58 518.855,1176.6 518.864,1176.61 518.874,1176.62 518.883,1176.63 518.892,1176.65 518.901,1176.66 518.91,1176.67 518.919,1176.68 518.929,1176.7 518.938,1176.71 518.947,1176.72 518.956,1176.74 518.965,1176.75 518.975,1176.76 518.984,1176.77 518.993,1176.79 519.002,1176.8 519.011,1176.81 519.021,1176.82 519.03,1176.84 519.039,1176.85 519.048,1176.86 519.057,1176.87 519.067,1176.89 519.076,1176.9 519.085,1176.91 519.094,1176.92 519.103,1176.94 519.112,1176.95 519.122,1176.96 519.131,1176.98 519.14,1176.99 519.149,1177 519.158,1177.01 519.168,1177.03 519.177,1177.04 519.186,1177.05 519.195,1177.06 519.204,1177.08 519.214,1177.09 519.223,1177.1 519.232,1177.11 519.241,1177.13 519.25,1177.14 519.259,1177.15 519.269,1177.16 519.278,1177.18 519.287,1177.19 519.296,1177.2 519.305,1177.21 519.315,1177.23 519.324,1177.24 519.333,1177.25 519.342,1177.27 519.351,1177.28 519.361,1177.29 519.37,1177.3 519.379,1177.32 519.388,1177.33 519.397,1177.34 519.407,1177.35 519.416,1177.37 519.425,1177.38 519.434,1177.39 519.443,1177.4 519.452,1177.42 519.462,1177.43 519.471,1177.44 519.48,1177.45 519.489,1177.47 519.498,1177.48 519.508,1177.49 519.517,1177.5 519.526,1177.52 519.535,1177.53 519.544,1177.54 519.554,1177.55 519.563,1177.57 519.572,1177.58 519.581,1177.59 519.59,1177.6 519.599,1177.62 519.609,1177.63 519.618,1177.64 519.627,1177.65 519.636,1177.67 519.645,1177.68 519.655,1177.69 519.664,1177.71 519.673,1177.72 519.682,1177.73 519.691,1177.74 519.701,1177.76 519.71,1177.77 519.719,1177.78 519.728,1177.79 519.737,1177.81 519.747,1177.82 519.756,1177.83 519.765,1177.84 519.774,1177.86 519.783,1177.87 519.792,1177.88 519.802,1177.89 519.811,1177.91 519.82,1177.92 519.829,1177.93 519.838,1177.94 519.848,1177.96 519.857,1177.97 519.866,1177.98 519.875,1177.99 519.884,1178.01 519.894,1178.02 519.903,1178.03 519.912,1178.04 519.921,1178.06 519.93,1178.07 519.939,1178.08 519.949,1178.09 519.958,1178.11 519.967,1178.12 519.976,1178.13 519.985,1178.14 519.995,1178.16 520.004,1178.17 520.013,1178.18 520.022,1178.19 520.031,1178.21 520.041,1178.22 520.05,1178.23 520.059,1178.24 520.068,1178.26 520.077,1178.27 520.087,1178.28 520.096,1178.29 520.105,1178.31 520.114,1178.32 520.123,1178.33 520.132,1178.34 520.142,1178.36 520.151,1178.37 520.16,1178.38 520.169,1178.39 520.178,1178.41 520.188,1178.42 520.197,1178.43 520.206,1178.44 520.215,1178.46 520.224,1178.47 520.234,1178.48 520.243,1178.49 520.252,1178.51 520.261,1178.52 520.27,1178.53 520.279,1178.54 520.289,1178.56 520.298,1178.57 520.307,1178.58 520.316,1178.59 520.325,1178.61 520.335,1178.62 520.344,1178.63 520.353,1178.64 520.362,1178.66 520.371,1178.67 520.381,1178.68 520.39,1178.69 520.399,1178.71 520.408,1178.72 520.417,1178.73 520.427,1178.74 520.436,1178.76 520.445,1178.77 520.454,1178.78 520.463,1178.79 520.472,1178.81 520.482,1178.82 520.491,1178.83 520.5,1178.84 520.509,1178.86 520.518,1178.87 520.528,1178.88 520.537,1178.89 520.546,1178.91 520.555,1178.92 520.564,1178.93 520.574,1178.94 520.583,1178.96 520.592,1178.97 520.601,1178.98 520.61,1178.99 520.619,1179 520.629,1179.02 520.638,1179.03 520.647,1179.04 520.656,1179.05 520.665,1179.07 520.675,1179.08 520.684,1179.09 520.693,1179.1 520.702,1179.12 520.711,1179.13 520.721,1179.14 520.73,1179.15 520.739,1179.17 520.748,1179.18 520.757,1179.19 520.767,1179.2 520.776,1179.22 520.785,1179.23 520.794,1179.24 520.803,1179.25 520.812,1179.27 520.822,1179.28 520.831,1179.29 520.84,1179.3 520.849,1179.32 520.858,1179.33 520.868,1179.34 520.877,1179.35 520.886,1179.37 520.895,1179.38 520.904,1179.39 520.914,1179.4 520.923,1179.41 520.932,1179.43 520.941,1179.44 520.95,1179.45 520.959,1179.46 520.969,1179.48 520.978,1179.49 520.987,1179.5 520.996,1179.51 521.005,1179.53 521.015,1179.54 521.024,1179.55 521.033,1179.56 521.042,1179.58 521.051,1179.59 521.061,1179.6 521.07,1179.61 521.079,1179.63 521.088,1179.64 521.097,1179.65 521.107,1179.66 521.116,1179.67 521.125,1179.69 521.134,1179.7 521.143,1179.71 521.152,1179.72 521.162,1179.74 521.171,1179.75 521.18,1179.76 521.189,1179.77 521.198,1179.79 521.208,1179.8 521.217,1179.81 521.226,1179.82 521.235,1179.84 521.244,1179.85 521.254,1179.86 521.263,1179.87 521.272,1179.89 521.281,1179.9 521.29,1179.91 521.3,1179.92 521.309,1179.93 521.318,1179.95 521.327,1179.96 521.336,1179.97 521.345,1179.98 521.355,1180 521.364,1180.01 521.373,1180.02 521.382,1180.03 521.391,1180.05 521.401,1180.06 521.41,1180.07 521.419,1180.08 521.428,1180.1 521.437,1180.11 521.447,1180.12 521.456,1180.13 521.465,1180.14 521.474,1180.16 521.483,1180.17 521.492,1180.18 521.502,1180.19 521.511,1180.21 521.52,1180.22 521.529,1180.23 521.538,1180.24 521.548,1180.26 521.557,1180.27 521.566,1180.28 521.575,1180.29 521.584,1180.31 521.594,1180.32 521.603,1180.33 521.612,1180.34 521.621,1180.35 521.63,1180.37 521.64,1180.38 521.649,1180.39 521.658,1180.4 521.667,1180.42 521.676,1180.43 521.685,1180.44 521.695,1180.45 521.704,1180.47 521.713,1180.48 521.722,1180.49 521.731,1180.5 521.741,1180.51 521.75,1180.53 521.759,1180.54 521.768,1180.55 521.777,1180.56 521.787,1180.58 521.796,1180.59 521.805,1180.6 521.814,1180.61 521.823,1180.63 521.832,1180.64 521.842,1180.65 521.851,1180.66 521.86,1180.67 521.869,1180.69 521.878,1180.7 521.888,1180.71 521.897,1180.72 521.906,1180.74 521.915,1180.75 521.924,1180.76 521.934,1180.77 521.943,1180.79 521.952,1180.8 521.961,1180.81 521.97,1180.82 521.98,1180.83 521.989,1180.85 521.998,1180.86 522.007,1180.87 522.016,1180.88 522.025,1180.9 522.035,1180.91 522.044,1180.92 522.053,1180.93 522.062,1180.94 522.071,1180.96 522.081,1180.97 522.09,1180.98 522.099,1180.99 522.108,1181.01 522.117,1181.02 522.127,1181.03 522.136,1181.04 522.145,1181.06 522.154,1181.07 522.163,1181.08 522.172,1181.09 522.182,1181.1 522.191,1181.12 522.2,1181.13 522.209,1181.14 522.218,1181.15 522.228,1181.17 522.237,1181.18 522.246,1181.19 522.255,1181.2 522.264,1181.21 522.274,1181.23 522.283,1181.24 522.292,1181.25 522.301,1181.26 522.31,1181.28 522.32,1181.29 522.329,1181.3 522.338,1181.31 522.347,1181.32 522.356,1181.34 522.365,1181.35 522.375,1181.36 522.384,1181.37 522.393,1181.39 522.402,1181.4 522.411,1181.41 522.421,1181.42 522.43,1181.43 522.439,1181.45 522.448,1181.46 522.457,1181.47 522.467,1181.48 522.476,1181.5 522.485,1181.51 522.494,1181.52 522.503,1181.53 522.512,1181.54 522.522,1181.56 522.531,1181.57 522.54,1181.58 522.549,1181.59 522.558,1181.61 522.568,1181.62 522.577,1181.63 522.586,1181.64 522.595,1181.65 522.604,1181.67 522.614,1181.68 522.623,1181.69 522.632,1181.7 522.641,1181.72 522.65,1181.73 522.66,1181.74 522.669,1181.75 522.678,1181.76 522.687,1181.78 522.696,1181.79 522.705,1181.8 522.715,1181.81 522.724,1181.83 522.733,1181.84 522.742,1181.85 522.751,1181.86 522.761,1181.87 522.77,1181.89 522.779,1181.9 522.788,1181.91 522.797,1181.92 522.807,1181.94 522.816,1181.95 522.825,1181.96 522.834,1181.97 522.843,1181.98 522.852,1182 522.862,1182.01 522.871,1182.02 522.88,1182.03 522.889,1182.05 522.898,1182.06 522.908,1182.07 522.917,1182.08 522.926,1182.09 522.935,1182.11 522.944,1182.12 522.954,1182.13 522.963,1182.14 522.972,1182.15 522.981,1182.17 522.99,1182.18 523,1182.19 523.009,1182.2 523.018,1182.22 523.027,1182.23 523.036,1182.24 523.045,1182.25 523.055,1182.26 523.064,1182.28 523.073,1182.29 523.082,1182.3 523.091,1182.31 523.101,1182.33 523.11,1182.34 523.119,1182.35 523.128,1182.36 523.137,1182.37 523.147,1182.39 523.156,1182.4 523.165,1182.41 523.174,1182.42 523.183,1182.43 523.192,1182.45 523.202,1182.46 523.211,1182.47 523.22,1182.48 523.229,1182.5 523.238,1182.51 523.248,1182.52 523.257,1182.53 523.266,1182.54 523.275,1182.56 523.284,1182.57 523.294,1182.58 523.303,1182.59 523.312,1182.6 523.321,1182.62 523.33,1182.63 523.34,1182.64 523.349,1182.65 523.358,1182.66 523.367,1182.68 523.376,1182.69 523.385,1182.7 523.395,1182.71 523.404,1182.73 523.413,1182.74 523.422,1182.75 523.431,1182.76 523.441,1182.77 523.45,1182.79 523.459,1182.8 523.468,1182.81 523.477,1182.82 523.487,1182.83 523.496,1182.85 523.505,1182.86 523.514,1182.87 523.523,1182.88 523.532,1182.9 523.542,1182.91 523.551,1182.92 523.56,1182.93 523.569,1182.94 523.578,1182.96 523.588,1182.97 523.597,1182.98 523.606,1182.99 523.615,1183 523.624,1183.02 523.634,1183.03 523.643,1183.04 523.652,1183.05 523.661,1183.06 523.67,1183.08 523.68,1183.09 523.689,1183.1 523.698,1183.11 523.707,1183.13 523.716,1183.14 523.725,1183.15 523.735,1183.16 523.744,1183.17 523.753,1183.19 523.762,1183.2 523.771,1183.21 523.781,1183.22 523.79,1183.23 523.799,1183.25 523.808,1183.26 523.817,1183.27 523.827,1183.28 523.836,1183.29 523.845,1183.31 523.854,1183.32 523.863,1183.33 523.873,1183.34 523.882,1183.35 523.891,1183.37 523.9,1183.38 523.909,1183.39 523.918,1183.4 523.928,1183.41 523.937,1183.43 523.946,1183.44 523.955,1183.45 523.964,1183.46 523.974,1183.48 523.983,1183.49 523.992,1183.5 524.001,1183.51 524.01,1183.52 524.02,1183.54 524.029,1183.55 524.038,1183.56 524.047,1183.57 524.056,1183.58 524.065,1183.6 524.075,1183.61 524.084,1183.62 524.093,1183.63 524.102,1183.64 524.111,1183.66 524.121,1183.67 524.13,1183.68 524.139,1183.69 524.148,1183.7 524.157,1183.72 524.167,1183.73 524.176,1183.74 524.185,1183.75 524.194,1183.76 524.203,1183.78 524.213,1183.79 524.222,1183.8 524.231,1183.81 524.24,1183.82 524.249,1183.84 524.258,1183.85 524.268,1183.86 524.277,1183.87 524.286,1183.88 524.295,1183.9 524.304,1183.91 524.314,1183.92 524.323,1183.93 524.332,1183.94 524.341,1183.96 524.35,1183.97 524.36,1183.98 524.369,1183.99 524.378,1184 524.387,1184.02 524.396,1184.03 524.405,1184.04 524.415,1184.05 524.424,1184.06 524.433,1184.08 524.442,1184.09 524.451,1184.1 524.461,1184.11 524.47,1184.12 524.479,1184.14 524.488,1184.15 524.497,1184.16 524.507,1184.17 524.516,1184.18 524.525,1184.2 524.534,1184.21 524.543,1184.22 524.553,1184.23 524.562,1184.24 524.571,1184.26 524.58,1184.27 524.589,1184.28 524.598,1184.29 524.608,1184.3 524.617,1184.32 524.626,1184.33 524.635,1184.34 524.644,1184.35 524.654,1184.36 524.663,1184.38 524.672,1184.39 524.681,1184.4 524.69,1184.41 524.7,1184.42 524.709,1184.44 524.718,1184.45 524.727,1184.46 524.736,1184.47 524.745,1184.48 524.755,1184.5 524.764,1184.51 524.773,1184.52 524.782,1184.53 524.791,1184.54 524.801,1184.56 524.81,1184.57 524.819,1184.58 524.828,1184.59 524.837,1184.6 524.847,1184.62 524.856,1184.63 524.865,1184.64 524.874,1184.65 524.883,1184.66 524.893,1184.68 524.902,1184.69 524.911,1184.7 524.92,1184.71 524.929,1184.72 524.938,1184.74 524.948,1184.75 524.957,1184.76 524.966,1184.77 524.975,1184.78 524.984,1184.8 524.994,1184.81 525.003,1184.82 525.012,1184.83 525.021,1184.84 525.03,1184.86 525.04,1184.87 525.049,1184.88 525.058,1184.89 525.067,1184.9 525.076,1184.91 525.085,1184.93 525.095,1184.94 525.104,1184.95 525.113,1184.96 525.122,1184.97 525.131,1184.99 525.141,1185 525.15,1185.01 525.159,1185.02 525.168,1185.03 525.177,1185.05 525.187,1185.06 525.196,1185.07 525.205,1185.08 525.214,1185.09 525.223,1185.11 525.233,1185.12 525.242,1185.13 525.251,1185.14 525.26,1185.15 525.269,1185.17 525.278,1185.18 525.288,1185.19 525.297,1185.2 525.306,1185.21 525.315,1185.22 525.324,1185.24 525.334,1185.25 525.343,1185.26 525.352,1185.27 525.361,1185.28 525.37,1185.3 525.38,1185.31 525.389,1185.32 525.398,1185.33 525.407,1185.34 525.416,1185.36 525.425,1185.37 525.435,1185.38 525.444,1185.39 525.453,1185.4 525.462,1185.42 525.471,1185.43 525.481,1185.44 525.49,1185.45 525.499,1185.46 525.508,1185.47 525.517,1185.49 525.527,1185.5 525.536,1185.51 525.545,1185.52 525.554,1185.53 525.563,1185.55 525.573,1185.56 525.582,1185.57 525.591,1185.58 525.6,1185.59 525.609,1185.61 525.618,1185.62 525.628,1185.63 525.637,1185.64 525.646,1185.65 525.655,1185.66 525.664,1185.68 525.674,1185.69 525.683,1185.7 525.692,1185.71 525.701,1185.72 525.71,1185.74 525.72,1185.75 525.729,1185.76 525.738,1185.77 525.747,1185.78 525.756,1185.8 525.765,1185.81 525.775,1185.82 525.784,1185.83 525.793,1185.84 525.802,1185.85 525.811,1185.87 525.821,1185.88 525.83,1185.89 525.839,1185.9 525.848,1185.91 525.857,1185.93 525.867,1185.94 525.876,1185.95 525.885,1185.96 525.894,1185.97 525.903,1185.98 525.913,1186 525.922,1186.01 525.931,1186.02 525.94,1186.03 525.949,1186.04 525.958,1186.06 525.968,1186.07 525.977,1186.08 525.986,1186.09 525.995,1186.1 526.004,1186.12 526.014,1186.13 526.023,1186.14 526.032,1186.15 526.041,1186.16 526.05,1186.17 526.06,1186.19 526.069,1186.2 526.078,1186.21 526.087,1186.22 526.096,1186.23 526.105,1186.25 526.115,1186.26 526.124,1186.27 526.133,1186.28 526.142,1186.29 526.151,1186.3 526.161,1186.32 526.17,1186.33 526.179,1186.34 526.188,1186.35 526.197,1186.36 526.207,1186.38 526.216,1186.39 526.225,1186.4 526.234,1186.41 526.243,1186.42 526.253,1186.43 526.262,1186.45 526.271,1186.46 526.28,1186.47 526.289,1186.48 526.298,1186.49 526.308,1186.51 526.317,1186.52 526.326,1186.53 526.335,1186.54 526.344,1186.55 526.354,1186.56 526.363,1186.58 526.372,1186.59 526.381,1186.6 526.39,1186.61 526.4,1186.62 526.409,1186.63 526.418,1186.65 526.427,1186.66 526.436,1186.67 526.446,1186.68 526.455,1186.69 526.464,1186.71 526.473,1186.72 526.482,1186.73 526.491,1186.74 526.501,1186.75 526.51,1186.76 526.519,1186.78 526.528,1186.79 526.537,1186.8 526.547,1186.81 526.556,1186.82 526.565,1186.84 526.574,1186.85 526.583,1186.86 526.593,1186.87 526.602,1186.88 526.611,1186.89 526.62,1186.91 526.629,1186.92 526.638,1186.93 526.648,1186.94 526.657,1186.95 526.666,1186.96 526.675,1186.98 526.684,1186.99 526.694,1187 526.703,1187.01 526.712,1187.02 526.721,1187.04 526.73,1187.05 526.74,1187.06 526.749,1187.07 526.758,1187.08 526.767,1187.09 526.776,1187.11 526.786,1187.12 526.795,1187.13 526.804,1187.14 526.813,1187.15 526.822,1187.16 526.831,1187.18 526.841,1187.19 526.85,1187.2 526.859,1187.21 526.868,1187.22 526.877,1187.23 526.887,1187.25 526.896,1187.26 526.905,1187.27 526.914,1187.28 526.923,1187.29 526.933,1187.31 526.942,1187.32 526.951,1187.33 526.96,1187.34 526.969,1187.35 526.978,1187.36 526.988,1187.38 526.997,1187.39 527.006,1187.4 527.015,1187.41 527.024,1187.42 527.034,1187.43 527.043,1187.45 527.052,1187.46 527.061,1187.47 527.07,1187.48 527.08,1187.49 527.089,1187.5 527.098,1187.52 527.107,1187.53 527.116,1187.54 527.126,1187.55 527.135,1187.56 527.144,1187.58 527.153,1187.59 527.162,1187.6 527.171,1187.61 527.181,1187.62 527.19,1187.63 527.199,1187.65 527.208,1187.66 527.217,1187.67 527.227,1187.68 527.236,1187.69 527.245,1187.7 527.254,1187.72 527.263,1187.73 527.273,1187.74 527.282,1187.75 527.291,1187.76 527.3,1187.77 527.309,1187.79 527.318,1187.8 527.328,1187.81 527.337,1187.82 527.346,1187.83 527.355,1187.84 527.364,1187.86 527.374,1187.87 527.383,1187.88 527.392,1187.89 527.401,1187.9 527.41,1187.91 527.42,1187.93 527.429,1187.94 527.438,1187.95 527.447,1187.96 527.456,1187.97 527.466,1187.98 527.475,1188 527.484,1188.01 527.493,1188.02 527.502,1188.03 527.511,1188.04 527.521,1188.05 527.53,1188.07 527.539,1188.08 527.548,1188.09 527.557,1188.1 527.567,1188.11 527.576,1188.12 527.585,1188.14 527.594,1188.15 527.603,1188.16 527.613,1188.17 527.622,1188.18 527.631,1188.19 527.64,1188.21 527.649,1188.22 527.658,1188.23 527.668,1188.24 527.677,1188.25 527.686,1188.26 527.695,1188.28 527.704,1188.29 527.714,1188.3 527.723,1188.31 527.732,1188.32 527.741,1188.33 527.75,1188.35 527.76,1188.36 527.769,1188.37 527.778,1188.38 527.787,1188.39 527.796,1188.4 527.806,1188.42 527.815,1188.43 527.824,1188.44 527.833,1188.45 527.842,1188.46 527.851,1188.47 527.861,1188.49 527.87,1188.5 527.879,1188.51 527.888,1188.52 527.897,1188.53 527.907,1188.54 527.916,1188.56 527.925,1188.57 527.934,1188.58 527.943,1188.59 527.953,1188.6 527.962,1188.61 527.971,1188.63 527.98,1188.64 527.989,1188.65 527.998,1188.66 528.008,1188.67 528.017,1188.68 528.026,1188.69 528.035,1188.71 528.044,1188.72 528.054,1188.73 528.063,1188.74 528.072,1188.75 528.081,1188.76 528.09,1188.78 528.1,1188.79 528.109,1188.8 528.118,1188.81 528.127,1188.82 528.136,1188.83 528.146,1188.85 528.155,1188.86 528.164,1188.87 528.173,1188.88 528.182,1188.89 528.191,1188.9 528.201,1188.92 528.21,1188.93 528.219,1188.94 528.228,1188.95 528.237,1188.96 528.247,1188.97 528.256,1188.99 528.265,1189 528.274,1189.01 528.283,1189.02 528.293,1189.03 528.302,1189.04 528.311,1189.05 528.32,1189.07 528.329,1189.08 528.338,1189.09 528.348,1189.1 528.357,1189.11 528.366,1189.12 528.375,1189.14 528.384,1189.15 528.394,1189.16 528.403,1189.17 528.412,1189.18 528.421,1189.19 528.43,1189.21 528.44,1189.22 528.449,1189.23 528.458,1189.24 528.467,1189.25 528.476,1189.26 528.486,1189.27 528.495,1189.29 528.504,1189.3 528.513,1189.31 528.522,1189.32 528.531,1189.33 528.541,1189.34 528.55,1189.36 528.559,1189.37 528.568,1189.38 528.577,1189.39 528.587,1189.4 528.596,1189.41 528.605,1189.43 528.614,1189.44 528.623,1189.45 528.633,1189.46 528.642,1189.47 528.651,1189.48 528.66,1189.49 528.669,1189.51 528.678,1189.52 528.688,1189.53 528.697,1189.54 528.706,1189.55 528.715,1189.56 528.724,1189.58 528.734,1189.59 528.743,1189.6 528.752,1189.61 528.761,1189.62 528.77,1189.63 528.78,1189.64 528.789,1189.66 528.798,1189.67 528.807,1189.68 528.816,1189.69 528.826,1189.7 528.835,1189.71 528.844,1189.73 528.853,1189.74 528.862,1189.75 528.871,1189.76 528.881,1189.77 528.89,1189.78 528.899,1189.79 528.908,1189.81 528.917,1189.82 528.927,1189.83 528.936,1189.84 528.945,1189.85 528.954,1189.86 528.963,1189.88 528.973,1189.89 528.982,1189.9 528.991,1189.91 529,1189.92 529.009,1189.93 529.019,1189.94 529.028,1189.96 529.037,1189.97 529.046,1189.98 529.055,1189.99 529.064,1190 529.074,1190.01 529.083,1190.02 529.092,1190.04 529.101,1190.05 529.11,1190.06 529.12,1190.07 529.129,1190.08 529.138,1190.09 529.147,1190.11 529.156,1190.12 529.166,1190.13 529.175,1190.14 529.184,1190.15 529.193,1190.16 529.202,1190.17 529.211,1190.19 529.221,1190.2 529.23,1190.21 529.239,1190.22 529.248,1190.23 529.257,1190.24 529.267,1190.25 529.276,1190.27 529.285,1190.28 529.294,1190.29 529.303,1190.3 529.313,1190.31 529.322,1190.32 529.331,1190.34 529.34,1190.35 529.349,1190.36 529.359,1190.37 529.368,1190.38 529.377,1190.39 529.386,1190.4 529.395,1190.42 529.404,1190.43 529.414,1190.44 529.423,1190.45 529.432,1190.46 529.441,1190.47 529.45,1190.48 529.46,1190.5 529.469,1190.51 529.478,1190.52 529.487,1190.53 529.496,1190.54 529.506,1190.55 529.515,1190.56 529.524,1190.58 529.533,1190.59 529.542,1190.6 529.551,1190.61 529.561,1190.62 529.57,1190.63 529.579,1190.64 529.588,1190.66 529.597,1190.67 529.607,1190.68 529.616,1190.69 529.625,1190.7 529.634,1190.71 529.643,1190.73 529.653,1190.74 529.662,1190.75 529.671,1190.76 529.68,1190.77 529.689,1190.78 529.699,1190.79 529.708,1190.81 529.717,1190.82 529.726,1190.83 529.735,1190.84 529.744,1190.85 529.754,1190.86 529.763,1190.87 529.772,1190.89 529.781,1190.9 529.79,1190.91 529.8,1190.92 529.809,1190.93 529.818,1190.94 529.827,1190.95 529.836,1190.97 529.846,1190.98 529.855,1190.99 529.864,1191 529.873,1191.01 529.882,1191.02 529.891,1191.03 529.901,1191.05 529.91,1191.06 529.919,1191.07 529.928,1191.08 529.937,1191.09 529.947,1191.1 529.956,1191.11 529.965,1191.13 529.974,1191.14 529.983,1191.15 529.993,1191.16 530.002,1191.17 530.011,1191.18 530.02,1191.19 530.029,1191.21 530.039,1191.22 530.048,1191.23 530.057,1191.24 530.066,1191.25 530.075,1191.26 530.084,1191.27 530.094,1191.29 530.103,1191.3 530.112,1191.31 530.121,1191.32 530.13,1191.33 530.14,1191.34 530.149,1191.35 530.158,1191.36 530.167,1191.38 530.176,1191.39 530.186,1191.4 530.195,1191.41 530.204,1191.42 530.213,1191.43 530.222,1191.44 530.231,1191.46 530.241,1191.47 530.25,1191.48 530.259,1191.49 530.268,1191.5 530.277,1191.51 530.287,1191.52 530.296,1191.54 530.305,1191.55 530.314,1191.56 530.323,1191.57 530.333,1191.58 530.342,1191.59 530.351,1191.6 530.36,1191.62 530.369,1191.63 530.379,1191.64 530.388,1191.65 530.397,1191.66 530.406,1191.67 530.415,1191.68 530.424,1191.7 530.434,1191.71 530.443,1191.72 530.452,1191.73 530.461,1191.74 530.47,1191.75 530.48,1191.76 530.489,1191.77 530.498,1191.79 530.507,1191.8 530.516,1191.81 530.526,1191.82 530.535,1191.83 530.544,1191.84 530.553,1191.85 530.562,1191.87 530.571,1191.88 530.581,1191.89 530.59,1191.9 530.599,1191.91 530.608,1191.92 530.617,1191.93 530.627,1191.94 530.636,1191.96 530.645,1191.97 530.654,1191.98 530.663,1191.99 530.673,1192 530.682,1192.01 530.691,1192.02 530.7,1192.04 530.709,1192.05 530.719,1192.06 530.728,1192.07 530.737,1192.08 530.746,1192.09 530.755,1192.1 530.764,1192.12 530.774,1192.13 530.783,1192.14 530.792,1192.15 530.801,1192.16 530.81,1192.17 530.82,1192.18 530.829,1192.19 530.838,1192.21 530.847,1192.22 530.856,1192.23 530.866,1192.24 530.875,1192.25 530.884,1192.26 530.893,1192.27 530.902,1192.29 530.911,1192.3 530.921,1192.31 530.93,1192.32 530.939,1192.33 530.948,1192.34 530.957,1192.35 530.967,1192.36 530.976,1192.38 530.985,1192.39 530.994,1192.4 531.003,1192.41 531.013,1192.42 531.022,1192.43 531.031,1192.44 531.04,1192.45 531.049,1192.47 531.059,1192.48 531.068,1192.49 531.077,1192.5 531.086,1192.51 531.095,1192.52 531.104,1192.53 531.114,1192.55 531.123,1192.56 531.132,1192.57 531.141,1192.58 531.15,1192.59 531.16,1192.6 531.169,1192.61 531.178,1192.62 531.187,1192.64 531.196,1192.65 531.206,1192.66 531.215,1192.67 531.224,1192.68 531.233,1192.69 531.242,1192.7 531.252,1192.71 531.261,1192.73 531.27,1192.74 531.279,1192.75 531.288,1192.76 531.297,1192.77 531.307,1192.78 531.316,1192.79 531.325,1192.8 531.334,1192.82 531.343,1192.83 531.353,1192.84 531.362,1192.85 531.371,1192.86 531.38,1192.87 531.389,1192.88 531.399,1192.9 531.408,1192.91 531.417,1192.92 531.426,1192.93 531.435,1192.94 531.444,1192.95 531.454,1192.96 531.463,1192.97 531.472,1192.99 531.481,1193 531.49,1193.01 531.5,1193.02 531.509,1193.03 531.518,1193.04 531.527,1193.05 531.536,1193.06 531.546,1193.08 531.555,1193.09 531.564,1193.1 531.573,1193.11 531.582,1193.12 531.592,1193.13 531.601,1193.14 531.61,1193.15 531.619,1193.17 531.628,1193.18 531.637,1193.19 531.647,1193.2 531.656,1193.21 531.665,1193.22 531.674,1193.23 531.683,1193.24 531.693,1193.26 531.702,1193.27 531.711,1193.28 531.72,1193.29 531.729,1193.3 531.739,1193.31 531.748,1193.32 531.757,1193.33 531.766,1193.35 531.775,1193.36 531.784,1193.37 531.794,1193.38 531.803,1193.39 531.812,1193.4 531.821,1193.41 531.83,1193.42 531.84,1193.44 531.849,1193.45 531.858,1193.46 531.867,1193.47 531.876,1193.48 531.886,1193.49 531.895,1193.5 531.904,1193.51 531.913,1193.53 531.922,1193.54 531.932,1193.55 531.941,1193.56 531.95,1193.57 531.959,1193.58 531.968,1193.59 531.977,1193.6 531.987,1193.61 531.996,1193.63 532.005,1193.64 532.014,1193.65 532.023,1193.66 532.033,1193.67 532.042,1193.68 532.051,1193.69 532.06,1193.7 532.069,1193.72 532.079,1193.73 532.088,1193.74 532.097,1193.75 532.106,1193.76 532.115,1193.77 532.124,1193.78 532.134,1193.79 532.143,1193.81 532.152,1193.82 532.161,1193.83 532.17,1193.84 532.18,1193.85 532.189,1193.86 532.198,1193.87 532.207,1193.88 532.216,1193.89 532.226,1193.91 532.235,1193.92 532.244,1193.93 532.253,1193.94 532.262,1193.95 532.272,1193.96 532.281,1193.97 532.29,1193.98 532.299,1194 532.308,1194.01 532.317,1194.02 532.327,1194.03 532.336,1194.04 532.345,1194.05 532.354,1194.06 532.363,1194.07 532.373,1194.09 532.382,1194.1 532.391,1194.11 532.4,1194.12 532.409,1194.13 532.419,1194.14 532.428,1194.15 532.437,1194.16 532.446,1194.17 532.455,1194.19 532.464,1194.2 532.474,1194.21 532.483,1194.22 532.492,1194.23 532.501,1194.24 532.51,1194.25 532.52,1194.26 532.529,1194.27 532.538,1194.29 532.547,1194.3 532.556,1194.31 532.566,1194.32 532.575,1194.33 532.584,1194.34 532.593,1194.35 532.602,1194.36 532.612,1194.38 532.621,1194.39 532.63,1194.4 532.639,1194.41 532.648,1194.42 532.657,1194.43 532.667,1194.44 532.676,1194.45 532.685,1194.46 532.694,1194.48 532.703,1194.49 532.713,1194.5 532.722,1194.51 532.731,1194.52 532.74,1194.53 532.749,1194.54 532.759,1194.55 532.768,1194.56 532.777,1194.58 532.786,1194.59 532.795,1194.6 532.804,1194.61 532.814,1194.62 532.823,1194.63 532.832,1194.64 532.841,1194.65 532.85,1194.67 532.86,1194.68 532.869,1194.69 532.878,1194.7 532.887,1194.71 532.896,1194.72 532.906,1194.73 532.915,1194.74 532.924,1194.75 532.933,1194.77 532.942,1194.78 532.952,1194.79 532.961,1194.8 532.97,1194.81 532.979,1194.82 532.988,1194.83 532.997,1194.84 533.007,1194.85 533.016,1194.87 533.025,1194.88 533.034,1194.89 533.043,1194.9 533.053,1194.91 533.062,1194.92 533.071,1194.93 533.08,1194.94 533.089,1194.95 533.099,1194.97 533.108,1194.98 533.117,1194.99 533.126,1195 533.135,1195.01 533.144,1195.02 533.154,1195.03 533.163,1195.04 533.172,1195.05 533.181,1195.07 533.19,1195.08 533.2,1195.09 533.209,1195.1 533.218,1195.11 533.227,1195.12 533.236,1195.13 533.246,1195.14 533.255,1195.15 533.264,1195.16 533.273,1195.18 533.282,1195.19 533.292,1195.2 533.301,1195.21 533.31,1195.22 533.319,1195.23 533.328,1195.24 533.337,1195.25 533.347,1195.26 533.356,1195.28 533.365,1195.29 533.374,1195.3 533.383,1195.31 533.393,1195.32 533.402,1195.33 533.411,1195.34 533.42,1195.35 533.429,1195.36 533.439,1195.38 533.448,1195.39 533.457,1195.4 533.466,1195.41 533.475,1195.42 533.484,1195.43 533.494,1195.44 533.503,1195.45 533.512,1195.46 533.521,1195.48 533.53,1195.49 533.54,1195.5 533.549,1195.51 533.558,1195.52 533.567,1195.53 533.576,1195.54 533.586,1195.55 533.595,1195.56 533.604,1195.57 533.613,1195.59 533.622,1195.6 533.632,1195.61 533.641,1195.62 533.65,1195.63 533.659,1195.64 533.668,1195.65 533.677,1195.66 533.687,1195.67 533.696,1195.69 533.705,1195.7 533.714,1195.71 533.723,1195.72 533.733,1195.73 533.742,1195.74 533.751,1195.75 533.76,1195.76 533.769,1195.77 533.779,1195.78 533.788,1195.8 533.797,1195.81 533.806,1195.82 533.815,1195.83 533.825,1195.84 533.834,1195.85 533.843,1195.86 533.852,1195.87 533.861,1195.88 533.87,1195.89 533.88,1195.91 533.889,1195.92 533.898,1195.93 533.907,1195.94 533.916,1195.95 533.926,1195.96 533.935,1195.97 533.944,1195.98 533.953,1195.99 533.962,1196.01 533.972,1196.02 533.981,1196.03 533.99,1196.04 533.999,1196.05 534.008,1196.06 534.017,1196.07 534.027,1196.08 534.036,1196.09 534.045,1196.1 534.054,1196.12 534.063,1196.13 534.073,1196.14 534.082,1196.15 534.091,1196.16 534.1,1196.17 534.109,1196.18 534.119,1196.19 534.128,1196.2 534.137,1196.21 534.146,1196.23 534.155,1196.24 534.165,1196.25 534.174,1196.26 534.183,1196.27 534.192,1196.28 534.201,1196.29 534.21,1196.3 534.22,1196.31 534.229,1196.32 534.238,1196.34 534.247,1196.35 534.256,1196.36 534.266,1196.37 534.275,1196.38 534.284,1196.39 534.293,1196.4 534.302,1196.41 534.312,1196.42 534.321,1196.43 534.33,1196.45 534.339,1196.46 534.348,1196.47 534.357,1196.48 534.367,1196.49 534.376,1196.5 534.385,1196.51 534.394,1196.52 534.403,1196.53 534.413,1196.54 534.422,1196.56 534.431,1196.57 534.44,1196.58 534.449,1196.59 534.459,1196.6 534.468,1196.61 534.477,1196.62 534.486,1196.63 534.495,1196.64 534.505,1196.65 534.514,1196.67 534.523,1196.68 534.532,1196.69 534.541,1196.7 534.55,1196.71 534.56,1196.72 534.569,1196.73 534.578,1196.74 534.587,1196.75 534.596,1196.76 534.606,1196.77 534.615,1196.79 534.624,1196.8 534.633,1196.81 534.642,1196.82 534.652,1196.83 534.661,1196.84 534.67,1196.85 534.679,1196.86 534.688,1196.87 534.697,1196.88 534.707,1196.9 534.716,1196.91 534.725,1196.92 534.734,1196.93 534.743,1196.94 534.753,1196.95 534.762,1196.96 534.771,1196.97 534.78,1196.98 534.789,1196.99 534.799,1197 534.808,1197.02 534.817,1197.03 534.826,1197.04 534.835,1197.05 534.845,1197.06 534.854,1197.07 534.863,1197.08 534.872,1197.09 534.881,1197.1 534.89,1197.11 534.9,1197.13 534.909,1197.14 534.918,1197.15 534.927,1197.16 534.936,1197.17 534.946,1197.18 534.955,1197.19 534.964,1197.2 534.973,1197.21 534.982,1197.22 534.992,1197.23 535.001,1197.25 535.01,1197.26 535.019,1197.27 535.028,1197.28 535.037,1197.29 535.047,1197.3 535.056,1197.31 535.065,1197.32 535.074,1197.33 535.083,1197.34 535.093,1197.35 535.102,1197.37 535.111,1197.38 535.12,1197.39 535.129,1197.4 535.139,1197.41 535.148,1197.42 535.157,1197.43 535.166,1197.44 535.175,1197.45 535.185,1197.46 535.194,1197.47 535.203,1197.49 535.212,1197.5 535.221,1197.51 535.23,1197.52 535.24,1197.53 535.249,1197.54 535.258,1197.55 535.267,1197.56 535.276,1197.57 535.286,1197.58 535.295,1197.59 535.304,1197.61 535.313,1197.62 535.322,1197.63 535.332,1197.64 535.341,1197.65 535.35,1197.66 535.359,1197.67 535.368,1197.68 535.377,1197.69 535.387,1197.7 535.396,1197.71 535.405,1197.73 535.414,1197.74 535.423,1197.75 535.433,1197.76 535.442,1197.77 535.451,1197.78 535.46,1197.79 535.469,1197.8 535.479,1197.81 535.488,1197.82 535.497,1197.83 535.506,1197.84 535.515,1197.86 535.525,1197.87 535.534,1197.88 535.543,1197.89 535.552,1197.9 535.561,1197.91 535.57,1197.92 535.58,1197.93 535.589,1197.94 535.598,1197.95 535.607,1197.96 535.616,1197.98 535.626,1197.99 535.635,1198 535.644,1198.01 535.653,1198.02 535.662,1198.03 535.672,1198.04 535.681,1198.05 535.69,1198.06 535.699,1198.07 535.708,1198.08 535.717,1198.09 535.727,1198.11 535.736,1198.12 535.745,1198.13 535.754,1198.14 535.763,1198.15 535.773,1198.16 535.782,1198.17 535.791,1198.18 535.8,1198.19 535.809,1198.2 535.819,1198.21 535.828,1198.22 535.837,1198.24 535.846,1198.25 535.855,1198.26 535.865,1198.27 535.874,1198.28 535.883,1198.29 535.892,1198.3 535.901,1198.31 535.91,1198.32 535.92,1198.33 535.929,1198.34 535.938,1198.36 535.947,1198.37 535.956,1198.38 535.966,1198.39 535.975,1198.4 535.984,1198.41 535.993,1198.42 536.002,1198.43 536.012,1198.44 536.021,1198.45 536.03,1198.46 536.039,1198.47 536.048,1198.48 536.057,1198.5 536.067,1198.51 536.076,1198.52 536.085,1198.53 536.094,1198.54 536.103,1198.55 536.113,1198.56 536.122,1198.57 536.131,1198.58 536.14,1198.59 536.149,1198.6 536.159,1198.61 536.168,1198.63 536.177,1198.64 536.186,1198.65 536.195,1198.66 536.205,1198.67 536.214,1198.68 536.223,1198.69 536.232,1198.7 536.241,1198.71 536.25,1198.72 536.26,1198.73 536.269,1198.74 536.278,1198.76 536.287,1198.77 536.296,1198.78 536.306,1198.79 536.315,1198.8 536.324,1198.81 536.333,1198.82 536.342,1198.83 536.352,1198.84 536.361,1198.85 536.37,1198.86 536.379,1198.87 536.388,1198.88 536.398,1198.9 536.407,1198.91 536.416,1198.92 536.425,1198.93 536.434,1198.94 536.443,1198.95 536.453,1198.96 536.462,1198.97 536.471,1198.98 536.48,1198.99 536.489,1199 536.499,1199.01 536.508,1199.03 536.517,1199.04 536.526,1199.05 536.535,1199.06 536.545,1199.07 536.554,1199.08 536.563,1199.09 536.572,1199.1 536.581,1199.11 536.59,1199.12 536.6,1199.13 536.609,1199.14 536.618,1199.15 536.627,1199.17 536.636,1199.18 536.646,1199.19 536.655,1199.2 536.664,1199.21 536.673,1199.22 536.682,1199.23 536.692,1199.24 536.701,1199.25 536.71,1199.26 536.719,1199.27 536.728,1199.28 536.738,1199.29 536.747,1199.31 536.756,1199.32 536.765,1199.33 536.774,1199.34 536.783,1199.35 536.793,1199.36 536.802,1199.37 536.811,1199.38 536.82,1199.39 536.829,1199.4 536.839,1199.41 536.848,1199.42 536.857,1199.43 536.866,1199.45 536.875,1199.46 536.885,1199.47 536.894,1199.48 536.903,1199.49 536.912,1199.5 536.921,1199.51 536.93,1199.52 536.94,1199.53 536.949,1199.54 536.958,1199.55 536.967,1199.56 536.976,1199.57 536.986,1199.58 536.995,1199.6 537.004,1199.61 537.013,1199.62 537.022,1199.63 537.032,1199.64 537.041,1199.65 537.05,1199.66 537.059,1199.67 537.068,1199.68 537.078,1199.69 537.087,1199.7 537.096,1199.71 537.105,1199.72 537.114,1199.74 537.123,1199.75 537.133,1199.76 537.142,1199.77 537.151,1199.78 537.16,1199.79 537.169,1199.8 537.179,1199.81 537.188,1199.82 537.197,1199.83 537.206,1199.84 537.215,1199.85 537.225,1199.86 537.234,1199.87 537.243,1199.89 537.252,1199.9 537.261,1199.91 537.27,1199.92 537.28,1199.93 537.289,1199.94 537.298,1199.95 537.307,1199.96 537.316,1199.97 537.326,1199.98 537.335,1199.99 537.344,1200 537.353,1200.01 537.362,1200.02 537.372,1200.04 537.381,1200.05 537.39,1200.06 537.399,1200.07 537.408,1200.08 537.418,1200.09 537.427,1200.1 537.436,1200.11 537.445,1200.12 537.454,1200.13 537.463,1200.14 537.473,1200.15 537.482,1200.16 537.491,1200.17 537.5,1200.19 537.509,1200.2 537.519,1200.21 537.528,1200.22 537.537,1200.23 537.546,1200.24 537.555,1200.25 537.565,1200.26 537.574,1200.27 537.583,1200.28 537.592,1200.29 537.601,1200.3 537.61,1200.31 537.62,1200.32 537.629,1200.33 537.638,1200.35 537.647,1200.36 537.656,1200.37 537.666,1200.38 537.675,1200.39 537.684,1200.4 537.693,1200.41 537.702,1200.42 537.712,1200.43 537.721,1200.44 537.73,1200.45 537.739,1200.46 537.748,1200.47 537.758,1200.48 537.767,1200.49 537.776,1200.51 537.785,1200.52 537.794,1200.53 537.803,1200.54 537.813,1200.55 537.822,1200.56 537.831,1200.57 537.84,1200.58 537.849,1200.59 537.859,1200.6 537.868,1200.61 537.877,1200.62 537.886,1200.63 537.895,1200.64 537.905,1200.65 537.914,1200.67 537.923,1200.68 537.932,1200.69 537.941,1200.7 537.95,1200.71 537.96,1200.72 537.969,1200.73 537.978,1200.74 537.987,1200.75 537.996,1200.76 538.006,1200.77 538.015,1200.78 538.024,1200.79 538.033,1200.8 538.042,1200.81 538.052,1200.83 538.061,1200.84 538.07,1200.85 538.079,1200.86 538.088,1200.87 538.098,1200.88 538.107,1200.89 538.116,1200.9 538.125,1200.91 538.134,1200.92 538.143,1200.93 538.153,1200.94 538.162,1200.95 538.171,1200.96 538.18,1200.97 538.189,1200.98 538.199,1201 538.208,1201.01 538.217,1201.02 538.226,1201.03 538.235,1201.04 538.245,1201.05 538.254,1201.06 538.263,1201.07 538.272,1201.08 538.281,1201.09 538.29,1201.1 538.3,1201.11 538.309,1201.12 538.318,1201.13 538.327,1201.14 538.336,1201.15 538.346,1201.17 538.355,1201.18 538.364,1201.19 538.373,1201.2 538.382,1201.21 538.392,1201.22 538.401,1201.23 538.41,1201.24 538.419,1201.25 538.428,1201.26 538.438,1201.27 538.447,1201.28 538.456,1201.29 538.465,1201.3 538.474,1201.31 538.483,1201.32 538.493,1201.34 538.502,1201.35 538.511,1201.36 538.52,1201.37 538.529,1201.38 538.539,1201.39 538.548,1201.4 538.557,1201.41 538.566,1201.42 538.575,1201.43 538.585,1201.44 538.594,1201.45 538.603,1201.46 538.612,1201.47 538.621,1201.48 538.631,1201.49 538.64,1201.5 538.649,1201.52 538.658,1201.53 538.667,1201.54 538.676,1201.55 538.686,1201.56 538.695,1201.57 538.704,1201.58 538.713,1201.59 538.722,1201.6 538.732,1201.61 538.741,1201.62 538.75,1201.63 538.759,1201.64 538.768,1201.65 538.778,1201.66 538.787,1201.67 538.796,1201.68 538.805,1201.7 538.814,1201.71 538.823,1201.72 538.833,1201.73 538.842,1201.74 538.851,1201.75 538.86,1201.76 538.869,1201.77 538.879,1201.78 538.888,1201.79 538.897,1201.8 538.906,1201.81 538.915,1201.82 538.925,1201.83 538.934,1201.84 538.943,1201.85 538.952,1201.86 538.961,1201.87 538.971,1201.89 538.98,1201.9 538.989,1201.91 538.998,1201.92 539.007,1201.93 539.016,1201.94 539.026,1201.95 539.035,1201.96 539.044,1201.97 539.053,1201.98 539.062,1201.99 539.072,1202 539.081,1202.01 539.09,1202.02 539.099,1202.03 539.108,1202.04 539.118,1202.05 539.127,1202.07 539.136,1202.08 539.145,1202.09 539.154,1202.1 539.163,1202.11 539.173,1202.12 539.182,1202.13 539.191,1202.14 539.2,1202.15 539.209,1202.16 539.219,1202.17 539.228,1202.18 539.237,1202.19 539.246,1202.2 539.255,1202.21 539.265,1202.22 539.274,1202.23 539.283,1202.24 539.292,1202.25 539.301,1202.27 539.311,1202.28 539.32,1202.29 539.329,1202.3 539.338,1202.31 539.347,1202.32 539.356,1202.33 539.366,1202.34 539.375,1202.35 539.384,1202.36 539.393,1202.37 539.402,1202.38 539.412,1202.39 539.421,1202.4 539.43,1202.41 539.439,1202.42 539.448,1202.43 539.458,1202.44 539.467,1202.45 539.476,1202.47 539.485,1202.48 539.494,1202.49 539.503,1202.5 539.513,1202.51 539.522,1202.52 539.531,1202.53 539.54,1202.54 539.549,1202.55 539.559,1202.56 539.568,1202.57 539.577,1202.58 539.586,1202.59 539.595,1202.6 539.605,1202.61 539.614,1202.62 539.623,1202.63 539.632,1202.64 539.641,1202.65 539.651,1202.67 539.66,1202.68 539.669,1202.69 539.678,1202.7 539.687,1202.71 539.696,1202.72 539.706,1202.73 539.715,1202.74 539.724,1202.75 539.733,1202.76 539.742,1202.77 539.752,1202.78 539.761,1202.79 539.77,1202.8 539.779,1202.81 539.788,1202.82 539.798,1202.83 539.807,1202.84 539.816,1202.85 539.825,1202.86 539.834,1202.87 539.843,1202.89 539.853,1202.9 539.862,1202.91 539.871,1202.92 539.88,1202.93 539.889,1202.94 539.899,1202.95 539.908,1202.96 539.917,1202.97 539.926,1202.98 539.935,1202.99 539.945,1203 539.954,1203.01 539.963,1203.02 539.972,1203.03 539.981,1203.04 539.991,1203.05 540,1203.06 540.009,1203.07 540.018,1203.08 540.027,1203.1 540.036,1203.11 540.046,1203.12 540.055,1203.13 540.064,1203.14 540.073,1203.15 540.082,1203.16 540.092,1203.17 540.101,1203.18 540.11,1203.19 540.119,1203.2 540.128,1203.21 540.138,1203.22 540.147,1203.23 540.156,1203.24 540.165,1203.25 540.174,1203.26 540.183,1203.27 540.193,1203.28 540.202,1203.29 540.211,1203.3 540.22,1203.31 540.229,1203.33 540.239,1203.34 540.248,1203.35 540.257,1203.36 540.266,1203.37 540.275,1203.38 540.285,1203.39 540.294,1203.4 540.303,1203.41 540.312,1203.42 540.321,1203.43 540.331,1203.44 540.34,1203.45 540.349,1203.46 540.358,1203.47 540.367,1203.48 540.376,1203.49 540.386,1203.5 540.395,1203.51 540.404,1203.52 540.413,1203.53 540.422,1203.54 540.432,1203.56 540.441,1203.57 540.45,1203.58 540.459,1203.59 540.468,1203.6 540.478,1203.61 540.487,1203.62 540.496,1203.63 540.505,1203.64 540.514,1203.65 540.523,1203.66 540.533,1203.67 540.542,1203.68 540.551,1203.69 540.56,1203.7 540.569,1203.71 540.579,1203.72 540.588,1203.73 540.597,1203.74 540.606,1203.75 540.615,1203.76 540.625,1203.77 540.634,1203.78 540.643,1203.79 540.652,1203.81 540.661,1203.82 540.671,1203.83 540.68,1203.84 540.689,1203.85 540.698,1203.86 540.707,1203.87 540.716,1203.88 540.726,1203.89 540.735,1203.9 540.744,1203.91 540.753,1203.92 540.762,1203.93 540.772,1203.94 540.781,1203.95 540.79,1203.96 540.799,1203.97 540.808,1203.98 540.818,1203.99 540.827,1204 540.836,1204.01 540.845,1204.02 540.854,1204.03 540.863,1204.04 540.873,1204.06 540.882,1204.07 540.891,1204.08 540.9,1204.09 540.909,1204.1 540.919,1204.11 540.928,1204.12 540.937,1204.13 540.946,1204.14 540.955,1204.15 540.965,1204.16 540.974,1204.17 540.983,1204.18 540.992,1204.19 541.001,1204.2 541.011,1204.21 541.02,1204.22 541.029,1204.23 541.038,1204.24 541.047,1204.25 541.056,1204.26 541.066,1204.27 541.075,1204.28 541.084,1204.29 541.093,1204.3 541.102,1204.31 541.112,1204.33 541.121,1204.34 541.13,1204.35 541.139,1204.36 541.148,1204.37 541.158,1204.38 541.167,1204.39 541.176,1204.4 541.185,1204.41 541.194,1204.42 541.204,1204.43 541.213,1204.44 541.222,1204.45 541.231,1204.46 541.24,1204.47 541.249,1204.48 541.259,1204.49 541.268,1204.5 541.277,1204.51 541.286,1204.52 541.295,1204.53 541.305,1204.54 541.314,1204.55 541.323,1204.56 541.332,1204.57 541.341,1204.58 541.351,1204.59 541.36,1204.61 541.369,1204.62 541.378,1204.63 541.387,1204.64 541.396,1204.65 541.406,1204.66 541.415,1204.67 541.424,1204.68 541.433,1204.69 541.442,1204.7 541.452,1204.71 541.461,1204.72 541.47,1204.73 541.479,1204.74 541.488,1204.75 541.498,1204.76 541.507,1204.77 541.516,1204.78 541.525,1204.79 541.534,1204.8 541.544,1204.81 541.553,1204.82 541.562,1204.83 541.571,1204.84 541.58,1204.85 541.589,1204.86 541.599,1204.87 541.608,1204.88 541.617,1204.89 541.626,1204.91 541.635,1204.92 541.645,1204.93 541.654,1204.94 541.663,1204.95 541.672,1204.96 541.681,1204.97 541.691,1204.98 541.7,1204.99 541.709,1205 541.718,1205.01 541.727,1205.02 541.736,1205.03 541.746,1205.04 541.755,1205.05 541.764,1205.06 541.773,1205.07 541.782,1205.08 541.792,1205.09 541.801,1205.1 541.81,1205.11 541.819,1205.12 541.828,1205.13 541.838,1205.14 541.847,1205.15 541.856,1205.16 541.865,1205.17 541.874,1205.18 541.884,1205.19 541.893,1205.2 541.902,1205.21 541.911,1205.23 541.92,1205.24 541.929,1205.25 541.939,1205.26 541.948,1205.27 541.957,1205.28 541.966,1205.29 541.975,1205.3 541.985,1205.31 541.994,1205.32 542.003,1205.33 542.012,1205.34 542.021,1205.35 542.031,1205.36 542.04,1205.37 542.049,1205.38 542.058,1205.39 542.067,1205.4 542.076,1205.41 542.086,1205.42 542.095,1205.43 542.104,1205.44 542.113,1205.45 542.122,1205.46 542.132,1205.47 542.141,1205.48 542.15,1205.49 542.159,1205.5 542.168,1205.51 542.178,1205.52 542.187,1205.53 542.196,1205.54 542.205,1205.55 542.214,1205.57 542.224,1205.58 542.233,1205.59 542.242,1205.6 542.251,1205.61 542.26,1205.62 542.269,1205.63 542.279,1205.64 542.288,1205.65 542.297,1205.66 542.306,1205.67 542.315,1205.68 542.325,1205.69 542.334,1205.7 542.343,1205.71 542.352,1205.72 542.361,1205.73 542.371,1205.74 542.38,1205.75 542.389,1205.76 542.398,1205.77 542.407,1205.78 542.416,1205.79 542.426,1205.8 542.435,1205.81 542.444,1205.82 542.453,1205.83 542.462,1205.84 542.472,1205.85 542.481,1205.86 542.49,1205.87 542.499,1205.88 542.508,1205.89 542.518,1205.9 542.527,1205.91 542.536,1205.92 542.545,1205.94 542.554,1205.95 542.564,1205.96 542.573,1205.97 542.582,1205.98 542.591,1205.99 542.6,1206 542.609,1206.01 542.619,1206.02 542.628,1206.03 542.637,1206.04 542.646,1206.05 542.655,1206.06 542.665,1206.07 542.674,1206.08 542.683,1206.09 542.692,1206.1 542.701,1206.11 542.711,1206.12 542.72,1206.13 542.729,1206.14 542.738,1206.15 542.747,1206.16 542.756,1206.17 542.766,1206.18 542.775,1206.19 542.784,1206.2 542.793,1206.21 542.802,1206.22 542.812,1206.23 542.821,1206.24 542.83,1206.25 542.839,1206.26 542.848,1206.27 542.858,1206.28 542.867,1206.29 542.876,1206.3 542.885,1206.31 542.894,1206.32 542.904,1206.33 542.913,1206.34 542.922,1206.36 542.931,1206.37 542.94,1206.38 542.949,1206.39 542.959,1206.4 542.968,1206.41 542.977,1206.42 542.986,1206.43 542.995,1206.44 543.005,1206.45 543.014,1206.46 543.023,1206.47 543.032,1206.48 543.041,1206.49 543.051,1206.5 543.06,1206.51 543.069,1206.52 543.078,1206.53 543.087,1206.54 543.096,1206.55 543.106,1206.56 543.115,1206.57 543.124,1206.58 543.133,1206.59 543.142,1206.6 543.152,1206.61 543.161,1206.62 543.17,1206.63 543.179,1206.64 543.188,1206.65 543.198,1206.66 543.207,1206.67 543.216,1206.68 543.225,1206.69 543.234,1206.7 543.244,1206.71 543.253,1206.72 543.262,1206.73 543.271,1206.74 543.28,1206.75 543.289,1206.76 543.299,1206.77 543.308,1206.78 543.317,1206.79 543.326,1206.8 543.335,1206.81 543.345,1206.82 543.354,1206.84 543.363,1206.85 543.372,1206.86 543.381,1206.87 543.391,1206.88 543.4,1206.89 543.409,1206.9 543.418,1206.91 543.427,1206.92 543.436,1206.93 543.446,1206.94 543.455,1206.95 543.464,1206.96 543.473,1206.97 543.482,1206.98 543.492,1206.99 543.501,1207 543.51,1207.01 543.519,1207.02 543.528,1207.03 543.538,1207.04 543.547,1207.05 543.556,1207.06 543.565,1207.07 543.574,1207.08 543.584,1207.09 543.593,1207.1 543.602,1207.11 543.611,1207.12 543.62,1207.13 543.629,1207.14 543.639,1207.15 543.648,1207.16 543.657,1207.17 543.666,1207.18 543.675,1207.19 543.685,1207.2 543.694,1207.21 543.703,1207.22 543.712,1207.23 543.721,1207.24 543.731,1207.25 543.74,1207.26 543.749,1207.27 543.758,1207.28 543.767,1207.29 543.777,1207.3 543.786,1207.31 543.795,1207.32 543.804,1207.33 543.813,1207.34 543.822,1207.35 543.832,1207.36 543.841,1207.37 543.85,1207.38 543.859,1207.39 543.868,1207.4 543.878,1207.42 543.887,1207.43 543.896,1207.44 543.905,1207.45 543.914,1207.46 543.924,1207.47 543.933,1207.48 543.942,1207.49 543.951,1207.5 543.96,1207.51 543.969,1207.52 543.979,1207.53 543.988,1207.54 543.997,1207.55 544.006,1207.56 544.015,1207.57 544.025,1207.58 544.034,1207.59 544.043,1207.6 544.052,1207.61 544.061,1207.62 544.071,1207.63 544.08,1207.64 544.089,1207.65 544.098,1207.66 544.107,1207.67 544.117,1207.68 544.126,1207.69 544.135,1207.7 544.144,1207.71 544.153,1207.72 544.162,1207.73 544.172,1207.74 544.181,1207.75 544.19,1207.76 544.199,1207.77 544.208,1207.78 544.218,1207.79 544.227,1207.8 544.236,1207.81 544.245,1207.82 544.254,1207.83 544.264,1207.84 544.273,1207.85 544.282,1207.86 544.291,1207.87 544.3,1207.88 544.309,1207.89 544.319,1207.9 544.328,1207.91 544.337,1207.92 544.346,1207.93 544.355,1207.94 544.365,1207.95 544.374,1207.96 544.383,1207.97 544.392,1207.98 544.401,1207.99 544.411,1208 544.42,1208.01 544.429,1208.02 544.438,1208.03 544.447,1208.04 544.457,1208.05 544.466,1208.06 544.475,1208.07 544.484,1208.08 544.493,1208.09 544.502,1208.1 544.512,1208.11 544.521,1208.12 544.53,1208.13 544.539,1208.14 544.548,1208.15 544.558,1208.16 544.567,1208.17 544.576,1208.18 544.585,1208.19 544.594,1208.2 544.604,1208.21 544.613,1208.22 544.622,1208.24 544.631,1208.25 544.64,1208.26 544.649,1208.27 544.659,1208.28 544.668,1208.29 544.677,1208.3 544.686,1208.31 544.695,1208.32 544.705,1208.33 544.714,1208.34 544.723,1208.35 544.732,1208.36 544.741,1208.37 544.751,1208.38 544.76,1208.39 544.769,1208.4 544.778,1208.41 544.787,1208.42 544.797,1208.43 544.806,1208.44 544.815,1208.45 544.824,1208.46 544.833,1208.47 544.842,1208.48 544.852,1208.49 544.861,1208.5 544.87,1208.51 544.879,1208.52 544.888,1208.53 544.898,1208.54 544.907,1208.55 544.916,1208.56 544.925,1208.57 544.934,1208.58 544.944,1208.59 544.953,1208.6 544.962,1208.61 544.971,1208.62 544.98,1208.63 544.989,1208.64 544.999,1208.65 545.008,1208.66 545.017,1208.67 545.026,1208.68 545.035,1208.69 545.045,1208.7 545.054,1208.71 545.063,1208.72 545.072,1208.73 545.081,1208.74 545.091,1208.75 545.1,1208.76 545.109,1208.77 545.118,1208.78 545.127,1208.79 545.137,1208.8 545.146,1208.81 545.155,1208.82 545.164,1208.83 545.173,1208.84 545.182,1208.85 545.192,1208.86 545.201,1208.87 545.21,1208.88 545.219,1208.89 545.228,1208.9 545.238,1208.91 545.247,1208.92 545.256,1208.93 545.265,1208.94 545.274,1208.95 545.284,1208.96 545.293,1208.97 545.302,1208.98 545.311,1208.99 545.32,1209 545.329,1209.01 545.339,1209.02 545.348,1209.03 545.357,1209.04 545.366,1209.05 545.375,1209.06 545.385,1209.07 545.394,1209.08 545.403,1209.09 545.412,1209.1 545.421,1209.11 545.431,1209.12 545.44,1209.13 545.449,1209.14 545.458,1209.15 545.467,1209.16 545.477,1209.17 545.486,1209.18 545.495,1209.19 545.504,1209.2 545.513,1209.21 545.522,1209.22 545.532,1209.23 545.541,1209.24 545.55,1209.25 545.559,1209.26 545.568,1209.27 545.578,1209.28 545.587,1209.29 545.596,1209.3 545.605,1209.31 545.614,1209.32 545.624,1209.33 545.633,1209.34 545.642,1209.35 545.651,1209.36 545.66,1209.37 545.669,1209.38 545.679,1209.39 545.688,1209.4 545.697,1209.41 545.706,1209.42 545.715,1209.43 545.725,1209.44 545.734,1209.45 545.743,1209.46 545.752,1209.47 545.761,1209.48 545.771,1209.49 545.78,1209.5 545.789,1209.51 545.798,1209.52 545.807,1209.53 545.817,1209.54 545.826,1209.55 545.835,1209.56 545.844,1209.57 545.853,1209.58 545.862,1209.59 545.872,1209.6 545.881,1209.61 545.89,1209.62 545.899,1209.63 545.908,1209.64 545.918,1209.65 545.927,1209.66 545.936,1209.67 545.945,1209.68 545.954,1209.69 545.964,1209.7 545.973,1209.71 545.982,1209.72 545.991,1209.73 546,1209.74 546.01,1209.75 546.019,1209.76 546.028,1209.77 546.037,1209.78 546.046,1209.79 546.055,1209.8 546.065,1209.81 546.074,1209.82 546.083,1209.83 546.092,1209.84 546.101,1209.85 546.111,1209.86 546.12,1209.87 546.129,1209.88 546.138,1209.89 546.147,1209.9 546.157,1209.91 546.166,1209.92 546.175,1209.93 546.184,1209.94 546.193,1209.95 546.202,1209.96 546.212,1209.97 546.221,1209.98 546.23,1209.99 546.239,1210 546.248,1210.01 546.258,1210.02 546.267,1210.03 546.276,1210.04 546.285,1210.05 546.294,1210.06 546.304,1210.07 546.313,1210.08 546.322,1210.09 546.331,1210.1 546.34,1210.11 546.35,1210.12 546.359,1210.13 546.368,1210.14 546.377,1210.15 546.386,1210.16 546.395,1210.17 546.405,1210.18 546.414,1210.19 546.423,1210.2 546.432,1210.21 546.441,1210.22 546.451,1210.23 546.46,1210.24 546.469,1210.25 546.478,1210.26 546.487,1210.27 546.497,1210.28 546.506,1210.29 546.515,1210.3 546.524,1210.31 546.533,1210.32 546.542,1210.33 546.552,1210.34 546.561,1210.35 546.57,1210.36 546.579,1210.37 546.588,1210.38 546.598,1210.39 546.607,1210.4 546.616,1210.41 546.625,1210.42 546.634,1210.43 546.644,1210.44 546.653,1210.45 546.662,1210.46 546.671,1210.47 546.68,1210.48 546.69,1210.49 546.699,1210.5 546.708,1210.51 546.717,1210.52 546.726,1210.53 546.735,1210.54 546.745,1210.55 546.754,1210.56 546.763,1210.57 546.772,1210.58 546.781,1210.59 546.791,1210.6 546.8,1210.61 546.809,1210.62 546.818,1210.63 546.827,1210.64 546.837,1210.65 546.846,1210.66 546.855,1210.67 546.864,1210.68 546.873,1210.69 546.882,1210.7 546.892,1210.71 546.901,1210.72 546.91,1210.73 546.919,1210.74 546.928,1210.75 546.938,1210.76 546.947,1210.77 546.956,1210.78 546.965,1210.79 546.974,1210.8 546.984,1210.81 546.993,1210.82 547.002,1210.83 547.011,1210.84 547.02,1210.85 547.03,1210.86 547.039,1210.87 547.048,1210.88 547.057,1210.89 547.066,1210.9 547.075,1210.91 547.085,1210.92 547.094,1210.93 547.103,1210.93 547.112,1210.94 547.121,1210.95 547.131,1210.96 547.14,1210.97 547.149,1210.98 547.158,1210.99 547.167,1211 547.177,1211.01 547.186,1211.02 547.195,1211.03 547.204,1211.04 547.213,1211.05 547.222,1211.06 547.232,1211.07 547.241,1211.08 547.25,1211.09 547.259,1211.1 547.268,1211.11 547.278,1211.12 547.287,1211.13 547.296,1211.14 547.305,1211.15 547.314,1211.16 547.324,1211.17 547.333,1211.18 547.342,1211.19 547.351,1211.2 547.36,1211.21 547.37,1211.22 547.379,1211.23 547.388,1211.24 547.397,1211.25 547.406,1211.26 547.415,1211.27 547.425,1211.28 547.434,1211.29 547.443,1211.3 547.452,1211.31 547.461,1211.32 547.471,1211.33 547.48,1211.34 547.489,1211.35 547.498,1211.36 547.507,1211.37 547.517,1211.38 547.526,1211.39 547.535,1211.4 547.544,1211.41 547.553,1211.42 547.562,1211.43 547.572,1211.44 547.581,1211.45 547.59,1211.46 547.599,1211.47 547.608,1211.48 547.618,1211.49 547.627,1211.5 547.636,1211.51 547.645,1211.52 547.654,1211.53 547.664,1211.54 547.673,1211.55 547.682,1211.56 547.691,1211.57 547.7,1211.58 547.71,1211.59 547.719,1211.6 547.728,1211.61 547.737,1211.62 547.746,1211.63 547.755,1211.64 547.765,1211.65 547.774,1211.66 547.783,1211.67 547.792,1211.68 547.801,1211.69 547.811,1211.7 547.82,1211.71 547.829,1211.72 547.838,1211.73 547.847,1211.74 547.857,1211.75 547.866,1211.75 547.875,1211.76 547.884,1211.77 547.893,1211.78 547.902,1211.79 547.912,1211.8 547.921,1211.81 547.93,1211.82 547.939,1211.83 547.948,1211.84 547.958,1211.85 547.967,1211.86 547.976,1211.87 547.985,1211.88 547.994,1211.89 548.004,1211.9 548.013,1211.91 548.022,1211.92 548.031,1211.93 548.04,1211.94 548.05,1211.95 548.059,1211.96 548.068,1211.97 548.077,1211.98 548.086,1211.99 548.095,1212 548.105,1212.01 548.114,1212.02 548.123,1212.03 548.132,1212.04 548.141,1212.05 548.151,1212.06 548.16,1212.07 548.169,1212.08 548.178,1212.09 548.187,1212.1 548.197,1212.11 548.206,1212.12 548.215,1212.13 548.224,1212.14 548.233,1212.15 548.242,1212.16 548.252,1212.17 548.261,1212.18 548.27,1212.19 548.279,1212.2 548.288,1212.21 548.298,1212.22 548.307,1212.23 548.316,1212.24 548.325,1212.25 548.334,1212.26 548.344,1212.27 548.353,1212.28 548.362,1212.29 548.371,1212.3 548.38,1212.31 548.39,1212.32 548.399,1212.33 548.408,1212.33 548.417,1212.34 548.426,1212.35 548.435,1212.36 548.445,1212.37 548.454,1212.38 548.463,1212.39 548.472,1212.4 548.481,1212.41 548.491,1212.42 548.5,1212.43 548.509,1212.44 548.518,1212.45 548.527,1212.46 548.537,1212.47 548.546,1212.48 548.555,1212.49 548.564,1212.5 548.573,1212.51 548.583,1212.52 548.592,1212.53 548.601,1212.54 548.61,1212.55 548.619,1212.56 548.628,1212.57 548.638,1212.58 548.647,1212.59 548.656,1212.6 548.665,1212.61 548.674,1212.62 548.684,1212.63 548.693,1212.64 548.702,1212.65 548.711,1212.66 548.72,1212.67 548.73,1212.68 548.739,1212.69 548.748,1212.7 548.757,1212.71 548.766,1212.72 548.775,1212.73 548.785,1212.74 548.794,1212.75 548.803,1212.76 548.812,1212.77 548.821,1212.78 548.831,1212.79 548.84,1212.8 548.849,1212.81 548.858,1212.81 548.867,1212.82 548.877,1212.83 548.886,1212.84 548.895,1212.85 548.904,1212.86 548.913,1212.87 548.923,1212.88 548.932,1212.89 548.941,1212.9 548.95,1212.91 548.959,1212.92 548.968,1212.93 548.978,1212.94 548.987,1212.95 548.996,1212.96 549.005,1212.97 549.014,1212.98 549.024,1212.99 549.033,1213 549.042,1213.01 549.051,1213.02 549.06,1213.03 549.07,1213.04 549.079,1213.05 549.088,1213.06 549.097,1213.07 549.106,1213.08 549.115,1213.09 549.125,1213.1 549.134,1213.11 549.143,1213.12 549.152,1213.13 549.161,1213.14 549.171,1213.15 549.18,1213.16 549.189,1213.17 549.198,1213.18 549.207,1213.19 549.217,1213.2 549.226,1213.21 549.235,1213.22 549.244,1213.23 549.253,1213.23 549.263,1213.24 549.272,1213.25 549.281,1213.26 549.29,1213.27 549.299,1213.28 549.308,1213.29 549.318,1213.3 549.327,1213.31 549.336,1213.32 549.345,1213.33 549.354,1213.34 549.364,1213.35 549.373,1213.36 549.382,1213.37 549.391,1213.38 549.4,1213.39 549.41,1213.4 549.419,1213.41 549.428,1213.42 549.437,1213.43 549.446,1213.44 549.455,1213.45 549.465,1213.46 549.474,1213.47 549.483,1213.48 549.492,1213.49 549.501,1213.5 549.511,1213.51 549.52,1213.52 549.529,1213.53 549.538,1213.54 549.547,1213.55 549.557,1213.56 549.566,1213.57 549.575,1213.58 549.584,1213.59 549.593,1213.6 549.603,1213.61 549.612,1213.61 549.621,1213.62 549.63,1213.63 549.639,1213.64 549.648,1213.65 549.658,1213.66 549.667,1213.67 549.676,1213.68 549.685,1213.69 549.694,1213.7 549.704,1213.71 549.713,1213.72 549.722,1213.73 549.731,1213.74 549.74,1213.75 549.75,1213.76 549.759,1213.77 549.768,1213.78 549.777,1213.79 549.786,1213.8 549.795,1213.81 549.805,1213.82 549.814,1213.83 549.823,1213.84 549.832,1213.85 549.841,1213.86 549.851,1213.87 549.86,1213.88 549.869,1213.89 549.878,1213.9 549.887,1213.91 549.897,1213.92 549.906,1213.93 549.915,1213.94 549.924,1213.95 549.933,1213.95 549.943,1213.96 549.952,1213.97 549.961,1213.98 549.97,1213.99 549.979,1214 549.988,1214.01 549.998,1214.02 550.007,1214.03 550.016,1214.04 550.025,1214.05 550.034,1214.06 550.044,1214.07 550.053,1214.08 550.062,1214.09 550.071,1214.1 550.08,1214.11 550.09,1214.12 550.099,1214.13 550.108,1214.14 550.117,1214.15 550.126,1214.16 550.135,1214.17 550.145,1214.18 550.154,1214.19 550.163,1214.2 550.172,1214.21 550.181,1214.22 550.191,1214.23 550.2,1214.24 550.209,1214.25 550.218,1214.26 550.227,1214.27 550.237,1214.27 550.246,1214.28 550.255,1214.29 550.264,1214.3 550.273,1214.31 550.283,1214.32 550.292,1214.33 550.301,1214.34 550.31,1214.35 550.319,1214.36 550.328,1214.37 550.338,1214.38 550.347,1214.39 550.356,1214.4 550.365,1214.41 550.374,1214.42 550.384,1214.43 550.393,1214.44 550.402,1214.45 550.411,1214.46 550.42,1214.47 550.43,1214.48 550.439,1214.49 550.448,1214.5 550.457,1214.51 550.466,1214.52 550.475,1214.53 550.485,1214.54 550.494,1214.55 550.503,1214.56 550.512,1214.57 550.521,1214.57 550.531,1214.58 550.54,1214.59 550.549,1214.6 550.558,1214.61 550.567,1214.62 550.577,1214.63 550.586,1214.64 550.595,1214.65 550.604,1214.66 550.613,1214.67 550.623,1214.68 550.632,1214.69 550.641,1214.7 550.65,1214.71 550.659,1214.72 550.668,1214.73 550.678,1214.74 550.687,1214.75 550.696,1214.76 550.705,1214.77 550.714,1214.78 550.724,1214.79 550.733,1214.8 550.742,1214.81 550.751,1214.82 550.76,1214.83 550.77,1214.84 550.779,1214.85 550.788,1214.85 550.797,1214.86 550.806,1214.87 550.815,1214.88 550.825,1214.89 550.834,1214.9 550.843,1214.91 550.852,1214.92 550.861,1214.93 550.871,1214.94 550.88,1214.95 550.889,1214.96 550.898,1214.97 550.907,1214.98 550.917,1214.99 550.926,1215 550.935,1215.01 550.944,1215.02 550.953,1215.03 550.963,1215.04 550.972,1215.05 550.981,1215.06 550.99,1215.07 550.999,1215.08 551.008,1215.09 551.018,1215.1 551.027,1215.11 551.036,1215.12 551.045,1215.12 551.054,1215.13 551.064,1215.14 551.073,1215.15 551.082,1215.16 551.091,1215.17 551.1,1215.18 551.11,1215.19 551.119,1215.2 551.128,1215.21 551.137,1215.22 551.146,1215.23 551.156,1215.24 551.165,1215.25 551.174,1215.26 551.183,1215.27 551.192,1215.28 551.201,1215.29 551.211,1215.3 551.22,1215.31 551.229,1215.32 551.238,1215.33 551.247,1215.34 551.257,1215.35 551.266,1215.36 551.275,1215.37 551.284,1215.37 551.293,1215.38 551.303,1215.39 551.312,1215.4 551.321,1215.41 551.33,1215.42 551.339,1215.43 551.348,1215.44 551.358,1215.45 551.367,1215.46 551.376,1215.47 551.385,1215.48 551.394,1215.49 551.404,1215.5 551.413,1215.51 551.422,1215.52 551.431,1215.53 551.44,1215.54 551.45,1215.55 551.459,1215.56 551.468,1215.57 551.477,1215.58 551.486,1215.59 551.496,1215.6 551.505,1215.61 551.514,1215.62 551.523,1215.62 551.532,1215.63 551.541,1215.64 551.551,1215.65 551.56,1215.66 551.569,1215.67 551.578,1215.68 551.587,1215.69 551.597,1215.7 551.606,1215.71 551.615,1215.72 551.624,1215.73 551.633,1215.74 551.643,1215.75 551.652,1215.76 551.661,1215.77 551.67,1215.78 551.679,1215.79 551.688,1215.8 551.698,1215.81 551.707,1215.82 551.716,1215.83 551.725,1215.84 551.734,1215.85 551.744,1215.85 551.753,1215.86 551.762,1215.87 551.771,1215.88 551.78,1215.89 551.79,1215.9 551.799,1215.91 551.808,1215.92 551.817,1215.93 551.826,1215.94 551.836,1215.95 551.845,1215.96 551.854,1215.97 551.863,1215.98 551.872,1215.99 551.881,1216 551.891,1216.01 551.9,1216.02 551.909,1216.03 551.918,1216.04 551.927,1216.05 551.937,1216.06 551.946,1216.07 551.955,1216.08 551.964,1216.08 551.973,1216.09 551.983,1216.1 551.992,1216.11 552.001,1216.12 552.01,1216.13 552.019,1216.14 552.028,1216.15 552.038,1216.16 552.047,1216.17 552.056,1216.18 552.065,1216.19 552.074,1216.2 552.084,1216.21 552.093,1216.22 552.102,1216.23 552.111,1216.24 552.12,1216.25 552.13,1216.26 552.139,1216.27 552.148,1216.28 552.157,1216.29 552.166,1216.3 552.176,1216.3 552.185,1216.31 552.194,1216.32 552.203,1216.33 552.212,1216.34 552.221,1216.35 552.231,1216.36 552.24,1216.37 552.249,1216.38 552.258,1216.39 552.267,1216.4 552.277,1216.41 552.286,1216.42 552.295,1216.43 552.304,1216.44 552.313,1216.45 552.323,1216.46 552.332,1216.47 552.341,1216.48 552.35,1216.49 552.359,1216.5 552.368,1216.51 552.378,1216.52 552.387,1216.52 552.396,1216.53 552.405,1216.54 552.414,1216.55 552.424,1216.56 552.433,1216.57 552.442,1216.58 552.451,1216.59 552.46,1216.6 552.47,1216.61 552.479,1216.62 552.488,1216.63 552.497,1216.64 552.506,1216.65 552.516,1216.66 552.525,1216.67 552.534,1216.68 552.543,1216.69 552.552,1216.7 552.561,1216.71 552.571,1216.72 552.58,1216.72 552.589,1216.73 552.598,1216.74 552.607,1216.75 552.617,1216.76 552.626,1216.77 552.635,1216.78 552.644,1216.79 552.653,1216.8 552.663,1216.81 552.672,1216.82 552.681,1216.83 552.69,1216.84 552.699,1216.85 552.708,1216.86 552.718,1216.87 552.727,1216.88 552.736,1216.89 552.745,1216.9 552.754,1216.91 552.764,1216.92 552.773,1216.92 552.782,1216.93 552.791,1216.94 552.8,1216.95 552.81,1216.96 552.819,1216.97 552.828,1216.98 552.837,1216.99 552.846,1217 552.856,1217.01 552.865,1217.02 552.874,1217.03 552.883,1217.04 552.892,1217.05 552.901,1217.06 552.911,1217.07 552.92,1217.08 552.929,1217.09 552.938,1217.1 552.947,1217.11 552.957,1217.12 552.966,1217.12 552.975,1217.13 552.984,1217.14 552.993,1217.15 553.003,1217.16 553.012,1217.17 553.021,1217.18 553.03,1217.19 553.039,1217.2 553.048,1217.21 553.058,1217.22 553.067,1217.23 553.076,1217.24 553.085,1217.25 553.094,1217.26 553.104,1217.27 553.113,1217.28 553.122,1217.29 553.131,1217.3 553.14,1217.31 553.15,1217.31 553.159,1217.32 553.168,1217.33 553.177,1217.34 553.186,1217.35 553.196,1217.36 553.205,1217.37 553.214,1217.38 553.223,1217.39 553.232,1217.4 553.241,1217.41 553.251,1217.42 553.26,1217.43 553.269,1217.44 553.278,1217.45 553.287,1217.46 553.297,1217.47 553.306,1217.48 553.315,1217.49 553.324,1217.5 553.333,1217.5 553.343,1217.51 553.352,1217.52 553.361,1217.53 553.37,1217.54 553.379,1217.55 553.389,1217.56 553.398,1217.57 553.407,1217.58 553.416,1217.59 553.425,1217.6 553.434,1217.61 553.444,1217.62 553.453,1217.63 553.462,1217.64 553.471,1217.65 553.48,1217.66 553.49,1217.67 553.499,1217.68 553.508,1217.68 553.517,1217.69 553.526,1217.7 553.536,1217.71 553.545,1217.72 553.554,1217.73 553.563,1217.74 553.572,1217.75 553.581,1217.76 553.591,1217.77 553.6,1217.78 553.609,1217.79 553.618,1217.8 553.627,1217.81 553.637,1217.82 553.646,1217.83 553.655,1217.84 553.664,1217.85 553.673,1217.86 553.683,1217.86 553.692,1217.87 553.701,1217.88 553.71,1217.89 553.719,1217.9 553.729,1217.91 553.738,1217.92 553.747,1217.93 553.756,1217.94 553.765,1217.95 553.774,1217.96 553.784,1217.97 553.793,1217.98 553.802,1217.99 553.811,1218 553.82,1218.01 553.83,1218.02 553.839,1218.03 553.848,1218.03 553.857,1218.04 553.866,1218.05 553.876,1218.06 553.885,1218.07 553.894,1218.08 553.903,1218.09 553.912,1218.1 553.921,1218.11 553.931,1218.12 553.94,1218.13 553.949,1218.14 553.958,1218.15 553.967,1218.16 553.977,1218.17 553.986,1218.18 553.995,1218.19 554.004,1218.2 554.013,1218.21 554.023,1218.21 554.032,1218.22 554.041,1218.23 554.05,1218.24 554.059,1218.25 554.069,1218.26 554.078,1218.27 554.087,1218.28 554.096,1218.29 554.105,1218.3 554.114,1218.31 554.124,1218.32 554.133,1218.33 554.142,1218.34 554.151,1218.35 554.16,1218.36 554.17,1218.37 554.179,1218.37 554.188,1218.38 554.197,1218.39 554.206,1218.4 554.216,1218.41 554.225,1218.42 554.234,1218.43 554.243,1218.44 554.252,1218.45 554.261,1218.46 554.271,1218.47 554.28,1218.48 554.289,1218.49 554.298,1218.5 554.307,1218.51 554.317,1218.52 554.326,1218.53 554.335,1218.54 554.344,1218.54 554.353,1218.55 554.363,1218.56 554.372,1218.57 554.381,1218.58 554.39,1218.59 554.399,1218.6 554.409,1218.61 554.418,1218.62 554.427,1218.63 554.436,1218.64 554.445,1218.65 554.454,1218.66 554.464,1218.67 554.473,1218.68 554.482,1218.69 554.491,1218.7 554.5,1218.7 554.51,1218.71 554.519,1218.72 554.528,1218.73 554.537,1218.74 554.546,1218.75 554.556,1218.76 554.565,1218.77 554.574,1218.78 554.583,1218.79 554.592,1218.8 554.601,1218.81 554.611,1218.82 554.62,1218.83 554.629,1218.84 554.638,1218.85 554.647,1218.86 554.657,1218.86 554.666,1218.87 554.675,1218.88 554.684,1218.89 554.693,1218.9 554.703,1218.91 554.712,1218.92 554.721,1218.93 554.73,1218.94 554.739,1218.95 554.749,1218.96 554.758,1218.97 554.767,1218.98 554.776,1218.99 554.785,1219 554.794,1219.01 554.804,1219.02 554.813,1219.02 554.822,1219.03 554.831,1219.04 554.84,1219.05 554.85,1219.06 554.859,1219.07 554.868,1219.08 554.877,1219.09 554.886,1219.1 554.896,1219.11 554.905,1219.12 554.914,1219.13 554.923,1219.14 554.932,1219.15 554.941,1219.16 554.951,1219.17 554.96,1219.17 554.969,1219.18 554.978,1219.19 554.987,1219.2 554.997,1219.21 555.006,1219.22 555.015,1219.23 555.024,1219.24 555.033,1219.25 555.043,1219.26 555.052,1219.27 555.061,1219.28 555.07,1219.29 555.079,1219.3 555.089,1219.31 555.098,1219.32 555.107,1219.33 555.116,1219.33 555.125,1219.34 555.134,1219.35 555.144,1219.36 555.153,1219.37 555.162,1219.38 555.171,1219.39 555.18,1219.4 555.19,1219.41 555.199,1219.42 555.208,1219.43 555.217,1219.44 555.226,1219.45 555.236,1219.46 555.245,1219.47 555.254,1219.48 555.263,1219.48 555.272,1219.49 555.281,1219.5 555.291,1219.51 555.3,1219.52 555.309,1219.53 555.318,1219.54 555.327,1219.55 555.337,1219.56 555.346,1219.57 555.355,1219.58 555.364,1219.59 555.373,1219.6 555.383,1219.61 555.392,1219.62 555.401,1219.63 555.41,1219.63 555.419,1219.64 555.429,1219.65 555.438,1219.66 555.447,1219.67 555.456,1219.68 555.465,1219.69 555.474,1219.7 555.484,1219.71 555.493,1219.72 555.502,1219.73 555.511,1219.74 555.52,1219.75 555.53,1219.76 555.539,1219.77 555.548,1219.77 555.557,1219.78 555.566,1219.79 555.576,1219.8 555.585,1219.81 555.594,1219.82 555.603,1219.83 555.612,1219.84 555.621,1219.85 555.631,1219.86 555.64,1219.87 555.649,1219.88 555.658,1219.89 555.667,1219.9 555.677,1219.91 555.686,1219.92 555.695,1219.92 555.704,1219.93 555.713,1219.94 555.723,1219.95 555.732,1219.96 555.741,1219.97 555.75,1219.98 555.759,1219.99 555.769,1220 555.778,1220.01 555.787,1220.02 555.796,1220.03 555.805,1220.04 555.814,1220.05 555.824,1220.06 555.833,1220.06 555.842,1220.07 555.851,1220.08 555.86,1220.09 555.87,1220.1 555.879,1220.11 555.888,1220.12 555.897,1220.13 555.906,1220.14 555.916,1220.15 555.925,1220.16 555.934,1220.17 555.943,1220.18 555.952,1220.19 555.962,1220.2 555.971,1220.2 555.98,1220.21 555.989,1220.22 555.998,1220.23 556.007,1220.24 556.017,1220.25 556.026,1220.26 556.035,1220.27 556.044,1220.28 556.053,1220.29 556.063,1220.3 556.072,1220.31 556.081,1220.32 556.09,1220.33 556.099,1220.34 556.109,1220.34 556.118,1220.35 556.127,1220.36 556.136,1220.37 556.145,1220.38 556.154,1220.39 556.164,1220.4 556.173,1220.41 556.182,1220.42 556.191,1220.43 556.2,1220.44 556.21,1220.45 556.219,1220.46 556.228,1220.47 556.237,1220.48 556.246,1220.48 556.256,1220.49 556.265,1220.5 556.274,1220.51 556.283,1220.52 556.292,1220.53 556.302,1220.54 556.311,1220.55 556.32,1220.56 556.329,1220.57 556.338,1220.58 556.347,1220.59 556.357,1220.6 556.366,1220.61 556.375,1220.61 556.384,1220.62 556.393,1220.63 556.403,1220.64 556.412,1220.65 556.421,1220.66 556.43,1220.67 556.439,1220.68 556.449,1220.69 556.458,1220.7 556.467,1220.71 556.476,1220.72 556.485,1220.73 556.494,1220.74 556.504,1220.75 556.513,1220.75 556.522,1220.76 556.531,1220.77 556.54,1220.78 556.55,1220.79 556.559,1220.8 556.568,1220.81 556.577,1220.82 556.586,1220.83 556.596,1220.84 556.605,1220.85 556.614,1220.86 556.623,1220.87 556.632,1220.88 556.642,1220.88 556.651,1220.89 556.66,1220.9 556.669,1220.91 556.678,1220.92 556.687,1220.93 556.697,1220.94 556.706,1220.95 556.715,1220.96 556.724,1220.97 556.733,1220.98 556.743,1220.99 556.752,1221 556.761,1221.01 556.77,1221.01 556.779,1221.02 556.789,1221.03 556.798,1221.04 556.807,1221.05 556.816,1221.06 556.825,1221.07 556.834,1221.08 556.844,1221.09 556.853,1221.1 556.862,1221.11 556.871,1221.12 556.88,1221.13 556.89,1221.14 556.899,1221.14 556.908,1221.15 556.917,1221.16 556.926,1221.17 556.936,1221.18 556.945,1221.19 556.954,1221.2 556.963,1221.21 556.972,1221.22 556.982,1221.23 556.991,1221.24 557,1221.25 557.009,1221.26 557.018,1221.27 557.027,1221.27 557.037,1221.28 557.046,1221.29 557.055,1221.3 557.064,1221.31 557.073,1221.32 557.083,1221.33 557.092,1221.34 557.101,1221.35 557.11,1221.36 557.119,1221.37 557.129,1221.38 557.138,1221.39 557.147,1221.4 557.156,1221.4 557.165,1221.41 557.174,1221.42 557.184,1221.43 557.193,1221.44 557.202,1221.45 557.211,1221.46 557.22,1221.47 557.23,1221.48 557.239,1221.49 557.248,1221.5 557.257,1221.51 557.266,1221.52 557.276,1221.52 557.285,1221.53 557.294,1221.54 557.303,1221.55 557.312,1221.56 557.322,1221.57 557.331,1221.58 557.34,1221.59 557.349,1221.6 557.358,1221.61 557.367,1221.62 557.377,1221.63 557.386,1221.64 557.395,1221.65 557.404,1221.65 557.413,1221.66 557.423,1221.67 557.432,1221.68 557.441,1221.69 557.45,1221.7 557.459,1221.71 557.469,1221.72 557.478,1221.73 557.487,1221.74 557.496,1221.75 557.505,1221.76 557.514,1221.77 557.524,1221.77 557.533,1221.78 557.542,1221.79 557.551,1221.8 557.56,1221.81 557.57,1221.82 557.579,1221.83 557.588,1221.84 557.597,1221.85 557.606,1221.86 557.616,1221.87 557.625,1221.88 557.634,1221.89 557.643,1221.89 557.652,1221.9 557.662,1221.91 557.671,1221.92 557.68,1221.93 557.689,1221.94 557.698,1221.95 557.707,1221.96 557.717,1221.97 557.726,1221.98 557.735,1221.99 557.744,1222 557.753,1222.01 557.763,1222.01 557.772,1222.02 557.781,1222.03 557.79,1222.04 557.799,1222.05 557.809,1222.06 557.818,1222.07 557.827,1222.08 557.836,1222.09 557.845,1222.1 557.854,1222.11 557.864,1222.12 557.873,1222.13 557.882,1222.13 557.891,1222.14 557.9,1222.15 557.91,1222.16 557.919,1222.17 557.928,1222.18 557.937,1222.19 557.946,1222.2 557.956,1222.21 557.965,1222.22 557.974,1222.23 557.983,1222.24 557.992,1222.25 558.002,1222.25 558.011,1222.26 558.02,1222.27 558.029,1222.28 558.038,1222.29 558.047,1222.3 558.057,1222.31 558.066,1222.32 558.075,1222.33 558.084,1222.34 558.093,1222.35 558.103,1222.36 558.112,1222.37 558.121,1222.37 558.13,1222.38 558.139,1222.39 558.149,1222.4 558.158,1222.41 558.167,1222.42 558.176,1222.43 558.185,1222.44 558.194,1222.45 558.204,1222.46 558.213,1222.47 558.222,1222.48 558.231,1222.49 558.24,1222.49 558.25,1222.5 558.259,1222.51 558.268,1222.52 558.277,1222.53 558.286,1222.54 558.296,1222.55 558.305,1222.56 558.314,1222.57 558.323,1222.58 558.332,1222.59 558.342,1222.6 558.351,1222.61 558.36,1222.61 558.369,1222.62 558.378,1222.63 558.387,1222.64 558.397,1222.65 558.406,1222.66 558.415,1222.67 558.424,1222.68 558.433,1222.69 558.443,1222.7 558.452,1222.71 558.461,1222.72 558.47,1222.72 558.479,1222.73 558.489,1222.74 558.498,1222.75 558.507,1222.76 558.516,1222.77 558.525,1222.78 558.535,1222.79 558.544,1222.8 558.553,1222.81 558.562,1222.82 558.571,1222.83 558.58,1222.84 558.59,1222.84 558.599,1222.85 558.608,1222.86 558.617,1222.87 558.626,1222.88 558.636,1222.89 558.645,1222.9 558.654,1222.91 558.663,1222.92 558.672,1222.93 558.682,1222.94 558.691,1222.95 558.7,1222.95 558.709,1222.96 558.718,1222.97 558.727,1222.98 558.737,1222.99 558.746,1223 558.755,1223.01 558.764,1223.02 558.773,1223.03 558.783,1223.04 558.792,1223.05 558.801,1223.06 558.81,1223.06 558.819,1223.07 558.829,1223.08 558.838,1223.09 558.847,1223.1 558.856,1223.11 558.865,1223.12 558.875,1223.13 558.884,1223.14 558.893,1223.15 558.902,1223.16 558.911,1223.17 558.92,1223.18 558.93,1223.18 558.939,1223.19 558.948,1223.2 558.957,1223.21 558.966,1223.22 558.976,1223.23 558.985,1223.24 558.994,1223.25 559.003,1223.26 559.012,1223.27 559.022,1223.28 559.031,1223.29 559.04,1223.29 559.049,1223.3 559.058,1223.31 559.067,1223.32 559.077,1223.33 559.086,1223.34 559.095,1223.35 559.104,1223.36 559.113,1223.37 559.123,1223.38 559.132,1223.39 559.141,1223.4 559.15,1223.4 559.159,1223.41 559.169,1223.42 559.178,1223.43 559.187,1223.44 559.196,1223.45 559.205,1223.46 559.215,1223.47 559.224,1223.48 559.233,1223.49 559.242,1223.5 559.251,1223.51 559.26,1223.51 559.27,1223.52 559.279,1223.53 559.288,1223.54 559.297,1223.55 559.306,1223.56 559.316,1223.57 559.325,1223.58 559.334,1223.59 559.343,1223.6 559.352,1223.61 559.362,1223.62 559.371,1223.62 559.38,1223.63 559.389,1223.64 559.398,1223.65 559.407,1223.66 559.417,1223.67 559.426,1223.68 559.435,1223.69 559.444,1223.7 559.453,1223.71 559.463,1223.72 559.472,1223.73 559.481,1223.73 559.49,1223.74 559.499,1223.75 559.509,1223.76 559.518,1223.77 559.527,1223.78 559.536,1223.79 559.545,1223.8 559.555,1223.81 559.564,1223.82 559.573,1223.83 559.582,1223.83 559.591,1223.84 559.6,1223.85 559.61,1223.86 559.619,1223.87 559.628,1223.88 559.637,1223.89 559.646,1223.9 559.656,1223.91 559.665,1223.92 559.674,1223.93 559.683,1223.94 559.692,1223.94 559.702,1223.95 559.711,1223.96 559.72,1223.97 559.729,1223.98 559.738,1223.99 559.747,1224 559.757,1224.01 559.766,1224.02 559.775,1224.03 559.784,1224.04 559.793,1224.05 559.803,1224.05 559.812,1224.06 559.821,1224.07 559.83,1224.08 559.839,1224.09 559.849,1224.1 559.858,1224.11 559.867,1224.12 559.876,1224.13 559.885,1224.14 559.895,1224.15 559.904,1224.15 559.913,1224.16 559.922,1224.17 559.931,1224.18 559.94,1224.19 559.95,1224.2 559.959,1224.21 559.968,1224.22 559.977,1224.23 559.986,1224.24 559.996,1224.25 560.005,1224.26 560.014,1224.26 560.023,1224.27 560.032,1224.28 560.042,1224.29 560.051,1224.3 560.06,1224.31 560.069,1224.32 560.078,1224.33 560.087,1224.34 560.097,1224.35 560.106,1224.36 560.115,1224.36 560.124,1224.37 560.133,1224.38 560.143,1224.39 560.152,1224.4 560.161,1224.41 560.17,1224.42 560.179,1224.43 560.189,1224.44 560.198,1224.45 560.207,1224.46 560.216,1224.47 560.225,1224.47 560.235,1224.48 560.244,1224.49 560.253,1224.5 560.262,1224.51 560.271,1224.52 560.28,1224.53 560.29,1224.54 560.299,1224.55 560.308,1224.56 560.317,1224.57 560.326,1224.57 560.336,1224.58 560.345,1224.59 560.354,1224.6 560.363,1224.61 560.372,1224.62 560.382,1224.63 560.391,1224.64 560.4,1224.65 560.409,1224.66 560.418,1224.67 560.427,1224.67 560.437,1224.68 560.446,1224.69 560.455,1224.7 560.464,1224.71 560.473,1224.72 560.483,1224.73 560.492,1224.74 560.501,1224.75 560.51,1224.76 560.519,1224.77 560.529,1224.77 560.538,1224.78 560.547,1224.79 560.556,1224.8 560.565,1224.81 560.575,1224.82 560.584,1224.83 560.593,1224.84 560.602,1224.85 560.611,1224.86 560.62,1224.87 560.63,1224.87 560.639,1224.88 560.648,1224.89 560.657,1224.9 560.666,1224.91 560.676,1224.92 560.685,1224.93 560.694,1224.94 560.703,1224.95 560.712,1224.96 560.722,1224.97 560.731,1224.98 560.74,1224.98 560.749,1224.99 560.758,1225 560.768,1225.01 560.777,1225.02 560.786,1225.03 560.795,1225.04 560.804,1225.05 560.813,1225.06 560.823,1225.07 560.832,1225.08 560.841,1225.08 560.85,1225.09 560.859,1225.1 560.869,1225.11 560.878,1225.12 560.887,1225.13 560.896,1225.14 560.905,1225.15 560.915,1225.16 560.924,1225.17 560.933,1225.18 560.942,1225.18 560.951,1225.19 560.96,1225.2 560.97,1225.21 560.979,1225.22 560.988,1225.23 560.997,1225.24 561.006,1225.25 561.016,1225.26 561.025,1225.27 561.034,1225.28 561.043,1225.28 561.052,1225.29 561.062,1225.3 561.071,1225.31 561.08,1225.32 561.089,1225.33 561.098,1225.34 561.108,1225.35 561.117,1225.36 561.126,1225.37 561.135,1225.37 561.144,1225.38 561.153,1225.39 561.163,1225.4 561.172,1225.41 561.181,1225.42 561.19,1225.43 561.199,1225.44 561.209,1225.45 561.218,1225.46 561.227,1225.47 561.236,1225.47 561.245,1225.48 561.255,1225.49 561.264,1225.5 561.273,1225.51 561.282,1225.52 561.291,1225.53 561.3,1225.54 561.31,1225.55 561.319,1225.56 561.328,1225.57 561.337,1225.57 561.346,1225.58 561.356,1225.59 561.365,1225.6 561.374,1225.61 561.383,1225.62 561.392,1225.63 561.402,1225.64 561.411,1225.65 561.42,1225.66 561.429,1225.67 561.438,1225.67 561.448,1225.68 561.457,1225.69 561.466,1225.7 561.475,1225.71 561.484,1225.72 561.493,1225.73 561.503,1225.74 561.512,1225.75 561.521,1225.76 561.53,1225.76 561.539,1225.77 561.549,1225.78 561.558,1225.79 561.567,1225.8 561.576,1225.81 561.585,1225.82 561.595,1225.83 561.604,1225.84 561.613,1225.85 561.622,1225.86 561.631,1225.86 561.64,1225.87 561.65,1225.88 561.659,1225.89 561.668,1225.9 561.677,1225.91 561.686,1225.92 561.696,1225.93 561.705,1225.94 561.714,1225.95 561.723,1225.96 561.732,1225.96 561.742,1225.97 561.751,1225.98 561.76,1225.99 561.769,1226 561.778,1226.01 561.788,1226.02 561.797,1226.03 561.806,1226.04 561.815,1226.05 561.824,1226.05 561.833,1226.06 561.843,1226.07 561.852,1226.08 561.861,1226.09 561.87,1226.1 561.879,1226.11 561.889,1226.12 561.898,1226.13 561.907,1226.14 561.916,1226.15 561.925,1226.15 561.935,1226.16 561.944,1226.17 561.953,1226.18 561.962,1226.19 561.971,1226.2 561.98,1226.21 561.99,1226.22 561.999,1226.23 562.008,1226.24 562.017,1226.24 562.026,1226.25 562.036,1226.26 562.045,1226.27 562.054,1226.28 562.063,1226.29 562.072,1226.3 562.082,1226.31 562.091,1226.32 562.1,1226.33 562.109,1226.34 562.118,1226.34 562.128,1226.35 562.137,1226.36 562.146,1226.37 562.155,1226.38 562.164,1226.39 562.173,1226.4 562.183,1226.41 562.192,1226.42 562.201,1226.43 562.21,1226.43 562.219,1226.44 562.229,1226.45 562.238,1226.46 562.247,1226.47 562.256,1226.48 562.265,1226.49 562.275,1226.5 562.284,1226.51 562.293,1226.52 562.302,1226.52 562.311,1226.53 562.32,1226.54 562.33,1226.55 562.339,1226.56 562.348,1226.57 562.357,1226.58 562.366,1226.59 562.376,1226.6 562.385,1226.61 562.394,1226.62 562.403,1226.62 562.412,1226.63 562.422,1226.64 562.431,1226.65 562.44,1226.66 562.449,1226.67 562.458,1226.68 562.468,1226.69 562.477,1226.7 562.486,1226.71 562.495,1226.71 562.504,1226.72 562.513,1226.73 562.523,1226.74 562.532,1226.75 562.541,1226.76 562.55,1226.77 562.559,1226.78 562.569,1226.79 562.578,1226.8 562.587,1226.8 562.596,1226.81 562.605,1226.82 562.615,1226.83 562.624,1226.84 562.633,1226.85 562.642,1226.86 562.651,1226.87 562.66,1226.88 562.67,1226.89 562.679,1226.89 562.688,1226.9 562.697,1226.91 562.706,1226.92 562.716,1226.93 562.725,1226.94 562.734,1226.95 562.743,1226.96 562.752,1226.97 562.762,1226.98 562.771,1226.98 562.78,1226.99 562.789,1227 562.798,1227.01 562.808,1227.02 562.817,1227.03 562.826,1227.04 562.835,1227.05 562.844,1227.06 562.853,1227.07 562.863,1227.08 562.872,1227.08 562.881,1227.09 562.89,1227.1 562.899,1227.11 562.909,1227.12 562.918,1227.13 562.927,1227.14 562.936,1227.15 562.945,1227.16 562.955,1227.17 562.964,1227.17 562.973,1227.18 562.982,1227.19 562.991,1227.2 563,1227.21 563.01,1227.22 563.019,1227.23 563.028,1227.24 563.037,1227.25 563.046,1227.26 563.056,1227.26 563.065,1227.27 563.074,1227.28 563.083,1227.29 563.092,1227.3 563.102,1227.31 563.111,1227.32 563.12,1227.33 563.129,1227.34 563.138,1227.35 563.148,1227.35 563.157,1227.36 563.166,1227.37 563.175,1227.38 563.184,1227.39 563.193,1227.4 563.203,1227.41 563.212,1227.42 563.221,1227.43 563.23,1227.44 563.239,1227.44 563.249,1227.45 563.258,1227.46 563.267,1227.47 563.276,1227.48 563.285,1227.49 563.295,1227.5 563.304,1227.51 563.313,1227.52 563.322,1227.53 563.331,1227.53 563.341,1227.54 563.35,1227.55 563.359,1227.56 563.368,1227.57 563.377,1227.58 563.386,1227.59 563.396,1227.6 563.405,1227.61 563.414,1227.61 563.423,1227.62 563.432,1227.63 563.442,1227.64 563.451,1227.65 563.46,1227.66 563.469,1227.67 563.478,1227.68 563.488,1227.69 563.497,1227.7 563.506,1227.7 563.515,1227.71 563.524,1227.72 563.533,1227.73 563.543,1227.74 563.552,1227.75 563.561,1227.76 563.57,1227.77 563.579,1227.78 563.589,1227.79 563.598,1227.79 563.607,1227.8 563.616,1227.81 563.625,1227.82 563.635,1227.83 563.644,1227.84 563.653,1227.85 563.662,1227.86 563.671,1227.87 563.681,1227.88 563.69,1227.88 563.699,1227.89 563.708,1227.9 563.717,1227.91 563.726,1227.92 563.736,1227.93 563.745,1227.94 563.754,1227.95 563.763,1227.96 563.772,1227.97 563.782,1227.97 563.791,1227.98 563.8,1227.99 563.809,1228 563.818,1228.01 563.828,1228.02 563.837,1228.03 563.846,1228.04 563.855,1228.05 563.864,1228.06 563.873,1228.06 563.883,1228.07 563.892,1228.08 563.901,1228.09 563.91,1228.1 563.919,1228.11 563.929,1228.12 563.938,1228.13 563.947,1228.14 563.956,1228.14 563.965,1228.15 563.975,1228.16 563.984,1228.17 563.993,1228.18 564.002,1228.19 564.011,1228.2 564.021,1228.21 564.03,1228.22 564.039,1228.23 564.048,1228.23 564.057,1228.24 564.066,1228.25 564.076,1228.26 564.085,1228.27 564.094,1228.28 564.103,1228.29 564.112,1228.3 564.122,1228.31 564.131,1228.32 564.14,1228.32 564.149,1228.33 564.158,1228.34 564.168,1228.35 564.177,1228.36 564.186,1228.37 564.195,1228.38 564.204,1228.39 564.213,1228.4 564.223,1228.4 564.232,1228.41 564.241,1228.42 564.25,1228.43 564.259,1228.44 564.269,1228.45 564.278,1228.46 564.287,1228.47 564.296,1228.48 564.305,1228.49 564.315,1228.49 564.324,1228.5 564.333,1228.51 564.342,1228.52 564.351,1228.53 564.361,1228.54 564.37,1228.55 564.379,1228.56 564.388,1228.57 564.397,1228.57 564.406,1228.58 564.416,1228.59 564.425,1228.6 564.434,1228.61 564.443,1228.62 564.452,1228.63 564.462,1228.64 564.471,1228.65 564.48,1228.66 564.489,1228.66 564.498,1228.67 564.508,1228.68 564.517,1228.69 564.526,1228.7 564.535,1228.71 564.544,1228.72 564.553,1228.73 564.563,1228.74 564.572,1228.74 564.581,1228.75 564.59,1228.76 564.599,1228.77 564.609,1228.78 564.618,1228.79 564.627,1228.8 564.636,1228.81 564.645,1228.82 564.655,1228.83 564.664,1228.83 564.673,1228.84 564.682,1228.85 564.691,1228.86 564.701,1228.87 564.71,1228.88 564.719,1228.89 564.728,1228.9 564.737,1228.91 564.746,1228.91 564.756,1228.92 564.765,1228.93 564.774,1228.94 564.783,1228.95 564.792,1228.96 564.802,1228.97 564.811,1228.98 564.82,1228.99 564.829,1229 564.838,1229 564.848,1229.01 564.857,1229.02 564.866,1229.03 564.875,1229.04 564.884,1229.05 564.893,1229.06 564.903,1229.07 564.912,1229.08 564.921,1229.08 564.93,1229.09 564.939,1229.1 564.949,1229.11 564.958,1229.12 564.967,1229.13 564.976,1229.14 564.985,1229.15 564.995,1229.16 565.004,1229.17 565.013,1229.17 565.022,1229.18 565.031,1229.19 565.041,1229.2 565.05,1229.21 565.059,1229.22 565.068,1229.23 565.077,1229.24 565.086,1229.25 565.096,1229.25 565.105,1229.26 565.114,1229.27 565.123,1229.28 565.132,1229.29 565.142,1229.3 565.151,1229.31 565.16,1229.32 565.169,1229.33 565.178,1229.33 565.188,1229.34 565.197,1229.35 565.206,1229.36 565.215,1229.37 565.224,1229.38 565.233,1229.39 565.243,1229.4 565.252,1229.41 565.261,1229.42 565.27,1229.42 565.279,1229.43 565.289,1229.44 565.298,1229.45 565.307,1229.46 565.316,1229.47 565.325,1229.48 565.335,1229.49 565.344,1229.5 565.353,1229.5 565.362,1229.51 565.371,1229.52 565.381,1229.53 565.39,1229.54 565.399,1229.55 565.408,1229.56 565.417,1229.57 565.426,1229.58 565.436,1229.58 565.445,1229.59 565.454,1229.6 565.463,1229.61 565.472,1229.62 565.482,1229.63 565.491,1229.64 565.5,1229.65 565.509,1229.66 565.518,1229.67 565.528,1229.67 565.537,1229.68 565.546,1229.69 565.555,1229.7 565.564,1229.71 565.573,1229.72 565.583,1229.73 565.592,1229.74 565.601,1229.75 565.61,1229.75 565.619,1229.76 565.629,1229.77 565.638,1229.78 565.647,1229.79 565.656,1229.8 565.665,1229.81 565.675,1229.82 565.684,1229.83 565.693,1229.83 565.702,1229.84 565.711,1229.85 565.721,1229.86 565.73,1229.87 565.739,1229.88 565.748,1229.89 565.757,1229.9 565.766,1229.91 565.776,1229.91 565.785,1229.92 565.794,1229.93 565.803,1229.94 565.812,1229.95 565.822,1229.96 565.831,1229.97 565.84,1229.98 565.849,1229.99 565.858,1230 565.868,1230 565.877,1230.01 565.886,1230.02 565.895,1230.03 565.904,1230.04 565.914,1230.05 565.923,1230.06 565.932,1230.07 565.941,1230.08 565.95,1230.08 565.959,1230.09 565.969,1230.1 565.978,1230.11 565.987,1230.12 565.996,1230.13 566.005,1230.14 566.015,1230.15 566.024,1230.16 566.033,1230.16 566.042,1230.17 566.051,1230.18 566.061,1230.19 566.07,1230.2 566.079,1230.21 566.088,1230.22 566.097,1230.23 566.106,1230.24 566.116,1230.24 566.125,1230.25 566.134,1230.26 566.143,1230.27 566.152,1230.28 566.162,1230.29 566.171,1230.3 566.18,1230.31 566.189,1230.32 566.198,1230.32 566.208,1230.33 566.217,1230.34 566.226,1230.35 566.235,1230.36 566.244,1230.37 566.254,1230.38 566.263,1230.39 566.272,1230.4 566.281,1230.4 566.29,1230.41 566.299,1230.42 566.309,1230.43 566.318,1230.44 566.327,1230.45 566.336,1230.46 566.345,1230.47 566.355,1230.48 566.364,1230.48 566.373,1230.49 566.382,1230.5 566.391,1230.51 566.401,1230.52 566.41,1230.53 566.419,1230.54 566.428,1230.55 566.437,1230.56 566.446,1230.56 566.456,1230.57 566.465,1230.58 566.474,1230.59 566.483,1230.6 566.492,1230.61 566.502,1230.62 566.511,1230.63 566.52,1230.64 566.529,1230.64 566.538,1230.65 566.548,1230.66 566.557,1230.67 566.566,1230.68 566.575,1230.69 566.584,1230.7 566.594,1230.71 566.603,1230.72 566.612,1230.72 566.621,1230.73 566.63,1230.74 566.639,1230.75 566.649,1230.76 566.658,1230.77 566.667,1230.78 566.676,1230.79 566.685,1230.8 566.695,1230.8 566.704,1230.81 566.713,1230.82 566.722,1230.83 566.731,1230.84 566.741,1230.85 566.75,1230.86 566.759,1230.87 566.768,1230.88 566.777,1230.88 566.786,1230.89 566.796,1230.9 566.805,1230.91 566.814,1230.92 566.823,1230.93 566.832,1230.94 566.842,1230.95 566.851,1230.96 566.86,1230.96 566.869,1230.97 566.878,1230.98 566.888,1230.99 566.897,1231 566.906,1231.01 566.915,1231.02 566.924,1231.03 566.934,1231.04 566.943,1231.04 566.952,1231.05 566.961,1231.06 566.97,1231.07 566.979,1231.08 566.989,1231.09 566.998,1231.1 567.007,1231.11 567.016,1231.12 567.025,1231.12 567.035,1231.13 567.044,1231.14 567.053,1231.15 567.062,1231.16 567.071,1231.17 567.081,1231.18 567.09,1231.19 567.099,1231.2 567.108,1231.2 567.117,1231.21 567.126,1231.22 567.136,1231.23 567.145,1231.24 567.154,1231.25 567.163,1231.26 567.172,1231.27 567.182,1231.28 567.191,1231.28 567.2,1231.29 567.209,1231.3 567.218,1231.31 567.228,1231.32 567.237,1231.33 567.246,1231.34 567.255,1231.35 567.264,1231.36 567.274,1231.36 567.283,1231.37 567.292,1231.38 567.301,1231.39 567.31,1231.4 567.319,1231.41 567.329,1231.42 567.338,1231.43 567.347,1231.44 567.356,1231.44 567.365,1231.45 567.375,1231.46 567.384,1231.47 567.393,1231.48 567.402,1231.49 567.411,1231.5 567.421,1231.51 567.43,1231.51 567.439,1231.52 567.448,1231.53 567.457,1231.54 567.466,1231.55 567.476,1231.56 567.485,1231.57 567.494,1231.58 567.503,1231.59 567.512,1231.59 567.522,1231.6 567.531,1231.61 567.54,1231.62 567.549,1231.63 567.558,1231.64 567.568,1231.65 567.577,1231.66 567.586,1231.67 567.595,1231.67 567.604,1231.68 567.614,1231.69 567.623,1231.7 567.632,1231.71 567.641,1231.72 567.65,1231.73 567.659,1231.74 567.669,1231.75 567.678,1231.75 567.687,1231.76 567.696,1231.77 567.705,1231.78 567.715,1231.79 567.724,1231.8 567.733,1231.81 567.742,1231.82 567.751,1231.83 567.761,1231.83 567.77,1231.84 567.779,1231.85 567.788,1231.86 567.797,1231.87 567.806,1231.88 567.816,1231.89 567.825,1231.9 567.834,1231.91 567.843,1231.91 567.852,1231.92 567.862,1231.93 567.871,1231.94 567.88,1231.95 567.889,1231.96 567.898,1231.97 567.908,1231.98 567.917,1231.98 567.926,1231.99 567.935,1232 567.944,1232.01 567.954,1232.02 567.963,1232.03 567.972,1232.04 567.981,1232.05 567.99,1232.06 567.999,1232.06 568.009,1232.07 568.018,1232.08 568.027,1232.09 568.036,1232.1 568.045,1232.11 568.055,1232.12 568.064,1232.13 568.073,1232.14 568.082,1232.14 568.091,1232.15 568.101,1232.16 568.11,1232.17 568.119,1232.18 568.128,1232.19 568.137,1232.2 568.147,1232.21 568.156,1232.21 568.165,1232.22 568.174,1232.23 568.183,1232.24 568.192,1232.25 568.202,1232.26 568.211,1232.27 568.22,1232.28 568.229,1232.29 568.238,1232.29 568.248,1232.3 568.257,1232.31 568.266,1232.32 568.275,1232.33 568.284,1232.34 568.294,1232.35 568.303,1232.36 568.312,1232.37 568.321,1232.37 568.33,1232.38 568.339,1232.39 568.349,1232.4 568.358,1232.41 568.367,1232.42 568.376,1232.43 568.385,1232.44 568.395,1232.45 568.404,1232.45 568.413,1232.46 568.422,1232.47 568.431,1232.48 568.441,1232.49 568.45,1232.5 568.459,1232.51 568.468,1232.52 568.477,1232.52 568.487,1232.53 568.496,1232.54 568.505,1232.55 568.514,1232.56 568.523,1232.57 568.532,1232.58 568.542,1232.59 568.551,1232.6 568.56,1232.6 568.569,1232.61 568.578,1232.62 568.588,1232.63 568.597,1232.64 568.606,1232.65 568.615,1232.66 568.624,1232.67 568.634,1232.68 568.643,1232.68 568.652,1232.69 568.661,1232.7 568.67,1232.71 568.679,1232.72 568.689,1232.73 568.698,1232.74 568.707,1232.75 568.716,1232.75 568.725,1232.76 568.735,1232.77 568.744,1232.78 568.753,1232.79 568.762,1232.8 568.771,1232.81 568.781,1232.82 568.79,1232.83 568.799,1232.83 568.808,1232.84 568.817,1232.85 568.827,1232.86 568.836,1232.87 568.845,1232.88 568.854,1232.89 568.863,1232.9 568.872,1232.9 568.882,1232.91 568.891,1232.92 568.9,1232.93 568.909,1232.94 568.918,1232.95 568.928,1232.96 568.937,1232.97 568.946,1232.98 568.955,1232.98 568.964,1232.99 568.974,1233 568.983,1233.01 568.992,1233.02 569.001,1233.03 569.01,1233.04 569.019,1233.05 569.029,1233.06 569.038,1233.06 569.047,1233.07 569.056,1233.08 569.065,1233.09 569.075,1233.1 569.084,1233.11 569.093,1233.12 569.102,1233.13 569.111,1233.13 569.121,1233.14 569.13,1233.15 569.139,1233.16 569.148,1233.17 569.157,1233.18 569.167,1233.19 569.176,1233.2 569.185,1233.21 569.194,1233.21 569.203,1233.22 569.212,1233.23 569.222,1233.24 569.231,1233.25 569.24,1233.26 569.249,1233.27 569.258,1233.28 569.268,1233.28 569.277,1233.29 569.286,1233.3 569.295,1233.31 569.304,1233.32 569.314,1233.33 569.323,1233.34 569.332,1233.35 569.341,1233.36 569.35,1233.36 569.359,1233.37 569.369,1233.38 569.378,1233.39 569.387,1233.4 569.396,1233.41 569.405,1233.42 569.415,1233.43 569.424,1233.43 569.433,1233.44 569.442,1233.45 569.451,1233.46 569.461,1233.47 569.47,1233.48 569.479,1233.49 569.488,1233.5 569.497,1233.51 569.507,1233.51 569.516,1233.52 569.525,1233.53 569.534,1233.54 569.543,1233.55 569.552,1233.56 569.562,1233.57 569.571,1233.58 569.58,1233.59 569.589,1233.59 569.598,1233.6 569.608,1233.61 569.617,1233.62 569.626,1233.63 569.635,1233.64 569.644,1233.65 569.654,1233.66 569.663,1233.66 569.672,1233.67 569.681,1233.68 569.69,1233.69 569.699,1233.7 569.709,1233.71 569.718,1233.72 569.727,1233.73 569.736,1233.74 569.745,1233.74 569.755,1233.75 569.764,1233.76 569.773,1233.77 569.782,1233.78 569.791,1233.79 569.801,1233.8 569.81,1233.81 569.819,1233.81 569.828,1233.82 569.837,1233.83 569.847,1233.84 569.856,1233.85 569.865,1233.86 569.874,1233.87 569.883,1233.88 569.892,1233.89 569.902,1233.89 569.911,1233.9 569.92,1233.91 569.929,1233.92 569.938,1233.93 569.948,1233.94 569.957,1233.95 569.966,1233.96 569.975,1233.96 569.984,1233.97 569.994,1233.98 570.003,1233.99 570.012,1234 570.021,1234.01 570.03,1234.02 570.039,1234.03 570.049,1234.03 570.058,1234.04 570.067,1234.05 570.076,1234.06 570.085,1234.07 570.095,1234.08 570.104,1234.09 570.113,1234.1 570.122,1234.11 570.131,1234.11 570.141,1234.12 570.15,1234.13 570.159,1234.14 570.168,1234.15 570.177,1234.16 570.187,1234.17 570.196,1234.18 570.205,1234.18 570.214,1234.19 570.223,1234.2 570.232,1234.21 570.242,1234.22 570.251,1234.23 570.26,1234.24 570.269,1234.25 570.278,1234.26 570.288,1234.26 570.297,1234.27 570.306,1234.28 570.315,1234.29 570.324,1234.3 570.334,1234.31 570.343,1234.32 570.352,1234.33 570.361,1234.33 570.37,1234.34 570.379,1234.35 570.389,1234.36 570.398,1234.37 570.407,1234.38 570.416,1234.39 570.425,1234.4 570.435,1234.41 570.444,1234.41 570.453,1234.42 570.462,1234.43 570.471,1234.44 570.481,1234.45 570.49,1234.46 570.499,1234.47 570.508,1234.48 570.517,1234.48 570.527,1234.49 570.536,1234.5 570.545,1234.51 570.554,1234.52 570.563,1234.53 570.572,1234.54 570.582,1234.55 570.591,1234.56 570.6,1234.56 570.609,1234.57 570.618,1234.58 570.628,1234.59 570.637,1234.6 570.646,1234.61 570.655,1234.62 570.664,1234.63 570.674,1234.63 570.683,1234.64 570.692,1234.65 570.701,1234.66 570.71,1234.67 570.72,1234.68 570.729,1234.69 570.738,1234.7 570.747,1234.7 570.756,1234.71 570.765,1234.72 570.775,1234.73 570.784,1234.74 570.793,1234.75 570.802,1234.76 570.811,1234.77 570.821,1234.78 570.83,1234.78 570.839,1234.79 570.848,1234.8 570.857,1234.81 570.867,1234.82 570.876,1234.83 570.885,1234.84 570.894,1234.85 570.903,1234.85 570.912,1234.86 570.922,1234.87 570.931,1234.88 570.94,1234.89 570.949,1234.9 570.958,1234.91 570.968,1234.92 570.977,1234.93 570.986,1234.93 570.995,1234.94 571.004,1234.95 571.014,1234.96 571.023,1234.97 571.032,1234.98 571.041,1234.99 571.05,1235 571.06,1235 571.069,1235.01 571.078,1235.02 571.087,1235.03 571.096,1235.04 571.105,1235.05 571.115,1235.06 571.124,1235.07 571.133,1235.07 571.142,1235.08 571.151,1235.09 571.161,1235.1 571.17,1235.11 571.179,1235.12 571.188,1235.13 571.197,1235.14 571.207,1235.15 571.216,1235.15 571.225,1235.16 571.234,1235.17 571.243,1235.18 571.252,1235.19 571.262,1235.2 571.271,1235.21 571.28,1235.22 571.289,1235.22 571.298,1235.23 571.308,1235.24 571.317,1235.25 571.326,1235.26 571.335,1235.27 571.344,1235.28 571.354,1235.29 571.363,1235.29 571.372,1235.3 571.381,1235.31 571.39,1235.32 571.4,1235.33 571.409,1235.34 571.418,1235.35 571.427,1235.36 571.436,1235.37 571.445,1235.37 571.455,1235.38 571.464,1235.39 571.473,1235.4 571.482,1235.41 571.491,1235.42 571.501,1235.43 571.51,1235.44 571.519,1235.44 571.528,1235.45 571.537,1235.46 571.547,1235.47 571.556,1235.48 571.565,1235.49 571.574,1235.5 571.583,1235.51 571.592,1235.52 571.602,1235.52 571.611,1235.53 571.62,1235.54 571.629,1235.55 571.638,1235.56 571.648,1235.57 571.657,1235.58 571.666,1235.59 571.675,1235.59 571.684,1235.6 571.694,1235.61 571.703,1235.62 571.712,1235.63 571.721,1235.64 571.73,1235.65 571.74,1235.66 571.749,1235.66 571.758,1235.67 571.767,1235.68 571.776,1235.69 571.785,1235.7 571.795,1235.71 571.804,1235.72 571.813,1235.73 571.822,1235.74 571.831,1235.74 571.841,1235.75 571.85,1235.76 571.859,1235.77 571.868,1235.78 571.877,1235.79 571.887,1235.8 571.896,1235.81 571.905,1235.81 571.914,1235.82 571.923,1235.83 571.932,1235.84 571.942,1235.85 571.951,1235.86 571.96,1235.87 571.969,1235.88 571.978,1235.88 571.988,1235.89 571.997,1235.9 572.006,1235.91 572.015,1235.92 572.024,1235.93 572.034,1235.94 572.043,1235.95 572.052,1235.96 572.061,1235.96 572.07,1235.97 572.08,1235.98 572.089,1235.99 572.098,1236 572.107,1236.01 572.116,1236.02 572.125,1236.03 572.135,1236.03 572.144,1236.04 572.153,1236.05 572.162,1236.06 572.171,1236.07 572.181,1236.08 572.19,1236.09 572.199,1236.1 572.208,1236.1 572.217,1236.11 572.227,1236.12 572.236,1236.13 572.245,1236.14 572.254,1236.15 572.263,1236.16 572.272,1236.17 572.282,1236.18 572.291,1236.18 572.3,1236.19 572.309,1236.2 572.318,1236.21 572.328,1236.22 572.337,1236.23 572.346,1236.24 572.355,1236.25 572.364,1236.25 572.374,1236.26 572.383,1236.27 572.392,1236.28 572.401,1236.29 572.41,1236.3 572.42,1236.31 572.429,1236.32 572.438,1236.32 572.447,1236.33 572.456,1236.34 572.465,1236.35 572.475,1236.36 572.484,1236.37 572.493,1236.38 572.502,1236.39 572.511,1236.4 572.521,1236.4 572.53,1236.41 572.539,1236.42 572.548,1236.43 572.557,1236.44 572.567,1236.45 572.576,1236.46 572.585,1236.47 572.594,1236.47 572.603,1236.48 572.612,1236.49 572.622,1236.5 572.631,1236.51 572.64,1236.52 572.649,1236.53 572.658,1236.54 572.668,1236.54 572.677,1236.55 572.686,1236.56 572.695,1236.57 572.704,1236.58 572.714,1236.59 572.723,1236.6 572.732,1236.61 572.741,1236.61 572.75,1236.62 572.76,1236.63 572.769,1236.64 572.778,1236.65 572.787,1236.66 572.796,1236.67 572.805,1236.68 572.815,1236.69 572.824,1236.69 572.833,1236.7 572.842,1236.71 572.851,1236.72 572.861,1236.73 572.87,1236.74 572.879,1236.75 572.888,1236.76 572.897,1236.76 572.907,1236.77 572.916,1236.78 572.925,1236.79 572.934,1236.8 572.943,1236.81 572.952,1236.82 572.962,1236.83 572.971,1236.83 572.98,1236.84 572.989,1236.85 572.998,1236.86 573.008,1236.87 573.017,1236.88 573.026,1236.89 573.035,1236.9 573.044,1236.91 573.054,1236.91 573.063,1236.92 573.072,1236.93 573.081,1236.94 573.09,1236.95 573.1,1236.96 573.109,1236.97 573.118,1236.98 573.127,1236.98 573.136,1236.99 573.145,1237 573.155,1237.01 573.164,1237.02 573.173,1237.03 573.182,1237.04 573.191,1237.05 573.201,1237.05 573.21,1237.06 573.219,1237.07 573.228,1237.08 573.237,1237.09 573.247,1237.1 573.256,1237.11 573.265,1237.12 573.274,1237.13 573.283,1237.13 573.293,1237.14 573.302,1237.15 573.311,1237.16 573.32,1237.17 573.329,1237.18 573.338,1237.19 573.348,1237.2 573.357,1237.2 573.366,1237.21 573.375,1237.22 573.384,1237.23 573.394,1237.24 573.403,1237.25 573.412,1237.26 573.421,1237.27 573.43,1237.27 573.44,1237.28 573.449,1237.29 573.458,1237.3 573.467,1237.31 573.476,1237.32 573.485,1237.33 573.495,1237.34 573.504,1237.34 573.513,1237.35 573.522,1237.36 573.531,1237.37 573.541,1237.38 573.55,1237.39 573.559,1237.4 573.568,1237.41 573.577,1237.42 573.587,1237.42 573.596,1237.43 573.605,1237.44 573.614,1237.45 573.623,1237.46 573.633,1237.47 573.642,1237.48 573.651,1237.49 573.66,1237.49 573.669,1237.5 573.678,1237.51 573.688,1237.52 573.697,1237.53 573.706,1237.54 573.715,1237.55 573.724,1237.56 573.734,1237.56 573.743,1237.57 573.752,1237.58 573.761,1237.59 573.77,1237.6 573.78,1237.61 573.789,1237.62 573.798,1237.63 573.807,1237.64 573.816,1237.64 573.825,1237.65 573.835,1237.66 573.844,1237.67 573.853,1237.68 573.862,1237.69 573.871,1237.7 573.881,1237.71 573.89,1237.71 573.899,1237.72 573.908,1237.73 573.917,1237.74 573.927,1237.75 573.936,1237.76 573.945,1237.77 573.954,1237.78 573.963,1237.78 573.973,1237.79 573.982,1237.8 573.991,1237.81 574,1237.82 574.009,1237.83 574.018,1237.84 574.028,1237.85 574.037,1237.86 574.046,1237.86 574.055,1237.87 574.064,1237.88 574.074,1237.89 574.083,1237.9 574.092,1237.91 574.101,1237.92 574.11,1237.93 574.12,1237.93 574.129,1237.94 574.138,1237.95 574.147,1237.96 574.156,1237.97 574.165,1237.98 574.175,1237.99 574.184,1238 574.193,1238 574.202,1238.01 574.211,1238.02 574.221,1238.03 574.23,1238.04 574.239,1238.05 574.248,1238.06 574.257,1238.07 574.267,1238.07 574.276,1238.08 574.285,1238.09 574.294,1238.1 574.303,1238.11 574.313,1238.12 574.322,1238.13 574.331,1238.14 574.34,1238.15 574.349,1238.15 574.358,1238.16 574.368,1238.17 574.377,1238.18 574.386,1238.19 574.395,1238.2 574.404,1238.21 574.414,1238.22 574.423,1238.22 574.432,1238.23 574.441,1238.24 574.45,1238.25 574.46,1238.26 574.469,1238.27 574.478,1238.28 574.487,1238.29 574.496,1238.29 574.505,1238.3 574.515,1238.31 574.524,1238.32 574.533,1238.33 574.542,1238.34 574.551,1238.35 574.561,1238.36 574.57,1238.37 574.579,1238.37 574.588,1238.38 574.597,1238.39 574.607,1238.4 574.616,1238.41 574.625,1238.42 574.634,1238.43 574.643,1238.44 574.653,1238.44 574.662,1238.45 574.671,1238.46 574.68,1238.47 574.689,1238.48 574.698,1238.49 574.708,1238.5 574.717,1238.51 574.726,1238.51 574.735,1238.52 574.744,1238.53 574.754,1238.54 574.763,1238.55 574.772,1238.56 574.781,1238.57 574.79,1238.58 574.8,1238.59 574.809,1238.59 574.818,1238.6 574.827,1238.61 574.836,1238.62 574.845,1238.63 574.855,1238.64 574.864,1238.65 574.873,1238.66 574.882,1238.66 574.891,1238.67 574.901,1238.68 574.91,1238.69 574.919,1238.7 574.928,1238.71 574.937,1238.72 574.947,1238.73 574.956,1238.73 574.965,1238.74 574.974,1238.75 574.983,1238.76 574.993,1238.77 575.002,1238.78 575.011,1238.79 575.02,1238.8 575.029,1238.81 575.038,1238.81 575.048,1238.82 575.057,1238.83 575.066,1238.84 575.075,1238.85 575.084,1238.86 575.094,1238.87 575.103,1238.88 575.112,1238.88 575.121,1238.89 575.13,1238.9 575.14,1238.91 575.149,1238.92 575.158,1238.93 575.167,1238.94 575.176,1238.95 575.185,1238.95 575.195,1238.96 575.204,1238.97 575.213,1238.98 575.222,1238.99 575.231,1239 575.241,1239.01 575.25,1239.02 575.259,1239.03 575.268,1239.03 575.277,1239.04 575.287,1239.05 575.296,1239.06 575.305,1239.07 575.314,1239.08 575.323,1239.09 575.333,1239.1 575.342,1239.1 575.351,1239.11 575.36,1239.12 575.369,1239.13 575.378,1239.14 575.388,1239.15 575.397,1239.16 575.406,1239.17 575.415,1239.17 575.424,1239.18 575.434,1239.19 575.443,1239.2 575.452,1239.21 575.461,1239.22 575.47,1239.23 575.48,1239.24 575.489,1239.25 575.498,1239.25 575.507,1239.26 575.516,1239.27 575.526,1239.28 575.535,1239.29 575.544,1239.3 575.553,1239.31 575.562,1239.32 575.571,1239.32 575.581,1239.33 575.59,1239.34 575.599,1239.35 575.608,1239.36 575.617,1239.37 575.627,1239.38 575.636,1239.39 575.645,1239.39 575.654,1239.4 575.663,1239.41 575.673,1239.42 575.682,1239.43 575.691,1239.44 575.7,1239.45 575.709,1239.46 575.718,1239.47 575.728,1239.47 575.737,1239.48 575.746,1239.49 575.755,1239.5 575.764,1239.51 575.774,1239.52 575.783,1239.53 575.792,1239.54 575.801,1239.54 575.81,1239.55 575.82,1239.56 575.829,1239.57 575.838,1239.58 575.847,1239.59 575.856,1239.6 575.866,1239.61 575.875,1239.62 575.884,1239.62 575.893,1239.63 575.902,1239.64 575.911,1239.65 575.921,1239.66 575.93,1239.67 575.939,1239.68 575.948,1239.69 575.957,1239.69 575.967,1239.7 575.976,1239.71 575.985,1239.72 575.994,1239.73 576.003,1239.74 576.013,1239.75 576.022,1239.76 576.031,1239.76 576.04,1239.77 576.049,1239.78 576.058,1239.79 576.068,1239.8 576.077,1239.81 576.086,1239.82 576.095,1239.83 576.104,1239.84 576.114,1239.84 576.123,1239.85 576.132,1239.86 576.141,1239.87 576.15,1239.88 576.16,1239.89 576.169,1239.9 576.178,1239.91 576.187,1239.91 576.196,1239.92 576.206,1239.93 576.215,1239.94 576.224,1239.95 576.233,1239.96 576.242,1239.97 576.251,1239.98 576.261,1239.99 576.27,1239.99 576.279,1240 576.288,1240.01 576.297,1240.02 576.307,1240.03 576.316,1240.04 576.325,1240.05 576.334,1240.06 576.343,1240.06 576.353,1240.07 576.362,1240.08 576.371,1240.09 576.38,1240.1 576.389,1240.11 576.398,1240.12 576.408,1240.13 576.417,1240.13 576.426,1240.14 576.435,1240.15 576.444,1240.16 576.454,1240.17 576.463,1240.18 576.472,1240.19 576.481,1240.2 576.49,1240.21 576.5,1240.21 576.509,1240.22 576.518,1240.23 576.527,1240.24 576.536,1240.25 576.546,1240.26 576.555,1240.27 576.564,1240.28 576.573,1240.28 576.582,1240.29 576.591,1240.3 576.601,1240.31 576.61,1240.32 576.619,1240.33 576.628,1240.34 576.637,1240.35 576.647,1240.36 576.656,1240.36 576.665,1240.37 576.674,1240.38 576.683,1240.39 576.693,1240.4 576.702,1240.41 576.711,1240.42 576.72,1240.43 576.729,1240.43 576.738,1240.44 576.748,1240.45 576.757,1240.46 576.766,1240.47 576.775,1240.48 576.784,1240.49 576.794,1240.5 576.803,1240.51 576.812,1240.51 576.821,1240.52 576.83,1240.53 576.84,1240.54 576.849,1240.55 576.858,1240.56 576.867,1240.57 576.876,1240.58 576.886,1240.58 576.895,1240.59 576.904,1240.6 576.913,1240.61 576.922,1240.62 576.931,1240.63 576.941,1240.64 576.95,1240.65 576.959,1240.66 576.968,1240.66 576.977,1240.67 576.987,1240.68 576.996,1240.69 577.005,1240.7 577.014,1240.71 577.023,1240.72 577.033,1240.73 577.042,1240.73 577.051,1240.74 577.06,1240.75 577.069,1240.76 577.078,1240.77 577.088,1240.78 577.097,1240.79 577.106,1240.8 577.115,1240.81 577.124,1240.81 577.134,1240.82 577.143,1240.83 577.152,1240.84 577.161,1240.85 577.17,1240.86 577.18,1240.87 577.189,1240.88 577.198,1240.88 577.207,1240.89 577.216,1240.9 577.226,1240.91 577.235,1240.92 577.244,1240.93 577.253,1240.94 577.262,1240.95 577.271,1240.96 577.281,1240.96 577.29,1240.97 577.299,1240.98 577.308,1240.99 577.317,1241 577.327,1241.01 577.336,1241.02 577.345,1241.03 577.354,1241.03 577.363,1241.04 577.373,1241.05 577.382,1241.06 577.391,1241.07 577.4,1241.08 577.409,1241.09 577.418,1241.1 577.428,1241.11 577.437,1241.11 577.446,1241.12 577.455,1241.13 577.464,1241.14 577.474,1241.15 577.483,1241.16 577.492,1241.17 577.501,1241.18 577.51,1241.18 577.52,1241.19 577.529,1241.2 577.538,1241.21 577.547,1241.22 577.556,1241.23 577.566,1241.24 577.575,1241.25 577.584,1241.26 577.593,1241.26 577.602,1241.27 577.611,1241.28 577.621,1241.29 577.63,1241.3 577.639,1241.31 577.648,1241.32 577.657,1241.33 577.667,1241.33 577.676,1241.34 577.685,1241.35 577.694,1241.36 577.703,1241.37 577.713,1241.38 577.722,1241.39 577.731,1241.4 577.74,1241.41 577.749,1241.41 577.758,1241.42 577.768,1241.43 577.777,1241.44 577.786,1241.45 577.795,1241.46 577.804,1241.47 577.814,1241.48 577.823,1241.49 577.832,1241.49 577.841,1241.5 577.85,1241.51 577.86,1241.52 577.869,1241.53 577.878,1241.54 577.887,1241.55 577.896,1241.56 577.906,1241.56 577.915,1241.57 577.924,1241.58 577.933,1241.59 577.942,1241.6 577.951,1241.61 577.961,1241.62 577.97,1241.63 577.979,1241.64 577.988,1241.64 577.997,1241.65 578.007,1241.66 578.016,1241.67 578.025,1241.68 578.034,1241.69 578.043,1241.7 578.053,1241.71 578.062,1241.71 578.071,1241.72 578.08,1241.73 578.089,1241.74 578.099,1241.75 578.108,1241.76 578.117,1241.77 578.126,1241.78 578.135,1241.79 578.144,1241.79 578.154,1241.8 578.163,1241.81 578.172,1241.82 578.181,1241.83 578.19,1241.84 578.2,1241.85 578.209,1241.86 578.218,1241.87 578.227,1241.87 578.236,1241.88 578.246,1241.89 578.255,1241.9 578.264,1241.91 578.273,1241.92 578.282,1241.93 578.291,1241.94 578.301,1241.94 578.31,1241.95 578.319,1241.96 578.328,1241.97 578.337,1241.98 578.347,1241.99 578.356,1242 578.365,1242.01 578.374,1242.02 578.383,1242.02 578.393,1242.03 578.402,1242.04 578.411,1242.05 578.42,1242.06 578.429,1242.07 578.439,1242.08 578.448,1242.09 578.457,1242.1 578.466,1242.1 578.475,1242.11 578.484,1242.12 578.494,1242.13 578.503,1242.14 578.512,1242.15 578.521,1242.16 578.53,1242.17 578.54,1242.18 578.549,1242.18 578.558,1242.19 578.567,1242.2 578.576,1242.21 578.586,1242.22 578.595,1242.23 578.604,1242.24 578.613,1242.25 578.622,1242.25 578.631,1242.26 578.641,1242.27 578.65,1242.28 578.659,1242.29 578.668,1242.3 578.677,1242.31 578.687,1242.32 578.696,1242.33 578.705,1242.33 578.714,1242.34 578.723,1242.35 578.733,1242.36 578.742,1242.37 578.751,1242.38 578.76,1242.39 578.769,1242.4 578.779,1242.41 578.788,1242.41 578.797,1242.42 578.806,1242.43 578.815,1242.44 578.824,1242.45 578.834,1242.46 578.843,1242.47 578.852,1242.48 578.861,1242.49 578.87,1242.49 578.88,1242.5 578.889,1242.51 578.898,1242.52 578.907,1242.53 578.916,1242.54 578.926,1242.55 578.935,1242.56 578.944,1242.56 578.953,1242.57 578.962,1242.58 578.971,1242.59 578.981,1242.6 578.99,1242.61 578.999,1242.62 579.008,1242.63 579.017,1242.64 579.027,1242.64 579.036,1242.65 579.045,1242.66 579.054,1242.67 579.063,1242.68 579.073,1242.69 579.082,1242.7 579.091,1242.71 579.1,1242.72 579.109,1242.72 579.119,1242.73 579.128,1242.74 579.137,1242.75 579.146,1242.76 579.155,1242.77 579.164,1242.78 579.174,1242.79 579.183,1242.8 579.192,1242.8 579.201,1242.81 579.21,1242.82 579.22,1242.83 579.229,1242.84 579.238,1242.85 579.247,1242.86 579.256,1242.87 579.266,1242.88 579.275,1242.88 579.284,1242.89 579.293,1242.9 579.302,1242.91 579.311,1242.92 579.321,1242.93 579.33,1242.94 579.339,1242.95 579.348,1242.96 579.357,1242.96 579.367,1242.97 579.376,1242.98 579.385,1242.99 579.394,1243 579.403,1243.01 579.413,1243.02 579.422,1243.03 579.431,1243.04 579.44,1243.04 579.449,1243.05 579.459,1243.06 579.468,1243.07 579.477,1243.08 579.486,1243.09 579.495,1243.1 579.504,1243.11 579.514,1243.12 579.523,1243.12 579.532,1243.13 579.541,1243.14 579.55,1243.15 579.56,1243.16 579.569,1243.17 579.578,1243.18 579.587,1243.19 579.596,1243.19 579.606,1243.2 579.615,1243.21 579.624,1243.22 579.633,1243.23 579.642,1243.24 579.651,1243.25 579.661,1243.26 579.67,1243.27 579.679,1243.27 579.688,1243.28 579.697,1243.29 579.707,1243.3 579.716,1243.31 579.725,1243.32 579.734,1243.33 579.743,1243.34 579.753,1243.35 579.762,1243.35 579.771,1243.36 579.78,1243.37 579.789,1243.38 579.799,1243.39 579.808,1243.4 579.817,1243.41 579.826,1243.42 579.835,1243.43 579.844,1243.43 579.854,1243.44 579.863,1243.45 579.872,1243.46 579.881,1243.47 579.89,1243.48 579.9,1243.49 579.909,1243.5 579.918,1243.51 579.927,1243.51 579.936,1243.52 579.946,1243.53 579.955,1243.54 579.964,1243.55 579.973,1243.56 579.982,1243.57 579.991,1243.58 580.001,1243.59 580.01,1243.59 580.019,1243.6 580.028,1243.61 580.037,1243.62 580.047,1243.63 580.056,1243.64 580.065,1243.65 580.074,1243.66 580.083,1243.67 580.093,1243.68 580.102,1243.68 580.111,1243.69 580.12,1243.7 580.129,1243.71 580.139,1243.72 580.148,1243.73 580.157,1243.74 580.166,1243.75 580.175,1243.76 580.184,1243.76 580.194,1243.77 580.203,1243.78 580.212,1243.79 580.221,1243.8 580.23,1243.81 580.24,1243.82 580.249,1243.83 580.258,1243.84 580.267,1243.84 580.276,1243.85 580.286,1243.86 580.295,1243.87 580.304,1243.88 580.313,1243.89 580.322,1243.9 580.331,1243.91 580.341,1243.92 580.35,1243.92 580.359,1243.93 580.368,1243.94 580.377,1243.95 580.387,1243.96 580.396,1243.97 580.405,1243.98 580.414,1243.99 580.423,1244 580.433,1244 580.442,1244.01 580.451,1244.02 580.46,1244.03 580.469,1244.04 580.479,1244.05 580.488,1244.06 580.497,1244.07 580.506,1244.08 580.515,1244.08 580.524,1244.09 580.534,1244.1 580.543,1244.11 580.552,1244.12 580.561,1244.13 580.57,1244.14 580.58,1244.15 580.589,1244.16 580.598,1244.16 580.607,1244.17 580.616,1244.18 580.626,1244.19 580.635,1244.2 580.644,1244.21 580.653,1244.22 580.662,1244.23 580.672,1244.24 580.681,1244.25 580.69,1244.25 580.699,1244.26 580.708,1244.27 580.717,1244.28 580.727,1244.29 580.736,1244.3 580.745,1244.31 580.754,1244.32 580.763,1244.33 580.773,1244.33 580.782,1244.34 580.791,1244.35 580.8,1244.36 580.809,1244.37 580.819,1244.38 580.828,1244.39 580.837,1244.4 580.846,1244.41 580.855,1244.41 580.864,1244.42 580.874,1244.43 580.883,1244.44 580.892,1244.45 580.901,1244.46 580.91,1244.47 580.92,1244.48 580.929,1244.49 580.938,1244.5 580.947,1244.5 580.956,1244.51 580.966,1244.52 580.975,1244.53 580.984,1244.54 580.993,1244.55 581.002,1244.56 581.012,1244.57 581.021,1244.58 581.03,1244.58 581.039,1244.59 581.048,1244.6 581.057,1244.61 581.067,1244.62 581.076,1244.63 581.085,1244.64 581.094,1244.65 581.103,1244.66 581.113,1244.66 581.122,1244.67 581.131,1244.68 581.14,1244.69 581.149,1244.7 581.159,1244.71 581.168,1244.72 581.177,1244.73 581.186,1244.74 581.195,1244.75 581.204,1244.75 581.214,1244.76 581.223,1244.77 581.232,1244.78 581.241,1244.79 581.25,1244.8 581.26,1244.81 581.269,1244.82 581.278,1244.83 581.287,1244.83 581.296,1244.84 581.306,1244.85 581.315,1244.86 581.324,1244.87 581.333,1244.88 581.342,1244.89 581.352,1244.9 581.361,1244.91 581.37,1244.92 581.379,1244.92 581.388,1244.93 581.397,1244.94 581.407,1244.95 581.416,1244.96 581.425,1244.97 581.434,1244.98 581.443,1244.99 581.453,1245 581.462,1245 581.471,1245.01 581.48,1245.02 581.489,1245.03 581.499,1245.04 581.508,1245.05 581.517,1245.06 581.526,1245.07 581.535,1245.08 581.544,1245.09 581.554,1245.09 581.563,1245.1 581.572,1245.11 581.581,1245.12 581.59,1245.13 581.6,1245.14 581.609,1245.15 581.618,1245.16 581.627,1245.17 581.636,1245.17 581.646,1245.18 581.655,1245.19 581.664,1245.2 581.673,1245.21 581.682,1245.22 581.692,1245.23 581.701,1245.24 581.71,1245.25 581.719,1245.26 581.728,1245.26 581.737,1245.27 581.747,1245.28 581.756,1245.29 581.765,1245.3 581.774,1245.31 581.783,1245.32 581.793,1245.33 581.802,1245.34 581.811,1245.35 581.82,1245.35 581.829,1245.36 581.839,1245.37 581.848,1245.38 581.857,1245.39 581.866,1245.4 581.875,1245.41 581.884,1245.42 581.894,1245.43 581.903,1245.43 581.912,1245.44 581.921,1245.45 581.93,1245.46 581.94,1245.47 581.949,1245.48 581.958,1245.49 581.967,1245.5 581.976,1245.51 581.986,1245.52 581.995,1245.52 582.004,1245.53 582.013,1245.54 582.022,1245.55 582.032,1245.56 582.041,1245.57 582.05,1245.58 582.059,1245.59 582.068,1245.6 582.077,1245.61 582.087,1245.61 582.096,1245.62 582.105,1245.63 582.114,1245.64 582.123,1245.65 582.133,1245.66 582.142,1245.67 582.151,1245.68 582.16,1245.69 582.169,1245.7 582.179,1245.7 582.188,1245.71 582.197,1245.72 582.206,1245.73 582.215,1245.74 582.224,1245.75 582.234,1245.76 582.243,1245.77 582.252,1245.78 582.261,1245.78 582.27,1245.79 582.28,1245.8 582.289,1245.81 582.298,1245.82 582.307,1245.83 582.316,1245.84 582.326,1245.85 582.335,1245.86 582.344,1245.87 582.353,1245.87 582.362,1245.88 582.372,1245.89 582.381,1245.9 582.39,1245.91 582.399,1245.92 582.408,1245.93 582.417,1245.94 582.427,1245.95 582.436,1245.96 582.445,1245.96 582.454,1245.97 582.463,1245.98 582.473,1245.99 582.482,1246 582.491,1246.01 582.5,1246.02 582.509,1246.03 582.519,1246.04 582.528,1246.05 582.537,1246.05 582.546,1246.06 582.555,1246.07 582.564,1246.08 582.574,1246.09 582.583,1246.1 582.592,1246.11 582.601,1246.12 582.61,1246.13 582.62,1246.14 582.629,1246.14 582.638,1246.15 582.647,1246.16 582.656,1246.17 582.666,1246.18 582.675,1246.19 582.684,1246.2 582.693,1246.21 582.702,1246.22 582.712,1246.23 582.721,1246.23 582.73,1246.24 582.739,1246.25 582.748,1246.26 582.757,1246.27 582.767,1246.28 582.776,1246.29 582.785,1246.3 582.794,1246.31 582.803,1246.32 582.813,1246.32 582.822,1246.33 582.831,1246.34 582.84,1246.35 582.849,1246.36 582.859,1246.37 582.868,1246.38 582.877,1246.39 582.886,1246.4 582.895,1246.41 582.905,1246.41 582.914,1246.42 582.923,1246.43 582.932,1246.44 582.941,1246.45 582.95,1246.46 582.96,1246.47 582.969,1246.48 582.978,1246.49 582.987,1246.5 582.996,1246.51 583.006,1246.51 583.015,1246.52 583.024,1246.53 583.033,1246.54 583.042,1246.55 583.052,1246.56 583.061,1246.57 583.07,1246.58 583.079,1246.59 583.088,1246.6 583.097,1246.6 583.107,1246.61 583.116,1246.62 583.125,1246.63 583.134,1246.64 583.143,1246.65 583.153,1246.66 583.162,1246.67 583.171,1246.68 583.18,1246.69 583.189,1246.69 583.199,1246.7 583.208,1246.71 583.217,1246.72 583.226,1246.73 583.235,1246.74 583.245,1246.75 583.254,1246.76 583.263,1246.77 583.272,1246.78 583.281,1246.78 583.29,1246.79 583.3,1246.8 583.309,1246.81 583.318,1246.82 583.327,1246.83 583.336,1246.84 583.346,1246.85 583.355,1246.86 583.364,1246.87 583.373,1246.88 583.382,1246.88 583.392,1246.89 583.401,1246.9 583.41,1246.91 583.419,1246.92 583.428,1246.93 583.437,1246.94 583.447,1246.95 583.456,1246.96 583.465,1246.97 583.474,1246.97 583.483,1246.98 583.493,1246.99 583.502,1247 583.511,1247.01 583.52,1247.02 583.529,1247.03 583.539,1247.04 583.548,1247.05 583.557,1247.06 583.566,1247.07 583.575,1247.07 583.585,1247.08 583.594,1247.09 583.603,1247.1 583.612,1247.11 583.621,1247.12 583.63,1247.13 583.64,1247.14 583.649,1247.15 583.658,1247.16 583.667,1247.16 583.676,1247.17 583.686,1247.18 583.695,1247.19 583.704,1247.2 583.713,1247.21 583.722,1247.22 583.732,1247.23 583.741,1247.24 583.75,1247.25 583.759,1247.26 583.768,1247.26 583.777,1247.27 583.787,1247.28 583.796,1247.29 583.805,1247.3 583.814,1247.31 583.823,1247.32 583.833,1247.33 583.842,1247.34 583.851,1247.35 583.86,1247.36 583.869,1247.36 583.879,1247.37 583.888,1247.38 583.897,1247.39 583.906,1247.4 583.915,1247.41 583.925,1247.42 583.934,1247.43 583.943,1247.44 583.952,1247.45 583.961,1247.46 583.97,1247.46 583.98,1247.47 583.989,1247.48 583.998,1247.49 584.007,1247.5 584.016,1247.51 584.026,1247.52 584.035,1247.53 584.044,1247.54 584.053,1247.55 584.062,1247.55 584.072,1247.56 584.081,1247.57 584.09,1247.58 584.099,1247.59 584.108,1247.6 584.117,1247.61 584.127,1247.62 584.136,1247.63 584.145,1247.64 584.154,1247.65 584.163,1247.65 584.173,1247.66 584.182,1247.67 584.191,1247.68 584.2,1247.69 584.209,1247.7 584.219,1247.71 584.228,1247.72 584.237,1247.73 584.246,1247.74 584.255,1247.75 584.265,1247.75 584.274,1247.76 584.283,1247.77 584.292,1247.78 584.301,1247.79 584.31,1247.8 584.32,1247.81 584.329,1247.82 584.338,1247.83 584.347,1247.84 584.356,1247.85 584.366,1247.85 584.375,1247.86 584.384,1247.87 584.393,1247.88 584.402,1247.89 584.412,1247.9 584.421,1247.91 584.43,1247.92 584.439,1247.93 584.448,1247.94 584.457,1247.95 584.467,1247.95 584.476,1247.96 584.485,1247.97 584.494,1247.98 584.503,1247.99 584.513,1248 584.522,1248.01 584.531,1248.02 584.54,1248.03 584.549,1248.04 584.559,1248.05 584.568,1248.06 584.577,1248.06 584.586,1248.07 584.595,1248.08 584.605,1248.09 584.614,1248.1 584.623,1248.11 584.632,1248.12 584.641,1248.13 584.65,1248.14 584.66,1248.15 584.669,1248.16 584.678,1248.16 584.687,1248.17 584.696,1248.18 584.706,1248.19 584.715,1248.2 584.724,1248.21 584.733,1248.22 584.742,1248.23 584.752,1248.24 584.761,1248.25 584.77,1248.26 584.779,1248.26 584.788,1248.27 584.797,1248.28 584.807,1248.29 584.816,1248.3 584.825,1248.31 584.834,1248.32 584.843,1248.33 584.853,1248.34 584.862,1248.35 584.871,1248.36 584.88,1248.37 584.889,1248.37 584.899,1248.38 584.908,1248.39 584.917,1248.4 584.926,1248.41 584.935,1248.42 584.945,1248.43 584.954,1248.44 584.963,1248.45 584.972,1248.46 584.981,1248.47 584.99,1248.47 585,1248.48 585.009,1248.49 585.018,1248.5 585.027,1248.51 585.036,1248.52 585.046,1248.53 585.055,1248.54 585.064,1248.55 585.073,1248.56 585.082,1248.57 585.092,1248.58 585.101,1248.58 585.11,1248.59 585.119,1248.6 585.128,1248.61 585.137,1248.62 585.147,1248.63 585.156,1248.64 585.165,1248.65 585.174,1248.66 585.183,1248.67 585.193,1248.68 585.202,1248.69 585.211,1248.69 585.22,1248.7 585.229,1248.71 585.239,1248.72 585.248,1248.73 585.257,1248.74 585.266,1248.75 585.275,1248.76 585.285,1248.77 585.294,1248.78 585.303,1248.79 585.312,1248.79 585.321,1248.8 585.33,1248.81 585.34,1248.82 585.349,1248.83 585.358,1248.84 585.367,1248.85 585.376,1248.86 585.386,1248.87 585.395,1248.88 585.404,1248.89 585.413,1248.9 585.422,1248.9 585.432,1248.91 585.441,1248.92 585.45,1248.93 585.459,1248.94 585.468,1248.95 585.478,1248.96 585.487,1248.97 585.496,1248.98 585.505,1248.99 585.514,1249 585.523,1249.01 585.533,1249.01 585.542,1249.02 585.551,1249.03 585.56,1249.04 585.569,1249.05 585.579,1249.06 585.588,1249.07 585.597,1249.08 585.606,1249.09 585.615,1249.1 585.625,1249.11 585.634,1249.12 585.643,1249.13 585.652,1249.13 585.661,1249.14 585.67,1249.15 585.68,1249.16 585.689,1249.17 585.698,1249.18 585.707,1249.19 585.716,1249.2 585.726,1249.21 585.735,1249.22 585.744,1249.23 585.753,1249.24 585.762,1249.24 585.772,1249.25 585.781,1249.26 585.79,1249.27 585.799,1249.28 585.808,1249.29 585.818,1249.3 585.827,1249.31 585.836,1249.32 585.845,1249.33 585.854,1249.34 585.863,1249.35 585.873,1249.35 585.882,1249.36 585.891,1249.37 585.9,1249.38 585.909,1249.39 585.919,1249.4 585.928,1249.41 585.937,1249.42 585.946,1249.43 585.955,1249.44 585.965,1249.45 585.974,1249.46 585.983,1249.47 585.992,1249.47 586.001,1249.48 586.01,1249.49 586.02,1249.5 586.029,1249.51 586.038,1249.52 586.047,1249.53 586.056,1249.54 586.066,1249.55 586.075,1249.56 586.084,1249.57 586.093,1249.58 586.102,1249.58 586.112,1249.59 586.121,1249.6 586.13,1249.61 586.139,1249.62 586.148,1249.63 586.158,1249.64 586.167,1249.65 586.176,1249.66 586.185,1249.67 586.194,1249.68 586.203,1249.69 586.213,1249.7 586.222,1249.7 586.231,1249.71 586.24,1249.72 586.249,1249.73 586.259,1249.74 586.268,1249.75 586.277,1249.76 586.286,1249.77 586.295,1249.78 586.305,1249.79 586.314,1249.8 586.323,1249.81 586.332,1249.82 586.341,1249.82 586.35,1249.83 586.36,1249.84 586.369,1249.85 586.378,1249.86 586.387,1249.87 586.396,1249.88 586.406,1249.89 586.415,1249.9 586.424,1249.91 586.433,1249.92 586.442,1249.93 586.452,1249.94 586.461,1249.94 586.47,1249.95 586.479,1249.96 586.488,1249.97 586.498,1249.98 586.507,1249.99 586.516,1250 586.525,1250.01 586.534,1250.02 586.543,1250.03 586.553,1250.04 586.562,1250.05 586.571,1250.06 586.58,1250.06 586.589,1250.07 586.599,1250.08 586.608,1250.09 586.617,1250.1 586.626,1250.11 586.635,1250.12 586.645,1250.13 586.654,1250.14 586.663,1250.15 586.672,1250.16 586.681,1250.17 586.69,1250.18 586.7,1250.19 586.709,1250.19 586.718,1250.2 586.727,1250.21 586.736,1250.22 586.746,1250.23 586.755,1250.24 586.764,1250.25 586.773,1250.26 586.782,1250.27 586.792,1250.28 586.801,1250.29 586.81,1250.3 586.819,1250.31 586.828,1250.31 586.838,1250.32 586.847,1250.33 586.856,1250.34 586.865,1250.35 586.874,1250.36 586.883,1250.37 586.893,1250.38 586.902,1250.39 586.911,1250.4 586.92,1250.41 586.929,1250.42 586.939,1250.43 586.948,1250.44 586.957,1250.44 586.966,1250.45 586.975,1250.46 586.985,1250.47 586.994,1250.48 587.003,1250.49 587.012,1250.5 587.021,1250.51 587.03,1250.52 587.04,1250.53 587.049,1250.54 587.058,1250.55 587.067,1250.56 587.076,1250.57 587.086,1250.57 587.095,1250.58 587.104,1250.59 587.113,1250.6 587.122,1250.61 587.132,1250.62 587.141,1250.63 587.15,1250.64 587.159,1250.65 587.168,1250.66 587.178,1250.67 587.187,1250.68 587.196,1250.69 587.205,1250.7 587.214,1250.7 587.223,1250.71 587.233,1250.72 587.242,1250.73 587.251,1250.74 587.26,1250.75 587.269,1250.76 587.279,1250.77 587.288,1250.78 587.297,1250.79 587.306,1250.8 587.315,1250.81 587.325,1250.82 587.334,1250.83 587.343,1250.84 587.352,1250.84 587.361,1250.85 587.37,1250.86 587.38,1250.87 587.389,1250.88 587.398,1250.89 587.407,1250.9 587.416,1250.91 587.426,1250.92 587.435,1250.93 587.444,1250.94 587.453,1250.95 587.462,1250.96 587.472,1250.97 587.481,1250.97 587.49,1250.98 587.499,1250.99 587.508,1251 587.518,1251.01 587.527,1251.02 587.536,1251.03 587.545,1251.04 587.554,1251.05 587.563,1251.06 587.573,1251.07 587.582,1251.08 587.591,1251.09 587.6,1251.1 587.609,1251.11 587.619,1251.11 587.628,1251.12 587.637,1251.13 587.646,1251.14 587.655,1251.15 587.665,1251.16 587.674,1251.17 587.683,1251.18 587.692,1251.19 587.701,1251.2 587.71,1251.21 587.72,1251.22 587.729,1251.23 587.738,1251.24 587.747,1251.25 587.756,1251.25 587.766,1251.26 587.775,1251.27 587.784,1251.28 587.793,1251.29 587.802,1251.3 587.812,1251.31 587.821,1251.32 587.83,1251.33 587.839,1251.34 587.848,1251.35 587.858,1251.36 587.867,1251.37 587.876,1251.38 587.885,1251.39 587.894,1251.4 587.903,1251.4 587.913,1251.41 587.922,1251.42 587.931,1251.43 587.94,1251.44 587.949,1251.45 587.959,1251.46 587.968,1251.47 587.977,1251.48 587.986,1251.49 587.995,1251.5 588.005,1251.51 588.014,1251.52 588.023,1251.53 588.032,1251.54 588.041,1251.55 588.051,1251.55 588.06,1251.56 588.069,1251.57 588.078,1251.58 588.087,1251.59 588.096,1251.6 588.106,1251.61 588.115,1251.62 588.124,1251.63 588.133,1251.64 588.142,1251.65 588.152,1251.66 588.161,1251.67 588.17,1251.68 588.179,1251.69 588.188,1251.7 588.198,1251.7 588.207,1251.71 588.216,1251.72 588.225,1251.73 588.234,1251.74 588.243,1251.75 588.253,1251.76 588.262,1251.77 588.271,1251.78 588.28,1251.79 588.289,1251.8 588.299,1251.81 588.308,1251.82 588.317,1251.83 588.326,1251.84 588.335,1251.85 588.345,1251.85 588.354,1251.86 588.363,1251.87 588.372,1251.88 588.381,1251.89 588.391,1251.9 588.4,1251.91 588.409,1251.92 588.418,1251.93 588.427,1251.94 588.436,1251.95 588.446,1251.96 588.455,1251.97 588.464,1251.98 588.473,1251.99 588.482,1252 588.492,1252.01 588.501,1252.01 588.51,1252.02 588.519,1252.03 588.528,1252.04 588.538,1252.05 588.547,1252.06 588.556,1252.07 588.565,1252.08 588.574,1252.09 588.583,1252.1 588.593,1252.11 588.602,1252.12 588.611,1252.13 588.62,1252.14 588.629,1252.15 588.639,1252.16 588.648,1252.17 588.657,1252.17 588.666,1252.18 588.675,1252.19 588.685,1252.2 588.694,1252.21 588.703,1252.22 588.712,1252.23 588.721,1252.24 588.731,1252.25 588.74,1252.26 588.749,1252.27 588.758,1252.28 588.767,1252.29 588.776,1252.3 588.786,1252.31 588.795,1252.32 588.804,1252.33 588.813,1252.34 588.822,1252.34 588.832,1252.35 588.841,1252.36 588.85,1252.37 588.859,1252.38 588.868,1252.39 588.878,1252.4 588.887,1252.41 588.896,1252.42 588.905,1252.43 588.914,1252.44 588.923,1252.45 588.933,1252.46 588.942,1252.47 588.951,1252.48 588.96,1252.49 588.969,1252.5 588.979,1252.51 588.988,1252.51 588.997,1252.52 589.006,1252.53 589.015,1252.54 589.025,1252.55 589.034,1252.56 589.043,1252.57 589.052,1252.58 589.061,1252.59 589.071,1252.6 589.08,1252.61 589.089,1252.62 589.098,1252.63 589.107,1252.64 589.116,1252.65 589.126,1252.66 589.135,1252.67 589.144,1252.68 589.153,1252.69 589.162,1252.69 589.172,1252.7 589.181,1252.71 589.19,1252.72 589.199,1252.73 589.208,1252.74 589.218,1252.75 589.227,1252.76 589.236,1252.77 589.245,1252.78 589.254,1252.79 589.263,1252.8 589.273,1252.81 589.282,1252.82 589.291,1252.83 589.3,1252.84 589.309,1252.85 589.319,1252.86 589.328,1252.87 589.337,1252.87 589.346,1252.88 589.355,1252.89 589.365,1252.9 589.374,1252.91 589.383,1252.92 589.392,1252.93 589.401,1252.94 589.411,1252.95 589.42,1252.96 589.429,1252.97 589.438,1252.98 589.447,1252.99 589.456,1253 589.466,1253.01 589.475,1253.02 589.484,1253.03 589.493,1253.04 589.502,1253.05 589.512,1253.06 589.521,1253.06 589.53,1253.07 589.539,1253.08 589.548,1253.09 589.558,1253.1 589.567,1253.11 589.576,1253.12 589.585,1253.13 589.594,1253.14 589.603,1253.15 589.613,1253.16 589.622,1253.17 589.631,1253.18 589.64,1253.19 589.649,1253.2 589.659,1253.21 589.668,1253.22 589.677,1253.23 589.686,1253.24 589.695,1253.25 589.705,1253.26 589.714,1253.26 589.723,1253.27 589.732,1253.28 589.741,1253.29 589.751,1253.3 589.76,1253.31 589.769,1253.32 589.778,1253.33 589.787,1253.34 589.796,1253.35 589.806,1253.36 589.815,1253.37 589.824,1253.38 589.833,1253.39 589.842,1253.4 589.852,1253.41 589.861,1253.42 589.87,1253.43 589.879,1253.44 589.888,1253.45 589.898,1253.46 589.907,1253.47 589.916,1253.47 589.925,1253.48 589.934,1253.49 589.943,1253.5 589.953,1253.51 589.962,1253.52 589.971,1253.53 589.98,1253.54 589.989,1253.55 589.999,1253.56 590.008,1253.57 590.017,1253.58 590.026,1253.59 590.035,1253.6 590.045,1253.61 590.054,1253.62 590.063,1253.63 590.072,1253.64 590.081,1253.65 590.091,1253.66 590.1,1253.67 590.109,1253.68 590.118,1253.69 590.127,1253.69 590.136,1253.7 590.146,1253.71 590.155,1253.72 590.164,1253.73 590.173,1253.74 590.182,1253.75 590.192,1253.76 590.201,1253.77 590.21,1253.78 590.219,1253.79 590.228,1253.8 590.238,1253.81 590.247,1253.82 590.256,1253.83 590.265,1253.84 590.274,1253.85 590.283,1253.86 590.293,1253.87 590.302,1253.88 590.311,1253.89 590.32,1253.9 590.329,1253.91 590.339,1253.92 590.348,1253.92 590.357,1253.93 590.366,1253.94 590.375,1253.95 590.385,1253.96 590.394,1253.97 590.403,1253.98 590.412,1253.99 590.421,1254 590.431,1254.01 590.44,1254.02 590.449,1254.03 590.458,1254.04 590.467,1254.05 590.476,1254.06 590.486,1254.07 590.495,1254.08 590.504,1254.09 590.513,1254.1 590.522,1254.11 590.532,1254.12 590.541,1254.13 590.55,1254.14 590.559,1254.15 590.568,1254.16 590.578,1254.17 590.587,1254.17 590.596,1254.18 590.605,1254.19 590.614,1254.2 590.624,1254.21 590.633,1254.22 590.642,1254.23 590.651,1254.24 590.66,1254.25 590.669,1254.26 590.679,1254.27 590.688,1254.28 590.697,1254.29 590.706,1254.3 590.715,1254.31 590.725,1254.32 590.734,1254.33 590.743,1254.34 590.752,1254.35 590.761,1254.36 590.771,1254.37 590.78,1254.38 590.789,1254.39 590.798,1254.4 590.807,1254.41 590.816,1254.42 590.826,1254.43 590.835,1254.43 590.844,1254.44 590.853,1254.45 590.862,1254.46 590.872,1254.47 590.881,1254.48 590.89,1254.49 590.899,1254.5 590.908,1254.51 590.918,1254.52 590.927,1254.53 590.936,1254.54 590.945,1254.55 590.954,1254.56 590.964,1254.57 590.973,1254.58 590.982,1254.59 590.991,1254.6 591,1254.61 591.009,1254.62 591.019,1254.63 591.028,1254.64 591.037,1254.65 591.046,1254.66 591.055,1254.67 591.065,1254.68 591.074,1254.69 591.083,1254.7 591.092,1254.71 591.101,1254.72 591.111,1254.73 591.12,1254.73 591.129,1254.74 591.138,1254.75 591.147,1254.76 591.156,1254.77 591.166,1254.78 591.175,1254.79 591.184,1254.8 591.193,1254.81 591.202,1254.82 591.212,1254.83 591.221,1254.84 591.23,1254.85 591.239,1254.86 591.248,1254.87 591.258,1254.88 591.267,1254.89 591.276,1254.9 591.285,1254.91 591.294,1254.92 591.304,1254.93 591.313,1254.94 591.322,1254.95 591.331,1254.96 591.34,1254.97 591.349,1254.98 591.359,1254.99 591.368,1255 591.377,1255.01 591.386,1255.02 591.395,1255.03 591.405,1255.04 591.414,1255.05 591.423,1255.05 591.432,1255.06 591.441,1255.07 591.451,1255.08 591.46,1255.09 591.469,1255.1 591.478,1255.11 591.487,1255.12 591.496,1255.13 591.506,1255.14 591.515,1255.15 591.524,1255.16 591.533,1255.17 591.542,1255.18 591.552,1255.19 591.561,1255.2 591.57,1255.21 591.579,1255.22 591.588,1255.23 591.598,1255.24 591.607,1255.25 591.616,1255.26 591.625,1255.27 591.634,1255.28 591.644,1255.29 591.653,1255.3 591.662,1255.31 591.671,1255.32 591.68,1255.33 591.689,1255.34 591.699,1255.35 591.708,1255.36 591.717,1255.37 591.726,1255.38 591.735,1255.39 591.745,1255.4 591.754,1255.41 591.763,1255.42 591.772,1255.43 591.781,1255.43 591.791,1255.44 591.8,1255.45 591.809,1255.46 591.818,1255.47 591.827,1255.48 591.836,1255.49 591.846,1255.5 591.855,1255.51 591.864,1255.52 591.873,1255.53 591.882,1255.54 591.892,1255.55 591.901,1255.56 591.91,1255.57 591.919,1255.58 591.928,1255.59 591.938,1255.6 591.947,1255.61 591.956,1255.62 591.965,1255.63 591.974,1255.64 591.984,1255.65 591.993,1255.66 592.002,1255.67 592.011,1255.68 592.02,1255.69 592.029,1255.7 592.039,1255.71 592.048,1255.72 592.057,1255.73 592.066,1255.74 592.075,1255.75 592.085,1255.76 592.094,1255.77 592.103,1255.78 592.112,1255.79 592.121,1255.8 592.131,1255.81 592.14,1255.82 592.149,1255.83 592.158,1255.84 592.167,1255.85 592.176,1255.86 592.186,1255.87 592.195,1255.88 592.204,1255.89 592.213,1255.9 592.222,1255.9 592.232,1255.91 592.241,1255.92 592.25,1255.93 592.259,1255.94 592.268,1255.95 592.278,1255.96 592.287,1255.97 592.296,1255.98 592.305,1255.99 592.314,1256 592.324,1256.01 592.333,1256.02 592.342,1256.03 592.351,1256.04 592.36,1256.05 592.369,1256.06 592.379,1256.07 592.388,1256.08 592.397,1256.09 592.406,1256.1 592.415,1256.11 592.425,1256.12 592.434,1256.13 592.443,1256.14 592.452,1256.15 592.461,1256.16 592.471,1256.17 592.48,1256.18 592.489,1256.19 592.498,1256.2 592.507,1256.21 592.516,1256.22 592.526,1256.23 592.535,1256.24 592.544,1256.25 592.553,1256.26 592.562,1256.27 592.572,1256.28 592.581,1256.29 592.59,1256.3 592.599,1256.31 592.608,1256.32 592.618,1256.33 592.627,1256.34 592.636,1256.35 592.645,1256.36 592.654,1256.37 592.664,1256.38 592.673,1256.39 592.682,1256.4 592.691,1256.41 592.7,1256.42 592.709,1256.43 592.719,1256.44 592.728,1256.45 592.737,1256.46 592.746,1256.47 592.755,1256.48 592.765,1256.49 592.774,1256.5 592.783,1256.51 592.792,1256.52 592.801,1256.53 592.811,1256.54 592.82,1256.55 592.829,1256.56 592.838,1256.57 592.847,1256.58 592.857,1256.59 592.866,1256.6 592.875,1256.61 592.884,1256.62 592.893,1256.62 592.902,1256.63 592.912,1256.64 592.921,1256.65 592.93,1256.66 592.939,1256.67 592.948,1256.68 592.958,1256.69 592.967,1256.7 592.976,1256.71 592.985,1256.72 592.994,1256.73 593.004,1256.74 593.013,1256.75 593.022,1256.76 593.031,1256.77 593.04,1256.78 593.049,1256.79 593.059,1256.8 593.068,1256.81 593.077,1256.82 593.086,1256.83 593.095,1256.84 593.105,1256.85 593.114,1256.86 593.123,1256.87 593.132,1256.88 593.141,1256.89 593.151,1256.9 593.16,1256.91 593.169,1256.92 593.178,1256.93 593.187,1256.94 593.197,1256.95 593.206,1256.96 593.215,1256.97 593.224,1256.98 593.233,1256.99 593.242,1257 593.252,1257.01 593.261,1257.02 593.27,1257.03 593.279,1257.04 593.288,1257.05 593.298,1257.06 593.307,1257.07 593.316,1257.08 593.325,1257.09 593.334,1257.1 593.344,1257.11 593.353,1257.12 593.362,1257.13 593.371,1257.14 593.38,1257.15 593.389,1257.16 593.399,1257.17 593.408,1257.18 593.417,1257.19 593.426,1257.2 593.435,1257.21 593.445,1257.22 593.454,1257.23 593.463,1257.24 593.472,1257.25 593.481,1257.26 593.491,1257.27 593.5,1257.28 593.509,1257.29 593.518,1257.3 593.527,1257.31 593.537,1257.32 593.546,1257.33 593.555,1257.34 593.564,1257.35 593.573,1257.36 593.582,1257.37 593.592,1257.38 593.601,1257.39 593.61,1257.4 593.619,1257.41 593.628,1257.42 593.638,1257.43 593.647,1257.44 593.656,1257.45 593.665,1257.46 593.674,1257.47 593.684,1257.48 593.693,1257.49 593.702,1257.5 593.711,1257.51 593.72,1257.52 593.729,1257.53 593.739,1257.54 593.748,1257.55 593.757,1257.56 593.766,1257.57 593.775,1257.58 593.785,1257.59 593.794,1257.6 593.803,1257.61 593.812,1257.62 593.821,1257.63 593.831,1257.64 593.84,1257.65 593.849,1257.66 593.858,1257.67 593.867,1257.68 593.877,1257.69 593.886,1257.7 593.895,1257.71 593.904,1257.72 593.913,1257.73 593.922,1257.74 593.932,1257.75 593.941,1257.76 593.95,1257.77 593.959,1257.78 593.968,1257.79 593.978,1257.8 593.987,1257.81 593.996,1257.82 594.005,1257.83 594.014,1257.84 594.024,1257.85 594.033,1257.86 594.042,1257.87 594.051,1257.88 594.06,1257.89 594.069,1257.9 594.079,1257.91 594.088,1257.92 594.097,1257.93 594.106,1257.94 594.115,1257.95 594.125,1257.96 594.134,1257.97 594.143,1257.98 594.152,1257.99 594.161,1258 594.171,1258.01 594.18,1258.02 594.189,1258.03 594.198,1258.04 594.207,1258.05 594.217,1258.06 594.226,1258.08 594.235,1258.09 594.244,1258.1 594.253,1258.11 594.262,1258.12 594.272,1258.13 594.281,1258.14 594.29,1258.15 594.299,1258.16 594.308,1258.17 594.318,1258.18 594.327,1258.19 594.336,1258.2 594.345,1258.21 594.354,1258.22 594.364,1258.23 594.373,1258.24 594.382,1258.25 594.391,1258.26 594.4,1258.27 594.409,1258.28 594.419,1258.29 594.428,1258.3 594.437,1258.31 594.446,1258.32 594.455,1258.33 594.465,1258.34 594.474,1258.35 594.483,1258.36 594.492,1258.37 594.501,1258.38 594.511,1258.39 594.52,1258.4 594.529,1258.41 594.538,1258.42 594.547,1258.43 594.557,1258.44 594.566,1258.45 594.575,1258.46 594.584,1258.47 594.593,1258.48 594.602,1258.49 594.612,1258.5 594.621,1258.51 594.63,1258.52 594.639,1258.53 594.648,1258.54 594.658,1258.55 594.667,1258.56 594.676,1258.57 594.685,1258.58 594.694,1258.59 594.704,1258.6 594.713,1258.61 594.722,1258.62 594.731,1258.63 594.74,1258.64 594.749,1258.65 594.759,1258.66 594.768,1258.67 594.777,1258.68 594.786,1258.69 594.795,1258.7 594.805,1258.71 594.814,1258.72 594.823,1258.73 594.832,1258.74 594.841,1258.75 594.851,1258.76 594.86,1258.77 594.869,1258.79 594.878,1258.8 594.887,1258.81 594.897,1258.82 594.906,1258.83 594.915,1258.84 594.924,1258.85 594.933,1258.86 594.942,1258.87 594.952,1258.88 594.961,1258.89 594.97,1258.9 594.979,1258.91 594.988,1258.92 594.998,1258.93 595.007,1258.94 595.016,1258.95 595.025,1258.96 595.034,1258.97 595.044,1258.98 595.053,1258.99 595.062,1259 595.071,1259.01 595.08,1259.02 595.089,1259.03 595.099,1259.04 595.108,1259.05 595.117,1259.06 595.126,1259.07 595.135,1259.08 595.145,1259.09 595.154,1259.1 595.163,1259.11 595.172,1259.12 595.181,1259.13 595.191,1259.14 595.2,1259.15 595.209,1259.16 595.218,1259.17 595.227,1259.18 595.237,1259.19 595.246,1259.2 595.255,1259.21 595.264,1259.22 595.273,1259.24 595.282,1259.25 595.292,1259.26 595.301,1259.27 595.31,1259.28 595.319,1259.29 595.328,1259.3 595.338,1259.31 595.347,1259.32 595.356,1259.33 595.365,1259.34 595.374,1259.35 595.384,1259.36 595.393,1259.37 595.402,1259.38 595.411,1259.39 595.42,1259.4 595.43,1259.41 595.439,1259.42 595.448,1259.43 595.457,1259.44 595.466,1259.45 595.475,1259.46 595.485,1259.47 595.494,1259.48 595.503,1259.49 595.512,1259.5 595.521,1259.51 595.531,1259.52 595.54,1259.53 595.549,1259.54 595.558,1259.55 595.567,1259.56 595.577,1259.57 595.586,1259.58 595.595,1259.59 595.604,1259.61 595.613,1259.62 595.622,1259.63 595.632,1259.64 595.641,1259.65 595.65,1259.66 595.659,1259.67 595.668,1259.68 595.678,1259.69 595.687,1259.7 595.696,1259.71 595.705,1259.72 595.714,1259.73 595.724,1259.74 595.733,1259.75 595.742,1259.76 595.751,1259.77 595.76,1259.78 595.77,1259.79 595.779,1259.8 595.788,1259.81 595.797,1259.82 595.806,1259.83 595.815,1259.84 595.825,1259.85 595.834,1259.86 595.843,1259.87 595.852,1259.88 595.861,1259.89 595.871,1259.9 595.88,1259.92 595.889,1259.93 595.898,1259.94 595.907,1259.95 595.917,1259.96 595.926,1259.97 595.935,1259.98 595.944,1259.99 595.953,1260 595.962,1260.01 595.972,1260.02 595.981,1260.03 595.99,1260.04 595.999,1260.05 596.008,1260.06 596.018,1260.07 596.027,1260.08 596.036,1260.09 596.045,1260.1 596.054,1260.11 596.064,1260.12 596.073,1260.13 596.082,1260.14 596.091,1260.15 596.1,1260.16 596.11,1260.17 596.119,1260.19 596.128,1260.2 596.137,1260.21 596.146,1260.22 596.155,1260.23 596.165,1260.24 596.174,1260.25 596.183,1260.26 596.192,1260.27 596.201,1260.28 596.211,1260.29 596.22,1260.3 596.229,1260.31 596.238,1260.32 596.247,1260.33 596.257,1260.34 596.266,1260.35 596.275,1260.36 596.284,1260.37 596.293,1260.38 596.302,1260.39 596.312,1260.4 596.321,1260.41 596.33,1260.42 596.339,1260.44 596.348,1260.45 596.358,1260.46 596.367,1260.47 596.376,1260.48 596.385,1260.49 596.394,1260.5 596.404,1260.51 596.413,1260.52 596.422,1260.53 596.431,1260.54 596.44,1260.55 596.45,1260.56 596.459,1260.57 596.468,1260.58 596.477,1260.59 596.486,1260.6 596.495,1260.61 596.505,1260.62 596.514,1260.63 596.523,1260.64 596.532,1260.65 596.541,1260.67 596.551,1260.68 596.56,1260.69 596.569,1260.7 596.578,1260.71 596.587,1260.72 596.597,1260.73 596.606,1260.74 596.615,1260.75 596.624,1260.76 596.633,1260.77 596.642,1260.78 596.652,1260.79 596.661,1260.8 596.67,1260.81 596.679,1260.82 596.688,1260.83 596.698,1260.84 596.707,1260.85 596.716,1260.86 596.725,1260.87 596.734,1260.89 596.744,1260.9 596.753,1260.91 596.762,1260.92 596.771,1260.93 596.78,1260.94 596.79,1260.95 596.799,1260.96 596.808,1260.97 596.817,1260.98 596.826,1260.99 596.835,1261 596.845,1261.01 596.854,1261.02 596.863,1261.03 596.872,1261.04 596.881,1261.05 596.891,1261.06 596.9,1261.07 596.909,1261.09 596.918,1261.1 596.927,1261.11 596.937,1261.12 596.946,1261.13 596.955,1261.14 596.964,1261.15 596.973,1261.16 596.982,1261.17 596.992,1261.18 597.001,1261.19 597.01,1261.2 597.019,1261.21 597.028,1261.22 597.038,1261.23 597.047,1261.24 597.056,1261.25 597.065,1261.26 597.074,1261.28 597.084,1261.29 597.093,1261.3 597.102,1261.31 597.111,1261.32 597.12,1261.33 597.13,1261.34 597.139,1261.35 597.148,1261.36 597.157,1261.37 597.166,1261.38 597.175,1261.39 597.185,1261.4 597.194,1261.41 597.203,1261.42 597.212,1261.43 597.221,1261.44 597.231,1261.45 597.24,1261.47 597.249,1261.48 597.258,1261.49 597.267,1261.5 597.277,1261.51 597.286,1261.52 597.295,1261.53 597.304,1261.54 597.313,1261.55 597.322,1261.56 597.332,1261.57 597.341,1261.58 597.35,1261.59 597.359,1261.6 597.368,1261.61 597.378,1261.62 597.387,1261.64 597.396,1261.65 597.405,1261.66 597.414,1261.67 597.424,1261.68 597.433,1261.69 597.442,1261.7 597.451,1261.71 597.46,1261.72 597.47,1261.73 597.479,1261.74 597.488,1261.75 597.497,1261.76 597.506,1261.77 597.515,1261.78 597.525,1261.79 597.534,1261.81 597.543,1261.82 597.552,1261.83 597.561,1261.84 597.571,1261.85 597.58,1261.86 597.589,1261.87 597.598,1261.88 597.607,1261.89 597.617,1261.9 597.626,1261.91 597.635,1261.92 597.644,1261.93 597.653,1261.94 597.662,1261.95 597.672,1261.97 597.681,1261.98 597.69,1261.99 597.699,1262 597.708,1262.01 597.718,1262.02 597.727,1262.03 597.736,1262.04 597.745,1262.05 597.754,1262.06 597.764,1262.07 597.773,1262.08 597.782,1262.09 597.791,1262.1 597.8,1262.12 597.81,1262.13 597.819,1262.14 597.828,1262.15 597.837,1262.16 597.846,1262.17 597.855,1262.18 597.865,1262.19 597.874,1262.2 597.883,1262.21 597.892,1262.22 597.901,1262.23 597.911,1262.24 597.92,1262.25 597.929,1262.27 597.938,1262.28 597.947,1262.29 597.957,1262.3 597.966,1262.31 597.975,1262.32 597.984,1262.33 597.993,1262.34 598.003,1262.35 598.012,1262.36 598.021,1262.37 598.03,1262.38 598.039,1262.39 598.048,1262.4 598.058,1262.42 598.067,1262.43 598.076,1262.44 598.085,1262.45 598.094,1262.46 598.104,1262.47 598.113,1262.48 598.122,1262.49 598.131,1262.5 598.14,1262.51 598.15,1262.52 598.159,1262.53 598.168,1262.54 598.177,1262.56 598.186,1262.57 598.195,1262.58 598.205,1262.59 598.214,1262.6 598.223,1262.61 598.232,1262.62 598.241,1262.63 598.251,1262.64 598.26,1262.65 598.269,1262.66 598.278,1262.67 598.287,1262.68 598.297,1262.7 598.306,1262.71 598.315,1262.72 598.324,1262.73 598.333,1262.74 598.343,1262.75 598.352,1262.76 598.361,1262.77 598.37,1262.78 598.379,1262.79 598.388,1262.8 598.398,1262.81 598.407,1262.83 598.416,1262.84 598.425,1262.85 598.434,1262.86 598.444,1262.87 598.453,1262.88 598.462,1262.89 598.471,1262.9 598.48,1262.91 598.49,1262.92 598.499,1262.93 598.508,1262.94 598.517,1262.96 598.526,1262.97 598.535,1262.98 598.545,1262.99 598.554,1263 598.563,1263.01 598.572,1263.02 598.581,1263.03 598.591,1263.04 598.6,1263.05 598.609,1263.06 598.618,1263.07 598.627,1263.09 598.637,1263.1 598.646,1263.11 598.655,1263.12 598.664,1263.13 598.673,1263.14 598.683,1263.15 598.692,1263.16 598.701,1263.17 598.71,1263.18 598.719,1263.19 598.728,1263.21 598.738,1263.22 598.747,1263.23 598.756,1263.24 598.765,1263.25 598.774,1263.26 598.784,1263.27 598.793,1263.28 598.802,1263.29 598.811,1263.3 598.82,1263.31 598.83,1263.32 598.839,1263.34 598.848,1263.35 598.857,1263.36 598.866,1263.37 598.875,1263.38 598.885,1263.39 598.894,1263.4 598.903,1263.41 598.912,1263.42 598.921,1263.43 598.931,1263.44 598.94,1263.46 598.949,1263.47 598.958,1263.48 598.967,1263.49 598.977,1263.5 598.986,1263.51 598.995,1263.52 599.004,1263.53 599.013,1263.54 599.023,1263.55 599.032,1263.57 599.041,1263.58 599.05,1263.59 599.059,1263.6 599.068,1263.61 599.078,1263.62 599.087,1263.63 599.096,1263.64 599.105,1263.65 599.114,1263.66 599.124,1263.67 599.133,1263.69 599.142,1263.7 599.151,1263.71 599.16,1263.72 599.17,1263.73 599.179,1263.74 599.188,1263.75 599.197,1263.76 599.206,1263.77 599.215,1263.78 599.225,1263.8 599.234,1263.81 599.243,1263.82 599.252,1263.83 599.261,1263.84 599.271,1263.85 599.28,1263.86 599.289,1263.87 599.298,1263.88 599.307,1263.89 599.317,1263.91 599.326,1263.92 599.335,1263.93 599.344,1263.94 599.353,1263.95 599.363,1263.96 599.372,1263.97 599.381,1263.98 599.39,1263.99 599.399,1264 599.408,1264.02 599.418,1264.03 599.427,1264.04 599.436,1264.05 599.445,1264.06 599.454,1264.07 599.464,1264.08 599.473,1264.09 599.482,1264.1 599.491,1264.12 599.5,1264.13 599.51,1264.14 599.519,1264.15 599.528,1264.16 599.537,1264.17 599.546,1264.18 599.555,1264.19 599.565,1264.2 599.574,1264.21 599.583,1264.23 599.592,1264.24 599.601,1264.25 599.611,1264.26 599.62,1264.27 599.629,1264.28 599.638,1264.29 599.647,1264.3 599.657,1264.31 599.666,1264.33 599.675,1264.34 599.684,1264.35 599.693,1264.36 599.703,1264.37 599.712,1264.38 599.721,1264.39 599.73,1264.4 599.739,1264.41 599.748,1264.43 599.758,1264.44 599.767,1264.45 599.776,1264.46 599.785,1264.47 599.794,1264.48 599.804,1264.49 599.813,1264.5 599.822,1264.51 599.831,1264.53 599.84,1264.54 599.85,1264.55 599.859,1264.56 599.868,1264.57 599.877,1264.58 599.886,1264.59 599.895,1264.6 599.905,1264.61 599.914,1264.63 599.923,1264.64 599.932,1264.65 599.941,1264.66 599.951,1264.67 599.96,1264.68 599.969,1264.69 599.978,1264.7 599.987,1264.71 599.997,1264.73 600.006,1264.74 600.015,1264.75 600.024,1264.76 600.033,1264.77 600.043,1264.78 600.052,1264.79 600.061,1264.8 600.07,1264.81 600.079,1264.83 600.088,1264.84 600.098,1264.85 600.107,1264.86 600.116,1264.87 600.125,1264.88 600.134,1264.89 600.144,1264.9 600.153,1264.92 600.162,1264.93 600.171,1264.94 600.18,1264.95 600.19,1264.96 600.199,1264.97 600.208,1264.98 600.217,1264.99 600.226,1265 600.236,1265.02 600.245,1265.03 600.254,1265.04 600.263,1265.05 600.272,1265.06 600.281,1265.07 600.291,1265.08 600.3,1265.09 600.309,1265.11 600.318,1265.12 600.327,1265.13 600.337,1265.14 600.346,1265.15 600.355,1265.16 600.364,1265.17 600.373,1265.18 600.383,1265.2 600.392,1265.21 600.401,1265.22 600.41,1265.23 600.419,1265.24 600.428,1265.25 600.438,1265.26 600.447,1265.27 600.456,1265.29 600.465,1265.3 600.474,1265.31 600.484,1265.32 600.493,1265.33 600.502,1265.34 600.511,1265.35 600.52,1265.36 600.53,1265.38 600.539,1265.39 600.548,1265.4 600.557,1265.41 600.566,1265.42 600.576,1265.43 600.585,1265.44 600.594,1265.45 600.603,1265.47 600.612,1265.48 600.621,1265.49 600.631,1265.5 600.64,1265.51 600.649,1265.52 600.658,1265.53 600.667,1265.55 600.677,1265.56 600.686,1265.57 600.695,1265.58 600.704,1265.59 600.713,1265.6 600.723,1265.61 600.732,1265.62 600.741,1265.64 600.75,1265.65 600.759,1265.66 600.768,1265.67 600.778,1265.68 600.787,1265.69 600.796,1265.7 600.805,1265.72 600.814,1265.73 600.824,1265.74 600.833,1265.75 600.842,1265.76 600.851,1265.77 600.86,1265.78 600.87,1265.79 600.879,1265.81 600.888,1265.82 600.897,1265.83 600.906,1265.84 600.916,1265.85 600.925,1265.86 600.934,1265.87 600.943,1265.89 600.952,1265.9 600.961,1265.91 600.971,1265.92 600.98,1265.93 600.989,1265.94 600.998,1265.95 601.007,1265.96 601.017,1265.98 601.026,1265.99 601.035,1266 601.044,1266.01 601.053,1266.02 601.063,1266.03 601.072,1266.04 601.081,1266.06 601.09,1266.07 601.099,1266.08 601.108,1266.09 601.118,1266.1 601.127,1266.11 601.136,1266.12 601.145,1266.14 601.154,1266.15 601.164,1266.16 601.173,1266.17 601.182,1266.18 601.191,1266.19 601.2,1266.2 601.21,1266.22 601.219,1266.23 601.228,1266.24 601.237,1266.25 601.246,1266.26 601.256,1266.27 601.265,1266.28 601.274,1266.3 601.283,1266.31 601.292,1266.32 601.301,1266.33 601.311,1266.34 601.32,1266.35 601.329,1266.36 601.338,1266.38 601.347,1266.39 601.357,1266.4 601.366,1266.41 601.375,1266.42 601.384,1266.43 601.393,1266.45 601.403,1266.46 601.412,1266.47 601.421,1266.48 601.43,1266.49 601.439,1266.5 601.448,1266.51 601.458,1266.53 601.467,1266.54 601.476,1266.55 601.485,1266.56 601.494,1266.57 601.504,1266.58 601.513,1266.59 601.522,1266.61 601.531,1266.62 601.54,1266.63 601.55,1266.64 601.559,1266.65 601.568,1266.66 601.577,1266.68 601.586,1266.69 601.596,1266.7 601.605,1266.71 601.614,1266.72 601.623,1266.73 601.632,1266.74 601.641,1266.76 601.651,1266.77 601.66,1266.78 601.669,1266.79 601.678,1266.8 601.687,1266.81 601.697,1266.83 601.706,1266.84 601.715,1266.85 601.724,1266.86 601.733,1266.87 601.743,1266.88 601.752,1266.89 601.761,1266.91 601.77,1266.92 601.779,1266.93 601.788,1266.94 601.798,1266.95 601.807,1266.96 601.816,1266.98 601.825,1266.99 601.834,1267 601.844,1267.01 601.853,1267.02 601.862,1267.03 601.871,1267.05 601.88,1267.06 601.89,1267.07 601.899,1267.08 601.908,1267.09 601.917,1267.1 601.926,1267.11 601.936,1267.13 601.945,1267.14 601.954,1267.15 601.963,1267.16 601.972,1267.17 601.981,1267.18 601.991,1267.2 602,1267.21 602.009,1267.22 602.018,1267.23 602.027,1267.24 602.037,1267.25 602.046,1267.27 602.055,1267.28 602.064,1267.29 602.073,1267.3 602.083,1267.31 602.092,1267.32 602.101,1267.34 602.11,1267.35 602.119,1267.36 602.128,1267.37 602.138,1267.38 602.147,1267.39 602.156,1267.41 602.165,1267.42 602.174,1267.43 602.184,1267.44 602.193,1267.45 602.202,1267.46 602.211,1267.48 602.22,1267.49 602.23,1267.5 602.239,1267.51 602.248,1267.52 602.257,1267.53 602.266,1267.55 602.276,1267.56 602.285,1267.57 602.294,1267.58 602.303,1267.59 602.312,1267.6 602.321,1267.62 602.331,1267.63 602.34,1267.64 602.349,1267.65 602.358,1267.66 602.367,1267.67 602.377,1267.69 602.386,1267.7 602.395,1267.71 602.404,1267.72 602.413,1267.73 602.423,1267.74 602.432,1267.76 602.441,1267.77 602.45,1267.78 602.459,1267.79 602.468,1267.8 602.478,1267.82 602.487,1267.83 602.496,1267.84 602.505,1267.85 602.514,1267.86 602.524,1267.87 602.533,1267.89 602.542,1267.9 602.551,1267.91 602.56,1267.92 602.57,1267.93 602.579,1267.94 602.588,1267.96 602.597,1267.97 602.606,1267.98 602.616,1267.99 602.625,1268 602.634,1268.02 602.643,1268.03 602.652,1268.04 602.661,1268.05 602.671,1268.06 602.68,1268.07 602.689,1268.09 602.698,1268.1 602.707,1268.11 602.717,1268.12 602.726,1268.13 602.735,1268.15 602.744,1268.16 602.753,1268.17 602.763,1268.18 602.772,1268.19 602.781,1268.2 602.79,1268.22 602.799,1268.23 602.809,1268.24 602.818,1268.25 602.827,1268.26 602.836,1268.28 602.845,1268.29 602.854,1268.3 602.864,1268.31 602.873,1268.32 602.882,1268.33 602.891,1268.35 602.9,1268.36 602.91,1268.37 602.919,1268.38 602.928,1268.39 602.937,1268.41 602.946,1268.42 602.956,1268.43 602.965,1268.44 602.974,1268.45 602.983,1268.47 602.992,1268.48 603.001,1268.49 603.011,1268.5 603.02,1268.51 603.029,1268.52 603.038,1268.54 603.047,1268.55 603.057,1268.56 603.066,1268.57 603.075,1268.58 603.084,1268.6 603.093,1268.61 603.103,1268.62 603.112,1268.63 603.121,1268.64 603.13,1268.66 603.139,1268.67 603.149,1268.68 603.158,1268.69 603.167,1268.7 603.176,1268.72 603.185,1268.73 603.194,1268.74 603.204,1268.75 603.213,1268.76 603.222,1268.78 603.231,1268.79 603.24,1268.8 603.25,1268.81 603.259,1268.82 603.268,1268.83 603.277,1268.85 603.286,1268.86 603.296,1268.87 603.305,1268.88 603.314,1268.89 603.323,1268.91 603.332,1268.92 603.341,1268.93 603.351,1268.94 603.36,1268.95 603.369,1268.97 603.378,1268.98 603.387,1268.99 603.397,1269 603.406,1269.01 603.415,1269.03 603.424,1269.04 603.433,1269.05 603.443,1269.06 603.452,1269.07 603.461,1269.09 603.47,1269.1 603.479,1269.11 603.489,1269.12 603.498,1269.13 603.507,1269.15 603.516,1269.16 603.525,1269.17 603.534,1269.18 603.544,1269.19 603.553,1269.21 603.562,1269.22 603.571,1269.23 603.58,1269.24 603.59,1269.25 603.599,1269.27 603.608,1269.28 603.617,1269.29 603.626,1269.3 603.636,1269.32 603.645,1269.33 603.654,1269.34 603.663,1269.35 603.672,1269.36 603.681,1269.38 603.691,1269.39 603.7,1269.4 603.709,1269.41 603.718,1269.42 603.727,1269.44 603.737,1269.45 603.746,1269.46 603.755,1269.47 603.764,1269.48 603.773,1269.5 603.783,1269.51 603.792,1269.52 603.801,1269.53 603.81,1269.54 603.819,1269.56 603.829,1269.57 603.838,1269.58 603.847,1269.59 603.856,1269.61 603.865,1269.62 603.874,1269.63 603.884,1269.64 603.893,1269.65 603.902,1269.67 603.911,1269.68 603.92,1269.69 603.93,1269.7 603.939,1269.71 603.948,1269.73 603.957,1269.74 603.966,1269.75 603.976,1269.76 603.985,1269.78 603.994,1269.79 604.003,1269.8 604.012,1269.81 604.021,1269.82 604.031,1269.84 604.04,1269.85 604.049,1269.86 604.058,1269.87 604.067,1269.88 604.077,1269.9 604.086,1269.91 604.095,1269.92 604.104,1269.93 604.113,1269.95 604.123,1269.96 604.132,1269.97 604.141,1269.98 604.15,1269.99 604.159,1270.01 604.169,1270.02 604.178,1270.03 604.187,1270.04 604.196,1270.06 604.205,1270.07 604.214,1270.08 604.224,1270.09 604.233,1270.1 604.242,1270.12 604.251,1270.13 604.26,1270.14 604.27,1270.15 604.279,1270.17 604.288,1270.18 604.297,1270.19 604.306,1270.2 604.316,1270.21 604.325,1270.23 604.334,1270.24 604.343,1270.25 604.352,1270.26 604.361,1270.28 604.371,1270.29 604.38,1270.3 604.389,1270.31 604.398,1270.33 604.407,1270.34 604.417,1270.35 604.426,1270.36 604.435,1270.37 604.444,1270.39 604.453,1270.4 604.463,1270.41 604.472,1270.42 604.481,1270.44 604.49,1270.45 604.499,1270.46 604.509,1270.47 604.518,1270.49 604.527,1270.5 604.536,1270.51 604.545,1270.52 604.554,1270.53 604.564,1270.55 604.573,1270.56 604.582,1270.57 604.591,1270.58 604.6,1270.6 604.61,1270.61 604.619,1270.62 604.628,1270.63 604.637,1270.65 604.646,1270.66 604.656,1270.67 604.665,1270.68 604.674,1270.69 604.683,1270.71 604.692,1270.72 604.701,1270.73 604.711,1270.74 604.72,1270.76 604.729,1270.77 604.738,1270.78 604.747,1270.79 604.757,1270.81 604.766,1270.82 604.775,1270.83 604.784,1270.84 604.793,1270.86 604.803,1270.87 604.812,1270.88 604.821,1270.89 604.83,1270.91 604.839,1270.92 604.849,1270.93 604.858,1270.94 604.867,1270.95 604.876,1270.97 604.885,1270.98 604.894,1270.99 604.904,1271 604.913,1271.02 604.922,1271.03 604.931,1271.04 604.94,1271.05 604.95,1271.07 604.959,1271.08 604.968,1271.09 604.977,1271.1 604.986,1271.12 604.996,1271.13 605.005,1271.14 605.014,1271.15 605.023,1271.17 605.032,1271.18 605.041,1271.19 605.051,1271.2 605.06,1271.22 605.069,1271.23 605.078,1271.24 605.087,1271.25 605.097,1271.27 605.106,1271.28 605.115,1271.29 605.124,1271.3 605.133,1271.32 605.143,1271.33 605.152,1271.34 605.161,1271.35 605.17,1271.37 605.179,1271.38 605.189,1271.39 605.198,1271.4 605.207,1271.42 605.216,1271.43 605.225,1271.44 605.234,1271.45 605.244,1271.47 605.253,1271.48 605.262,1271.49 605.271,1271.5 605.28,1271.52 605.29,1271.53 605.299,1271.54 605.308,1271.55 605.317,1271.57 605.326,1271.58 605.336,1271.59 605.345,1271.6 605.354,1271.62 605.363,1271.63 605.372,1271.64 605.382,1271.65 605.391,1271.67 605.4,1271.68 605.409,1271.69 605.418,1271.7 605.427,1271.72 605.437,1271.73 605.446,1271.74 605.455,1271.76 605.464,1271.77 605.473,1271.78 605.483,1271.79 605.492,1271.81 605.501,1271.82 605.51,1271.83 605.519,1271.84 605.529,1271.86 605.538,1271.87 605.547,1271.88 605.556,1271.89 605.565,1271.91 605.574,1271.92 605.584,1271.93 605.593,1271.94 605.602,1271.96 605.611,1271.97 605.62,1271.98 605.63,1272 605.639,1272.01 605.648,1272.02 605.657,1272.03 605.666,1272.05 605.676,1272.06 605.685,1272.07 605.694,1272.08 605.703,1272.1 605.712,1272.11 605.722,1272.12 605.731,1272.13 605.74,1272.15 605.749,1272.16 605.758,1272.17 605.767,1272.19 605.777,1272.2 605.786,1272.21 605.795,1272.22 605.804,1272.24 605.813,1272.25 605.823,1272.26 605.832,1272.27 605.841,1272.29 605.85,1272.3 605.859,1272.31 605.869,1272.33 605.878,1272.34 605.887,1272.35 605.896,1272.36 605.905,1272.38 605.914,1272.39 605.924,1272.4 605.933,1272.41 605.942,1272.43 605.951,1272.44 605.96,1272.45 605.97,1272.47 605.979,1272.48 605.988,1272.49 605.997,1272.5 606.006,1272.52 606.016,1272.53 606.025,1272.54 606.034,1272.55 606.043,1272.57 606.052,1272.58 606.062,1272.59 606.071,1272.61 606.08,1272.62 606.089,1272.63 606.098,1272.64 606.107,1272.66 606.117,1272.67 606.126,1272.68 606.135,1272.7 606.144,1272.71 606.153,1272.72 606.163,1272.73 606.172,1272.75 606.181,1272.76 606.19,1272.77 606.199,1272.79 606.209,1272.8 606.218,1272.81 606.227,1272.82 606.236,1272.84 606.245,1272.85 606.254,1272.86 606.264,1272.88 606.273,1272.89 606.282,1272.9 606.291,1272.91 606.3,1272.93 606.31,1272.94 606.319,1272.95 606.328,1272.97 606.337,1272.98 606.346,1272.99 606.356,1273 606.365,1273.02 606.374,1273.03 606.383,1273.04 606.392,1273.06 606.402,1273.07 606.411,1273.08 606.42,1273.09 606.429,1273.11 606.438,1273.12 606.447,1273.13 606.457,1273.15 606.466,1273.16 606.475,1273.17 606.484,1273.18 606.493,1273.2 606.503,1273.21 606.512,1273.22 606.521,1273.24 606.53,1273.25 606.539,1273.26 606.549,1273.28 606.558,1273.29 606.567,1273.3 606.576,1273.31 606.585,1273.33 606.594,1273.34 606.604,1273.35 606.613,1273.37 606.622,1273.38 606.631,1273.39 606.64,1273.4 606.65,1273.42 606.659,1273.43 606.668,1273.44 606.677,1273.46 606.686,1273.47 606.696,1273.48 606.705,1273.5 606.714,1273.51 606.723,1273.52 606.732,1273.53 606.742,1273.55 606.751,1273.56 606.76,1273.57 606.769,1273.59 606.778,1273.6 606.787,1273.61 606.797,1273.63 606.806,1273.64 606.815,1273.65 606.824,1273.66 606.833,1273.68 606.843,1273.69 606.852,1273.7 606.861,1273.72 606.87,1273.73 606.879,1273.74 606.889,1273.76 606.898,1273.77 606.907,1273.78 606.916,1273.8 606.925,1273.81 606.934,1273.82 606.944,1273.83 606.953,1273.85 606.962,1273.86 606.971,1273.87 606.98,1273.89 606.99,1273.9 606.999,1273.91 607.008,1273.93 607.017,1273.94 607.026,1273.95 607.036,1273.97 607.045,1273.98 607.054,1273.99 607.063,1274 607.072,1274.02 607.082,1274.03 607.091,1274.04 607.1,1274.06 607.109,1274.07 607.118,1274.08 607.127,1274.1 607.137,1274.11 607.146,1274.12 607.155,1274.14 607.164,1274.15 607.173,1274.16 607.183,1274.18 607.192,1274.19 607.201,1274.2 607.21,1274.22 607.219,1274.23 607.229,1274.24 607.238,1274.25 607.247,1274.27 607.256,1274.28 607.265,1274.29 607.274,1274.31 607.284,1274.32 607.293,1274.33 607.302,1274.35 607.311,1274.36 607.32,1274.37 607.33,1274.39 607.339,1274.4 607.348,1274.41 607.357,1274.43 607.366,1274.44 607.376,1274.45 607.385,1274.47 607.394,1274.48 607.403,1274.49 607.412,1274.51 607.422,1274.52 607.431,1274.53 607.44,1274.55 607.449,1274.56 607.458,1274.57 607.467,1274.59 607.477,1274.6 607.486,1274.61 607.495,1274.63 607.504,1274.64 607.513,1274.65 607.523,1274.66 607.532,1274.68 607.541,1274.69 607.55,1274.7 607.559,1274.72 607.569,1274.73 607.578,1274.74 607.587,1274.76 607.596,1274.77 607.605,1274.78 607.615,1274.8 607.624,1274.81 607.633,1274.82 607.642,1274.84 607.651,1274.85 607.66,1274.86 607.67,1274.88 607.679,1274.89 607.688,1274.9 607.697,1274.92 607.706,1274.93 607.716,1274.94 607.725,1274.96 607.734,1274.97 607.743,1274.98 607.752,1275 607.762,1275.01 607.771,1275.02 607.78,1275.04 607.789,1275.05 607.798,1275.06 607.807,1275.08 607.817,1275.09 607.826,1275.1 607.835,1275.12 607.844,1275.13 607.853,1275.15 607.863,1275.16 607.872,1275.17 607.881,1275.19 607.89,1275.2 607.899,1275.21 607.909,1275.23 607.918,1275.24 607.927,1275.25 607.936,1275.27 607.945,1275.28 607.955,1275.29 607.964,1275.31 607.973,1275.32 607.982,1275.33 607.991,1275.35 608,1275.36 608.01,1275.37 608.019,1275.39 608.028,1275.4 608.037,1275.41 608.046,1275.43 608.056,1275.44 608.065,1275.45 608.074,1275.47 608.083,1275.48 608.092,1275.49 608.102,1275.51 608.111,1275.52 608.12,1275.53 608.129,1275.55 608.138,1275.56 608.147,1275.58 608.157,1275.59 608.166,1275.6 608.175,1275.62 608.184,1275.63 608.193,1275.64 608.203,1275.66 608.212,1275.67 608.221,1275.68 608.23,1275.7 608.239,1275.71 608.249,1275.72 608.258,1275.74 608.267,1275.75 608.276,1275.76 608.285,1275.78 608.295,1275.79 608.304,1275.81 608.313,1275.82 608.322,1275.83 608.331,1275.85 608.34,1275.86 608.35,1275.87 608.359,1275.89 608.368,1275.9 608.377,1275.91 608.386,1275.93 608.396,1275.94 608.405,1275.95 608.414,1275.97 608.423,1275.98 608.432,1276 608.442,1276.01 608.451,1276.02 608.46,1276.04 608.469,1276.05 608.478,1276.06 608.487,1276.08 608.497,1276.09 608.506,1276.1 608.515,1276.12 608.524,1276.13 608.533,1276.15 608.543,1276.16 608.552,1276.17 608.561,1276.19 608.57,1276.2 608.579,1276.21 608.589,1276.23 608.598,1276.24 608.607,1276.25 608.616,1276.27 608.625,1276.28 608.635,1276.3 608.644,1276.31 608.653,1276.32 608.662,1276.34 608.671,1276.35 608.68,1276.36 608.69,1276.38 608.699,1276.39 608.708,1276.41 608.717,1276.42 608.726,1276.43 608.736,1276.45 608.745,1276.46 608.754,1276.47 608.763,1276.49 608.772,1276.5 608.782,1276.52 608.791,1276.53 608.8,1276.54 608.809,1276.56 608.818,1276.57 608.827,1276.58 608.837,1276.6 608.846,1276.61 608.855,1276.63 608.864,1276.64 608.873,1276.65 608.883,1276.67 608.892,1276.68 608.901,1276.69 608.91,1276.71 608.919,1276.72 608.929,1276.74 608.938,1276.75 608.947,1276.76 608.956,1276.78 608.965,1276.79 608.975,1276.8 608.984,1276.82 608.993,1276.83 609.002,1276.85 609.011,1276.86 609.02,1276.87 609.03,1276.89 609.039,1276.9 609.048,1276.91 609.057,1276.93 609.066,1276.94 609.076,1276.96 609.085,1276.97 609.094,1276.98 609.103,1277 609.112,1277.01 609.122,1277.03 609.131,1277.04 609.14,1277.05 609.149,1277.07 609.158,1277.08 609.167,1277.1 609.177,1277.11 609.186,1277.12 609.195,1277.14 609.204,1277.15 609.213,1277.16 609.223,1277.18 609.232,1277.19 609.241,1277.21 609.25,1277.22 609.259,1277.23 609.269,1277.25 609.278,1277.26 609.287,1277.28 609.296,1277.29 609.305,1277.3 609.315,1277.32 609.324,1277.33 609.333,1277.35 609.342,1277.36 609.351,1277.37 609.36,1277.39 609.37,1277.4 609.379,1277.42 609.388,1277.43 609.397,1277.44 609.406,1277.46 609.416,1277.47 609.425,1277.49 609.434,1277.5 609.443,1277.51 609.452,1277.53 609.462,1277.54 609.471,1277.56 609.48,1277.57 609.489,1277.58 609.498,1277.6 609.507,1277.61 609.517,1277.63 609.526,1277.64 609.535,1277.65 609.544,1277.67 609.553,1277.68 609.563,1277.7 609.572,1277.71 609.581,1277.72 609.59,1277.74 609.599,1277.75 609.609,1277.77 609.618,1277.78 609.627,1277.79 609.636,1277.81 609.645,1277.82 609.655,1277.84 609.664,1277.85 609.673,1277.86 609.682,1277.88 609.691,1277.89 609.7,1277.91 609.71,1277.92 609.719,1277.93 609.728,1277.95 609.737,1277.96 609.746,1277.98 609.756,1277.99 609.765,1278.01 609.774,1278.02 609.783,1278.03 609.792,1278.05 609.802,1278.06 609.811,1278.08 609.82,1278.09 609.829,1278.1 609.838,1278.12 609.847,1278.13 609.857,1278.15 609.866,1278.16 609.875,1278.17 609.884,1278.19 609.893,1278.2 609.903,1278.22 609.912,1278.23 609.921,1278.25 609.93,1278.26 609.939,1278.27 609.949,1278.29 609.958,1278.3 609.967,1278.32 609.976,1278.33 609.985,1278.35 609.995,1278.36 610.004,1278.37 610.013,1278.39 610.022,1278.4 610.031,1278.42 610.04,1278.43 610.05,1278.44 610.059,1278.46 610.068,1278.47 610.077,1278.49 610.086,1278.5 610.096,1278.52 610.105,1278.53 610.114,1278.54 610.123,1278.56 610.132,1278.57 610.142,1278.59 610.151,1278.6 610.16,1278.62 610.169,1278.63 610.178,1278.64 610.188,1278.66 610.197,1278.67 610.206,1278.69 610.215,1278.7 610.224,1278.72 610.233,1278.73 610.243,1278.74 610.252,1278.76 610.261,1278.77 610.27,1278.79 610.279,1278.8 610.289,1278.82 610.298,1278.83 610.307,1278.84 610.316,1278.86 610.325,1278.87 610.335,1278.89 610.344,1278.9 610.353,1278.92 610.362,1278.93 610.371,1278.94 610.38,1278.96 610.39,1278.97 610.399,1278.99 610.408,1279 610.417,1279.02 610.426,1279.03 610.436,1279.05 610.445,1279.06 610.454,1279.07 610.463,1279.09 610.472,1279.1 610.482,1279.12 610.491,1279.13 610.5,1279.15 610.509,1279.16 610.518,1279.18 610.528,1279.19 610.537,1279.2 610.546,1279.22 610.555,1279.23 610.564,1279.25 610.573,1279.26 610.583,1279.28 610.592,1279.29 610.601,1279.31 610.61,1279.32 610.619,1279.33 610.629,1279.35 610.638,1279.36 610.647,1279.38 610.656,1279.39 610.665,1279.41 610.675,1279.42 610.684,1279.44 610.693,1279.45 610.702,1279.46 610.711,1279.48 610.72,1279.49 610.73,1279.51 610.739,1279.52 610.748,1279.54 610.757,1279.55 610.766,1279.57 610.776,1279.58 610.785,1279.6 610.794,1279.61 610.803,1279.62 610.812,1279.64 610.822,1279.65 610.831,1279.67 610.84,1279.68 610.849,1279.7 610.858,1279.71 610.868,1279.73 610.877,1279.74 610.886,1279.76 610.895,1279.77 610.904,1279.78 610.913,1279.8 610.923,1279.81 610.932,1279.83 610.941,1279.84 610.95,1279.86 610.959,1279.87 610.969,1279.89 610.978,1279.9 610.987,1279.92 610.996,1279.93 611.005,1279.95 611.015,1279.96 611.024,1279.97 611.033,1279.99 611.042,1280 611.051,1280.02 611.06,1280.03 611.07,1280.05 611.079,1280.06 611.088,1280.08 611.097,1280.09 611.106,1280.11 611.116,1280.12 611.125,1280.14 611.134,1280.15 611.143,1280.17 611.152,1280.18 611.162,1280.19 611.171,1280.21 611.18,1280.22 611.189,1280.24 611.198,1280.25 611.208,1280.27 611.217,1280.28 611.226,1280.3 611.235,1280.31 611.244,1280.33 611.253,1280.34 611.263,1280.36 611.272,1280.37 611.281,1280.39 611.29,1280.4 611.299,1280.42 611.309,1280.43 611.318,1280.44 611.327,1280.46 611.336,1280.47 611.345,1280.49 611.355,1280.5 611.364,1280.52 611.373,1280.53 611.382,1280.55 611.391,1280.56 611.4,1280.58 611.41,1280.59 611.419,1280.61 611.428,1280.62 611.437,1280.64 611.446,1280.65 611.456,1280.67 611.465,1280.68 611.474,1280.7 611.483,1280.71 611.492,1280.73 611.502,1280.74 611.511,1280.76 611.52,1280.77 611.529,1280.79 611.538,1280.8 611.548,1280.82 611.557,1280.83 611.566,1280.84 611.575,1280.86 611.584,1280.87 611.593,1280.89 611.603,1280.9 611.612,1280.92 611.621,1280.93 611.63,1280.95 611.639,1280.96 611.649,1280.98 611.658,1280.99 611.667,1281.01 611.676,1281.02 611.685,1281.04 611.695,1281.05 611.704,1281.07 611.713,1281.08 611.722,1281.1 611.731,1281.11 611.74,1281.13 611.75,1281.14 611.759,1281.16 611.768,1281.17 611.777,1281.19 611.786,1281.2 611.796,1281.22 611.805,1281.23 611.814,1281.25 611.823,1281.26 611.832,1281.28 611.842,1281.29 611.851,1281.31 611.86,1281.32 611.869,1281.34 611.878,1281.35 611.888,1281.37 611.897,1281.38 611.906,1281.4 611.915,1281.41 611.924,1281.43 611.933,1281.44 611.943,1281.46 611.952,1281.47 611.961,1281.49 611.97,1281.5 611.979,1281.52 611.989,1281.53 611.998,1281.55 612.007,1281.56 612.016,1281.58 612.025,1281.59 612.035,1281.61 612.044,1281.62 612.053,1281.64 612.062,1281.65 612.071,1281.67 612.08,1281.68 612.09,1281.7 612.099,1281.71 612.108,1281.73 612.117,1281.74 612.126,1281.76 612.136,1281.77 612.145,1281.79 612.154,1281.81 612.163,1281.82 612.172,1281.84 612.182,1281.85 612.191,1281.87 612.2,1281.88 612.209,1281.9 612.218,1281.91 612.228,1281.93 612.237,1281.94 612.246,1281.96 612.255,1281.97 612.264,1281.99 612.273,1282 612.283,1282.02 612.292,1282.03 612.301,1282.05 612.31,1282.06 612.319,1282.08 612.329,1282.09 612.338,1282.11 612.347,1282.12 612.356,1282.14 612.365,1282.15 612.375,1282.17 612.384,1282.18 612.393,1282.2 612.402,1282.22 612.411,1282.23 612.42,1282.25 612.43,1282.26 612.439,1282.28 612.448,1282.29 612.457,1282.31 612.466,1282.32 612.476,1282.34 612.485,1282.35 612.494,1282.37 612.503,1282.38 612.512,1282.4 612.522,1282.41 612.531,1282.43 612.54,1282.44 612.549,1282.46 612.558,1282.48 612.568,1282.49 612.577,1282.51 612.586,1282.52 612.595,1282.54 612.604,1282.55 612.613,1282.57 612.623,1282.58 612.632,1282.6 612.641,1282.61 612.65,1282.63 612.659,1282.64 612.669,1282.66 612.678,1282.67 612.687,1282.69 612.696,1282.71 612.705,1282.72 612.715,1282.74 612.724,1282.75 612.733,1282.77 612.742,1282.78 612.751,1282.8 612.761,1282.81 612.77,1282.83 612.779,1282.84 612.788,1282.86 612.797,1282.87 612.806,1282.89 612.816,1282.91 612.825,1282.92 612.834,1282.94 612.843,1282.95 612.852,1282.97 612.862,1282.98 612.871,1283 612.88,1283.01 612.889,1283.03 612.898,1283.04 612.908,1283.06 612.917,1283.08 612.926,1283.09 612.935,1283.11 612.944,1283.12 612.953,1283.14 612.963,1283.15 612.972,1283.17 612.981,1283.18 612.99,1283.2 612.999,1283.22 613.009,1283.23 613.018,1283.25 613.027,1283.26 613.036,1283.28 613.045,1283.29 613.055,1283.31 613.064,1283.32 613.073,1283.34 613.082,1283.36 613.091,1283.37 613.101,1283.39 613.11,1283.4 613.119,1283.42 613.128,1283.43 613.137,1283.45 613.146,1283.46 613.156,1283.48 613.165,1283.5 613.174,1283.51 613.183,1283.53 613.192,1283.54 613.202,1283.56 613.211,1283.57 613.22,1283.59 613.229,1283.6 613.238,1283.62 613.248,1283.64 613.257,1283.65 613.266,1283.67 613.275,1283.68 613.284,1283.7 613.293,1283.71 613.303,1283.73 613.312,1283.75 613.321,1283.76 613.33,1283.78 613.339,1283.79 613.349,1283.81 613.358,1283.82 613.367,1283.84 613.376,1283.86 613.385,1283.87 613.395,1283.89 613.404,1283.9 613.413,1283.92 613.422,1283.93 613.431,1283.95 613.441,1283.97 613.45,1283.98 613.459,1284 613.468,1284.01 613.477,1284.03 613.486,1284.04 613.496,1284.06 613.505,1284.08 613.514,1284.09 613.523,1284.11 613.532,1284.12 613.542,1284.14 613.551,1284.15 613.56,1284.17 613.569,1284.19 613.578,1284.2 613.588,1284.22 613.597,1284.23 613.606,1284.25 613.615,1284.27 613.624,1284.28 613.633,1284.3 613.643,1284.31 613.652,1284.33 613.661,1284.34 613.67,1284.36 613.679,1284.38 613.689,1284.39 613.698,1284.41 613.707,1284.42 613.716,1284.44 613.725,1284.46 613.735,1284.47 613.744,1284.49 613.753,1284.5 613.762,1284.52 613.771,1284.54 613.781,1284.55 613.79,1284.57 613.799,1284.58 613.808,1284.6 613.817,1284.61 613.826,1284.63 613.836,1284.65 613.845,1284.66 613.854,1284.68 613.863,1284.69 613.872,1284.71 613.882,1284.73 613.891,1284.74 613.9,1284.76 613.909,1284.77 613.918,1284.79 613.928,1284.81 613.937,1284.82 613.946,1284.84 613.955,1284.85 613.964,1284.87 613.973,1284.89 613.983,1284.9 613.992,1284.92 614.001,1284.93 614.01,1284.95 614.019,1284.97 614.029,1284.98 614.038,1285 614.047,1285.01 614.056,1285.03 614.065,1285.05 614.075,1285.06 614.084,1285.08 614.093,1285.09 614.102,1285.11 614.111,1285.13 614.121,1285.14 614.13,1285.16 614.139,1285.17 614.148,1285.19 614.157,1285.21 614.166,1285.22 614.176,1285.24 614.185,1285.26 614.194,1285.27 614.203,1285.29 614.212,1285.3 614.222,1285.32 614.231,1285.34 614.24,1285.35 614.249,1285.37 614.258,1285.38 614.268,1285.4 614.277,1285.42 614.286,1285.43 614.295,1285.45 614.304,1285.47 614.313,1285.48 614.323,1285.5 614.332,1285.51 614.341,1285.53 614.35,1285.55 614.359,1285.56 614.369,1285.58 614.378,1285.59 614.387,1285.61 614.396,1285.63 614.405,1285.64 614.415,1285.66 614.424,1285.68 614.433,1285.69 614.442,1285.71 614.451,1285.72 614.461,1285.74 614.47,1285.76 614.479,1285.77 614.488,1285.79 614.497,1285.81 614.506,1285.82 614.516,1285.84 614.525,1285.85 614.534,1285.87 614.543,1285.89 614.552,1285.9 614.562,1285.92 614.571,1285.94 614.58,1285.95 614.589,1285.97 614.598,1285.99 614.608,1286 614.617,1286.02 614.626,1286.03 614.635,1286.05 614.644,1286.07 614.653,1286.08 614.663,1286.1 614.672,1286.12 614.681,1286.13 614.69,1286.15 614.699,1286.16 614.709,1286.18 614.718,1286.2 614.727,1286.21 614.736,1286.23 614.745,1286.25 614.755,1286.26 614.764,1286.28 614.773,1286.3 614.782,1286.31 614.791,1286.33 614.801,1286.35 614.81,1286.36 614.819,1286.38 614.828,1286.39 614.837,1286.41 614.846,1286.43 614.856,1286.44 614.865,1286.46 614.874,1286.48 614.883,1286.49 614.892,1286.51 614.902,1286.53 614.911,1286.54 614.92,1286.56 614.929,1286.58 614.938,1286.59 614.948,1286.61 614.957,1286.63 614.966,1286.64 614.975,1286.66 614.984,1286.67 614.994,1286.69 615.003,1286.71 615.012,1286.72 615.021,1286.74 615.03,1286.76 615.039,1286.77 615.049,1286.79 615.058,1286.81 615.067,1286.82 615.076,1286.84 615.085,1286.86 615.095,1286.87 615.104,1286.89 615.113,1286.91 615.122,1286.92 615.131,1286.94 615.141,1286.96 615.15,1286.97 615.159,1286.99 615.168,1287.01 615.177,1287.02 615.186,1287.04 615.196,1287.06 615.205,1287.07 615.214,1287.09 615.223,1287.11 615.232,1287.12 615.242,1287.14 615.251,1287.16 615.26,1287.17 615.269,1287.19 615.278,1287.21 615.288,1287.22 615.297,1287.24 615.306,1287.26 615.315,1287.27 615.324,1287.29 615.334,1287.31 615.343,1287.32 615.352,1287.34 615.361,1287.36 615.37,1287.37 615.379,1287.39 615.389,1287.41 615.398,1287.42 615.407,1287.44 615.416,1287.46 615.425,1287.47 615.435,1287.49 615.444,1287.51 615.453,1287.52 615.462,1287.54 615.471,1287.56 615.481,1287.57 615.49,1287.59 615.499,1287.61 615.508,1287.62 615.517,1287.64 615.526,1287.66 615.536,1287.67 615.545,1287.69 615.554,1287.71 615.563,1287.73 615.572,1287.74 615.582,1287.76 615.591,1287.78 615.6,1287.79 615.609,1287.81 615.618,1287.83 615.628,1287.84 615.637,1287.86 615.646,1287.88 615.655,1287.89 615.664,1287.91 615.674,1287.93 615.683,1287.94 615.692,1287.96 615.701,1287.98 615.71,1288 615.719,1288.01 615.729,1288.03 615.738,1288.05 615.747,1288.06 615.756,1288.08 615.765,1288.1 615.775,1288.11 615.784,1288.13 615.793,1288.15 615.802,1288.16 615.811,1288.18 615.821,1288.2 615.83,1288.22 615.839,1288.23 615.848,1288.25 615.857,1288.27 615.866,1288.28 615.876,1288.3 615.885,1288.32 615.894,1288.33 615.903,1288.35 615.912,1288.37 615.922,1288.39 615.931,1288.4 615.94,1288.42 615.949,1288.44 615.958,1288.45 615.968,1288.47 615.977,1288.49 615.986,1288.5 615.995,1288.52 616.004,1288.54 616.014,1288.56 616.023,1288.57 616.032,1288.59 616.041,1288.61 616.05,1288.62 616.059,1288.64 616.069,1288.66 616.078,1288.68 616.087,1288.69 616.096,1288.71 616.105,1288.73 616.115,1288.74 616.124,1288.76 616.133,1288.78 616.142,1288.8 616.151,1288.81 616.161,1288.83 616.17,1288.85 616.179,1288.86 616.188,1288.88 616.197,1288.9 616.206,1288.92 616.216,1288.93 616.225,1288.95 616.234,1288.97 616.243,1288.98 616.252,1289 616.262,1289.02 616.271,1289.04 616.28,1289.05 616.289,1289.07 616.298,1289.09 616.308,1289.11 616.317,1289.12 616.326,1289.14 616.335,1289.16 616.344,1289.17 616.354,1289.19 616.363,1289.21 616.372,1289.23 616.381,1289.24 616.39,1289.26 616.399,1289.28 616.409,1289.3 616.418,1289.31 616.427,1289.33 616.436,1289.35 616.445,1289.36 616.455,1289.38 616.464,1289.4 616.473,1289.42 616.482,1289.43 616.491,1289.45 616.501,1289.47 616.51,1289.49 616.519,1289.5 616.528,1289.52 616.537,1289.54 616.546,1289.56 616.556,1289.57 616.565,1289.59 616.574,1289.61 616.583,1289.63 616.592,1289.64 616.602,1289.66 616.611,1289.68 616.62,1289.69 616.629,1289.71 616.638,1289.73 616.648,1289.75 616.657,1289.76 616.666,1289.78 616.675,1289.8 616.684,1289.82 616.694,1289.83 616.703,1289.85 616.712,1289.87 616.721,1289.89 616.73,1289.9 616.739,1289.92 616.749,1289.94 616.758,1289.96 616.767,1289.97 616.776,1289.99 616.785,1290.01 616.795,1290.03 616.804,1290.04 616.813,1290.06 616.822,1290.08 616.831,1290.1 616.841,1290.11 616.85,1290.13 616.859,1290.15 616.868,1290.17 616.877,1290.18 616.886,1290.2 616.896,1290.22 616.905,1290.24 616.914,1290.25 616.923,1290.27 616.932,1290.29 616.942,1290.31 616.951,1290.33 616.96,1290.34 616.969,1290.36 616.978,1290.38 616.988,1290.4 616.997,1290.41 617.006,1290.43 617.015,1290.45 617.024,1290.47 617.034,1290.48 617.043,1290.5 617.052,1290.52 617.061,1290.54 617.07,1290.55 617.079,1290.57 617.089,1290.59 617.098,1290.61 617.107,1290.63 617.116,1290.64 617.125,1290.66 617.135,1290.68 617.144,1290.7 617.153,1290.71 617.162,1290.73 617.171,1290.75 617.181,1290.77 617.19,1290.79 617.199,1290.8 617.208,1290.82 617.217,1290.84 617.226,1290.86 617.236,1290.87 617.245,1290.89 617.254,1290.91 617.263,1290.93 617.272,1290.95 617.282,1290.96 617.291,1290.98 617.3,1291 617.309,1291.02 617.318,1291.03 617.328,1291.05 617.337,1291.07 617.346,1291.09 617.355,1291.11 617.364,1291.12 617.374,1291.14 617.383,1291.16 617.392,1291.18 617.401,1291.2 617.41,1291.21 617.419,1291.23 617.429,1291.25 617.438,1291.27 617.447,1291.28 617.456,1291.3 617.465,1291.32 617.475,1291.34 617.484,1291.36 617.493,1291.37 617.502,1291.39 617.511,1291.41 617.521,1291.43 617.53,1291.45 617.539,1291.46 617.548,1291.48 617.557,1291.5 617.567,1291.52 617.576,1291.54 617.585,1291.55 617.594,1291.57 617.603,1291.59 617.612,1291.61 617.622,1291.63 617.631,1291.64 617.64,1291.66 617.649,1291.68 617.658,1291.7 617.668,1291.72 617.677,1291.73 617.686,1291.75 617.695,1291.77 617.704,1291.79 617.714,1291.81 617.723,1291.82 617.732,1291.84 617.741,1291.86 617.75,1291.88 617.759,1291.9 617.769,1291.91 617.778,1291.93 617.787,1291.95 617.796,1291.97 617.805,1291.99 617.815,1292.01 617.824,1292.02 617.833,1292.04 617.842,1292.06 617.851,1292.08 617.861,1292.1 617.87,1292.11 617.879,1292.13 617.888,1292.15 617.897,1292.17 617.907,1292.19 617.916,1292.21 617.925,1292.22 617.934,1292.24 617.943,1292.26 617.952,1292.28 617.962,1292.3 617.971,1292.31 617.98,1292.33 617.989,1292.35 617.998,1292.37 618.008,1292.39 618.017,1292.41 618.026,1292.42 618.035,1292.44 618.044,1292.46 618.054,1292.48 618.063,1292.5 618.072,1292.52 618.081,1292.53 618.09,1292.55 618.099,1292.57 618.109,1292.59 618.118,1292.61 618.127,1292.63 618.136,1292.64 618.145,1292.66 618.155,1292.68 618.164,1292.7 618.173,1292.72 618.182,1292.74 618.191,1292.75 618.201,1292.77 618.21,1292.79 618.219,1292.81 618.228,1292.83 618.237,1292.85 618.247,1292.86 618.256,1292.88 618.265,1292.9 618.274,1292.92 618.283,1292.94 618.292,1292.96 618.302,1292.97 618.311,1292.99 618.32,1293.01 618.329,1293.03 618.338,1293.05 618.348,1293.07 618.357,1293.08 618.366,1293.1 618.375,1293.12 618.384,1293.14 618.394,1293.16 618.403,1293.18 618.412,1293.2 618.421,1293.21 618.43,1293.23 618.439,1293.25 618.449,1293.27 618.458,1293.29 618.467,1293.31 618.476,1293.33 618.485,1293.34 618.495,1293.36 618.504,1293.38 618.513,1293.4 618.522,1293.42 618.531,1293.44 618.541,1293.46 618.55,1293.47 618.559,1293.49 618.568,1293.51 618.577,1293.53 618.587,1293.55 618.596,1293.57 618.605,1293.59 618.614,1293.6 618.623,1293.62 618.632,1293.64 618.642,1293.66 618.651,1293.68 618.66,1293.7 618.669,1293.72 618.678,1293.73 618.688,1293.75 618.697,1293.77 618.706,1293.79 618.715,1293.81 618.724,1293.83 618.734,1293.85 618.743,1293.87 618.752,1293.88 618.761,1293.9 618.77,1293.92 618.779,1293.94 618.789,1293.96 618.798,1293.98 618.807,1294 618.816,1294.02 618.825,1294.03 618.835,1294.05 618.844,1294.07 618.853,1294.09 618.862,1294.11 618.871,1294.13 618.881,1294.15 618.89,1294.17 618.899,1294.18 618.908,1294.2 618.917,1294.22 618.927,1294.24 618.936,1294.26 618.945,1294.28 618.954,1294.3 618.963,1294.32 618.972,1294.34 618.982,1294.35 618.991,1294.37 619,1294.39 619.009,1294.41 619.018,1294.43 619.028,1294.45 619.037,1294.47 619.046,1294.49 619.055,1294.51 619.064,1294.52 619.074,1294.54 619.083,1294.56 619.092,1294.58 619.101,1294.6 619.11,1294.62 619.119,1294.64 619.129,1294.66 619.138,1294.68 619.147,1294.69 619.156,1294.71 619.165,1294.73 619.175,1294.75 619.184,1294.77 619.193,1294.79 619.202,1294.81 619.211,1294.83 619.221,1294.85 619.23,1294.87 619.239,1294.88 619.248,1294.9 619.257,1294.92 619.267,1294.94 619.276,1294.96 619.285,1294.98 619.294,1295 619.303,1295.02 619.312,1295.04 619.322,1295.06 619.331,1295.08 619.34,1295.09 619.349,1295.11 619.358,1295.13 619.368,1295.15 619.377,1295.17 619.386,1295.19 619.395,1295.21 619.404,1295.23 619.414,1295.25 619.423,1295.27 619.432,1295.29 619.441,1295.31 619.45,1295.32 619.459,1295.34 619.469,1295.36 619.478,1295.38 619.487,1295.4 619.496,1295.42 619.505,1295.44 619.515,1295.46 619.524,1295.48 619.533,1295.5 619.542,1295.52 619.551,1295.54 619.561,1295.55 619.57,1295.57 619.579,1295.59 619.588,1295.61 619.597,1295.63 619.607,1295.65 619.616,1295.67 619.625,1295.69 619.634,1295.71 619.643,1295.73 619.652,1295.75 619.662,1295.77 619.671,1295.79 619.68,1295.81 619.689,1295.82 619.698,1295.84 619.708,1295.86 619.717,1295.88 619.726,1295.9 619.735,1295.92 619.744,1295.94 619.754,1295.96 619.763,1295.98 619.772,1296 619.781,1296.02 619.79,1296.04 619.799,1296.06 619.809,1296.08 619.818,1296.1 619.827,1296.12 619.836,1296.14 619.845,1296.15 619.855,1296.17 619.864,1296.19 619.873,1296.21 619.882,1296.23 619.891,1296.25 619.901,1296.27 619.91,1296.29 619.919,1296.31 619.928,1296.33 619.937,1296.35 619.947,1296.37 619.956,1296.39 619.965,1296.41 619.974,1296.43 619.983,1296.45 619.992,1296.47 620.002,1296.49 620.011,1296.51 620.02,1296.52 620.029,1296.54 620.038,1296.56 620.048,1296.58 620.057,1296.6 620.066,1296.62 620.075,1296.64 620.084,1296.66 620.094,1296.68 620.103,1296.7 620.112,1296.72 620.121,1296.74 620.13,1296.76 620.14,1296.78 620.149,1296.8 620.158,1296.82 620.167,1296.84 620.176,1296.86 620.185,1296.88 620.195,1296.9 620.204,1296.92 620.213,1296.94 620.222,1296.96 620.231,1296.98 620.241,1297 620.25,1297.02 620.259,1297.04 620.268,1297.06 620.277,1297.08 620.287,1297.09 620.296,1297.11 620.305,1297.13 620.314,1297.15 620.323,1297.17 620.332,1297.19 620.342,1297.21 620.351,1297.23 620.36,1297.25 620.369,1297.27 620.378,1297.29 620.388,1297.31 620.397,1297.33 620.406,1297.35 620.415,1297.37 620.424,1297.39 620.434,1297.41 620.443,1297.43 620.452,1297.45 620.461,1297.47 620.47,1297.49 620.48,1297.51 620.489,1297.53 620.498,1297.55 620.507,1297.57 620.516,1297.59 620.525,1297.61 620.535,1297.63 620.544,1297.65 620.553,1297.67 620.562,1297.69 620.571,1297.71 620.581,1297.73 620.59,1297.75 620.599,1297.77 620.608,1297.79 620.617,1297.81 620.627,1297.83 620.636,1297.85 620.645,1297.87 620.654,1297.89 620.663,1297.91 620.672,1297.93 620.682,1297.95 620.691,1297.97 620.7,1297.99 620.709,1298.01 620.718,1298.03 620.728,1298.05 620.737,1298.07 620.746,1298.09 620.755,1298.11 620.764,1298.13 620.774,1298.15 620.783,1298.17 620.792,1298.19 620.801,1298.21 620.81,1298.23 620.82,1298.25 620.829,1298.27 620.838,1298.29 620.847,1298.31 620.856,1298.33 620.865,1298.35 620.875,1298.37 620.884,1298.39 620.893,1298.41 620.902,1298.43 620.911,1298.45 620.921,1298.47 620.93,1298.49 620.939,1298.51 620.948,1298.53 620.957,1298.55 620.967,1298.57 620.976,1298.59 620.985,1298.61 620.994,1298.63 621.003,1298.65 621.012,1298.67 621.022,1298.69 621.031,1298.71 621.04,1298.74 621.049,1298.76 621.058,1298.78 621.068,1298.8 621.077,1298.82 621.086,1298.84 621.095,1298.86 621.104,1298.88 621.114,1298.9 621.123,1298.92 621.132,1298.94 621.141,1298.96 621.15,1298.98 621.16,1299 621.169,1299.02 621.178,1299.04 621.187,1299.06 621.196,1299.08 621.205,1299.1 621.215,1299.12 621.224,1299.14 621.233,1299.16 621.242,1299.18 621.251,1299.2 621.261,1299.22 621.27,1299.24 621.279,1299.26 621.288,1299.28 621.297,1299.31 621.307,1299.33 621.316,1299.35 621.325,1299.37 621.334,1299.39 621.343,1299.41 621.352,1299.43 621.362,1299.45 621.371,1299.47 621.38,1299.49 621.389,1299.51 621.398,1299.53 621.408,1299.55 621.417,1299.57 621.426,1299.59 621.435,1299.61 621.444,1299.63 621.454,1299.65 621.463,1299.67 621.472,1299.7 621.481,1299.72 621.49,1299.74 621.5,1299.76 621.509,1299.78 621.518,1299.8 621.527,1299.82 621.536,1299.84 621.545,1299.86 621.555,1299.88 621.564,1299.9 621.573,1299.92 621.582,1299.94 621.591,1299.96 621.601,1299.98 621.61,1300 621.619,1300.03 621.628,1300.05 621.637,1300.07 621.647,1300.09 621.656,1300.11 621.665,1300.13 621.674,1300.15 621.683,1300.17 621.692,1300.19 621.702,1300.21 621.711,1300.23 621.72,1300.25 621.729,1300.27 621.738,1300.3 621.748,1300.32 621.757,1300.34 621.766,1300.36 621.775,1300.38 621.784,1300.4 621.794,1300.42 621.803,1300.44 621.812,1300.46 621.821,1300.48 621.83,1300.5 621.84,1300.52 621.849,1300.55 621.858,1300.57 621.867,1300.59 621.876,1300.61 621.885,1300.63 621.895,1300.65 621.904,1300.67 621.913,1300.69 621.922,1300.71 621.931,1300.73 621.941,1300.75 621.95,1300.78 621.959,1300.8 621.968,1300.82 621.977,1300.84 621.987,1300.86 621.996,1300.88 622.005,1300.9 622.014,1300.92 622.023,1300.94 622.032,1300.96 622.042,1300.98 622.051,1301.01 622.06,1301.03 622.069,1301.05 622.078,1301.07 622.088,1301.09 622.097,1301.11 622.106,1301.13 622.115,1301.15 622.124,1301.17 622.134,1301.2 622.143,1301.22 622.152,1301.24 622.161,1301.26 622.17,1301.28 622.18,1301.3 622.189,1301.32 622.198,1301.34 622.207,1301.36 622.216,1301.39 622.225,1301.41 622.235,1301.43 622.244,1301.45 622.253,1301.47 622.262,1301.49 622.271,1301.51 622.281,1301.53 622.29,1301.55 622.299,1301.58 622.308,1301.6 622.317,1301.62 622.327,1301.64 622.336,1301.66 622.345,1301.68 622.354,1301.7 622.363,1301.72 622.373,1301.75 622.382,1301.77 622.391,1301.79 622.4,1301.81 622.409,1301.83 622.418,1301.85 622.428,1301.87 622.437,1301.89 622.446,1301.92 622.455,1301.94 622.464,1301.96 622.474,1301.98 622.483,1302 622.492,1302.02 622.501,1302.04 622.51,1302.07 622.52,1302.09 622.529,1302.11 622.538,1302.13 622.547,1302.15 622.556,1302.17 622.565,1302.19 622.575,1302.22 622.584,1302.24 622.593,1302.26 622.602,1302.28 622.611,1302.3 622.621,1302.32 622.63,1302.34 622.639,1302.37 622.648,1302.39 622.657,1302.41 622.667,1302.43 622.676,1302.45 622.685,1302.47 622.694,1302.49 622.703,1302.52 622.713,1302.54 622.722,1302.56 622.731,1302.58 622.74,1302.6 622.749,1302.62 622.758,1302.65 622.768,1302.67 622.777,1302.69 622.786,1302.71 622.795,1302.73 622.804,1302.75 622.814,1302.77 622.823,1302.8 622.832,1302.82 622.841,1302.84 622.85,1302.86 622.86,1302.88 622.869,1302.9 622.878,1302.93 622.887,1302.95 622.896,1302.97 622.905,1302.99 622.915,1303.01 622.924,1303.03 622.933,1303.06 622.942,1303.08 622.951,1303.1 622.961,1303.12 622.97,1303.14 622.979,1303.16 622.988,1303.19 622.997,1303.21 623.007,1303.23 623.016,1303.25 623.025,1303.27 623.034,1303.3 623.043,1303.32 623.053,1303.34 623.062,1303.36 623.071,1303.38 623.08,1303.4 623.089,1303.43 623.098,1303.45 623.108,1303.47 623.117,1303.49 623.126,1303.51 623.135,1303.54 623.144,1303.56 623.154,1303.58 623.163,1303.6 623.172,1303.62 623.181,1303.64 623.19,1303.67 623.2,1303.69 623.209,1303.71 623.218,1303.73 623.227,1303.75 623.236,1303.78 623.245,1303.8 623.255,1303.82 623.264,1303.84 623.273,1303.86 623.282,1303.89 623.291,1303.91 623.301,1303.93 623.31,1303.95 623.319,1303.97 623.328,1304 623.337,1304.02 623.347,1304.04 623.356,1304.06 623.365,1304.08 623.374,1304.11 623.383,1304.13 623.393,1304.15 623.402,1304.17 623.411,1304.19 623.42,1304.22 623.429,1304.24 623.438,1304.26 623.448,1304.28 623.457,1304.3 623.466,1304.33 623.475,1304.35 623.484,1304.37 623.494,1304.39 623.503,1304.42 623.512,1304.44 623.521,1304.46 623.53,1304.48 623.54,1304.5 623.549,1304.53 623.558,1304.55 623.567,1304.57 623.576,1304.59 623.585,1304.61 623.595,1304.64 623.604,1304.66 623.613,1304.68 623.622,1304.7 623.631,1304.73 623.641,1304.75 623.65,1304.77 623.659,1304.79 623.668,1304.82 623.677,1304.84 623.687,1304.86 623.696,1304.88 623.705,1304.9 623.714,1304.93 623.723,1304.95 623.733,1304.97 623.742,1304.99 623.751,1305.02 623.76,1305.04 623.769,1305.06 623.778,1305.08 623.788,1305.11 623.797,1305.13 623.806,1305.15 623.815,1305.17 623.824,1305.2 623.834,1305.22 623.843,1305.24 623.852,1305.26 623.861,1305.28 623.87,1305.31 623.88,1305.33 623.889,1305.35 623.898,1305.37 623.907,1305.4 623.916,1305.42 623.925,1305.44 623.935,1305.46 623.944,1305.49 623.953,1305.51 623.962,1305.53 623.971,1305.55 623.981,1305.58 623.99,1305.6 623.999,1305.62 624.008,1305.65 624.017,1305.67 624.027,1305.69 624.036,1305.71 624.045,1305.74 624.054,1305.76 624.063,1305.78 624.073,1305.8 624.082,1305.83 624.091,1305.85 624.1,1305.87 624.109,1305.89 624.118,1305.92 624.128,1305.94 624.137,1305.96 624.146,1305.98 624.155,1306.01 624.164,1306.03 624.174,1306.05 624.183,1306.08 624.192,1306.1 624.201,1306.12 624.21,1306.14 624.22,1306.17 624.229,1306.19 624.238,1306.21 624.247,1306.23 624.256,1306.26 624.265,1306.28 624.275,1306.3 624.284,1306.33 624.293,1306.35 624.302,1306.37 624.311,1306.39 624.321,1306.42 624.33,1306.44 624.339,1306.46 624.348,1306.49 624.357,1306.51 624.367,1306.53 624.376,1306.55 624.385,1306.58 624.394,1306.6 624.403,1306.62 624.413,1306.65 624.422,1306.67 624.431,1306.69 624.44,1306.71 624.449,1306.74 624.458,1306.76 624.468,1306.78 624.477,1306.81 624.486,1306.83 624.495,1306.85 624.504,1306.87 624.514,1306.9 624.523,1306.92 624.532,1306.94 624.541,1306.97 624.55,1306.99 624.56,1307.01 624.569,1307.04 624.578,1307.06 624.587,1307.08 624.596,1307.11 624.605,1307.13 624.615,1307.15 624.624,1307.17 624.633,1307.2 624.642,1307.22 624.651,1307.24 624.661,1307.27 624.67,1307.29 624.679,1307.31 624.688,1307.34 624.697,1307.36 624.707,1307.38 624.716,1307.41 624.725,1307.43 624.734,1307.45 624.743,1307.48 624.753,1307.5 624.762,1307.52 624.771,1307.54 624.78,1307.57 624.789,1307.59 624.798,1307.61 624.808,1307.64 624.817,1307.66 624.826,1307.68 624.835,1307.71 624.844,1307.73 624.854,1307.75 624.863,1307.78 624.872,1307.8 624.881,1307.82 624.89,1307.85 624.9,1307.87 624.909,1307.89 624.918,1307.92 624.927,1307.94 624.936,1307.96 624.946,1307.99 624.955,1308.01 624.964,1308.03 624.973,1308.06 624.982,1308.08 624.991,1308.1 625.001,1308.13 625.01,1308.15 625.019,1308.17 625.028,1308.2 625.037,1308.22 625.047,1308.24 625.056,1308.27 625.065,1308.29 625.074,1308.32 625.083,1308.34 625.093,1308.36 625.102,1308.39 625.111,1308.41 625.12,1308.43 625.129,1308.46 625.138,1308.48 625.148,1308.5 625.157,1308.53 625.166,1308.55 625.175,1308.57 625.184,1308.6 625.194,1308.62 625.203,1308.64 625.212,1308.67 625.221,1308.69 625.23,1308.72 625.24,1308.74 625.249,1308.76 625.258,1308.79 625.267,1308.81 625.276,1308.83 625.286,1308.86 625.295,1308.88 625.304,1308.9 625.313,1308.93 625.322,1308.95 625.331,1308.98 625.341,1309 625.35,1309.02 625.359,1309.05 625.368,1309.07 625.377,1309.09 625.387,1309.12 625.396,1309.14 625.405,1309.17 625.414,1309.19 625.423,1309.21 625.433,1309.24 625.442,1309.26 625.451,1309.28 625.46,1309.31 625.469,1309.33 625.478,1309.36 625.488,1309.38 625.497,1309.4 625.506,1309.43 625.515,1309.45 625.524,1309.48 625.534,1309.5 625.543,1309.52 625.552,1309.55 625.561,1309.57 625.57,1309.59 625.58,1309.62 625.589,1309.64 625.598,1309.67 625.607,1309.69 625.616,1309.71 625.626,1309.74 625.635,1309.76 625.644,1309.79 625.653,1309.81 625.662,1309.83 625.671,1309.86 625.681,1309.88 625.69,1309.91 625.699,1309.93 625.708,1309.95 625.717,1309.98 625.727,1310 625.736,1310.03 625.745,1310.05 625.754,1310.07 625.763,1310.1 625.773,1310.12 625.782,1310.15 625.791,1310.17 625.8,1310.2 625.809,1310.22 625.818,1310.24 625.828,1310.27 625.837,1310.29 625.846,1310.32 625.855,1310.34 625.864,1310.36 625.874,1310.39 625.883,1310.41 625.892,1310.44 625.901,1310.46 625.91,1310.49 625.92,1310.51 625.929,1310.53 625.938,1310.56 625.947,1310.58 625.956,1310.61 625.966,1310.63 625.975,1310.65 625.984,1310.68 625.993,1310.7 626.002,1310.73 626.011,1310.75 626.021,1310.78 626.03,1310.8 626.039,1310.83 626.048,1310.85 626.057,1310.87 626.067,1310.9 626.076,1310.92 626.085,1310.95 626.094,1310.97 626.103,1311 626.113,1311.02 626.122,1311.04 626.131,1311.07 626.14,1311.09 626.149,1311.12 626.158,1311.14 626.168,1311.17 626.177,1311.19 626.186,1311.22 626.195,1311.24 626.204,1311.26 626.214,1311.29 626.223,1311.31 626.232,1311.34 626.241,1311.36 626.25,1311.39 626.26,1311.41 626.269,1311.44 626.278,1311.46 626.287,1311.49 626.296,1311.51 626.306,1311.53 626.315,1311.56 626.324,1311.58 626.333,1311.61 626.342,1311.63 626.351,1311.66 626.361,1311.68 626.37,1311.71 626.379,1311.73 626.388,1311.76 626.397,1311.78 626.407,1311.81 626.416,1311.83 626.425,1311.85 626.434,1311.88 626.443,1311.9 626.453,1311.93 626.462,1311.95 626.471,1311.98 626.48,1312 626.489,1312.03 626.498,1312.05 626.508,1312.08 626.517,1312.1 626.526,1312.13 626.535,1312.15 626.544,1312.18 626.554,1312.2 626.563,1312.23 626.572,1312.25 626.581,1312.28 626.59,1312.3 626.6,1312.33 626.609,1312.35 626.618,1312.38 626.627,1312.4 626.636,1312.42 626.646,1312.45 626.655,1312.47 626.664,1312.5 626.673,1312.52 626.682,1312.55 626.691,1312.57 626.701,1312.6 626.71,1312.62 626.719,1312.65 626.728,1312.67 626.737,1312.7 626.747,1312.72 626.756,1312.75 626.765,1312.77 626.774,1312.8 626.783,1312.82 626.793,1312.85 626.802,1312.87 626.811,1312.9 626.82,1312.92 626.829,1312.95 626.838,1312.97 626.848,1313 626.857,1313.02 626.866,1313.05 626.875,1313.07 626.884,1313.1 626.894,1313.13 626.903,1313.15 626.912,1313.18 626.921,1313.2 626.93,1313.23 626.94,1313.25 626.949,1313.28 626.958,1313.3 626.967,1313.33 626.976,1313.35 626.986,1313.38 626.995,1313.4 627.004,1313.43 627.013,1313.45 627.022,1313.48 627.031,1313.5 627.041,1313.53 627.05,1313.55 627.059,1313.58 627.068,1313.6 627.077,1313.63 627.087,1313.65 627.096,1313.68 627.105,1313.71 627.114,1313.73 627.123,1313.76 627.133,1313.78 627.142,1313.81 627.151,1313.83 627.16,1313.86 627.169,1313.88 627.178,1313.91 627.188,1313.93 627.197,1313.96 627.206,1313.98 627.215,1314.01 627.224,1314.04 627.234,1314.06 627.243,1314.09 627.252,1314.11 627.261,1314.14 627.27,1314.16 627.28,1314.19 627.289,1314.21 627.298,1314.24 627.307,1314.27 627.316,1314.29 627.326,1314.32 627.335,1314.34 627.344,1314.37 627.353,1314.39 627.362,1314.42 627.371,1314.44 627.381,1314.47 627.39,1314.5 627.399,1314.52 627.408,1314.55 627.417,1314.57 627.427,1314.6 627.436,1314.62 627.445,1314.65 627.454,1314.67 627.463,1314.7 627.473,1314.73 627.482,1314.75 627.491,1314.78 627.5,1314.8 627.509,1314.83 627.519,1314.85 627.528,1314.88 627.537,1314.91 627.546,1314.93 627.555,1314.96 627.564,1314.98 627.574,1315.01 627.583,1315.04 627.592,1315.06 627.601,1315.09 627.61,1315.11 627.62,1315.14 627.629,1315.16 627.638,1315.19 627.647,1315.22 627.656,1315.24 627.666,1315.27 627.675,1315.29 627.684,1315.32 627.693,1315.35 627.702,1315.37 627.711,1315.4 627.721,1315.42 627.73,1315.45 627.739,1315.48 627.748,1315.5 627.757,1315.53 627.767,1315.55 627.776,1315.58 627.785,1315.6 627.794,1315.63 627.803,1315.66 627.813,1315.68 627.822,1315.71 627.831,1315.74 627.84,1315.76 627.849,1315.79 627.859,1315.81 627.868,1315.84 627.877,1315.87 627.886,1315.89 627.895,1315.92 627.904,1315.94 627.914,1315.97 627.923,1316 627.932,1316.02 627.941,1316.05 627.95,1316.07 627.96,1316.1 627.969,1316.13 627.978,1316.15 627.987,1316.18 627.996,1316.21 628.006,1316.23 628.015,1316.26 628.024,1316.28 628.033,1316.31 628.042,1316.34 628.051,1316.36 628.061,1316.39 628.07,1316.42 628.079,1316.44 628.088,1316.47 628.097,1316.49 628.107,1316.52 628.116,1316.55 628.125,1316.57 628.134,1316.6 628.143,1316.63 628.153,1316.65 628.162,1316.68 628.171,1316.7 628.18,1316.73 628.189,1316.76 628.199,1316.78 628.208,1316.81 628.217,1316.84 628.226,1316.86 628.235,1316.89 628.244,1316.92 628.254,1316.94 628.263,1316.97 628.272,1317 628.281,1317.02 628.29,1317.05 628.3,1317.08 628.309,1317.1 628.318,1317.13 628.327,1317.15 628.336,1317.18 628.346,1317.21 628.355,1317.23 628.364,1317.26 628.373,1317.29 628.382,1317.31 628.391,1317.34 628.401,1317.37 628.41,1317.39 628.419,1317.42 628.428,1317.45 628.437,1317.47 628.447,1317.5 628.456,1317.53 628.465,1317.55 628.474,1317.58 628.483,1317.61 628.493,1317.63 628.502,1317.66 628.511,1317.69 628.52,1317.71 628.529,1317.74 628.539,1317.77 628.548,1317.79 628.557,1317.82 628.566,1317.85 628.575,1317.87 628.584,1317.9 628.594,1317.93 628.603,1317.96 628.612,1317.98 628.621,1318.01 628.63,1318.04 628.64,1318.06 628.649,1318.09 628.658,1318.12 628.667,1318.14 628.676,1318.17 628.686,1318.2 628.695,1318.22 628.704,1318.25 628.713,1318.28 628.722,1318.3 628.731,1318.33 628.741,1318.36 628.75,1318.39 628.759,1318.41 628.768,1318.44 628.777,1318.47 628.787,1318.49 628.796,1318.52 628.805,1318.55 628.814,1318.57 628.823,1318.6 628.833,1318.63 628.842,1318.66 628.851,1318.68 628.86,1318.71 628.869,1318.74 628.879,1318.76 628.888,1318.79 628.897,1318.82 628.906,1318.85 628.915,1318.87 628.924,1318.9 628.934,1318.93 628.943,1318.95 628.952,1318.98 628.961,1319.01 628.97,1319.04 628.98,1319.06 628.989,1319.09 628.998,1319.12 629.007,1319.14 629.016,1319.17 629.026,1319.2 629.035,1319.23 629.044,1319.25 629.053,1319.28 629.062,1319.31 629.071,1319.34 629.081,1319.36 629.09,1319.39 629.099,1319.42 629.108,1319.45 629.117,1319.47 629.127,1319.5 629.136,1319.53 629.145,1319.55 629.154,1319.58 629.163,1319.61 629.173,1319.64 629.182,1319.66 629.191,1319.69 629.2,1319.72 629.209,1319.75 629.219,1319.77 629.228,1319.8 629.237,1319.83 629.246,1319.86 629.255,1319.88 629.264,1319.91 629.274,1319.94 629.283,1319.97 629.292,1319.99 629.301,1320.02 629.31,1320.05 629.32,1320.08 629.329,1320.1 629.338,1320.13 629.347,1320.16 629.356,1320.19 629.366,1320.21 629.375,1320.24 629.384,1320.27 629.393,1320.3 629.402,1320.33 629.411,1320.35 629.421,1320.38 629.43,1320.41 629.439,1320.44 629.448,1320.46 629.457,1320.49 629.467,1320.52 629.476,1320.55 629.485,1320.57 629.494,1320.6 629.503,1320.63 629.513,1320.66 629.522,1320.69 629.531,1320.71 629.54,1320.74 629.549,1320.77 629.559,1320.8 629.568,1320.82 629.577,1320.85 629.586,1320.88 629.595,1320.91 629.604,1320.94 629.614,1320.96 629.623,1320.99 629.632,1321.02 629.641,1321.05 629.65,1321.08 629.66,1321.1 629.669,1321.13 629.678,1321.16 629.687,1321.19 629.696,1321.22 629.706,1321.24 629.715,1321.27 629.724,1321.3 629.733,1321.33 629.742,1321.36 629.752,1321.38 629.761,1321.41 629.77,1321.44 629.779,1321.47 629.788,1321.5 629.797,1321.52 629.807,1321.55 629.816,1321.58 629.825,1321.61 629.834,1321.64 629.843,1321.66 629.853,1321.69 629.862,1321.72 629.871,1321.75 629.88,1321.78 629.889,1321.81 629.899,1321.83 629.908,1321.86 629.917,1321.89 629.926,1321.92 629.935,1321.95 629.944,1321.97 629.954,1322 629.963,1322.03 629.972,1322.06 629.981,1322.09 629.99,1322.12 630,1322.14 630.009,1322.17 630.018,1322.2 630.027,1322.23 630.036,1322.26 630.046,1322.29 630.055,1322.31 630.064,1322.34 630.073,1322.37 630.082,1322.4 630.092,1322.43 630.101,1322.46 630.11,1322.48 630.119,1322.51 630.128,1322.54 630.137,1322.57 630.147,1322.6 630.156,1322.63 630.165,1322.66 630.174,1322.68 630.183,1322.71 630.193,1322.74 630.202,1322.77 630.211,1322.8 630.22,1322.83 630.229,1322.86 630.239,1322.88 630.248,1322.91 630.257,1322.94 630.266,1322.97 630.275,1323 630.284,1323.03 630.294,1323.06 630.303,1323.08 630.312,1323.11 630.321,1323.14 630.33,1323.17 630.34,1323.2 630.349,1323.23 630.358,1323.26 630.367,1323.28 630.376,1323.31 630.386,1323.34 630.395,1323.37 630.404,1323.4 630.413,1323.43 630.422,1323.46 630.432,1323.49 630.441,1323.51 630.45,1323.54 630.459,1323.57 630.468,1323.6 630.477,1323.63 630.487,1323.66 630.496,1323.69 630.505,1323.72 630.514,1323.75 630.523,1323.77 630.533,1323.8 630.542,1323.83 630.551,1323.86 630.56,1323.89 630.569,1323.92 630.579,1323.95 630.588,1323.98 630.597,1324.01 630.606,1324.03 630.615,1324.06 630.624,1324.09 630.634,1324.12 630.643,1324.15 630.652,1324.18 630.661,1324.21 630.67,1324.24 630.68,1324.27 630.689,1324.3 630.698,1324.33 630.707,1324.35 630.716,1324.38 630.726,1324.41 630.735,1324.44 630.744,1324.47 630.753,1324.5 630.762,1324.53 630.772,1324.56 630.781,1324.59 630.79,1324.62 630.799,1324.65 630.808,1324.67 630.817,1324.7 630.827,1324.73 630.836,1324.76 630.845,1324.79 630.854,1324.82 630.863,1324.85 630.873,1324.88 630.882,1324.91 630.891,1324.94 630.9,1324.97 630.909,1325 630.919,1325.03 630.928,1325.06 630.937,1325.08 630.946,1325.11 630.955,1325.14 630.964,1325.17 630.974,1325.2 630.983,1325.23 630.992,1325.26 631.001,1325.29 631.01,1325.32 631.02,1325.35 631.029,1325.38 631.038,1325.41 631.047,1325.44 631.056,1325.47 631.066,1325.5 631.075,1325.53 631.084,1325.56 631.093,1325.59 631.102,1325.62 631.112,1325.64 631.121,1325.67 631.13,1325.7 631.139,1325.73 631.148,1325.76 631.157,1325.79 631.167,1325.82 631.176,1325.85 631.185,1325.88 631.194,1325.91 631.203,1325.94 631.213,1325.97 631.222,1326 631.231,1326.03 631.24,1326.06 631.249,1326.09 631.259,1326.12 631.268,1326.15 631.277,1326.18 631.286,1326.21 631.295,1326.24 631.304,1326.27 631.314,1326.3 631.323,1326.33 631.332,1326.36 631.341,1326.39 631.35,1326.42 631.36,1326.45 631.369,1326.48 631.378,1326.51 631.387,1326.54 631.396,1326.57 631.406,1326.6 631.415,1326.63 631.424,1326.66 631.433,1326.69 631.442,1326.72 631.452,1326.75 631.461,1326.78 631.47,1326.81 631.479,1326.84 631.488,1326.87 631.497,1326.9 631.507,1326.93 631.516,1326.96 631.525,1326.99 631.534,1327.02 631.543,1327.05 631.553,1327.08 631.562,1327.11 631.571,1327.14 631.58,1327.17 631.589,1327.2 631.599,1327.23 631.608,1327.26 631.617,1327.29 631.626,1327.32 631.635,1327.35 631.644,1327.38 631.654,1327.41 631.663,1327.44 631.672,1327.47 631.681,1327.5 631.69,1327.53 631.7,1327.56 631.709,1327.59 631.718,1327.62 631.727,1327.65 631.736,1327.68 631.746,1327.71 631.755,1327.74 631.764,1327.77 631.773,1327.8 631.782,1327.83 631.792,1327.86 631.801,1327.89 631.81,1327.92 631.819,1327.95 631.828,1327.98 631.837,1328.01 631.847,1328.04 631.856,1328.07 631.865,1328.1 631.874,1328.13 631.883,1328.17 631.893,1328.2 631.902,1328.23 631.911,1328.26 631.92,1328.29 631.929,1328.32 631.939,1328.35 631.948,1328.38 631.957,1328.41 631.966,1328.44 631.975,1328.47 631.984,1328.5 631.994,1328.53 632.003,1328.56 632.012,1328.59 632.021,1328.62 632.03,1328.65 632.04,1328.68 632.049,1328.72 632.058,1328.75 632.067,1328.78 632.076,1328.81 632.086,1328.84 632.095,1328.87 632.104,1328.9 632.113,1328.93 632.122,1328.96 632.132,1328.99 632.141,1329.02 632.15,1329.05 632.159,1329.08 632.168,1329.11 632.177,1329.15 632.187,1329.18 632.196,1329.21 632.205,1329.24 632.214,1329.27 632.223,1329.3 632.233,1329.33 632.242,1329.36 632.251,1329.39 632.26,1329.42 632.269,1329.45 632.279,1329.49 632.288,1329.52 632.297,1329.55 632.306,1329.58 632.315,1329.61 632.325,1329.64 632.334,1329.67 632.343,1329.7 632.352,1329.73 632.361,1329.76 632.37,1329.79 632.38,1329.83 632.389,1329.86 632.398,1329.89 632.407,1329.92 632.416,1329.95 632.426,1329.98 632.435,1330.01 632.444,1330.04 632.453,1330.07 632.462,1330.11 632.472,1330.14 632.481,1330.17 632.49,1330.2 632.499,1330.23 632.508,1330.26 632.517,1330.29 632.527,1330.32 632.536,1330.36 632.545,1330.39 632.554,1330.42 632.563,1330.45 632.573,1330.48 632.582,1330.51 632.591,1330.54 632.6,1330.57 632.609,1330.61 632.619,1330.64 632.628,1330.67 632.637,1330.7 632.646,1330.73 632.655,1330.76 632.665,1330.79 632.674,1330.83 632.683,1330.86 632.692,1330.89 632.701,1330.92 632.71,1330.95 632.72,1330.98 632.729,1331.01 632.738,1331.05 632.747,1331.08 632.756,1331.11 632.766,1331.14 632.775,1331.17 632.784,1331.2 632.793,1331.24 632.802,1331.27 632.812,1331.3 632.821,1331.33 632.83,1331.36 632.839,1331.39 632.848,1331.42 632.857,1331.46 632.867,1331.49 632.876,1331.52 632.885,1331.55 632.894,1331.58 632.903,1331.61 632.913,1331.65 632.922,1331.68 632.931,1331.71 632.94,1331.74 632.949,1331.77 632.959,1331.81 632.968,1331.84 632.977,1331.87 632.986,1331.9 632.995,1331.93 633.005,1331.96 633.014,1332 633.023,1332.03 633.032,1332.06 633.041,1332.09 633.05,1332.12 633.06,1332.16 633.069,1332.19 633.078,1332.22 633.087,1332.25 633.096,1332.28 633.106,1332.31 633.115,1332.35 633.124,1332.38 633.133,1332.41 633.142,1332.44 633.152,1332.47 633.161,1332.51 633.17,1332.54 633.179,1332.57 633.188,1332.6 633.197,1332.64 633.207,1332.67 633.216,1332.7 633.225,1332.73 633.234,1332.76 633.243,1332.8 633.253,1332.83 633.262,1332.86 633.271,1332.89 633.28,1332.92 633.289,1332.96 633.299,1332.99 633.308,1333.02 633.317,1333.05 633.326,1333.09 633.335,1333.12 633.345,1333.15 633.354,1333.18 633.363,1333.21 633.372,1333.25 633.381,1333.28 633.39,1333.31 633.4,1333.34 633.409,1333.38 633.418,1333.41 633.427,1333.44 633.436,1333.47 633.446,1333.51 633.455,1333.54 633.464,1333.57 633.473,1333.6 633.482,1333.63 633.492,1333.67 633.501,1333.7 633.51,1333.73 633.519,1333.76 633.528,1333.8 633.537,1333.83 633.547,1333.86 633.556,1333.89 633.565,1333.93 633.574,1333.96 633.583,1333.99 633.593,1334.02 633.602,1334.06 633.611,1334.09 633.62,1334.12 633.629,1334.16 633.639,1334.19 633.648,1334.22 633.657,1334.25 633.666,1334.29 633.675,1334.32 633.685,1334.35 633.694,1334.38 633.703,1334.42 633.712,1334.45 633.721,1334.48 633.73,1334.51 633.74,1334.55 633.749,1334.58 633.758,1334.61 633.767,1334.65 633.776,1334.68 633.786,1334.71 633.795,1334.74 633.804,1334.78 633.813,1334.81 633.822,1334.84 633.832,1334.88 633.841,1334.91 633.85,1334.94 633.859,1334.97 633.868,1335.01 633.877,1335.04 633.887,1335.07 633.896,1335.11 633.905,1335.14 633.914,1335.17 633.923,1335.21 633.933,1335.24 633.942,1335.27 633.951,1335.3 633.96,1335.34 633.969,1335.37 633.979,1335.4 633.988,1335.44 633.997,1335.47 634.006,1335.5 634.015,1335.54 634.025,1335.57 634.034,1335.6 634.043,1335.64 634.052,1335.67 634.061,1335.7 634.07,1335.73 634.08,1335.77 634.089,1335.8 634.098,1335.83 634.107,1335.87 634.116,1335.9 634.126,1335.93 634.135,1335.97 634.144,1336 634.153,1336.03 634.162,1336.07 634.172,1336.1 634.181,1336.13 634.19,1336.17 634.199,1336.2 634.208,1336.23 634.217,1336.27 634.227,1336.3 634.236,1336.33 634.245,1336.37 634.254,1336.4 634.263,1336.43 634.273,1336.47 634.282,1336.5 634.291,1336.53 634.3,1336.57 634.309,1336.6 634.319,1336.64 634.328,1336.67 634.337,1336.7 634.346,1336.74 634.355,1336.77 634.365,1336.8 634.374,1336.84 634.383,1336.87 634.392,1336.9 634.401,1336.94 634.41,1336.97 634.42,1337 634.429,1337.04 634.438,1337.07 634.447,1337.11 634.456,1337.14 634.466,1337.17 634.475,1337.21 634.484,1337.24 634.493,1337.27 634.502,1337.31 634.512,1337.34 634.521,1337.38 634.53,1337.41 634.539,1337.44 634.548,1337.48 634.557,1337.51 634.567,1337.54 634.576,1337.58 634.585,1337.61 634.594,1337.65 634.603,1337.68 634.613,1337.71 634.622,1337.75 634.631,1337.78 634.64,1337.82 634.649,1337.85 634.659,1337.88 634.668,1337.92 634.677,1337.95 634.686,1337.99 634.695,1338.02 634.705,1338.05 634.714,1338.09 634.723,1338.12 634.732,1338.16 634.741,1338.19 634.75,1338.22 634.76,1338.26 634.769,1338.29 634.778,1338.33 634.787,1338.36 634.796,1338.39 634.806,1338.43 634.815,1338.46 634.824,1338.5 634.833,1338.53 634.842,1338.57 634.852,1338.6 634.861,1338.63 634.87,1338.67 634.879,1338.7 634.888,1338.74 634.898,1338.77 634.907,1338.81 634.916,1338.84 634.925,1338.87 634.934,1338.91 634.943,1338.94 634.953,1338.98 634.962,1339.01 634.971,1339.05 634.98,1339.08 634.989,1339.12 634.999,1339.15 635.008,1339.18 635.017,1339.22 635.026,1339.25 635.035,1339.29 635.045,1339.32 635.054,1339.36 635.063,1339.39 635.072,1339.43 635.081,1339.46 635.09,1339.49 635.1,1339.53 635.109,1339.56 635.118,1339.6 635.127,1339.63 635.136,1339.67 635.146,1339.7 635.155,1339.74 635.164,1339.77 635.173,1339.81 635.182,1339.84 635.192,1339.88 635.201,1339.91 635.21,1339.94 635.219,1339.98 635.228,1340.01 635.238,1340.05 635.247,1340.08 635.256,1340.12 635.265,1340.15 635.274,1340.19 635.283,1340.22 635.293,1340.26 635.302,1340.29 635.311,1340.33 635.32,1340.36 635.329,1340.4 635.339,1340.43 635.348,1340.47 635.357,1340.5 635.366,1340.54 635.375,1340.57 635.385,1340.61 635.394,1340.64 635.403,1340.68 635.412,1340.71 635.421,1340.75 635.43,1340.78 635.44,1340.82 635.449,1340.85 635.458,1340.89 635.467,1340.92 635.476,1340.96 635.486,1340.99 635.495,1341.03 635.504,1341.06 635.513,1341.1 635.522,1341.13 635.532,1341.17 635.541,1341.2 635.55,1341.24 635.559,1341.27 635.568,1341.31 635.578,1341.34 635.587,1341.38 635.596,1341.41 635.605,1341.45 635.614,1341.48 635.623,1341.52 635.633,1341.56 635.642,1341.59 635.651,1341.63 635.66,1341.66 635.669,1341.7 635.679,1341.73 635.688,1341.77 635.697,1341.8 635.706,1341.84 635.715,1341.87 635.725,1341.91 635.734,1341.94 635.743,1341.98 635.752,1342.02 635.761,1342.05 635.77,1342.09 635.78,1342.12 635.789,1342.16 635.798,1342.19 635.807,1342.23 635.816,1342.26 635.826,1342.3 635.835,1342.34 635.844,1342.37 635.853,1342.41 635.862,1342.44 635.872,1342.48 635.881,1342.51 635.89,1342.55 635.899,1342.58 635.908,1342.62 635.918,1342.66 635.927,1342.69 635.936,1342.73 635.945,1342.76 635.954,1342.8 635.963,1342.83 635.973,1342.87 635.982,1342.91 635.991,1342.94 636,1342.98 636.009,1343.01 636.019,1343.05 636.028,1343.09 636.037,1343.12 636.046,1343.16 636.055,1343.19 636.065,1343.23 636.074,1343.26 636.083,1343.3 636.092,1343.34 636.101,1343.37 636.11,1343.41 636.12,1343.44 636.129,1343.48 636.138,1343.52 636.147,1343.55 636.156,1343.59 636.166,1343.62 636.175,1343.66 636.184,1343.7 636.193,1343.73 636.202,1343.77 636.212,1343.81 636.221,1343.84 636.23,1343.88 636.239,1343.91 636.248,1343.95 636.258,1343.99 636.267,1344.02 636.276,1344.06 636.285,1344.09 636.294,1344.13 636.303,1344.17 636.313,1344.2 636.322,1344.24 636.331,1344.28 636.34,1344.31 636.349,1344.35 636.359,1344.39 636.368,1344.42 636.377,1344.46 636.386,1344.49 636.395,1344.53 636.405,1344.57 636.414,1344.6 636.423,1344.64 636.432,1344.68 636.441,1344.71 636.45,1344.75 636.46,1344.79 636.469,1344.82 636.478,1344.86 636.487,1344.9 636.496,1344.93 636.506,1344.97 636.515,1345 636.524,1345.04 636.533,1345.08 636.542,1345.11 636.552,1345.15 636.561,1345.19 636.57,1345.22 636.579,1345.26 636.588,1345.3 636.598,1345.33 636.607,1345.37 636.616,1345.41 636.625,1345.44 636.634,1345.48 636.643,1345.52 636.653,1345.55 636.662,1345.59 636.671,1345.63 636.68,1345.67 636.689,1345.7 636.699,1345.74 636.708,1345.78 636.717,1345.81 636.726,1345.85 636.735,1345.89 636.745,1345.92 636.754,1345.96 636.763,1346 636.772,1346.03 636.781,1346.07 636.79,1346.11 636.8,1346.14 636.809,1346.18 636.818,1346.22 636.827,1346.26 636.836,1346.29 636.846,1346.33 636.855,1346.37 636.864,1346.4 636.873,1346.44 636.882,1346.48 636.892,1346.52 636.901,1346.55 636.91,1346.59 636.919,1346.63 636.928,1346.66 636.938,1346.7 636.947,1346.74 636.956,1346.78 636.965,1346.81 636.974,1346.85 636.983,1346.89 636.993,1346.92 637.002,1346.96 637.011,1347 637.02,1347.04 637.029,1347.07 637.039,1347.11 637.048,1347.15 637.057,1347.19 637.066,1347.22 637.075,1347.26 637.085,1347.3 637.094,1347.33 637.103,1347.37 637.112,1347.41 637.121,1347.45 637.131,1347.48 637.14,1347.52 637.149,1347.56 637.158,1347.6 637.167,1347.63 637.176,1347.67 637.186,1347.71 637.195,1347.75 637.204,1347.78 637.213,1347.82 637.222,1347.86 637.232,1347.9 637.241,1347.94 637.25,1347.97 637.259,1348.01 637.268,1348.05 637.278,1348.09 637.287,1348.12 637.296,1348.16 637.305,1348.2 637.314,1348.24 637.323,1348.27 637.333,1348.31 637.342,1348.35 637.351,1348.39 637.36,1348.43 637.369,1348.46 637.379,1348.5 637.388,1348.54 637.397,1348.58 637.406,1348.61 637.415,1348.65 637.425,1348.69 637.434,1348.73 637.443,1348.77 637.452,1348.8 637.461,1348.84 637.471,1348.88 637.48,1348.92 637.489,1348.96 637.498,1348.99 637.507,1349.03 637.516,1349.07 637.526,1349.11 637.535,1349.15 637.544,1349.18 637.553,1349.22 637.562,1349.26 637.572,1349.3 637.581,1349.34 637.59,1349.38 637.599,1349.41 637.608,1349.45 637.618,1349.49 637.627,1349.53 637.636,1349.57 637.645,1349.6 637.654,1349.64 637.663,1349.68 637.673,1349.72 637.682,1349.76 637.691,1349.8 637.7,1349.83 637.709,1349.87 637.719,1349.91 637.728,1349.95 637.737,1349.99 637.746,1350.03 637.755,1350.06 637.765,1350.1 637.774,1350.14 637.783,1350.18 637.792,1350.22 637.801,1350.26 637.811,1350.3 637.82,1350.33 637.829,1350.37 637.838,1350.41 637.847,1350.45 637.856,1350.49 637.866,1350.53 637.875,1350.56 637.884,1350.6 637.893,1350.64 637.902,1350.68 637.912,1350.72 637.921,1350.76 637.93,1350.8 637.939,1350.84 637.948,1350.87 637.958,1350.91 637.967,1350.95 637.976,1350.99 637.985,1351.03 637.994,1351.07 638.003,1351.11 638.013,1351.15 638.022,1351.18 638.031,1351.22 638.04,1351.26 638.049,1351.3 638.059,1351.34 638.068,1351.38 638.077,1351.42 638.086,1351.46 638.095,1351.5 638.105,1351.53 638.114,1351.57 638.123,1351.61 638.132,1351.65 638.141,1351.69 638.151,1351.73 638.16,1351.77 638.169,1351.81 638.178,1351.85 638.187,1351.89 638.196,1351.92 638.206,1351.96 638.215,1352 638.224,1352.04 638.233,1352.08 638.242,1352.12 638.252,1352.16 638.261,1352.2 638.27,1352.24 638.279,1352.28 638.288,1352.32 638.298,1352.36 638.307,1352.39 638.316,1352.43 638.325,1352.47 638.334,1352.51 638.343,1352.55 638.353,1352.59 638.362,1352.63 638.371,1352.67 638.38,1352.71 638.389,1352.75 638.399,1352.79 638.408,1352.83 638.417,1352.87 638.426,1352.91 638.435,1352.95 638.445,1352.99 638.454,1353.02 638.463,1353.06 638.472,1353.1 638.481,1353.14 638.491,1353.18 638.5,1353.22 638.509,1353.26 638.518,1353.3 638.527,1353.34 638.536,1353.38 638.546,1353.42 638.555,1353.46 638.564,1353.5 638.573,1353.54 638.582,1353.58 638.592,1353.62 638.601,1353.66 638.61,1353.7 638.619,1353.74 638.628,1353.78 638.638,1353.82 638.647,1353.86 638.656,1353.9 638.665,1353.94 638.674,1353.98 638.683,1354.02 638.693,1354.06 638.702,1354.1 638.711,1354.14 638.72,1354.18 638.729,1354.22 638.739,1354.26 638.748,1354.3 638.757,1354.34 638.766,1354.38 638.775,1354.42 638.785,1354.46 638.794,1354.5 638.803,1354.54 638.812,1354.58 638.821,1354.62 638.831,1354.66 638.84,1354.7 638.849,1354.74 638.858,1354.78 638.867,1354.82 638.876,1354.86 638.886,1354.9 638.895,1354.94 638.904,1354.98 638.913,1355.02 638.922,1355.06 638.932,1355.1 638.941,1355.14 638.95,1355.18 638.959,1355.22 638.968,1355.26 638.978,1355.3 638.987,1355.34 638.996,1355.38 639.005,1355.42 639.014,1355.46 639.023,1355.5 639.033,1355.54 639.042,1355.58 639.051,1355.62 639.06,1355.66 639.069,1355.7 639.079,1355.74 639.088,1355.78 639.097,1355.82 639.106,1355.87 639.115,1355.91 639.125,1355.95 639.134,1355.99 639.143,1356.03 639.152,1356.07 639.161,1356.11 639.171,1356.15 639.18,1356.19 639.189,1356.23 639.198,1356.27 639.207,1356.31 639.216,1356.35 639.226,1356.39 639.235,1356.43 639.244,1356.47 639.253,1356.52 639.262,1356.56 639.272,1356.6 639.281,1356.64 639.29,1356.68 639.299,1356.72 639.308,1356.76 639.318,1356.8 639.327,1356.84 639.336,1356.88 639.345,1356.92 639.354,1356.96 639.363,1357.01 639.373,1357.05 639.382,1357.09 639.391,1357.13 639.4,1357.17 639.409,1357.21 639.419,1357.25 639.428,1357.29 639.437,1357.33 639.446,1357.37 639.455,1357.42 639.465,1357.46 639.474,1357.5 639.483,1357.54 639.492,1357.58 639.501,1357.62 639.511,1357.66 639.52,1357.7 639.529,1357.75 639.538,1357.79 639.547,1357.83 639.556,1357.87 639.566,1357.91 639.575,1357.95 639.584,1357.99 639.593,1358.03 639.602,1358.08 639.612,1358.12 639.621,1358.16 639.63,1358.2 639.639,1358.24 639.648,1358.28 639.658,1358.32 639.667,1358.37 639.676,1358.41 639.685,1358.45 639.694,1358.49 639.704,1358.53 639.713,1358.57 639.722,1358.61 639.731,1358.66 639.74,1358.7 639.749,1358.74 639.759,1358.78 639.768,1358.82 639.777,1358.86 639.786,1358.91 639.795,1358.95 639.805,1358.99 639.814,1359.03 639.823,1359.07 639.832,1359.11 639.841,1359.16 639.851,1359.2 639.86,1359.24 639.869,1359.28 639.878,1359.32 639.887,1359.36 639.896,1359.41 639.906,1359.45 639.915,1359.49 639.924,1359.53 639.933,1359.57 639.942,1359.62 639.952,1359.66 639.961,1359.7 639.97,1359.74 639.979,1359.78 639.988,1359.82 639.998,1359.87 640.007,1359.91 640.016,1359.95 640.025,1359.99 640.034,1360.03 640.044,1360.08 640.053,1360.12 640.062,1360.16 640.071,1360.2 640.08,1360.25 640.089,1360.29 640.099,1360.33 640.108,1360.37 640.117,1360.41 640.126,1360.46 640.135,1360.5 640.145,1360.54 640.154,1360.58 640.163,1360.63 640.172,1360.67 640.181,1360.71 640.191,1360.75 640.2,1360.79 640.209,1360.84 640.218,1360.88 640.227,1360.92 640.236,1360.96 640.246,1361.01 640.255,1361.05 640.264,1361.09 640.273,1361.13 640.282,1361.18 640.292,1361.22 640.301,1361.26 640.31,1361.3 640.319,1361.35 640.328,1361.39 640.338,1361.43 640.347,1361.47 640.356,1361.52 640.365,1361.56 640.374,1361.6 640.384,1361.64 640.393,1361.69 640.402,1361.73 640.411,1361.77 640.42,1361.81 640.429,1361.86 640.439,1361.9 640.448,1361.94 640.457,1361.99 640.466,1362.03 640.475,1362.07 640.485,1362.11 640.494,1362.16 640.503,1362.2 640.512,1362.24 640.521,1362.29 640.531,1362.33 640.54,1362.37 640.549,1362.41 640.558,1362.46 640.567,1362.5 640.576,1362.54 640.586,1362.59 640.595,1362.63 640.604,1362.67 640.613,1362.71 640.622,1362.76 640.632,1362.8 640.641,1362.84 640.65,1362.89 640.659,1362.93 640.668,1362.97 640.678,1363.02 640.687,1363.06 640.696,1363.1 640.705,1363.15 640.714,1363.19 640.724,1363.23 640.733,1363.28 640.742,1363.32 640.751,1363.36 640.76,1363.41 640.769,1363.45 640.779,1363.49 640.788,1363.54 640.797,1363.58 640.806,1363.62 640.815,1363.67 640.825,1363.71 640.834,1363.75 640.843,1363.8 640.852,1363.84 640.861,1363.88 640.871,1363.93 640.88,1363.97 640.889,1364.01 640.898,1364.06 640.907,1364.1 640.916,1364.14 640.926,1364.19 640.935,1364.23 640.944,1364.27 640.953,1364.32 640.962,1364.36 640.972,1364.41 640.981,1364.45 640.99,1364.49 640.999,1364.54 641.008,1364.58 641.018,1364.62 641.027,1364.67 641.036,1364.71 641.045,1364.75 641.054,1364.8 641.064,1364.84 641.073,1364.89 641.082,1364.93 641.091,1364.97 641.1,1365.02 641.109,1365.06 641.119,1365.11 641.128,1365.15 641.137,1365.19 641.146,1365.24 641.155,1365.28 641.165,1365.33 641.174,1365.37 641.183,1365.41 641.192,1365.46 641.201,1365.5 641.211,1365.55 641.22,1365.59 641.229,1365.63 641.238,1365.68 641.247,1365.72 641.256,1365.77 641.266,1365.81 641.275,1365.85 641.284,1365.9 641.293,1365.94 641.302,1365.99 641.312,1366.03 641.321,1366.08 641.33,1366.12 641.339,1366.16 641.348,1366.21 641.358,1366.25 641.367,1366.3 641.376,1366.34 641.385,1366.39 641.394,1366.43 641.404,1366.47 641.413,1366.52 641.422,1366.56 641.431,1366.61 641.44,1366.65 641.449,1366.7 641.459,1366.74 641.468,1366.79 641.477,1366.83 641.486,1366.87 641.495,1366.92 641.505,1366.96 641.514,1367.01 641.523,1367.05 641.532,1367.1 641.541,1367.14 641.551,1367.19 641.56,1367.23 641.569,1367.28 641.578,1367.32 641.587,1367.37 641.596,1367.41 641.606,1367.45 641.615,1367.5 641.624,1367.54 641.633,1367.59 641.642,1367.63 641.652,1367.68 641.661,1367.72 641.67,1367.77 641.679,1367.81 641.688,1367.86 641.698,1367.9 641.707,1367.95 641.716,1367.99 641.725,1368.04 641.734,1368.08 641.744,1368.13 641.753,1368.17 641.762,1368.22 641.771,1368.26 641.78,1368.31 641.789,1368.35 641.799,1368.4 641.808,1368.44 641.817,1368.49 641.826,1368.53 641.835,1368.58 641.845,1368.62 641.854,1368.67 641.863,1368.71 641.872,1368.76 641.881,1368.81 641.891,1368.85 641.9,1368.9 641.909,1368.94 641.918,1368.99 641.927,1369.03 641.936,1369.08 641.946,1369.12 641.955,1369.17 641.964,1369.21 641.973,1369.26 641.982,1369.3 641.992,1369.35 642.001,1369.39 642.01,1369.44 642.019,1369.49 642.028,1369.53 642.038,1369.58 642.047,1369.62 642.056,1369.67 642.065,1369.71 642.074,1369.76 642.084,1369.8 642.093,1369.85 642.102,1369.9 642.111,1369.94 642.12,1369.99 642.129,1370.03 642.139,1370.08 642.148,1370.12 642.157,1370.17 642.166,1370.22 642.175,1370.26 642.185,1370.31 642.194,1370.35 642.203,1370.4 642.212,1370.44 642.221,1370.49 642.231,1370.54 642.24,1370.58 642.249,1370.63 642.258,1370.67 642.267,1370.72 642.277,1370.77 642.286,1370.81 642.295,1370.86 642.304,1370.9 642.313,1370.95 642.322,1371 642.332,1371.04 642.341,1371.09 642.35,1371.13 642.359,1371.18 642.368,1371.23 642.378,1371.27 642.387,1371.32 642.396,1371.37 642.405,1371.41 642.414,1371.46 642.424,1371.5 642.433,1371.55 642.442,1371.6 642.451,1371.64 642.46,1371.69 642.469,1371.74 642.479,1371.78 642.488,1371.83 642.497,1371.87 642.506,1371.92 642.515,1371.97 642.525,1372.01 642.534,1372.06 642.543,1372.11 642.552,1372.15 642.561,1372.2 642.571,1372.25 642.58,1372.29 642.589,1372.34 642.598,1372.39 642.607,1372.43 642.617,1372.48 642.626,1372.53 642.635,1372.57 642.644,1372.62 642.653,1372.67 642.662,1372.71 642.672,1372.76 642.681,1372.81 642.69,1372.85 642.699,1372.9 642.708,1372.95 642.718,1372.99 642.727,1373.04 642.736,1373.09 642.745,1373.13 642.754,1373.18 642.764,1373.23 642.773,1373.27 642.782,1373.32 642.791,1373.37 642.8,1373.41 642.809,1373.46 642.819,1373.51 642.828,1373.55 642.837,1373.6 642.846,1373.65 642.855,1373.7 642.865,1373.74 642.874,1373.79 642.883,1373.84 642.892,1373.88 642.901,1373.93 642.911,1373.98 642.92,1374.03 642.929,1374.07 642.938,1374.12 642.947,1374.17 642.957,1374.21 642.966,1374.26 642.975,1374.31 642.984,1374.36 642.993,1374.4 643.002,1374.45 643.012,1374.5 643.021,1374.54 643.03,1374.59 643.039,1374.64 643.048,1374.69 643.058,1374.73 643.067,1374.78 643.076,1374.83 643.085,1374.88 643.094,1374.92 643.104,1374.97 643.113,1375.02 643.122,1375.07 643.131,1375.11 643.14,1375.16 643.149,1375.21 643.159,1375.26 643.168,1375.3 643.177,1375.35 643.186,1375.4 643.195,1375.45 643.205,1375.5 643.214,1375.54 643.223,1375.59 643.232,1375.64 643.241,1375.69 643.251,1375.73 643.26,1375.78 643.269,1375.83 643.278,1375.88 643.287,1375.93 643.297,1375.97 643.306,1376.02 643.315,1376.07 643.324,1376.12 643.333,1376.16 643.342,1376.21 643.352,1376.26 643.361,1376.31 643.37,1376.36 643.379,1376.4 643.388,1376.45 643.398,1376.5 643.407,1376.55 643.416,1376.6 643.425,1376.64 643.434,1376.69 643.444,1376.74 643.453,1376.79 643.462,1376.84 643.471,1376.89 643.48,1376.93 643.489,1376.98 643.499,1377.03 643.508,1377.08 643.517,1377.13 643.526,1377.17 643.535,1377.22 643.545,1377.27 643.554,1377.32 643.563,1377.37 643.572,1377.42 643.581,1377.47 643.591,1377.51 643.6,1377.56 643.609,1377.61 643.618,1377.66 643.627,1377.71 643.637,1377.76 643.646,1377.8 643.655,1377.85 643.664,1377.9 643.673,1377.95 643.682,1378 643.692,1378.05 643.701,1378.1 643.71,1378.14 643.719,1378.19 643.728,1378.24 643.738,1378.29 643.747,1378.34 643.756,1378.39 643.765,1378.44 643.774,1378.49 643.784,1378.53 643.793,1378.58 643.802,1378.63 643.811,1378.68 643.82,1378.73 643.829,1378.78 643.839,1378.83 643.848,1378.88 643.857,1378.93 643.866,1378.97 643.875,1379.02 643.885,1379.07 643.894,1379.12 643.903,1379.17 643.912,1379.22 643.921,1379.27 643.931,1379.32 643.94,1379.37 643.949,1379.42 643.958,1379.46 643.967,1379.51 643.977,1379.56 643.986,1379.61 643.995,1379.66 644.004,1379.71 644.013,1379.76 644.022,1379.81 644.032,1379.86 644.041,1379.91 644.05,1379.96 644.059,1380.01 644.068,1380.06 644.078,1380.1 644.087,1380.15 644.096,1380.2 644.105,1380.25 644.114,1380.3 644.124,1380.35 644.133,1380.4 644.142,1380.45 644.151,1380.5 644.16,1380.55 644.169,1380.6 644.179,1380.65 644.188,1380.7 644.197,1380.75 644.206,1380.8 644.215,1380.85 644.225,1380.9 644.234,1380.95 644.243,1381 644.252,1381.05 644.261,1381.1 644.271,1381.15 644.28,1381.19 644.289,1381.24 644.298,1381.29 644.307,1381.34 644.317,1381.39 644.326,1381.44 644.335,1381.49 644.344,1381.54 644.353,1381.59 644.362,1381.64 644.372,1381.69 644.381,1381.74 644.39,1381.79 644.399,1381.84 644.408,1381.89 644.418,1381.94 644.427,1381.99 644.436,1382.04 644.445,1382.09 644.454,1382.14 644.464,1382.19 644.473,1382.24 644.482,1382.29 644.491,1382.34 644.5,1382.39 644.509,1382.44 644.519,1382.49 644.528,1382.54 644.537,1382.6 644.546,1382.65 644.555,1382.7 644.565,1382.75 644.574,1382.8 644.583,1382.85 644.592,1382.9 644.601,1382.95 644.611,1383 644.62,1383.05 644.629,1383.1 644.638,1383.15 644.647,1383.2 644.657,1383.25 644.666,1383.3 644.675,1383.35 644.684,1383.4 644.693,1383.45 644.702,1383.5 644.712,1383.55 644.721,1383.6 644.73,1383.65 644.739,1383.71 644.748,1383.76 644.758,1383.81 644.767,1383.86 644.776,1383.91 644.785,1383.96 644.794,1384.01 644.804,1384.06 644.813,1384.11 644.822,1384.16 644.831,1384.21 644.84,1384.26 644.85,1384.31 644.859,1384.37 644.868,1384.42 644.877,1384.47 644.886,1384.52 644.895,1384.57 644.905,1384.62 644.914,1384.67 644.923,1384.72 644.932,1384.77 644.941,1384.82 644.951,1384.88 644.96,1384.93 644.969,1384.98 644.978,1385.03 644.987,1385.08 644.997,1385.13 645.006,1385.18 645.015,1385.23 645.024,1385.28 645.033,1385.34 645.042,1385.39 645.052,1385.44 645.061,1385.49 645.07,1385.54 645.079,1385.59 645.088,1385.64 645.098,1385.7 645.107,1385.75 645.116,1385.8 645.125,1385.85 645.134,1385.9 645.144,1385.95 645.153,1386 645.162,1386.06 645.171,1386.11 645.18,1386.16 645.19,1386.21 645.199,1386.26 645.208,1386.31 645.217,1386.36 645.226,1386.42 645.235,1386.47 645.245,1386.52 645.254,1386.57 645.263,1386.62 645.272,1386.67 645.281,1386.73 645.291,1386.78 645.3,1386.83 645.309,1386.88 645.318,1386.93 645.327,1386.99 645.337,1387.04 645.346,1387.09 645.355,1387.14 645.364,1387.19 645.373,1387.25 645.382,1387.3 645.392,1387.35 645.401,1387.4 645.41,1387.45 645.419,1387.51 645.428,1387.56 645.438,1387.61 645.447,1387.66 645.456,1387.71 645.465,1387.77 645.474,1387.82 645.484,1387.87 645.493,1387.92 645.502,1387.97 645.511,1388.03 645.52,1388.08 645.53,1388.13 645.539,1388.18 645.548,1388.24 645.557,1388.29 645.566,1388.34 645.575,1388.39 645.585,1388.44 645.594,1388.5 645.603,1388.55 645.612,1388.6 645.621,1388.65 645.631,1388.71 645.64,1388.76 645.649,1388.81 645.658,1388.86 645.667,1388.92 645.677,1388.97 645.686,1389.02 645.695,1389.07 645.704,1389.13 645.713,1389.18 645.722,1389.23 645.732,1389.29 645.741,1389.34 645.75,1389.39 645.759,1389.44 645.768,1389.5 645.778,1389.55 645.787,1389.6 645.796,1389.65 645.805,1389.71 645.814,1389.76 645.824,1389.81 645.833,1389.87 645.842,1389.92 645.851,1389.97 645.86,1390.02 645.87,1390.08 645.879,1390.13 645.888,1390.18 645.897,1390.24 645.906,1390.29 645.915,1390.34 645.925,1390.4 645.934,1390.45 645.943,1390.5 645.952,1390.56 645.961,1390.61 645.971,1390.66 645.98,1390.71 645.989,1390.77 645.998,1390.82 646.007,1390.87 646.017,1390.93 646.026,1390.98 646.035,1391.03 646.044,1391.09 646.053,1391.14 646.062,1391.19 646.072,1391.25 646.081,1391.3 646.09,1391.35 646.099,1391.41 646.108,1391.46 646.118,1391.51 646.127,1391.57 646.136,1391.62 646.145,1391.68 646.154,1391.73 646.164,1391.78 646.173,1391.84 646.182,1391.89 646.191,1391.94 646.2,1392 646.21,1392.05 646.219,1392.1 646.228,1392.16 646.237,1392.21 646.246,1392.27 646.255,1392.32 646.265,1392.37 646.274,1392.43 646.283,1392.48 646.292,1392.53 646.301,1392.59 646.311,1392.64 646.32,1392.7 646.329,1392.75 646.338,1392.8 646.347,1392.86 646.357,1392.91 646.366,1392.97 646.375,1393.02 646.384,1393.07 646.393,1393.13 646.402,1393.18 646.412,1393.24 646.421,1393.29 646.43,1393.34 646.439,1393.4 646.448,1393.45 646.458,1393.51 646.467,1393.56 646.476,1393.62 646.485,1393.67 646.494,1393.72 646.504,1393.78 646.513,1393.83 646.522,1393.89 646.531,1393.94 646.54,1394 646.55,1394.05 646.559,1394.1 646.568,1394.16 646.577,1394.21 646.586,1394.27 646.595,1394.32 646.605,1394.38 646.614,1394.43 646.623,1394.49 646.632,1394.54 646.641,1394.59 646.651,1394.65 646.66,1394.7 646.669,1394.76 646.678,1394.81 646.687,1394.87 646.697,1394.92 646.706,1394.98 646.715,1395.03 646.724,1395.09 646.733,1395.14 646.742,1395.2 646.752,1395.25 646.761,1395.31 646.77,1395.36 646.779,1395.42 646.788,1395.47 646.798,1395.53 646.807,1395.58 646.816,1395.64 646.825,1395.69 646.834,1395.75 646.844,1395.8 646.853,1395.86 646.862,1395.91 646.871,1395.97 646.88,1396.02 646.89,1396.08 646.899,1396.13 646.908,1396.19 646.917,1396.24 646.926,1396.3 646.935,1396.35 646.945,1396.41 646.954,1396.46 646.963,1396.52 646.972,1396.57 646.981,1396.63 646.991,1396.68 647,1396.74 647.009,1396.79 647.018,1396.85 647.027,1396.9 647.037,1396.96 647.046,1397.02 647.055,1397.07 647.064,1397.13 647.073,1397.18 647.083,1397.24 647.092,1397.29 647.101,1397.35 647.11,1397.4 647.119,1397.46 647.128,1397.52 647.138,1397.57 647.147,1397.63 647.156,1397.68 647.165,1397.74 647.174,1397.79 647.184,1397.85 647.193,1397.91 647.202,1397.96 647.211,1398.02 647.22,1398.07 647.23,1398.13 647.239,1398.18 647.248,1398.24 647.257,1398.3 647.266,1398.35 647.275,1398.41 647.285,1398.46 647.294,1398.52 647.303,1398.58 647.312,1398.63 647.321,1398.69 647.331,1398.74 647.34,1398.8 647.349,1398.86 647.358,1398.91 647.367,1398.97 647.377,1399.03 647.386,1399.08 647.395,1399.14 647.404,1399.19 647.413,1399.25 647.423,1399.31 647.432,1399.36 647.441,1399.42 647.45,1399.48 647.459,1399.53 647.468,1399.59 647.478,1399.64 647.487,1399.7 647.496,1399.76 647.505,1399.81 647.514,1399.87 647.524,1399.93 647.533,1399.98 647.542,1400.04 647.551,1400.1 647.56,1400.15 647.57,1400.21 647.579,1400.27 647.588,1400.32 647.597,1400.38 647.606,1400.44 647.615,1400.49 647.625,1400.55 647.634,1400.61 647.643,1400.66 647.652,1400.72 647.661,1400.78 647.671,1400.83 647.68,1400.89 647.689,1400.95 647.698,1401 647.707,1401.06 647.717,1401.12 647.726,1401.17 647.735,1401.23 647.744,1401.29 647.753,1401.35 647.763,1401.4 647.772,1401.46 647.781,1401.52 647.79,1401.57 647.799,1401.63 647.808,1401.69 647.818,1401.75 647.827,1401.8 647.836,1401.86 647.845,1401.92 647.854,1401.97 647.864,1402.03 647.873,1402.09 647.882,1402.15 647.891,1402.2 647.9,1402.26 647.91,1402.32 647.919,1402.38 647.928,1402.43 647.937,1402.49 647.946,1402.55 647.955,1402.6 647.965,1402.66 647.974,1402.72 647.983,1402.78 647.992,1402.83 648.001,1402.89 648.011,1402.95 648.02,1403.01 648.029,1403.07 648.038,1403.12 648.047,1403.18 648.057,1403.24 648.066,1403.3 648.075,1403.35 648.084,1403.41 648.093,1403.47 648.103,1403.53 648.112,1403.58 648.121,1403.64 648.13,1403.7 648.139,1403.76 648.148,1403.82 648.158,1403.87 648.167,1403.93 648.176,1403.99 648.185,1404.05 648.194,1404.11 648.204,1404.16 648.213,1404.22 648.222,1404.28 648.231,1404.34 648.24,1404.4 648.25,1404.45 648.259,1404.51 648.268,1404.57 648.277,1404.63 648.286,1404.69 648.295,1404.74 648.305,1404.8 648.314,1404.86 648.323,1404.92 648.332,1404.98 648.341,1405.04 648.351,1405.09 648.36,1405.15 648.369,1405.21 648.378,1405.27 648.387,1405.33 648.397,1405.39 648.406,1405.44 648.415,1405.5 648.424,1405.56 648.433,1405.62 648.443,1405.68 648.452,1405.74 648.461,1405.8 648.47,1405.85 648.479,1405.91 648.488,1405.97 648.498,1406.03 648.507,1406.09 648.516,1406.15 648.525,1406.21 648.534,1406.27 648.544,1406.32 648.553,1406.38 648.562,1406.44 648.571,1406.5 648.58,1406.56 648.59,1406.62 648.599,1406.68 648.608,1406.74 648.617,1406.8 648.626,1406.85 648.635,1406.88 648.645,1406.88 648.654,1406.88 648.663,1406.88 648.672,1406.88 648.681,1406.88 648.691,1406.88 648.7,1406.88 648.709,1406.88 648.718,1406.88 648.727,1406.88 648.737,1406.88 648.746,1406.88 648.755,1406.88 648.764,1406.88 648.773,1406.88 648.783,1406.88 648.792,1406.88 648.801,1406.88 648.81,1406.88 648.819,1406.88 648.828,1406.88 648.838,1406.88 648.847,1406.88 648.856,1406.88 648.865,1406.88 648.874,1406.88 648.884,1406.88 648.893,1406.88 648.902,1406.88 648.911,1406.88 648.92,1406.88 648.93,1406.88 648.939,1406.88 648.948,1406.88 648.957,1406.88 648.966,1406.88 648.975,1406.88 648.985,1406.88 648.994,1406.88 649.003,1406.88 649.012,1406.88 649.021,1406.88 649.031,1406.88 649.04,1406.88 649.049,1406.88 649.058,1406.88 649.067,1406.88 649.077,1406.88 649.086,1406.88 649.095,1406.88 649.104,1406.88 649.113,1406.88 649.123,1406.88 649.132,1406.88 649.141,1406.88 649.15,1406.88 649.159,1406.88 649.168,1406.88 649.178,1406.88 649.187,1406.88 649.196,1406.88 649.205,1406.88 649.214,1406.88 649.224,1406.88 649.233,1406.88 649.242,1406.88 649.251,1406.88 649.26,1406.88 649.27,1406.88 649.279,1406.88 649.288,1406.88 649.297,1406.88 649.306,1406.88 649.315,1406.88 649.325,1406.88 649.334,1406.88 649.343,1406.88 649.352,1406.88 649.361,1406.88 649.371,1406.88 649.38,1406.88 649.389,1406.88 649.398,1406.88 649.407,1406.88 649.417,1406.88 649.426,1406.88 649.435,1406.88 649.444,1406.88 649.453,1406.88 649.463,1406.88 649.472,1406.88 649.481,1406.88 649.49,1406.88 649.499,1406.88 649.508,1406.88 649.518,1406.88 649.527,1406.88 649.536,1406.88 649.545,1406.88 649.554,1406.88 649.564,1406.88 649.573,1406.88 649.582,1406.88 649.591,1406.88 649.6,1406.88 649.61,1406.88 649.619,1406.88 649.628,1406.88 649.637,1406.88 649.646,1406.88 649.656,1406.88 649.665,1406.88 649.674,1406.88 649.683,1406.88 649.692,1406.88 649.701,1406.88 649.711,1406.88 649.72,1406.88 649.729,1406.88 649.738,1406.88 649.747,1406.88 649.757,1406.88 649.766,1406.88 649.775,1406.88 649.784,1406.88 649.793,1406.88 649.803,1406.88 649.812,1406.88 649.821,1406.88 649.83,1406.88 649.839,1406.88 649.848,1406.88 649.858,1406.88 649.867,1406.88 649.876,1406.88 649.885,1406.88 649.894,1406.88 649.904,1406.88 649.913,1406.88 649.922,1406.88 649.931,1406.88 649.94,1406.88 649.95,1406.88 649.959,1406.88 649.968,1406.88 649.977,1406.88 649.986,1406.88 649.996,1406.88 650.005,1406.88 650.014,1406.88 650.023,1406.88 650.032,1406.88 650.041,1406.88 650.051,1406.88 650.06,1406.88 650.069,1406.88 650.078,1406.88 650.087,1406.88 650.097,1406.88 650.106,1406.88 650.115,1406.88 650.124,1406.88 650.133,1406.88 650.143,1406.88 650.152,1406.88 650.161,1406.88 650.17,1406.88 650.179,1406.88 650.188,1406.88 650.198,1406.88 650.207,1406.88 650.216,1406.88 650.225,1406.88 650.234,1406.88 650.244,1406.88 650.253,1406.88 650.262,1406.88 650.271,1406.88 650.28,1406.88 650.29,1406.88 650.299,1406.88 650.308,1406.88 650.317,1406.88 650.326,1406.88 650.336,1406.88 650.345,1406.88 650.354,1406.88 650.363,1406.88 650.372,1406.88 650.381,1406.88 650.391,1406.88 650.4,1406.88 650.409,1406.88 650.418,1406.88 650.427,1406.88 650.437,1406.88 650.446,1406.88 650.455,1406.88 650.464,1406.88 650.473,1406.88 650.483,1406.88 650.492,1406.88 650.501,1406.88 650.51,1406.88 650.519,1406.88 650.528,1406.88 650.538,1406.88 650.547,1406.88 650.556,1406.88 650.565,1406.88 650.574,1406.88 650.584,1406.88 650.593,1406.88 650.602,1406.88 650.611,1406.88 650.62,1406.88 650.63,1406.88 650.639,1406.88 650.648,1406.88 650.657,1406.88 650.666,1406.88 650.676,1406.88 650.685,1406.88 650.694,1406.88 650.703,1406.88 650.712,1406.88 650.721,1406.88 650.731,1406.88 650.74,1406.88 650.749,1406.88 650.758,1406.88 650.767,1406.88 650.777,1406.88 650.786,1406.88 650.795,1406.88 650.804,1406.88 650.813,1406.88 650.823,1406.88 650.832,1406.88 650.841,1406.88 650.85,1406.88 650.859,1406.88 650.868,1406.88 650.878,1406.88 650.887,1406.88 650.896,1406.88 650.905,1406.88 650.914,1406.88 650.924,1406.88 650.933,1406.88 650.942,1406.88 650.951,1406.88 650.96,1406.88 650.97,1406.88 650.979,1406.88 650.988,1406.88 650.997,1406.88 651.006,1406.88 651.016,1406.88 651.025,1406.88 651.034,1406.88 651.043,1406.88 651.052,1406.88 651.061,1406.88 651.071,1406.88 651.08,1406.88 651.089,1406.88 651.098,1406.88 651.107,1406.88 651.117,1406.88 651.126,1406.88 651.135,1406.88 651.144,1406.88 651.153,1406.88 651.163,1406.88 651.172,1406.88 651.181,1406.88 651.19,1406.88 651.199,1406.88 651.208,1406.88 651.218,1406.88 651.227,1406.88 651.236,1406.88 651.245,1406.88 651.254,1406.88 651.264,1406.88 651.273,1406.88 651.282,1406.88 651.291,1406.88 651.3,1406.88 651.31,1406.88 651.319,1406.88 651.328,1406.88 651.337,1406.88 651.346,1406.88 651.356,1406.88 651.365,1406.88 651.374,1406.88 651.383,1406.88 651.392,1406.88 651.401,1406.88 651.411,1406.88 651.42,1406.88 651.429,1406.88 651.438,1406.88 651.447,1406.88 651.457,1406.88 651.466,1406.88 651.475,1406.88 651.484,1406.88 651.493,1406.88 651.503,1406.88 651.512,1406.88 651.521,1406.88 651.53,1406.88 651.539,1406.88 651.548,1406.88 651.558,1406.88 651.567,1406.88 651.576,1406.88 651.585,1406.88 651.594,1406.88 651.604,1406.88 651.613,1406.88 651.622,1406.88 651.631,1406.88 651.64,1406.88 651.65,1406.88 651.659,1406.88 651.668,1406.88 651.677,1406.88 651.686,1406.88 651.696,1406.88 651.705,1406.88 651.714,1406.88 651.723,1406.88 651.732,1406.88 651.741,1406.88 651.751,1406.88 651.76,1406.88 651.769,1406.88 651.778,1406.88 651.787,1406.88 651.797,1406.88 651.806,1406.88 651.815,1406.88 651.824,1406.88 651.833,1406.88 651.843,1406.88 651.852,1406.88 651.861,1406.88 651.87,1406.88 651.879,1406.88 651.888,1406.88 651.898,1406.88 651.907,1406.88 651.916,1406.88 651.925,1406.88 651.934,1406.88 651.944,1406.88 651.953,1406.88 651.962,1406.88 651.971,1406.88 651.98,1406.88 651.99,1406.88 651.999,1406.88 652.008,1406.88 652.017,1406.88 652.026,1406.88 652.036,1406.88 652.045,1406.88 652.054,1406.88 652.063,1406.88 652.072,1406.88 652.081,1406.88 652.091,1406.88 652.1,1406.88 652.109,1406.88 652.118,1406.88 652.127,1406.88 652.137,1406.88 652.146,1406.88 652.155,1406.88 652.164,1406.88 652.173,1406.88 652.183,1406.88 652.192,1406.88 652.201,1406.88 652.21,1406.88 652.219,1406.88 652.229,1406.88 652.238,1406.88 652.247,1406.88 652.256,1406.88 652.265,1406.88 652.274,1406.88 652.284,1406.88 652.293,1406.88 652.302,1406.88 652.311,1406.88 652.32,1406.88 652.33,1406.88 652.339,1406.88 652.348,1406.88 652.357,1406.88 652.366,1406.88 652.376,1406.88 652.385,1406.88 652.394,1406.88 652.403,1406.88 652.412,1406.88 652.421,1406.88 652.431,1406.88 652.44,1406.88 652.449,1406.88 652.458,1406.88 652.467,1406.88 652.477,1406.88 652.486,1406.88 652.495,1406.88 652.504,1406.88 652.513,1406.88 652.523,1406.88 652.532,1406.88 652.541,1406.88 652.55,1406.88 652.559,1406.88 652.569,1406.88 652.578,1406.88 652.587,1406.88 652.596,1406.88 652.605,1406.88 652.614,1406.88 652.624,1406.88 652.633,1406.88 652.642,1406.88 652.651,1406.88 652.66,1406.88 652.67,1406.88 652.679,1406.88 652.688,1406.88 652.697,1406.88 652.706,1406.88 652.716,1406.88 652.725,1406.88 652.734,1406.88 652.743,1406.88 652.752,1406.88 652.761,1406.88 652.771,1406.88 652.78,1406.88 652.789,1406.88 652.798,1406.88 652.807,1406.88 652.817,1406.88 652.826,1406.88 652.835,1406.88 652.844,1406.88 652.853,1406.88 652.863,1406.88 652.872,1406.88 652.881,1406.88 652.89,1406.88 652.899,1406.88 652.909,1406.88 652.918,1406.88 652.927,1406.88 652.936,1406.88 652.945,1406.88 652.954,1406.88 652.964,1406.88 652.973,1406.88 652.982,1406.88 652.991,1406.88 653,1406.88 653.01,1406.88 653.019,1406.88 653.028,1406.88 653.037,1406.88 653.046,1406.88 653.056,1406.88 653.065,1406.88 653.074,1406.88 653.083,1406.88 653.092,1406.88 653.101,1406.88 653.111,1406.88 653.12,1406.88 653.129,1406.88 653.138,1406.88 653.147,1406.88 653.157,1406.88 653.166,1406.88 653.175,1406.88 653.184,1406.88 653.193,1406.88 653.203,1406.88 653.212,1406.88 653.221,1406.88 653.23,1406.88 653.239,1406.88 653.249,1406.88 653.258,1406.88 653.267,1406.88 653.276,1406.88 653.285,1406.88 653.294,1406.88 653.304,1406.88 653.313,1406.88 653.322,1406.88 653.331,1406.88 653.34,1406.88 653.35,1406.88 653.359,1406.88 653.368,1406.88 653.377,1406.88 653.386,1406.88 653.396,1406.88 653.405,1406.88 653.414,1406.88 653.423,1406.88 653.432,1406.88 653.441,1406.88 653.451,1406.88 653.46,1406.88 653.469,1406.88 653.478,1406.88 653.487,1406.88 653.497,1406.88 653.506,1406.88 653.515,1406.88 653.524,1406.88 653.533,1406.88 653.543,1406.88 653.552,1406.88 653.561,1406.88 653.57,1406.88 653.579,1406.88 653.589,1406.88 653.598,1406.88 653.607,1406.88 653.616,1406.88 653.625,1406.88 653.634,1406.88 653.644,1406.88 653.653,1406.88 653.662,1406.88 653.671,1406.88 653.68,1406.88 653.69,1406.88 653.699,1406.88 653.708,1406.88 653.717,1406.88 653.726,1406.88 653.736,1406.88 653.745,1406.88 653.754,1406.88 653.763,1406.88 653.772,1406.88 653.781,1406.88 653.791,1406.88 653.8,1406.88 653.809,1406.88 653.818,1406.88 653.827,1406.88 653.837,1406.88 653.846,1406.88 653.855,1406.88 653.864,1406.88 653.873,1406.88 653.883,1406.88 653.892,1406.88 653.901,1406.88 653.91,1406.88 653.919,1406.88 653.929,1406.88 653.938,1406.88 653.947,1406.88 653.956,1406.88 653.965,1406.88 653.974,1406.88 653.984,1406.88 653.993,1406.88 654.002,1406.88 654.011,1406.88 654.02,1406.88 654.03,1406.88 654.039,1406.88 654.048,1406.88 654.057,1406.88 654.066,1406.88 654.076,1406.88 654.085,1406.88 654.094,1406.88 654.103,1406.88 654.112,1406.88 654.121,1406.88 654.131,1406.88 654.14,1406.88 654.149,1406.88 654.158,1406.88 654.167,1406.88 654.177,1406.88 654.186,1406.88 654.195,1406.88 654.204,1406.88 654.213,1406.88 654.223,1406.88 654.232,1406.88 654.241,1406.88 654.25,1406.88 654.259,1406.88 654.269,1406.88 654.278,1406.88 654.287,1406.88 654.296,1406.88 654.305,1406.88 654.314,1406.88 654.324,1406.88 654.333,1406.88 654.342,1406.88 654.351,1406.88 654.36,1406.88 654.37,1406.88 654.379,1406.88 654.388,1406.88 654.397,1406.88 654.406,1406.88 654.416,1406.88 654.425,1406.88 654.434,1406.88 654.443,1406.88 654.452,1406.88 654.462,1406.88 654.471,1406.88 654.48,1406.88 654.489,1406.88 654.498,1406.88 654.507,1406.88 654.517,1406.88 654.526,1406.88 654.535,1406.88 654.544,1406.88 654.553,1406.88 654.563,1406.88 654.572,1406.88 654.581,1406.88 654.59,1406.88 654.599,1406.88 654.609,1406.88 654.618,1406.88 654.627,1406.88 654.636,1406.88 654.645,1406.88 654.654,1406.88 654.664,1406.88 654.673,1406.88 654.682,1406.88 654.691,1406.88 654.7,1406.88 654.71,1406.88 654.719,1406.88 654.728,1406.88 654.737,1406.88 654.746,1406.88 654.756,1406.88 654.765,1406.88 654.774,1406.88 654.783,1406.88 654.792,1406.88 654.802,1406.88 654.811,1406.88 654.82,1406.88 654.829,1406.88 654.838,1406.88 654.847,1406.88 654.857,1406.88 654.866,1406.88 654.875,1406.88 654.884,1406.88 654.893,1406.88 654.903,1406.88 654.912,1406.88 654.921,1406.88 654.93,1406.88 654.939,1406.88 654.949,1406.88 654.958,1406.88 654.967,1406.88 654.976,1406.88 654.985,1406.88 654.994,1406.88 655.004,1406.88 655.013,1406.88 655.022,1406.88 655.031,1406.88 655.04,1406.88 655.05,1406.88 655.059,1406.88 655.068,1406.88 655.077,1406.88 655.086,1406.88 655.096,1406.88 655.105,1406.88 655.114,1406.88 655.123,1406.88 655.132,1406.88 655.142,1406.88 655.151,1406.88 655.16,1406.88 655.169,1406.88 655.178,1406.88 655.187,1406.88 655.197,1406.88 655.206,1406.88 655.215,1406.88 655.224,1406.88 655.233,1406.88 655.243,1406.88 655.252,1406.88 655.261,1406.88 655.27,1406.88 655.279,1406.88 655.289,1406.88 655.298,1406.88 655.307,1406.88 655.316,1406.88 655.325,1406.88 655.334,1406.88 655.344,1406.88 655.353,1406.88 655.362,1406.88 655.371,1406.88 655.38,1406.88 655.39,1406.88 655.399,1406.88 655.408,1406.88 655.417,1406.88 655.426,1406.88 655.436,1406.88 655.445,1406.88 655.454,1406.88 655.463,1406.88 655.472,1406.88 655.482,1406.88 655.491,1406.88 655.5,1406.88 655.509,1406.88 655.518,1406.88 655.527,1406.88 655.537,1406.88 655.546,1406.88 655.555,1406.88 655.564,1406.88 655.573,1406.88 655.583,1406.88 655.592,1406.88 655.601,1406.88 655.61,1406.88 655.619,1406.88 655.629,1406.88 655.638,1406.88 655.647,1406.88 655.656,1406.88 655.665,1406.88 655.674,1406.88 655.684,1406.88 655.693,1406.88 655.702,1406.88 655.711,1406.88 655.72,1406.88 655.73,1406.88 655.739,1406.88 655.748,1406.88 655.757,1406.88 655.766,1406.88 655.776,1406.88 655.785,1406.88 655.794,1406.88 655.803,1406.88 655.812,1406.88 655.822,1406.88 655.831,1406.88 655.84,1406.88 655.849,1406.88 655.858,1406.88 655.867,1406.88 655.877,1406.88 655.886,1406.88 655.895,1406.88 655.904,1406.88 655.913,1406.88 655.923,1406.88 655.932,1406.88 655.941,1406.88 655.95,1406.88 655.959,1406.88 655.969,1406.88 655.978,1406.88 655.987,1406.88 655.996,1406.88 656.005,1406.88 656.014,1406.88 656.024,1406.88 656.033,1406.88 656.042,1406.88 656.051,1406.88 656.06,1406.88 656.07,1406.88 656.079,1406.88 656.088,1406.88 656.097,1406.88 656.106,1406.88 656.116,1406.88 656.125,1406.88 656.134,1406.88 656.143,1406.88 656.152,1406.88 656.162,1406.88 656.171,1406.88 656.18,1406.88 656.189,1406.88 656.198,1406.88 656.207,1406.88 656.217,1406.88 656.226,1406.88 656.235,1406.88 656.244,1406.88 656.253,1406.88 656.263,1406.88 656.272,1406.88 656.281,1406.88 656.29,1406.88 656.299,1406.88 656.309,1406.88 656.318,1406.88 656.327,1406.88 656.336,1406.88 656.345,1406.88 656.354,1406.88 656.364,1406.88 656.373,1406.88 656.382,1406.88 656.391,1406.88 656.4,1406.88 656.41,1406.88 656.419,1406.88 656.428,1406.88 656.437,1406.88 656.446,1406.88 656.456,1406.88 656.465,1406.88 656.474,1406.88 656.483,1406.88 656.492,1406.88 656.502,1406.88 656.511,1406.88 656.52,1406.88 656.529,1406.88 656.538,1406.88 656.547,1406.88 656.557,1406.88 656.566,1406.88 656.575,1406.88 656.584,1406.88 656.593,1406.88 656.603,1406.88 656.612,1406.88 656.621,1406.88 656.63,1406.88 656.639,1406.88 656.649,1406.88 656.658,1406.88 656.667,1406.88 656.676,1406.88 656.685,1406.88 656.694,1406.88 656.704,1406.88 656.713,1406.88 656.722,1406.88 656.731,1406.88 656.74,1406.88 656.75,1406.88 656.759,1406.88 656.768,1406.88 656.777,1406.88 656.786,1406.88 656.796,1406.88 656.805,1406.88 656.814,1406.88 656.823,1406.88 656.832,1406.88 656.842,1406.88 656.851,1406.88 656.86,1406.88 656.869,1406.88 656.878,1406.88 656.887,1406.88 656.897,1406.88 656.906,1406.88 656.915,1406.88 656.924,1406.88 656.933,1406.88 656.943,1406.88 656.952,1406.88 656.961,1406.88 656.97,1406.88 656.979,1406.88 656.989,1406.88 656.998,1406.88 657.007,1406.88 657.016,1406.88 657.025,1406.88 657.035,1406.88 657.044,1406.88 657.053,1406.88 657.062,1406.88 657.071,1406.88 657.08,1406.88 657.09,1406.88 657.099,1406.88 657.108,1406.88 657.117,1406.88 657.126,1406.88 657.136,1406.88 657.145,1406.88 657.154,1406.88 657.163,1406.88 657.172,1406.88 657.182,1406.88 657.191,1406.88 657.2,1406.88 657.209,1406.88 657.218,1406.88 657.227,1406.88 657.237,1406.88 657.246,1406.88 657.255,1406.88 657.264,1406.88 657.273,1406.88 657.283,1406.88 657.292,1406.88 657.301,1406.88 657.31,1406.88 657.319,1406.88 657.329,1406.88 657.338,1406.88 657.347,1406.88 657.356,1406.88 657.365,1406.88 657.375,1406.88 657.384,1406.88 657.393,1406.88 657.402,1406.88 657.411,1406.88 657.42,1406.88 657.43,1406.88 657.439,1406.88 657.448,1406.88 657.457,1406.88 657.466,1406.88 657.476,1406.88 657.485,1406.88 657.494,1406.88 657.503,1406.88 657.512,1406.88 657.522,1406.88 657.531,1406.88 657.54,1406.88 657.549,1406.88 657.558,1406.88 657.567,1406.88 657.577,1406.88 657.586,1406.88 657.595,1406.88 657.604,1406.88 657.613,1406.88 657.623,1406.88 657.632,1406.88 657.641,1406.88 657.65,1406.88 657.659,1406.88 657.669,1406.88 657.678,1406.88 657.687,1406.88 657.696,1406.88 657.705,1406.88 657.715,1406.88 657.724,1406.88 657.733,1406.88 657.742,1406.88 657.751,1406.88 657.76,1406.88 657.77,1406.88 657.779,1406.88 657.788,1406.88 657.797,1406.88 657.806,1406.88 657.816,1406.88 657.825,1406.88 657.834,1406.88 657.843,1406.88 657.852,1406.88 657.862,1406.88 657.871,1406.88 657.88,1406.88 657.889,1406.88 657.898,1406.88 657.907,1406.88 657.917,1406.88 657.926,1406.88 657.935,1406.88 657.944,1406.88 657.953,1406.88 657.963,1406.88 657.972,1406.88 657.981,1406.88 657.99,1406.88 657.999,1406.88 658.009,1406.88 658.018,1406.88 658.027,1406.88 658.036,1406.88 658.045,1406.88 658.055,1406.88 658.064,1406.88 658.073,1406.88 658.082,1406.88 658.091,1406.88 658.1,1406.88 658.11,1406.88 658.119,1406.88 658.128,1406.88 658.137,1406.88 658.146,1406.88 658.156,1406.88 658.165,1406.88 658.174,1406.88 658.183,1406.88 658.192,1406.88 658.202,1406.88 658.211,1406.88 658.22,1406.88 658.229,1406.88 658.238,1406.88 658.247,1406.88 658.257,1406.88 658.266,1406.88 658.275,1406.88 658.284,1406.88 658.293,1406.88 658.303,1406.88 658.312,1406.88 658.321,1406.88 658.33,1406.88 658.339,1406.88 658.349,1406.88 658.358,1406.88 658.367,1406.88 658.376,1406.88 658.385,1406.88 658.395,1406.88 658.404,1406.88 658.413,1406.88 658.422,1406.88 658.431,1406.88 658.44,1406.88 658.45,1406.88 658.459,1406.88 658.468,1406.88 658.477,1406.88 658.486,1406.88 658.496,1406.88 658.505,1406.88 658.514,1406.88 658.523,1406.88 658.532,1406.88 658.542,1406.88 658.551,1406.88 658.56,1406.88 658.569,1406.88 658.578,1406.88 658.587,1406.88 658.597,1406.88 658.606,1406.88 658.615,1406.88 658.624,1406.88 658.633,1406.88 658.643,1406.88 658.652,1406.88 658.661,1406.88 658.67,1406.88 658.679,1406.88 658.689,1406.88 658.698,1406.88 658.707,1406.88 658.716,1406.88 658.725,1406.88 658.735,1406.88 658.744,1406.88 658.753,1406.88 658.762,1406.88 658.771,1406.88 658.78,1406.88 658.79,1406.88 658.799,1406.88 658.808,1406.88 658.817,1406.88 658.826,1406.88 658.836,1406.88 658.845,1406.88 658.854,1406.88 658.863,1406.88 658.872,1406.88 658.882,1406.88 658.891,1406.88 658.9,1406.88 658.909,1406.88 658.918,1406.88 658.927,1406.88 658.937,1406.88 658.946,1406.88 658.955,1406.88 658.964,1406.88 658.973,1406.88 658.983,1406.88 658.992,1406.88 659.001,1406.88 659.01,1406.88 659.019,1406.88 659.029,1406.88 659.038,1406.88 659.047,1406.88 659.056,1406.88 659.065,1406.88 659.075,1406.88 659.084,1406.88 659.093,1406.88 659.102,1406.88 659.111,1406.88 659.12,1406.88 659.13,1406.88 659.139,1406.88 659.148,1406.88 659.157,1406.88 659.166,1406.88 659.176,1406.88 659.185,1406.88 659.194,1406.88 659.203,1406.88 659.212,1406.88 659.222,1406.88 659.231,1406.88 659.24,1406.88 659.249,1406.88 659.258,1406.88 659.267,1406.88 659.277,1406.88 659.286,1406.88 659.295,1406.88 659.304,1406.88 659.313,1406.88 659.323,1406.88 659.332,1406.88 659.341,1406.88 659.35,1406.88 659.359,1406.88 659.369,1406.88 659.378,1406.88 659.387,1406.88 659.396,1406.88 659.405,1406.88 659.415,1406.88 659.424,1406.88 659.433,1406.88 659.442,1406.88 659.451,1406.88 659.46,1406.88 659.47,1406.88 659.479,1406.88 659.488,1406.88 659.497,1406.88 659.506,1406.88 659.516,1406.88 659.525,1406.88 659.534,1406.88 659.543,1406.88 659.552,1406.88 659.562,1406.88 659.571,1406.88 659.58,1406.88 659.589,1406.88 659.598,1406.88 659.608,1406.88 659.617,1406.88 659.626,1406.88 659.635,1406.88 659.644,1406.88 659.653,1406.88 659.663,1406.88 659.672,1406.88 659.681,1406.88 659.69,1406.88 659.699,1406.88 659.709,1406.88 659.718,1406.88 659.727,1406.88 659.736,1406.88 659.745,1406.88 659.755,1406.88 659.764,1406.88 659.773,1406.88 659.782,1406.88 659.791,1406.88 659.8,1406.88 659.81,1406.88 659.819,1406.88 659.828,1406.88 659.837,1406.88 659.846,1406.88 659.856,1406.88 659.865,1406.88 659.874,1406.88 659.883,1406.88 659.892,1406.88 659.902,1406.88 659.911,1406.88 659.92,1406.88 659.929,1406.88 659.938,1406.88 659.948,1406.88 659.957,1406.88 659.966,1406.88 659.975,1406.88 659.984,1406.88 659.993,1406.88 660.003,1406.88 660.012,1406.88 660.021,1406.88 660.03,1406.88 660.039,1406.88 660.049,1406.88 660.058,1406.88 660.067,1406.88 660.076,1406.88 660.085,1406.88 660.095,1406.88 660.104,1406.88 660.113,1406.88 660.122,1406.88 660.131,1406.88 660.14,1406.88 660.15,1406.88 660.159,1406.88 660.168,1406.88 660.177,1406.88 660.186,1406.88 660.196,1406.88 660.205,1406.88 660.214,1406.88 660.223,1406.88 660.232,1406.88 660.242,1406.88 660.251,1406.88 660.26,1406.88 660.269,1406.88 660.278,1406.88 660.288,1406.88 660.297,1406.88 660.306,1406.88 660.315,1406.88 660.324,1406.88 660.333,1406.88 660.343,1406.88 660.352,1406.88 660.361,1406.88 660.37,1406.88 660.379,1406.88 660.389,1406.88 660.398,1406.88 660.407,1406.88 660.416,1406.88 660.425,1406.88 660.435,1406.88 660.444,1406.88 660.453,1406.88 660.462,1406.88 660.471,1406.88 660.48,1406.88 660.49,1406.88 660.499,1406.88 660.508,1406.88 660.517,1406.88 660.526,1406.88 660.536,1406.88 660.545,1406.88 660.554,1406.88 660.563,1406.88 660.572,1406.88 660.582,1406.88 660.591,1406.88 660.6,1406.88 660.609,1406.88 660.618,1406.88 660.628,1406.88 660.637,1406.88 660.646,1406.88 660.655,1406.88 660.664,1406.88 660.673,1406.88 660.683,1406.88 660.692,1406.88 660.701,1406.88 660.71,1406.88 660.719,1406.88 660.729,1406.88 660.738,1406.88 660.747,1406.88 660.756,1406.88 660.765,1406.88 660.775,1406.88 660.784,1406.88 660.793,1406.88 660.802,1406.88 660.811,1406.88 660.82,1406.88 660.83,1406.88 660.839,1406.88 660.848,1406.88 660.857,1406.88 660.866,1406.88 660.876,1406.88 660.885,1406.88 660.894,1406.88 660.903,1406.88 660.912,1406.88 660.922,1406.88 660.931,1406.88 660.94,1406.88 660.949,1406.88 660.958,1406.88 660.968,1406.88 660.977,1406.88 660.986,1406.88 660.995,1406.88 661.004,1406.88 661.013,1406.88 661.023,1406.88 661.032,1406.88 661.041,1406.88 661.05,1406.88 661.059,1406.88 661.069,1406.88 661.078,1406.88 661.087,1406.88 661.096,1406.88 661.105,1406.88 661.115,1406.88 661.124,1406.88 661.133,1406.88 661.142,1406.88 661.151,1406.88 661.16,1406.88 661.17,1406.88 661.179,1406.88 661.188,1406.88 661.197,1406.88 661.206,1406.88 661.216,1406.88 661.225,1406.88 661.234,1406.88 661.243,1406.88 661.252,1406.88 661.262,1406.88 661.271,1406.88 661.28,1406.88 661.289,1406.88 661.298,1406.88 661.308,1406.88 661.317,1406.88 661.326,1406.88 661.335,1406.88 661.344,1406.88 661.353,1406.88 661.363,1406.88 661.372,1406.88 661.381,1406.88 661.39,1406.88 661.399,1406.88 661.409,1406.88 661.418,1406.88 661.427,1406.88 661.436,1406.88 661.445,1406.88 661.455,1406.88 661.464,1406.88 661.473,1406.88 661.482,1406.88 661.491,1406.88 661.5,1406.88 661.51,1406.88 661.519,1406.88 661.528,1406.88 661.537,1406.88 661.546,1406.88 661.556,1406.88 661.565,1406.88 661.574,1406.88 661.583,1406.88 661.592,1406.88 661.602,1406.88 661.611,1406.88 661.62,1406.88 661.629,1406.88 661.638,1406.88 661.648,1406.88 661.657,1406.88 661.666,1406.88 661.675,1406.88 661.684,1406.88 661.693,1406.88 661.703,1406.88 661.712,1406.88 661.721,1406.88 661.73,1406.88 661.739,1406.88 661.749,1406.88 661.758,1406.88 661.767,1406.88 661.776,1406.88 661.785,1406.88 661.795,1406.88 661.804,1406.88 661.813,1406.88 661.822,1406.88 661.831,1406.88 661.841,1406.88 661.85,1406.88 661.859,1406.88 661.868,1406.88 661.877,1406.88 661.886,1406.88 661.896,1406.88 661.905,1406.88 661.914,1406.88 661.923,1406.88 661.932,1406.88 661.942,1406.88 661.951,1406.88 661.96,1406.88 661.969,1406.88 661.978,1406.88 661.988,1406.88 661.997,1406.88 662.006,1406.88 662.015,1406.88 662.024,1406.88 662.033,1406.88 662.043,1406.88 662.052,1406.88 662.061,1406.88 662.07,1406.88 662.079,1406.88 662.089,1406.88 662.098,1406.88 662.107,1406.88 662.116,1406.88 662.125,1406.88 662.135,1406.88 662.144,1406.88 662.153,1406.88 662.162,1406.88 662.171,1406.88 662.181,1406.88 662.19,1406.88 662.199,1406.88 662.208,1406.88 662.217,1406.88 662.226,1406.88 662.236,1406.88 662.245,1406.88 662.254,1406.88 662.263,1406.88 662.272,1406.88 662.282,1406.88 662.291,1406.88 662.3,1406.88 662.309,1406.88 662.318,1406.88 662.328,1406.88 662.337,1406.88 662.346,1406.88 662.355,1406.88 662.364,1406.88 662.373,1406.88 662.383,1406.88 662.392,1406.88 662.401,1406.88 662.41,1406.88 662.419,1406.88 662.429,1406.88 662.438,1406.88 662.447,1406.88 662.456,1406.88 662.465,1406.88 662.475,1406.88 662.484,1406.88 662.493,1406.88 662.502,1406.88 662.511,1406.88 662.521,1406.88 662.53,1406.88 662.539,1406.88 662.548,1406.88 662.557,1406.88 662.566,1406.88 662.576,1406.88 662.585,1406.88 662.594,1406.88 662.603,1406.88 662.612,1406.88 662.622,1406.88 662.631,1406.88 662.64,1406.88 662.649,1406.88 662.658,1406.88 662.668,1406.88 662.677,1406.88 662.686,1406.88 662.695,1406.88 662.704,1406.88 662.713,1406.88 662.723,1406.88 662.732,1406.88 662.741,1406.88 662.75,1406.88 662.759,1406.88 662.769,1406.88 662.778,1406.88 662.787,1406.88 662.796,1406.88 662.805,1406.88 662.815,1406.88 662.824,1406.88 662.833,1406.88 662.842,1406.88 662.851,1406.88 662.861,1406.88 662.87,1406.88 662.879,1406.88 662.888,1406.88 662.897,1406.88 662.906,1406.88 662.916,1406.88 662.925,1406.88 662.934,1406.88 662.943,1406.88 662.952,1406.88 662.962,1406.88 662.971,1406.88 662.98,1406.88 662.989,1406.88 662.998,1406.88 663.008,1406.88 663.017,1406.88 663.026,1406.88 663.035,1406.88 663.044,1406.88 663.053,1406.88 663.063,1406.88 663.072,1406.88 663.081,1406.88 663.09,1406.88 663.099,1406.88 663.109,1406.88 663.118,1406.88 663.127,1406.88 663.136,1406.88 663.145,1406.88 663.155,1406.88 663.164,1406.88 663.173,1406.88 663.182,1406.88 663.191,1406.88 663.201,1406.88 663.21,1406.88 663.219,1406.88 663.228,1406.88 663.237,1406.88 663.246,1406.88 663.256,1406.88 663.265,1406.88 663.274,1406.88 663.283,1406.88 663.292,1406.88 663.302,1406.88 663.311,1406.88 663.32,1406.88 663.329,1406.88 663.338,1406.88 663.348,1406.88 663.357,1406.88 663.366,1406.88 663.375,1406.88 663.384,1406.88 663.393,1406.88 663.403,1406.88 663.412,1406.88 663.421,1406.88 663.43,1406.88 663.439,1406.88 663.449,1406.88 663.458,1406.88 663.467,1406.88 663.476,1406.88 663.485,1406.88 663.495,1406.88 663.504,1406.88 663.513,1406.88 663.522,1406.88 663.531,1406.88 663.541,1406.88 663.55,1406.88 663.559,1406.88 663.568,1406.88 663.577,1406.88 663.586,1406.88 663.596,1406.88 663.605,1406.88 663.614,1406.88 663.623,1406.88 663.632,1406.88 663.642,1406.88 663.651,1406.88 663.66,1406.88 663.669,1406.88 663.678,1406.88 663.688,1406.88 663.697,1406.88 663.706,1406.88 663.715,1406.88 663.724,1406.88 663.733,1406.88 663.743,1406.88 663.752,1406.88 663.761,1406.88 663.77,1406.88 663.779,1406.88 663.789,1406.88 663.798,1406.88 663.807,1406.88 663.816,1406.88 663.825,1406.88 663.835,1406.88 663.844,1406.88 663.853,1406.88 663.862,1406.88 663.871,1406.88 663.881,1406.88 663.89,1406.88 663.899,1406.88 663.908,1406.88 663.917,1406.88 663.926,1406.88 663.936,1406.88 663.945,1406.88 663.954,1406.88 663.963,1406.88 663.972,1406.88 663.982,1406.88 663.991,1406.88 664,1406.88 664.009,1406.88 664.018,1406.88 664.028,1406.88 664.037,1406.88 664.046,1406.88 664.055,1406.88 664.064,1406.88 664.073,1406.88 664.083,1406.88 664.092,1406.88 664.101,1406.88 664.11,1406.88 664.119,1406.88 664.129,1406.88 664.138,1406.88 664.147,1406.88 664.156,1406.88 664.165,1406.88 664.175,1406.88 664.184,1406.88 664.193,1406.88 664.202,1406.88 664.211,1406.88 664.221,1406.88 664.23,1406.88 664.239,1406.88 664.248,1406.88 664.257,1406.88 664.266,1406.88 664.276,1406.88 664.285,1406.88 664.294,1406.88 664.303,1406.88 664.312,1406.88 664.322,1406.88 664.331,1406.88 664.34,1406.88 664.349,1406.88 664.358,1406.88 664.368,1406.88 664.377,1406.88 664.386,1406.88 664.395,1406.88 664.404,1406.88 664.414,1406.88 664.423,1406.88 664.432,1406.88 664.441,1406.88 664.45,1406.88 664.459,1406.88 664.469,1406.88 664.478,1406.88 664.487,1406.88 664.496,1406.88 664.505,1406.88 664.515,1406.88 664.524,1406.88 664.533,1406.88 664.542,1406.88 664.551,1406.88 664.561,1406.88 664.57,1406.88 664.579,1406.88 664.588,1406.88 664.597,1406.88 664.606,1406.88 664.616,1406.88 664.625,1406.88 664.634,1406.88 664.643,1406.88 664.652,1406.88 664.662,1406.88 664.671,1406.88 664.68,1406.88 664.689,1406.88 664.698,1406.88 664.708,1406.88 664.717,1406.88 664.726,1406.88 664.735,1406.88 664.744,1406.88 664.754,1406.88 664.763,1406.88 664.772,1406.88 664.781,1406.88 664.79,1406.88 664.799,1406.88 664.809,1406.88 664.818,1406.88 664.827,1406.88 664.836,1406.88 664.845,1406.88 664.855,1406.88 664.864,1406.88 664.873,1406.88 664.882,1406.88 664.891,1406.88 664.901,1406.88 664.91,1406.88 664.919,1406.88 664.928,1406.88 664.937,1406.88 664.946,1406.88 664.956,1406.88 664.965,1406.88 664.974,1406.88 664.983,1406.88 664.992,1406.88 665.002,1406.88 665.011,1406.88 665.02,1406.88 665.029,1406.88 665.038,1406.88 665.048,1406.88 665.057,1406.88 665.066,1406.88 665.075,1406.88 665.084,1406.88 665.094,1406.88 665.103,1406.88 665.112,1406.88 665.121,1406.88 665.13,1406.88 665.139,1406.88 665.149,1406.88 665.158,1406.88 665.167,1406.88 665.176,1406.88 665.185,1406.88 665.195,1406.88 665.204,1406.88 665.213,1406.88 665.222,1406.88 665.231,1406.88 665.241,1406.88 665.25,1406.88 665.259,1406.88 665.268,1406.88 665.277,1406.88 665.286,1406.88 665.296,1406.88 665.305,1406.88 665.314,1406.88 665.323,1406.88 665.332,1406.88 665.342,1406.88 665.351,1406.88 665.36,1406.88 665.369,1406.88 665.378,1406.88 665.388,1406.88 665.397,1406.88 665.406,1406.88 665.415,1406.88 665.424,1406.88 665.434,1406.88 665.443,1406.88 665.452,1406.88 665.461,1406.88 665.47,1406.88 665.479,1406.88 665.489,1406.88 665.498,1406.88 665.507,1406.88 665.516,1406.88 665.525,1406.88 665.535,1406.88 665.544,1406.88 665.553,1406.88 665.562,1406.88 665.571,1406.88 665.581,1406.88 665.59,1406.88 665.599,1406.88 665.608,1406.88 665.617,1406.88 665.626,1406.88 665.636,1406.88 665.645,1406.88 665.654,1406.88 665.663,1406.88 665.672,1406.88 665.682,1406.88 665.691,1406.88 665.7,1406.88 665.709,1406.88 665.718,1406.88 665.728,1406.88 665.737,1406.88 665.746,1406.88 665.755,1406.88 665.764,1406.88 665.774,1406.88 665.783,1406.88 665.792,1406.88 665.801,1406.88 665.81,1406.88 665.819,1406.88 665.829,1406.88 665.838,1406.88 665.847,1406.88 665.856,1406.88 665.865,1406.88 665.875,1406.88 665.884,1406.88 665.893,1406.88 665.902,1406.88 665.911,1406.88 665.921,1406.88 665.93,1406.88 665.939,1406.88 665.948,1406.88 665.957,1406.88 665.966,1406.88 665.976,1406.88 665.985,1406.88 665.994,1406.88 666.003,1406.88 666.012,1406.88 666.022,1406.88 666.031,1406.88 666.04,1406.88 666.049,1406.88 666.058,1406.88 666.068,1406.88 666.077,1406.88 666.086,1406.88 666.095,1406.88 666.104,1406.88 666.114,1406.88 666.123,1406.88 666.132,1406.88 666.141,1406.88 666.15,1406.88 666.159,1406.88 666.169,1406.88 666.178,1406.88 666.187,1406.88 666.196,1406.88 666.205,1406.88 666.215,1406.88 666.224,1406.88 666.233,1406.88 666.242,1406.88 666.251,1406.88 666.261,1406.88 666.27,1406.88 666.279,1406.88 666.288,1406.88 666.297,1406.88 666.306,1406.88 666.316,1406.88 666.325,1406.88 666.334,1406.88 666.343,1406.88 666.352,1406.88 666.362,1406.88 666.371,1406.88 666.38,1406.88 666.389,1406.88 666.398,1406.88 666.408,1406.88 666.417,1406.88 666.426,1406.88 666.435,1406.88 666.444,1406.88 666.454,1406.88 666.463,1406.88 666.472,1406.88 666.481,1406.88 666.49,1406.88 666.499,1406.88 666.509,1406.88 666.518,1406.88 666.527,1406.88 666.536,1406.88 666.545,1406.88 666.555,1406.88 666.564,1406.88 666.573,1406.88 666.582,1406.88 666.591,1406.88 666.601,1406.88 666.61,1406.88 666.619,1406.88 666.628,1406.88 666.637,1406.88 666.646,1406.88 666.656,1406.88 666.665,1406.88 666.674,1406.88 666.683,1406.88 666.692,1406.88 666.702,1406.88 666.711,1406.88 666.72,1406.88 666.729,1406.88 666.738,1406.88 666.748,1406.88 666.757,1406.88 666.766,1406.88 666.775,1406.88 666.784,1406.88 666.794,1406.88 666.803,1406.88 666.812,1406.88 666.821,1406.88 666.83,1406.88 666.839,1406.88 666.849,1406.88 666.858,1406.88 666.867,1406.88 666.876,1406.88 666.885,1406.88 666.895,1406.88 666.904,1406.88 666.913,1406.88 666.922,1406.88 666.931,1406.88 666.941,1406.88 666.95,1406.88 666.959,1406.88 666.968,1406.88 666.977,1406.88 666.987,1406.88 666.996,1406.88 667.005,1406.88 667.014,1406.88 667.023,1406.88 667.032,1406.88 667.042,1406.88 667.051,1406.88 667.06,1406.88 667.069,1406.88 667.078,1406.88 667.088,1406.88 667.097,1406.88 667.106,1406.88 667.115,1406.88 667.124,1406.88 667.134,1406.88 667.143,1406.88 667.152,1406.88 667.161,1406.88 667.17,1406.88 667.179,1406.88 667.189,1406.88 667.198,1406.88 667.207,1406.88 667.216,1406.88 667.225,1406.88 667.235,1406.88 667.244,1406.88 667.253,1406.88 667.262,1406.88 667.271,1406.88 667.281,1406.88 667.29,1406.88 667.299,1406.88 667.308,1406.88 667.317,1406.88 667.327,1406.88 667.336,1406.88 667.345,1406.88 667.354,1406.88 667.363,1406.88 667.372,1406.88 667.382,1406.88 667.391,1406.88 667.4,1406.88 667.409,1406.88 667.418,1406.88 667.428,1406.88 667.437,1406.88 667.446,1406.88 667.455,1406.88 667.464,1406.88 667.474,1406.88 667.483,1406.88 667.492,1406.88 667.501,1406.88 667.51,1406.88 667.519,1406.88 667.529,1406.88 667.538,1406.88 667.547,1406.88 667.556,1406.88 667.565,1406.88 667.575,1406.88 667.584,1406.88 667.593,1406.88 667.602,1406.88 667.611,1406.88 667.621,1406.88 667.63,1406.88 667.639,1406.88 667.648,1406.88 667.657,1406.88 667.667,1406.88 667.676,1406.88 667.685,1406.88 667.694,1406.88 667.703,1406.88 667.712,1406.88 667.722,1406.88 667.731,1406.88 667.74,1406.88 667.749,1406.88 667.758,1406.88 667.768,1406.88 667.777,1406.88 667.786,1406.88 667.795,1406.88 667.804,1406.88 667.814,1406.88 667.823,1406.88 667.832,1406.88 667.841,1406.88 667.85,1406.88 667.859,1406.88 667.869,1406.88 667.878,1406.88 667.887,1406.88 667.896,1406.88 667.905,1406.88 667.915,1406.88 667.924,1406.88 667.933,1406.88 667.942,1406.88 667.951,1406.88 667.961,1406.88 667.97,1406.88 667.979,1406.88 667.988,1406.88 667.997,1406.88 668.007,1406.88 668.016,1406.88 668.025,1406.88 668.034,1406.88 668.043,1406.88 668.052,1406.88 668.062,1406.88 668.071,1406.88 668.08,1406.88 668.089,1406.88 668.098,1406.88 668.108,1406.88 668.117,1406.88 668.126,1406.88 668.135,1406.88 668.144,1406.88 668.154,1406.88 668.163,1406.88 668.172,1406.88 668.181,1406.88 668.19,1406.88 668.199,1406.88 668.209,1406.88 668.218,1406.88 668.227,1406.88 668.236,1406.88 668.245,1406.88 668.255,1406.88 668.264,1406.88 668.273,1406.88 668.282,1406.88 668.291,1406.88 668.301,1406.88 668.31,1406.88 668.319,1406.88 668.328,1406.88 668.337,1406.88 668.347,1406.88 668.356,1406.88 668.365,1406.88 668.374,1406.88 668.383,1406.88 668.392,1406.88 668.402,1406.88 668.411,1406.88 668.42,1406.88 668.429,1406.88 668.438,1406.88 668.448,1406.88 668.457,1406.88 668.466,1406.88 668.475,1406.88 668.484,1406.88 668.494,1406.88 668.503,1406.88 668.512,1406.88 668.521,1406.88 668.53,1406.88 668.539,1406.88 668.549,1406.88 668.558,1406.88 668.567,1406.88 668.576,1406.88 668.585,1406.88 668.595,1406.88 668.604,1406.88 668.613,1406.88 668.622,1406.88 668.631,1406.88 668.641,1406.88 668.65,1406.88 668.659,1406.88 668.668,1406.88 668.677,1406.88 668.687,1406.88 668.696,1406.88 668.705,1406.88 668.714,1406.88 668.723,1406.88 668.732,1406.88 668.742,1406.88 668.751,1406.88 668.76,1406.88 668.769,1406.88 668.778,1406.88 668.788,1406.88 668.797,1406.88 668.806,1406.88 668.815,1406.88 668.824,1406.88 668.834,1406.88 668.843,1406.88 668.852,1406.88 668.861,1406.88 668.87,1406.88 668.879,1406.88 668.889,1406.88 668.898,1406.88 668.907,1406.88 668.916,1406.88 668.925,1406.88 668.935,1406.88 668.944,1406.88 668.953,1406.88 668.962,1406.88 668.971,1406.88 668.981,1406.88 668.99,1406.88 668.999,1406.88 669.008,1406.88 669.017,1406.88 669.027,1406.88 669.036,1406.88 669.045,1406.88 669.054,1406.88 669.063,1406.88 669.072,1406.88 669.082,1406.88 669.091,1406.88 669.1,1406.88 669.109,1406.88 669.118,1406.88 669.128,1406.88 669.137,1406.88 669.146,1406.88 669.155,1406.88 669.164,1406.88 669.174,1406.88 669.183,1406.88 669.192,1406.88 669.201,1406.88 669.21,1406.88 669.22,1406.88 669.229,1406.88 669.238,1406.88 669.247,1406.88 669.256,1406.88 669.265,1406.88 669.275,1406.88 669.284,1406.88 669.293,1406.88 669.302,1406.88 669.311,1406.88 669.321,1406.88 669.33,1406.88 669.339,1406.88 669.348,1406.88 669.357,1406.88 669.367,1406.88 669.376,1406.88 669.385,1406.88 669.394,1406.88 669.403,1406.88 669.412,1406.88 669.422,1406.88 669.431,1406.88 669.44,1406.88 669.449,1406.88 669.458,1406.88 669.468,1406.88 669.477,1406.88 669.486,1406.88 669.495,1406.88 669.504,1406.88 669.514,1406.88 669.523,1406.88 669.532,1406.88 669.541,1406.88 669.55,1406.88 669.56,1406.88 669.569,1406.88 669.578,1406.88 669.587,1406.88 669.596,1406.88 669.605,1406.88 669.615,1406.88 669.624,1406.88 669.633,1406.88 669.642,1406.88 669.651,1406.88 669.661,1406.88 669.67,1406.88 669.679,1406.88 669.688,1406.88 669.697,1406.88 669.707,1406.88 669.716,1406.88 669.725,1406.88 669.734,1406.88 669.743,1406.88 669.752,1406.88 669.762,1406.88 669.771,1406.88 669.78,1406.88 669.789,1406.88 669.798,1406.88 669.808,1406.88 669.817,1406.88 669.826,1406.88 669.835,1406.88 669.844,1406.88 669.854,1406.88 669.863,1406.88 669.872,1406.88 669.881,1406.88 669.89,1406.88 669.9,1406.88 669.909,1406.88 669.918,1406.88 669.927,1406.88 669.936,1406.88 669.945,1406.88 669.955,1406.88 669.964,1406.88 669.973,1406.88 669.982,1406.88 669.991,1406.88 670.001,1406.88 670.01,1406.88 670.019,1406.88 670.028,1406.88 670.037,1406.88 670.047,1406.88 670.056,1406.88 670.065,1406.88 670.074,1406.88 670.083,1406.88 670.092,1406.88 670.102,1406.88 670.111,1406.88 670.12,1406.88 670.129,1406.88 670.138,1406.88 670.148,1406.88 670.157,1406.88 670.166,1406.88 670.175,1406.88 670.184,1406.88 670.194,1406.88 670.203,1406.88 670.212,1406.88 670.221,1406.88 670.23,1406.88 670.24,1406.88 670.249,1406.88 670.258,1406.88 670.267,1406.88 670.276,1406.88 670.285,1406.88 670.295,1406.88 670.304,1406.88 670.313,1406.88 670.322,1406.88 670.331,1406.88 670.341,1406.88 670.35,1406.88 670.359,1406.88 670.368,1406.88 670.377,1406.88 670.387,1406.88 670.396,1406.88 670.405,1406.88 670.414,1406.88 670.423,1406.88 670.432,1406.88 670.442,1406.88 670.451,1406.88 670.46,1406.88 670.469,1406.88 670.478,1406.88 670.488,1406.88 670.497,1406.88 670.506,1406.88 670.515,1406.88 670.524,1406.88 670.534,1406.88 670.543,1406.88 670.552,1406.88 670.561,1406.88 670.57,1406.88 670.58,1406.88 670.589,1406.88 670.598,1406.88 670.607,1406.88 670.616,1406.88 670.625,1406.88 670.635,1406.88 670.644,1406.88 670.653,1406.88 670.662,1406.88 670.671,1406.88 670.681,1406.88 670.69,1406.88 670.699,1406.88 670.708,1406.88 670.717,1406.88 670.727,1406.88 670.736,1406.88 670.745,1406.88 670.754,1406.88 670.763,1406.88 670.772,1406.88 670.782,1406.88 670.791,1406.88 670.8,1406.88 670.809,1406.88 670.818,1406.88 670.828,1406.88 670.837,1406.88 670.846,1406.88 670.855,1406.88 670.864,1406.88 670.874,1406.88 670.883,1406.88 670.892,1406.88 670.901,1406.88 670.91,1406.88 670.92,1406.88 670.929,1406.88 670.938,1406.88 670.947,1406.88 670.956,1406.88 670.965,1406.88 670.975,1406.88 670.984,1406.88 670.993,1406.88 671.002,1406.88 671.011,1406.88 671.021,1406.88 671.03,1406.88 671.039,1406.88 671.048,1406.88 671.057,1406.88 671.067,1406.88 671.076,1406.88 671.085,1406.88 671.094,1406.88 671.103,1406.88 671.112,1406.88 671.122,1406.88 671.131,1406.88 671.14,1406.88 671.149,1406.88 671.158,1406.88 671.168,1406.88 671.177,1406.88 671.186,1406.88 671.195,1406.88 671.204,1406.88 671.214,1406.88 671.223,1406.88 671.232,1406.88 671.241,1406.88 671.25,1406.88 671.26,1406.88 671.269,1406.88 671.278,1406.88 671.287,1406.88 671.296,1406.88 671.305,1406.88 671.315,1406.88 671.324,1406.88 671.333,1406.88 671.342,1406.88 671.351,1406.88 671.361,1406.88 671.37,1406.88 671.379,1406.88 671.388,1406.88 671.397,1406.88 671.407,1406.88 671.416,1406.88 671.425,1406.88 671.434,1406.88 671.443,1406.88 671.452,1406.88 671.462,1406.88 671.471,1406.88 671.48,1406.88 671.489,1406.88 671.498,1406.88 671.508,1406.88 671.517,1406.88 671.526,1406.88 671.535,1406.88 671.544,1406.88 671.554,1406.88 671.563,1406.88 671.572,1406.88 671.581,1406.88 671.59,1406.88 671.6,1406.88 671.609,1406.88 671.618,1406.88 671.627,1406.88 671.636,1406.88 671.645,1406.88 671.655,1406.88 671.664,1406.88 671.673,1406.88 671.682,1406.88 671.691,1406.88 671.701,1406.88 671.71,1406.88 671.719,1406.88 671.728,1406.88 671.737,1406.88 671.747,1406.88 671.756,1406.88 671.765,1406.88 671.774,1406.88 671.783,1406.88 671.793,1406.88 671.802,1406.88 671.811,1406.88 671.82,1406.88 671.829,1406.88 671.838,1406.88 671.848,1406.88 671.857,1406.88 671.866,1406.88 671.875,1406.88 671.884,1406.88 671.894,1406.88 671.903,1406.88 671.912,1406.88 671.921,1406.88 671.93,1406.88 671.94,1406.88 671.949,1406.88 671.958,1406.88 671.967,1406.88 671.976,1406.88 671.985,1406.88 671.995,1406.88 672.004,1406.88 672.013,1406.88 672.022,1406.88 672.031,1406.88 672.041,1406.88 672.05,1406.88 672.059,1406.88 672.068,1406.88 672.077,1406.88 672.087,1406.88 672.096,1406.88 672.105,1406.88 672.114,1406.88 672.123,1406.88 672.133,1406.88 672.142,1406.88 672.151,1406.88 672.16,1406.88 672.169,1406.88 672.178,1406.88 672.188,1406.88 672.197,1406.88 672.206,1406.88 672.215,1406.88 672.224,1406.88 672.234,1406.88 672.243,1406.88 672.252,1406.88 672.261,1406.88 672.27,1406.88 672.28,1406.88 672.289,1406.88 672.298,1406.88 672.307,1406.88 672.316,1406.88 672.325,1406.88 672.335,1406.88 672.344,1406.88 672.353,1406.88 672.362,1406.88 672.371,1406.88 672.381,1406.88 672.39,1406.88 672.399,1406.88 672.408,1406.88 672.417,1406.88 672.427,1406.88 672.436,1406.88 672.445,1406.88 672.454,1406.88 672.463,1406.88 672.473,1406.88 672.482,1406.88 672.491,1406.88 672.5,1406.88 672.509,1406.88 672.518,1406.88 672.528,1406.88 672.537,1406.88 672.546,1406.88 672.555,1406.88 672.564,1406.88 672.574,1406.88 672.583,1406.88 672.592,1406.88 672.601,1406.88 672.61,1406.88 672.62,1406.88 672.629,1406.88 672.638,1406.88 672.647,1406.88 672.656,1406.88 672.665,1406.88 672.675,1406.88 672.684,1406.88 672.693,1406.88 672.702,1406.88 672.711,1406.88 672.721,1406.88 672.73,1406.88 672.739,1406.88 672.748,1406.88 672.757,1406.88 672.767,1406.88 672.776,1406.88 672.785,1406.88 672.794,1406.88 672.803,1406.88 672.813,1406.88 672.822,1406.88 672.831,1406.88 672.84,1406.88 672.849,1406.88 672.858,1406.88 672.868,1406.88 672.877,1406.88 672.886,1406.88 672.895,1406.88 672.904,1406.88 672.914,1406.88 672.923,1406.88 672.932,1406.88 672.941,1406.88 672.95,1406.88 672.96,1406.88 672.969,1406.88 672.978,1406.88 672.987,1406.88 672.996,1406.88 673.005,1406.88 673.015,1406.88 673.024,1406.88 673.033,1406.88 673.042,1406.88 673.051,1406.88 673.061,1406.88 673.07,1406.88 673.079,1406.88 673.088,1406.88 673.097,1406.88 673.107,1406.88 673.116,1406.88 673.125,1406.88 673.134,1406.88 673.143,1406.88 673.153,1406.88 673.162,1406.88 673.171,1406.88 673.18,1406.88 673.189,1406.88 673.198,1406.88 673.208,1406.88 673.217,1406.88 673.226,1406.88 673.235,1406.88 673.244,1406.88 673.254,1406.88 673.263,1406.88 673.272,1406.88 673.281,1406.88 673.29,1406.88 673.3,1406.88 673.309,1406.88 673.318,1406.88 673.327,1406.88 673.336,1406.88 673.345,1406.88 673.355,1406.88 673.364,1406.88 673.373,1406.88 673.382,1406.88 673.391,1406.88 673.401,1406.88 673.41,1406.88 673.419,1406.88 673.428,1406.88 673.437,1406.88 673.447,1406.88 673.456,1406.88 673.465,1406.88 673.474,1406.88 673.483,1406.88 673.493,1406.88 673.502,1406.88 673.511,1406.88 673.52,1406.88 673.529,1406.88 673.538,1406.88 673.548,1406.88 673.557,1406.88 673.566,1406.88 673.575,1406.88 673.584,1406.88 673.594,1406.88 673.603,1406.88 673.612,1406.88 673.621,1406.88 673.63,1406.88 673.64,1406.88 673.649,1406.88 673.658,1406.88 673.667,1406.88 673.676,1406.88 673.685,1406.88 673.695,1406.88 673.704,1406.88 673.713,1406.88 673.722,1406.88 673.731,1406.88 673.741,1406.88 673.75,1406.88 673.759,1406.88 673.768,1406.88 673.777,1406.88 673.787,1406.88 673.796,1406.88 673.805,1406.88 673.814,1406.88 673.823,1406.88 673.833,1406.88 673.842,1406.88 673.851,1406.88 673.86,1406.88 673.869,1406.88 673.878,1406.88 673.888,1406.88 673.897,1406.88 673.906,1406.88 673.915,1406.88 673.924,1406.88 673.934,1406.88 673.943,1406.88 673.952,1406.88 673.961,1406.88 673.97,1406.88 673.98,1406.88 673.989,1406.88 673.998,1406.88 674.007,1406.88 674.016,1406.88 674.025,1406.88 674.035,1406.88 674.044,1406.88 674.053,1406.88 674.062,1406.88 674.071,1406.88 674.081,1406.88 674.09,1406.88 674.099,1406.88 674.108,1406.88 674.117,1406.88 674.127,1406.88 674.136,1406.88 674.145,1406.88 674.154,1406.88 674.163,1406.88 674.173,1406.88 674.182,1406.88 674.191,1406.88 674.2,1406.88 674.209,1406.88 674.218,1406.88 674.228,1406.88 674.237,1406.88 674.246,1406.88 674.255,1406.88 674.264,1406.88 674.274,1406.88 674.283,1406.88 674.292,1406.88 674.301,1406.88 674.31,1406.88 674.32,1406.88 674.329,1406.88 674.338,1406.88 674.347,1406.88 674.356,1406.88 674.366,1406.88 674.375,1406.88 674.384,1406.88 674.393,1406.88 674.402,1406.88 674.411,1406.88 674.421,1406.88 674.43,1406.88 674.439,1406.88 674.448,1406.88 674.457,1406.88 674.467,1406.88 674.476,1406.88 674.485,1406.88 674.494,1406.88 674.503,1406.88 674.513,1406.88 674.522,1406.88 674.531,1406.88 674.54,1406.88 674.549,1406.88 674.558,1406.88 674.568,1406.88 674.577,1406.88 674.586,1406.88 674.595,1406.88 674.604,1406.88 674.614,1406.88 674.623,1406.88 674.632,1406.88 674.641,1406.88 674.65,1406.88 674.66,1406.88 674.669,1406.88 674.678,1406.88 674.687,1406.88 674.696,1406.88 674.706,1406.88 674.715,1406.88 674.724,1406.88 674.733,1406.88 674.742,1406.88 674.751,1406.88 674.761,1406.88 674.77,1406.88 674.779,1406.88 674.788,1406.88 674.797,1406.88 674.807,1406.88 674.816,1406.88 674.825,1406.88 674.834,1406.88 674.843,1406.88 674.853,1406.88 674.862,1406.88 674.871,1406.88 674.88,1406.88 674.889,1406.88 674.898,1406.88 674.908,1406.88 674.917,1406.88 674.926,1406.88 674.935,1406.88 674.944,1406.88 674.954,1406.88 674.963,1406.88 674.972,1406.88 674.981,1406.88 674.99,1406.88 675,1406.88 675.009,1406.88 675.018,1406.88 675.027,1406.88 675.036,1406.88 675.046,1406.88 675.055,1406.88 675.064,1406.88 675.073,1406.88 675.082,1406.88 675.091,1406.88 675.101,1406.88 675.11,1406.88 675.119,1406.88 675.128,1406.88 675.137,1406.88 675.147,1406.88 675.156,1406.88 675.165,1406.88 675.174,1406.88 675.183,1406.88 675.193,1406.88 675.202,1406.88 675.211,1406.88 675.22,1406.88 675.229,1406.88 675.238,1406.88 675.248,1406.88 675.257,1406.88 675.266,1406.88 675.275,1406.88 675.284,1406.88 675.294,1406.88 675.303,1406.88 675.312,1406.88 675.321,1406.88 675.33,1406.88 675.34,1406.88 675.349,1406.88 675.358,1406.88 675.367,1406.88 675.376,1406.88 675.386,1406.88 675.395,1406.88 675.404,1406.88 675.413,1406.88 675.422,1406.88 675.431,1406.88 675.441,1406.88 675.45,1406.88 675.459,1406.88 675.468,1406.88 675.477,1406.88 675.487,1406.88 675.496,1406.88 675.505,1406.88 675.514,1406.88 675.523,1406.88 675.533,1406.88 675.542,1406.88 675.551,1406.88 675.56,1406.88 675.569,1406.88 675.578,1406.88 675.588,1406.88 675.597,1406.88 675.606,1406.88 675.615,1406.88 675.624,1406.88 675.634,1406.88 675.643,1406.88 675.652,1406.88 675.661,1406.88 675.67,1406.88 675.68,1406.88 675.689,1406.88 675.698,1406.88 675.707,1406.88 675.716,1406.88 675.726,1406.88 675.735,1406.88 675.744,1406.88 675.753,1406.88 675.762,1406.88 675.771,1406.88 675.781,1406.88 675.79,1406.88 675.799,1406.88 675.808,1406.88 675.817,1406.88 675.827,1406.88 675.836,1406.88 675.845,1406.88 675.854,1406.88 675.863,1406.88 675.873,1406.88 675.882,1406.88 675.891,1406.88 675.9,1406.88 675.909,1406.88 675.918,1406.88 675.928,1406.88 675.937,1406.88 675.946,1406.88 675.955,1406.88 675.964,1406.88 675.974,1406.88 675.983,1406.88 675.992,1406.88 676.001,1406.88 676.01,1406.88 676.02,1406.88 676.029,1406.88 676.038,1406.88 676.047,1406.88 676.056,1406.88 676.066,1406.88 676.075,1406.88 676.084,1406.88 676.093,1406.88 676.102,1406.88 676.111,1406.88 676.121,1406.88 676.13,1406.88 676.139,1406.88 676.148,1406.88 676.157,1406.88 676.167,1406.88 676.176,1406.88 676.185,1406.88 676.194,1406.88 676.203,1406.88 676.213,1406.88 676.222,1406.88 676.231,1406.88 676.24,1406.88 676.249,1406.88 676.258,1406.88 676.268,1406.88 676.277,1406.88 676.286,1406.88 676.295,1406.88 676.304,1406.88 676.314,1406.88 676.323,1406.88 676.332,1406.88 676.341,1406.88 676.35,1406.88 676.36,1406.88 676.369,1406.88 676.378,1406.88 676.387,1406.88 676.396,1406.88 676.406,1406.88 676.415,1406.88 676.424,1406.88 676.433,1406.88 676.442,1406.88 676.451,1406.88 676.461,1406.88 676.47,1406.88 676.479,1406.88 676.488,1406.88 676.497,1406.88 676.507,1406.88 676.516,1406.88 676.525,1406.88 676.534,1406.88 676.543,1406.88 676.553,1406.88 676.562,1406.88 676.571,1406.88 676.58,1406.88 676.589,1406.88 676.599,1406.88 676.608,1406.88 676.617,1406.88 676.626,1406.88 676.635,1406.88 676.644,1406.88 676.654,1406.88 676.663,1406.88 676.672,1406.88 676.681,1406.88 676.69,1406.88 676.7,1406.88 676.709,1406.88 676.718,1406.88 676.727,1406.88 676.736,1406.88 676.746,1406.88 676.755,1406.88 676.764,1406.88 676.773,1406.88 676.782,1406.88 676.791,1406.88 676.801,1406.88 676.81,1406.88 676.819,1406.88 676.828,1406.88 676.837,1406.88 676.847,1406.88 676.856,1406.88 676.865,1406.88 676.874,1406.88 676.883,1406.88 676.893,1406.88 676.902,1406.88 676.911,1406.88 676.92,1406.88 676.929,1406.88 676.939,1406.88 676.948,1406.88 676.957,1406.88 676.966,1406.88 676.975,1406.88 676.984,1406.88 676.994,1406.88 677.003,1406.88 677.012,1406.88 677.021,1406.88 677.03,1406.88 677.04,1406.88 677.049,1406.88 677.058,1406.88 677.067,1406.88 677.076,1406.88 677.086,1406.88 677.095,1406.88 677.104,1406.88 677.113,1406.88 677.122,1406.88 677.131,1406.88 677.141,1406.88 677.15,1406.88 677.159,1406.88 677.168,1406.88 677.177,1406.88 677.187,1406.88 677.196,1406.88 677.205,1406.88 677.214,1406.88 677.223,1406.88 677.233,1406.88 677.242,1406.88 677.251,1406.88 677.26,1406.88 677.269,1406.88 677.279,1406.88 677.288,1406.88 677.297,1406.88 677.306,1406.88 677.315,1406.88 677.324,1406.88 677.334,1406.88 677.343,1406.88 677.352,1406.88 677.361,1406.88 677.37,1406.88 677.38,1406.88 677.389,1406.88 677.398,1406.88 677.407,1406.88 677.416,1406.88 677.426,1406.88 677.435,1406.88 677.444,1406.88 677.453,1406.88 677.462,1406.88 677.471,1406.88 677.481,1406.88 677.49,1406.88 677.499,1406.88 677.508,1406.88 677.517,1406.88 677.527,1406.88 677.536,1406.88 677.545,1406.88 677.554,1406.88 677.563,1406.88 677.573,1406.88 677.582,1406.88 677.591,1406.88 677.6,1406.88 677.609,1406.88 677.619,1406.88 677.628,1406.88 677.637,1406.88 677.646,1406.88 677.655,1406.88 677.664,1406.88 677.674,1406.88 677.683,1406.88 677.692,1406.88 677.701,1406.88 677.71,1406.88 677.72,1406.88 677.729,1406.88 677.738,1406.88 677.747,1406.88 677.756,1406.88 677.766,1406.88 677.775,1406.88 677.784,1406.88 677.793,1406.88 677.802,1406.88 677.811,1406.88 677.821,1406.88 677.83,1406.88 677.839,1406.88 677.848,1406.88 677.857,1406.88 677.867,1406.88 677.876,1406.88 677.885,1406.88 677.894,1406.88 677.903,1406.88 677.913,1406.88 677.922,1406.88 677.931,1406.88 677.94,1406.88 677.949,1406.88 677.959,1406.88 677.968,1406.88 677.977,1406.88 677.986,1406.88 677.995,1406.88 678.004,1406.88 678.014,1406.88 678.023,1406.88 678.032,1406.88 678.041,1406.88 678.05,1406.88 678.06,1406.88 678.069,1406.88 678.078,1406.88 678.087,1406.88 678.096,1406.88 678.106,1406.88 678.115,1406.88 678.124,1406.88 678.133,1406.88 678.142,1406.88 678.151,1406.88 678.161,1406.88 678.17,1406.88 678.179,1406.88 678.188,1406.88 678.197,1406.88 678.207,1406.88 678.216,1406.88 678.225,1406.88 678.234,1406.88 678.243,1406.88 678.253,1406.88 678.262,1406.88 678.271,1406.88 678.28,1406.88 678.289,1406.88 678.299,1406.88 678.308,1406.88 678.317,1406.88 678.326,1406.88 678.335,1406.88 678.344,1406.88 678.354,1406.88 678.363,1406.88 678.372,1406.88 678.381,1406.88 678.39,1406.88 678.4,1406.88 678.409,1406.88 678.418,1406.88 678.427,1406.88 678.436,1406.88 678.446,1406.88 678.455,1406.88 678.464,1406.88 678.473,1406.88 678.482,1406.88 678.491,1406.88 678.501,1406.88 678.51,1406.88 678.519,1406.88 678.528,1406.88 678.537,1406.88 678.547,1406.88 678.556,1406.88 678.565,1406.88 678.574,1406.88 678.583,1406.88 678.593,1406.88 678.602,1406.88 678.611,1406.88 678.62,1406.88 678.629,1406.88 678.639,1406.88 678.648,1406.88 678.657,1406.88 678.666,1406.88 678.675,1406.88 678.684,1406.88 678.694,1406.88 678.703,1406.88 678.712,1406.88 678.721,1406.88 678.73,1406.88 678.74,1406.88 678.749,1406.88 678.758,1406.88 678.767,1406.88 678.776,1406.88 678.786,1406.88 678.795,1406.88 678.804,1406.88 678.813,1406.88 678.822,1406.88 678.831,1406.88 678.841,1406.88 678.85,1406.88 678.859,1406.88 678.868,1406.88 678.877,1406.88 678.887,1406.88 678.896,1406.88 678.905,1406.88 678.914,1406.88 678.923,1406.88 678.933,1406.88 678.942,1406.88 678.951,1406.88 678.96,1406.88 678.969,1406.88 678.979,1406.88 678.988,1406.88 678.997,1406.88 679.006,1406.88 679.015,1406.88 679.024,1406.88 679.034,1406.88 679.043,1406.88 679.052,1406.88 679.061,1406.88 679.07,1406.88 679.08,1406.88 679.089,1406.88 679.098,1406.88 679.107,1406.88 679.116,1406.88 679.126,1406.88 679.135,1406.88 679.144,1406.88 679.153,1406.88 679.162,1406.88 679.172,1406.88 679.181,1406.88 679.19,1406.88 679.199,1406.88 679.208,1406.88 679.217,1406.88 679.227,1406.88 679.236,1406.88 679.245,1406.88 679.254,1406.88 679.263,1406.88 679.273,1406.88 679.282,1406.88 679.291,1406.88 679.3,1406.88 679.309,1406.88 679.319,1406.88 679.328,1406.88 679.337,1406.88 679.346,1406.88 679.355,1406.88 679.364,1406.88 679.374,1406.88 679.383,1406.88 679.392,1406.88 679.401,1406.88 679.41,1406.88 679.42,1406.88 679.429,1406.88 679.438,1406.88 679.447,1406.88 679.456,1406.88 679.466,1406.88 679.475,1406.88 679.484,1406.88 679.493,1406.88 679.502,1406.88 679.512,1406.88 679.521,1406.88 679.53,1406.88 679.539,1406.88 679.548,1406.88 679.557,1406.88 679.567,1406.88 679.576,1406.88 679.585,1406.88 679.594,1406.88 679.603,1406.88 679.613,1406.88 679.622,1406.88 679.631,1406.88 679.64,1406.88 679.649,1406.88 679.659,1406.88 679.668,1406.88 679.677,1406.88 679.686,1406.88 679.695,1406.88 679.704,1406.88 679.714,1406.88 679.723,1406.88 679.732,1406.88 679.741,1406.88 679.75,1406.88 679.76,1406.88 679.769,1406.88 679.778,1406.88 679.787,1406.88 679.796,1406.88 679.806,1406.88 679.815,1406.88 679.824,1406.88 679.833,1406.88 679.842,1406.88 679.852,1406.88 679.861,1406.88 679.87,1406.88 679.879,1406.88 679.888,1406.88 679.897,1406.88 679.907,1406.88 679.916,1406.88 679.925,1406.88 679.934,1406.88 679.943,1406.88 679.953,1406.88 679.962,1406.88 679.971,1406.88 679.98,1406.88 679.989,1406.88 679.999,1406.88 680.008,1406.88 680.017,1406.88 680.026,1406.88 680.035,1406.88 680.044,1406.88 680.054,1406.88 680.063,1406.88 680.072,1406.88 680.081,1406.88 680.09,1406.88 680.1,1406.88 680.109,1406.88 680.118,1406.88 680.127,1406.88 680.136,1406.88 680.146,1406.88 680.155,1406.88 680.164,1406.88 680.173,1406.88 680.182,1406.88 680.192,1406.88 680.201,1406.88 680.21,1406.88 680.219,1406.88 680.228,1406.88 680.237,1406.88 680.247,1406.88 680.256,1406.88 680.265,1406.88 680.274,1406.88 680.283,1406.88 680.293,1406.88 680.302,1406.88 680.311,1406.88 680.32,1406.88 680.329,1406.88 680.339,1406.88 680.348,1406.88 680.357,1406.88 680.366,1406.88 680.375,1406.88 680.384,1406.88 680.394,1406.88 680.403,1406.88 680.412,1406.88 680.421,1406.88 680.43,1406.88 680.44,1406.88 680.449,1406.88 680.458,1406.88 680.467,1406.88 680.476,1406.88 680.486,1406.88 680.495,1406.88 680.504,1406.88 680.513,1406.88 680.522,1406.88 680.532,1406.88 680.541,1406.88 680.55,1406.88 680.559,1406.88 680.568,1406.88 680.577,1406.88 680.587,1406.88 680.596,1406.88 680.605,1406.88 680.614,1406.88 680.623,1406.88 680.633,1406.88 680.642,1406.88 680.651,1406.88 680.66,1406.88 680.669,1406.88 680.679,1406.88 680.688,1406.88 680.697,1406.88 680.706,1406.88 680.715,1406.88 680.724,1406.88 680.734,1406.88 680.743,1406.88 680.752,1406.88 680.761,1406.88 680.77,1406.88 680.78,1406.88 680.789,1406.88 680.798,1406.88 680.807,1406.88 680.816,1406.88 680.826,1406.88 680.835,1406.88 680.844,1406.88 680.853,1406.88 680.862,1406.88 680.872,1406.88 680.881,1406.88 680.89,1406.88 680.899,1406.88 680.908,1406.88 680.917,1406.88 680.927,1406.88 680.936,1406.88 680.945,1406.88 680.954,1406.88 680.963,1406.88 680.973,1406.88 680.982,1406.88 680.991,1406.88 681,1406.88 681.009,1406.88 681.019,1406.88 681.028,1406.88 681.037,1406.88 681.046,1406.88 681.055,1406.88 681.064,1406.88 681.074,1406.88 681.083,1406.88 681.092,1406.88 681.101,1406.88 681.11,1406.88 681.12,1406.88 681.129,1406.88 681.138,1406.88 681.147,1406.88 681.156,1406.88 681.166,1406.88 681.175,1406.88 681.184,1406.88 681.193,1406.88 681.202,1406.88 681.212,1406.88 681.221,1406.88 681.23,1406.88 681.239,1406.88 681.248,1406.88 681.257,1406.88 681.267,1406.88 681.276,1406.88 681.285,1406.88 681.294,1406.88 681.303,1406.88 681.313,1406.88 681.322,1406.88 681.331,1406.88 681.34,1406.88 681.349,1406.88 681.359,1406.88 681.368,1406.88 681.377,1406.88 681.386,1406.88 681.395,1406.88 681.404,1406.88 681.414,1406.88 681.423,1406.88 681.432,1406.88 681.441,1406.88 681.45,1406.88 681.46,1406.88 681.469,1406.88 681.478,1406.88 681.487,1406.88 681.496,1406.88 681.506,1406.88 681.515,1406.88 681.524,1406.88 681.533,1406.88 681.542,1406.88 681.552,1406.88 681.561,1406.88 681.57,1406.88 681.579,1406.88 681.588,1406.88 681.597,1406.88 681.607,1406.88 681.616,1406.88 681.625,1406.88 681.634,1406.88 681.643,1406.88 681.653,1406.88 681.662,1406.88 681.671,1406.88 681.68,1406.88 681.689,1406.88 681.699,1406.88 681.708,1406.88 681.717,1406.88 681.726,1406.88 681.735,1406.88 681.745,1406.88 681.754,1406.88 681.763,1406.88 681.772,1406.88 681.781,1406.88 681.79,1406.88 681.8,1406.88 681.809,1406.88 681.818,1406.88 681.827,1406.88 681.836,1406.88 681.846,1406.88 681.855,1406.88 681.864,1406.88 681.873,1406.88 681.882,1406.88 681.892,1406.88 681.901,1406.88 681.91,1406.88 681.919,1406.88 681.928,1406.88 681.937,1406.88 681.947,1406.88 681.956,1406.88 681.965,1406.88 681.974,1406.88 681.983,1406.88 681.993,1406.88 682.002,1406.88 682.011,1406.88 682.02,1406.88 682.029,1406.88 682.039,1406.88 682.048,1406.88 682.057,1406.88 682.066,1406.88 682.075,1406.88 682.085,1406.88 682.094,1406.88 682.103,1406.88 682.112,1406.88 682.121,1406.88 682.13,1406.88 682.14,1406.88 682.149,1406.88 682.158,1406.88 682.167,1406.88 682.176,1406.88 682.186,1406.88 682.195,1406.88 682.204,1406.88 682.213,1406.88 682.222,1406.88 682.232,1406.88 682.241,1406.88 682.25,1406.88 682.259,1406.88 682.268,1406.88 682.277,1406.88 682.287,1406.88 682.296,1406.88 682.305,1406.88 682.314,1406.88 682.323,1406.88 682.333,1406.88 682.342,1406.88 682.351,1406.88 682.36,1406.88 682.369,1406.88 682.379,1406.88 682.388,1406.88 682.397,1406.88 682.406,1406.88 682.415,1406.88 682.425,1406.88 682.434,1406.88 682.443,1406.88 682.452,1406.88 682.461,1406.88 682.47,1406.88 682.48,1406.88 682.489,1406.88 682.498,1406.88 682.507,1406.88 682.516,1406.88 682.526,1406.88 682.535,1406.88 682.544,1406.88 682.553,1406.88 682.562,1406.88 682.572,1406.88 682.581,1406.88 682.59,1406.88 682.599,1406.88 682.608,1406.88 682.617,1406.88 682.627,1406.88 682.636,1406.88 682.645,1406.88 682.654,1406.88 682.663,1406.88 682.673,1406.88 682.682,1406.88 682.691,1406.88 682.7,1406.88 682.709,1406.88 682.719,1406.88 682.728,1406.88 682.737,1406.88 682.746,1406.88 682.755,1406.88 682.765,1406.88 682.774,1406.88 682.783,1406.88 682.792,1406.88 682.801,1406.88 682.81,1406.88 682.82,1406.88 682.829,1406.88 682.838,1406.88 682.847,1406.88 682.856,1406.88 682.866,1406.88 682.875,1406.88 682.884,1406.88 682.893,1406.88 682.902,1406.88 682.912,1406.88 682.921,1406.88 682.93,1406.88 682.939,1406.88 682.948,1406.88 682.957,1406.88 682.967,1406.88 682.976,1406.88 682.985,1406.88 682.994,1406.88 683.003,1406.88 683.013,1406.88 683.022,1406.88 683.031,1406.88 683.04,1406.88 683.049,1406.88 683.059,1406.88 683.068,1406.88 683.077,1406.88 683.086,1406.88 683.095,1406.88 683.105,1406.88 683.114,1406.88 683.123,1406.88 683.132,1406.88 683.141,1406.88 683.15,1406.88 683.16,1406.88 683.169,1406.88 683.178,1406.88 683.187,1406.88 683.196,1406.88 683.206,1406.88 683.215,1406.88 683.224,1406.88 683.233,1406.88 683.242,1406.88 683.252,1406.88 683.261,1406.88 683.27,1406.88 683.279,1406.88 683.288,1406.88 683.297,1406.88 683.307,1406.88 683.316,1406.88 683.325,1406.88 683.334,1406.88 683.343,1406.88 683.353,1406.88 683.362,1406.88 683.371,1406.88 683.38,1406.88 683.389,1406.88 683.399,1406.88 683.408,1406.88 683.417,1406.88 683.426,1406.88 683.435,1406.88 683.445,1406.88 683.454,1406.88 683.463,1406.88 683.472,1406.88 683.481,1406.88 683.49,1406.88 683.5,1406.88 683.509,1406.88 683.518,1406.88 683.527,1406.88 683.536,1406.88 683.546,1406.88 683.555,1406.88 683.564,1406.88 683.573,1406.88 683.582,1406.88 683.592,1406.88 683.601,1406.88 683.61,1406.88 683.619,1406.88 683.628,1406.88 683.637,1406.88 683.647,1406.88 683.656,1406.88 683.665,1406.88 683.674,1406.88 683.683,1406.88 683.693,1406.88 683.702,1406.88 683.711,1406.88 683.72,1406.88 683.729,1406.88 683.739,1406.88 683.748,1406.88 683.757,1406.88 683.766,1406.88 683.775,1406.88 683.785,1406.88 683.794,1406.88 683.803,1406.88 683.812,1406.88 683.821,1406.88 683.83,1406.88 683.84,1406.88 683.849,1406.88 683.858,1406.88 683.867,1406.88 683.876,1406.88 683.886,1406.88 683.895,1406.88 683.904,1406.88 683.913,1406.88 683.922,1406.88 683.932,1406.88 683.941,1406.88 683.95,1406.88 683.959,1406.88 683.968,1406.88 683.978,1406.88 683.987,1406.88 683.996,1406.88 684.005,1406.88 684.014,1406.88 684.023,1406.88 684.033,1406.88 684.042,1406.88 684.051,1406.88 684.06,1406.88 684.069,1406.88 684.079,1406.88 684.088,1406.88 684.097,1406.88 684.106,1406.88 684.115,1406.88 684.125,1406.88 684.134,1406.88 684.143,1406.88 684.152,1406.88 684.161,1406.88 684.17,1406.88 684.18,1406.88 684.189,1406.88 684.198,1406.88 684.207,1406.88 684.216,1406.88 684.226,1406.88 684.235,1406.88 684.244,1406.88 684.253,1406.88 684.262,1406.88 684.272,1406.88 684.281,1406.88 684.29,1406.88 684.299,1406.88 684.308,1406.88 684.318,1406.88 684.327,1406.88 684.336,1406.88 684.345,1406.88 684.354,1406.88 684.363,1406.88 684.373,1406.88 684.382,1406.88 684.391,1406.88 684.4,1406.88 684.409,1406.88 684.419,1406.88 684.428,1406.88 684.437,1406.88 684.446,1406.88 684.455,1406.88 684.465,1406.88 684.474,1406.88 684.483,1406.88 684.492,1406.88 684.501,1406.88 684.51,1406.88 684.52,1406.88 684.529,1406.88 684.538,1406.88 684.547,1406.88 684.556,1406.88 684.566,1406.88 684.575,1406.88 684.584,1406.88 684.593,1406.88 684.602,1406.88 684.612,1406.88 684.621,1406.88 684.63,1406.88 684.639,1406.88 684.648,1406.88 684.658,1406.88 684.667,1406.88 684.676,1406.88 684.685,1406.88 684.694,1406.88 684.703,1406.88 684.713,1406.88 684.722,1406.88 684.731,1406.88 684.74,1406.88 684.749,1406.88 684.759,1406.88 684.768,1406.88 684.777,1406.88 684.786,1406.88 684.795,1406.88 684.805,1406.88 684.814,1406.88 684.823,1406.88 684.832,1406.88 684.841,1406.88 684.85,1406.88 684.86,1406.88 684.869,1406.88 684.878,1406.88 684.887,1406.88 684.896,1406.88 684.906,1406.88 684.915,1406.88 684.924,1406.88 684.933,1406.88 684.942,1406.88 684.952,1406.88 684.961,1406.88 684.97,1406.88 684.979,1406.88 684.988,1406.88 684.998,1406.88 685.007,1406.88 685.016,1406.88 685.025,1406.88 685.034,1406.88 685.043,1406.88 685.053,1406.88 685.062,1406.88 685.071,1406.88 685.08,1406.88 685.089,1406.88 685.099,1406.88 685.108,1406.88 685.117,1406.88 685.126,1406.88 685.135,1406.88 685.145,1406.88 685.154,1406.88 685.163,1406.88 685.172,1406.88 685.181,1406.88 685.19,1406.88 685.2,1406.88 685.209,1406.88 685.218,1406.88 685.227,1406.88 685.236,1406.88 685.246,1406.88 685.255,1406.88 685.264,1406.88 685.273,1406.88 685.282,1406.88 685.292,1406.88 685.301,1406.88 685.31,1406.88 685.319,1406.88 685.328,1406.88 685.338,1406.88 685.347,1406.88 685.356,1406.88 685.365,1406.88 685.374,1406.88 685.383,1406.88 685.393,1406.88 685.402,1406.88 685.411,1406.88 685.42,1406.88 685.429,1406.88 685.439,1406.88 685.448,1406.88 685.457,1406.88 685.466,1406.88 685.475,1406.88 685.485,1406.88 685.494,1406.88 685.503,1406.88 685.512,1406.88 685.521,1406.88 685.53,1406.88 685.54,1406.88 685.549,1406.88 685.558,1406.88 685.567,1406.88 685.576,1406.88 685.586,1406.88 685.595,1406.88 685.604,1406.88 685.613,1406.88 685.622,1406.88 685.632,1406.88 685.641,1406.88 685.65,1406.88 685.659,1406.88 685.668,1406.88 685.678,1406.88 685.687,1406.88 685.696,1406.88 685.705,1406.88 685.714,1406.88 685.723,1406.88 685.733,1406.88 685.742,1406.88 685.751,1406.88 685.76,1406.88 685.769,1406.88 685.779,1406.88 685.788,1406.88 685.797,1406.88 685.806,1406.88 685.815,1406.88 685.825,1406.88 685.834,1406.88 685.843,1406.88 685.852,1406.88 685.861,1406.88 685.87,1406.88 685.88,1406.88 685.889,1406.88 685.898,1406.88 685.907,1406.88 685.916,1406.88 685.926,1406.88 685.935,1406.88 685.944,1406.88 685.953,1406.88 685.962,1406.88 685.972,1406.88 685.981,1406.88 685.99,1406.88 685.999,1406.88 686.008,1406.88 686.018,1406.88 686.027,1406.88 686.036,1406.88 686.045,1406.88 686.054,1406.88 686.063,1406.88 686.073,1406.88 686.082,1406.88 686.091,1406.88 686.1,1406.88 686.109,1406.88 686.119,1406.88 686.128,1406.88 686.137,1406.88 686.146,1406.88 686.155,1406.88 686.165,1406.88 686.174,1406.88 686.183,1406.88 686.192,1406.88 686.201,1406.88 686.21,1406.88 686.22,1406.88 686.229,1406.88 686.238,1406.88 686.247,1406.88 686.256,1406.88 686.266,1406.88 686.275,1406.88 686.284,1406.88 686.293,1406.88 686.302,1406.88 686.312,1406.88 686.321,1406.88 686.33,1406.88 686.339,1406.88 686.348,1406.88 686.358,1406.88 686.367,1406.88 686.376,1406.88 686.385,1406.88 686.394,1406.88 686.403,1406.88 686.413,1406.88 686.422,1406.88 686.431,1406.88 686.44,1406.88 686.449,1406.88 686.459,1406.88 686.468,1406.88 686.477,1406.88 686.486,1406.88 686.495,1406.88 686.505,1406.88 686.514,1406.88 686.523,1406.88 686.532,1406.88 686.541,1406.88 686.551,1406.88 686.56,1406.88 686.569,1406.88 686.578,1406.88 686.587,1406.88 686.596,1406.88 686.606,1406.88 686.615,1406.88 686.624,1406.88 686.633,1406.88 686.642,1406.88 686.652,1406.88 686.661,1406.88 686.67,1406.88 686.679,1406.88 686.688,1406.88 686.698,1406.88 686.707,1406.88 686.716,1406.88 686.725,1406.88 686.734,1406.88 686.743,1406.88 686.753,1406.88 686.762,1406.88 686.771,1406.88 686.78,1406.88 686.789,1406.88 686.799,1406.88 686.808,1406.88 686.817,1406.88 686.826,1406.88 686.835,1406.88 686.845,1406.88 686.854,1406.88 686.863,1406.88 686.872,1406.88 686.881,1406.88 686.891,1406.88 686.9,1406.88 686.909,1406.88 686.918,1406.88 686.927,1406.88 686.936,1406.88 686.946,1406.88 686.955,1406.88 686.964,1406.88 686.973,1406.88 686.982,1406.88 686.992,1406.88 687.001,1406.88 687.01,1406.88 687.019,1406.88 687.028,1406.88 687.038,1406.88 687.047,1406.88 687.056,1406.88 687.065,1406.88 687.074,1406.88 687.083,1406.88 687.093,1406.88 687.102,1406.88 687.111,1406.88 687.12,1406.88 687.129,1406.88 687.139,1406.88 687.148,1406.88 687.157,1406.88 687.166,1406.88 687.175,1406.88 687.185,1406.88 687.194,1406.88 687.203,1406.88 687.212,1406.88 687.221,1406.88 687.231,1406.88 687.24,1406.88 687.249,1406.88 687.258,1406.88 687.267,1406.88 687.276,1406.88 687.286,1406.88 687.295,1406.88 687.304,1406.88 687.313,1406.88 687.322,1406.88 687.332,1406.88 687.341,1406.88 687.35,1406.88 687.359,1406.88 687.368,1406.88 687.378,1406.88 687.387,1406.88 687.396,1406.88 687.405,1406.88 687.414,1406.88 687.423,1406.88 687.433,1406.88 687.442,1406.88 687.451,1406.88 687.46,1406.88 687.469,1406.88 687.479,1406.88 687.488,1406.88 687.497,1406.88 687.506,1406.88 687.515,1406.88 687.525,1406.88 687.534,1406.88 687.543,1406.88 687.552,1406.88 687.561,1406.88 687.571,1406.88 687.58,1406.88 687.589,1406.88 687.598,1406.88 687.607,1406.88 687.616,1406.88 687.626,1406.88 687.635,1406.88 687.644,1406.88 687.653,1406.88 687.662,1406.88 687.672,1406.88 687.681,1406.88 687.69,1406.88 687.699,1406.88 687.708,1406.88 687.718,1406.88 687.727,1406.88 687.736,1406.88 687.745,1406.88 687.754,1406.88 687.763,1406.88 687.773,1406.88 687.782,1406.88 687.791,1406.88 687.8,1406.88 687.809,1406.88 687.819,1406.88 687.828,1406.88 687.837,1406.88 687.846,1406.88 687.855,1406.88 687.865,1406.88 687.874,1406.88 687.883,1406.88 687.892,1406.88 687.901,1406.88 687.911,1406.88 687.92,1406.88 687.929,1406.88 687.938,1406.88 687.947,1406.88 687.956,1406.88 687.966,1406.88 687.975,1406.88 687.984,1406.88 687.993,1406.88 688.002,1406.88 688.012,1406.88 688.021,1406.88 688.03,1406.88 688.039,1406.88 688.048,1406.88 688.058,1406.88 688.067,1406.88 688.076,1406.88 688.085,1406.88 688.094,1406.88 688.103,1406.88 688.113,1406.88 688.122,1406.88 688.131,1406.88 688.14,1406.88 688.149,1406.88 688.159,1406.88 688.168,1406.88 688.177,1406.88 688.186,1406.88 688.195,1406.88 688.205,1406.88 688.214,1406.88 688.223,1406.88 688.232,1406.88 688.241,1406.88 688.251,1406.88 688.26,1406.88 688.269,1406.88 688.278,1406.88 688.287,1406.88 688.296,1406.88 688.306,1406.88 688.315,1406.88 688.324,1406.88 688.333,1406.88 688.342,1406.88 688.352,1406.88 688.361,1406.88 688.37,1406.88 688.379,1406.88 688.388,1406.88 688.398,1406.88 688.407,1406.88 688.416,1406.88 688.425,1406.88 688.434,1406.88 688.443,1406.88 688.453,1406.88 688.462,1406.88 688.471,1406.88 688.48,1406.88 688.489,1406.88 688.499,1406.88 688.508,1406.88 688.517,1406.88 688.526,1406.88 688.535,1406.88 688.545,1406.88 688.554,1406.88 688.563,1406.88 688.572,1406.88 688.581,1406.88 688.591,1406.88 688.6,1406.88 688.609,1406.88 688.618,1406.88 688.627,1406.88 688.636,1406.88 688.646,1406.88 688.655,1406.88 688.664,1406.88 688.673,1406.88 688.682,1406.88 688.692,1406.88 688.701,1406.88 688.71,1406.88 688.719,1406.88 688.728,1406.88 688.738,1406.88 688.747,1406.88 688.756,1406.88 688.765,1406.88 688.774,1406.88 688.783,1406.88 688.793,1406.88 688.802,1406.88 688.811,1406.88 688.82,1406.88 688.829,1406.88 688.839,1406.88 688.848,1406.88 688.857,1406.88 688.866,1406.88 688.875,1406.88 688.885,1406.88 688.894,1406.88 688.903,1406.88 688.912,1406.88 688.921,1406.88 688.931,1406.88 688.94,1406.88 688.949,1406.88 688.958,1406.88 688.967,1406.88 688.976,1406.88 688.986,1406.88 688.995,1406.88 689.004,1406.88 689.013,1406.88 689.022,1406.88 689.032,1406.88 689.041,1406.88 689.05,1406.88 689.059,1406.88 689.068,1406.88 689.078,1406.88 689.087,1406.88 689.096,1406.88 689.105,1406.88 689.114,1406.88 689.124,1406.88 689.133,1406.88 689.142,1406.88 689.151,1406.88 689.16,1406.88 689.169,1406.88 689.179,1406.88 689.188,1406.88 689.197,1406.88 689.206,1406.88 689.215,1406.88 689.225,1406.88 689.234,1406.88 689.243,1406.88 689.252,1406.88 689.261,1406.88 689.271,1406.88 689.28,1406.88 689.289,1406.88 689.298,1406.88 689.307,1406.88 689.316,1406.88 689.326,1406.88 689.335,1406.88 689.344,1406.88 689.353,1406.88 689.362,1406.88 689.372,1406.88 689.381,1406.88 689.39,1406.88 689.399,1406.88 689.408,1406.88 689.418,1406.88 689.427,1406.88 689.436,1406.88 689.445,1406.88 689.454,1406.88 689.464,1406.88 689.473,1406.88 689.482,1406.88 689.491,1406.88 689.5,1406.88 689.509,1406.88 689.519,1406.88 689.528,1406.88 689.537,1406.88 689.546,1406.88 689.555,1406.88 689.565,1406.88 689.574,1406.88 689.583,1406.88 689.592,1406.88 689.601,1406.88 689.611,1406.88 689.62,1406.88 689.629,1406.88 689.638,1406.88 689.647,1406.88 689.656,1406.88 689.666,1406.88 689.675,1406.88 689.684,1406.88 689.693,1406.88 689.702,1406.88 689.712,1406.88 689.721,1406.88 689.73,1406.88 689.739,1406.88 689.748,1406.88 689.758,1406.88 689.767,1406.88 689.776,1406.88 689.785,1406.88 689.794,1406.88 689.804,1406.88 689.813,1406.88 689.822,1406.88 689.831,1406.88 689.84,1406.88 689.849,1406.88 689.859,1406.88 689.868,1406.88 689.877,1406.88 689.886,1406.88 689.895,1406.88 689.905,1406.88 689.914,1406.88 689.923,1406.88 689.932,1406.88 689.941,1406.88 689.951,1406.88 689.96,1406.88 689.969,1406.88 689.978,1406.88 689.987,1406.88 689.996,1406.88 690.006,1406.88 690.015,1406.88 690.024,1406.88 690.033,1406.88 690.042,1406.88 690.052,1406.88 690.061,1406.88 690.07,1406.88 690.079,1406.88 690.088,1406.88 690.098,1406.88 690.107,1406.88 690.116,1406.88 690.125,1406.88 690.134,1406.88 690.144,1406.88 690.153,1406.88 690.162,1406.88 690.171,1406.88 690.18,1406.88 690.189,1406.88 690.199,1406.88 690.208,1406.88 690.217,1406.88 690.226,1406.88 690.235,1406.88 690.245,1406.88 690.254,1406.88 690.263,1406.88 690.272,1406.88 690.281,1406.88 690.291,1406.88 690.3,1406.88 690.309,1406.88 690.318,1406.88 690.327,1406.88 690.336,1406.88 690.346,1406.88 690.355,1406.88 690.364,1406.88 690.373,1406.88 690.382,1406.88 690.392,1406.88 690.401,1406.88 690.41,1406.88 690.419,1406.88 690.428,1406.88 690.438,1406.88 690.447,1406.88 690.456,1406.88 690.465,1406.88 690.474,1406.88 690.484,1406.88 690.493,1406.88 690.502,1406.88 690.511,1406.88 690.52,1406.88 690.529,1406.88 690.539,1406.88 690.548,1406.88 690.557,1406.88 690.566,1406.88 690.575,1406.88 690.585,1406.88 690.594,1406.88 690.603,1406.88 690.612,1406.88 690.621,1406.88 690.631,1406.88 690.64,1406.88 690.649,1406.88 690.658,1406.88 690.667,1406.88 690.676,1406.88 690.686,1406.88 690.695,1406.88 690.704,1406.88 690.713,1406.88 690.722,1406.88 690.732,1406.88 690.741,1406.88 690.75,1406.88 690.759,1406.88 690.768,1406.88 690.778,1406.88 690.787,1406.88 690.796,1406.88 690.805,1406.88 690.814,1406.88 690.824,1406.88 690.833,1406.88 690.842,1406.88 690.851,1406.88 690.86,1406.88 690.869,1406.88 690.879,1406.88 690.888,1406.88 690.897,1406.88 690.906,1406.88 690.915,1406.88 690.925,1406.88 690.934,1406.88 690.943,1406.88 690.952,1406.88 690.961,1406.88 690.971,1406.88 690.98,1406.88 690.989,1406.88 690.998,1406.88 691.007,1406.88 691.016,1406.88 691.026,1406.88 691.035,1406.88 691.044,1406.88 691.053,1406.88 691.062,1406.88 691.072,1406.88 691.081,1406.88 691.09,1406.88 691.099,1406.88 691.108,1406.88 691.118,1406.88 691.127,1406.88 691.136,1406.88 691.145,1406.88 691.154,1406.88 691.164,1406.88 691.173,1406.88 691.182,1406.88 691.191,1406.88 691.2,1406.88 691.209,1406.88 691.219,1406.88 691.228,1406.88 691.237,1406.88 691.246,1406.88 691.255,1406.88 691.265,1406.88 691.274,1406.88 691.283,1406.88 691.292,1406.88 691.301,1406.88 691.311,1406.88 691.32,1406.88 691.329,1406.88 691.338,1406.88 691.347,1406.88 691.357,1406.88 691.366,1406.88 691.375,1406.88 691.384,1406.88 691.393,1406.88 691.402,1406.88 691.412,1406.88 691.421,1406.88 691.43,1406.88 691.439,1406.88 691.448,1406.88 691.458,1406.88 691.467,1406.88 691.476,1406.88 691.485,1406.88 691.494,1406.88 691.504,1406.88 691.513,1406.88 691.522,1406.88 691.531,1406.88 691.54,1406.88 691.549,1406.88 691.559,1406.88 691.568,1406.88 691.577,1406.88 691.586,1406.88 691.595,1406.88 691.605,1406.88 691.614,1406.88 691.623,1406.88 691.632,1406.88 691.641,1406.88 691.651,1406.88 691.66,1406.88 691.669,1406.88 691.678,1406.88 691.687,1406.88 691.697,1406.88 691.706,1406.88 691.715,1406.88 691.724,1406.88 691.733,1406.88 691.742,1406.88 691.752,1406.88 691.761,1406.88 691.77,1406.88 691.779,1406.88 691.788,1406.88 691.798,1406.88 691.807,1406.88 691.816,1406.88 691.825,1406.88 691.834,1406.88 691.844,1406.88 691.853,1406.88 691.862,1406.88 691.871,1406.88 691.88,1406.88 691.889,1406.88 691.899,1406.88 691.908,1406.88 691.917,1406.88 691.926,1406.88 691.935,1406.88 691.945,1406.88 691.954,1406.88 691.963,1406.88 691.972,1406.88 691.981,1406.88 691.991,1406.88 692,1406.88 692.009,1406.88 692.018,1406.88 692.027,1406.88 692.037,1406.88 692.046,1406.88 692.055,1406.88 692.064,1406.88 692.073,1406.88 692.082,1406.88 692.092,1406.88 692.101,1406.88 692.11,1406.88 692.119,1406.88 692.128,1406.88 692.138,1406.88 692.147,1406.88 692.156,1406.88 692.165,1406.88 692.174,1406.88 692.184,1406.88 692.193,1406.88 692.202,1406.88 692.211,1406.88 692.22,1406.88 692.229,1406.88 692.239,1406.88 692.248,1406.88 692.257,1406.88 692.266,1406.88 692.275,1406.88 692.285,1406.88 692.294,1406.88 692.303,1406.88 692.312,1406.88 692.321,1406.88 692.331,1406.88 692.34,1406.88 692.349,1406.88 692.358,1406.88 692.367,1406.88 692.377,1406.88 692.386,1406.88 692.395,1406.88 692.404,1406.88 692.413,1406.88 692.422,1406.88 692.432,1406.88 692.441,1406.88 692.45,1406.88 692.459,1406.88 692.468,1406.88 692.478,1406.88 692.487,1406.88 692.496,1406.88 692.505,1406.88 692.514,1406.88 692.524,1406.88 692.533,1406.88 692.542,1406.88 692.551,1406.88 692.56,1406.88 692.569,1406.88 692.579,1406.88 692.588,1406.88 692.597,1406.88 692.606,1406.88 692.615,1406.88 692.625,1406.88 692.634,1406.88 692.643,1406.88 692.652,1406.88 692.661,1406.88 692.671,1406.88 692.68,1406.88 692.689,1406.88 692.698,1406.88 692.707,1406.88 692.717,1406.88 692.726,1406.88 692.735,1406.88 692.744,1406.88 692.753,1406.88 692.762,1406.88 692.772,1406.88 692.781,1406.88 692.79,1406.88 692.799,1406.88 692.808,1406.88 692.818,1406.88 692.827,1406.88 692.836,1406.88 692.845,1406.88 692.854,1406.88 692.864,1406.88 692.873,1406.88 692.882,1406.88 692.891,1406.88 692.9,1406.88 692.909,1406.88 692.919,1406.88 692.928,1406.88 692.937,1406.88 692.946,1406.88 692.955,1406.88 692.965,1406.88 692.974,1406.88 692.983,1406.88 692.992,1406.88 693.001,1406.88 693.011,1406.88 693.02,1406.88 693.029,1406.88 693.038,1406.88 693.047,1406.88 693.057,1406.88 693.066,1406.88 693.075,1406.88 693.084,1406.88 693.093,1406.88 693.102,1406.88 693.112,1406.88 693.121,1406.88 693.13,1406.88 693.139,1406.88 693.148,1406.88 693.158,1406.88 693.167,1406.88 693.176,1406.88 693.185,1406.88 693.194,1406.88 693.204,1406.88 693.213,1406.88 693.222,1406.88 693.231,1406.88 693.24,1406.88 693.249,1406.88 693.259,1406.88 693.268,1406.88 693.277,1406.88 693.286,1406.88 693.295,1406.88 693.305,1406.88 693.314,1406.88 693.323,1406.88 693.332,1406.88 693.341,1406.88 693.351,1406.88 693.36,1406.88 693.369,1406.88 693.378,1406.88 693.387,1406.88 693.397,1406.88 693.406,1406.88 693.415,1406.88 693.424,1406.88 693.433,1406.88 693.442,1406.88 693.452,1406.88 693.461,1406.88 693.47,1406.88 693.479,1406.88 693.488,1406.88 693.498,1406.88 693.507,1406.88 693.516,1406.88 693.525,1406.88 693.534,1406.88 693.544,1406.88 693.553,1406.88 693.562,1406.88 693.571,1406.88 693.58,1406.88 693.589,1406.88 693.599,1406.88 693.608,1406.88 693.617,1406.88 693.626,1406.88 693.635,1406.88 693.645,1406.88 693.654,1406.88 693.663,1406.88 693.672,1406.88 693.681,1406.88 693.691,1406.88 693.7,1406.88 693.709,1406.88 693.718,1406.88 693.727,1406.88 693.737,1406.88 693.746,1406.88 693.755,1406.88 693.764,1406.88 693.773,1406.88 693.782,1406.88 693.792,1406.88 693.801,1406.88 693.81,1406.88 693.819,1406.88 693.828,1406.88 693.838,1406.88 693.847,1406.88 693.856,1406.88 693.865,1406.88 693.874,1406.88 693.884,1406.88 693.893,1406.88 693.902,1406.88 693.911,1406.88 693.92,1406.88 693.93,1406.88 693.939,1406.88 693.948,1406.88 693.957,1406.88 693.966,1406.88 693.975,1406.88 693.985,1406.88 693.994,1406.88 694.003,1406.88 694.012,1406.88 694.021,1406.88 694.031,1406.88 694.04,1406.88 694.049,1406.88 694.058,1406.88 694.067,1406.88 694.077,1406.88 694.086,1406.88 694.095,1406.88 694.104,1406.88 694.113,1406.88 694.122,1406.88 694.132,1406.88 694.141,1406.88 694.15,1406.88 694.159,1406.88 694.168,1406.88 694.178,1406.88 694.187,1406.88 694.196,1406.88 694.205,1406.88 694.214,1406.88 694.224,1406.88 694.233,1406.88 694.242,1406.88 694.251,1406.88 694.26,1406.88 694.27,1406.88 694.279,1406.88 694.288,1406.88 694.297,1406.88 694.306,1406.88 694.315,1406.88 694.325,1406.88 694.334,1406.88 694.343,1406.88 694.352,1406.88 694.361,1406.88 694.371,1406.88 694.38,1406.88 694.389,1406.88 694.398,1406.88 694.407,1406.88 694.417,1406.88 694.426,1406.88 694.435,1406.88 694.444,1406.88 694.453,1406.88 694.462,1406.88 694.472,1406.88 694.481,1406.88 694.49,1406.88 694.499,1406.88 694.508,1406.88 694.518,1406.88 694.527,1406.88 694.536,1406.88 694.545,1406.88 694.554,1406.88 694.564,1406.88 694.573,1406.88 694.582,1406.88 694.591,1406.88 694.6,1406.88 694.61,1406.88 694.619,1406.88 694.628,1406.88 694.637,1406.88 694.646,1406.88 694.655,1406.88 694.665,1406.88 694.674,1406.88 694.683,1406.88 694.692,1406.88 694.701,1406.88 694.711,1406.88 694.72,1406.88 694.729,1406.88 694.738,1406.88 694.747,1406.88 694.757,1406.88 694.766,1406.88 694.775,1406.88 694.784,1406.88 694.793,1406.88 694.802,1406.88 694.812,1406.88 694.821,1406.88 694.83,1406.88 694.839,1406.88 694.848,1406.88 694.858,1406.88 694.867,1406.88 694.876,1406.88 694.885,1406.88 694.894,1406.88 694.904,1406.88 694.913,1406.88 694.922,1406.88 694.931,1406.88 694.94,1406.88 694.95,1406.88 694.959,1406.88 694.968,1406.88 694.977,1406.88 694.986,1406.88 694.995,1406.88 695.005,1406.88 695.014,1406.88 695.023,1406.88 695.032,1406.88 695.041,1406.88 695.051,1406.88 695.06,1406.88 695.069,1406.88 695.078,1406.88 695.087,1406.88 695.097,1406.88 695.106,1406.88 695.115,1406.88 695.124,1406.88 695.133,1406.88 695.142,1406.88 695.152,1406.88 695.161,1406.88 695.17,1406.88 695.179,1406.88 695.188,1406.88 695.198,1406.88 695.207,1406.88 695.216,1406.88 695.225,1406.88 695.234,1406.88 695.244,1406.88 695.253,1406.88 695.262,1406.88 695.271,1406.88 695.28,1406.88 695.29,1406.88 695.299,1406.88 695.308,1406.88 695.317,1406.88 695.326,1406.88 695.335,1406.88 695.345,1406.88 695.354,1406.88 695.363,1406.88 695.372,1406.88 695.381,1406.88 695.391,1406.88 695.4,1406.88 695.409,1406.88 695.418,1406.88 695.427,1406.88 695.437,1406.88 695.446,1406.88 695.455,1406.88 695.464,1406.88 695.473,1406.88 695.482,1406.88 695.492,1406.88 695.501,1406.88 695.51,1406.88 695.519,1406.88 695.528,1406.88 695.538,1406.88 695.547,1406.88 695.556,1406.88 695.565,1406.88 695.574,1406.88 695.584,1406.88 695.593,1406.88 695.602,1406.88 695.611,1406.88 695.62,1406.88 695.63,1406.88 695.639,1406.88 695.648,1406.88 695.657,1406.88 695.666,1406.88 695.675,1406.88 695.685,1406.88 695.694,1406.88 695.703,1406.88 695.712,1406.88 695.721,1406.88 695.731,1406.88 695.74,1406.88 695.749,1406.88 695.758,1406.88 695.767,1406.88 695.777,1406.88 695.786,1406.88 695.795,1406.88 695.804,1406.88 695.813,1406.88 695.822,1406.88 695.832,1406.88 695.841,1406.88 695.85,1406.88 695.859,1406.88 695.868,1406.88 695.878,1406.88 695.887,1406.88 695.896,1406.88 695.905,1406.88 695.914,1406.88 695.924,1406.88 695.933,1406.88 695.942,1406.88 695.951,1406.88 695.96,1406.88 695.97,1406.88 695.979,1406.88 695.988,1406.88 695.997,1406.88 696.006,1406.88 696.015,1406.88 696.025,1406.88 696.034,1406.88 696.043,1406.88 696.052,1406.88 696.061,1406.88 696.071,1406.88 696.08,1406.88 696.089,1406.88 696.098,1406.88 696.107,1406.88 696.117,1406.88 696.126,1406.88 696.135,1406.88 696.144,1406.88 696.153,1406.88 696.162,1406.88 696.172,1406.88 696.181,1406.88 696.19,1406.88 696.199,1406.88 696.208,1406.88 696.218,1406.88 696.227,1406.88 696.236,1406.88 696.245,1406.88 696.254,1406.88 696.264,1406.88 696.273,1406.88 696.282,1406.88 696.291,1406.88 696.3,1406.88 696.31,1406.88 696.319,1406.88 696.328,1406.88 696.337,1406.88 696.346,1406.88 696.355,1406.88 696.365,1406.88 696.374,1406.88 696.383,1406.88 696.392,1406.88 696.401,1406.88 696.411,1406.88 696.42,1406.88 696.429,1406.88 696.438,1406.88 696.447,1406.88 696.457,1406.88 696.466,1406.88 696.475,1406.88 696.484,1406.88 696.493,1406.88 696.503,1406.88 696.512,1406.88 696.521,1406.88 696.53,1406.88 696.539,1406.88 696.548,1406.88 696.558,1406.88 696.567,1406.88 696.576,1406.88 696.585,1406.88 696.594,1406.88 696.604,1406.88 696.613,1406.88 696.622,1406.88 696.631,1406.88 696.64,1406.88 696.65,1406.88 696.659,1406.88 696.668,1406.88 696.677,1406.88 696.686,1406.88 696.695,1406.88 696.705,1406.88 696.714,1406.88 696.723,1406.88 696.732,1406.88 696.741,1406.88 696.751,1406.88 696.76,1406.88 696.769,1406.88 696.778,1406.88 696.787,1406.88 696.797,1406.88 696.806,1406.88 696.815,1406.88 696.824,1406.88 696.833,1406.88 696.843,1406.88 696.852,1406.88 696.861,1406.88 696.87,1406.88 696.879,1406.88 696.888,1406.88 696.898,1406.88 696.907,1406.88 696.916,1406.88 696.925,1406.88 696.934,1406.88 696.944,1406.88 696.953,1406.88 696.962,1406.88 696.971,1406.88 696.98,1406.88 696.99,1406.88 696.999,1406.88 697.008,1406.88 697.017,1406.88 697.026,1406.88 697.035,1406.88 697.045,1406.88 697.054,1406.88 697.063,1406.88 697.072,1406.88 697.081,1406.88 697.091,1406.88 697.1,1406.88 697.109,1406.88 697.118,1406.88 697.127,1406.88 697.137,1406.88 697.146,1406.88 697.155,1406.88 697.164,1406.88 697.173,1406.88 697.183,1406.88 697.192,1406.88 697.201,1406.88 697.21,1406.88 697.219,1406.88 697.228,1406.88 697.238,1406.88 697.247,1406.88 697.256,1406.88 697.265,1406.88 697.274,1406.88 697.284,1406.88 697.293,1406.88 697.302,1406.88 697.311,1406.88 697.32,1406.88 697.33,1406.88 697.339,1406.88 697.348,1406.88 697.357,1406.88 697.366,1406.88 697.375,1406.88 697.385,1406.88 697.394,1406.88 697.403,1406.88 697.412,1406.88 697.421,1406.88 697.431,1406.88 697.44,1406.88 697.449,1406.88 697.458,1406.88 697.467,1406.88 697.477,1406.88 697.486,1406.88 697.495,1406.88 697.504,1406.88 697.513,1406.88 697.523,1406.88 697.532,1406.88 697.541,1406.88 697.55,1406.88 697.559,1406.88 697.568,1406.88 697.578,1406.88 697.587,1406.88 697.596,1406.88 697.605,1406.88 697.614,1406.88 697.624,1406.88 697.633,1406.88 697.642,1406.88 697.651,1406.88 697.66,1406.88 697.67,1406.88 697.679,1406.88 697.688,1406.88 697.697,1406.88 697.706,1406.88 697.715,1406.88 697.725,1406.88 697.734,1406.88 697.743,1406.88 697.752,1406.88 697.761,1406.88 697.771,1406.88 697.78,1406.88 697.789,1406.88 697.798,1406.88 697.807,1406.88 697.817,1406.88 697.826,1406.88 697.835,1406.88 697.844,1406.88 697.853,1406.88 697.863,1406.88 697.872,1406.88 697.881,1406.88 697.89,1406.88 697.899,1406.88 697.908,1406.88 697.918,1406.88 697.927,1406.88 697.936,1406.88 697.945,1406.88 697.954,1406.88 697.964,1406.88 697.973,1406.88 697.982,1406.88 697.991,1406.88 698,1406.88 698.01,1406.88 698.019,1406.88 698.028,1406.88 698.037,1406.88 698.046,1406.88 698.055,1406.88 698.065,1406.88 698.074,1406.88 698.083,1406.88 698.092,1406.88 698.101,1406.88 698.111,1406.88 698.12,1406.88 698.129,1406.88 698.138,1406.88 698.147,1406.88 698.157,1406.88 698.166,1406.88 698.175,1406.88 698.184,1406.88 698.193,1406.88 698.203,1406.88 698.212,1406.88 698.221,1406.88 698.23,1406.88 698.239,1406.88 698.248,1406.88 698.258,1406.88 698.267,1406.88 698.276,1406.88 698.285,1406.88 698.294,1406.88 698.304,1406.88 698.313,1406.88 698.322,1406.88 698.331,1406.88 698.34,1406.88 698.35,1406.88 698.359,1406.88 698.368,1406.88 698.377,1406.88 698.386,1406.88 698.395,1406.88 698.405,1406.88 698.414,1406.88 698.423,1406.88 698.432,1406.88 698.441,1406.88 698.451,1406.88 698.46,1406.88 698.469,1406.88 698.478,1406.88 698.487,1406.88 698.497,1406.88 698.506,1406.88 698.515,1406.88 698.524,1406.88 698.533,1406.88 698.543,1406.88 698.552,1406.88 698.561,1406.88 698.57,1406.88 698.579,1406.88 698.588,1406.88 698.598,1406.88 698.607,1406.88 698.616,1406.88 698.625,1406.88 698.634,1406.88 698.644,1406.88 698.653,1406.88 698.662,1406.88 698.671,1406.88 698.68,1406.88 698.69,1406.88 698.699,1406.88 698.708,1406.88 698.717,1406.88 698.726,1406.88 698.736,1406.88 698.745,1406.88 698.754,1406.88 698.763,1406.88 698.772,1406.88 698.781,1406.88 698.791,1406.88 698.8,1406.88 698.809,1406.88 698.818,1406.88 698.827,1406.88 698.837,1406.88 698.846,1406.88 698.855,1406.88 698.864,1406.88 698.873,1406.88 698.883,1406.88 698.892,1406.88 698.901,1406.88 698.91,1406.88 698.919,1406.88 698.928,1406.88 698.938,1406.88 698.947,1406.88 698.956,1406.88 698.965,1406.88 698.974,1406.88 698.984,1406.88 698.993,1406.88 699.002,1406.88 699.011,1406.88 699.02,1406.88 699.03,1406.88 699.039,1406.88 699.048,1406.88 699.057,1406.88 699.066,1406.88 699.076,1406.88 699.085,1406.88 699.094,1406.88 699.103,1406.88 699.112,1406.88 699.121,1406.88 699.131,1406.88 699.14,1406.88 699.149,1406.88 699.158,1406.88 699.167,1406.88 699.177,1406.88 699.186,1406.88 699.195,1406.88 699.204,1406.88 699.213,1406.88 699.223,1406.88 699.232,1406.88 699.241,1406.88 699.25,1406.88 699.259,1406.88 699.268,1406.88 699.278,1406.88 699.287,1406.88 699.296,1406.88 699.305,1406.88 699.314,1406.88 699.324,1406.88 699.333,1406.88 699.342,1406.88 699.351,1406.88 699.36,1406.88 699.37,1406.88 699.379,1406.88 699.388,1406.88 699.397,1406.88 699.406,1406.88 699.416,1406.88 699.425,1406.88 699.434,1406.88 699.443,1406.88 699.452,1406.88 699.461,1406.88 699.471,1406.88 699.48,1406.88 699.489,1406.88 699.498,1406.88 699.507,1406.88 699.517,1406.88 699.526,1406.88 699.535,1406.88 699.544,1406.88 699.553,1406.88 699.563,1406.88 699.572,1406.88 699.581,1406.88 699.59,1406.88 699.599,1406.88 699.608,1406.88 699.618,1406.88 699.627,1406.88 699.636,1406.88 699.645,1406.88 699.654,1406.88 699.664,1406.88 699.673,1406.88 699.682,1406.88 699.691,1406.88 699.7,1406.88 699.71,1406.88 699.719,1406.88 699.728,1406.88 699.737,1406.88 699.746,1406.88 699.756,1406.88 699.765,1406.88 699.774,1406.88 699.783,1406.88 699.792,1406.88 699.801,1406.88 699.811,1406.88 699.82,1406.88 699.829,1406.88 699.838,1406.88 699.847,1406.88 699.857,1406.88 699.866,1406.88 699.875,1406.88 699.884,1406.88 699.893,1406.88 699.903,1406.88 699.912,1406.88 699.921,1406.88 699.93,1406.88 699.939,1406.88 699.948,1406.88 699.958,1406.88 699.967,1406.88 699.976,1406.88 699.985,1406.88 699.994,1406.88 700.004,1406.88 700.013,1406.88 700.022,1406.88 700.031,1406.88 700.04,1406.88 700.05,1406.88 700.059,1406.88 700.068,1406.88 700.077,1406.88 700.086,1406.88 700.096,1406.88 700.105,1406.88 700.114,1406.88 700.123,1406.88 700.132,1406.88 700.141,1406.88 700.151,1406.88 700.16,1406.88 700.169,1406.88 700.178,1406.88 700.187,1406.88 700.197,1406.88 700.206,1406.88 700.215,1406.88 700.224,1406.88 700.233,1406.88 700.243,1406.88 700.252,1406.88 700.261,1406.88 700.27,1406.88 700.279,1406.88 700.288,1406.88 700.298,1406.88 700.307,1406.88 700.316,1406.88 700.325,1406.88 700.334,1406.88 700.344,1406.88 700.353,1406.88 700.362,1406.88 700.371,1406.88 700.38,1406.88 700.39,1406.88 700.399,1406.88 700.408,1406.88 700.417,1406.88 700.426,1406.88 700.436,1406.88 700.445,1406.88 700.454,1406.88 700.463,1406.88 700.472,1406.88 700.481,1406.88 700.491,1406.88 700.5,1406.88 700.509,1406.88 700.518,1406.88 700.527,1406.88 700.537,1406.88 700.546,1406.88 700.555,1406.88 700.564,1406.88 700.573,1406.88 700.583,1406.88 700.592,1406.88 700.601,1406.88 700.61,1406.88 700.619,1406.88 700.628,1406.88 700.638,1406.88 700.647,1406.88 700.656,1406.88 700.665,1406.88 700.674,1406.88 700.684,1406.88 700.693,1406.88 700.702,1406.88 700.711,1406.88 700.72,1406.88 700.73,1406.88 700.739,1406.88 700.748,1406.88 700.757,1406.88 700.766,1406.88 700.776,1406.88 700.785,1406.88 700.794,1406.88 700.803,1406.88 700.812,1406.88 700.821,1406.88 700.831,1406.88 700.84,1406.88 700.849,1406.88 700.858,1406.88 700.867,1406.88 700.877,1406.88 700.886,1406.88 700.895,1406.88 700.904,1406.88 700.913,1406.88 700.923,1406.88 700.932,1406.88 700.941,1406.88 700.95,1406.88 700.959,1406.88 700.968,1406.88 700.978,1406.88 700.987,1406.88 700.996,1406.88 701.005,1406.88 701.014,1406.88 701.024,1406.88 701.033,1406.88 701.042,1406.88 701.051,1406.88 701.06,1406.88 701.07,1406.88 701.079,1406.88 701.088,1406.88 701.097,1406.88 701.106,1406.88 701.116,1406.88 701.125,1406.88 701.134,1406.88 701.143,1406.88 701.152,1406.88 701.161,1406.88 701.171,1406.88 701.18,1406.88 701.189,1406.88 701.198,1406.88 701.207,1406.88 701.217,1406.88 701.226,1406.88 701.235,1406.88 701.244,1406.88 701.253,1406.88 701.263,1406.88 701.272,1406.88 701.281,1406.88 701.29,1406.88 701.299,1406.88 701.309,1406.88 701.318,1406.88 701.327,1406.88 701.336,1406.88 701.345,1406.88 701.354,1406.88 701.364,1406.88 701.373,1406.88 701.382,1406.88 701.391,1406.88 701.4,1406.88 701.41,1406.88 701.419,1406.88 701.428,1406.88 701.437,1406.88 701.446,1406.88 701.456,1406.88 701.465,1406.88 701.474,1406.88 701.483,1406.88 701.492,1406.88 701.501,1406.88 701.511,1406.88 701.52,1406.88 701.529,1406.88 701.538,1406.88 701.547,1406.88 701.557,1406.88 701.566,1406.88 701.575,1406.88 701.584,1406.88 701.593,1406.88 701.603,1406.88 701.612,1406.88 701.621,1406.88 701.63,1406.88 701.639,1406.88 701.649,1406.88 701.658,1406.88 701.667,1406.88 701.676,1406.88 701.685,1406.88 701.694,1406.88 701.704,1406.88 701.713,1406.88 701.722,1406.88 701.731,1406.88 701.74,1406.88 701.75,1406.88 701.759,1406.88 701.768,1406.88 701.777,1406.88 701.786,1406.88 701.796,1406.88 701.805,1406.88 701.814,1406.88 701.823,1406.88 701.832,1406.88 701.841,1406.88 701.851,1406.88 701.86,1406.88 701.869,1406.88 701.878,1406.88 701.887,1406.88 701.897,1406.88 701.906,1406.88 701.915,1406.88 701.924,1406.88 701.933,1406.88 701.943,1406.88 701.952,1406.88 701.961,1406.88 701.97,1406.88 701.979,1406.88 701.989,1406.88 701.998,1406.88 702.007,1406.88 702.016,1406.88 702.025,1406.88 702.034,1406.88 702.044,1406.88 702.053,1406.88 702.062,1406.88 702.071,1406.88 702.08,1406.88 702.09,1406.88 702.099,1406.88 702.108,1406.88 702.117,1406.88 702.126,1406.88 702.136,1406.88 702.145,1406.88 702.154,1406.88 702.163,1406.88 702.172,1406.88 702.181,1406.88 702.191,1406.88 702.2,1406.88 702.209,1406.88 702.218,1406.88 702.227,1406.88 702.237,1406.88 702.246,1406.88 702.255,1406.88 702.264,1406.88 702.273,1406.88 702.283,1406.88 702.292,1406.88 702.301,1406.88 702.31,1406.88 702.319,1406.88 702.329,1406.88 702.338,1406.88 702.347,1406.88 702.356,1406.88 702.365,1406.88 702.374,1406.88 702.384,1406.88 702.393,1406.88 702.402,1406.88 702.411,1406.88 702.42,1406.88 702.43,1406.88 702.439,1406.88 702.448,1406.88 702.457,1406.88 702.466,1406.88 702.476,1406.88 702.485,1406.88 702.494,1406.88 702.503,1406.88 702.512,1406.88 702.521,1406.88 702.531,1406.88 702.54,1406.88 702.549,1406.88 702.558,1406.88 702.567,1406.88 702.577,1406.88 702.586,1406.88 702.595,1406.88 702.604,1406.88 702.613,1406.88 702.623,1406.88 702.632,1406.88 702.641,1406.88 702.65,1406.88 702.659,1406.88 702.669,1406.88 702.678,1406.88 702.687,1406.88 702.696,1406.88 702.705,1406.88 702.714,1406.88 702.724,1406.88 702.733,1406.88 702.742,1406.88 702.751,1406.88 702.76,1406.88 702.77,1406.88 702.779,1406.88 702.788,1406.88 702.797,1406.88 702.806,1406.88 702.816,1406.88 702.825,1406.88 702.834,1406.88 702.843,1406.88 702.852,1406.88 702.861,1406.88 702.871,1406.88 702.88,1406.88 702.889,1406.88 702.898,1406.88 702.907,1406.88 702.917,1406.88 702.926,1406.88 702.935,1406.88 702.944,1406.88 702.953,1406.88 702.963,1406.88 702.972,1406.88 702.981,1406.88 702.99,1406.88 702.999,1406.88 703.009,1406.88 703.018,1406.88 703.027,1406.88 703.036,1406.88 703.045,1406.88 703.054,1406.88 703.064,1406.88 703.073,1406.88 703.082,1406.88 703.091,1406.88 703.1,1406.88 703.11,1406.88 703.119,1406.88 703.128,1406.88 703.137,1406.88 703.146,1406.88 703.156,1406.88 703.165,1406.88 703.174,1406.88 703.183,1406.88 703.192,1406.88 703.201,1406.88 703.211,1406.88 703.22,1406.88 703.229,1406.88 703.238,1406.88 703.247,1406.88 703.257,1406.88 703.266,1406.88 703.275,1406.88 703.284,1406.88 703.293,1406.88 703.303,1406.88 703.312,1406.88 703.321,1406.88 703.33,1406.88 703.339,1406.88 703.349,1406.88 703.358,1406.88 703.367,1406.88 703.376,1406.88 703.385,1406.88 703.394,1406.88 703.404,1406.88 703.413,1406.88 703.422,1406.88 703.431,1406.88 703.44,1406.88 703.45,1406.88 703.459,1406.88 703.468,1406.88 703.477,1406.88 703.486,1406.88 703.496,1406.88 703.505,1406.88 703.514,1406.88 703.523,1406.88 703.532,1406.88 703.541,1406.88 703.551,1406.88 703.56,1406.88 703.569,1406.88 703.578,1406.88 703.587,1406.88 703.597,1406.88 703.606,1406.88 703.615,1406.88 703.624,1406.88 703.633,1406.88 703.643,1406.88 703.652,1406.88 703.661,1406.88 703.67,1406.88 703.679,1406.88 703.689,1406.88 703.698,1406.88 703.707,1406.88 703.716,1406.88 703.725,1406.88 703.734,1406.88 703.744,1406.88 703.753,1406.88 703.762,1406.88 703.771,1406.88 703.78,1406.88 703.79,1406.88 703.799,1406.88 703.808,1406.88 703.817,1406.88 703.826,1406.88 703.836,1406.88 703.845,1406.88 703.854,1406.88 703.863,1406.88 703.872,1406.88 703.882,1406.88 703.891,1406.88 703.9,1406.88 703.909,1406.88 703.918,1406.88 703.927,1406.88 703.937,1406.88 703.946,1406.88 703.955,1406.88 703.964,1406.88 703.973,1406.88 703.983,1406.88 703.992,1406.88 704.001,1406.88 704.01,1406.88 704.019,1406.88 704.029,1406.88 704.038,1406.88 704.047,1406.88 704.056,1406.88 704.065,1406.88 704.074,1406.88 704.084,1406.88 704.093,1406.88 704.102,1406.88 704.111,1406.88 704.12,1406.88 704.13,1406.88 704.139,1406.88 704.148,1406.88 704.157,1406.88 704.166,1406.88 704.176,1406.88 704.185,1406.88 704.194,1406.88 704.203,1406.88 704.212,1406.88 704.222,1406.88 704.231,1406.88 704.24,1406.88 704.249,1406.88 704.258,1406.88 704.267,1406.88 704.277,1406.88 704.286,1406.88 704.295,1406.88 704.304,1406.88 704.313,1406.88 704.323,1406.88 704.332,1406.88 704.341,1406.88 704.35,1406.88 704.359,1406.88 704.369,1406.88 704.378,1406.88 704.387,1406.88 704.396,1406.88 704.405,1406.88 704.414,1406.88 704.424,1406.88 704.433,1406.88 704.442,1406.88 704.451,1406.88 704.46,1406.88 704.47,1406.88 704.479,1406.88 704.488,1406.88 704.497,1406.88 704.506,1406.88 704.516,1406.88 704.525,1406.88 704.534,1406.88 704.543,1406.88 704.552,1406.88 704.562,1406.88 704.571,1406.88 704.58,1406.88 704.589,1406.88 704.598,1406.88 704.607,1406.88 704.617,1406.88 704.626,1406.88 704.635,1406.88 704.644,1406.88 704.653,1406.88 704.663,1406.88 704.672,1406.88 704.681,1406.88 704.69,1406.88 704.699,1406.88 704.709,1406.88 704.718,1406.88 704.727,1406.88 704.736,1406.88 704.745,1406.88 704.754,1406.88 704.764,1406.88 704.773,1406.88 704.782,1406.88 704.791,1406.88 704.8,1406.88 704.81,1406.88 704.819,1406.88 704.828,1406.88 704.837,1406.88 704.846,1406.88 704.856,1406.88 704.865,1406.88 704.874,1406.88 704.883,1406.88 704.892,1406.88 704.902,1406.88 704.911,1406.88 704.92,1406.88 704.929,1406.88 704.938,1406.88 704.947,1406.88 704.957,1406.88 704.966,1406.88 704.975,1406.88 704.984,1406.88 704.993,1406.88 705.003,1406.88 705.012,1406.88 705.021,1406.88 705.03,1406.88 705.039,1406.88 705.049,1406.88 705.058,1406.88 705.067,1406.88 705.076,1406.88 705.085,1406.88 705.094,1406.88 705.104,1406.88 705.113,1406.88 705.122,1406.88 705.131,1406.88 705.14,1406.88 705.15,1406.88 705.159,1406.88 705.168,1406.88 705.177,1406.88 705.186,1406.88 705.196,1406.88 705.205,1406.88 705.214,1406.88 705.223,1406.88 705.232,1406.88 705.242,1406.88 705.251,1406.88 705.26,1406.88 705.269,1406.88 705.278,1406.88 705.287,1406.88 705.297,1406.88 705.306,1406.88 705.315,1406.88 705.324,1406.88 705.333,1406.88 705.343,1406.88 705.352,1406.88 705.361,1406.88 705.37,1406.88 705.379,1406.88 705.389,1406.88 705.398,1406.88 705.407,1406.88 705.416,1406.88 705.425,1406.88 705.434,1406.88 705.444,1406.88 705.453,1406.88 705.462,1406.88 705.471,1406.88 705.48,1406.88 705.49,1406.88 705.499,1406.88 705.508,1406.88 705.517,1406.88 705.526,1406.88 705.536,1406.88 705.545,1406.88 705.554,1406.88 705.563,1406.88 705.572,1406.88 705.582,1406.88 705.591,1406.88 705.6,1406.88 705.609,1406.88 705.618,1406.88 705.627,1406.88 705.637,1406.88 705.646,1406.88 705.655,1406.88 705.664,1406.88 705.673,1406.88 705.683,1406.88 705.692,1406.88 705.701,1406.88 705.71,1406.88 705.719,1406.88 705.729,1406.88 705.738,1406.88 705.747,1406.88 705.756,1406.88 705.765,1406.88 705.774,1406.88 705.784,1406.88 705.793,1406.88 705.802,1406.88 705.811,1406.88 705.82,1406.88 705.83,1406.88 705.839,1406.88 705.848,1406.88 705.857,1406.88 705.866,1406.88 705.876,1406.88 705.885,1406.88 705.894,1406.88 705.903,1406.88 705.912,1406.88 705.922,1406.88 705.931,1406.88 705.94,1406.88 705.949,1406.88 705.958,1406.88 705.967,1406.88 705.977,1406.88 705.986,1406.88 705.995,1406.88 706.004,1406.88 706.013,1406.88 706.023,1406.88 706.032,1406.88 706.041,1406.88 706.05,1406.88 706.059,1406.88 706.069,1406.88 706.078,1406.88 706.087,1406.88 706.096,1406.88 706.105,1406.88 706.114,1406.88 706.124,1406.88 706.133,1406.88 706.142,1406.88 706.151,1406.88 706.16,1406.88 706.17,1406.88 706.179,1406.88 706.188,1406.88 706.197,1406.88 706.206,1406.88 706.216,1406.88 706.225,1406.88 706.234,1406.88 706.243,1406.88 706.252,1406.88 706.262,1406.88 706.271,1406.88 706.28,1406.88 706.289,1406.88 706.298,1406.88 706.307,1406.88 706.317,1406.88 706.326,1406.88 706.335,1406.88 706.344,1406.88 706.353,1406.88 706.363,1406.88 706.372,1406.88 706.381,1406.88 706.39,1406.88 706.399,1406.88 706.409,1406.88 706.418,1406.88 706.427,1406.88 706.436,1406.88 706.445,1406.88 706.455,1406.88 706.464,1406.88 706.473,1406.88 706.482,1406.88 706.491,1406.88 706.5,1406.88 706.51,1406.88 706.519,1406.88 706.528,1406.88 706.537,1406.88 706.546,1406.88 706.556,1406.88 706.565,1406.88 706.574,1406.88 706.583,1406.88 706.592,1406.88 706.602,1406.88 706.611,1406.88 706.62,1406.88 706.629,1406.88 706.638,1406.88 706.647,1406.88 706.657,1406.88 706.666,1406.88 706.675,1406.88 706.684,1406.88 706.693,1406.88 706.703,1406.88 706.712,1406.88 706.721,1406.88 706.73,1406.88 706.739,1406.88 706.749,1406.88 706.758,1406.88 706.767,1406.88 706.776,1406.88 706.785,1406.88 706.795,1406.88 706.804,1406.88 706.813,1406.88 706.822,1406.88 706.831,1406.88 706.84,1406.88 706.85,1406.88 706.859,1406.88 706.868,1406.88 706.877,1406.88 706.886,1406.88 706.896,1406.88 706.905,1406.88 706.914,1406.88 706.923,1406.88 706.932,1406.88 706.942,1406.88 706.951,1406.88 706.96,1406.88 706.969,1406.88 706.978,1406.88 706.987,1406.88 706.997,1406.88 707.006,1406.88 707.015,1406.88 707.024,1406.88 707.033,1406.88 707.043,1406.88 707.052,1406.88 707.061,1406.88 707.07,1406.88 707.079,1406.88 707.089,1406.88 707.098,1406.88 707.107,1406.88 707.116,1406.88 707.125,1406.88 707.135,1406.88 707.144,1406.88 707.153,1406.88 707.162,1406.88 707.171,1406.88 707.18,1406.88 707.19,1406.88 707.199,1406.88 707.208,1406.88 707.217,1406.88 707.226,1406.88 707.236,1406.88 707.245,1406.88 707.254,1406.88 707.263,1406.88 707.272,1406.88 707.282,1406.88 707.291,1406.88 707.3,1406.88 707.309,1406.88 707.318,1406.88 707.327,1406.88 707.337,1406.88 707.346,1406.88 707.355,1406.88 707.364,1406.88 707.373,1406.88 707.383,1406.88 707.392,1406.88 707.401,1406.88 707.41,1406.88 707.419,1406.88 707.429,1406.88 707.438,1406.88 707.447,1406.88 707.456,1406.88 707.465,1406.88 707.475,1406.88 707.484,1406.88 707.493,1406.88 707.502,1406.88 707.511,1406.88 707.52,1406.88 707.53,1406.88 707.539,1406.88 707.548,1406.88 707.557,1406.88 707.566,1406.88 707.576,1406.88 707.585,1406.88 707.594,1406.88 707.603,1406.88 707.612,1406.88 707.622,1406.88 707.631,1406.88 707.64,1406.88 707.649,1406.88 707.658,1406.88 707.667,1406.88 707.677,1406.88 707.686,1406.88 707.695,1406.88 707.704,1406.88 707.713,1406.88 707.723,1406.88 707.732,1406.88 707.741,1406.88 707.75,1406.88 707.759,1406.88 707.769,1406.88 707.778,1406.88 707.787,1406.88 707.796,1406.88 707.805,1406.88 707.815,1406.88 707.824,1406.88 707.833,1406.88 707.842,1406.88 707.851,1406.88 707.86,1406.88 707.87,1406.88 707.879,1406.88 707.888,1406.88 707.897,1406.88 707.906,1406.88 707.916,1406.88 707.925,1406.88 707.934,1406.88 707.943,1406.88 707.952,1406.88 707.962,1406.88 707.971,1406.88 707.98,1406.88 707.989,1406.88 707.998,1406.88 708.007,1406.88 708.017,1406.88 708.026,1406.88 708.035,1406.88 708.044,1406.88 708.053,1406.88 708.063,1406.88 708.072,1406.88 708.081,1406.88 708.09,1406.88 708.099,1406.88 708.109,1406.88 708.118,1406.88 708.127,1406.88 708.136,1406.88 708.145,1406.88 708.155,1406.88 708.164,1406.88 708.173,1406.88 708.182,1406.88 708.191,1406.88 708.2,1406.88 708.21,1406.88 708.219,1406.88 708.228,1406.88 708.237,1406.88 708.246,1406.88 708.256,1406.88 708.265,1406.88 708.274,1406.88 708.283,1406.88 708.292,1406.88 708.302,1406.88 708.311,1406.88 708.32,1406.88 708.329,1406.88 708.338,1406.88 708.347,1406.88 708.357,1406.88 708.366,1406.88 708.375,1406.88 708.384,1406.88 708.393,1406.88 708.403,1406.88 708.412,1406.88 708.421,1406.88 708.43,1406.88 708.439,1406.88 708.449,1406.88 708.458,1406.88 708.467,1406.88 708.476,1406.88 708.485,1406.88 708.495,1406.88 708.504,1406.88 708.513,1406.88 708.522,1406.88 708.531,1406.88 708.54,1406.88 708.55,1406.88 708.559,1406.88 708.568,1406.88 708.577,1406.88 708.586,1406.88 708.596,1406.88 708.605,1406.88 708.614,1406.88 708.623,1406.88 708.632,1406.88 708.642,1406.88 708.651,1406.88 708.66,1406.88 708.669,1406.88 708.678,1406.88 708.688,1406.88 708.697,1406.88 708.706,1406.88 708.715,1406.88 708.724,1406.88 708.733,1406.88 708.743,1406.88 708.752,1406.88 708.761,1406.88 708.77,1406.88 708.779,1406.88 708.789,1406.88 708.798,1406.88 708.807,1406.88 708.816,1406.88 708.825,1406.88 708.835,1406.88 708.844,1406.88 708.853,1406.88 708.862,1406.88 708.871,1406.88 708.88,1406.88 708.89,1406.88 708.899,1406.88 708.908,1406.88 708.917,1406.88 708.926,1406.88 708.936,1406.88 708.945,1406.88 708.954,1406.88 708.963,1406.88 708.972,1406.88 708.982,1406.88 708.991,1406.88 709,1406.88 709.009,1406.88 709.018,1406.88 709.028,1406.88 709.037,1406.88 709.046,1406.88 709.055,1406.88 709.064,1406.88 709.073,1406.88 709.083,1406.88 709.092,1406.88 709.101,1406.88 709.11,1406.88 709.119,1406.88 709.129,1406.88 709.138,1406.88 709.147,1406.88 709.156,1406.88 709.165,1406.88 709.175,1406.88 709.184,1406.88 709.193,1406.88 709.202,1406.88 709.211,1406.88 709.22,1406.88 709.23,1406.88 709.239,1406.88 709.248,1406.88 709.257,1406.88 709.266,1406.88 709.276,1406.88 709.285,1406.88 709.294,1406.88 709.303,1406.88 709.312,1406.88 709.322,1406.88 709.331,1406.88 709.34,1406.88 709.349,1406.88 709.358,1406.88 709.368,1406.88 709.377,1406.88 709.386,1406.88 709.395,1406.88 709.404,1406.88 709.413,1406.88 709.423,1406.88 709.432,1406.88 709.441,1406.88 709.45,1406.88 709.459,1406.88 709.469,1406.88 709.478,1406.88 709.487,1406.88 709.496,1406.88 709.505,1406.88 709.515,1406.88 709.524,1406.88 709.533,1406.88 709.542,1406.88 709.551,1406.88 709.56,1406.88 709.57,1406.88 709.579,1406.88 709.588,1406.88 709.597,1406.88 709.606,1406.88 709.616,1406.88 709.625,1406.88 709.634,1406.88 709.643,1406.88 709.652,1406.88 709.662,1406.88 709.671,1406.88 709.68,1406.88 709.689,1406.88 709.698,1406.88 709.708,1406.88 709.717,1406.88 709.726,1406.88 709.735,1406.88 709.744,1406.88 709.753,1406.88 709.763,1406.88 709.772,1406.88 709.781,1406.88 709.79,1406.88 709.799,1406.88 709.809,1406.88 709.818,1406.88 709.827,1406.88 709.836,1406.88 709.845,1406.88 709.855,1406.88 709.864,1406.88 709.873,1406.88 709.882,1406.88 709.891,1406.88 709.9,1406.88 709.91,1406.88 709.919,1406.88 709.928,1406.88 709.937,1406.88 709.946,1406.88 709.956,1406.88 709.965,1406.88 709.974,1406.88 709.983,1406.88 709.992,1406.88 710.002,1406.88 710.011,1406.88 710.02,1406.88 710.029,1406.88 710.038,1406.88 710.048,1406.88 710.057,1406.88 710.066,1406.88 710.075,1406.88 710.084,1406.88 710.093,1406.88 710.103,1406.88 710.112,1406.88 710.121,1406.88 710.13,1406.88 710.139,1406.88 710.149,1406.88 710.158,1406.88 710.167,1406.88 710.176,1406.88 710.185,1406.88 710.195,1406.88 710.204,1406.88 710.213,1406.88 710.222,1406.88 710.231,1406.88 710.24,1406.88 710.25,1406.88 710.259,1406.88 710.268,1406.88 710.277,1406.88 710.286,1406.88 710.296,1406.88 710.305,1406.88 710.314,1406.88 710.323,1406.88 710.332,1406.88 710.342,1406.88 710.351,1406.88 710.36,1406.88 710.369,1406.88 710.378,1406.88 710.388,1406.88 710.397,1406.88 710.406,1406.88 710.415,1406.88 710.424,1406.88 710.433,1406.88 710.443,1406.88 710.452,1406.88 710.461,1406.88 710.47,1406.88 710.479,1406.88 710.489,1406.88 710.498,1406.88 710.507,1406.88 710.516,1406.88 710.525,1406.88 710.535,1406.88 710.544,1406.88 710.553,1406.88 710.562,1406.88 710.571,1406.88 710.58,1406.88 710.59,1406.88 710.599,1406.88 710.608,1406.88 710.617,1406.88 710.626,1406.88 710.636,1406.88 710.645,1406.88 710.654,1406.88 710.663,1406.88 710.672,1406.88 710.682,1406.88 710.691,1406.88 710.7,1406.88 710.709,1406.88 710.718,1406.88 710.728,1406.88 710.737,1406.88 710.746,1406.88 710.755,1406.88 710.764,1406.88 710.773,1406.88 710.783,1406.88 710.792,1406.88 710.801,1406.88 710.81,1406.88 710.819,1406.88 710.829,1406.88 710.838,1406.88 710.847,1406.88 710.856,1406.88 710.865,1406.88 710.875,1406.88 710.884,1406.88 710.893,1406.88 710.902,1406.88 710.911,1406.88 710.92,1406.88 710.93,1406.88 710.939,1406.88 710.948,1406.88 710.957,1406.88 710.966,1406.88 710.976,1406.88 710.985,1406.88 710.994,1406.88 711.003,1406.88 711.012,1406.88 711.022,1406.88 711.031,1406.88 711.04,1406.88 711.049,1406.88 711.058,1406.88 711.068,1406.88 711.077,1406.88 711.086,1406.88 711.095,1406.88 711.104,1406.88 711.113,1406.88 711.123,1406.88 711.132,1406.88 711.141,1406.88 711.15,1406.88 711.159,1406.88 711.169,1406.88 711.178,1406.88 711.187,1406.88 711.196,1406.88 711.205,1406.88 711.215,1406.88 711.224,1406.88 711.233,1406.88 711.242,1406.88 711.251,1406.88 711.261,1406.88 711.27,1406.88 711.279,1406.88 711.288,1406.88 711.297,1406.88 711.306,1406.88 711.316,1406.88 711.325,1406.88 711.334,1406.88 711.343,1406.88 711.352,1406.88 711.362,1406.88 711.371,1406.88 711.38,1406.88 711.389,1406.88 711.398,1406.88 711.408,1406.88 711.417,1406.88 711.426,1406.88 711.435,1406.88 711.444,1406.88 711.453,1406.88 711.463,1406.88 711.472,1406.88 711.481,1406.88 711.49,1406.88 711.499,1406.88 711.509,1406.88 711.518,1406.88 711.527,1406.88 711.536,1406.88 711.545,1406.88 711.555,1406.88 711.564,1406.88 711.573,1406.88 711.582,1406.88 711.591,1406.88 711.601,1406.88 711.61,1406.88 711.619,1406.88 711.628,1406.88 711.637,1406.88 711.646,1406.88 711.656,1406.88 711.665,1406.88 711.674,1406.88 711.683,1406.88 711.692,1406.88 711.702,1406.88 711.711,1406.88 711.72,1406.88 711.729,1406.88 711.738,1406.88 711.748,1406.88 711.757,1406.88 711.766,1406.88 711.775,1406.88 711.784,1406.88 711.793,1406.88 711.803,1406.88 711.812,1406.88 711.821,1406.88 711.83,1406.88 711.839,1406.88 711.849,1406.88 711.858,1406.88 711.867,1406.88 711.876,1406.88 711.885,1406.88 711.895,1406.88 711.904,1406.88 711.913,1406.88 711.922,1406.88 711.931,1406.88 711.941,1406.88 711.95,1406.88 711.959,1406.88 711.968,1406.88 711.977,1406.88 711.986,1406.88 711.996,1406.88 712.005,1406.88 712.014,1406.88 712.023,1406.88 712.032,1406.88 712.042,1406.88 712.051,1406.88 712.06,1406.88 712.069,1406.88 712.078,1406.88 712.088,1406.88 712.097,1406.88 712.106,1406.88 712.115,1406.88 712.124,1406.88 712.133,1406.88 712.143,1406.88 712.152,1406.88 712.161,1406.88 712.17,1406.88 712.179,1406.88 712.189,1406.88 712.198,1406.88 712.207,1406.88 712.216,1406.88 712.225,1406.88 712.235,1406.88 712.244,1406.88 712.253,1406.88 712.262,1406.88 712.271,1406.88 712.281,1406.88 712.29,1406.88 712.299,1406.88 712.308,1406.88 712.317,1406.88 712.326,1406.88 712.336,1406.88 712.345,1406.88 712.354,1406.88 712.363,1406.88 712.372,1406.88 712.382,1406.88 712.391,1406.88 712.4,1406.88 712.409,1406.88 712.418,1406.88 712.428,1406.88 712.437,1406.88 712.446,1406.88 712.455,1406.88 712.464,1406.88 712.473,1406.88 712.483,1406.88 712.492,1406.88 712.501,1406.88 712.51,1406.88 712.519,1406.88 712.529,1406.88 712.538,1406.88 712.547,1406.88 712.556,1406.88 712.565,1406.88 712.575,1406.88 712.584,1406.88 712.593,1406.88 712.602,1406.88 712.611,1406.88 712.621,1406.88 712.63,1406.88 712.639,1406.88 712.648,1406.88 712.657,1406.88 712.666,1406.88 712.676,1406.88 712.685,1406.88 712.694,1406.88 712.703,1406.88 712.712,1406.88 712.722,1406.88 712.731,1406.88 712.74,1406.88 712.749,1406.88 712.758,1406.88 712.768,1406.88 712.777,1406.88 712.786,1406.88 712.795,1406.88 712.804,1406.88 712.813,1406.88 712.823,1406.88 712.832,1406.88 712.841,1406.88 712.85,1406.88 712.859,1406.88 712.869,1406.88 712.878,1406.88 712.887,1406.88 712.896,1406.88 712.905,1406.88 712.915,1406.88 712.924,1406.88 712.933,1406.88 712.942,1406.88 712.951,1406.88 712.961,1406.88 712.97,1406.88 712.979,1406.88 712.988,1406.88 712.997,1406.88 713.006,1406.88 713.016,1406.88 713.025,1406.88 713.034,1406.88 713.043,1406.88 713.052,1406.88 713.062,1406.88 713.071,1406.88 713.08,1406.88 713.089,1406.88 713.098,1406.88 713.108,1406.88 713.117,1406.88 713.126,1406.88 713.135,1406.88 713.144,1406.88 713.153,1406.88 713.163,1406.88 713.172,1406.88 713.181,1406.88 713.19,1406.88 713.199,1406.88 713.209,1406.88 713.218,1406.88 713.227,1406.88 713.236,1406.88 713.245,1406.88 713.255,1406.88 713.264,1406.88 713.273,1406.88 713.282,1406.88 713.291,1406.88 713.301,1406.88 713.31,1406.88 713.319,1406.88 713.328,1406.88 713.337,1406.88 713.346,1406.88 713.356,1406.88 713.365,1406.88 713.374,1406.88 713.383,1406.88 713.392,1406.88 713.402,1406.88 713.411,1406.88 713.42,1406.88 713.429,1406.88 713.438,1406.88 713.448,1406.88 713.457,1406.88 713.466,1406.88 713.475,1406.88 713.484,1406.88 713.493,1406.88 713.503,1406.88 713.512,1406.88 713.521,1406.88 713.53,1406.88 713.539,1406.88 713.549,1406.88 713.558,1406.88 713.567,1406.88 713.576,1406.88 713.585,1406.88 713.595,1406.88 713.604,1406.88 713.613,1406.88 713.622,1406.88 713.631,1406.88 713.641,1406.88 713.65,1406.88 713.659,1406.88 713.668,1406.88 713.677,1406.88 713.686,1406.88 713.696,1406.88 713.705,1406.88 713.714,1406.88 713.723,1406.88 713.732,1406.88 713.742,1406.88 713.751,1406.88 713.76,1406.88 713.769,1406.88 713.778,1406.88 713.788,1406.88 713.797,1406.88 713.806,1406.88 713.815,1406.88 713.824,1406.88 713.834,1406.88 713.843,1406.88 713.852,1406.88 713.861,1406.88 713.87,1406.88 713.879,1406.88 713.889,1406.88 713.898,1406.88 713.907,1406.88 713.916,1406.88 713.925,1406.88 713.935,1406.88 713.944,1406.88 713.953,1406.88 713.962,1406.88 713.971,1406.88 713.981,1406.88 713.99,1406.88 713.999,1406.88 714.008,1406.88 714.017,1406.88 714.026,1406.88 714.036,1406.88 714.045,1406.88 714.054,1406.88 714.063,1406.88 714.072,1406.88 714.082,1406.88 714.091,1406.88 714.1,1406.88 714.109,1406.88 714.118,1406.88 714.128,1406.88 714.137,1406.88 714.146,1406.88 714.155,1406.88 714.164,1406.88 714.174,1406.88 714.183,1406.88 714.192,1406.88 714.201,1406.88 714.21,1406.88 714.219,1406.88 714.229,1406.88 714.238,1406.88 714.247,1406.88 714.256,1406.88 714.265,1406.88 714.275,1406.88 714.284,1406.88 714.293,1406.88 714.302,1406.88 714.311,1406.88 714.321,1406.88 714.33,1406.88 714.339,1406.88 714.348,1406.88 714.357,1406.88 714.366,1406.88 714.376,1406.88 714.385,1406.88 714.394,1406.88 714.403,1406.88 714.412,1406.88 714.422,1406.88 714.431,1406.88 714.44,1406.88 714.449,1406.88 714.458,1406.88 714.468,1406.88 714.477,1406.88 714.486,1406.88 714.495,1406.88 714.504,1406.88 714.514,1406.88 714.523,1406.88 714.532,1406.88 714.541,1406.88 714.55,1406.88 714.559,1406.88 714.569,1406.88 714.578,1406.88 714.587,1406.88 714.596,1406.88 714.605,1406.88 714.615,1406.88 714.624,1406.88 714.633,1406.88 714.642,1406.88 714.651,1406.88 714.661,1406.88 714.67,1406.88 714.679,1406.88 714.688,1406.88 714.697,1406.88 714.706,1406.88 714.716,1406.88 714.725,1406.88 714.734,1406.88 714.743,1406.88 714.752,1406.88 714.762,1406.88 714.771,1406.88 714.78,1406.88 714.789,1406.88 714.798,1406.88 714.808,1406.88 714.817,1406.88 714.826,1406.88 714.835,1406.88 714.844,1406.88 714.854,1406.88 714.863,1406.88 714.872,1406.88 714.881,1406.88 714.89,1406.88 714.899,1406.88 714.909,1406.88 714.918,1406.88 714.927,1406.88 714.936,1406.88 714.945,1406.88 714.955,1406.88 714.964,1406.88 714.973,1406.88 714.982,1406.88 714.991,1406.88 715.001,1406.88 715.01,1406.88 715.019,1406.88 715.028,1406.88 715.037,1406.88 715.046,1406.88 715.056,1406.88 715.065,1406.88 715.074,1406.88 715.083,1406.88 715.092,1406.88 715.102,1406.88 715.111,1406.88 715.12,1406.88 715.129,1406.88 715.138,1406.88 715.148,1406.88 715.157,1406.88 715.166,1406.88 715.175,1406.88 715.184,1406.88 715.194,1406.88 715.203,1406.88 715.212,1406.88 715.221,1406.88 715.23,1406.88 715.239,1406.88 715.249,1406.88 715.258,1406.88 715.267,1406.88 715.276,1406.88 715.285,1406.88 715.295,1406.88 715.304,1406.88 715.313,1406.88 715.322,1406.88 715.331,1406.88 715.341,1406.88 715.35,1406.88 715.359,1406.88 715.368,1406.88 715.377,1406.88 715.386,1406.88 715.396,1406.88 715.405,1406.88 715.414,1406.88 715.423,1406.88 715.432,1406.88 715.442,1406.88 715.451,1406.88 715.46,1406.88 715.469,1406.88 715.478,1406.88 715.488,1406.88 715.497,1406.88 715.506,1406.88 715.515,1406.88 715.524,1406.88 715.534,1406.88 715.543,1406.88 715.552,1406.88 715.561,1406.88 715.57,1406.88 715.579,1406.88 715.589,1406.88 715.598,1406.88 715.607,1406.88 715.616,1406.88 715.625,1406.88 715.635,1406.88 715.644,1406.88 715.653,1406.88 715.662,1406.88 715.671,1406.88 715.681,1406.88 715.69,1406.88 715.699,1406.88 715.708,1406.88 715.717,1406.88 715.726,1406.88 715.736,1406.88 715.745,1406.88 715.754,1406.88 715.763,1406.88 715.772,1406.88 715.782,1406.88 715.791,1406.88 715.8,1406.88 715.809,1406.88 715.818,1406.88 715.828,1406.88 715.837,1406.88 715.846,1406.88 715.855,1406.88 715.864,1406.88 715.874,1406.88 715.883,1406.88 715.892,1406.88 715.901,1406.88 715.91,1406.88 715.919,1406.88 715.929,1406.88 715.938,1406.88 715.947,1406.88 715.956,1406.88 715.965,1406.88 715.975,1406.88 715.984,1406.88 715.993,1406.88 716.002,1406.88 716.011,1406.88 716.021,1406.88 716.03,1406.88 716.039,1406.88 716.048,1406.88 716.057,1406.88 716.067,1406.88 716.076,1406.88 716.085,1406.88 716.094,1406.88 716.103,1406.88 716.112,1406.88 716.122,1406.88 716.131,1406.88 716.14,1406.88 716.149,1406.88 716.158,1406.88 716.168,1406.88 716.177,1406.88 716.186,1406.88 716.195,1406.88 716.204,1406.88 716.214,1406.88 716.223,1406.88 716.232,1406.88 716.241,1406.88 716.25,1406.88 716.259,1406.88 716.269,1406.88 716.278,1406.88 716.287,1406.88 716.296,1406.88 716.305,1406.88 716.315,1406.88 716.324,1406.88 716.333,1406.88 716.342,1406.88 716.351,1406.88 716.361,1406.88 716.37,1406.88 716.379,1406.88 716.388,1406.88 716.397,1406.88 716.407,1406.88 716.416,1406.88 716.425,1406.88 716.434,1406.88 716.443,1406.88 716.452,1406.88 716.462,1406.88 716.471,1406.88 716.48,1406.88 716.489,1406.88 716.498,1406.88 716.508,1406.88 716.517,1406.88 716.526,1406.88 716.535,1406.88 716.544,1406.88 716.554,1406.88 716.563,1406.88 716.572,1406.88 716.581,1406.88 716.59,1406.88 716.599,1406.88 716.609,1406.88 716.618,1406.88 716.627,1406.88 716.636,1406.88 716.645,1406.88 716.655,1406.88 716.664,1406.88 716.673,1406.88 716.682,1406.88 716.691,1406.88 716.701,1406.88 716.71,1406.88 716.719,1406.88 716.728,1406.88 716.737,1406.88 716.747,1406.88 716.756,1406.88 716.765,1406.88 716.774,1406.88 716.783,1406.88 716.792,1406.88 716.802,1406.88 716.811,1406.88 716.82,1406.88 716.829,1406.88 716.838,1406.88 716.848,1406.88 716.857,1406.88 716.866,1406.88 716.875,1406.88 716.884,1406.88 716.894,1406.88 716.903,1406.88 716.912,1406.88 716.921,1406.88 716.93,1406.88 716.939,1406.88 716.949,1406.88 716.958,1406.88 716.967,1406.88 716.976,1406.88 716.985,1406.88 716.995,1406.88 717.004,1406.88 717.013,1406.88 717.022,1406.88 717.031,1406.88 717.041,1406.88 717.05,1406.88 717.059,1406.88 717.068,1406.88 717.077,1406.88 717.087,1406.88 717.096,1406.88 717.105,1406.88 717.114,1406.88 717.123,1406.88 717.132,1406.88 717.142,1406.88 717.151,1406.88 717.16,1406.88 717.169,1406.88 717.178,1406.88 717.188,1406.88 717.197,1406.88 717.206,1406.88 717.215,1406.88 717.224,1406.88 717.234,1406.88 717.243,1406.88 717.252,1406.88 717.261,1406.88 717.27,1406.88 717.279,1406.88 717.289,1406.88 717.298,1406.88 717.307,1406.88 717.316,1406.88 717.325,1406.88 717.335,1406.88 717.344,1406.88 717.353,1406.88 717.362,1406.88 717.371,1406.88 717.381,1406.88 717.39,1406.88 717.399,1406.88 717.408,1406.88 717.417,1406.88 717.427,1406.88 717.436,1406.88 717.445,1406.88 717.454,1406.88 717.463,1406.88 717.472,1406.88 717.482,1406.88 717.491,1406.88 717.5,1406.88 717.509,1406.88 717.518,1406.88 717.528,1406.88 717.537,1406.88 717.546,1406.88 717.555,1406.88 717.564,1406.88 717.574,1406.88 717.583,1406.88 717.592,1406.88 717.601,1406.88 717.61,1406.88 717.619,1406.88 717.629,1406.88 717.638,1406.88 717.647,1406.88 717.656,1406.88 717.665,1406.88 717.675,1406.88 717.684,1406.88 717.693,1406.88 717.702,1406.88 717.711,1406.88 717.721,1406.88 717.73,1406.88 717.739,1406.88 717.748,1406.88 717.757,1406.88 717.767,1406.88 717.776,1406.88 717.785,1406.88 717.794,1406.88 717.803,1406.88 717.812,1406.88 717.822,1406.88 717.831,1406.88 717.84,1406.88 717.849,1406.88 717.858,1406.88 717.868,1406.88 717.877,1406.88 717.886,1406.88 717.895,1406.88 717.904,1406.88 717.914,1406.88 717.923,1406.88 717.932,1406.88 717.941,1406.88 717.95,1406.88 717.959,1406.88 717.969,1406.88 717.978,1406.88 717.987,1406.88 717.996,1406.88 718.005,1406.88 718.015,1406.88 718.024,1406.88 718.033,1406.88 718.042,1406.88 718.051,1406.88 718.061,1406.88 718.07,1406.88 718.079,1406.88 718.088,1406.88 718.097,1406.88 718.107,1406.88 718.116,1406.88 718.125,1406.88 718.134,1406.88 718.143,1406.88 718.152,1406.88 718.162,1406.88 718.171,1406.88 718.18,1406.88 718.189,1406.88 718.198,1406.88 718.208,1406.88 718.217,1406.88 718.226,1406.88 718.235,1406.88 718.244,1406.88 718.254,1406.88 718.263,1406.88 718.272,1406.88 718.281,1406.88 718.29,1406.88 718.299,1406.88 718.309,1406.88 718.318,1406.88 718.327,1406.88 718.336,1406.88 718.345,1406.88 718.355,1406.88 718.364,1406.88 718.373,1406.88 718.382,1406.88 718.391,1406.88 718.401,1406.88 718.41,1406.88 718.419,1406.88 718.428,1406.88 718.437,1406.88 718.447,1406.88 718.456,1406.88 718.465,1406.88 718.474,1406.88 718.483,1406.88 718.492,1406.88 718.502,1406.88 718.511,1406.88 718.52,1406.88 718.529,1406.88 718.538,1406.88 718.548,1406.88 718.557,1406.88 718.566,1406.88 718.575,1406.88 718.584,1406.88 718.594,1406.88 718.603,1406.88 718.612,1406.88 718.621,1406.88 718.63,1406.88 718.64,1406.88 718.649,1406.88 718.658,1406.88 718.667,1406.88 718.676,1406.88 718.685,1406.88 718.695,1406.88 718.704,1406.88 718.713,1406.88 718.722,1406.88 718.731,1406.88 718.741,1406.88 718.75,1406.88 718.759,1406.88 718.768,1406.88 718.777,1406.88 718.787,1406.88 718.796,1406.88 718.805,1406.88 718.814,1406.88 718.823,1406.88 718.832,1406.88 718.842,1406.88 718.851,1406.88 718.86,1406.88 718.869,1406.88 718.878,1406.88 718.888,1406.88 718.897,1406.88 718.906,1406.88 718.915,1406.88 718.924,1406.88 718.934,1406.88 718.943,1406.88 718.952,1406.88 718.961,1406.88 718.97,1406.88 718.98,1406.88 718.989,1406.88 718.998,1406.88 719.007,1406.88 719.016,1406.88 719.025,1406.88 719.035,1406.88 719.044,1406.88 719.053,1406.88 719.062,1406.88 719.071,1406.88 719.081,1406.88 719.09,1406.88 719.099,1406.88 719.108,1406.88 719.117,1406.88 719.127,1406.88 719.136,1406.88 719.145,1406.88 719.154,1406.88 719.163,1406.88 719.172,1406.88 719.182,1406.88 719.191,1406.88 719.2,1406.88 719.209,1406.88 719.218,1406.88 719.228,1406.88 719.237,1406.88 719.246,1406.88 719.255,1406.88 719.264,1406.88 719.274,1406.88 719.283,1406.88 719.292,1406.88 719.301,1406.88 719.31,1406.88 719.32,1406.88 719.329,1406.88 719.338,1406.88 719.347,1406.88 719.356,1406.88 719.365,1406.88 719.375,1406.88 719.384,1406.88 719.393,1406.88 719.402,1406.88 719.411,1406.88 719.421,1406.88 719.43,1406.88 719.439,1406.88 719.448,1406.88 719.457,1406.88 719.467,1406.88 719.476,1406.88 719.485,1406.88 719.494,1406.88 719.503,1406.88 719.512,1406.88 719.522,1406.88 719.531,1406.88 719.54,1406.88 719.549,1406.88 719.558,1406.88 719.568,1406.88 719.577,1406.88 719.586,1406.88 719.595,1406.88 719.604,1406.88 719.614,1406.88 719.623,1406.88 719.632,1406.88 719.641,1406.88 719.65,1406.88 719.66,1406.88 719.669,1406.88 719.678,1406.88 719.687,1406.88 719.696,1406.88 719.705,1406.88 719.715,1406.88 719.724,1406.88 719.733,1406.88 719.742,1406.88 719.751,1406.88 719.761,1406.88 719.77,1406.88 719.779,1406.88 719.788,1406.88 719.797,1406.88 719.807,1406.88 719.816,1406.88 719.825,1406.88 719.834,1406.88 719.843,1406.88 719.852,1406.88 719.862,1406.88 719.871,1406.88 719.88,1406.88 719.889,1406.88 719.898,1406.88 719.908,1406.88 719.917,1406.88 719.926,1406.88 719.935,1406.88 719.944,1406.88 719.954,1406.88 719.963,1406.88 719.972,1406.88 719.981,1406.88 719.99,1406.88 720,1406.88 720.009,1406.88 720.018,1406.88 720.027,1406.88 720.036,1406.88 720.045,1406.88 720.055,1406.88 720.064,1406.88 720.073,1406.88 720.082,1406.88 720.091,1406.88 720.101,1406.88 720.11,1406.88 720.119,1406.88 720.128,1406.88 720.137,1406.88 720.147,1406.88 720.156,1406.88 720.165,1406.88 720.174,1406.88 720.183,1406.88 720.192,1406.88 720.202,1406.88 720.211,1406.88 720.22,1406.88 720.229,1406.88 720.238,1406.88 720.248,1406.88 720.257,1406.88 720.266,1406.88 720.275,1406.88 720.284,1406.88 720.294,1406.88 720.303,1406.88 720.312,1406.88 720.321,1406.88 720.33,1406.88 720.34,1406.88 720.349,1406.88 720.358,1406.88 720.367,1406.88 720.376,1406.88 720.385,1406.88 720.395,1406.88 720.404,1406.88 720.413,1406.88 720.422,1406.88 720.431,1406.88 720.441,1406.88 720.45,1406.88 720.459,1406.88 720.468,1406.88 720.477,1406.88 720.487,1406.88 720.496,1406.88 720.505,1406.88 720.514,1406.88 720.523,1406.88 720.532,1406.88 720.542,1406.88 720.551,1406.88 720.56,1406.88 720.569,1406.88 720.578,1406.88 720.588,1406.88 720.597,1406.88 720.606,1406.88 720.615,1406.88 720.624,1406.88 720.634,1406.88 720.643,1406.88 720.652,1406.88 720.661,1406.88 720.67,1406.88 720.68,1406.88 720.689,1406.88 720.698,1406.88 720.707,1406.88 720.716,1406.88 720.725,1406.88 720.735,1406.88 720.744,1406.88 720.753,1406.88 720.762,1406.88 720.771,1406.88 720.781,1406.88 720.79,1406.88 720.799,1406.88 720.808,1406.88 720.817,1406.88 720.827,1406.88 720.836,1406.88 720.845,1406.88 720.854,1406.88 720.863,1406.88 720.872,1406.88 720.882,1406.88 720.891,1406.88 720.9,1406.88 720.909,1406.88 720.918,1406.88 720.928,1406.88 720.937,1406.88 720.946,1406.88 720.955,1406.88 720.964,1406.88 720.974,1406.88 720.983,1406.88 720.992,1406.88 721.001,1406.88 721.01,1406.88 721.02,1406.88 721.029,1406.88 721.038,1406.88 721.047,1406.88 721.056,1406.88 721.065,1406.88 721.075,1406.88 721.084,1406.88 721.093,1406.88 721.102,1406.88 721.111,1406.88 721.121,1406.88 721.13,1406.88 721.139,1406.88 721.148,1406.88 721.157,1406.88 721.167,1406.88 721.176,1406.88 721.185,1406.88 721.194,1406.88 721.203,1406.88 721.213,1406.88 721.222,1406.88 721.231,1406.88 721.24,1406.88 721.249,1406.88 721.258,1406.88 721.268,1406.88 721.277,1406.88 721.286,1406.88 721.295,1406.88 721.304,1406.88 721.314,1406.88 721.323,1406.88 721.332,1406.88 721.341,1406.88 721.35,1406.88 721.36,1406.88 721.369,1406.88 721.378,1406.88 721.387,1406.88 721.396,1406.88 721.405,1406.88 721.415,1406.88 721.424,1406.88 721.433,1406.88 721.442,1406.88 721.451,1406.88 721.461,1406.88 721.47,1406.88 721.479,1406.88 721.488,1406.88 721.497,1406.88 721.507,1406.88 721.516,1406.88 721.525,1406.88 721.534,1406.88 721.543,1406.88 721.553,1406.88 721.562,1406.88 721.571,1406.88 721.58,1406.88 721.589,1406.88 721.598,1406.88 721.608,1406.88 721.617,1406.88 721.626,1406.88 721.635,1406.88 721.644,1406.88 721.654,1406.88 721.663,1406.88 721.672,1406.88 721.681,1406.88 721.69,1406.88 721.7,1406.88 721.709,1406.88 721.718,1406.88 721.727,1406.88 721.736,1406.88 721.745,1406.88 721.755,1406.88 721.764,1406.88 721.773,1406.88 721.782,1406.88 721.791,1406.88 721.801,1406.88 721.81,1406.88 721.819,1406.88 721.828,1406.88 721.837,1406.88 721.847,1406.88 721.856,1406.88 721.865,1406.88 721.874,1406.88 721.883,1406.88 721.893,1406.88 721.902,1406.88 721.911,1406.88 721.92,1406.88 721.929,1406.88 721.938,1406.88 721.948,1406.88 721.957,1406.88 721.966,1406.88 721.975,1406.88 721.984,1406.88 721.994,1406.88 722.003,1406.88 722.012,1406.88 722.021,1406.88 722.03,1406.88 722.04,1406.88 722.049,1406.88 722.058,1406.88 722.067,1406.88 722.076,1406.88 722.085,1406.88 722.095,1406.88 722.104,1406.88 722.113,1406.88 722.122,1406.88 722.131,1406.88 722.141,1406.88 722.15,1406.88 722.159,1406.88 722.168,1406.88 722.177,1406.88 722.187,1406.88 722.196,1406.88 722.205,1406.88 722.214,1406.88 722.223,1406.88 722.233,1406.88 722.242,1406.88 722.251,1406.88 722.26,1406.88 722.269,1406.88 722.278,1406.88 722.288,1406.88 722.297,1406.88 722.306,1406.88 722.315,1406.88 722.324,1406.88 722.334,1406.88 722.343,1406.88 722.352,1406.88 722.361,1406.88 722.37,1406.88 722.38,1406.88 722.389,1406.88 722.398,1406.88 722.407,1406.88 722.416,1406.88 722.425,1406.88 722.435,1406.88 722.444,1406.88 722.453,1406.88 722.462,1406.88 722.471,1406.88 722.481,1406.88 722.49,1406.88 722.499,1406.88 722.508,1406.88 722.517,1406.88 722.527,1406.88 722.536,1406.88 722.545,1406.88 722.554,1406.88 722.563,1406.88 722.573,1406.88 722.582,1406.88 722.591,1406.88 722.6,1406.88 722.609,1406.88 722.618,1406.88 722.628,1406.88 722.637,1406.88 722.646,1406.88 722.655,1406.88 722.664,1406.88 722.674,1406.88 722.683,1406.88 722.692,1406.88 722.701,1406.88 722.71,1406.88 722.72,1406.88 722.729,1406.88 722.738,1406.88 722.747,1406.88 722.756,1406.88 722.765,1406.88 722.775,1406.88 722.784,1406.88 722.793,1406.88 722.802,1406.88 722.811,1406.88 722.821,1406.88 722.83,1406.88 722.839,1406.88 722.848,1406.88 722.857,1406.88 722.867,1406.88 722.876,1406.88 722.885,1406.88 722.894,1406.88 722.903,1406.88 722.913,1406.88 722.922,1406.88 722.931,1406.88 722.94,1406.88 722.949,1406.88 722.958,1406.88 722.968,1406.88 722.977,1406.88 722.986,1406.88 722.995,1406.88 723.004,1406.88 723.014,1406.88 723.023,1406.88 723.032,1406.88 723.041,1406.88 723.05,1406.88 723.06,1406.88 723.069,1406.88 723.078,1406.88 723.087,1406.88 723.096,1406.88 723.105,1406.88 723.115,1406.88 723.124,1406.88 723.133,1406.88 723.142,1406.88 723.151,1406.88 723.161,1406.88 723.17,1406.88 723.179,1406.88 723.188,1406.88 723.197,1406.88 723.207,1406.88 723.216,1406.88 723.225,1406.88 723.234,1406.88 723.243,1406.88 723.253,1406.88 723.262,1406.88 723.271,1406.88 723.28,1406.88 723.289,1406.88 723.298,1406.88 723.308,1406.88 723.317,1406.88 723.326,1406.88 723.335,1406.88 723.344,1406.88 723.354,1406.88 723.363,1406.88 723.372,1406.88 723.381,1406.88 723.39,1406.88 723.4,1406.88 723.409,1406.88 723.418,1406.88 723.427,1406.88 723.436,1406.88 723.446,1406.88 723.455,1406.88 723.464,1406.88 723.473,1406.88 723.482,1406.88 723.491,1406.88 723.501,1406.88 723.51,1406.88 723.519,1406.88 723.528,1406.88 723.537,1406.88 723.547,1406.88 723.556,1406.88 723.565,1406.88 723.574,1406.88 723.583,1406.88 723.593,1406.88 723.602,1406.88 723.611,1406.88 723.62,1406.88 723.629,1406.88 723.638,1406.88 723.648,1406.88 723.657,1406.88 723.666,1406.88 723.675,1406.88 723.684,1406.88 723.694,1406.88 723.703,1406.88 723.712,1406.88 723.721,1406.88 723.73,1406.88 723.74,1406.88 723.749,1406.88 723.758,1406.88 723.767,1406.88 723.776,1406.88 723.786,1406.88 723.795,1406.88 723.804,1406.88 723.813,1406.88 723.822,1406.88 723.831,1406.88 723.841,1406.88 723.85,1406.88 723.859,1406.88 723.868,1406.88 723.877,1406.88 723.887,1406.88 723.896,1406.88 723.905,1406.88 723.914,1406.88 723.923,1406.88 723.933,1406.88 723.942,1406.88 723.951,1406.88 723.96,1406.88 723.969,1406.88 723.978,1406.88 723.988,1406.88 723.997,1406.88 724.006,1406.88 724.015,1406.88 724.024,1406.88 724.034,1406.88 724.043,1406.88 724.052,1406.88 724.061,1406.88 724.07,1406.88 724.08,1406.88 724.089,1406.88 724.098,1406.88 724.107,1406.88 724.116,1406.88 724.126,1406.88 724.135,1406.88 724.144,1406.88 724.153,1406.88 724.162,1406.88 724.171,1406.88 724.181,1406.88 724.19,1406.88 724.199,1406.88 724.208,1406.88 724.217,1406.88 724.227,1406.88 724.236,1406.88 724.245,1406.88 724.254,1406.88 724.263,1406.88 724.273,1406.88 724.282,1406.88 724.291,1406.88 724.3,1406.88 724.309,1406.88 724.318,1406.88 724.328,1406.88 724.337,1406.88 724.346,1406.88 724.355,1406.88 724.364,1406.88 724.374,1406.88 724.383,1406.88 724.392,1406.88 724.401,1406.88 724.41,1406.88 724.42,1406.88 724.429,1406.88 724.438,1406.88 724.447,1406.88 724.456,1406.88 724.466,1406.88 724.475,1406.88 724.484,1406.88 724.493,1406.88 724.502,1406.88 724.511,1406.88 724.521,1406.88 724.53,1406.88 724.539,1406.88 724.548,1406.88 724.557,1406.88 724.567,1406.88 724.576,1406.88 724.585,1406.88 724.594,1406.88 724.603,1406.88 724.613,1406.88 724.622,1406.88 724.631,1406.88 724.64,1406.88 724.649,1406.88 724.658,1406.88 724.668,1406.88 724.677,1406.88 724.686,1406.88 724.695,1406.88 724.704,1406.88 724.714,1406.88 724.723,1406.88 724.732,1406.88 724.741,1406.88 724.75,1406.88 724.76,1406.88 724.769,1406.88 724.778,1406.88 724.787,1406.88 724.796,1406.88 724.806,1406.88 724.815,1406.88 724.824,1406.88 724.833,1406.88 724.842,1406.88 724.851,1406.88 724.861,1406.88 724.87,1406.88 724.879,1406.88 724.888,1406.88 724.897,1406.88 724.907,1406.88 724.916,1406.88 724.925,1406.88 724.934,1406.88 724.943,1406.88 724.953,1406.88 724.962,1406.88 724.971,1406.88 724.98,1406.88 724.989,1406.88 724.998,1406.88 725.008,1406.88 725.017,1406.88 725.026,1406.88 725.035,1406.88 725.044,1406.88 725.054,1406.88 725.063,1406.88 725.072,1406.88 725.081,1406.88 725.09,1406.88 725.1,1406.88 725.109,1406.88 725.118,1406.88 725.127,1406.88 725.136,1406.88 725.146,1406.88 725.155,1406.88 725.164,1406.88 725.173,1406.88 725.182,1406.88 725.191,1406.88 725.201,1406.88 725.21,1406.88 725.219,1406.88 725.228,1406.88 725.237,1406.88 725.247,1406.88 725.256,1406.88 725.265,1406.88 725.274,1406.88 725.283,1406.88 725.293,1406.88 725.302,1406.88 725.311,1406.88 725.32,1406.88 725.329,1406.88 725.338,1406.88 725.348,1406.88 725.357,1406.88 725.366,1406.88 725.375,1406.88 725.384,1406.88 725.394,1406.88 725.403,1406.88 725.412,1406.88 725.421,1406.88 725.43,1406.88 725.44,1406.88 725.449,1406.88 725.458,1406.88 725.467,1406.88 725.476,1406.88 725.486,1406.88 725.495,1406.88 725.504,1406.88 725.513,1406.88 725.522,1406.88 725.531,1406.88 725.541,1406.88 725.55,1406.88 725.559,1406.88 725.568,1406.88 725.577,1406.88 725.587,1406.88 725.596,1406.88 725.605,1406.88 725.614,1406.88 725.623,1406.88 725.633,1406.88 725.642,1406.88 725.651,1406.88 725.66,1406.88 725.669,1406.88 725.678,1406.88 725.688,1406.88 725.697,1406.88 725.706,1406.88 725.715,1406.88 725.724,1406.88 725.734,1406.88 725.743,1406.88 725.752,1406.88 725.761,1406.88 725.77,1406.88 725.78,1406.88 725.789,1406.88 725.798,1406.88 725.807,1406.88 725.816,1406.88 725.826,1406.88 725.835,1406.88 725.844,1406.88 725.853,1406.88 725.862,1406.88 725.871,1406.88 725.881,1406.88 725.89,1406.88 725.899,1406.88 725.908,1406.88 725.917,1406.88 725.927,1406.88 725.936,1406.88 725.945,1406.88 725.954,1406.88 725.963,1406.88 725.973,1406.88 725.982,1406.88 725.991,1406.88 726,1406.88 726.009,1406.88 726.019,1406.88 726.028,1406.88 726.037,1406.88 726.046,1406.88 726.055,1406.88 726.064,1406.88 726.074,1406.88 726.083,1406.88 726.092,1406.88 726.101,1406.88 726.11,1406.88 726.12,1406.88 726.129,1406.88 726.138,1406.88 726.147,1406.88 726.156,1406.88 726.166,1406.88 726.175,1406.88 726.184,1406.88 726.193,1406.88 726.202,1406.88 726.211,1406.88 726.221,1406.88 726.23,1406.88 726.239,1406.88 726.248,1406.88 726.257,1406.88 726.267,1406.88 726.276,1406.88 726.285,1406.88 726.294,1406.88 726.303,1406.88 726.313,1406.88 726.322,1406.88 726.331,1406.88 726.34,1406.88 726.349,1406.88 726.359,1406.88 726.368,1406.88 726.377,1406.88 726.386,1406.88 726.395,1406.88 726.404,1406.88 726.414,1406.88 726.423,1406.88 726.432,1406.88 726.441,1406.88 726.45,1406.88 726.46,1406.88 726.469,1406.88 726.478,1406.88 726.487,1406.88 726.496,1406.88 726.506,1406.88 726.515,1406.88 726.524,1406.88 726.533,1406.88 726.542,1406.88 726.551,1406.88 726.561,1406.88 726.57,1406.88 726.579,1406.88 726.588,1406.88 726.597,1406.88 726.607,1406.88 726.616,1406.88 726.625,1406.88 726.634,1406.88 726.643,1406.88 726.653,1406.88 726.662,1406.88 726.671,1406.88 726.68,1406.88 726.689,1406.88 726.699,1406.88 726.708,1406.88 726.717,1406.88 726.726,1406.88 726.735,1406.88 726.744,1406.88 726.754,1406.88 726.763,1406.88 726.772,1406.88 726.781,1406.88 726.79,1406.88 726.8,1406.88 726.809,1406.88 726.818,1406.88 726.827,1406.88 726.836,1406.88 726.846,1406.88 726.855,1406.88 726.864,1406.88 726.873,1406.88 726.882,1406.88 726.891,1406.88 726.901,1406.88 726.91,1406.88 726.919,1406.88 726.928,1406.88 726.937,1406.88 726.947,1406.88 726.956,1406.88 726.965,1406.88 726.974,1406.88 726.983,1406.88 726.993,1406.88 727.002,1406.88 727.011,1406.88 727.02,1406.88 727.029,1406.88 727.039,1406.88 727.048,1406.88 727.057,1406.88 727.066,1406.88 727.075,1406.88 727.084,1406.88 727.094,1406.88 727.103,1406.88 727.112,1406.88 727.121,1406.88 727.13,1406.88 727.14,1406.88 727.149,1406.88 727.158,1406.88 727.167,1406.88 727.176,1406.88 727.186,1406.88 727.195,1406.88 727.204,1406.88 727.213,1406.88 727.222,1406.88 727.231,1406.88 727.241,1406.88 727.25,1406.88 727.259,1406.88 727.268,1406.88 727.277,1406.88 727.287,1406.88 727.296,1406.88 727.305,1406.88 727.314,1406.88 727.323,1406.88 727.333,1406.88 727.342,1406.88 727.351,1406.88 727.36,1406.88 727.369,1406.88 727.379,1406.88 727.388,1406.88 727.397,1406.88 727.406,1406.88 727.415,1406.88 727.424,1406.88 727.434,1406.88 727.443,1406.88 727.452,1406.88 727.461,1406.88 727.47,1406.88 727.48,1406.88 727.489,1406.88 727.498,1406.88 727.507,1406.88 727.516,1406.88 727.526,1406.88 727.535,1406.88 727.544,1406.88 727.553,1406.88 727.562,1406.88 727.571,1406.88 727.581,1406.88 727.59,1406.88 727.599,1406.88 727.608,1406.88 727.617,1406.88 727.627,1406.88 727.636,1406.88 727.645,1406.88 727.654,1406.88 727.663,1406.88 727.673,1406.88 727.682,1406.88 727.691,1406.88 727.7,1406.88 727.709,1406.88 727.719,1406.88 727.728,1406.88 727.737,1406.88 727.746,1406.88 727.755,1406.88 727.764,1406.88 727.774,1406.88 727.783,1406.88 727.792,1406.88 727.801,1406.88 727.81,1406.88 727.82,1406.88 727.829,1406.88 727.838,1406.88 727.847,1406.88 727.856,1406.88 727.866,1406.88 727.875,1406.88 727.884,1406.88 727.893,1406.88 727.902,1406.88 727.911,1406.88 727.921,1406.88 727.93,1406.88 727.939,1406.88 727.948,1406.88 727.957,1406.88 727.967,1406.88 727.976,1406.88 727.985,1406.88 727.994,1406.88 728.003,1406.88 728.013,1406.88 728.022,1406.88 728.031,1406.88 728.04,1406.88 728.049,1406.88 728.059,1406.88 728.068,1406.88 728.077,1406.88 728.086,1406.88 728.095,1406.88 728.104,1406.88 728.114,1406.88 728.123,1406.88 728.132,1406.88 728.141,1406.88 728.15,1406.88 728.16,1406.88 728.169,1406.88 728.178,1406.88 728.187,1406.88 728.196,1406.88 728.206,1406.88 728.215,1406.88 728.224,1406.88 728.233,1406.88 728.242,1406.88 728.251,1406.88 728.261,1406.88 728.27,1406.88 728.279,1406.88 728.288,1406.88 728.297,1406.88 728.307,1406.88 728.316,1406.88 728.325,1406.88 728.334,1406.88 728.343,1406.88 728.353,1406.88 728.362,1406.88 728.371,1406.88 728.38,1406.88 728.389,1406.88 728.399,1406.88 728.408,1406.88 728.417,1406.88 728.426,1406.88 728.435,1406.88 728.444,1406.88 728.454,1406.88 728.463,1406.88 728.472,1406.88 728.481,1406.88 728.49,1406.88 728.5,1406.88 728.509,1406.88 728.518,1406.88 728.527,1406.88 728.536,1406.88 728.546,1406.88 728.555,1406.88 728.564,1406.88 728.573,1406.88 728.582,1406.88 728.592,1406.88 728.601,1406.88 728.61,1406.88 728.619,1406.88 728.628,1406.88 728.637,1406.88 728.647,1406.88 728.656,1406.88 728.665,1406.88 728.674,1406.88 728.683,1406.88 728.693,1406.88 728.702,1406.88 728.711,1406.88 728.72,1406.88 728.729,1406.88 728.739,1406.88 728.748,1406.88 728.757,1406.88 728.766,1406.88 728.775,1406.88 728.784,1406.88 728.794,1406.88 728.803,1406.88 728.812,1406.88 728.821,1406.88 728.83,1406.88 728.84,1406.88 728.849,1406.88 728.858,1406.88 728.867,1406.88 728.876,1406.88 728.886,1406.88 728.895,1406.88 728.904,1406.88 728.913,1406.88 728.922,1406.88 728.932,1406.88 728.941,1406.88 728.95,1406.88 728.959,1406.88 728.968,1406.88 728.977,1406.88 728.987,1406.88 728.996,1406.88 729.005,1406.88 729.014,1406.88 729.023,1406.88 729.033,1406.88 729.042,1406.88 729.051,1406.88 729.06,1406.88 729.069,1406.88 729.079,1406.88 729.088,1406.88 729.097,1406.88 729.106,1406.88 729.115,1406.88 729.124,1406.88 729.134,1406.88 729.143,1406.88 729.152,1406.88 729.161,1406.88 729.17,1406.88 729.18,1406.88 729.189,1406.88 729.198,1406.88 729.207,1406.88 729.216,1406.88 729.226,1406.88 729.235,1406.88 729.244,1406.88 729.253,1406.88 729.262,1406.88 729.272,1406.88 729.281,1406.88 729.29,1406.88 729.299,1406.88 729.308,1406.88 729.317,1406.88 729.327,1406.88 729.336,1406.88 729.345,1406.88 729.354,1406.88 729.363,1406.88 729.373,1406.88 729.382,1406.88 729.391,1406.88 729.4,1406.88 729.409,1406.88 729.419,1406.88 729.428,1406.88 729.437,1406.88 729.446,1406.88 729.455,1406.88 729.464,1406.88 729.474,1406.88 729.483,1406.88 729.492,1406.88 729.501,1406.88 729.51,1406.88 729.52,1406.88 729.529,1406.88 729.538,1406.88 729.547,1406.88 729.556,1406.88 729.566,1406.88 729.575,1406.88 729.584,1406.88 729.593,1406.88 729.602,1406.88 729.612,1406.88 729.621,1406.88 729.63,1406.88 729.639,1406.88 729.648,1406.88 729.657,1406.88 729.667,1406.88 729.676,1406.88 729.685,1406.88 729.694,1406.88 729.703,1406.88 729.713,1406.88 729.722,1406.88 729.731,1406.88 729.74,1406.88 729.749,1406.88 729.759,1406.88 729.768,1406.88 729.777,1406.88 729.786,1406.88 729.795,1406.88 729.804,1406.88 729.814,1406.88 729.823,1406.88 729.832,1406.88 729.841,1406.88 729.85,1406.88 729.86,1406.88 729.869,1406.88 729.878,1406.88 729.887,1406.88 729.896,1406.88 729.906,1406.88 729.915,1406.88 729.924,1406.88 729.933,1406.88 729.942,1406.88 729.952,1406.88 729.961,1406.88 729.97,1406.88 729.979,1406.88 729.988,1406.88 729.997,1406.88 730.007,1406.88 730.016,1406.88 730.025,1406.88 730.034,1406.88 730.043,1406.88 730.053,1406.88 730.062,1406.88 730.071,1406.88 730.08,1406.88 730.089,1406.88 730.099,1406.88 730.108,1406.88 730.117,1406.88 730.126,1406.88 730.135,1406.88 730.144,1406.88 730.154,1406.88 730.163,1406.88 730.172,1406.88 730.181,1406.88 730.19,1406.88 730.2,1406.88 730.209,1406.88 730.218,1406.88 730.227,1406.88 730.236,1406.88 730.246,1406.88 730.255,1406.88 730.264,1406.88 730.273,1406.88 730.282,1406.88 730.292,1406.88 730.301,1406.88 730.31,1406.88 730.319,1406.88 730.328,1406.88 730.337,1406.88 730.347,1406.88 730.356,1406.88 730.365,1406.88 730.374,1406.88 730.383,1406.88 730.393,1406.88 730.402,1406.88 730.411,1406.88 730.42,1406.88 730.429,1406.88 730.439,1406.88 730.448,1406.88 730.457,1406.88 730.466,1406.88 730.475,1406.88 730.484,1406.88 730.494,1406.88 730.503,1406.88 730.512,1406.88 730.521,1406.88 730.53,1406.88 730.54,1406.88 730.549,1406.88 730.558,1406.88 730.567,1406.88 730.576,1406.88 730.586,1406.88 730.595,1406.88 730.604,1406.88 730.613,1406.88 730.622,1406.88 730.632,1406.88 730.641,1406.88 730.65,1406.88 730.659,1406.88 730.668,1406.88 730.677,1406.88 730.687,1406.88 730.696,1406.88 730.705,1406.88 730.714,1406.88 730.723,1406.88 730.733,1406.88 730.742,1406.88 730.751,1406.88 730.76,1406.88 730.769,1406.88 730.779,1406.88 730.788,1406.88 730.797,1406.88 730.806,1406.88 730.815,1406.88 730.825,1406.88 730.834,1406.88 730.843,1406.88 730.852,1406.88 730.861,1406.88 730.87,1406.88 730.88,1406.88 730.889,1406.88 730.898,1406.88 730.907,1406.88 730.916,1406.88 730.926,1406.88 730.935,1406.88 730.944,1406.88 730.953,1406.88 730.962,1406.88 730.972,1406.88 730.981,1406.88 730.99,1406.88 730.999,1406.88 731.008,1406.88 731.017,1406.88 731.027,1406.88 731.036,1406.88 731.045,1406.88 731.054,1406.88 731.063,1406.88 731.073,1406.88 731.082,1406.88 731.091,1406.88 731.1,1406.88 731.109,1406.88 731.119,1406.88 731.128,1406.88 731.137,1406.88 731.146,1406.88 731.155,1406.88 731.165,1406.88 731.174,1406.88 731.183,1406.88 731.192,1406.88 731.201,1406.88 731.21,1406.88 731.22,1406.88 731.229,1406.88 731.238,1406.88 731.247,1406.88 731.256,1406.88 731.266,1406.88 731.275,1406.88 731.284,1406.88 731.293,1406.88 731.302,1406.88 731.312,1406.88 731.321,1406.88 731.33,1406.88 731.339,1406.88 731.348,1406.88 731.357,1406.88 731.367,1406.88 731.376,1406.88 731.385,1406.88 731.394,1406.88 731.403,1406.88 731.413,1406.88 731.422,1406.88 731.431,1406.88 731.44,1406.88 731.449,1406.88 731.459,1406.88 731.468,1406.88 731.477,1406.88 731.486,1406.88 731.495,1406.88 731.505,1406.88 731.514,1406.88 731.523,1406.88 731.532,1406.88 731.541,1406.88 731.55,1406.88 731.56,1406.88 731.569,1406.88 731.578,1406.88 731.587,1406.88 731.596,1406.88 731.606,1406.88 731.615,1406.88 731.624,1406.88 731.633,1406.88 731.642,1406.88 731.652,1406.88 731.661,1406.88 731.67,1406.88 731.679,1406.88 731.688,1406.88 731.697,1406.88 731.707,1406.88 731.716,1406.88 731.725,1406.88 731.734,1406.88 731.743,1406.88 731.753,1406.88 731.762,1406.88 731.771,1406.88 731.78,1406.88 731.789,1406.88 731.799,1406.88 731.808,1406.88 731.817,1406.88 731.826,1406.88 731.835,1406.88 731.845,1406.88 731.854,1406.88 731.863,1406.88 731.872,1406.88 731.881,1406.88 731.89,1406.88 731.9,1406.88 731.909,1406.88 731.918,1406.88 731.927,1406.88 731.936,1406.88 731.946,1406.88 731.955,1406.88 731.964,1406.88 731.973,1406.88 731.982,1406.88 731.992,1406.88 732.001,1406.88 732.01,1406.88 732.019,1406.88 732.028,1406.88 732.037,1406.88 732.047,1406.88 732.056,1406.88 732.065,1406.88 732.074,1406.88 732.083,1406.88 732.093,1406.88 732.102,1406.88 732.111,1406.88 732.12,1406.88 732.129,1406.88 732.139,1406.88 732.148,1406.88 732.157,1406.88 732.166,1406.88 732.175,1406.88 732.185,1406.88 732.194,1406.88 732.203,1406.88 732.212,1406.88 732.221,1406.88 732.23,1406.88 732.24,1406.88 732.249,1406.88 732.258,1406.88 732.267,1406.88 732.276,1406.88 732.286,1406.88 732.295,1406.88 732.304,1406.88 732.313,1406.88 732.322,1406.88 732.332,1406.88 732.341,1406.88 732.35,1406.88 732.359,1406.88 732.368,1406.88 732.377,1406.88 732.387,1406.88 732.396,1406.88 732.405,1406.88 732.414,1406.88 732.423,1406.88 732.433,1406.88 732.442,1406.88 732.451,1406.88 732.46,1406.88 732.469,1406.88 732.479,1406.88 732.488,1406.88 732.497,1406.88 732.506,1406.88 732.515,1406.88 732.525,1406.88 732.534,1406.88 732.543,1406.88 732.552,1406.88 732.561,1406.88 732.57,1406.88 732.58,1406.88 732.589,1406.88 732.598,1406.88 732.607,1406.88 732.616,1406.88 732.626,1406.88 732.635,1406.88 732.644,1406.88 732.653,1406.88 732.662,1406.88 732.672,1406.88 732.681,1406.88 732.69,1406.88 732.699,1406.88 732.708,1406.88 732.717,1406.88 732.727,1406.88 732.736,1406.88 732.745,1406.88 732.754,1406.88 732.763,1406.88 732.773,1406.88 732.782,1406.88 732.791,1406.88 732.8,1406.88 732.809,1406.88 732.819,1406.88 732.828,1406.88 732.837,1406.88 732.846,1406.88 732.855,1406.88 732.865,1406.88 732.874,1406.88 732.883,1406.88 732.892,1406.88 732.901,1406.88 732.91,1406.88 732.92,1406.88 732.929,1406.88 732.938,1406.88 732.947,1406.88 732.956,1406.88 732.966,1406.88 732.975,1406.88 732.984,1406.88 732.993,1406.88 733.002,1406.88 733.012,1406.88 733.021,1406.88 733.03,1406.88 733.039,1406.88 733.048,1406.88 733.057,1406.88 733.067,1406.88 733.076,1406.88 733.085,1406.88 733.094,1406.88 733.103,1406.88 733.113,1406.88 733.122,1406.88 733.131,1406.88 733.14,1406.88 733.149,1406.88 733.159,1406.88 733.168,1406.88 733.177,1406.88 733.186,1406.88 733.195,1406.88 733.205,1406.88 733.214,1406.88 733.223,1406.88 733.232,1406.88 733.241,1406.88 733.25,1406.88 733.26,1406.88 733.269,1406.88 733.278,1406.88 733.287,1406.88 733.296,1406.88 733.306,1406.88 733.315,1406.88 733.324,1406.88 733.333,1406.88 733.342,1406.88 733.352,1406.88 733.361,1406.88 733.37,1406.88 733.379,1406.88 733.388,1406.88 733.398,1406.88 733.407,1406.88 733.416,1406.88 733.425,1406.88 733.434,1406.88 733.443,1406.88 733.453,1406.88 733.462,1406.88 733.471,1406.88 733.48,1406.88 733.489,1406.88 733.499,1406.88 733.508,1406.88 733.517,1406.88 733.526,1406.88 733.535,1406.88 733.545,1406.88 733.554,1406.88 733.563,1406.88 733.572,1406.88 733.581,1406.88 733.59,1406.88 733.6,1406.88 733.609,1406.88 733.618,1406.88 733.627,1406.88 733.636,1406.88 733.646,1406.88 733.655,1406.88 733.664,1406.88 733.673,1406.88 733.682,1406.88 733.692,1406.88 733.701,1406.88 733.71,1406.88 733.719,1406.88 733.728,1406.88 733.738,1406.88 733.747,1406.88 733.756,1406.88 733.765,1406.88 733.774,1406.88 733.783,1406.88 733.793,1406.88 733.802,1406.88 733.811,1406.88 733.82,1406.88 733.829,1406.88 733.839,1406.88 733.848,1406.88 733.857,1406.88 733.866,1406.88 733.875,1406.88 733.885,1406.88 733.894,1406.88 733.903,1406.88 733.912,1406.88 733.921,1406.88 733.93,1406.88 733.94,1406.88 733.949,1406.88 733.958,1406.88 733.967,1406.88 733.976,1406.88 733.986,1406.88 733.995,1406.88 734.004,1406.88 734.013,1406.88 734.022,1406.88 734.032,1406.88 734.041,1406.88 734.05,1406.88 734.059,1406.88 734.068,1406.88 734.078,1406.88 734.087,1406.88 734.096,1406.88 734.105,1406.88 734.114,1406.88 734.123,1406.88 734.133,1406.88 734.142,1406.88 734.151,1406.88 734.16,1406.88 734.169,1406.88 734.179,1406.88 734.188,1406.88 734.197,1406.88 734.206,1406.88 734.215,1406.88 734.225,1406.88 734.234,1406.88 734.243,1406.88 734.252,1406.88 734.261,1406.88 734.27,1406.88 734.28,1406.88 734.289,1406.88 734.298,1406.88 734.307,1406.88 734.316,1406.88 734.326,1406.88 734.335,1406.88 734.344,1406.88 734.353,1406.88 734.362,1406.88 734.372,1406.88 734.381,1406.88 734.39,1406.88 734.399,1406.88 734.408,1406.88 734.418,1406.88 734.427,1406.88 734.436,1406.88 734.445,1406.88 734.454,1406.88 734.463,1406.88 734.473,1406.88 734.482,1406.88 734.491,1406.88 734.5,1406.88 734.509,1406.88 734.519,1406.88 734.528,1406.88 734.537,1406.88 734.546,1406.88 734.555,1406.88 734.565,1406.88 734.574,1406.88 734.583,1406.88 734.592,1406.88 734.601,1406.88 734.61,1406.88 734.62,1406.88 734.629,1406.88 734.638,1406.88 734.647,1406.88 734.656,1406.88 734.666,1406.88 734.675,1406.88 734.684,1406.88 734.693,1406.88 734.702,1406.88 734.712,1406.88 734.721,1406.88 734.73,1406.88 734.739,1406.88 734.748,1406.88 734.758,1406.88 734.767,1406.88 734.776,1406.88 734.785,1406.88 734.794,1406.88 734.803,1406.88 734.813,1406.88 734.822,1406.88 734.831,1406.88 734.84,1406.88 734.849,1406.88 734.859,1406.88 734.868,1406.88 734.877,1406.88 734.886,1406.88 734.895,1406.88 734.905,1406.88 734.914,1406.88 734.923,1406.88 734.932,1406.88 734.941,1406.88 734.95,1406.88 734.96,1406.88 734.969,1406.88 734.978,1406.88 734.987,1406.88 734.996,1406.88 735.006,1406.88 735.015,1406.88 735.024,1406.88 735.033,1406.88 735.042,1406.88 735.052,1406.88 735.061,1406.88 735.07,1406.88 735.079,1406.88 735.088,1406.88 735.098,1406.88 735.107,1406.88 735.116,1406.88 735.125,1406.88 735.134,1406.88 735.143,1406.88 735.153,1406.88 735.162,1406.88 735.171,1406.88 735.18,1406.88 735.189,1406.88 735.199,1406.88 735.208,1406.88 735.217,1406.88 735.226,1406.88 735.235,1406.88 735.245,1406.88 735.254,1406.88 735.263,1406.88 735.272,1406.88 735.281,1406.88 735.29,1406.88 735.3,1406.88 735.309,1406.88 735.318,1406.88 735.327,1406.88 735.336,1406.88 735.346,1406.88 735.355,1406.88 735.364,1406.88 735.373,1406.88 735.382,1406.88 735.392,1406.88 735.401,1406.88 735.41,1406.88 735.419,1406.88 735.428,1406.88 735.438,1406.88 735.447,1406.88 735.456,1406.88 735.465,1406.88 735.474,1406.88 735.483,1406.88 735.493,1406.88 735.502,1406.88 735.511,1406.88 735.52,1406.88 735.529,1406.88 735.539,1406.88 735.548,1406.88 735.557,1406.88 735.566,1406.88 735.575,1406.88 735.585,1406.88 735.594,1406.88 735.603,1406.88 735.612,1406.88 735.621,1406.88 735.63,1406.88 735.64,1406.88 735.649,1406.88 735.658,1406.88 735.667,1406.88 735.676,1406.88 735.686,1406.88 735.695,1406.88 735.704,1406.88 735.713,1406.88 735.722,1406.88 735.732,1406.88 735.741,1406.88 735.75,1406.88 735.759,1406.88 735.768,1406.88 735.778,1406.88 735.787,1406.88 735.796,1406.88 735.805,1406.88 735.814,1406.88 735.823,1406.88 735.833,1406.88 735.842,1406.88 735.851,1406.88 735.86,1406.88 735.869,1406.88 735.879,1406.88 735.888,1406.88 735.897,1406.88 735.906,1406.88 735.915,1406.88 735.925,1406.88 735.934,1406.88 735.943,1406.88 735.952,1406.88 735.961,1406.88 735.971,1406.88 735.98,1406.88 735.989,1406.88 735.998,1406.88 736.007,1406.88 736.016,1406.88 736.026,1406.88 736.035,1406.88 736.044,1406.88 736.053,1406.88 736.062,1406.88 736.072,1406.88 736.081,1406.88 736.09,1406.88 736.099,1406.88 736.108,1406.88 736.118,1406.88 736.127,1406.88 736.136,1406.88 736.145,1406.88 736.154,1406.88 736.163,1406.88 736.173,1406.88 736.182,1406.88 736.191,1406.88 736.2,1406.88 736.209,1406.88 736.219,1406.88 736.228,1406.88 736.237,1406.88 736.246,1406.88 736.255,1406.88 736.265,1406.88 736.274,1406.88 736.283,1406.88 736.292,1406.88 736.301,1406.88 736.311,1406.88 736.32,1406.88 736.329,1406.88 736.338,1406.88 736.347,1406.88 736.356,1406.88 736.366,1406.88 736.375,1406.88 736.384,1406.88 736.393,1406.88 736.402,1406.88 736.412,1406.88 736.421,1406.88 736.43,1406.88 736.439,1406.88 736.448,1406.88 736.458,1406.88 736.467,1406.88 736.476,1406.88 736.485,1406.88 736.494,1406.88 736.503,1406.88 736.513,1406.88 736.522,1406.88 736.531,1406.88 736.54,1406.88 736.549,1406.88 736.559,1406.88 736.568,1406.88 736.577,1406.88 736.586,1406.88 736.595,1406.88 736.605,1406.88 736.614,1406.88 736.623,1406.88 736.632,1406.88 736.641,1406.88 736.651,1406.88 736.66,1406.88 736.669,1406.88 736.678,1406.88 736.687,1406.88 736.696,1406.88 736.706,1406.88 736.715,1406.88 736.724,1406.88 736.733,1406.88 736.742,1406.88 736.752,1406.88 736.761,1406.88 736.77,1406.88 736.779,1406.88 736.788,1406.88 736.798,1406.88 736.807,1406.88 736.816,1406.88 736.825,1406.88 736.834,1406.88 736.843,1406.88 736.853,1406.88 736.862,1406.88 736.871,1406.88 736.88,1406.88 736.889,1406.88 736.899,1406.88 736.908,1406.88 736.917,1406.88 736.926,1406.88 736.935,1406.88 736.945,1406.88 736.954,1406.88 736.963,1406.88 736.972,1406.88 736.981,1406.88 736.991,1406.88 737,1406.88 737.009,1406.88 737.018,1406.88 737.027,1406.88 737.036,1406.88 737.046,1406.88 737.055,1406.88 737.064,1406.88 737.073,1406.88 737.082,1406.88 737.092,1406.88 737.101,1406.88 737.11,1406.88 737.119,1406.88 737.128,1406.88 737.138,1406.88 737.147,1406.88 737.156,1406.88 737.165,1406.88 737.174,1406.88 737.183,1406.88 737.193,1406.88 737.202,1406.88 737.211,1406.88 737.22,1406.88 737.229,1406.88 737.239,1406.88 737.248,1406.88 737.257,1406.88 737.266,1406.88 737.275,1406.88 737.285,1406.88 737.294,1406.88 737.303,1406.88 737.312,1406.88 737.321,1406.88 737.331,1406.88 737.34,1406.88 737.349,1406.88 737.358,1406.88 737.367,1406.88 737.376,1406.88 737.386,1406.88 737.395,1406.88 737.404,1406.88 737.413,1406.88 737.422,1406.88 737.432,1406.88 737.441,1406.88 737.45,1406.88 737.459,1406.88 737.468,1406.88 737.478,1406.88 737.487,1406.88 737.496,1406.88 737.505,1406.88 737.514,1406.88 737.523,1406.88 737.533,1406.88 737.542,1406.88 737.551,1406.88 737.56,1406.88 737.569,1406.88 737.579,1406.88 737.588,1406.88 737.597,1406.88 737.606,1406.88 737.615,1406.88 737.625,1406.88 737.634,1406.88 737.643,1406.88 737.652,1406.88 737.661,1406.88 737.671,1406.88 737.68,1406.88 737.689,1406.88 737.698,1406.88 737.707,1406.88 737.716,1406.88 737.726,1406.88 737.735,1406.88 737.744,1406.88 737.753,1406.88 737.762,1406.88 737.772,1406.88 737.781,1406.88 737.79,1406.88 737.799,1406.88 737.808,1406.88 737.818,1406.88 737.827,1406.88 737.836,1406.88 737.845,1406.88 737.854,1406.88 737.863,1406.88 737.873,1406.88 737.882,1406.88 737.891,1406.88 737.9,1406.88 737.909,1406.88 737.919,1406.88 737.928,1406.88 737.937,1406.88 737.946,1406.88 737.955,1406.88 737.965,1406.88 737.974,1406.88 737.983,1406.88 737.992,1406.88 738.001,1406.88 738.011,1406.88 738.02,1406.88 738.029,1406.88 738.038,1406.88 738.047,1406.88 738.056,1406.88 738.066,1406.88 738.075,1406.88 738.084,1406.88 738.093,1406.88 738.102,1406.88 738.112,1406.88 738.121,1406.88 738.13,1406.88 738.139,1406.88 738.148,1406.88 738.158,1406.88 738.167,1406.88 738.176,1406.88 738.185,1406.88 738.194,1406.88 738.204,1406.88 738.213,1406.88 738.222,1406.88 738.231,1406.88 738.24,1406.88 738.249,1406.88 738.259,1406.88 738.268,1406.88 738.277,1406.88 738.286,1406.88 738.295,1406.88 738.305,1406.88 738.314,1406.88 738.323,1406.88 738.332,1406.88 738.341,1406.88 738.351,1406.88 738.36,1406.88 738.369,1406.88 738.378,1406.88 738.387,1406.88 738.396,1406.88 738.406,1406.88 738.415,1406.88 738.424,1406.88 738.433,1406.88 738.442,1406.88 738.452,1406.88 738.461,1406.88 738.47,1406.88 738.479,1406.88 738.488,1406.88 738.498,1406.88 738.507,1406.88 738.516,1406.88 738.525,1406.88 738.534,1406.88 738.544,1406.88 738.553,1406.88 738.562,1406.88 738.571,1406.88 738.58,1406.88 738.589,1406.88 738.599,1406.88 738.608,1406.88 738.617,1406.88 738.626,1406.88 738.635,1406.88 738.645,1406.88 738.654,1406.88 738.663,1406.88 738.672,1406.88 738.681,1406.88 738.691,1406.88 738.7,1406.88 738.709,1406.88 738.718,1406.88 738.727,1406.88 738.736,1406.88 738.746,1406.88 738.755,1406.88 738.764,1406.88 738.773,1406.88 738.782,1406.88 738.792,1406.88 738.801,1406.88 738.81,1406.88 738.819,1406.88 738.828,1406.88 738.838,1406.88 738.847,1406.88 738.856,1406.88 738.865,1406.88 738.874,1406.88 738.884,1406.88 738.893,1406.88 738.902,1406.88 738.911,1406.88 738.92,1406.88 738.929,1406.88 738.939,1406.88 738.948,1406.88 738.957,1406.88 738.966,1406.88 738.975,1406.88 738.985,1406.88 738.994,1406.88 739.003,1406.88 739.012,1406.88 739.021,1406.88 739.031,1406.88 739.04,1406.88 739.049,1406.88 739.058,1406.88 739.067,1406.88 739.076,1406.88 739.086,1406.88 739.095,1406.88 739.104,1406.88 739.113,1406.88 739.122,1406.88 739.132,1406.88 739.141,1406.88 739.15,1406.88 739.159,1406.88 739.168,1406.88 739.178,1406.88 739.187,1406.88 739.196,1406.88 739.205,1406.88 739.214,1406.88 739.224,1406.88 739.233,1406.88 739.242,1406.88 739.251,1406.88 739.26,1406.88 739.269,1406.88 739.279,1406.88 739.288,1406.88 739.297,1406.88 739.306,1406.88 739.315,1406.88 739.325,1406.88 739.334,1406.88 739.343,1406.88 739.352,1406.88 739.361,1406.88 739.371,1406.88 739.38,1406.88 739.389,1406.88 739.398,1406.88 739.407,1406.88 739.416,1406.88 739.426,1406.88 739.435,1406.88 739.444,1406.88 739.453,1406.88 739.462,1406.88 739.472,1406.88 739.481,1406.88 739.49,1406.88 739.499,1406.88 739.508,1406.88 739.518,1406.88 739.527,1406.88 739.536,1406.88 739.545,1406.88 739.554,1406.88 739.564,1406.88 739.573,1406.88 739.582,1406.88 739.591,1406.88 739.6,1406.88 739.609,1406.88 739.619,1406.88 739.628,1406.88 739.637,1406.88 739.646,1406.88 739.655,1406.88 739.665,1406.88 739.674,1406.88 739.683,1406.88 739.692,1406.88 739.701,1406.88 739.711,1406.88 739.72,1406.88 739.729,1406.88 739.738,1406.88 739.747,1406.88 739.756,1406.88 739.766,1406.88 739.775,1406.88 739.784,1406.88 739.793,1406.88 739.802,1406.88 739.812,1406.88 739.821,1406.88 739.83,1406.88 739.839,1406.88 739.848,1406.88 739.858,1406.88 739.867,1406.88 739.876,1406.88 739.885,1406.88 739.894,1406.88 739.904,1406.88 739.913,1406.88 739.922,1406.88 739.931,1406.88 739.94,1406.88 739.949,1406.88 739.959,1406.88 739.968,1406.88 739.977,1406.88 739.986,1406.88 739.995,1406.88 740.005,1406.88 740.014,1406.88 740.023,1406.88 740.032,1406.88 740.041,1406.88 740.051,1406.88 740.06,1406.88 740.069,1406.88 740.078,1406.88 740.087,1406.88 740.096,1406.88 740.106,1406.88 740.115,1406.88 740.124,1406.88 740.133,1406.88 740.142,1406.88 740.152,1406.88 740.161,1406.88 740.17,1406.88 740.179,1406.88 740.188,1406.88 740.198,1406.88 740.207,1406.88 740.216,1406.88 740.225,1406.88 740.234,1406.88 740.244,1406.88 740.253,1406.88 740.262,1406.88 740.271,1406.88 740.28,1406.88 740.289,1406.88 740.299,1406.88 740.308,1406.88 740.317,1406.88 740.326,1406.88 740.335,1406.88 740.345,1406.88 740.354,1406.88 740.363,1406.88 740.372,1406.88 740.381,1406.88 740.391,1406.88 740.4,1406.88 740.409,1406.88 740.418,1406.88 740.427,1406.88 740.436,1406.88 740.446,1406.88 740.455,1406.88 740.464,1406.88 740.473,1406.88 740.482,1406.88 740.492,1406.88 740.501,1406.88 740.51,1406.88 740.519,1406.88 740.528,1406.88 740.538,1406.88 740.547,1406.88 740.556,1406.88 740.565,1406.88 740.574,1406.88 740.584,1406.88 740.593,1406.88 740.602,1406.88 740.611,1406.88 740.62,1406.88 740.629,1406.88 740.639,1406.88 740.648,1406.88 740.657,1406.88 740.666,1406.88 740.675,1406.88 740.685,1406.88 740.694,1406.88 740.703,1406.88 740.712,1406.88 740.721,1406.88 740.731,1406.88 740.74,1406.88 740.749,1406.88 740.758,1406.88 740.767,1406.88 740.777,1406.88 740.786,1406.88 740.795,1406.88 740.804,1406.88 740.813,1406.88 740.822,1406.88 740.832,1406.88 740.841,1406.88 740.85,1406.88 740.859,1406.88 740.868,1406.88 740.878,1406.88 740.887,1406.88 740.896,1406.88 740.905,1406.88 740.914,1406.88 740.924,1406.88 740.933,1406.88 740.942,1406.88 740.951,1406.88 740.96,1406.88 740.969,1406.88 740.979,1406.88 740.988,1406.88 740.997,1406.88 741.006,1406.88 741.015,1406.88 741.025,1406.88 741.034,1406.88 741.043,1406.88 741.052,1406.88 741.061,1406.88 741.071,1406.88 741.08,1406.88 741.089,1406.88 741.098,1406.88 741.107,1406.88 741.117,1406.88 741.126,1406.88 741.135,1406.88 741.144,1406.88 741.153,1406.88 741.162,1406.88 741.172,1406.88 741.181,1406.88 741.19,1406.88 741.199,1406.88 741.208,1406.88 741.218,1406.88 741.227,1406.88 741.236,1406.88 741.245,1406.88 741.254,1406.88 741.264,1406.88 741.273,1406.88 741.282,1406.88 741.291,1406.88 741.3,1406.88 741.309,1406.88 741.319,1406.88 741.328,1406.88 741.337,1406.88 741.346,1406.88 741.355,1406.88 741.365,1406.88 741.374,1406.88 741.383,1406.88 741.392,1406.88 741.401,1406.88 741.411,1406.88 741.42,1406.88 741.429,1406.88 741.438,1406.88 741.447,1406.88 741.457,1406.88 741.466,1406.88 741.475,1406.88 741.484,1406.88 741.493,1406.88 741.502,1406.88 741.512,1406.88 741.521,1406.88 741.53,1406.88 741.539,1406.88 741.548,1406.88 741.558,1406.88 741.567,1406.88 741.576,1406.88 741.585,1406.88 741.594,1406.88 741.604,1406.88 741.613,1406.88 741.622,1406.88 741.631,1406.88 741.64,1406.88 741.649,1406.88 741.659,1406.88 741.668,1406.88 741.677,1406.88 741.686,1406.88 741.695,1406.88 741.705,1406.88 741.714,1406.88 741.723,1406.88 741.732,1406.88 741.741,1406.88 741.751,1406.88 741.76,1406.88 741.769,1406.88 741.778,1406.88 741.787,1406.88 741.797,1406.88 741.806,1406.88 741.815,1406.88 741.824,1406.88 741.833,1406.88 741.842,1406.88 741.852,1406.88 741.861,1406.88 741.87,1406.88 741.879,1406.88 741.888,1406.88 741.898,1406.88 741.907,1406.88 741.916,1406.88 741.925,1406.88 741.934,1406.88 741.944,1406.88 741.953,1406.88 741.962,1406.88 741.971,1406.88 741.98,1406.88 741.989,1406.88 741.999,1406.88 742.008,1406.88 742.017,1406.88 742.026,1406.88 742.035,1406.88 742.045,1406.88 742.054,1406.88 742.063,1406.88 742.072,1406.88 742.081,1406.88 742.091,1406.88 742.1,1406.88 742.109,1406.88 742.118,1406.88 742.127,1406.88 742.137,1406.88 742.146,1406.88 742.155,1406.88 742.164,1406.88 742.173,1406.88 742.182,1406.88 742.192,1406.88 742.201,1406.88 742.21,1406.88 742.219,1406.88 742.228,1406.88 742.238,1406.88 742.247,1406.88 742.256,1406.88 742.265,1406.88 742.274,1406.88 742.284,1406.88 742.293,1406.88 742.302,1406.88 742.311,1406.88 742.32,1406.88 742.329,1406.88 742.339,1406.88 742.348,1406.88 742.357,1406.88 742.366,1406.88 742.375,1406.88 742.385,1406.88 742.394,1406.88 742.403,1406.88 742.412,1406.88 742.421,1406.88 742.431,1406.88 742.44,1406.88 742.449,1406.88 742.458,1406.88 742.467,1406.88 742.477,1406.88 742.486,1406.88 742.495,1406.88 742.504,1406.88 742.513,1406.88 742.522,1406.88 742.532,1406.88 742.541,1406.88 742.55,1406.88 742.559,1406.88 742.568,1406.88 742.578,1406.88 742.587,1406.88 742.596,1406.88 742.605,1406.88 742.614,1406.88 742.624,1406.88 742.633,1406.88 742.642,1406.88 742.651,1406.88 742.66,1406.88 742.669,1406.88 742.679,1406.88 742.688,1406.88 742.697,1406.88 742.706,1406.88 742.715,1406.88 742.725,1406.88 742.734,1406.88 742.743,1406.88 742.752,1406.88 742.761,1406.88 742.771,1406.88 742.78,1406.88 742.789,1406.88 742.798,1406.88 742.807,1406.88 742.817,1406.88 742.826,1406.88 742.835,1406.88 742.844,1406.88 742.853,1406.88 742.862,1406.88 742.872,1406.88 742.881,1406.88 742.89,1406.88 742.899,1406.88 742.908,1406.88 742.918,1406.88 742.927,1406.88 742.936,1406.88 742.945,1406.88 742.954,1406.88 742.964,1406.88 742.973,1406.88 742.982,1406.88 742.991,1406.88 743,1406.88 743.009,1406.88 743.019,1406.88 743.028,1406.88 743.037,1406.88 743.046,1406.88 743.055,1406.88 743.065,1406.88 743.074,1406.88 743.083,1406.88 743.092,1406.88 743.101,1406.88 743.111,1406.88 743.12,1406.88 743.129,1406.88 743.138,1406.88 743.147,1406.88 743.157,1406.88 743.166,1406.88 743.175,1406.88 743.184,1406.88 743.193,1406.88 743.202,1406.88 743.212,1406.88 743.221,1406.88 743.23,1406.88 743.239,1406.88 743.248,1406.88 743.258,1406.88 743.267,1406.88 743.276,1406.88 743.285,1406.88 743.294,1406.88 743.304,1406.88 743.313,1406.88 743.322,1406.88 743.331,1406.88 743.34,1406.88 743.35,1406.88 743.359,1406.88 743.368,1406.88 743.377,1406.88 743.386,1406.88 743.395,1406.88 743.405,1406.88 743.414,1406.88 743.423,1406.88 743.432,1406.88 743.441,1406.88 743.451,1406.88 743.46,1406.88 743.469,1406.88 743.478,1406.88 743.487,1406.88 743.497,1406.88 743.506,1406.88 743.515,1406.88 743.524,1406.88 743.533,1406.88 743.542,1406.88 743.552,1406.88 743.561,1406.88 743.57,1406.88 743.579,1406.88 743.588,1406.88 743.598,1406.88 743.607,1406.88 743.616,1406.88 743.625,1406.88 743.634,1406.88 743.644,1406.88 743.653,1406.88 743.662,1406.88 743.671,1406.88 743.68,1406.88 743.69,1406.88 743.699,1406.88 743.708,1406.88 743.717,1406.88 743.726,1406.88 743.735,1406.88 743.745,1406.88 743.754,1406.88 743.763,1406.88 743.772,1406.88 743.781,1406.88 743.791,1406.88 743.8,1406.88 743.809,1406.88 743.818,1406.88 743.827,1406.88 743.837,1406.88 743.846,1406.88 743.855,1406.88 743.864,1406.88 743.873,1406.88 743.882,1406.88 743.892,1406.88 743.901,1406.88 743.91,1406.88 743.919,1406.88 743.928,1406.88 743.938,1406.88 743.947,1406.88 743.956,1406.88 743.965,1406.88 743.974,1406.88 743.984,1406.88 743.993,1406.88 744.002,1406.88 744.011,1406.88 744.02,1406.88 744.03,1406.88 744.039,1406.88 744.048,1406.88 744.057,1406.88 744.066,1406.88 744.075,1406.88 744.085,1406.88 744.094,1406.88 744.103,1406.88 744.112,1406.88 744.121,1406.88 744.131,1406.88 744.14,1406.88 744.149,1406.88 744.158,1406.88 744.167,1406.88 744.177,1406.88 744.186,1406.88 744.195,1406.88 744.204,1406.88 744.213,1406.88 744.222,1406.88 744.232,1406.88 744.241,1406.88 744.25,1406.88 744.259,1406.88 744.268,1406.88 744.278,1406.88 744.287,1406.88 744.296,1406.88 744.305,1406.88 744.314,1406.88 744.324,1406.88 744.333,1406.88 744.342,1406.88 744.351,1406.88 744.36,1406.88 744.37,1406.88 744.379,1406.88 744.388,1406.88 744.397,1406.88 744.406,1406.88 744.415,1406.88 744.425,1406.88 744.434,1406.88 744.443,1406.88 744.452,1406.88 744.461,1406.88 744.471,1406.88 744.48,1406.88 744.489,1406.88 744.498,1406.88 744.507,1406.88 744.517,1406.88 744.526,1406.88 744.535,1406.88 744.544,1406.88 744.553,1406.88 744.562,1406.88 744.572,1406.88 744.581,1406.88 744.59,1406.88 744.599,1406.88 744.608,1406.88 744.618,1406.88 744.627,1406.88 744.636,1406.88 744.645,1406.88 744.654,1406.88 744.664,1406.88 744.673,1406.88 744.682,1406.88 744.691,1406.88 744.7,1406.88 744.71,1406.88 744.719,1406.88 744.728,1406.88 744.737,1406.88 744.746,1406.88 744.755,1406.88 744.765,1406.88 744.774,1406.88 744.783,1406.88 744.792,1406.88 744.801,1406.88 744.811,1406.88 744.82,1406.88 744.829,1406.88 744.838,1406.88 744.847,1406.88 744.857,1406.88 744.866,1406.88 744.875,1406.88 744.884,1406.88 744.893,1406.88 744.902,1406.88 744.912,1406.88 744.921,1406.88 744.93,1406.88 744.939,1406.88 744.948,1406.88 744.958,1406.88 744.967,1406.88 744.976,1406.88 744.985,1406.88 744.994,1406.88 745.004,1406.88 745.013,1406.88 745.022,1406.88 745.031,1406.88 745.04,1406.88 745.05,1406.88 745.059,1406.88 745.068,1406.88 745.077,1406.88 745.086,1406.88 745.095,1406.88 745.105,1406.88 745.114,1406.88 745.123,1406.88 745.132,1406.88 745.141,1406.88 745.151,1406.88 745.16,1406.88 745.169,1406.88 745.178,1406.88 745.187,1406.88 745.197,1406.88 745.206,1406.88 745.215,1406.88 745.224,1406.88 745.233,1406.88 745.242,1406.88 745.252,1406.88 745.261,1406.88 745.27,1406.88 745.279,1406.88 745.288,1406.88 745.298,1406.88 745.307,1406.88 745.316,1406.88 745.325,1406.88 745.334,1406.88 745.344,1406.88 745.353,1406.88 745.362,1406.88 745.371,1406.88 745.38,1406.88 745.39,1406.88 745.399,1406.88 745.408,1406.88 745.417,1406.88 745.426,1406.88 745.435,1406.88 745.445,1406.88 745.454,1406.88 745.463,1406.88 745.472,1406.88 745.481,1406.88 745.491,1406.88 745.5,1406.88 745.509,1406.88 745.518,1406.88 745.527,1406.88 745.537,1406.88 745.546,1406.88 745.555,1406.88 745.564,1406.88 745.573,1406.88 745.583,1406.88 745.592,1406.88 745.601,1406.88 745.61,1406.88 745.619,1406.88 745.628,1406.88 745.638,1406.88 745.647,1406.88 745.656,1406.88 745.665,1406.88 745.674,1406.88 745.684,1406.88 745.693,1406.88 745.702,1406.88 745.711,1406.88 745.72,1406.88 745.73,1406.88 745.739,1406.88 745.748,1406.88 745.757,1406.88 745.766,1406.88 745.775,1406.88 745.785,1406.88 745.794,1406.88 745.803,1406.88 745.812,1406.88 745.821,1406.88 745.831,1406.88 745.84,1406.88 745.849,1406.88 745.858,1406.88 745.867,1406.88 745.877,1406.88 745.886,1406.88 745.895,1406.88 745.904,1406.88 745.913,1406.88 745.923,1406.88 745.932,1406.88 745.941,1406.88 745.95,1406.88 745.959,1406.88 745.968,1406.88 745.978,1406.88 745.987,1406.88 745.996,1406.88 746.005,1406.88 746.014,1406.88 746.024,1406.88 746.033,1406.88 746.042,1406.88 746.051,1406.88 746.06,1406.88 746.07,1406.88 746.079,1406.88 746.088,1406.88 746.097,1406.88 746.106,1406.88 746.115,1406.88 746.125,1406.88 746.134,1406.88 746.143,1406.88 746.152,1406.88 746.161,1406.88 746.171,1406.88 746.18,1406.88 746.189,1406.88 746.198,1406.88 746.207,1406.88 746.217,1406.88 746.226,1406.88 746.235,1406.88 746.244,1406.88 746.253,1406.88 746.263,1406.88 746.272,1406.88 746.281,1406.88 746.29,1406.88 746.299,1406.88 746.308,1406.88 746.318,1406.88 746.327,1406.88 746.336,1406.88 746.345,1406.88 746.354,1406.88 746.364,1406.88 746.373,1406.88 746.382,1406.88 746.391,1406.88 746.4,1406.88 746.41,1406.88 746.419,1406.88 746.428,1406.88 746.437,1406.88 746.446,1406.88 746.455,1406.88 746.465,1406.88 746.474,1406.88 746.483,1406.88 746.492,1406.88 746.501,1406.88 746.511,1406.88 746.52,1406.88 746.529,1406.88 746.538,1406.88 746.547,1406.88 746.557,1406.88 746.566,1406.88 746.575,1406.88 746.584,1406.88 746.593,1406.88 746.603,1406.88 746.612,1406.88 746.621,1406.88 746.63,1406.88 746.639,1406.88 746.648,1406.88 746.658,1406.88 746.667,1406.88 746.676,1406.88 746.685,1406.88 746.694,1406.88 746.704,1406.88 746.713,1406.88 746.722,1406.88 746.731,1406.88 746.74,1406.88 746.75,1406.88 746.759,1406.88 746.768,1406.88 746.777,1406.88 746.786,1406.88 746.795,1406.88 746.805,1406.88 746.814,1406.88 746.823,1406.88 746.832,1406.88 746.841,1406.88 746.851,1406.88 746.86,1406.88 746.869,1406.88 746.878,1406.88 746.887,1406.88 746.897,1406.88 746.906,1406.88 746.915,1406.88 746.924,1406.88 746.933,1406.88 746.943,1406.88 746.952,1406.88 746.961,1406.88 746.97,1406.88 746.979,1406.88 746.988,1406.88 746.998,1406.88 747.007,1406.88 747.016,1406.88 747.025,1406.88 747.034,1406.88 747.044,1406.88 747.053,1406.88 747.062,1406.88 747.071,1406.88 747.08,1406.88 747.09,1406.88 747.099,1406.88 747.108,1406.88 747.117,1406.88 747.126,1406.88 747.135,1406.88 747.145,1406.88 747.154,1406.88 747.163,1406.88 747.172,1406.88 747.181,1406.88 747.191,1406.88 747.2,1406.88 747.209,1406.88 747.218,1406.88 747.227,1406.88 747.237,1406.88 747.246,1406.88 747.255,1406.88 747.264,1406.88 747.273,1406.88 747.283,1406.88 747.292,1406.88 747.301,1406.88 747.31,1406.88 747.319,1406.88 747.328,1406.88 747.338,1406.88 747.347,1406.88 747.356,1406.88 747.365,1406.88 747.374,1406.88 747.384,1406.88 747.393,1406.88 747.402,1406.88 747.411,1406.88 747.42,1406.88 747.43,1406.88 747.439,1406.88 747.448,1406.88 747.457,1406.88 747.466,1406.88 747.475,1406.88 747.485,1406.88 747.494,1406.88 747.503,1406.88 747.512,1406.88 747.521,1406.88 747.531,1406.88 747.54,1406.88 747.549,1406.88 747.558,1406.88 747.567,1406.88 747.577,1406.88 747.586,1406.88 747.595,1406.88 747.604,1406.88 747.613,1406.88 747.623,1406.88 747.632,1406.88 747.641,1406.88 747.65,1406.88 747.659,1406.88 747.668,1406.88 747.678,1406.88 747.687,1406.88 747.696,1406.88 747.705,1406.88 747.714,1406.88 747.724,1406.88 747.733,1406.88 747.742,1406.88 747.751,1406.88 747.76,1406.88 747.77,1406.88 747.779,1406.88 747.788,1406.88 747.797,1406.88 747.806,1406.88 747.815,1406.88 747.825,1406.88 747.834,1406.88 747.843,1406.88 747.852,1406.88 747.861,1406.88 747.871,1406.88 747.88,1406.88 747.889,1406.88 747.898,1406.88 747.907,1406.88 747.917,1406.88 747.926,1406.88 747.935,1406.88 747.944,1406.88 747.953,1406.88 747.963,1406.88 747.972,1406.88 747.981,1406.88 747.99,1406.88 747.999,1406.88 748.008,1406.88 748.018,1406.88 748.027,1406.88 748.036,1406.88 748.045,1406.88 748.054,1406.88 748.064,1406.88 748.073,1406.88 748.082,1406.88 748.091,1406.88 748.1,1406.88 748.11,1406.88 748.119,1406.88 748.128,1406.88 748.137,1406.88 748.146,1406.88 748.156,1406.88 748.165,1406.88 748.174,1406.88 748.183,1406.88 748.192,1406.88 748.201,1406.88 748.211,1406.88 748.22,1406.88 748.229,1406.88 748.238,1406.88 748.247,1406.88 748.257,1406.88 748.266,1406.88 748.275,1406.88 748.284,1406.88 748.293,1406.88 748.303,1406.88 748.312,1406.88 748.321,1406.88 748.33,1406.88 748.339,1406.88 748.348,1406.88 748.358,1406.88 748.367,1406.88 748.376,1406.88 748.385,1406.88 748.394,1406.88 748.404,1406.88 748.413,1406.88 748.422,1406.88 748.431,1406.88 748.44,1406.88 748.45,1406.88 748.459,1406.88 748.468,1406.88 748.477,1406.88 748.486,1406.88 748.496,1406.88 748.505,1406.88 748.514,1406.88 748.523,1406.88 748.532,1406.88 748.541,1406.88 748.551,1406.88 748.56,1406.88 748.569,1406.88 748.578,1406.88 748.587,1406.88 748.597,1406.88 748.606,1406.88 748.615,1406.88 748.624,1406.88 748.633,1406.88 748.643,1406.88 748.652,1406.88 748.661,1406.88 748.67,1406.88 748.679,1406.88 748.688,1406.88 748.698,1406.88 748.707,1406.88 748.716,1406.88 748.725,1406.88 748.734,1406.88 748.744,1406.88 748.753,1406.88 748.762,1406.88 748.771,1406.88 748.78,1406.88 748.79,1406.88 748.799,1406.88 748.808,1406.88 748.817,1406.88 748.826,1406.88 748.836,1406.88 748.845,1406.88 748.854,1406.88 748.863,1406.88 748.872,1406.88 748.881,1406.88 748.891,1406.88 748.9,1406.88 748.909,1406.88 748.918,1406.88 748.927,1406.88 748.937,1406.88 748.946,1406.88 748.955,1406.88 748.964,1406.88 748.973,1406.88 748.983,1406.88 748.992,1406.88 749.001,1406.88 749.01,1406.88 749.019,1406.88 749.028,1406.88 749.038,1406.88 749.047,1406.88 749.056,1406.88 749.065,1406.88 749.074,1406.88 749.084,1406.88 749.093,1406.88 749.102,1406.88 749.111,1406.88 749.12,1406.88 749.13,1406.88 749.139,1406.88 749.148,1406.88 749.157,1406.88 749.166,1406.88 749.176,1406.88 749.185,1406.88 749.194,1406.88 749.203,1406.88 749.212,1406.88 749.221,1406.88 749.231,1406.88 749.24,1406.88 749.249,1406.88 749.258,1406.88 749.267,1406.88 749.277,1406.88 749.286,1406.88 749.295,1406.88 749.304,1406.88 749.313,1406.88 749.323,1406.88 749.332,1406.88 749.341,1406.88 749.35,1406.88 749.359,1406.88 749.368,1406.88 749.378,1406.88 749.387,1406.88 749.396,1406.88 749.405,1406.88 749.414,1406.88 749.424,1406.88 749.433,1406.88 749.442,1406.88 749.451,1406.88 749.46,1406.88 749.47,1406.88 749.479,1406.88 749.488,1406.88 749.497,1406.88 749.506,1406.88 749.516,1406.88 749.525,1406.88 749.534,1406.88 749.543,1406.88 749.552,1406.88 749.561,1406.88 749.571,1406.88 749.58,1406.88 749.589,1406.88 749.598,1406.88 749.607,1406.88 749.617,1406.88 749.626,1406.88 749.635,1406.88 749.644,1406.88 749.653,1406.88 749.663,1406.88 749.672,1406.88 749.681,1406.88 749.69,1406.88 749.699,1406.88 749.708,1406.88 749.718,1406.88 749.727,1406.88 749.736,1406.88 749.745,1406.88 749.754,1406.88 749.764,1406.88 749.773,1406.88 749.782,1406.88 749.791,1406.88 749.8,1406.88 749.81,1406.88 749.819,1406.88 749.828,1406.88 749.837,1406.88 749.846,1406.88 749.856,1406.88 749.865,1406.88 749.874,1406.88 749.883,1406.88 749.892,1406.88 749.901,1406.88 749.911,1406.88 749.92,1406.88 749.929,1406.88 749.938,1406.88 749.947,1406.88 749.957,1406.88 749.966,1406.88 749.975,1406.88 749.984,1406.88 749.993,1406.88 750.003,1406.88 750.012,1406.88 750.021,1406.88 750.03,1406.88 750.039,1406.88 750.048,1406.88 750.058,1406.88 750.067,1406.88 750.076,1406.88 750.085,1406.88 750.094,1406.88 750.104,1406.88 750.113,1406.88 750.122,1406.88 750.131,1406.88 750.14,1406.88 750.15,1406.88 750.159,1406.88 750.168,1406.88 750.177,1406.88 750.186,1406.88 750.196,1406.88 750.205,1406.88 750.214,1406.88 750.223,1406.88 750.232,1406.88 750.241,1406.88 750.251,1406.88 750.26,1406.88 750.269,1406.88 750.278,1406.88 750.287,1406.88 750.297,1406.88 750.306,1406.88 750.315,1406.88 750.324,1406.88 750.333,1406.88 750.343,1406.88 750.352,1406.88 750.361,1406.88 750.37,1406.88 750.379,1406.88 750.388,1406.88 750.398,1406.88 750.407,1406.88 750.416,1406.88 750.425,1406.88 750.434,1406.88 750.444,1406.88 750.453,1406.88 750.462,1406.88 750.471,1406.88 750.48,1406.88 750.49,1406.88 750.499,1406.88 750.508,1406.88 750.517,1406.88 750.526,1406.88 750.536,1406.88 750.545,1406.88 750.554,1406.88 750.563,1406.88 750.572,1406.88 750.581,1406.88 750.591,1406.88 750.6,1406.88 750.609,1406.88 750.618,1406.88 750.627,1406.88 750.637,1406.88 750.646,1406.88 750.655,1406.88 750.664,1406.88 750.673,1406.88 750.683,1406.88 750.692,1406.88 750.701,1406.88 750.71,1406.88 750.719,1406.88 750.729,1406.88 750.738,1406.88 750.747,1406.88 750.756,1406.88 750.765,1406.88 750.774,1406.88 750.784,1406.88 750.793,1406.88 750.802,1406.88 750.811,1406.88 750.82,1406.88 750.83,1406.88 750.839,1406.88 750.848,1406.88 750.857,1406.88 750.866,1406.88 750.876,1406.88 750.885,1406.88 750.894,1406.88 750.903,1406.88 750.912,1406.88 750.921,1406.88 750.931,1406.88 750.94,1406.88 750.949,1406.88 750.958,1406.88 750.967,1406.88 750.977,1406.88 750.986,1406.88 750.995,1406.88 751.004,1406.88 751.013,1406.88 751.023,1406.88 751.032,1406.88 751.041,1406.88 751.05,1406.88 751.059,1406.88 751.069,1406.88 751.078,1406.88 751.087,1406.88 751.096,1406.88 751.105,1406.88 751.114,1406.88 751.124,1406.88 751.133,1406.88 751.142,1406.88 751.151,1406.88 751.16,1406.88 751.17,1406.88 751.179,1406.88 751.188,1406.88 751.197,1406.88 751.206,1406.88 751.216,1406.88 751.225,1406.88 751.234,1406.88 751.243,1406.88 751.252,1406.88 751.261,1406.88 751.271,1406.88 751.28,1406.88 751.289,1406.88 751.298,1406.88 751.307,1406.88 751.317,1406.88 751.326,1406.88 751.335,1406.88 751.344,1406.88 751.353,1406.88 751.363,1406.88 751.372,1406.88 751.381,1406.88 751.39,1406.88 751.399,1406.88 751.409,1406.88 751.418,1406.88 751.427,1406.88 751.436,1406.88 751.445,1406.88 751.454,1406.88 751.464,1406.88 751.473,1406.88 751.482,1406.88 751.491,1406.88 751.5,1406.88 751.51,1406.88 751.519,1406.88 751.528,1406.88 751.537,1406.88 751.546,1406.88 751.556,1406.88 751.565,1406.88 751.574,1406.88 751.583,1406.88 751.592,1406.88 751.601,1406.88 751.611,1406.88 751.62,1406.88 751.629,1406.88 751.638,1406.88 751.647,1406.88 751.657,1406.88 751.666,1406.88 751.675,1406.88 751.684,1406.88 751.693,1406.88 751.703,1406.88 751.712,1406.88 751.721,1406.88 751.73,1406.88 751.739,1406.88 751.749,1406.88 751.758,1406.88 751.767,1406.88 751.776,1406.88 751.785,1406.88 751.794,1406.88 751.804,1406.88 751.813,1406.88 751.822,1406.88 751.831,1406.88 751.84,1406.88 751.85,1406.88 751.859,1406.88 751.868,1406.88 751.877,1406.88 751.886,1406.88 751.896,1406.88 751.905,1406.88 751.914,1406.88 751.923,1406.88 751.932,1406.88 751.941,1406.88 751.951,1406.88 751.96,1406.88 751.969,1406.88 751.978,1406.88 751.987,1406.88 751.997,1406.88 752.006,1406.88 752.015,1406.88 752.024,1406.88 752.033,1406.88 752.043,1406.88 752.052,1406.88 752.061,1406.88 752.07,1406.88 752.079,1406.88 752.089,1406.88 752.098,1406.88 752.107,1406.88 752.116,1406.88 752.125,1406.88 752.134,1406.88 752.144,1406.88 752.153,1406.88 752.162,1406.88 752.171,1406.88 752.18,1406.88 752.19,1406.88 752.199,1406.88 752.208,1406.88 752.217,1406.88 752.226,1406.88 752.236,1406.88 752.245,1406.88 752.254,1406.88 752.263,1406.88 752.272,1406.88 752.281,1406.88 752.291,1406.88 752.3,1406.88 752.309,1406.88 752.318,1406.88 752.327,1406.88 752.337,1406.88 752.346,1406.88 752.355,1406.88 752.364,1406.88 752.373,1406.88 752.383,1406.88 752.392,1406.88 752.401,1406.88 752.41,1406.88 752.419,1406.88 752.429,1406.88 752.438,1406.88 752.447,1406.88 752.456,1406.88 752.465,1406.88 752.474,1406.88 752.484,1406.88 752.493,1406.88 752.502,1406.88 752.511,1406.88 752.52,1406.88 752.53,1406.88 752.539,1406.88 752.548,1406.88 752.557,1406.88 752.566,1406.88 752.576,1406.88 752.585,1406.88 752.594,1406.88 752.603,1406.88 752.612,1406.88 752.621,1406.88 752.631,1406.88 752.64,1406.88 752.649,1406.88 752.658,1406.88 752.667,1406.88 752.677,1406.88 752.686,1406.88 752.695,1406.88 752.704,1406.88 752.713,1406.88 752.723,1406.88 752.732,1406.88 752.741,1406.88 752.75,1406.88 752.759,1406.88 752.769,1406.88 752.778,1406.88 752.787,1406.88 752.796,1406.88 752.805,1406.88 752.814,1406.88 752.824,1406.88 752.833,1406.88 752.842,1406.88 752.851,1406.88 752.86,1406.88 752.87,1406.88 752.879,1406.88 752.888,1406.88 752.897,1406.88 752.906,1406.88 752.916,1406.88 752.925,1406.88 752.934,1406.88 752.943,1406.88 752.952,1406.88 752.962,1406.88 752.971,1406.88 752.98,1406.88 752.989,1406.88 752.998,1406.88 753.007,1406.88 753.017,1406.88 753.026,1406.88 753.035,1406.88 753.044,1406.88 753.053,1406.88 753.063,1406.88 753.072,1406.88 753.081,1406.88 753.09,1406.88 753.099,1406.88 753.109,1406.88 753.118,1406.88 753.127,1406.88 753.136,1406.88 753.145,1406.88 753.154,1406.88 753.164,1406.88 753.173,1406.88 753.182,1406.88 753.191,1406.88 753.2,1406.88 753.21,1406.88 753.219,1406.88 753.228,1406.88 753.237,1406.88 753.246,1406.88 753.256,1406.88 753.265,1406.88 753.274,1406.88 753.283,1406.88 753.292,1406.88 753.302,1406.88 753.311,1406.88 753.32,1406.88 753.329,1406.88 753.338,1406.88 753.347,1406.88 753.357,1406.88 753.366,1406.88 753.375,1406.88 753.384,1406.88 753.393,1406.88 753.403,1406.88 753.412,1406.88 753.421,1406.88 753.43,1406.88 753.439,1406.88 753.449,1406.88 753.458,1406.88 753.467,1406.88 753.476,1406.88 753.485,1406.88 753.494,1406.88 753.504,1406.88 753.513,1406.88 753.522,1406.88 753.531,1406.88 753.54,1406.88 753.55,1406.88 753.559,1406.88 753.568,1406.88 753.577,1406.88 753.586,1406.88 753.596,1406.88 753.605,1406.88 753.614,1406.88 753.623,1406.88 753.632,1406.88 753.642,1406.88 753.651,1406.88 753.66,1406.88 753.669,1406.88 753.678,1406.88 753.687,1406.88 753.697,1406.88 753.706,1406.88 753.715,1406.88 753.724,1406.88 753.733,1406.88 753.743,1406.88 753.752,1406.88 753.761,1406.88 753.77,1406.88 753.779,1406.88 753.789,1406.88 753.798,1406.88 753.807,1406.88 753.816,1406.88 753.825,1406.88 753.834,1406.88 753.844,1406.88 753.853,1406.88 753.862,1406.88 753.871,1406.88 753.88,1406.88 753.89,1406.88 753.899,1406.88 753.908,1406.88 753.917,1406.88 753.926,1406.88 753.936,1406.88 753.945,1406.88 753.954,1406.88 753.963,1406.88 753.972,1406.88 753.982,1406.88 753.991,1406.88 754,1406.88 754.009,1406.88 754.018,1406.88 754.027,1406.88 754.037,1406.88 754.046,1406.88 754.055,1406.88 754.064,1406.88 754.073,1406.88 754.083,1406.88 754.092,1406.88 754.101,1406.88 754.11,1406.88 754.119,1406.88 754.129,1406.88 754.138,1406.88 754.147,1406.88 754.156,1406.88 754.165,1406.88 754.174,1406.88 754.184,1406.88 754.193,1406.88 754.202,1406.88 754.211,1406.88 754.22,1406.88 754.23,1406.88 754.239,1406.88 754.248,1406.88 754.257,1406.88 754.266,1406.88 754.276,1406.88 754.285,1406.88 754.294,1406.88 754.303,1406.88 754.312,1406.88 754.322,1406.88 754.331,1406.88 754.34,1406.88 754.349,1406.88 754.358,1406.88 754.367,1406.88 754.377,1406.88 754.386,1406.88 754.395,1406.88 754.404,1406.88 754.413,1406.88 754.423,1406.88 754.432,1406.88 754.441,1406.88 754.45,1406.88 754.459,1406.88 754.469,1406.88 754.478,1406.88 754.487,1406.88 754.496,1406.88 754.505,1406.88 754.514,1406.88 754.524,1406.88 754.533,1406.88 754.542,1406.88 754.551,1406.88 754.56,1406.88 754.57,1406.88 754.579,1406.88 754.588,1406.88 754.597,1406.88 754.606,1406.88 754.616,1406.88 754.625,1406.88 754.634,1406.88 754.643,1406.88 754.652,1406.88 754.662,1406.88 754.671,1406.88 754.68,1406.88 754.689,1406.88 754.698,1406.88 754.707,1406.88 754.717,1406.88 754.726,1406.88 754.735,1406.88 754.744,1406.88 754.753,1406.88 754.763,1406.88 754.772,1406.88 754.781,1406.88 754.79,1406.88 754.799,1406.88 754.809,1406.88 754.818,1406.88 754.827,1406.88 754.836,1406.88 754.845,1406.88 754.854,1406.88 754.864,1406.88 754.873,1406.88 754.882,1406.88 754.891,1406.88 754.9,1406.88 754.91,1406.88 754.919,1406.88 754.928,1406.88 754.937,1406.88 754.946,1406.88 754.956,1406.88 754.965,1406.88 754.974,1406.88 754.983,1406.88 754.992,1406.88 755.002,1406.88 755.011,1406.88 755.02,1406.88 755.029,1406.88 755.038,1406.88 755.047,1406.88 755.057,1406.88 755.066,1406.88 755.075,1406.88 755.084,1406.88 755.093,1406.88 755.103,1406.88 755.112,1406.88 755.121,1406.88 755.13,1406.88 755.139,1406.88 755.149,1406.88 755.158,1406.88 755.167,1406.88 755.176,1406.88 755.185,1406.88 755.194,1406.88 755.204,1406.88 755.213,1406.88 755.222,1406.88 755.231,1406.88 755.24,1406.88 755.25,1406.88 755.259,1406.88 755.268,1406.88 755.277,1406.88 755.286,1406.88 755.296,1406.88 755.305,1406.88 755.314,1406.88 755.323,1406.88 755.332,1406.88 755.342,1406.88 755.351,1406.88 755.36,1406.88 755.369,1406.88 755.378,1406.88 755.387,1406.88 755.397,1406.88 755.406,1406.88 755.415,1406.88 755.424,1406.88 755.433,1406.88 755.443,1406.88 755.452,1406.88 755.461,1406.88 755.47,1406.88 755.479,1406.88 755.489,1406.88 755.498,1406.88 755.507,1406.88 755.516,1406.88 755.525,1406.88 755.535,1406.88 755.544,1406.88 755.553,1406.88 755.562,1406.88 755.571,1406.88 755.58,1406.88 755.59,1406.88 755.599,1406.88 755.608,1406.88 755.617,1406.88 755.626,1406.88 755.636,1406.88 755.645,1406.88 755.654,1406.88 755.663,1406.88 755.672,1406.88 755.682,1406.88 755.691,1406.88 755.7,1406.88 755.709,1406.88 755.718,1406.88 755.727,1406.88 755.737,1406.88 755.746,1406.88 755.755,1406.88 755.764,1406.88 755.773,1406.88 755.783,1406.88 755.792,1406.88 755.801,1406.88 755.81,1406.88 755.819,1406.88 755.829,1406.88 755.838,1406.88 755.847,1406.88 755.856,1406.88 755.865,1406.88 755.875,1406.88 755.884,1406.88 755.893,1406.88 755.902,1406.88 755.911,1406.88 755.92,1406.88 755.93,1406.88 755.939,1406.88 755.948,1406.88 755.957,1406.88 755.966,1406.88 755.976,1406.88 755.985,1406.88 755.994,1406.88 756.003,1406.88 756.012,1406.88 756.022,1406.88 756.031,1406.88 756.04,1406.88 756.049,1406.88 756.058,1406.88 756.067,1406.88 756.077,1406.88 756.086,1406.88 756.095,1406.88 756.104,1406.88 756.113,1406.88 756.123,1406.88 756.132,1406.88 756.141,1406.88 756.15,1406.88 756.159,1406.88 756.169,1406.88 756.178,1406.88 756.187,1406.88 756.196,1406.88 756.205,1406.88 756.215,1406.88 756.224,1406.88 756.233,1406.88 756.242,1406.88 756.251,1406.88 756.26,1406.88 756.27,1406.88 756.279,1406.88 756.288,1406.88 756.297,1406.88 756.306,1406.88 756.316,1406.88 756.325,1406.88 756.334,1406.88 756.343,1406.88 756.352,1406.88 756.362,1406.88 756.371,1406.88 756.38,1406.88 756.389,1406.88 756.398,1406.88 756.407,1406.88 756.417,1406.88 756.426,1406.88 756.435,1406.88 756.444,1406.88 756.453,1406.88 756.463,1406.88 756.472,1406.88 756.481,1406.88 756.49,1406.88 756.499,1406.88 756.509,1406.88 756.518,1406.88 756.527,1406.88 756.536,1406.88 756.545,1406.88 756.555,1406.88 756.564,1406.88 756.573,1406.88 756.582,1406.88 756.591,1406.88 756.6,1406.88 756.61,1406.88 756.619,1406.88 756.628,1406.88 756.637,1406.88 756.646,1406.88 756.656,1406.88 756.665,1406.88 756.674,1406.88 756.683,1406.88 756.692,1406.88 756.702,1406.88 756.711,1406.88 756.72,1406.88 756.729,1406.88 756.738,1406.88 756.747,1406.88 756.757,1406.88 756.766,1406.88 756.775,1406.88 756.784,1406.88 756.793,1406.88 756.803,1406.88 756.812,1406.88 756.821,1406.88 756.83,1406.88 756.839,1406.88 756.849,1406.88 756.858,1406.88 756.867,1406.88 756.876,1406.88 756.885,1406.88 756.895,1406.88 756.904,1406.88 756.913,1406.88 756.922,1406.88 756.931,1406.88 756.94,1406.88 756.95,1406.88 756.959,1406.88 756.968,1406.88 756.977,1406.88 756.986,1406.88 756.996,1406.88 757.005,1406.88 757.014,1406.88 757.023,1406.88 757.032,1406.88 757.042,1406.88 757.051,1406.88 757.06,1406.88 757.069,1406.88 757.078,1406.88 757.087,1406.88 757.097,1406.88 757.106,1406.88 757.115,1406.88 757.124,1406.88 757.133,1406.88 757.143,1406.88 757.152,1406.88 757.161,1406.88 757.17,1406.88 757.179,1406.88 757.189,1406.88 757.198,1406.88 757.207,1406.88 757.216,1406.88 757.225,1406.88 757.235,1406.88 757.244,1406.88 757.253,1406.88 757.262,1406.88 757.271,1406.88 757.28,1406.88 757.29,1406.88 757.299,1406.88 757.308,1406.88 757.317,1406.88 757.326,1406.88 757.336,1406.88 757.345,1406.88 757.354,1406.88 757.363,1406.88 757.372,1406.88 757.382,1406.88 757.391,1406.88 757.4,1406.88 757.409,1406.88 757.418,1406.88 757.427,1406.88 757.437,1406.88 757.446,1406.88 757.455,1406.88 757.464,1406.88 757.473,1406.88 757.483,1406.88 757.492,1406.88 757.501,1406.88 757.51,1406.88 757.519,1406.88 757.529,1406.88 757.538,1406.88 757.547,1406.88 757.556,1406.88 757.565,1406.88 757.575,1406.88 757.584,1406.88 757.593,1406.88 757.602,1406.88 757.611,1406.88 757.62,1406.88 757.63,1406.88 757.639,1406.88 757.648,1406.88 757.657,1406.88 757.666,1406.88 757.676,1406.88 757.685,1406.88 757.694,1406.88 757.703,1406.88 757.712,1406.88 757.722,1406.88 757.731,1406.88 757.74,1406.88 757.749,1406.88 757.758,1406.88 757.767,1406.88 757.777,1406.88 757.786,1406.88 757.795,1406.88 757.804,1406.88 757.813,1406.88 757.823,1406.88 757.832,1406.88 757.841,1406.88 757.85,1406.88 757.859,1406.88 757.869,1406.88 757.878,1406.88 757.887,1406.88 757.896,1406.88 757.905,1406.88 757.915,1406.88 757.924,1406.88 757.933,1406.88 757.942,1406.88 757.951,1406.88 757.96,1406.88 757.97,1406.88 757.979,1406.88 757.988,1406.88 757.997,1406.88 758.006,1406.88 758.016,1406.88 758.025,1406.88 758.034,1406.88 758.043,1406.88 758.052,1406.88 758.062,1406.88 758.071,1406.88 758.08,1406.88 758.089,1406.88 758.098,1406.88 758.108,1406.88 758.117,1406.88 758.126,1406.88 758.135,1406.88 758.144,1406.88 758.153,1406.88 758.163,1406.88 758.172,1406.88 758.181,1406.88 758.19,1406.88 758.199,1406.88 758.209,1406.88 758.218,1406.88 758.227,1406.88 758.236,1406.88 758.245,1406.88 758.255,1406.88 758.264,1406.88 758.273,1406.88 758.282,1406.88 758.291,1406.88 758.3,1406.88 758.31,1406.88 758.319,1406.88 758.328,1406.88 758.337,1406.88 758.346,1406.88 758.356,1406.88 758.365,1406.88 758.374,1406.88 758.383,1406.88 758.392,1406.88 758.402,1406.88 758.411,1406.88 758.42,1406.88 758.429,1406.88 758.438,1406.88 758.448,1406.88 758.457,1406.88 758.466,1406.88 758.475,1406.88 758.484,1406.88 758.493,1406.88 758.503,1406.88 758.512,1406.88 758.521,1406.88 758.53,1406.88 758.539,1406.88 758.549,1406.88 758.558,1406.88 758.567,1406.88 758.576,1406.88 758.585,1406.88 758.595,1406.88 758.604,1406.88 758.613,1406.88 758.622,1406.88 758.631,1406.88 758.64,1406.88 758.65,1406.88 758.659,1406.88 758.668,1406.88 758.677,1406.88 758.686,1406.88 758.696,1406.88 758.705,1406.88 758.714,1406.88 758.723,1406.88 758.732,1406.88 758.742,1406.88 758.751,1406.88 758.76,1406.88 758.769,1406.88 758.778,1406.88 758.788,1406.88 758.797,1406.88 758.806,1406.88 758.815,1406.88 758.824,1406.88 758.833,1406.88 758.843,1406.88 758.852,1406.88 758.861,1406.88 758.87,1406.88 758.879,1406.88 758.889,1406.88 758.898,1406.88 758.907,1406.88 758.916,1406.88 758.925,1406.88 758.935,1406.88 758.944,1406.88 758.953,1406.88 758.962,1406.88 758.971,1406.88 758.98,1406.88 758.99,1406.88 758.999,1406.88 759.008,1406.88 759.017,1406.88 759.026,1406.88 759.036,1406.88 759.045,1406.88 759.054,1406.88 759.063,1406.88 759.072,1406.88 759.082,1406.88 759.091,1406.88 759.1,1406.88 759.109,1406.88 759.118,1406.88 759.128,1406.88 759.137,1406.88 759.146,1406.88 759.155,1406.88 759.164,1406.88 759.173,1406.88 759.183,1406.88 759.192,1406.88 759.201,1406.88 759.21,1406.88 759.219,1406.88 759.229,1406.88 759.238,1406.88 759.247,1406.88 759.256,1406.88 759.265,1406.88 759.275,1406.88 759.284,1406.88 759.293,1406.88 759.302,1406.88 759.311,1406.88 759.32,1406.88 759.33,1406.88 759.339,1406.88 759.348,1406.88 759.357,1406.88 759.366,1406.88 759.376,1406.88 759.385,1406.88 759.394,1406.88 759.403,1406.88 759.412,1406.88 759.422,1406.88 759.431,1406.88 759.44,1406.88 759.449,1406.88 759.458,1406.88 759.468,1406.88 759.477,1406.88 759.486,1406.88 759.495,1406.88 759.504,1406.88 759.513,1406.88 759.523,1406.88 759.532,1406.88 759.541,1406.88 759.55,1406.88 759.559,1406.88 759.569,1406.88 759.578,1406.88 759.587,1406.88 759.596,1406.88 759.605,1406.88 759.615,1406.88 759.624,1406.88 759.633,1406.88 759.642,1406.88 759.651,1406.88 759.66,1406.88 759.67,1406.88 759.679,1406.88 759.688,1406.88 759.697,1406.88 759.706,1406.88 759.716,1406.88 759.725,1406.88 759.734,1406.88 759.743,1406.88 759.752,1406.88 759.762,1406.88 759.771,1406.88 759.78,1406.88 759.789,1406.88 759.798,1406.88 759.808,1406.88 759.817,1406.88 759.826,1406.88 759.835,1406.88 759.844,1406.88 759.853,1406.88 759.863,1406.88 759.872,1406.88 759.881,1406.88 759.89,1406.88 759.899,1406.88 759.909,1406.88 759.918,1406.88 759.927,1406.88 759.936,1406.88 759.945,1406.88 759.955,1406.88 759.964,1406.88 759.973,1406.88 759.982,1406.88 759.991,1406.88 760,1406.88 760.01,1406.88 760.019,1406.88 760.028,1406.88 760.037,1406.88 760.046,1406.88 760.056,1406.88 760.065,1406.88 760.074,1406.88 760.083,1406.88 760.092,1406.88 760.102,1406.88 760.111,1406.88 760.12,1406.88 760.129,1406.88 760.138,1406.88 760.148,1406.88 760.157,1406.88 760.166,1406.88 760.175,1406.88 760.184,1406.88 760.193,1406.88 760.203,1406.88 760.212,1406.88 760.221,1406.88 760.23,1406.88 760.239,1406.88 760.249,1406.88 760.258,1406.88 760.267,1406.88 760.276,1406.88 760.285,1406.88 760.295,1406.88 760.304,1406.88 760.313,1406.88 760.322,1406.88 760.331,1406.88 760.34,1406.88 760.35,1406.88 760.359,1406.88 760.368,1406.88 760.377,1406.88 760.386,1406.88 760.396,1406.88 760.405,1406.88 760.414,1406.88 760.423,1406.88 760.432,1406.88 760.442,1406.88 760.451,1406.88 760.46,1406.88 760.469,1406.88 760.478,1406.88 760.488,1406.88 760.497,1406.88 760.506,1406.88 760.515,1406.88 760.524,1406.88 760.533,1406.88 760.543,1406.88 760.552,1406.88 760.561,1406.88 760.57,1406.88 760.579,1406.88 760.589,1406.88 760.598,1406.88 760.607,1406.88 760.616,1406.88 760.625,1406.88 760.635,1406.88 760.644,1406.88 760.653,1406.88 760.662,1406.88 760.671,1406.88 760.681,1406.88 760.69,1406.88 760.699,1406.88 760.708,1406.88 760.717,1406.88 760.726,1406.88 760.736,1406.88 760.745,1406.88 760.754,1406.88 760.763,1406.88 760.772,1406.88 760.782,1406.88 760.791,1406.88 760.8,1406.88 760.809,1406.88 760.818,1406.88 760.828,1406.88 760.837,1406.88 760.846,1406.88 760.855,1406.88 760.864,1406.88 760.873,1406.88 760.883,1406.88 760.892,1406.88 760.901,1406.88 760.91,1406.88 760.919,1406.88 760.929,1406.88 760.938,1406.88 760.947,1406.88 760.956,1406.88 760.965,1406.88 760.975,1406.88 760.984,1406.88 760.993,1406.88 761.002,1406.88 761.011,1406.88 761.021,1406.88 761.03,1406.88 761.039,1406.88 761.048,1406.88 761.057,1406.88 761.066,1406.88 761.076,1406.88 761.085,1406.88 761.094,1406.88 761.103,1406.88 761.112,1406.88 761.122,1406.88 761.131,1406.88 761.14,1406.88 761.149,1406.88 761.158,1406.88 761.168,1406.88 761.177,1406.88 761.186,1406.88 761.195,1406.88 761.204,1406.88 761.213,1406.88 761.223,1406.88 761.232,1406.88 761.241,1406.88 761.25,1406.88 761.259,1406.88 761.269,1406.88 761.278,1406.88 761.287,1406.88 761.296,1406.88 761.305,1406.88 761.315,1406.88 761.324,1406.88 761.333,1406.88 761.342,1406.88 761.351,1406.88 761.361,1406.88 761.37,1406.88 761.379,1406.88 761.388,1406.88 761.397,1406.88 761.406,1406.88 761.416,1406.88 761.425,1406.88 761.434,1406.88 761.443,1406.88 761.452,1406.88 761.462,1406.88 761.471,1406.88 761.48,1406.88 761.489,1406.88 761.498,1406.88 761.508,1406.88 761.517,1406.88 761.526,1406.88 761.535,1406.88 761.544,1406.88 761.553,1406.88 761.563,1406.88 761.572,1406.88 761.581,1406.88 761.59,1406.88 761.599,1406.88 761.609,1406.88 761.618,1406.88 761.627,1406.88 761.636,1406.88 761.645,1406.88 761.655,1406.88 761.664,1406.88 761.673,1406.88 761.682,1406.88 761.691,1406.88 761.701,1406.88 761.71,1406.88 761.719,1406.88 761.728,1406.88 761.737,1406.88 761.746,1406.88 761.756,1406.88 761.765,1406.88 761.774,1406.88 761.783,1406.88 761.792,1406.88 761.802,1406.88 761.811,1406.88 761.82,1406.88 761.829,1406.88 761.838,1406.88 761.848,1406.88 761.857,1406.88 761.866,1406.88 761.875,1406.88 761.884,1406.88 761.893,1406.88 761.903,1406.88 761.912,1406.88 761.921,1406.88 761.93,1406.88 761.939,1406.88 761.949,1406.88 761.958,1406.88 761.967,1406.88 761.976,1406.88 761.985,1406.88 761.995,1406.88 762.004,1406.88 762.013,1406.88 762.022,1406.88 762.031,1406.88 762.041,1406.88 762.05,1406.88 762.059,1406.88 762.068,1406.88 762.077,1406.88 762.086,1406.88 762.096,1406.88 762.105,1406.88 762.114,1406.88 762.123,1406.88 762.132,1406.88 762.142,1406.88 762.151,1406.88 762.16,1406.88 762.169,1406.88 762.178,1406.88 762.188,1406.88 762.197,1406.88 762.206,1406.88 762.215,1406.88 762.224,1406.88 762.233,1406.88 762.243,1406.88 762.252,1406.88 762.261,1406.88 762.27,1406.88 762.279,1406.88 762.289,1406.88 762.298,1406.88 762.307,1406.88 762.316,1406.88 762.325,1406.88 762.335,1406.88 762.344,1406.88 762.353,1406.88 762.362,1406.88 762.371,1406.88 762.381,1406.88 762.39,1406.88 762.399,1406.88 762.408,1406.88 762.417,1406.88 762.426,1406.88 762.436,1406.88 762.445,1406.88 762.454,1406.88 762.463,1406.88 762.472,1406.88 762.482,1406.88 762.491,1406.88 762.5,1406.88 762.509,1406.88 762.518,1406.88 762.528,1406.88 762.537,1406.88 762.546,1406.88 762.555,1406.88 762.564,1406.88 762.573,1406.88 762.583,1406.88 762.592,1406.88 762.601,1406.88 762.61,1406.88 762.619,1406.88 762.629,1406.88 762.638,1406.88 762.647,1406.88 762.656,1406.88 762.665,1406.88 762.675,1406.88 762.684,1406.88 762.693,1406.88 762.702,1406.88 762.711,1406.88 762.721,1406.88 762.73,1406.88 762.739,1406.88 762.748,1406.88 762.757,1406.88 762.766,1406.88 762.776,1406.88 762.785,1406.88 762.794,1406.88 762.803,1406.88 762.812,1406.88 762.822,1406.88 762.831,1406.88 762.84,1406.88 762.849,1406.88 762.858,1406.88 762.868,1406.88 762.877,1406.88 762.886,1406.88 762.895,1406.88 762.904,1406.88 762.914,1406.88 762.923,1406.88 762.932,1406.88 762.941,1406.88 762.95,1406.88 762.959,1406.88 762.969,1406.88 762.978,1406.88 762.987,1406.88 762.996,1406.88 763.005,1406.88 763.015,1406.88 763.024,1406.88 763.033,1406.88 763.042,1406.88 763.051,1406.88 763.061,1406.88 763.07,1406.88 763.079,1406.88 763.088,1406.88 763.097,1406.88 763.106,1406.88 763.116,1406.88 763.125,1406.88 763.134,1406.88 763.143,1406.88 763.152,1406.88 763.162,1406.88 763.171,1406.88 763.18,1406.88 763.189,1406.88 763.198,1406.88 763.208,1406.88 763.217,1406.88 763.226,1406.88 763.235,1406.88 763.244,1406.88 763.254,1406.88 763.263,1406.88 763.272,1406.88 763.281,1406.88 763.29,1406.88 763.299,1406.88 763.309,1406.88 763.318,1406.88 763.327,1406.88 763.336,1406.88 763.345,1406.88 763.355,1406.88 763.364,1406.88 763.373,1406.88 763.382,1406.88 763.391,1406.88 763.401,1406.88 763.41,1406.88 763.419,1406.88 763.428,1406.88 763.437,1406.88 763.446,1406.88 763.456,1406.88 763.465,1406.88 763.474,1406.88 763.483,1406.88 763.492,1406.88 763.502,1406.88 763.511,1406.88 763.52,1406.88 763.529,1406.88 763.538,1406.88 763.548,1406.88 763.557,1406.88 763.566,1406.88 763.575,1406.88 763.584,1406.88 763.594,1406.88 763.603,1406.88 763.612,1406.88 763.621,1406.88 763.63,1406.88 763.639,1406.88 763.649,1406.88 763.658,1406.88 763.667,1406.88 763.676,1406.88 763.685,1406.88 763.695,1406.88 763.704,1406.88 763.713,1406.88 763.722,1406.88 763.731,1406.88 763.741,1406.88 763.75,1406.88 763.759,1406.88 763.768,1406.88 763.777,1406.88 763.786,1406.88 763.796,1406.88 763.805,1406.88 763.814,1406.88 763.823,1406.88 763.832,1406.88 763.842,1406.88 763.851,1406.88 763.86,1406.88 763.869,1406.88 763.878,1406.88 763.888,1406.88 763.897,1406.88 763.906,1406.88 763.915,1406.88 763.924,1406.88 763.934,1406.88 763.943,1406.88 763.952,1406.88 763.961,1406.88 763.97,1406.88 763.979,1406.88 763.989,1406.88 763.998,1406.88 764.007,1406.88 764.016,1406.88 764.025,1406.88 764.035,1406.88 764.044,1406.88 764.053,1406.88 764.062,1406.88 764.071,1406.88 764.081,1406.88 764.09,1406.88 764.099,1406.88 764.108,1406.88 764.117,1406.88 764.126,1406.88 764.136,1406.88 764.145,1406.88 764.154,1406.88 764.163,1406.88 764.172,1406.88 764.182,1406.88 764.191,1406.88 764.2,1406.88 764.209,1406.88 764.218,1406.88 764.228,1406.88 764.237,1406.88 764.246,1406.88 764.255,1406.88 764.264,1406.88 764.274,1406.88 764.283,1406.88 764.292,1406.88 764.301,1406.88 764.31,1406.88 764.319,1406.88 764.329,1406.88 764.338,1406.88 764.347,1406.88 764.356,1406.88 764.365,1406.88 764.375,1406.88 764.384,1406.88 764.393,1406.88 764.402,1406.88 764.411,1406.88 764.421,1406.88 764.43,1406.88 764.439,1406.88 764.448,1406.88 764.457,1406.88 764.466,1406.88 764.476,1406.88 764.485,1406.88 764.494,1406.88 764.503,1406.88 764.512,1406.88 764.522,1406.88 764.531,1406.88 764.54,1406.88 764.549,1406.88 764.558,1406.88 764.568,1406.88 764.577,1406.88 764.586,1406.88 764.595,1406.88 764.604,1406.88 764.614,1406.88 764.623,1406.88 764.632,1406.88 764.641,1406.88 764.65,1406.88 764.659,1406.88 764.669,1406.88 764.678,1406.88 764.687,1406.88 764.696,1406.88 764.705,1406.88 764.715,1406.88 764.724,1406.88 764.733,1406.88 764.742,1406.88 764.751,1406.88 764.761,1406.88 764.77,1406.88 764.779,1406.88 764.788,1406.88 764.797,1406.88 764.806,1406.88 764.816,1406.88 764.825,1406.88 764.834,1406.88 764.843,1406.88 764.852,1406.88 764.862,1406.88 764.871,1406.88 764.88,1406.88 764.889,1406.88 764.898,1406.88 764.908,1406.88 764.917,1406.88 764.926,1406.88 764.935,1406.88 764.944,1406.88 764.954,1406.88 764.963,1406.88 764.972,1406.88 764.981,1406.88 764.99,1406.88 764.999,1406.88 765.009,1406.88 765.018,1406.88 765.027,1406.88 765.036,1406.88 765.045,1406.88 765.055,1406.88 765.064,1406.88 765.073,1406.88 765.082,1406.88 765.091,1406.88 765.101,1406.88 765.11,1406.88 765.119,1406.88 765.128,1406.88 765.137,1406.88 765.146,1406.88 765.156,1406.88 765.165,1406.88 765.174,1406.88 765.183,1406.88 765.192,1406.88 765.202,1406.88 765.211,1406.88 765.22,1406.88 765.229,1406.88 765.238,1406.88 765.248,1406.88 765.257,1406.88 765.266,1406.88 765.275,1406.88 765.284,1406.88 765.294,1406.88 765.303,1406.88 765.312,1406.88 765.321,1406.88 765.33,1406.88 765.339,1406.88 765.349,1406.88 765.358,1406.88 765.367,1406.88 765.376,1406.88 765.385,1406.88 765.395,1406.88 765.404,1406.88 765.413,1406.88 765.422,1406.88 765.431,1406.88 765.441,1406.88 765.45,1406.88 765.459,1406.88 765.468,1406.88 765.477,1406.88 765.487,1406.88 765.496,1406.88 765.505,1406.88 765.514,1406.88 765.523,1406.88 765.532,1406.88 765.542,1406.88 765.551,1406.88 765.56,1406.88 765.569,1406.88 765.578,1406.88 765.588,1406.88 765.597,1406.88 765.606,1406.88 765.615,1406.88 765.624,1406.88 765.634,1406.88 765.643,1406.88 765.652,1406.88 765.661,1406.88 765.67,1406.88 765.679,1406.88 765.689,1406.88 765.698,1406.88 765.707,1406.88 765.716,1406.88 765.725,1406.88 765.735,1406.88 765.744,1406.88 765.753,1406.88 765.762,1406.88 765.771,1406.88 765.781,1406.88 765.79,1406.88 765.799,1406.88 765.808,1406.88 765.817,1406.88 765.827,1406.88 765.836,1406.88 765.845,1406.88 765.854,1406.88 765.863,1406.88 765.872,1406.88 765.882,1406.88 765.891,1406.88 765.9,1406.88 765.909,1406.88 765.918,1406.88 765.928,1406.88 765.937,1406.88 765.946,1406.88 765.955,1406.88 765.964,1406.88 765.974,1406.88 765.983,1406.88 765.992,1406.88 766.001,1406.88 766.01,1406.88 766.019,1406.88 766.029,1406.88 766.038,1406.88 766.047,1406.88 766.056,1406.88 766.065,1406.88 766.075,1406.88 766.084,1406.88 766.093,1406.88 766.102,1406.88 766.111,1406.88 766.121,1406.88 766.13,1406.88 766.139,1406.88 766.148,1406.88 766.157,1406.88 766.167,1406.88 766.176,1406.88 766.185,1406.88 766.194,1406.88 766.203,1406.88 766.212,1406.88 766.222,1406.88 766.231,1406.88 766.24,1406.88 766.249,1406.88 766.258,1406.88 766.268,1406.88 766.277,1406.88 766.286,1406.88 766.295,1406.88 766.304,1406.88 766.314,1406.88 766.323,1406.88 766.332,1406.88 766.341,1406.88 766.35,1406.88 766.359,1406.88 766.369,1406.88 766.378,1406.88 766.387,1406.88 766.396,1406.88 766.405,1406.88 766.415,1406.88 766.424,1406.88 766.433,1406.88 766.442,1406.88 766.451,1406.88 766.461,1406.88 766.47,1406.88 766.479,1406.88 766.488,1406.88 766.497,1406.88 766.507,1406.88 766.516,1406.88 766.525,1406.88 766.534,1406.88 766.543,1406.88 766.552,1406.88 766.562,1406.88 766.571,1406.88 766.58,1406.88 766.589,1406.88 766.598,1406.88 766.608,1406.88 766.617,1406.88 766.626,1406.88 766.635,1406.88 766.644,1406.88 766.654,1406.88 766.663,1406.88 766.672,1406.88 766.681,1406.88 766.69,1406.88 766.699,1406.88 766.709,1406.88 766.718,1406.88 766.727,1406.88 766.736,1406.88 766.745,1406.88 766.755,1406.88 766.764,1406.88 766.773,1406.88 766.782,1406.88 766.791,1406.88 766.801,1406.88 766.81,1406.88 766.819,1406.88 766.828,1406.88 766.837,1406.88 766.847,1406.88 766.856,1406.88 766.865,1406.88 766.874,1406.88 766.883,1406.88 766.892,1406.88 766.902,1406.88 766.911,1406.88 766.92,1406.88 766.929,1406.88 766.938,1406.88 766.948,1406.88 766.957,1406.88 766.966,1406.88 766.975,1406.88 766.984,1406.88 766.994,1406.88 767.003,1406.88 767.012,1406.88 767.021,1406.88 767.03,1406.88 767.039,1406.88 767.049,1406.88 767.058,1406.88 767.067,1406.88 767.076,1406.88 767.085,1406.88 767.095,1406.88 767.104,1406.88 767.113,1406.88 767.122,1406.88 767.131,1406.88 767.141,1406.88 767.15,1406.88 767.159,1406.88 767.168,1406.88 767.177,1406.88 767.187,1406.88 767.196,1406.88 767.205,1406.88 767.214,1406.88 767.223,1406.88 767.232,1406.88 767.242,1406.88 767.251,1406.88 767.26,1406.88 767.269,1406.88 767.278,1406.88 767.288,1406.88 767.297,1406.88 767.306,1406.88 767.315,1406.88 767.324,1406.88 767.334,1406.88 767.343,1406.88 767.352,1406.88 767.361,1406.88 767.37,1406.88 767.379,1406.88 767.389,1406.88 767.398,1406.88 767.407,1406.88 767.416,1406.88 767.425,1406.88 767.435,1406.88 767.444,1406.88 767.453,1406.88 767.462,1406.88 767.471,1406.88 767.481,1406.88 767.49,1406.88 767.499,1406.88 767.508,1406.88 767.517,1406.88 767.527,1406.88 767.536,1406.88 767.545,1406.88 767.554,1406.88 767.563,1406.88 767.572,1406.88 767.582,1406.88 767.591,1406.88 767.6,1406.88 767.609,1406.88 767.618,1406.88 767.628,1406.88 767.637,1406.88 767.646,1406.88 767.655,1406.88 767.664,1406.88 767.674,1406.88 767.683,1406.88 767.692,1406.88 767.701,1406.88 767.71,1406.88 767.719,1406.88 767.729,1406.88 767.738,1406.88 767.747,1406.88 767.756,1406.88 767.765,1406.88 767.775,1406.88 767.784,1406.88 767.793,1406.88 767.802,1406.88 767.811,1406.88 767.821,1406.88 767.83,1406.88 767.839,1406.88 767.848,1406.88 767.857,1406.88 767.867,1406.88 767.876,1406.88 767.885,1406.88 767.894,1406.88 767.903,1406.88 767.912,1406.88 767.922,1406.88 767.931,1406.88 767.94,1406.88 767.949,1406.88 767.958,1406.88 767.968,1406.88 767.977,1406.88 767.986,1406.88 767.995,1406.88 768.004,1406.88 768.014,1406.88 768.023,1406.88 768.032,1406.88 768.041,1406.88 768.05,1406.88 768.06,1406.88 768.069,1406.88 768.078,1406.88 768.087,1406.88 768.096,1406.88 768.105,1406.88 768.115,1406.88 768.124,1406.88 768.133,1406.88 768.142,1406.88 768.151,1406.88 768.161,1406.88 768.17,1406.88 768.179,1406.88 768.188,1406.88 768.197,1406.88 768.207,1406.88 768.216,1406.88 768.225,1406.88 768.234,1406.88 768.243,1406.88 768.252,1406.88 768.262,1406.88 768.271,1406.88 768.28,1406.88 768.289,1406.88 768.298,1406.88 768.308,1406.88 768.317,1406.88 768.326,1406.88 768.335,1406.88 768.344,1406.88 768.354,1406.88 768.363,1406.88 768.372,1406.88 768.381,1406.88 768.39,1406.88 768.4,1406.88 768.409,1406.88 768.418,1406.88 768.427,1406.88 768.436,1406.88 768.445,1406.88 768.455,1406.88 768.464,1406.88 768.473,1406.88 768.482,1406.88 768.491,1406.88 768.501,1406.88 768.51,1406.88 768.519,1406.88 768.528,1406.88 768.537,1406.88 768.547,1406.88 768.556,1406.88 768.565,1406.88 768.574,1406.88 768.583,1406.88 768.592,1406.88 768.602,1406.88 768.611,1406.88 768.62,1406.88 768.629,1406.88 768.638,1406.88 768.648,1406.88 768.657,1406.88 768.666,1406.88 768.675,1406.88 768.684,1406.88 768.694,1406.88 768.703,1406.88 768.712,1406.88 768.721,1406.88 768.73,1406.88 768.74,1406.88 768.749,1406.88 768.758,1406.88 768.767,1406.88 768.776,1406.88 768.785,1406.88 768.795,1406.88 768.804,1406.88 768.813,1406.88 768.822,1406.88 768.831,1406.88 768.841,1406.88 768.85,1406.88 768.859,1406.88 768.868,1406.88 768.877,1406.88 768.887,1406.88 768.896,1406.88 768.905,1406.88 768.914,1406.88 768.923,1406.88 768.932,1406.88 768.942,1406.88 768.951,1406.88 768.96,1406.88 768.969,1406.88 768.978,1406.88 768.988,1406.88 768.997,1406.88 769.006,1406.88 769.015,1406.88 769.024,1406.88 769.034,1406.88 769.043,1406.88 769.052,1406.88 769.061,1406.88 769.07,1406.88 769.08,1406.88 769.089,1406.88 769.098,1406.88 769.107,1406.88 769.116,1406.88 769.125,1406.88 769.135,1406.88 769.144,1406.88 769.153,1406.88 769.162,1406.88 769.171,1406.88 769.181,1406.88 769.19,1406.88 769.199,1406.88 769.208,1406.88 769.217,1406.88 769.227,1406.88 769.236,1406.88 769.245,1406.88 769.254,1406.88 769.263,1406.88 769.272,1406.88 769.282,1406.88 769.291,1406.88 769.3,1406.88 769.309,1406.88 769.318,1406.88 769.328,1406.88 769.337,1406.88 769.346,1406.88 769.355,1406.88 769.364,1406.88 769.374,1406.88 769.383,1406.88 769.392,1406.88 769.401,1406.88 769.41,1406.88 769.42,1406.88 769.429,1406.88 769.438,1406.88 769.447,1406.88 769.456,1406.88 769.465,1406.88 769.475,1406.88 769.484,1406.88 769.493,1406.88 769.502,1406.88 769.511,1406.88 769.521,1406.88 769.53,1406.88 769.539,1406.88 769.548,1406.88 769.557,1406.88 769.567,1406.88 769.576,1406.88 769.585,1406.88 769.594,1406.88 769.603,1406.88 769.612,1406.88 769.622,1406.88 769.631,1406.88 769.64,1406.88 769.649,1406.88 769.658,1406.88 769.668,1406.88 769.677,1406.88 769.686,1406.88 769.695,1406.88 769.704,1406.88 769.714,1406.88 769.723,1406.88 769.732,1406.88 769.741,1406.88 769.75,1406.88 769.76,1406.88 769.769,1406.88 769.778,1406.88 769.787,1406.88 769.796,1406.88 769.805,1406.88 769.815,1406.88 769.824,1406.88 769.833,1406.88 769.842,1406.88 769.851,1406.88 769.861,1406.88 769.87,1406.88 769.879,1406.88 769.888,1406.88 769.897,1406.88 769.907,1406.88 769.916,1406.88 769.925,1406.88 769.934,1406.88 769.943,1406.88 769.952,1406.88 769.962,1406.88 769.971,1406.88 769.98,1406.88 769.989,1406.88 769.998,1406.88 770.008,1406.88 770.017,1406.88 770.026,1406.88 770.035,1406.88 770.044,1406.88 770.054,1406.88 770.063,1406.88 770.072,1406.88 770.081,1406.88 770.09,1406.88 770.1,1406.88 770.109,1406.88 770.118,1406.88 770.127,1406.88 770.136,1406.88 770.145,1406.88 770.155,1406.88 770.164,1406.88 770.173,1406.88 770.182,1406.88 770.191,1406.88 770.201,1406.88 770.21,1406.88 770.219,1406.88 770.228,1406.88 770.237,1406.88 770.247,1406.88 770.256,1406.88 770.265,1406.88 770.274,1406.88 770.283,1406.88 770.293,1406.88 770.302,1406.88 770.311,1406.88 770.32,1406.88 770.329,1406.88 770.338,1406.88 770.348,1406.88 770.357,1406.88 770.366,1406.88 770.375,1406.88 770.384,1406.88 770.394,1406.88 770.403,1406.88 770.412,1406.88 770.421,1406.88 770.43,1406.88 770.44,1406.88 770.449,1406.88 770.458,1406.88 770.467,1406.88 770.476,1406.88 770.485,1406.88 770.495,1406.88 770.504,1406.88 770.513,1406.88 770.522,1406.88 770.531,1406.88 770.541,1406.88 770.55,1406.88 770.559,1406.88 770.568,1406.88 770.577,1406.88 770.587,1406.88 770.596,1406.88 770.605,1406.88 770.614,1406.88 770.623,1406.88 770.633,1406.88 770.642,1406.88 770.651,1406.88 770.66,1406.88 770.669,1406.88 770.678,1406.88 770.688,1406.88 770.697,1406.88 770.706,1406.88 770.715,1406.88 770.724,1406.88 770.734,1406.88 770.743,1406.88 770.752,1406.88 770.761,1406.88 770.77,1406.88 770.78,1406.88 770.789,1406.88 770.798,1406.88 770.807,1406.88 770.816,1406.88 770.825,1406.88 770.835,1406.88 770.844,1406.88 770.853,1406.88 770.862,1406.88 770.871,1406.88 770.881,1406.88 770.89,1406.88 770.899,1406.88 770.908,1406.88 770.917,1406.88 770.927,1406.88 770.936,1406.88 770.945,1406.88 770.954,1406.88 770.963,1406.88 770.973,1406.88 770.982,1406.88 770.991,1406.88 771,1406.88 771.009,1406.88 771.018,1406.88 771.028,1406.88 771.037,1406.88 771.046,1406.88 771.055,1406.88 771.064,1406.88 771.074,1406.88 771.083,1406.88 771.092,1406.88 771.101,1406.88 771.11,1406.88 771.12,1406.88 771.129,1406.88 771.138,1406.88 771.147,1406.88 771.156,1406.88 771.165,1406.88 771.175,1406.88 771.184,1406.88 771.193,1406.88 771.202,1406.88 771.211,1406.88 771.221,1406.88 771.23,1406.88 771.239,1406.88 771.248,1406.88 771.257,1406.88 771.267,1406.88 771.276,1406.88 771.285,1406.88 771.294,1406.88 771.303,1406.88 771.313,1406.88 771.322,1406.88 771.331,1406.88 771.34,1406.88 771.349,1406.88 771.358,1406.88 771.368,1406.88 771.377,1406.88 771.386,1406.88 771.395,1406.88 771.404,1406.88 771.414,1406.88 771.423,1406.88 771.432,1406.88 771.441,1406.88 771.45,1406.88 771.46,1406.88 771.469,1406.88 771.478,1406.88 771.487,1406.88 771.496,1406.88 771.505,1406.88 771.515,1406.88 771.524,1406.88 771.533,1406.88 771.542,1406.88 771.551,1406.88 771.561,1406.88 771.57,1406.88 771.579,1406.88 771.588,1406.88 771.597,1406.88 771.607,1406.88 771.616,1406.88 771.625,1406.88 771.634,1406.88 771.643,1406.88 771.653,1406.88 771.662,1406.88 771.671,1406.88 771.68,1406.88 771.689,1406.88 771.698,1406.88 771.708,1406.88 771.717,1406.88 771.726,1406.88 771.735,1406.88 771.744,1406.88 771.754,1406.88 771.763,1406.88 771.772,1406.88 771.781,1406.88 771.79,1406.88 771.8,1406.88 771.809,1406.88 771.818,1406.88 771.827,1406.88 771.836,1406.88 771.845,1406.88 771.855,1406.88 771.864,1406.88 771.873,1406.88 771.882,1406.88 771.891,1406.88 771.901,1406.88 771.91,1406.88 771.919,1406.88 771.928,1406.88 771.937,1406.88 771.947,1406.88 771.956,1406.88 771.965,1406.88 771.974,1406.88 771.983,1406.88 771.993,1406.88 772.002,1406.88 772.011,1406.88 772.02,1406.88 772.029,1406.88 772.038,1406.88 772.048,1406.88 772.057,1406.88 772.066,1406.88 772.075,1406.88 772.084,1406.88 772.094,1406.88 772.103,1406.88 772.112,1406.88 772.121,1406.88 772.13,1406.88 772.14,1406.88 772.149,1406.88 772.158,1406.88 772.167,1406.88 772.176,1406.88 772.185,1406.88 772.195,1406.88 772.204,1406.88 772.213,1406.88 772.222,1406.88 772.231,1406.88 772.241,1406.88 772.25,1406.88 772.259,1406.88 772.268,1406.88 772.277,1406.88 772.287,1406.88 772.296,1406.88 772.305,1406.88 772.314,1406.88 772.323,1406.88 772.333,1406.88 772.342,1406.88 772.351,1406.88 772.36,1406.88 772.369,1406.88 772.378,1406.88 772.388,1406.88 772.397,1406.88 772.406,1406.88 772.415,1406.88 772.424,1406.88 772.434,1406.88 772.443,1406.88 772.452,1406.88 772.461,1406.88 772.47,1406.88 772.48,1406.88 772.489,1406.88 772.498,1406.88 772.507,1406.88 772.516,1406.88 772.525,1406.88 772.535,1406.88 772.544,1406.88 772.553,1406.88 772.562,1406.88 772.571,1406.88 772.581,1406.88 772.59,1406.88 772.599,1406.88 772.608,1406.88 772.617,1406.88 772.627,1406.88 772.636,1406.88 772.645,1406.88 772.654,1406.88 772.663,1406.88 772.673,1406.88 772.682,1406.88 772.691,1406.88 772.7,1406.88 772.709,1406.88 772.718,1406.88 772.728,1406.88 772.737,1406.88 772.746,1406.88 772.755,1406.88 772.764,1406.88 772.774,1406.88 772.783,1406.88 772.792,1406.88 772.801,1406.88 772.81,1406.88 772.82,1406.88 772.829,1406.88 772.838,1406.88 772.847,1406.88 772.856,1406.88 772.866,1406.88 772.875,1406.88 772.884,1406.88 772.893,1406.88 772.902,1406.88 772.911,1406.88 772.921,1406.88 772.93,1406.88 772.939,1406.88 772.948,1406.88 772.957,1406.88 772.967,1406.88 772.976,1406.88 772.985,1406.88 772.994,1406.88 773.003,1406.88 773.013,1406.88 773.022,1406.88 773.031,1406.88 773.04,1406.88 773.049,1406.88 773.058,1406.88 773.068,1406.88 773.077,1406.88 773.086,1406.88 773.095,1406.88 773.104,1406.88 773.114,1406.88 773.123,1406.88 773.132,1406.88 773.141,1406.88 773.15,1406.88 773.16,1406.88 773.169,1406.88 773.178,1406.88 773.187,1406.88 773.196,1406.88 773.206,1406.88 773.215,1406.88 773.224,1406.88 773.233,1406.88 773.242,1406.88 773.251,1406.88 773.261,1406.88 773.27,1406.88 773.279,1406.88 773.288,1406.88 773.297,1406.88 773.307,1406.88 773.316,1406.88 773.325,1406.88 773.334,1406.88 773.343,1406.88 773.353,1406.88 773.362,1406.88 773.371,1406.88 773.38,1406.88 773.389,1406.88 773.398,1406.88 773.408,1406.88 773.417,1406.88 773.426,1406.88 773.435,1406.88 773.444,1406.88 773.454,1406.88 773.463,1406.88 773.472,1406.88 773.481,1406.88 773.49,1406.88 773.5,1406.88 773.509,1406.88 773.518,1406.88 773.527,1406.88 773.536,1406.88 773.546,1406.88 773.555,1406.88 773.564,1406.88 773.573,1406.88 773.582,1406.88 773.591,1406.88 773.601,1406.88 773.61,1406.88 773.619,1406.88 773.628,1406.88 773.637,1406.88 773.647,1406.88 773.656,1406.88 773.665,1406.88 773.674,1406.88 773.683,1406.88 773.693,1406.88 773.702,1406.88 773.711,1406.88 773.72,1406.88 773.729,1406.88 773.738,1406.88 773.748,1406.88 773.757,1406.88 773.766,1406.88 773.775,1406.88 773.784,1406.88 773.794,1406.88 773.803,1406.88 773.812,1406.88 773.821,1406.88 773.83,1406.88 773.84,1406.88 773.849,1406.88 773.858,1406.88 773.867,1406.88 773.876,1406.88 773.886,1406.88 773.895,1406.88 773.904,1406.88 773.913,1406.88 773.922,1406.88 773.931,1406.88 773.941,1406.88 773.95,1406.88 773.959,1406.88 773.968,1406.88 773.977,1406.88 773.987,1406.88 773.996,1406.88 774.005,1406.88 774.014,1406.88 774.023,1406.88 774.033,1406.88 774.042,1406.88 774.051,1406.88 774.06,1406.88 774.069,1406.88 774.078,1406.88 774.088,1406.88 774.097,1406.88 774.106,1406.88 774.115,1406.88 774.124,1406.88 774.134,1406.88 774.143,1406.88 774.152,1406.88 774.161,1406.88 774.17,1406.88 774.18,1406.88 774.189,1406.88 774.198,1406.88 774.207,1406.88 774.216,1406.88 774.226,1406.88 774.235,1406.88 774.244,1406.88 774.253,1406.88 774.262,1406.88 774.271,1406.88 774.281,1406.88 774.29,1406.88 774.299,1406.88 774.308,1406.88 774.317,1406.88 774.327,1406.88 774.336,1406.88 774.345,1406.88 774.354,1406.88 774.363,1406.88 774.373,1406.88 774.382,1406.88 774.391,1406.88 774.4,1406.88 774.409,1406.88 774.418,1406.88 774.428,1406.88 774.437,1406.88 774.446,1406.88 774.455,1406.88 774.464,1406.88 774.474,1406.88 774.483,1406.88 774.492,1406.88 774.501,1406.88 774.51,1406.88 774.52,1406.88 774.529,1406.88 774.538,1406.88 774.547,1406.88 774.556,1406.88 774.566,1406.88 774.575,1406.88 774.584,1406.88 774.593,1406.88 774.602,1406.88 774.611,1406.88 774.621,1406.88 774.63,1406.88 774.639,1406.88 774.648,1406.88 774.657,1406.88 774.667,1406.88 774.676,1406.88 774.685,1406.88 774.694,1406.88 774.703,1406.88 774.713,1406.88 774.722,1406.88 774.731,1406.88 774.74,1406.88 774.749,1406.88 774.758,1406.88 774.768,1406.88 774.777,1406.88 774.786,1406.88 774.795,1406.88 774.804,1406.88 774.814,1406.88 774.823,1406.88 774.832,1406.88 774.841,1406.88 774.85,1406.88 774.86,1406.88 774.869,1406.88 774.878,1406.88 774.887,1406.88 774.896,1406.88 774.906,1406.88 774.915,1406.88 774.924,1406.88 774.933,1406.88 774.942,1406.88 774.951,1406.88 774.961,1406.88 774.97,1406.88 774.979,1406.88 774.988,1406.88 774.997,1406.88 775.007,1406.88 775.016,1406.88 775.025,1406.88 775.034,1406.88 775.043,1406.88 775.053,1406.88 775.062,1406.88 775.071,1406.88 775.08,1406.88 775.089,1406.88 775.098,1406.88 775.108,1406.88 775.117,1406.88 775.126,1406.88 775.135,1406.88 775.144,1406.88 775.154,1406.88 775.163,1406.88 775.172,1406.88 775.181,1406.88 775.19,1406.88 775.2,1406.88 775.209,1406.88 775.218,1406.88 775.227,1406.88 775.236,1406.88 775.246,1406.88 775.255,1406.88 775.264,1406.88 775.273,1406.88 775.282,1406.88 775.291,1406.88 775.301,1406.88 775.31,1406.88 775.319,1406.88 775.328,1406.88 775.337,1406.88 775.347,1406.88 775.356,1406.88 775.365,1406.88 775.374,1406.88 775.383,1406.88 775.393,1406.88 775.402,1406.88 775.411,1406.88 775.42,1406.88 775.429,1406.88 775.439,1406.88 775.448,1406.88 775.457,1406.88 775.466,1406.88 775.475,1406.88 775.484,1406.88 775.494,1406.88 775.503,1406.88 775.512,1406.88 775.521,1406.88 775.53,1406.88 775.54,1406.88 775.549,1406.88 775.558,1406.88 775.567,1406.88 775.576,1406.88 775.586,1406.88 775.595,1406.88 775.604,1406.88 775.613,1406.88 775.622,1406.88 775.631,1406.88 775.641,1406.88 775.65,1406.88 775.659,1406.88 775.668,1406.88 775.677,1406.88 775.687,1406.88 775.696,1406.88 775.705,1406.88 775.714,1406.88 775.723,1406.88 775.733,1406.88 775.742,1406.88 775.751,1406.88 775.76,1406.88 775.769,1406.88 775.779,1406.88 775.788,1406.88 775.797,1406.88 775.806,1406.88 775.815,1406.88 775.824,1406.88 775.834,1406.88 775.843,1406.88 775.852,1406.88 775.861,1406.88 775.87,1406.88 775.88,1406.88 775.889,1406.88 775.898,1406.88 775.907,1406.88 775.916,1406.88 775.926,1406.88 775.935,1406.88 775.944,1406.88 775.953,1406.88 775.962,1406.88 775.971,1406.88 775.981,1406.88 775.99,1406.88 775.999,1406.88 776.008,1406.88 776.017,1406.88 776.027,1406.88 776.036,1406.88 776.045,1406.88 776.054,1406.88 776.063,1406.88 776.073,1406.88 776.082,1406.88 776.091,1406.88 776.1,1406.88 776.109,1406.88 776.119,1406.88 776.128,1406.88 776.137,1406.88 776.146,1406.88 776.155,1406.88 776.164,1406.88 776.174,1406.88 776.183,1406.88 776.192,1406.88 776.201,1406.88 776.21,1406.88 776.22,1406.88 776.229,1406.88 776.238,1406.88 776.247,1406.88 776.256,1406.88 776.266,1406.88 776.275,1406.88 776.284,1406.88 776.293,1406.88 776.302,1406.88 776.311,1406.88 776.321,1406.88 776.33,1406.88 776.339,1406.88 776.348,1406.88 776.357,1406.88 776.367,1406.88 776.376,1406.88 776.385,1406.88 776.394,1406.88 776.403,1406.88 776.413,1406.88 776.422,1406.88 776.431,1406.88 776.44,1406.88 776.449,1406.88 776.459,1406.88 776.468,1406.88 776.477,1406.88 776.486,1406.88 776.495,1406.88 776.504,1406.88 776.514,1406.88 776.523,1406.88 776.532,1406.88 776.541,1406.88 776.55,1406.88 776.56,1406.88 776.569,1406.88 776.578,1406.88 776.587,1406.88 776.596,1406.88 776.606,1406.88 776.615,1406.88 776.624,1406.88 776.633,1406.88 776.642,1406.88 776.651,1406.88 776.661,1406.88 776.67,1406.88 776.679,1406.88 776.688,1406.88 776.697,1406.88 776.707,1406.88 776.716,1406.88 776.725,1406.88 776.734,1406.88 776.743,1406.88 776.753,1406.88 776.762,1406.88 776.771,1406.88 776.78,1406.88 776.789,1406.88 776.799,1406.88 776.808,1406.88 776.817,1406.88 776.826,1406.88 776.835,1406.88 776.844,1406.88 776.854,1406.88 776.863,1406.88 776.872,1406.88 776.881,1406.88 776.89,1406.88 776.9,1406.88 776.909,1406.88 776.918,1406.88 776.927,1406.88 776.936,1406.88 776.946,1406.88 776.955,1406.88 776.964,1406.88 776.973,1406.88 776.982,1406.88 776.991,1406.88 777.001,1406.88 777.01,1406.88 777.019,1406.88 777.028,1406.88 777.037,1406.88 777.047,1406.88 777.056,1406.88 777.065,1406.88 777.074,1406.88 777.083,1406.88 777.093,1406.88 777.102,1406.88 777.111,1406.88 777.12,1406.88 777.129,1406.88 777.139,1406.88 777.148,1406.88 777.157,1406.88 777.166,1406.88 777.175,1406.88 777.184,1406.88 777.194,1406.88 777.203,1406.88 777.212,1406.88 777.221,1406.88 777.23,1406.88 777.24,1406.88 777.249,1406.88 777.258,1406.88 777.267,1406.88 777.276,1406.88 777.286,1406.88 777.295,1406.88 777.304,1406.88 777.313,1406.88 777.322,1406.88 777.331,1406.88 777.341,1406.88 777.35,1406.88 777.359,1406.88 777.368,1406.88 777.377,1406.88 777.387,1406.88 777.396,1406.88 777.405,1406.88 777.414,1406.88 777.423,1406.88 777.433,1406.88 777.442,1406.88 777.451,1406.88 777.46,1406.88 777.469,1406.88 777.479,1406.88 777.488,1406.88 777.497,1406.88 777.506,1406.88 777.515,1406.88 777.524,1406.88 777.534,1406.88 777.543,1406.88 777.552,1406.88 777.561,1406.88 777.57,1406.88 777.58,1406.88 777.589,1406.88 777.598,1406.88 777.607,1406.88 777.616,1406.88 777.626,1406.88 777.635,1406.88 777.644,1406.88 777.653,1406.88 777.662,1406.88 777.672,1406.88 777.681,1406.88 777.69,1406.88 777.699,1406.88 777.708,1406.88 777.717,1406.88 777.727,1406.88 777.736,1406.88 777.745,1406.88 777.754,1406.88 777.763,1406.88 777.773,1406.88 777.782,1406.88 777.791,1406.88 777.8,1406.88 777.809,1406.88 777.819,1406.88 777.828,1406.88 777.837,1406.88 777.846,1406.88 777.855,1406.88 777.864,1406.88 777.874,1406.88 777.883,1406.88 777.892,1406.88 777.901,1406.88 777.91,1406.88 777.92,1406.88 777.929,1406.88 777.938,1406.88 777.947,1406.88 777.956,1406.88 777.966,1406.88 777.975,1406.88 777.984,1406.88 777.993,1406.88 778.002,1406.88 778.012,1406.88 778.021,1406.88 778.03,1406.88 778.039,1406.88 778.048,1406.88 778.057,1406.88 778.067,1406.88 778.076,1406.88 778.085,1406.88 778.094,1406.88 778.103,1406.88 778.113,1406.88 778.122,1406.88 778.131,1406.88 778.14,1406.88 778.149,1406.88 778.159,1406.88 778.168,1406.88 778.177,1406.88 778.186,1406.88 778.195,1406.88 778.204,1406.88 778.214,1406.88 778.223,1406.88 778.232,1406.88 778.241,1406.88 778.25,1406.88 778.26,1406.88 778.269,1406.88 778.278,1406.88 778.287,1406.88 778.296,1406.88 778.306,1406.88 778.315,1406.88 778.324,1406.88 778.333,1406.88 778.342,1406.88 778.352,1406.88 778.361,1406.88 778.37,1406.88 778.379,1406.88 778.388,1406.88 778.397,1406.88 778.407,1406.88 778.416,1406.88 778.425,1406.88 778.434,1406.88 778.443,1406.88 778.453,1406.88 778.462,1406.88 778.471,1406.88 778.48,1406.88 778.489,1406.88 778.499,1406.88 778.508,1406.88 778.517,1406.88 778.526,1406.88 778.535,1406.88 778.544,1406.88 778.554,1406.88 778.563,1406.88 778.572,1406.88 778.581,1406.88 778.59,1406.88 778.6,1406.88 778.609,1406.88 778.618,1406.88 778.627,1406.88 778.636,1406.88 778.646,1406.88 778.655,1406.88 778.664,1406.88 778.673,1406.88 778.682,1406.88 778.692,1406.88 778.701,1406.88 778.71,1406.88 778.719,1406.88 778.728,1406.88 778.737,1406.88 778.747,1406.88 778.756,1406.88 778.765,1406.88 778.774,1406.88 778.783,1406.88 778.793,1406.88 778.802,1406.88 778.811,1406.88 778.82,1406.88 778.829,1406.88 778.839,1406.88 778.848,1406.88 778.857,1406.88 778.866,1406.88 778.875,1406.88 778.884,1406.88 778.894,1406.88 778.903,1406.88 778.912,1406.88 778.921,1406.88 778.93,1406.88 778.94,1406.88 778.949,1406.88 778.958,1406.88 778.967,1406.88 778.976,1406.88 778.986,1406.88 778.995,1406.88 779.004,1406.88 779.013,1406.88 779.022,1406.88 779.032,1406.88 779.041,1406.88 779.05,1406.88 779.059,1406.88 779.068,1406.88 779.077,1406.88 779.087,1406.88 779.096,1406.88 779.105,1406.88 779.114,1406.88 779.123,1406.88 779.133,1406.88 779.142,1406.88 779.151,1406.88 779.16,1406.88 779.169,1406.88 779.179,1406.88 779.188,1406.88 779.197,1406.88 779.206,1406.88 779.215,1406.88 779.224,1406.88 779.234,1406.88 779.243,1406.88 779.252,1406.88 779.261,1406.88 779.27,1406.88 779.28,1406.88 779.289,1406.88 779.298,1406.88 779.307,1406.88 779.316,1406.88 779.326,1406.88 779.335,1406.88 779.344,1406.88 779.353,1406.88 779.362,1406.88 779.372,1406.88 779.381,1406.88 779.39,1406.88 779.399,1406.88 779.408,1406.88 779.417,1406.88 779.427,1406.88 779.436,1406.88 779.445,1406.88 779.454,1406.88 779.463,1406.88 779.473,1406.88 779.482,1406.88 779.491,1406.88 779.5,1406.88 779.509,1406.88 779.519,1406.88 779.528,1406.88 779.537,1406.88 779.546,1406.88 779.555,1406.88 779.564,1406.88 779.574,1406.88 779.583,1406.88 779.592,1406.88 779.601,1406.88 779.61,1406.88 779.62,1406.88 779.629,1406.88 779.638,1406.88 779.647,1406.88 779.656,1406.88 779.666,1406.88 779.675,1406.88 779.684,1406.88 779.693,1406.88 779.702,1406.88 779.712,1406.88 779.721,1406.88 779.73,1406.88 779.739,1406.88 779.748,1406.88 779.757,1406.88 779.767,1406.88 779.776,1406.88 779.785,1406.88 779.794,1406.88 779.803,1406.88 779.813,1406.88 779.822,1406.88 779.831,1406.88 779.84,1406.88 779.849,1406.88 779.859,1406.88 779.868,1406.88 779.877,1406.88 779.886,1406.88 779.895,1406.88 779.904,1406.88 779.914,1406.88 779.923,1406.88 779.932,1406.88 779.941,1406.88 779.95,1406.88 779.96,1406.88 779.969,1406.88 779.978,1406.88 779.987,1406.88 779.996,1406.88 780.006,1406.88 780.015,1406.88 780.024,1406.88 780.033,1406.88 780.042,1406.88 780.052,1406.88 780.061,1406.88 780.07,1406.88 780.079,1406.88 780.088,1406.88 780.097,1406.88 780.107,1406.88 780.116,1406.88 780.125,1406.88 780.134,1406.88 780.143,1406.88 780.153,1406.88 780.162,1406.88 780.171,1406.88 780.18,1406.88 780.189,1406.88 780.199,1406.88 780.208,1406.88 780.217,1406.88 780.226,1406.88 780.235,1406.88 780.245,1406.88 780.254,1406.88 780.263,1406.88 780.272,1406.88 780.281,1406.88 780.29,1406.88 780.3,1406.88 780.309,1406.88 780.318,1406.88 780.327,1406.88 780.336,1406.88 780.346,1406.88 780.355,1406.88 780.364,1406.88 780.373,1406.88 780.382,1406.88 780.392,1406.88 780.401,1406.88 780.41,1406.88 780.419,1406.88 780.428,1406.88 780.437,1406.88 780.447,1406.88 780.456,1406.88 780.465,1406.88 780.474,1406.88 780.483,1406.88 780.493,1406.88 780.502,1406.88 780.511,1406.88 780.52,1406.88 780.529,1406.88 780.539,1406.88 780.548,1406.88 780.557,1406.88 780.566,1406.88 780.575,1406.88 780.585,1406.88 780.594,1406.88 780.603,1406.88 780.612,1406.88 780.621,1406.88 780.63,1406.88 780.64,1406.88 780.649,1406.88 780.658,1406.88 780.667,1406.88 780.676,1406.88 780.686,1406.88 780.695,1406.88 780.704,1406.88 780.713,1406.88 780.722,1406.88 780.732,1406.88 780.741,1406.88 780.75,1406.88 780.759,1406.88 780.768,1406.88 780.777,1406.88 780.787,1406.88 780.796,1406.88 780.805,1406.88 780.814,1406.88 780.823,1406.88 780.833,1406.88 780.842,1406.88 780.851,1406.88 780.86,1406.88 780.869,1406.88 780.879,1406.88 780.888,1406.88 780.897,1406.88 780.906,1406.88 780.915,1406.88 780.925,1406.88 780.934,1406.88 780.943,1406.88 780.952,1406.88 780.961,1406.88 780.97,1406.88 780.98,1406.88 780.989,1406.88 780.998,1406.88 781.007,1406.88 781.016,1406.88 781.026,1406.88 781.035,1406.88 781.044,1406.88 781.053,1406.88 781.062,1406.88 781.072,1406.88 781.081,1406.88 781.09,1406.88 781.099,1406.88 781.108,1406.88 781.117,1406.88 781.127,1406.88 781.136,1406.88 781.145,1406.88 781.154,1406.88 781.163,1406.88 781.173,1406.88 781.182,1406.88 781.191,1406.88 781.2,1406.88 781.209,1406.88 781.219,1406.88 781.228,1406.88 781.237,1406.88 781.246,1406.88 781.255,1406.88 781.265,1406.88 781.274,1406.88 781.283,1406.88 781.292,1406.88 781.301,1406.88 781.31,1406.88 781.32,1406.88 781.329,1406.88 781.338,1406.88 781.347,1406.88 781.356,1406.88 781.366,1406.88 781.375,1406.88 781.384,1406.88 781.393,1406.88 781.402,1406.88 781.412,1406.88 781.421,1406.88 781.43,1406.88 781.439,1406.88 781.448,1406.88 781.457,1406.88 781.467,1406.88 781.476,1406.88 781.485,1406.88 781.494,1406.88 781.503,1406.88 781.513,1406.88 781.522,1406.88 781.531,1406.88 781.54,1406.88 781.549,1406.88 781.559,1406.88 781.568,1406.88 781.577,1406.88 781.586,1406.88 781.595,1406.88 781.605,1406.88 781.614,1406.88 781.623,1406.88 781.632,1406.88 781.641,1406.88 781.65,1406.88 781.66,1406.88 781.669,1406.88 781.678,1406.88 781.687,1406.88 781.696,1406.88 781.706,1406.88 781.715,1406.88 781.724,1406.88 781.733,1406.88 781.742,1406.88 781.752,1406.88 781.761,1406.88 781.77,1406.88 781.779,1406.88 781.788,1406.88 781.797,1406.88 781.807,1406.88 781.816,1406.88 781.825,1406.88 781.834,1406.88 781.843,1406.88 781.853,1406.88 781.862,1406.88 781.871,1406.88 781.88,1406.88 781.889,1406.88 781.899,1406.88 781.908,1406.88 781.917,1406.88 781.926,1406.88 781.935,1406.88 781.945,1406.88 781.954,1406.88 781.963,1406.88 781.972,1406.88 781.981,1406.88 781.99,1406.88 782,1406.88 782.009,1406.88 782.018,1406.88 782.027,1406.88 782.036,1406.88 782.046,1406.88 782.055,1406.88 782.064,1406.88 782.073,1406.88 782.082,1406.88 782.092,1406.88 782.101,1406.88 782.11,1406.88 782.119,1406.88 782.128,1406.88 782.137,1406.88 782.147,1406.88 782.156,1406.88 782.165,1406.88 782.174,1406.88 782.183,1406.88 782.193,1406.88 782.202,1406.88 782.211,1406.88 782.22,1406.88 782.229,1406.88 782.239,1406.88 782.248,1406.88 782.257,1406.88 782.266,1406.88 782.275,1406.88 782.285,1406.88 782.294,1406.88 782.303,1406.88 782.312,1406.88 782.321,1406.88 782.33,1406.88 782.34,1406.88 782.349,1406.88 782.358,1406.88 782.367,1406.88 782.376,1406.88 782.386,1406.88 782.395,1406.88 782.404,1406.88 782.413,1406.88 782.422,1406.88 782.432,1406.88 782.441,1406.88 782.45,1406.88 782.459,1406.88 782.468,1406.88 782.477,1406.88 782.487,1406.88 782.496,1406.88 782.505,1406.88 782.514,1406.88 782.523,1406.88 782.533,1406.88 782.542,1406.88 782.551,1406.88 782.56,1406.88 782.569,1406.88 782.579,1406.88 782.588,1406.88 782.597,1406.88 782.606,1406.88 782.615,1406.88 782.625,1406.88 782.634,1406.88 782.643,1406.88 782.652,1406.88 782.661,1406.88 782.67,1406.88 782.68,1406.88 782.689,1406.88 782.698,1406.88 782.707,1406.88 782.716,1406.88 782.726,1406.88 782.735,1406.88 782.744,1406.88 782.753,1406.88 782.762,1406.88 782.772,1406.88 782.781,1406.88 782.79,1406.88 782.799,1406.88 782.808,1406.88 782.818,1406.88 782.827,1406.88 782.836,1406.88 782.845,1406.88 782.854,1406.88 782.863,1406.88 782.873,1406.88 782.882,1406.88 782.891,1406.88 782.9,1406.88 782.909,1406.88 782.919,1406.88 782.928,1406.88 782.937,1406.88 782.946,1406.88 782.955,1406.88 782.965,1406.88 782.974,1406.88 782.983,1406.88 782.992,1406.88 783.001,1406.88 783.01,1406.88 783.02,1406.88 783.029,1406.88 783.038,1406.88 783.047,1406.88 783.056,1406.88 783.066,1406.88 783.075,1406.88 783.084,1406.88 783.093,1406.88 783.102,1406.88 783.112,1406.88 783.121,1406.88 783.13,1406.88 783.139,1406.88 783.148,1406.88 783.158,1406.88 783.167,1406.88 783.176,1406.88 783.185,1406.88 783.194,1406.88 783.203,1406.88 783.213,1406.88 783.222,1406.88 783.231,1406.88 783.24,1406.88 783.249,1406.88 783.259,1406.88 783.268,1406.88 783.277,1406.88 783.286,1406.88 783.295,1406.88 783.305,1406.88 783.314,1406.88 783.323,1406.88 783.332,1406.88 783.341,1406.88 783.35,1406.88 783.36,1406.88 783.369,1406.88 783.378,1406.88 783.387,1406.88 783.396,1406.88 783.406,1406.88 783.415,1406.88 783.424,1406.88 783.433,1406.88 783.442,1406.88 783.452,1406.88 783.461,1406.88 783.47,1406.88 783.479,1406.88 783.488,1406.88 783.498,1406.88 783.507,1406.88 783.516,1406.88 783.525,1406.88 783.534,1406.88 783.543,1406.88 783.553,1406.88 783.562,1406.88 783.571,1406.88 783.58,1406.88 783.589,1406.88 783.599,1406.88 783.608,1406.88 783.617,1406.88 783.626,1406.88 783.635,1406.88 783.645,1406.88 783.654,1406.88 783.663,1406.88 783.672,1406.88 783.681,1406.88 783.69,1406.88 783.7,1406.88 783.709,1406.88 783.718,1406.88 783.727,1406.88 783.736,1406.88 783.746,1406.88 783.755,1406.88 783.764,1406.88 783.773,1406.88 783.782,1406.88 783.792,1406.88 783.801,1406.88 783.81,1406.88 783.819,1406.88 783.828,1406.88 783.838,1406.88 783.847,1406.88 783.856,1406.88 783.865,1406.88 783.874,1406.88 783.883,1406.88 783.893,1406.88 783.902,1406.88 783.911,1406.88 783.92,1406.88 783.929,1406.88 783.939,1406.88 783.948,1406.88 783.957,1406.88 783.966,1406.88 783.975,1406.88 783.985,1406.88 783.994,1406.88 784.003,1406.88 784.012,1406.88 784.021,1406.88 784.03,1406.88 784.04,1406.88 784.049,1406.88 784.058,1406.88 784.067,1406.88 784.076,1406.88 784.086,1406.88 784.095,1406.88 784.104,1406.88 784.113,1406.88 784.122,1406.88 784.132,1406.88 784.141,1406.88 784.15,1406.88 784.159,1406.88 784.168,1406.88 784.178,1406.88 784.187,1406.88 784.196,1406.88 784.205,1406.88 784.214,1406.88 784.223,1406.88 784.233,1406.88 784.242,1406.88 784.251,1406.88 784.26,1406.88 784.269,1406.88 784.279,1406.88 784.288,1406.88 784.297,1406.88 784.306,1406.88 784.315,1406.88 784.325,1406.88 784.334,1406.88 784.343,1406.88 784.352,1406.88 784.361,1406.88 784.37,1406.88 784.38,1406.88 784.389,1406.88 784.398,1406.88 784.407,1406.88 784.416,1406.88 784.426,1406.88 784.435,1406.88 784.444,1406.88 784.453,1406.88 784.462,1406.88 784.472,1406.88 784.481,1406.88 784.49,1406.88 784.499,1406.88 784.508,1406.88 784.518,1406.88 784.527,1406.88 784.536,1406.88 784.545,1406.88 784.554,1406.88 784.563,1406.88 784.573,1406.88 784.582,1406.88 784.591,1406.88 784.6,1406.88 784.609,1406.88 784.619,1406.88 784.628,1406.88 784.637,1406.88 784.646,1406.88 784.655,1406.88 784.665,1406.88 784.674,1406.88 784.683,1406.88 784.692,1406.88 784.701,1406.88 784.71,1406.88 784.72,1406.88 784.729,1406.88 784.738,1406.88 784.747,1406.88 784.756,1406.88 784.766,1406.88 784.775,1406.88 784.784,1406.88 784.793,1406.88 784.802,1406.88 784.812,1406.88 784.821,1406.88 784.83,1406.88 784.839,1406.88 784.848,1406.88 784.858,1406.88 784.867,1406.88 784.876,1406.88 784.885,1406.88 784.894,1406.88 784.903,1406.88 784.913,1406.88 784.922,1406.88 784.931,1406.88 784.94,1406.88 784.949,1406.88 784.959,1406.88 784.968,1406.88 784.977,1406.88 784.986,1406.88 784.995,1406.88 785.005,1406.88 785.014,1406.88 785.023,1406.88 785.032,1406.88 785.041,1406.88 785.051,1406.88 785.06,1406.88 785.069,1406.88 785.078,1406.88 785.087,1406.88 785.096,1406.88 785.106,1406.88 785.115,1406.88 785.124,1406.88 785.133,1406.88 785.142,1406.88 785.152,1406.88 785.161,1406.88 785.17,1406.88 785.179,1406.88 785.188,1406.88 785.198,1406.88 785.207,1406.88 785.216,1406.88 785.225,1406.88 785.234,1406.88 785.243,1406.88 785.253,1406.88 785.262,1406.88 785.271,1406.88 785.28,1406.88 785.289,1406.88 785.299,1406.88 785.308,1406.88 785.317,1406.88 785.326,1406.88 785.335,1406.88 785.345,1406.88 785.354,1406.88 785.363,1406.88 785.372,1406.88 785.381,1406.88 785.391,1406.88 785.4,1406.88 785.409,1406.88 785.418,1406.88 785.427,1406.88 785.436,1406.88 785.446,1406.88 785.455,1406.88 785.464,1406.88 785.473,1406.88 785.482,1406.88 785.492,1406.88 785.501,1406.88 785.51,1406.88 785.519,1406.88 785.528,1406.88 785.538,1406.88 785.547,1406.88 785.556,1406.88 785.565,1406.88 785.574,1406.88 785.583,1406.88 785.593,1406.88 785.602,1406.88 785.611,1406.88 785.62,1406.88 785.629,1406.88 785.639,1406.88 785.648,1406.88 785.657,1406.88 785.666,1406.88 785.675,1406.88 785.685,1406.88 785.694,1406.88 785.703,1406.88 785.712,1406.88 785.721,1406.88 785.731,1406.88 785.74,1406.88 785.749,1406.88 785.758,1406.88 785.767,1406.88 785.776,1406.88 785.786,1406.88 785.795,1406.88 785.804,1406.88 785.813,1406.88 785.822,1406.88 785.832,1406.88 785.841,1406.88 785.85,1406.88 785.859,1406.88 785.868,1406.88 785.878,1406.88 785.887,1406.88 785.896,1406.88 785.905,1406.88 785.914,1406.88 785.923,1406.88 785.933,1406.88 785.942,1406.88 785.951,1406.88 785.96,1406.88 785.969,1406.88 785.979,1406.88 785.988,1406.88 785.997,1406.88 786.006,1406.88 786.015,1406.88 786.025,1406.88 786.034,1406.88 786.043,1406.88 786.052,1406.88 786.061,1406.88 786.071,1406.88 786.08,1406.88 786.089,1406.88 786.098,1406.88 786.107,1406.88 786.116,1406.88 786.126,1406.88 786.135,1406.88 786.144,1406.88 786.153,1406.88 786.162,1406.88 786.172,1406.88 786.181,1406.88 786.19,1406.88 786.199,1406.88 786.208,1406.88 786.218,1406.88 786.227,1406.88 786.236,1406.88 786.245,1406.88 786.254,1406.88 786.263,1406.88 786.273,1406.88 786.282,1406.88 786.291,1406.88 786.3,1406.88 786.309,1406.88 786.319,1406.88 786.328,1406.88 786.337,1406.88 786.346,1406.88 786.355,1406.88 786.365,1406.88 786.374,1406.88 786.383,1406.88 786.392,1406.88 786.401,1406.88 786.411,1406.88 786.42,1406.88 786.429,1406.88 786.438,1406.88 786.447,1406.88 786.456,1406.88 786.466,1406.88 786.475,1406.88 786.484,1406.88 786.493,1406.88 786.502,1406.88 786.512,1406.88 786.521,1406.88 786.53,1406.88 786.539,1406.88 786.548,1406.88 786.558,1406.88 786.567,1406.88 786.576,1406.88 786.585,1406.88 786.594,1406.88 786.603,1406.88 786.613,1406.88 786.622,1406.88 786.631,1406.88 786.64,1406.88 786.649,1406.88 786.659,1406.88 786.668,1406.88 786.677,1406.88 786.686,1406.88 786.695,1406.88 786.705,1406.88 786.714,1406.88 786.723,1406.88 786.732,1406.88 786.741,1406.88 786.751,1406.88 786.76,1406.88 786.769,1406.88 786.778,1406.88 786.787,1406.88 786.796,1406.88 786.806,1406.88 786.815,1406.88 786.824,1406.88 786.833,1406.88 786.842,1406.88 786.852,1406.88 786.861,1406.88 786.87,1406.88 786.879,1406.88 786.888,1406.88 786.898,1406.88 786.907,1406.88 786.916,1406.88 786.925,1406.88 786.934,1406.88 786.943,1406.88 786.953,1406.88 786.962,1406.88 786.971,1406.88 786.98,1406.88 786.989,1406.88 786.999,1406.88 787.008,1406.88 787.017,1406.88 787.026,1406.88 787.035,1406.88 787.045,1406.88 787.054,1406.88 787.063,1406.88 787.072,1406.88 787.081,1406.88 787.091,1406.88 787.1,1406.88 787.109,1406.88 787.118,1406.88 787.127,1406.88 787.136,1406.88 787.146,1406.88 787.155,1406.88 787.164,1406.88 787.173,1406.88 787.182,1406.88 787.192,1406.88 787.201,1406.88 787.21,1406.88 787.219,1406.88 787.228,1406.88 787.238,1406.88 787.247,1406.88 787.256,1406.88 787.265,1406.88 787.274,1406.88 787.283,1406.88 787.293,1406.88 787.302,1406.88 787.311,1406.88 787.32,1406.88 787.329,1406.88 787.339,1406.88 787.348,1406.88 787.357,1406.88 787.366,1406.88 787.375,1406.88 787.385,1406.88 787.394,1406.88 787.403,1406.88 787.412,1406.88 787.421,1406.88 787.431,1406.88 787.44,1406.88 787.449,1406.88 787.458,1406.88 787.467,1406.88 787.476,1406.88 787.486,1406.88 787.495,1406.88 787.504,1406.88 787.513,1406.88 787.522,1406.88 787.532,1406.88 787.541,1406.88 787.55,1406.88 787.559,1406.88 787.568,1406.88 787.578,1406.88 787.587,1406.88 787.596,1406.88 787.605,1406.88 787.614,1406.88 787.624,1406.88 787.633,1406.88 787.642,1406.88 787.651,1406.88 787.66,1406.88 787.669,1406.88 787.679,1406.88 787.688,1406.88 787.697,1406.88 787.706,1406.88 787.715,1406.88 787.725,1406.88 787.734,1406.88 787.743,1406.88 787.752,1406.88 787.761,1406.88 787.771,1406.88 787.78,1406.88 787.789,1406.88 787.798,1406.88 787.807,1406.88 787.816,1406.88 787.826,1406.88 787.835,1406.88 787.844,1406.88 787.853,1406.88 787.862,1406.88 787.872,1406.88 787.881,1406.88 787.89,1406.88 787.899,1406.88 787.908,1406.88 787.918,1406.88 787.927,1406.88 787.936,1406.88 787.945,1406.88 787.954,1406.88 787.964,1406.88 787.973,1406.88 787.982,1406.88 787.991,1406.88 788,1406.88 788.009,1406.88 788.019,1406.88 788.028,1406.88 788.037,1406.88 788.046,1406.88 788.055,1406.88 788.065,1406.88 788.074,1406.88 788.083,1406.88 788.092,1406.88 788.101,1406.88 788.111,1406.88 788.12,1406.88 788.129,1406.88 788.138,1406.88 788.147,1406.88 788.156,1406.88 788.166,1406.88 788.175,1406.88 788.184,1406.88 788.193,1406.88 788.202,1406.88 788.212,1406.88 788.221,1406.88 788.23,1406.88 788.239,1406.88 788.248,1406.88 788.258,1406.88 788.267,1406.88 788.276,1406.88 788.285,1406.88 788.294,1406.88 788.304,1406.88 788.313,1406.88 788.322,1406.88 788.331,1406.88 788.34,1406.88 788.349,1406.88 788.359,1406.88 788.368,1406.88 788.377,1406.88 788.386,1406.88 788.395,1406.88 788.405,1406.88 788.414,1406.88 788.423,1406.88 788.432,1406.88 788.441,1406.88 788.451,1406.88 788.46,1406.88 788.469,1406.88 788.478,1406.88 788.487,1406.88 788.496,1406.88 788.506,1406.88 788.515,1406.88 788.524,1406.88 788.533,1406.88 788.542,1406.88 788.552,1406.88 788.561,1406.88 788.57,1406.88 788.579,1406.88 788.588,1406.88 788.598,1406.88 788.607,1406.88 788.616,1406.88 788.625,1406.88 788.634,1406.88 788.644,1406.88 788.653,1406.88 788.662,1406.88 788.671,1406.88 788.68,1406.88 788.689,1406.88 788.699,1406.88 788.708,1406.88 788.717,1406.88 788.726,1406.88 788.735,1406.88 788.745,1406.88 788.754,1406.88 788.763,1406.88 788.772,1406.88 788.781,1406.88 788.791,1406.88 788.8,1406.88 788.809,1406.88 788.818,1406.88 788.827,1406.88 788.836,1406.88 788.846,1406.88 788.855,1406.88 788.864,1406.88 788.873,1406.88 788.882,1406.88 788.892,1406.88 788.901,1406.88 788.91,1406.88 788.919,1406.88 788.928,1406.88 788.938,1406.88 788.947,1406.88 788.956,1406.88 788.965,1406.88 788.974,1406.88 788.984,1406.88 788.993,1406.88 789.002,1406.88 789.011,1406.88 789.02,1406.88 789.029,1406.88 789.039,1406.88 789.048,1406.88 789.057,1406.88 789.066,1406.88 789.075,1406.88 789.085,1406.88 789.094,1406.88 789.103,1406.88 789.112,1406.88 789.121,1406.88 789.131,1406.88 789.14,1406.88 789.149,1406.88 789.158,1406.88 789.167,1406.88 789.176,1406.88 789.186,1406.88 789.195,1406.88 789.204,1406.88 789.213,1406.88 789.222,1406.88 789.232,1406.88 789.241,1406.88 789.25,1406.88 789.259,1406.88 789.268,1406.88 789.278,1406.88 789.287,1406.88 789.296,1406.88 789.305,1406.88 789.314,1406.88 789.324,1406.88 789.333,1406.88 789.342,1406.88 789.351,1406.88 789.36,1406.88 789.369,1406.88 789.379,1406.88 789.388,1406.88 789.397,1406.88 789.406,1406.88 789.415,1406.88 789.425,1406.88 789.434,1406.88 789.443,1406.88 789.452,1406.88 789.461,1406.88 789.471,1406.88 789.48,1406.88 789.489,1406.88 789.498,1406.88 789.507,1406.88 789.516,1406.88 789.526,1406.88 789.535,1406.88 789.544,1406.88 789.553,1406.88 789.562,1406.88 789.572,1406.88 789.581,1406.88 789.59,1406.88 789.599,1406.88 789.608,1406.88 789.618,1406.88 789.627,1406.88 789.636,1406.88 789.645,1406.88 789.654,1406.88 789.664,1406.88 789.673,1406.88 789.682,1406.88 789.691,1406.88 789.7,1406.88 789.709,1406.88 789.719,1406.88 789.728,1406.88 789.737,1406.88 789.746,1406.88 789.755,1406.88 789.765,1406.88 789.774,1406.88 789.783,1406.88 789.792,1406.88 789.801,1406.88 789.811,1406.88 789.82,1406.88 789.829,1406.88 789.838,1406.88 789.847,1406.88 789.856,1406.88 789.866,1406.88 789.875,1406.88 789.884,1406.88 789.893,1406.88 789.902,1406.88 789.912,1406.88 789.921,1406.88 789.93,1406.88 789.939,1406.88 789.948,1406.88 789.958,1406.88 789.967,1406.88 789.976,1406.88 789.985,1406.88 789.994,1406.88 790.004,1406.88 790.013,1406.88 790.022,1406.88 790.031,1406.88 790.04,1406.88 790.049,1406.88 790.059,1406.88 790.068,1406.88 790.077,1406.88 790.086,1406.88 790.095,1406.88 790.105,1406.88 790.114,1406.88 790.123,1406.88 790.132,1406.88 790.141,1406.88 790.151,1406.88 790.16,1406.88 790.169,1406.88 790.178,1406.88 790.187,1406.88 790.197,1406.88 790.206,1406.88 790.215,1406.88 790.224,1406.88 790.233,1406.88 790.242,1406.88 790.252,1406.88 790.261,1406.88 790.27,1406.88 790.279,1406.88 790.288,1406.88 790.298,1406.88 790.307,1406.88 790.316,1406.88 790.325,1406.88 790.334,1406.88 790.344,1406.88 790.353,1406.88 790.362,1406.88 790.371,1406.88 790.38,1406.88 790.389,1406.88 790.399,1406.88 790.408,1406.88 790.417,1406.88 790.426,1406.88 790.435,1406.88 790.445,1406.88 790.454,1406.88 790.463,1406.88 790.472,1406.88 790.481,1406.88 790.491,1406.88 790.5,1406.88 790.509,1406.88 790.518,1406.88 790.527,1406.88 790.537,1406.88 790.546,1406.88 790.555,1406.88 790.564,1406.88 790.573,1406.88 790.582,1406.88 790.592,1406.88 790.601,1406.88 790.61,1406.88 790.619,1406.88 790.628,1406.88 790.638,1406.88 790.647,1406.88 790.656,1406.88 790.665,1406.88 790.674,1406.88 790.684,1406.88 790.693,1406.88 790.702,1406.88 790.711,1406.88 790.72,1406.88 790.729,1406.88 790.739,1406.88 790.748,1406.88 790.757,1406.88 790.766,1406.88 790.775,1406.88 790.785,1406.88 790.794,1406.88 790.803,1406.88 790.812,1406.88 790.821,1406.88 790.831,1406.88 790.84,1406.88 790.849,1406.88 790.858,1406.88 790.867,1406.88 790.877,1406.88 790.886,1406.88 790.895,1406.88 790.904,1406.88 790.913,1406.88 790.922,1406.88 790.932,1406.88 790.941,1406.88 790.95,1406.88 790.959,1406.88 790.968,1406.88 790.978,1406.88 790.987,1406.88 790.996,1406.88 791.005,1406.88 791.014,1406.88 791.024,1406.88 791.033,1406.88 791.042,1406.88 791.051,1406.88 791.06,1406.88 791.069,1406.88 791.079,1406.88 791.088,1406.88 791.097,1406.88 791.106,1406.88 791.115,1406.88 791.125,1406.88 791.134,1406.88 791.143,1406.88 791.152,1406.88 791.161,1406.88 791.171,1406.88 791.18,1406.88 791.189,1406.88 791.198,1406.88 791.207,1406.88 791.217,1406.88 791.226,1406.88 791.235,1406.88 791.244,1406.88 791.253,1406.88 791.262,1406.88 791.272,1406.88 791.281,1406.88 791.29,1406.88 791.299,1406.88 791.308,1406.88 791.318,1406.88 791.327,1406.88 791.336,1406.88 791.345,1406.88 791.354,1406.88 791.364,1406.88 791.373,1406.88 791.382,1406.88 791.391,1406.88 791.4,1406.88 791.409,1406.88 791.419,1406.88 791.428,1406.88 791.437,1406.88 791.446,1406.88 791.455,1406.88 791.465,1406.88 791.474,1406.88 791.483,1406.88 791.492,1406.88 791.501,1406.88 791.511,1406.88 791.52,1406.88 791.529,1406.88 791.538,1406.88 791.547,1406.88 791.557,1406.88 791.566,1406.88 791.575,1406.88 791.584,1406.88 791.593,1406.88 791.602,1406.88 791.612,1406.88 791.621,1406.88 791.63,1406.88 791.639,1406.88 791.648,1406.88 791.658,1406.88 791.667,1406.88 791.676,1406.88 791.685,1406.88 791.694,1406.88 791.704,1406.88 791.713,1406.88 791.722,1406.88 791.731,1406.88 791.74,1406.88 791.749,1406.88 791.759,1406.88 791.768,1406.88 791.777,1406.88 791.786,1406.88 791.795,1406.88 791.805,1406.88 791.814,1406.88 791.823,1406.88 791.832,1406.88 791.841,1406.88 791.851,1406.88 791.86,1406.88 791.869,1406.88 791.878,1406.88 791.887,1406.88 791.897,1406.88 791.906,1406.88 791.915,1406.88 791.924,1406.88 791.933,1406.88 791.942,1406.88 791.952,1406.88 791.961,1406.88 791.97,1406.88 791.979,1406.88 791.988,1406.88 791.998,1406.88 792.007,1406.88 792.016,1406.88 792.025,1406.88 792.034,1406.88 792.044,1406.88 792.053,1406.88 792.062,1406.88 792.071,1406.88 792.08,1406.88 792.089,1406.88 792.099,1406.88 792.108,1406.88 792.117,1406.88 792.126,1406.88 792.135,1406.88 792.145,1406.88 792.154,1406.88 792.163,1406.88 792.172,1406.88 792.181,1406.88 792.191,1406.88 792.2,1406.88 792.209,1406.88 792.218,1406.88 792.227,1406.88 792.237,1406.88 792.246,1406.88 792.255,1406.88 792.264,1406.88 792.273,1406.88 792.282,1406.88 792.292,1406.88 792.301,1406.88 792.31,1406.88 792.319,1406.88 792.328,1406.88 792.338,1406.88 792.347,1406.88 792.356,1406.88 792.365,1406.88 792.374,1406.88 792.384,1406.88 792.393,1406.88 792.402,1406.88 792.411,1406.88 792.42,1406.88 792.43,1406.88 792.439,1406.88 792.448,1406.88 792.457,1406.88 792.466,1406.88 792.475,1406.88 792.485,1406.88 792.494,1406.88 792.503,1406.88 792.512,1406.88 792.521,1406.88 792.531,1406.88 792.54,1406.88 792.549,1406.88 792.558,1406.88 792.567,1406.88 792.577,1406.88 792.586,1406.88 792.595,1406.88 792.604,1406.88 792.613,1406.88 792.622,1406.88 792.632,1406.88 792.641,1406.88 792.65,1406.88 792.659,1406.88 792.668,1406.88 792.678,1406.88 792.687,1406.88 792.696,1406.88 792.705,1406.88 792.714,1406.88 792.724,1406.88 792.733,1406.88 792.742,1406.88 792.751,1406.88 792.76,1406.88 792.77,1406.88 792.779,1406.88 792.788,1406.88 792.797,1406.88 792.806,1406.88 792.815,1406.88 792.825,1406.88 792.834,1406.88 792.843,1406.88 792.852,1406.88 792.861,1406.88 792.871,1406.88 792.88,1406.88 792.889,1406.88 792.898,1406.88 792.907,1406.88 792.917,1406.88 792.926,1406.88 792.935,1406.88 792.944,1406.88 792.953,1406.88 792.962,1406.88 792.972,1406.88 792.981,1406.88 792.99,1406.88 792.999,1406.88 793.008,1406.88 793.018,1406.88 793.027,1406.88 793.036,1406.88 793.045,1406.88 793.054,1406.88 793.064,1406.88 793.073,1406.88 793.082,1406.88 793.091,1406.88 793.1,1406.88 793.11,1406.88 793.119,1406.88 793.128,1406.88 793.137,1406.88 793.146,1406.88 793.155,1406.88 793.165,1406.88 793.174,1406.88 793.183,1406.88 793.192,1406.88 793.201,1406.88 793.211,1406.88 793.22,1406.88 793.229,1406.88 793.238,1406.88 793.247,1406.88 793.257,1406.88 793.266,1406.88 793.275,1406.88 793.284,1406.88 793.293,1406.88 793.302,1406.88 793.312,1406.88 793.321,1406.88 793.33,1406.88 793.339,1406.88 793.348,1406.88 793.358,1406.88 793.367,1406.88 793.376,1406.88 793.385,1406.88 793.394,1406.88 793.404,1406.88 793.413,1406.88 793.422,1406.88 793.431,1406.88 793.44,1406.88 793.45,1406.88 793.459,1406.88 793.468,1406.88 793.477,1406.88 793.486,1406.88 793.495,1406.88 793.505,1406.88 793.514,1406.88 793.523,1406.88 793.532,1406.88 793.541,1406.88 793.551,1406.88 793.56,1406.88 793.569,1406.88 793.578,1406.88 793.587,1406.88 793.597,1406.88 793.606,1406.88 793.615,1406.88 793.624,1406.88 793.633,1406.88 793.642,1406.88 793.652,1406.88 793.661,1406.88 793.67,1406.88 793.679,1406.88 793.688,1406.88 793.698,1406.88 793.707,1406.88 793.716,1406.88 793.725,1406.88 793.734,1406.88 793.744,1406.88 793.753,1406.88 793.762,1406.88 793.771,1406.88 793.78,1406.88 793.79,1406.88 793.799,1406.88 793.808,1406.88 793.817,1406.88 793.826,1406.88 793.835,1406.88 793.845,1406.88 793.854,1406.88 793.863,1406.88 793.872,1406.88 793.881,1406.88 793.891,1406.88 793.9,1406.88 793.909,1406.88 793.918,1406.88 793.927,1406.88 793.937,1406.88 793.946,1406.88 793.955,1406.88 793.964,1406.88 793.973,1406.88 793.982,1406.88 793.992,1406.88 794.001,1406.88 794.01,1406.88 794.019,1406.88 794.028,1406.88 794.038,1406.88 794.047,1406.88 794.056,1406.88 794.065,1406.88 794.074,1406.88 794.084,1406.88 794.093,1406.88 794.102,1406.88 794.111,1406.88 794.12,1406.88 794.13,1406.88 794.139,1406.88 794.148,1406.88 794.157,1406.88 794.166,1406.88 794.175,1406.88 794.185,1406.88 794.194,1406.88 794.203,1406.88 794.212,1406.88 794.221,1406.88 794.231,1406.88 794.24,1406.88 794.249,1406.88 794.258,1406.88 794.267,1406.88 794.277,1406.88 794.286,1406.88 794.295,1406.88 794.304,1406.88 794.313,1406.88 794.322,1406.88 794.332,1406.88 794.341,1406.88 794.35,1406.88 794.359,1406.88 794.368,1406.88 794.378,1406.88 794.387,1406.88 794.396,1406.88 794.405,1406.88 794.414,1406.88 794.424,1406.88 794.433,1406.88 794.442,1406.88 794.451,1406.88 794.46,1406.88 794.47,1406.88 794.479,1406.88 794.488,1406.88 794.497,1406.88 794.506,1406.88 794.515,1406.88 794.525,1406.88 794.534,1406.88 794.543,1406.88 794.552,1406.88 794.561,1406.88 794.571,1406.88 794.58,1406.88 794.589,1406.88 794.598,1406.88 794.607,1406.88 794.617,1406.88 794.626,1406.88 794.635,1406.88 794.644,1406.88 794.653,1406.88 794.662,1406.88 794.672,1406.88 794.681,1406.88 794.69,1406.88 794.699,1406.88 794.708,1406.88 794.718,1406.88 794.727,1406.88 794.736,1406.88 794.745,1406.88 794.754,1406.88 794.764,1406.88 794.773,1406.88 794.782,1406.88 794.791,1406.88 794.8,1406.88 794.81,1406.88 794.819,1406.88 794.828,1406.88 794.837,1406.88 794.846,1406.88 794.855,1406.88 794.865,1406.88 794.874,1406.88 794.883,1406.88 794.892,1406.88 794.901,1406.88 794.911,1406.88 794.92,1406.88 794.929,1406.88 794.938,1406.88 794.947,1406.88 794.957,1406.88 794.966,1406.88 794.975,1406.88 794.984,1406.88 794.993,1406.88 795.003,1406.88 795.012,1406.88 795.021,1406.88 795.03,1406.88 795.039,1406.88 795.048,1406.88 795.058,1406.88 795.067,1406.88 795.076,1406.88 795.085,1406.88 795.094,1406.88 795.104,1406.88 795.113,1406.88 795.122,1406.88 795.131,1406.88 795.14,1406.88 795.15,1406.88 795.159,1406.88 795.168,1406.88 795.177,1406.88 795.186,1406.88 795.195,1406.88 795.205,1406.88 795.214,1406.88 795.223,1406.88 795.232,1406.88 795.241,1406.88 795.251,1406.88 795.26,1406.88 795.269,1406.88 795.278,1406.88 795.287,1406.88 795.297,1406.88 795.306,1406.88 795.315,1406.88 795.324,1406.88 795.333,1406.88 795.343,1406.88 795.352,1406.88 795.361,1406.88 795.37,1406.88 795.379,1406.88 795.388,1406.88 795.398,1406.88 795.407,1406.88 795.416,1406.88 795.425,1406.88 795.434,1406.88 795.444,1406.88 795.453,1406.88 795.462,1406.88 795.471,1406.88 795.48,1406.88 795.49,1406.88 795.499,1406.88 795.508,1406.88 795.517,1406.88 795.526,1406.88 795.535,1406.88 795.545,1406.88 795.554,1406.88 795.563,1406.88 795.572,1406.88 795.581,1406.88 795.591,1406.88 795.6,1406.88 795.609,1406.88 795.618,1406.88 795.627,1406.88 795.637,1406.88 795.646,1406.88 795.655,1406.88 795.664,1406.88 795.673,1406.88 795.683,1406.88 795.692,1406.88 795.701,1406.88 795.71,1406.88 795.719,1406.88 795.728,1406.88 795.738,1406.88 795.747,1406.88 795.756,1406.88 795.765,1406.88 795.774,1406.88 795.784,1406.88 795.793,1406.88 795.802,1406.88 795.811,1406.88 795.82,1406.88 795.83,1406.88 795.839,1406.88 795.848,1406.88 795.857,1406.88 795.866,1406.88 795.875,1406.88 795.885,1406.88 795.894,1406.88 795.903,1406.88 795.912,1406.88 795.921,1406.88 795.931,1406.88 795.94,1406.88 795.949,1406.88 795.958,1406.88 795.967,1406.88 795.977,1406.88 795.986,1406.88 795.995,1406.88 796.004,1406.88 796.013,1406.88 796.023,1406.88 796.032,1406.88 796.041,1406.88 796.05,1406.88 796.059,1406.88 796.068,1406.88 796.078,1406.88 796.087,1406.88 796.096,1406.88 796.105,1406.88 796.114,1406.88 796.124,1406.88 796.133,1406.88 796.142,1406.88 796.151,1406.88 796.16,1406.88 796.17,1406.88 796.179,1406.88 796.188,1406.88 796.197,1406.88 796.206,1406.88 796.215,1406.88 796.225,1406.88 796.234,1406.88 796.243,1406.88 796.252,1406.88 796.261,1406.88 796.271,1406.88 796.28,1406.88 796.289,1406.88 796.298,1406.88 796.307,1406.88 796.317,1406.88 796.326,1406.88 796.335,1406.88 796.344,1406.88 796.353,1406.88 796.363,1406.88 796.372,1406.88 796.381,1406.88 796.39,1406.88 796.399,1406.88 796.408,1406.88 796.418,1406.88 796.427,1406.88 796.436,1406.88 796.445,1406.88 796.454,1406.88 796.464,1406.88 796.473,1406.88 796.482,1406.88 796.491,1406.88 796.5,1406.88 796.51,1406.88 796.519,1406.88 796.528,1406.88 796.537,1406.88 796.546,1406.88 796.555,1406.88 796.565,1406.88 796.574,1406.88 796.583,1406.88 796.592,1406.88 796.601,1406.88 796.611,1406.88 796.62,1406.88 796.629,1406.88 796.638,1406.88 796.647,1406.88 796.657,1406.88 796.666,1406.88 796.675,1406.88 796.684,1406.88 796.693,1406.88 796.703,1406.88 796.712,1406.88 796.721,1406.88 796.73,1406.88 796.739,1406.88 796.748,1406.88 796.758,1406.88 796.767,1406.88 796.776,1406.88 796.785,1406.88 796.794,1406.88 796.804,1406.88 796.813,1406.88 796.822,1406.88 796.831,1406.88 796.84,1406.88 796.85,1406.88 796.859,1406.88 796.868,1406.88 796.877,1406.88 796.886,1406.88 796.895,1406.88 796.905,1406.88 796.914,1406.88 796.923,1406.88 796.932,1406.88 796.941,1406.88 796.951,1406.88 796.96,1406.88 796.969,1406.88 796.978,1406.88 796.987,1406.88 796.997,1406.88 797.006,1406.88 797.015,1406.88 797.024,1406.88 797.033,1406.88 797.043,1406.88 797.052,1406.88 797.061,1406.88 797.07,1406.88 797.079,1406.88 797.088,1406.88 797.098,1406.88 797.107,1406.88 797.116,1406.88 797.125,1406.88 797.134,1406.88 797.144,1406.88 797.153,1406.88 797.162,1406.88 797.171,1406.88 797.18,1406.88 797.19,1406.88 797.199,1406.88 797.208,1406.88 797.217,1406.88 797.226,1406.88 797.235,1406.88 797.245,1406.88 797.254,1406.88 797.263,1406.88 797.272,1406.88 797.281,1406.88 797.291,1406.88 797.3,1406.88 797.309,1406.88 797.318,1406.88 797.327,1406.88 797.337,1406.88 797.346,1406.88 797.355,1406.88 797.364,1406.88 797.373,1406.88 797.383,1406.88 797.392,1406.88 797.401,1406.88 797.41,1406.88 797.419,1406.88 797.428,1406.88 797.438,1406.88 797.447,1406.88 797.456,1406.88 797.465,1406.88 797.474,1406.88 797.484,1406.88 797.493,1406.88 797.502,1406.88 797.511,1406.88 797.52,1406.88 797.53,1406.88 797.539,1406.88 797.548,1406.88 797.557,1406.88 797.566,1406.88 797.576,1406.88 797.585,1406.88 797.594,1406.88 797.603,1406.88 797.612,1406.88 797.621,1406.88 797.631,1406.88 797.64,1406.88 797.649,1406.88 797.658,1406.88 797.667,1406.88 797.677,1406.88 797.686,1406.88 797.695,1406.88 797.704,1406.88 797.713,1406.88 797.723,1406.88 797.732,1406.88 797.741,1406.88 797.75,1406.88 797.759,1406.88 797.768,1406.88 797.778,1406.88 797.787,1406.88 797.796,1406.88 797.805,1406.88 797.814,1406.88 797.824,1406.88 797.833,1406.88 797.842,1406.88 797.851,1406.88 797.86,1406.88 797.87,1406.88 797.879,1406.88 797.888,1406.88 797.897,1406.88 797.906,1406.88 797.916,1406.88 797.925,1406.88 797.934,1406.88 797.943,1406.88 797.952,1406.88 797.961,1406.88 797.971,1406.88 797.98,1406.88 797.989,1406.88 797.998,1406.88 798.007,1406.88 798.017,1406.88 798.026,1406.88 798.035,1406.88 798.044,1406.88 798.053,1406.88 798.063,1406.88 798.072,1406.88 798.081,1406.88 798.09,1406.88 798.099,1406.88 798.108,1406.88 798.118,1406.88 798.127,1406.88 798.136,1406.88 798.145,1406.88 798.154,1406.88 798.164,1406.88 798.173,1406.88 798.182,1406.88 798.191,1406.88 798.2,1406.88 798.21,1406.88 798.219,1406.88 798.228,1406.88 798.237,1406.88 798.246,1406.88 798.256,1406.88 798.265,1406.88 798.274,1406.88 798.283,1406.88 798.292,1406.88 798.301,1406.88 798.311,1406.88 798.32,1406.88 798.329,1406.88 798.338,1406.88 798.347,1406.88 798.357,1406.88 798.366,1406.88 798.375,1406.88 798.384,1406.88 798.393,1406.88 798.403,1406.88 798.412,1406.88 798.421,1406.88 798.43,1406.88 798.439,1406.88 798.448,1406.88 798.458,1406.88 798.467,1406.88 798.476,1406.88 798.485,1406.88 798.494,1406.88 798.504,1406.88 798.513,1406.88 798.522,1406.88 798.531,1406.88 798.54,1406.88 798.55,1406.88 798.559,1406.88 798.568,1406.88 798.577,1406.88 798.586,1406.88 798.596,1406.88 798.605,1406.88 798.614,1406.88 798.623,1406.88 798.632,1406.88 798.641,1406.88 798.651,1406.88 798.66,1406.88 798.669,1406.88 798.678,1406.88 798.687,1406.88 798.697,1406.88 798.706,1406.88 798.715,1406.88 798.724,1406.88 798.733,1406.88 798.743,1406.88 798.752,1406.88 798.761,1406.88 798.77,1406.88 798.779,1406.88 798.788,1406.88 798.798,1406.88 798.807,1406.88 798.816,1406.88 798.825,1406.88 798.834,1406.88 798.844,1406.88 798.853,1406.88 798.862,1406.88 798.871,1406.88 798.88,1406.88 798.89,1406.88 798.899,1406.88 798.908,1406.88 798.917,1406.88 798.926,1406.88 798.936,1406.88 798.945,1406.88 798.954,1406.88 798.963,1406.88 798.972,1406.88 798.981,1406.88 798.991,1406.88 799,1406.88 799.009,1406.88 799.018,1406.88 799.027,1406.88 799.037,1406.88 799.046,1406.88 799.055,1406.88 799.064,1406.88 799.073,1406.88 799.083,1406.88 799.092,1406.88 799.101,1406.88 799.11,1406.88 799.119,1406.88 799.128,1406.88 799.138,1406.88 799.147,1406.88 799.156,1406.88 799.165,1406.88 799.174,1406.88 799.184,1406.88 799.193,1406.88 799.202,1406.88 799.211,1406.88 799.22,1406.88 799.23,1406.88 799.239,1406.88 799.248,1406.88 799.257,1406.88 799.266,1406.88 799.276,1406.88 799.285,1406.88 799.294,1406.88 799.303,1406.88 799.312,1406.88 799.321,1406.88 799.331,1406.88 799.34,1406.88 799.349,1406.88 799.358,1406.88 799.367,1406.88 799.377,1406.88 799.386,1406.88 799.395,1406.88 799.404,1406.88 799.413,1406.88 799.423,1406.88 799.432,1406.88 799.441,1406.88 799.45,1406.88 799.459,1406.88 799.468,1406.88 799.478,1406.88 799.487,1406.88 799.496,1406.88 799.505,1406.88 799.514,1406.88 799.524,1406.88 799.533,1406.88 799.542,1406.88 799.551,1406.88 799.56,1406.88 799.57,1406.88 799.579,1406.88 799.588,1406.88 799.597,1406.88 799.606,1406.88 799.616,1406.88 799.625,1406.88 799.634,1406.88 799.643,1406.88 799.652,1406.88 799.661,1406.88 799.671,1406.88 799.68,1406.88 799.689,1406.88 799.698,1406.88 799.707,1406.88 799.717,1406.88 799.726,1406.88 799.735,1406.88 799.744,1406.88 799.753,1406.88 799.763,1406.88 799.772,1406.88 799.781,1406.88 799.79,1406.88 799.799,1406.88 799.809,1406.88 799.818,1406.88 799.827,1406.88 799.836,1406.88 799.845,1406.88 799.854,1406.88 799.864,1406.88 799.873,1406.88 799.882,1406.88 799.891,1406.88 799.9,1406.88 799.91,1406.88 799.919,1406.88 799.928,1406.88 799.937,1406.88 799.946,1406.88 799.956,1406.88 799.965,1406.88 799.974,1406.88 799.983,1406.88 799.992,1406.88 800.001,1406.88 800.011,1406.88 800.02,1406.88 800.029,1406.88 800.038,1406.88 800.047,1406.88 800.057,1406.88 800.066,1406.88 800.075,1406.88 800.084,1406.88 800.093,1406.88 800.103,1406.88 800.112,1406.88 800.121,1406.88 800.13,1406.88 800.139,1406.88 800.149,1406.88 800.158,1406.88 800.167,1406.88 800.176,1406.88 800.185,1406.88 800.194,1406.88 800.204,1406.88 800.213,1406.88 800.222,1406.88 800.231,1406.88 800.24,1406.88 800.25,1406.88 800.259,1406.88 800.268,1406.88 800.277,1406.88 800.286,1406.88 800.296,1406.88 800.305,1406.88 800.314,1406.88 800.323,1406.88 800.332,1406.88 800.341,1406.88 800.351,1406.88 800.36,1406.88 800.369,1406.88 800.378,1406.88 800.387,1406.88 800.397,1406.88 800.406,1406.88 800.415,1406.88 800.424,1406.88 800.433,1406.88 800.443,1406.88 800.452,1406.88 800.461,1406.88 800.47,1406.88 800.479,1406.88 800.489,1406.88 800.498,1406.88 800.507,1406.88 800.516,1406.88 800.525,1406.88 800.534,1406.88 800.544,1406.88 800.553,1406.88 800.562,1406.88 800.571,1406.88 800.58,1406.88 800.59,1406.88 800.599,1406.88 800.608,1406.88 800.617,1406.88 800.626,1406.88 800.636,1406.88 800.645,1406.88 800.654,1406.88 800.663,1406.88 800.672,1406.88 800.681,1406.88 800.691,1406.88 800.7,1406.88 800.709,1406.88 800.718,1406.88 800.727,1406.88 800.737,1406.88 800.746,1406.88 800.755,1406.88 800.764,1406.88 800.773,1406.88 800.783,1406.88 800.792,1406.88 800.801,1406.88 800.81,1406.88 800.819,1406.88 800.829,1406.88 800.838,1406.88 800.847,1406.88 800.856,1406.88 800.865,1406.88 800.874,1406.88 800.884,1406.88 800.893,1406.88 800.902,1406.88 800.911,1406.88 800.92,1406.88 800.93,1406.88 800.939,1406.88 800.948,1406.88 800.957,1406.88 800.966,1406.88 800.976,1406.88 800.985,1406.88 800.994,1406.88 801.003,1406.88 801.012,1406.88 801.021,1406.88 801.031,1406.88 801.04,1406.88 801.049,1406.88 801.058,1406.88 801.067,1406.88 801.077,1406.88 801.086,1406.88 801.095,1406.88 801.104,1406.88 801.113,1406.88 801.123,1406.88 801.132,1406.88 801.141,1406.88 801.15,1406.88 801.159,1406.88 801.169,1406.88 801.178,1406.88 801.187,1406.88 801.196,1406.88 801.205,1406.88 801.214,1406.88 801.224,1406.88 801.233,1406.88 801.242,1406.88 801.251,1406.88 801.26,1406.88 801.27,1406.88 801.279,1406.88 801.288,1406.88 801.297,1406.88 801.306,1406.88 801.316,1406.88 801.325,1406.88 801.334,1406.88 801.343,1406.88 801.352,1406.88 801.361,1406.88 801.371,1406.88 801.38,1406.88 801.389,1406.88 801.398,1406.88 801.407,1406.88 801.417,1406.88 801.426,1406.88 801.435,1406.88 801.444,1406.88 801.453,1406.88 801.463,1406.88 801.472,1406.88 801.481,1406.88 801.49,1406.88 801.499,1406.88 801.509,1406.88 801.518,1406.88 801.527,1406.88 801.536,1406.88 801.545,1406.88 801.554,1406.88 801.564,1406.88 801.573,1406.88 801.582,1406.88 801.591,1406.88 801.6,1406.88 801.61,1406.88 801.619,1406.88 801.628,1406.88 801.637,1406.88 801.646,1406.88 801.656,1406.88 801.665,1406.88 801.674,1406.88 801.683,1406.88 801.692,1406.88 801.701,1406.88 801.711,1406.88 801.72,1406.88 801.729,1406.88 801.738,1406.88 801.747,1406.88 801.757,1406.88 801.766,1406.88 801.775,1406.88 801.784,1406.88 801.793,1406.88 801.803,1406.88 801.812,1406.88 801.821,1406.88 801.83,1406.88 801.839,1406.88 801.849,1406.88 801.858,1406.88 801.867,1406.88 801.876,1406.88 801.885,1406.88 801.894,1406.88 801.904,1406.88 801.913,1406.88 801.922,1406.88 801.931,1406.88 801.94,1406.88 801.95,1406.88 801.959,1406.88 801.968,1406.88 801.977,1406.88 801.986,1406.88 801.996,1406.88 802.005,1406.88 802.014,1406.88 802.023,1406.88 802.032,1406.88 802.041,1406.88 802.051,1406.88 802.06,1406.88 802.069,1406.88 802.078,1406.88 802.087,1406.88 802.097,1406.88 802.106,1406.88 802.115,1406.88 802.124,1406.88 802.133,1406.88 802.143,1406.88 802.152,1406.88 802.161,1406.88 802.17,1406.88 802.179,1406.88 802.189,1406.88 802.198,1406.88 802.207,1406.88 802.216,1406.88 802.225,1406.88 802.234,1406.88 802.244,1406.88 802.253,1406.88 802.262,1406.88 802.271,1406.88 802.28,1406.88 802.29,1406.88 802.299,1406.88 802.308,1406.88 802.317,1406.88 802.326,1406.88 802.336,1406.88 802.345,1406.88 802.354,1406.88 802.363,1406.88 802.372,1406.88 802.382,1406.88 802.391,1406.88 802.4,1406.88 802.409,1406.88 802.418,1406.88 802.427,1406.88 802.437,1406.88 802.446,1406.88 802.455,1406.88 802.464,1406.88 802.473,1406.88 802.483,1406.88 802.492,1406.88 802.501,1406.88 802.51,1406.88 802.519,1406.88 802.529,1406.88 802.538,1406.88 802.547,1406.88 802.556,1406.88 802.565,1406.88 802.574,1406.88 802.584,1406.88 802.593,1406.88 802.602,1406.88 802.611,1406.88 802.62,1406.88 802.63,1406.88 802.639,1406.88 802.648,1406.88 802.657,1406.88 802.666,1406.88 802.676,1406.88 802.685,1406.88 802.694,1406.88 802.703,1406.88 802.712,1406.88 802.722,1406.88 802.731,1406.88 802.74,1406.88 802.749,1406.88 802.758,1406.88 802.767,1406.88 802.777,1406.88 802.786,1406.88 802.795,1406.88 802.804,1406.88 802.813,1406.88 802.823,1406.88 802.832,1406.88 802.841,1406.88 802.85,1406.88 802.859,1406.88 802.869,1406.88 802.878,1406.88 802.887,1406.88 802.896,1406.88 802.905,1406.88 802.914,1406.88 802.924,1406.88 802.933,1406.88 802.942,1406.88 802.951,1406.88 802.96,1406.88 802.97,1406.88 802.979,1406.88 802.988,1406.88 802.997,1406.88 803.006,1406.88 803.016,1406.88 803.025,1406.88 803.034,1406.88 803.043,1406.88 803.052,1406.88 803.062,1406.88 803.071,1406.88 803.08,1406.88 803.089,1406.88 803.098,1406.88 803.107,1406.88 803.117,1406.88 803.126,1406.88 803.135,1406.88 803.144,1406.88 803.153,1406.88 803.163,1406.88 803.172,1406.88 803.181,1406.88 803.19,1406.88 803.199,1406.88 803.209,1406.88 803.218,1406.88 803.227,1406.88 803.236,1406.88 803.245,1406.88 803.254,1406.88 803.264,1406.88 803.273,1406.88 803.282,1406.88 803.291,1406.88 803.3,1406.88 803.31,1406.88 803.319,1406.88 803.328,1406.88 803.337,1406.88 803.346,1406.88 803.356,1406.88 803.365,1406.88 803.374,1406.88 803.383,1406.88 803.392,1406.88 803.402,1406.88 803.411,1406.88 803.42,1406.88 803.429,1406.88 803.438,1406.88 803.447,1406.88 803.457,1406.88 803.466,1406.88 803.475,1406.88 803.484,1406.88 803.493,1406.88 803.503,1406.88 803.512,1406.88 803.521,1406.88 803.53,1406.88 803.539,1406.88 803.549,1406.88 803.558,1406.88 803.567,1406.88 803.576,1406.88 803.585,1406.88 803.594,1406.88 803.604,1406.88 803.613,1406.88 803.622,1406.88 803.631,1406.88 803.64,1406.88 803.65,1406.88 803.659,1406.88 803.668,1406.88 803.677,1406.88 803.686,1406.88 803.696,1406.88 803.705,1406.88 803.714,1406.88 803.723,1406.88 803.732,1406.88 803.742,1406.88 803.751,1406.88 803.76,1406.88 803.769,1406.88 803.778,1406.88 803.787,1406.88 803.797,1406.88 803.806,1406.88 803.815,1406.88 803.824,1406.88 803.833,1406.88 803.843,1406.88 803.852,1406.88 803.861,1406.88 803.87,1406.88 803.879,1406.88 803.889,1406.88 803.898,1406.88 803.907,1406.88 803.916,1406.88 803.925,1406.88 803.934,1406.88 803.944,1406.88 803.953,1406.88 803.962,1406.88 803.971,1406.88 803.98,1406.88 803.99,1406.88 803.999,1406.88 804.008,1406.88 804.017,1406.88 804.026,1406.88 804.036,1406.88 804.045,1406.88 804.054,1406.88 804.063,1406.88 804.072,1406.88 804.082,1406.88 804.091,1406.88 804.1,1406.88 804.109,1406.88 804.118,1406.88 804.127,1406.88 804.137,1406.88 804.146,1406.88 804.155,1406.88 804.164,1406.88 804.173,1406.88 804.183,1406.88 804.192,1406.88 804.201,1406.88 804.21,1406.88 804.219,1406.88 804.229,1406.88 804.238,1406.88 804.247,1406.88 804.256,1406.88 804.265,1406.88 804.274,1406.88 804.284,1406.88 804.293,1406.88 804.302,1406.88 804.311,1406.88 804.32,1406.88 804.33,1406.88 804.339,1406.88 804.348,1406.88 804.357,1406.88 804.366,1406.88 804.376,1406.88 804.385,1406.88 804.394,1406.88 804.403,1406.88 804.412,1406.88 804.422,1406.88 804.431,1406.88 804.44,1406.88 804.449,1406.88 804.458,1406.88 804.467,1406.88 804.477,1406.88 804.486,1406.88 804.495,1406.88 804.504,1406.88 804.513,1406.88 804.523,1406.88 804.532,1406.88 804.541,1406.88 804.55,1406.88 804.559,1406.88 804.569,1406.88 804.578,1406.88 804.587,1406.88 804.596,1406.88 804.605,1406.88 804.614,1406.88 804.624,1406.88 804.633,1406.88 804.642,1406.88 804.651,1406.88 804.66,1406.88 804.67,1406.88 804.679,1406.88 804.688,1406.88 804.697,1406.88 804.706,1406.88 804.716,1406.88 804.725,1406.88 804.734,1406.88 804.743,1406.88 804.752,1406.88 804.762,1406.88 804.771,1406.88 804.78,1406.88 804.789,1406.88 804.798,1406.88 804.807,1406.88 804.817,1406.88 804.826,1406.88 804.835,1406.88 804.844,1406.88 804.853,1406.88 804.863,1406.88 804.872,1406.88 804.881,1406.88 804.89,1406.88 804.899,1406.88 804.909,1406.88 804.918,1406.88 804.927,1406.88 804.936,1406.88 804.945,1406.88 804.955,1406.88 804.964,1406.88 804.973,1406.88 804.982,1406.88 804.991,1406.88 805,1406.88 805.01,1406.88 805.019,1406.88 805.028,1406.88 805.037,1406.88 805.046,1406.88 805.056,1406.88 805.065,1406.88 805.074,1406.88 805.083,1406.88 805.092,1406.88 805.102,1406.88 805.111,1406.88 805.12,1406.88 805.129,1406.88 805.138,1406.88 805.147,1406.88 805.157,1406.88 805.166,1406.88 805.175,1406.88 805.184,1406.88 805.193,1406.88 805.203,1406.88 805.212,1406.88 805.221,1406.88 805.23,1406.88 805.239,1406.88 805.249,1406.88 805.258,1406.88 805.267,1406.88 805.276,1406.88 805.285,1406.88 805.295,1406.88 805.304,1406.88 805.313,1406.88 805.322,1406.88 805.331,1406.88 805.34,1406.88 805.35,1406.88 805.359,1406.88 805.368,1406.88 805.377,1406.88 805.386,1406.88 805.396,1406.88 805.405,1406.88 805.414,1406.88 805.423,1406.88 805.432,1406.88 805.442,1406.88 805.451,1406.88 805.46,1406.88 805.469,1406.88 805.478,1406.88 805.487,1406.88 805.497,1406.88 805.506,1406.88 805.515,1406.88 805.524,1406.88 805.533,1406.88 805.543,1406.88 805.552,1406.88 805.561,1406.88 805.57,1406.88 805.579,1406.88 805.589,1406.88 805.598,1406.88 805.607,1406.88 805.616,1406.88 805.625,1406.88 805.635,1406.88 805.644,1406.88 805.653,1406.88 805.662,1406.88 805.671,1406.88 805.68,1406.88 805.69,1406.88 805.699,1406.88 805.708,1406.88 805.717,1406.88 805.726,1406.88 805.736,1406.88 805.745,1406.88 805.754,1406.88 805.763,1406.88 805.772,1406.88 805.782,1406.88 805.791,1406.88 805.8,1406.88 805.809,1406.88 805.818,1406.88 805.827,1406.88 805.837,1406.88 805.846,1406.88 805.855,1406.88 805.864,1406.88 805.873,1406.88 805.883,1406.88 805.892,1406.88 805.901,1406.88 805.91,1406.88 805.919,1406.88 805.929,1406.88 805.938,1406.88 805.947,1406.88 805.956,1406.88 805.965,1406.88 805.975,1406.88 805.984,1406.88 805.993,1406.88 806.002,1406.88 806.011,1406.88 806.02,1406.88 806.03,1406.88 806.039,1406.88 806.048,1406.88 806.057,1406.88 806.066,1406.88 806.076,1406.88 806.085,1406.88 806.094,1406.88 806.103,1406.88 806.112,1406.88 806.122,1406.88 806.131,1406.88 806.14,1406.88 806.149,1406.88 806.158,1406.88 806.167,1406.88 806.177,1406.88 806.186,1406.88 806.195,1406.88 806.204,1406.88 806.213,1406.88 806.223,1406.88 806.232,1406.88 806.241,1406.88 806.25,1406.88 806.259,1406.88 806.269,1406.88 806.278,1406.88 806.287,1406.88 806.296,1406.88 806.305,1406.88 806.315,1406.88 806.324,1406.88 806.333,1406.88 806.342,1406.88 806.351,1406.88 806.36,1406.88 806.37,1406.88 806.379,1406.88 806.388,1406.88 806.397,1406.88 806.406,1406.88 806.416,1406.88 806.425,1406.88 806.434,1406.88 806.443,1406.88 806.452,1406.88 806.462,1406.88 806.471,1406.88 806.48,1406.88 806.489,1406.88 806.498,1406.88 806.507,1406.88 806.517,1406.88 806.526,1406.88 806.535,1406.88 806.544,1406.88 806.553,1406.88 806.563,1406.88 806.572,1406.88 806.581,1406.88 806.59,1406.88 806.599,1406.88 806.609,1406.88 806.618,1406.88 806.627,1406.88 806.636,1406.88 806.645,1406.88 806.655,1406.88 806.664,1406.88 806.673,1406.88 806.682,1406.88 806.691,1406.88 806.7,1406.88 806.71,1406.88 806.719,1406.88 806.728,1406.88 806.737,1406.88 806.746,1406.88 806.756,1406.88 806.765,1406.88 806.774,1406.88 806.783,1406.88 806.792,1406.88 806.802,1406.88 806.811,1406.88 806.82,1406.88 806.829,1406.88 806.838,1406.88 806.847,1406.88 806.857,1406.88 806.866,1406.88 806.875,1406.88 806.884,1406.88 806.893,1406.88 806.903,1406.88 806.912,1406.88 806.921,1406.88 806.93,1406.88 806.939,1406.88 806.949,1406.88 806.958,1406.88 806.967,1406.88 806.976,1406.88 806.985,1406.88 806.995,1406.88 807.004,1406.88 807.013,1406.88 807.022,1406.88 807.031,1406.88 807.04,1406.88 807.05,1406.88 807.059,1406.88 807.068,1406.88 807.077,1406.88 807.086,1406.88 807.096,1406.88 807.105,1406.88 807.114,1406.88 807.123,1406.88 807.132,1406.88 807.142,1406.88 807.151,1406.88 807.16,1406.88 807.169,1406.88 807.178,1406.88 807.188,1406.88 807.197,1406.88 807.206,1406.88 807.215,1406.88 807.224,1406.88 807.233,1406.88 807.243,1406.88 807.252,1406.88 807.261,1406.88 807.27,1406.88 807.279,1406.88 807.289,1406.88 807.298,1406.88 807.307,1406.88 807.316,1406.88 807.325,1406.88 807.335,1406.88 807.344,1406.88 807.353,1406.88 807.362,1406.88 807.371,1406.88 807.38,1406.88 807.39,1406.88 807.399,1406.88 807.408,1406.88 807.417,1406.88 807.426,1406.88 807.436,1406.88 807.445,1406.88 807.454,1406.88 807.463,1406.88 807.472,1406.88 807.482,1406.88 807.491,1406.88 807.5,1406.88 807.509,1406.88 807.518,1406.88 807.528,1406.88 807.537,1406.88 807.546,1406.88 807.555,1406.88 807.564,1406.88 807.573,1406.88 807.583,1406.88 807.592,1406.88 807.601,1406.88 807.61,1406.88 807.619,1406.88 807.629,1406.88 807.638,1406.88 807.647,1406.88 807.656,1406.88 807.665,1406.88 807.675,1406.88 807.684,1406.88 807.693,1406.88 807.702,1406.88 807.711,1406.88 807.72,1406.88 807.73,1406.88 807.739,1406.88 807.748,1406.88 807.757,1406.88 807.766,1406.88 807.776,1406.88 807.785,1406.88 807.794,1406.88 807.803,1406.88 807.812,1406.88 807.822,1406.88 807.831,1406.88 807.84,1406.88 807.849,1406.88 807.858,1406.88 807.868,1406.88 807.877,1406.88 807.886,1406.88 807.895,1406.88 807.904,1406.88 807.913,1406.88 807.923,1406.88 807.932,1406.88 807.941,1406.88 807.95,1406.88 807.959,1406.88 807.969,1406.88 807.978,1406.88 807.987,1406.88 807.996,1406.88 808.005,1406.88 808.015,1406.88 808.024,1406.88 808.033,1406.88 808.042,1406.88 808.051,1406.88 808.06,1406.88 808.07,1406.88 808.079,1406.88 808.088,1406.88 808.097,1406.88 808.106,1406.88 808.116,1406.88 808.125,1406.88 808.134,1406.88 808.143,1406.88 808.152,1406.88 808.162,1406.88 808.171,1406.88 808.18,1406.88 808.189,1406.88 808.198,1406.88 808.208,1406.88 808.217,1406.88 808.226,1406.88 808.235,1406.88 808.244,1406.88 808.253,1406.88 808.263,1406.88 808.272,1406.88 808.281,1406.88 808.29,1406.88 808.299,1406.88 808.309,1406.88 808.318,1406.88 808.327,1406.88 808.336,1406.88 808.345,1406.88 808.355,1406.88 808.364,1406.88 808.373,1406.88 808.382,1406.88 808.391,1406.88 808.4,1406.88 808.41,1406.88 808.419,1406.88 808.428,1406.88 808.437,1406.88 808.446,1406.88 808.456,1406.88 808.465,1406.88 808.474,1406.88 808.483,1406.88 808.492,1406.88 808.502,1406.88 808.511,1406.88 808.52,1406.88 808.529,1406.88 808.538,1406.88 808.548,1406.88 808.557,1406.88 808.566,1406.88 808.575,1406.88 808.584,1406.88 808.593,1406.88 808.603,1406.88 808.612,1406.88 808.621,1406.88 808.63,1406.88 808.639,1406.88 808.649,1406.88 808.658,1406.88 808.667,1406.88 808.676,1406.88 808.685,1406.88 808.695,1406.88 808.704,1406.88 808.713,1406.88 808.722,1406.88 808.731,1406.88 808.74,1406.88 808.75,1406.88 808.759,1406.88 808.768,1406.88 808.777,1406.88 808.786,1406.88 808.796,1406.88 808.805,1406.88 808.814,1406.88 808.823,1406.88 808.832,1406.88 808.842,1406.88 808.851,1406.88 808.86,1406.88 808.869,1406.88 808.878,1406.88 808.888,1406.88 808.897,1406.88 808.906,1406.88 808.915,1406.88 808.924,1406.88 808.933,1406.88 808.943,1406.88 808.952,1406.88 808.961,1406.88 808.97,1406.88 808.979,1406.88 808.989,1406.88 808.998,1406.88 809.007,1406.88 809.016,1406.88 809.025,1406.88 809.035,1406.88 809.044,1406.88 809.053,1406.88 809.062,1406.88 809.071,1406.88 809.08,1406.88 809.09,1406.88 809.099,1406.88 809.108,1406.88 809.117,1406.88 809.126,1406.88 809.136,1406.88 809.145,1406.88 809.154,1406.88 809.163,1406.88 809.172,1406.88 809.182,1406.88 809.191,1406.88 809.2,1406.88 809.209,1406.88 809.218,1406.88 809.228,1406.88 809.237,1406.88 809.246,1406.88 809.255,1406.88 809.264,1406.88 809.273,1406.88 809.283,1406.88 809.292,1406.88 809.301,1406.88 809.31,1406.88 809.319,1406.88 809.329,1406.88 809.338,1406.88 809.347,1406.88 809.356,1406.88 809.365,1406.88 809.375,1406.88 809.384,1406.88 809.393,1406.88 809.402,1406.88 809.411,1406.88 809.42,1406.88 809.43,1406.88 809.439,1406.88 809.448,1406.88 809.457,1406.88 809.466,1406.88 809.476,1406.88 809.485,1406.88 809.494,1406.88 809.503,1406.88 809.512,1406.88 809.522,1406.88 809.531,1406.88 809.54,1406.88 809.549,1406.88 809.558,1406.88 809.568,1406.88 809.577,1406.88 809.586,1406.88 809.595,1406.88 809.604,1406.88 809.613,1406.88 809.623,1406.88 809.632,1406.88 809.641,1406.88 809.65,1406.88 809.659,1406.88 809.669,1406.88 809.678,1406.88 809.687,1406.88 809.696,1406.88 809.705,1406.88 809.715,1406.88 809.724,1406.88 809.733,1406.88 809.742,1406.88 809.751,1406.88 809.761,1406.88 809.77,1406.88 809.779,1406.88 809.788,1406.88 809.797,1406.88 809.806,1406.88 809.816,1406.88 809.825,1406.88 809.834,1406.88 809.843,1406.88 809.852,1406.88 809.862,1406.88 809.871,1406.88 809.88,1406.88 809.889,1406.88 809.898,1406.88 809.908,1406.88 809.917,1406.88 809.926,1406.88 809.935,1406.88 809.944,1406.88 809.953,1406.88 809.963,1406.88 809.972,1406.88 809.981,1406.88 809.99,1406.88 809.999,1406.88 810.009,1406.88 810.018,1406.88 810.027,1406.88 810.036,1406.88 810.045,1406.88 810.055,1406.88 810.064,1406.88 810.073,1406.88 810.082,1406.88 810.091,1406.88 810.101,1406.88 810.11,1406.88 810.119,1406.88 810.128,1406.88 810.137,1406.88 810.146,1406.88 810.156,1406.88 810.165,1406.88 810.174,1406.88 810.183,1406.88 810.192,1406.88 810.202,1406.88 810.211,1406.88 810.22,1406.88 810.229,1406.88 810.238,1406.88 810.248,1406.88 810.257,1406.88 810.266,1406.88 810.275,1406.88 810.284,1406.88 810.293,1406.88 810.303,1406.88 810.312,1406.88 810.321,1406.88 810.33,1406.88 810.339,1406.88 810.349,1406.88 810.358,1406.88 810.367,1406.88 810.376,1406.88 810.385,1406.88 810.395,1406.88 810.404,1406.88 810.413,1406.88 810.422,1406.88 810.431,1406.88 810.441,1406.88 810.45,1406.88 810.459,1406.88 810.468,1406.88 810.477,1406.88 810.486,1406.88 810.496,1406.88 810.505,1406.88 810.514,1406.88 810.523,1406.88 810.532,1406.88 810.542,1406.88 810.551,1406.88 810.56,1406.88 810.569,1406.88 810.578,1406.88 810.588,1406.88 810.597,1406.88 810.606,1406.88 810.615,1406.88 810.624,1406.88 810.633,1406.88 810.643,1406.88 810.652,1406.88 810.661,1406.88 810.67,1406.88 810.679,1406.88 810.689,1406.88 810.698,1406.88 810.707,1406.88 810.716,1406.88 810.725,1406.88 810.735,1406.88 810.744,1406.88 810.753,1406.88 810.762,1406.88 810.771,1406.88 810.781,1406.88 810.79,1406.88 810.799,1406.88 810.808,1406.88 810.817,1406.88 810.826,1406.88 810.836,1406.88 810.845,1406.88 810.854,1406.88 810.863,1406.88 810.872,1406.88 810.882,1406.88 810.891,1406.88 810.9,1406.88 810.909,1406.88 810.918,1406.88 810.928,1406.88 810.937,1406.88 810.946,1406.88 810.955,1406.88 810.964,1406.88 810.973,1406.88 810.983,1406.88 810.992,1406.88 811.001,1406.88 811.01,1406.88 811.019,1406.88 811.029,1406.88 811.038,1406.88 811.047,1406.88 811.056,1406.88 811.065,1406.88 811.075,1406.88 811.084,1406.88 811.093,1406.88 811.102,1406.88 811.111,1406.88 811.121,1406.88 811.13,1406.88 811.139,1406.88 811.148,1406.88 811.157,1406.88 811.166,1406.88 811.176,1406.88 811.185,1406.88 811.194,1406.88 811.203,1406.88 811.212,1406.88 811.222,1406.88 811.231,1406.88 811.24,1406.88 811.249,1406.88 811.258,1406.88 811.268,1406.88 811.277,1406.88 811.286,1406.88 811.295,1406.88 811.304,1406.88 811.313,1406.88 811.323,1406.88 811.332,1406.88 811.341,1406.88 811.35,1406.88 811.359,1406.88 811.369,1406.88 811.378,1406.88 811.387,1406.88 811.396,1406.88 811.405,1406.88 811.415,1406.88 811.424,1406.88 811.433,1406.88 811.442,1406.88 811.451,1406.88 811.461,1406.88 811.47,1406.88 811.479,1406.88 811.488,1406.88 811.497,1406.88 811.506,1406.88 811.516,1406.88 811.525,1406.88 811.534,1406.88 811.543,1406.88 811.552,1406.88 811.562,1406.88 811.571,1406.88 811.58,1406.88 811.589,1406.88 811.598,1406.88 811.608,1406.88 811.617,1406.88 811.626,1406.88 811.635,1406.88 811.644,1406.88 811.653,1406.88 811.663,1406.88 811.672,1406.88 811.681,1406.88 811.69,1406.88 811.699,1406.88 811.709,1406.88 811.718,1406.88 811.727,1406.88 811.736,1406.88 811.745,1406.88 811.755,1406.88 811.764,1406.88 811.773,1406.88 811.782,1406.88 811.791,1406.88 811.801,1406.88 811.81,1406.88 811.819,1406.88 811.828,1406.88 811.837,1406.88 811.846,1406.88 811.856,1406.88 811.865,1406.88 811.874,1406.88 811.883,1406.88 811.892,1406.88 811.902,1406.88 811.911,1406.88 811.92,1406.88 811.929,1406.88 811.938,1406.88 811.948,1406.88 811.957,1406.88 811.966,1406.88 811.975,1406.88 811.984,1406.88 811.993,1406.88 812.003,1406.88 812.012,1406.88 812.021,1406.88 812.03,1406.88 812.039,1406.88 812.049,1406.88 812.058,1406.88 812.067,1406.88 812.076,1406.88 812.085,1406.88 812.095,1406.88 812.104,1406.88 812.113,1406.88 812.122,1406.88 812.131,1406.88 812.141,1406.88 812.15,1406.88 812.159,1406.88 812.168,1406.88 812.177,1406.88 812.186,1406.88 812.196,1406.88 812.205,1406.88 812.214,1406.88 812.223,1406.88 812.232,1406.88 812.242,1406.88 812.251,1406.88 812.26,1406.88 812.269,1406.88 812.278,1406.88 812.288,1406.88 812.297,1406.88 812.306,1406.88 812.315,1406.88 812.324,1406.88 812.334,1406.88 812.343,1406.88 812.352,1406.88 812.361,1406.88 812.37,1406.88 812.379,1406.88 812.389,1406.88 812.398,1406.88 812.407,1406.88 812.416,1406.88 812.425,1406.88 812.435,1406.88 812.444,1406.88 812.453,1406.88 812.462,1406.88 812.471,1406.88 812.481,1406.88 812.49,1406.88 812.499,1406.88 812.508,1406.88 812.517,1406.88 812.526,1406.88 812.536,1406.88 812.545,1406.88 812.554,1406.88 812.563,1406.88 812.572,1406.88 812.582,1406.88 812.591,1406.88 812.6,1406.88 812.609,1406.88 812.618,1406.88 812.628,1406.88 812.637,1406.88 812.646,1406.88 812.655,1406.88 812.664,1406.88 812.674,1406.88 812.683,1406.88 812.692,1406.88 812.701,1406.88 812.71,1406.88 812.719,1406.88 812.729,1406.88 812.738,1406.88 812.747,1406.88 812.756,1406.88 812.765,1406.88 812.775,1406.88 812.784,1406.88 812.793,1406.88 812.802,1406.88 812.811,1406.88 812.821,1406.88 812.83,1406.88 812.839,1406.88 812.848,1406.88 812.857,1406.88 812.866,1406.88 812.876,1406.88 812.885,1406.88 812.894,1406.88 812.903,1406.88 812.912,1406.88 812.922,1406.88 812.931,1406.88 812.94,1406.88 812.949,1406.88 812.958,1406.88 812.968,1406.88 812.977,1406.88 812.986,1406.88 812.995,1406.88 813.004,1406.88 813.014,1406.88 813.023,1406.88 813.032,1406.88 813.041,1406.88 813.05,1406.88 813.059,1406.88 813.069,1406.88 813.078,1406.88 813.087,1406.88 813.096,1406.88 813.105,1406.88 813.115,1406.88 813.124,1406.88 813.133,1406.88 813.142,1406.88 813.151,1406.88 813.161,1406.88 813.17,1406.88 813.179,1406.88 813.188,1406.88 813.197,1406.88 813.206,1406.88 813.216,1406.88 813.225,1406.88 813.234,1406.88 813.243,1406.88 813.252,1406.88 813.262,1406.88 813.271,1406.88 813.28,1406.88 813.289,1406.88 813.298,1406.88 813.308,1406.88 813.317,1406.88 813.326,1406.88 813.335,1406.88 813.344,1406.88 813.354,1406.88 813.363,1406.88 813.372,1406.88 813.381,1406.88 813.39,1406.88 813.399,1406.88 813.409,1406.88 813.418,1406.88 813.427,1406.88 813.436,1406.88 813.445,1406.88 813.455,1406.88 813.464,1406.88 813.473,1406.88 813.482,1406.88 813.491,1406.88 813.501,1406.88 813.51,1406.88 813.519,1406.88 813.528,1406.88 813.537,1406.88 813.546,1406.88 813.556,1406.88 813.565,1406.88 813.574,1406.88 813.583,1406.88 813.592,1406.88 813.602,1406.88 813.611,1406.88 813.62,1406.88 813.629,1406.88 813.638,1406.88 813.648,1406.88 813.657,1406.88 813.666,1406.88 813.675,1406.88 813.684,1406.88 813.694,1406.88 813.703,1406.88 813.712,1406.88 813.721,1406.88 813.73,1406.88 813.739,1406.88 813.749,1406.88 813.758,1406.88 813.767,1406.88 813.776,1406.88 813.785,1406.88 813.795,1406.88 813.804,1406.88 813.813,1406.88 813.822,1406.88 813.831,1406.88 813.841,1406.88 813.85,1406.88 813.859,1406.88 813.868,1406.88 813.877,1406.88 813.886,1406.88 813.896,1406.88 813.905,1406.88 813.914,1406.88 813.923,1406.88 813.932,1406.88 813.942,1406.88 813.951,1406.88 813.96,1406.88 813.969,1406.88 813.978,1406.88 813.988,1406.88 813.997,1406.88 814.006,1406.88 814.015,1406.88 814.024,1406.88 814.034,1406.88 814.043,1406.88 814.052,1406.88 814.061,1406.88 814.07,1406.88 814.079,1406.88 814.089,1406.88 814.098,1406.88 814.107,1406.88 814.116,1406.88 814.125,1406.88 814.135,1406.88 814.144,1406.88 814.153,1406.88 814.162,1406.88 814.171,1406.88 814.181,1406.88 814.19,1406.88 814.199,1406.88 814.208,1406.88 814.217,1406.88 814.226,1406.88 814.236,1406.88 814.245,1406.88 814.254,1406.88 814.263,1406.88 814.272,1406.88 814.282,1406.88 814.291,1406.88 814.3,1406.88 814.309,1406.88 814.318,1406.88 814.328,1406.88 814.337,1406.88 814.346,1406.88 814.355,1406.88 814.364,1406.88 814.374,1406.88 814.383,1406.88 814.392,1406.88 814.401,1406.88 814.41,1406.88 814.419,1406.88 814.429,1406.88 814.438,1406.88 814.447,1406.88 814.456,1406.88 814.465,1406.88 814.475,1406.88 814.484,1406.88 814.493,1406.88 814.502,1406.88 814.511,1406.88 814.521,1406.88 814.53,1406.88 814.539,1406.88 814.548,1406.88 814.557,1406.88 814.566,1406.88 814.576,1406.88 814.585,1406.88 814.594,1406.88 814.603,1406.88 814.612,1406.88 814.622,1406.88 814.631,1406.88 814.64,1406.88 814.649,1406.88 814.658,1406.88 814.668,1406.88 814.677,1406.88 814.686,1406.88 814.695,1406.88 814.704,1406.88 814.714,1406.88 814.723,1406.88 814.732,1406.88 814.741,1406.88 814.75,1406.88 814.759,1406.88 814.769,1406.88 814.778,1406.88 814.787,1406.88 814.796,1406.88 814.805,1406.88 814.815,1406.88 814.824,1406.88 814.833,1406.88 814.842,1406.88 814.851,1406.88 814.861,1406.88 814.87,1406.88 814.879,1406.88 814.888,1406.88 814.897,1406.88 814.907,1406.88 814.916,1406.88 814.925,1406.88 814.934,1406.88 814.943,1406.88 814.952,1406.88 814.962,1406.88 814.971,1406.88 814.98,1406.88 814.989,1406.88 814.998,1406.88 815.008,1406.88 815.017,1406.88 815.026,1406.88 815.035,1406.88 815.044,1406.88 815.054,1406.88 815.063,1406.88 815.072,1406.88 815.081,1406.88 815.09,1406.88 815.099,1406.88 815.109,1406.88 815.118,1406.88 815.127,1406.88 815.136,1406.88 815.145,1406.88 815.155,1406.88 815.164,1406.88 815.173,1406.88 815.182,1406.88 815.191,1406.88 815.201,1406.88 815.21,1406.88 815.219,1406.88 815.228,1406.88 815.237,1406.88 815.247,1406.88 815.256,1406.88 815.265,1406.88 815.274,1406.88 815.283,1406.88 815.292,1406.88 815.302,1406.88 815.311,1406.88 815.32,1406.88 815.329,1406.88 815.338,1406.88 815.348,1406.88 815.357,1406.88 815.366,1406.88 815.375,1406.88 815.384,1406.88 815.394,1406.88 815.403,1406.88 815.412,1406.88 815.421,1406.88 815.43,1406.88 815.439,1406.88 815.449,1406.88 815.458,1406.88 815.467,1406.88 815.476,1406.88 815.485,1406.88 815.495,1406.88 815.504,1406.88 815.513,1406.88 815.522,1406.88 815.531,1406.88 815.541,1406.88 815.55,1406.88 815.559,1406.88 815.568,1406.88 815.577,1406.88 815.587,1406.88 815.596,1406.88 815.605,1406.88 815.614,1406.88 815.623,1406.88 815.632,1406.88 815.642,1406.88 815.651,1406.88 815.66,1406.88 815.669,1406.88 815.678,1406.88 815.688,1406.88 815.697,1406.88 815.706,1406.88 815.715,1406.88 815.724,1406.88 815.734,1406.88 815.743,1406.88 815.752,1406.88 815.761,1406.88 815.77,1406.88 815.779,1406.88 815.789,1406.88 815.798,1406.88 815.807,1406.88 815.816,1406.88 815.825,1406.88 815.835,1406.88 815.844,1406.88 815.853,1406.88 815.862,1406.88 815.871,1406.88 815.881,1406.88 815.89,1406.88 815.899,1406.88 815.908,1406.88 815.917,1406.88 815.927,1406.88 815.936,1406.88 815.945,1406.88 815.954,1406.88 815.963,1406.88 815.972,1406.88 815.982,1406.88 815.991,1406.88 816,1406.88 816.009,1406.88 816.018,1406.88 816.028,1406.88 816.037,1406.88 816.046,1406.88 816.055,1406.88 816.064,1406.88 816.074,1406.88 816.083,1406.88 816.092,1406.88 816.101,1406.88 816.11,1406.88 816.119,1406.88 816.129,1406.88 816.138,1406.88 816.147,1406.88 816.156,1406.88 816.165,1406.88 816.175,1406.88 816.184,1406.88 816.193,1406.88 816.202,1406.88 816.211,1406.88 816.221,1406.88 816.23,1406.88 816.239,1406.88 816.248,1406.88 816.257,1406.88 816.267,1406.88 816.276,1406.88 816.285,1406.88 816.294,1406.88 816.303,1406.88 816.312,1406.88 816.322,1406.88 816.331,1406.88 816.34,1406.88 816.349,1406.88 816.358,1406.88 816.368,1406.88 816.377,1406.88 816.386,1406.88 816.395,1406.88 816.404,1406.88 816.414,1406.88 816.423,1406.88 816.432,1406.88 816.441,1406.88 816.45,1406.88 816.459,1406.88 816.469,1406.88 816.478,1406.88 816.487,1406.88 816.496,1406.88 816.505,1406.88 816.515,1406.88 816.524,1406.88 816.533,1406.88 816.542,1406.88 816.551,1406.88 816.561,1406.88 816.57,1406.88 816.579,1406.88 816.588,1406.88 816.597,1406.88 816.607,1406.88 816.616,1406.88 816.625,1406.88 816.634,1406.88 816.643,1406.88 816.652,1406.88 816.662,1406.88 816.671,1406.88 816.68,1406.88 816.689,1406.88 816.698,1406.88 816.708,1406.88 816.717,1406.88 816.726,1406.88 816.735,1406.88 816.744,1406.88 816.754,1406.88 816.763,1406.88 816.772,1406.88 816.781,1406.88 816.79,1406.88 816.799,1406.88 816.809,1406.88 816.818,1406.88 816.827,1406.88 816.836,1406.88 816.845,1406.88 816.855,1406.88 816.864,1406.88 816.873,1406.88 816.882,1406.88 816.891,1406.88 816.901,1406.88 816.91,1406.88 816.919,1406.88 816.928,1406.88 816.937,1406.88 816.947,1406.88 816.956,1406.88 816.965,1406.88 816.974,1406.88 816.983,1406.88 816.992,1406.88 817.002,1406.88 817.011,1406.88 817.02,1406.88 817.029,1406.88 817.038,1406.88 817.048,1406.88 817.057,1406.88 817.066,1406.88 817.075,1406.88 817.084,1406.88 817.094,1406.88 817.103,1406.88 817.112,1406.88 817.121,1406.88 817.13,1406.88 817.14,1406.88 817.149,1406.88 817.158,1406.88 817.167,1406.88 817.176,1406.88 817.185,1406.88 817.195,1406.88 817.204,1406.88 817.213,1406.88 817.222,1406.88 817.231,1406.88 817.241,1406.88 817.25,1406.88 817.259,1406.88 817.268,1406.88 817.277,1406.88 817.287,1406.88 817.296,1406.88 817.305,1406.88 817.314,1406.88 817.323,1406.88 817.332,1406.88 817.342,1406.88 817.351,1406.88 817.36,1406.88 817.369,1406.88 817.378,1406.88 817.388,1406.88 817.397,1406.88 817.406,1406.88 817.415,1406.88 817.424,1406.88 817.434,1406.88 817.443,1406.88 817.452,1406.88 817.461,1406.88 817.47,1406.88 817.48,1406.88 817.489,1406.88 817.498,1406.88 817.507,1406.88 817.516,1406.88 817.525,1406.88 817.535,1406.88 817.544,1406.88 817.553,1406.88 817.562,1406.88 817.571,1406.88 817.581,1406.88 817.59,1406.88 817.599,1406.88 817.608,1406.88 817.617,1406.88 817.627,1406.88 817.636,1406.88 817.645,1406.88 817.654,1406.88 817.663,1406.88 817.672,1406.88 817.682,1406.88 817.691,1406.88 817.7,1406.88 817.709,1406.88 817.718,1406.88 817.728,1406.88 817.737,1406.88 817.746,1406.88 817.755,1406.88 817.764,1406.88 817.774,1406.88 817.783,1406.88 817.792,1406.88 817.801,1406.88 817.81,1406.88 817.82,1406.88 817.829,1406.88 817.838,1406.88 817.847,1406.88 817.856,1406.88 817.865,1406.88 817.875,1406.88 817.884,1406.88 817.893,1406.88 817.902,1406.88 817.911,1406.88 817.921,1406.88 817.93,1406.88 817.939,1406.88 817.948,1406.88 817.957,1406.88 817.967,1406.88 817.976,1406.88 817.985,1406.88 817.994,1406.88 818.003,1406.88 818.012,1406.88 818.022,1406.88 818.031,1406.88 818.04,1406.88 818.049,1406.88 818.058,1406.88 818.068,1406.88 818.077,1406.88 818.086,1406.88 818.095,1406.88 818.104,1406.88 818.114,1406.88 818.123,1406.88 818.132,1406.88 818.141,1406.88 818.15,1406.88 818.16,1406.88 818.169,1406.88 818.178,1406.88 818.187,1406.88 818.196,1406.88 818.205,1406.88 818.215,1406.88 818.224,1406.88 818.233,1406.88 818.242,1406.88 818.251,1406.88 818.261,1406.88 818.27,1406.88 818.279,1406.88 818.288,1406.88 818.297,1406.88 818.307,1406.88 818.316,1406.88 818.325,1406.88 818.334,1406.88 818.343,1406.88 818.352,1406.88 818.362,1406.88 818.371,1406.88 818.38,1406.88 818.389,1406.88 818.398,1406.88 818.408,1406.88 818.417,1406.88 818.426,1406.88 818.435,1406.88 818.444,1406.88 818.454,1406.88 818.463,1406.88 818.472,1406.88 818.481,1406.88 818.49,1406.88 818.5,1406.88 818.509,1406.88 818.518,1406.88 818.527,1406.88 818.536,1406.88 818.545,1406.88 818.555,1406.88 818.564,1406.88 818.573,1406.88 818.582,1406.88 818.591,1406.88 818.601,1406.88 818.61,1406.88 818.619,1406.88 818.628,1406.88 818.637,1406.88 818.647,1406.88 818.656,1406.88 818.665,1406.88 818.674,1406.88 818.683,1406.88 818.692,1406.88 818.702,1406.88 818.711,1406.88 818.72,1406.88 818.729,1406.88 818.738,1406.88 818.748,1406.88 818.757,1406.88 818.766,1406.88 818.775,1406.88 818.784,1406.88 818.794,1406.88 818.803,1406.88 818.812,1406.88 818.821,1406.88 818.83,1406.88 818.84,1406.88 818.849,1406.88 818.858,1406.88 818.867,1406.88 818.876,1406.88 818.885,1406.88 818.895,1406.88 818.904,1406.88 818.913,1406.88 818.922,1406.88 818.931,1406.88 818.941,1406.88 818.95,1406.88 818.959,1406.88 818.968,1406.88 818.977,1406.88 818.987,1406.88 818.996,1406.88 819.005,1406.88 819.014,1406.88 819.023,1406.88 819.032,1406.88 819.042,1406.88 819.051,1406.88 819.06,1406.88 819.069,1406.88 819.078,1406.88 819.088,1406.88 819.097,1406.88 819.106,1406.88 819.115,1406.88 819.124,1406.88 819.134,1406.88 819.143,1406.88 819.152,1406.88 819.161,1406.88 819.17,1406.88 819.18,1406.88 819.189,1406.88 819.198,1406.88 819.207,1406.88 819.216,1406.88 819.225,1406.88 819.235,1406.88 819.244,1406.88 819.253,1406.88 819.262,1406.88 819.271,1406.88 819.281,1406.88 819.29,1406.88 819.299,1406.88 819.308,1406.88 819.317,1406.88 819.327,1406.88 819.336,1406.88 819.345,1406.88 819.354,1406.88 819.363,1406.88 819.372,1406.88 819.382,1406.88 819.391,1406.88 819.4,1406.88 819.409,1406.88 819.418,1406.88 819.428,1406.88 819.437,1406.88 819.446,1406.88 819.455,1406.88 819.464,1406.88 819.474,1406.88 819.483,1406.88 819.492,1406.88 819.501,1406.88 819.51,1406.88 819.52,1406.88 819.529,1406.88 819.538,1406.88 819.547,1406.88 819.556,1406.88 819.565,1406.88 819.575,1406.88 819.584,1406.88 819.593,1406.88 819.602,1406.88 819.611,1406.88 819.621,1406.88 819.63,1406.88 819.639,1406.88 819.648,1406.88 819.657,1406.88 819.667,1406.88 819.676,1406.88 819.685,1406.88 819.694,1406.88 819.703,1406.88 819.713,1406.88 819.722,1406.88 819.731,1406.88 819.74,1406.88 819.749,1406.88 819.758,1406.88 819.768,1406.88 819.777,1406.88 819.786,1406.88 819.795,1406.88 819.804,1406.88 819.814,1406.88 819.823,1406.88 819.832,1406.88 819.841,1406.88 819.85,1406.88 819.86,1406.88 819.869,1406.88 819.878,1406.88 819.887,1406.88 819.896,1406.88 819.905,1406.88 819.915,1406.88 819.924,1406.88 819.933,1406.88 819.942,1406.88 819.951,1406.88 819.961,1406.88 819.97,1406.88 819.979,1406.88 819.988,1406.88 819.997,1406.88 820.007,1406.88 820.016,1406.88 820.025,1406.88 820.034,1406.88 820.043,1406.88 820.053,1406.88 820.062,1406.88 820.071,1406.88 820.08,1406.88 820.089,1406.88 820.098,1406.88 820.108,1406.88 820.117,1406.88 820.126,1406.88 820.135,1406.88 820.144,1406.88 820.154,1406.88 820.163,1406.88 820.172,1406.88 820.181,1406.88 820.19,1406.88 820.2,1406.88 820.209,1406.88 820.218,1406.88 820.227,1406.88 820.236,1406.88 820.245,1406.88 820.255,1406.88 820.264,1406.88 820.273,1406.88 820.282,1406.88 820.291,1406.88 820.301,1406.88 820.31,1406.88 820.319,1406.88 820.328,1406.88 820.337,1406.88 820.347,1406.88 820.356,1406.88 820.365,1406.88 820.374,1406.88 820.383,1406.88 820.393,1406.88 820.402,1406.88 820.411,1406.88 820.42,1406.88 820.429,1406.88 820.438,1406.88 820.448,1406.88 820.457,1406.88 820.466,1406.88 820.475,1406.88 820.484,1406.88 820.494,1406.88 820.503,1406.88 820.512,1406.88 820.521,1406.88 820.53,1406.88 820.54,1406.88 820.549,1406.88 820.558,1406.88 820.567,1406.88 820.576,1406.88 820.585,1406.88 820.595,1406.88 820.604,1406.88 820.613,1406.88 820.622,1406.88 820.631,1406.88 820.641,1406.88 820.65,1406.88 820.659,1406.88 820.668,1406.88 820.677,1406.88 820.687,1406.88 820.696,1406.88 820.705,1406.88 820.714,1406.88 820.723,1406.88 820.733,1406.88 820.742,1406.88 820.751,1406.88 820.76,1406.88 820.769,1406.88 820.778,1406.88 820.788,1406.88 820.797,1406.88 820.806,1406.88 820.815,1406.88 820.824,1406.88 820.834,1406.88 820.843,1406.88 820.852,1406.88 820.861,1406.88 820.87,1406.88 820.88,1406.88 820.889,1406.88 820.898,1406.88 820.907,1406.88 820.916,1406.88 820.925,1406.88 820.935,1406.88 820.944,1406.88 820.953,1406.88 820.962,1406.88 820.971,1406.88 820.981,1406.88 820.99,1406.88 820.999,1406.88 821.008,1406.88 821.017,1406.88 821.027,1406.88 821.036,1406.88 821.045,1406.88 821.054,1406.88 821.063,1406.88 821.073,1406.88 821.082,1406.88 821.091,1406.88 821.1,1406.88 821.109,1406.88 821.118,1406.88 821.128,1406.88 821.137,1406.88 821.146,1406.88 821.155,1406.88 821.164,1406.88 821.174,1406.88 821.183,1406.88 821.192,1406.88 821.201,1406.88 821.21,1406.88 821.22,1406.88 821.229,1406.88 821.238,1406.88 821.247,1406.88 821.256,1406.88 821.265,1406.88 821.275,1406.88 821.284,1406.88 821.293,1406.88 821.302,1406.88 821.311,1406.88 821.321,1406.88 821.33,1406.88 821.339,1406.88 821.348,1406.88 821.357,1406.88 821.367,1406.88 821.376,1406.88 821.385,1406.88 821.394,1406.88 821.403,1406.88 821.413,1406.88 821.422,1406.88 821.431,1406.88 821.44,1406.88 821.449,1406.88 821.458,1406.88 821.468,1406.88 821.477,1406.88 821.486,1406.88 821.495,1406.88 821.504,1406.88 821.514,1406.88 821.523,1406.88 821.532,1406.88 821.541,1406.88 821.55,1406.88 821.56,1406.88 821.569,1406.88 821.578,1406.88 821.587,1406.88 821.596,1406.88 821.605,1406.88 821.615,1406.88 821.624,1406.88 821.633,1406.88 821.642,1406.88 821.651,1406.88 821.661,1406.88 821.67,1406.88 821.679,1406.88 821.688,1406.88 821.697,1406.88 821.707,1406.88 821.716,1406.88 821.725,1406.88 821.734,1406.88 821.743,1406.88 821.753,1406.88 821.762,1406.88 821.771,1406.88 821.78,1406.88 821.789,1406.88 821.798,1406.88 821.808,1406.88 821.817,1406.88 821.826,1406.88 821.835,1406.88 821.844,1406.88 821.854,1406.88 821.863,1406.88 821.872,1406.88 821.881,1406.88 821.89,1406.88 821.9,1406.88 821.909,1406.88 821.918,1406.88 821.927,1406.88 821.936,1406.88 821.945,1406.88 821.955,1406.88 821.964,1406.88 821.973,1406.88 821.982,1406.88 821.991,1406.88 822.001,1406.88 822.01,1406.88 822.019,1406.88 822.028,1406.88 822.037,1406.88 822.047,1406.88 822.056,1406.88 822.065,1406.88 822.074,1406.88 822.083,1406.88 822.093,1406.88 822.102,1406.88 822.111,1406.88 822.12,1406.88 822.129,1406.88 822.138,1406.88 822.148,1406.88 822.157,1406.88 822.166,1406.88 822.175,1406.88 822.184,1406.88 822.194,1406.88 822.203,1406.88 822.212,1406.88 822.221,1406.88 822.23,1406.88 822.24,1406.88 822.249,1406.88 822.258,1406.88 822.267,1406.88 822.276,1406.88 822.286,1406.88 822.295,1406.88 822.304,1406.88 822.313,1406.88 822.322,1406.88 822.331,1406.88 822.341,1406.88 822.35,1406.88 822.359,1406.88 822.368,1406.88 822.377,1406.88 822.387,1406.88 822.396,1406.88 822.405,1406.88 822.414,1406.88 822.423,1406.88 822.433,1406.88 822.442,1406.88 822.451,1406.88 822.46,1406.88 822.469,1406.88 822.478,1406.88 822.488,1406.88 822.497,1406.88 822.506,1406.88 822.515,1406.88 822.524,1406.88 822.534,1406.88 822.543,1406.88 822.552,1406.88 822.561,1406.88 822.57,1406.88 822.58,1406.88 822.589,1406.88 822.598,1406.88 822.607,1406.88 822.616,1406.88 822.626,1406.88 822.635,1406.88 822.644,1406.88 822.653,1406.88 822.662,1406.88 822.671,1406.88 822.681,1406.88 822.69,1406.88 822.699,1406.88 822.708,1406.88 822.717,1406.88 822.727,1406.88 822.736,1406.88 822.745,1406.88 822.754,1406.88 822.763,1406.88 822.773,1406.88 822.782,1406.88 822.791,1406.88 822.8,1406.88 822.809,1406.88 822.818,1406.88 822.828,1406.88 822.837,1406.88 822.846,1406.88 822.855,1406.88 822.864,1406.88 822.874,1406.88 822.883,1406.88 822.892,1406.88 822.901,1406.88 822.91,1406.88 822.92,1406.88 822.929,1406.88 822.938,1406.88 822.947,1406.88 822.956,1406.88 822.966,1406.88 822.975,1406.88 822.984,1406.88 822.993,1406.88 823.002,1406.88 823.011,1406.88 823.021,1406.88 823.03,1406.88 823.039,1406.88 823.048,1406.88 823.057,1406.88 823.067,1406.88 823.076,1406.88 823.085,1406.88 823.094,1406.88 823.103,1406.88 823.113,1406.88 823.122,1406.88 823.131,1406.88 823.14,1406.88 823.149,1406.88 823.158,1406.88 823.168,1406.88 823.177,1406.88 823.186,1406.88 823.195,1406.88 823.204,1406.88 823.214,1406.88 823.223,1406.88 823.232,1406.88 823.241,1406.88 823.25,1406.88 823.26,1406.88 823.269,1406.88 823.278,1406.88 823.287,1406.88 823.296,1406.88 823.306,1406.88 823.315,1406.88 823.324,1406.88 823.333,1406.88 823.342,1406.88 823.351,1406.88 823.361,1406.88 823.37,1406.88 823.379,1406.88 823.388,1406.88 823.397,1406.88 823.407,1406.88 823.416,1406.88 823.425,1406.88 823.434,1406.88 823.443,1406.88 823.453,1406.88 823.462,1406.88 823.471,1406.88 823.48,1406.88 823.489,1406.88 823.498,1406.88 823.508,1406.88 823.517,1406.88 823.526,1406.88 823.535,1406.88 823.544,1406.88 823.554,1406.88 823.563,1406.88 823.572,1406.88 823.581,1406.88 823.59,1406.88 823.6,1406.88 823.609,1406.88 823.618,1406.88 823.627,1406.88 823.636,1406.88 823.646,1406.88 823.655,1406.88 823.664,1406.88 823.673,1406.88 823.682,1406.88 823.691,1406.88 823.701,1406.88 823.71,1406.88 823.719,1406.88 823.728,1406.88 823.737,1406.88 823.747,1406.88 823.756,1406.88 823.765,1406.88 823.774,1406.88 823.783,1406.88 823.793,1406.88 823.802,1406.88 823.811,1406.88 823.82,1406.88 823.829,1406.88 823.838,1406.88 823.848,1406.88 823.857,1406.88 823.866,1406.88 823.875,1406.88 823.884,1406.88 823.894,1406.88 823.903,1406.88 823.912,1406.88 823.921,1406.88 823.93,1406.88 823.94,1406.88 823.949,1406.88 823.958,1406.88 823.967,1406.88 823.976,1406.88 823.986,1406.88 823.995,1406.88 824.004,1406.88 824.013,1406.88 824.022,1406.88 824.031,1406.88 824.041,1406.88 824.05,1406.88 824.059,1406.88 824.068,1406.88 824.077,1406.88 824.087,1406.88 824.096,1406.88 824.105,1406.88 824.114,1406.88 824.123,1406.88 824.133,1406.88 824.142,1406.88 824.151,1406.88 824.16,1406.88 824.169,1406.88 824.178,1406.88 824.188,1406.88 824.197,1406.88 824.206,1406.88 824.215,1406.88 824.224,1406.88 824.234,1406.88 824.243,1406.88 824.252,1406.88 824.261,1406.88 824.27,1406.88 824.28,1406.88 824.289,1406.88 824.298,1406.88 824.307,1406.88 824.316,1406.88 824.326,1406.88 824.335,1406.88 824.344,1406.88 824.353,1406.88 824.362,1406.88 824.371,1406.88 824.381,1406.88 824.39,1406.88 824.399,1406.88 824.408,1406.88 824.417,1406.88 824.427,1406.88 824.436,1406.88 824.445,1406.88 824.454,1406.88 824.463,1406.88 824.473,1406.88 824.482,1406.88 824.491,1406.88 824.5,1406.88 824.509,1406.88 824.519,1406.88 824.528,1406.88 824.537,1406.88 824.546,1406.88 824.555,1406.88 824.564,1406.88 824.574,1406.88 824.583,1406.88 824.592,1406.88 824.601,1406.88 824.61,1406.88 824.62,1406.88 824.629,1406.88 824.638,1406.88 824.647,1406.88 824.656,1406.88 824.666,1406.88 824.675,1406.88 824.684,1406.88 824.693,1406.88 824.702,1406.88 824.711,1406.88 824.721,1406.88 824.73,1406.88 824.739,1406.88 824.748,1406.88 824.757,1406.88 824.767,1406.88 824.776,1406.88 824.785,1406.88 824.794,1406.88 824.803,1406.88 824.813,1406.88 824.822,1406.88 824.831,1406.88 824.84,1406.88 824.849,1406.88 824.859,1406.88 824.868,1406.88 824.877,1406.88 824.886,1406.88 824.895,1406.88 824.904,1406.88 824.914,1406.88 824.923,1406.88 824.932,1406.88 824.941,1406.88 824.95,1406.88 824.96,1406.88 824.969,1406.88 824.978,1406.88 824.987,1406.88 824.996,1406.88 825.006,1406.88 825.015,1406.88 825.024,1406.88 825.033,1406.88 825.042,1406.88 825.051,1406.88 825.061,1406.88 825.07,1406.88 825.079,1406.88 825.088,1406.88 825.097,1406.88 825.107,1406.88 825.116,1406.88 825.125,1406.88 825.134,1406.88 825.143,1406.88 825.153,1406.88 825.162,1406.88 825.171,1406.88 825.18,1406.88 825.189,1406.88 825.199,1406.88 825.208,1406.88 825.217,1406.88 825.226,1406.88 825.235,1406.88 825.244,1406.88 825.254,1406.88 825.263,1406.88 825.272,1406.88 825.281,1406.88 825.29,1406.88 825.3,1406.88 825.309,1406.88 825.318,1406.88 825.327,1406.88 825.336,1406.88 825.346,1406.88 825.355,1406.88 825.364,1406.88 825.373,1406.88 825.382,1406.88 825.391,1406.88 825.401,1406.88 825.41,1406.88 825.419,1406.88 825.428,1406.88 825.437,1406.88 825.447,1406.88 825.456,1406.88 825.465,1406.88 825.474,1406.88 825.483,1406.88 825.493,1406.88 825.502,1406.88 825.511,1406.88 825.52,1406.88 825.529,1406.88 825.539,1406.88 825.548,1406.88 825.557,1406.88 825.566,1406.88 825.575,1406.88 825.584,1406.88 825.594,1406.88 825.603,1406.88 825.612,1406.88 825.621,1406.88 825.63,1406.88 825.64,1406.88 825.649,1406.88 825.658,1406.88 825.667,1406.88 825.676,1406.88 825.686,1406.88 825.695,1406.88 825.704,1406.88 825.713,1406.88 825.722,1406.88 825.731,1406.88 825.741,1406.88 825.75,1406.88 825.759,1406.88 825.768,1406.88 825.777,1406.88 825.787,1406.88 825.796,1406.88 825.805,1406.88 825.814,1406.88 825.823,1406.88 825.833,1406.88 825.842,1406.88 825.851,1406.88 825.86,1406.88 825.869,1406.88 825.879,1406.88 825.888,1406.88 825.897,1406.88 825.906,1406.88 825.915,1406.88 825.924,1406.88 825.934,1406.88 825.943,1406.88 825.952,1406.88 825.961,1406.88 825.97,1406.88 825.98,1406.88 825.989,1406.88 825.998,1406.88 826.007,1406.88 826.016,1406.88 826.026,1406.88 826.035,1406.88 826.044,1406.88 826.053,1406.88 826.062,1406.88 826.071,1406.88 826.081,1406.88 826.09,1406.88 826.099,1406.88 826.108,1406.88 826.117,1406.88 826.127,1406.88 826.136,1406.88 826.145,1406.88 826.154,1406.88 826.163,1406.88 826.173,1406.88 826.182,1406.88 826.191,1406.88 826.2,1406.88 826.209,1406.88 826.219,1406.88 826.228,1406.88 826.237,1406.88 826.246,1406.88 826.255,1406.88 826.264,1406.88 826.274,1406.88 826.283,1406.88 826.292,1406.88 826.301,1406.88 826.31,1406.88 826.32,1406.88 826.329,1406.88 826.338,1406.88 826.347,1406.88 826.356,1406.88 826.366,1406.88 826.375,1406.88 826.384,1406.88 826.393,1406.88 826.402,1406.88 826.411,1406.88 826.421,1406.88 826.43,1406.88 826.439,1406.88 826.448,1406.88 826.457,1406.88 826.467,1406.88 826.476,1406.88 826.485,1406.88 826.494,1406.88 826.503,1406.88 826.513,1406.88 826.522,1406.88 826.531,1406.88 826.54,1406.88 826.549,1406.88 826.559,1406.88 826.568,1406.88 826.577,1406.88 826.586,1406.88 826.595,1406.88 826.604,1406.88 826.614,1406.88 826.623,1406.88 826.632,1406.88 826.641,1406.88 826.65,1406.88 826.66,1406.88 826.669,1406.88 826.678,1406.88 826.687,1406.88 826.696,1406.88 826.706,1406.88 826.715,1406.88 826.724,1406.88 826.733,1406.88 826.742,1406.88 826.751,1406.88 826.761,1406.88 826.77,1406.88 826.779,1406.88 826.788,1406.88 826.797,1406.88 826.807,1406.88 826.816,1406.88 826.825,1406.88 826.834,1406.88 826.843,1406.88 826.853,1406.88 826.862,1406.88 826.871,1406.88 826.88,1406.88 826.889,1406.88 826.899,1406.88 826.908,1406.88 826.917,1406.88 826.926,1406.88 826.935,1406.88 826.944,1406.88 826.954,1406.88 826.963,1406.88 826.972,1406.88 826.981,1406.88 826.99,1406.88 827,1406.88 827.009,1406.88 827.018,1406.88 827.027,1406.88 827.036,1406.88 827.046,1406.88 827.055,1406.88 827.064,1406.88 827.073,1406.88 827.082,1406.88 827.092,1406.88 827.101,1406.88 827.11,1406.88 827.119,1406.88 827.128,1406.88 827.137,1406.88 827.147,1406.88 827.156,1406.88 827.165,1406.88 827.174,1406.88 827.183,1406.88 827.193,1406.88 827.202,1406.88 827.211,1406.88 827.22,1406.88 827.229,1406.88 827.239,1406.88 827.248,1406.88 827.257,1406.88 827.266,1406.88 827.275,1406.88 827.284,1406.88 827.294,1406.88 827.303,1406.88 827.312,1406.88 827.321,1406.88 827.33,1406.88 827.34,1406.88 827.349,1406.88 827.358,1406.88 827.367,1406.88 827.376,1406.88 827.386,1406.88 827.395,1406.88 827.404,1406.88 827.413,1406.88 827.422,1406.88 827.432,1406.88 827.441,1406.88 827.45,1406.88 827.459,1406.88 827.468,1406.88 827.477,1406.88 827.487,1406.88 827.496,1406.88 827.505,1406.88 827.514,1406.88 827.523,1406.88 827.533,1406.88 827.542,1406.88 827.551,1406.88 827.56,1406.88 827.569,1406.88 827.579,1406.88 827.588,1406.88 827.597,1406.88 827.606,1406.88 827.615,1406.88 827.624,1406.88 827.634,1406.88 827.643,1406.88 827.652,1406.88 827.661,1406.88 827.67,1406.88 827.68,1406.88 827.689,1406.88 827.698,1406.88 827.707,1406.88 827.716,1406.88 827.726,1406.88 827.735,1406.88 827.744,1406.88 827.753,1406.88 827.762,1406.88 827.772,1406.88 827.781,1406.88 827.79,1406.88 827.799,1406.88 827.808,1406.88 827.817,1406.88 827.827,1406.88 827.836,1406.88 827.845,1406.88 827.854,1406.88 827.863,1406.88 827.873,1406.88 827.882,1406.88 827.891,1406.88 827.9,1406.88 827.909,1406.88 827.919,1406.88 827.928,1406.88 827.937,1406.88 827.946,1406.88 827.955,1406.88 827.964,1406.88 827.974,1406.88 827.983,1406.88 827.992,1406.88 828.001,1406.88 828.01,1406.88 828.02,1406.88 828.029,1406.88 828.038,1406.88 828.047,1406.88 828.056,1406.88 828.066,1406.88 828.075,1406.88 828.084,1406.88 828.093,1406.88 828.102,1406.88 828.112,1406.88 828.121,1406.88 828.13,1406.88 828.139,1406.88 828.148,1406.88 828.157,1406.88 828.167,1406.88 828.176,1406.88 828.185,1406.88 828.194,1406.88 828.203,1406.88 828.213,1406.88 828.222,1406.88 828.231,1406.88 828.24,1406.88 828.249,1406.88 828.259,1406.88 828.268,1406.88 828.277,1406.88 828.286,1406.88 828.295,1406.88 828.304,1406.88 828.314,1406.88 828.323,1406.88 828.332,1406.88 828.341,1406.88 828.35,1406.88 828.36,1406.88 828.369,1406.88 828.378,1406.88 828.387,1406.88 828.396,1406.88 828.406,1406.88 828.415,1406.88 828.424,1406.88 828.433,1406.88 828.442,1406.88 828.452,1406.88 828.461,1406.88 828.47,1406.88 828.479,1406.88 828.488,1406.88 828.497,1406.88 828.507,1406.88 828.516,1406.88 828.525,1406.88 828.534,1406.88 828.543,1406.88 828.553,1406.88 828.562,1406.88 828.571,1406.88 828.58,1406.88 828.589,1406.88 828.599,1406.88 828.608,1406.88 828.617,1406.88 828.626,1406.88 828.635,1406.88 828.644,1406.88 828.654,1406.88 828.663,1406.88 828.672,1406.88 828.681,1406.88 828.69,1406.88 828.7,1406.88 828.709,1406.88 828.718,1406.88 828.727,1406.88 828.736,1406.88 828.746,1406.88 828.755,1406.88 828.764,1406.88 828.773,1406.88 828.782,1406.88 828.792,1406.88 828.801,1406.88 828.81,1406.88 828.819,1406.88 828.828,1406.88 828.837,1406.88 828.847,1406.88 828.856,1406.88 828.865,1406.88 828.874,1406.88 828.883,1406.88 828.893,1406.88 828.902,1406.88 828.911,1406.88 828.92,1406.88 828.929,1406.88 828.939,1406.88 828.948,1406.88 828.957,1406.88 828.966,1406.88 828.975,1406.88 828.984,1406.88 828.994,1406.88 829.003,1406.88 829.012,1406.88 829.021,1406.88 829.03,1406.88 829.04,1406.88 829.049,1406.88 829.058,1406.88 829.067,1406.88 829.076,1406.88 829.086,1406.88 829.095,1406.88 829.104,1406.88 829.113,1406.88 829.122,1406.88 829.132,1406.88 829.141,1406.88 829.15,1406.88 829.159,1406.88 829.168,1406.88 829.177,1406.88 829.187,1406.88 829.196,1406.88 829.205,1406.88 829.214,1406.88 829.223,1406.88 829.233,1406.88 829.242,1406.88 829.251,1406.88 829.26,1406.88 829.269,1406.88 829.279,1406.88 829.288,1406.88 829.297,1406.88 829.306,1406.88 829.315,1406.88 829.324,1406.88 829.334,1406.88 829.343,1406.88 829.352,1406.88 829.361,1406.88 829.37,1406.88 829.38,1406.88 829.389,1406.88 829.398,1406.88 829.407,1406.88 829.416,1406.88 829.426,1406.88 829.435,1406.88 829.444,1406.88 829.453,1406.88 829.462,1406.88 829.472,1406.88 829.481,1406.88 829.49,1406.88 829.499,1406.88 829.508,1406.88 829.517,1406.88 829.527,1406.88 829.536,1406.88 829.545,1406.88 829.554,1406.88 829.563,1406.88 829.573,1406.88 829.582,1406.88 829.591,1406.88 829.6,1406.88 829.609,1406.88 829.619,1406.88 829.628,1406.88 829.637,1406.88 829.646,1406.88 829.655,1406.88 829.665,1406.88 829.674,1406.88 829.683,1406.88 829.692,1406.88 829.701,1406.88 829.71,1406.88 829.72,1406.88 829.729,1406.88 829.738,1406.88 829.747,1406.88 829.756,1406.88 829.766,1406.88 829.775,1406.88 829.784,1406.88 829.793,1406.88 829.802,1406.88 829.812,1406.88 829.821,1406.88 829.83,1406.88 829.839,1406.88 829.848,1406.88 829.857,1406.88 829.867,1406.88 829.876,1406.88 829.885,1406.88 829.894,1406.88 829.903,1406.88 829.913,1406.88 829.922,1406.88 829.931,1406.88 829.94,1406.88 829.949,1406.88 829.959,1406.88 829.968,1406.88 829.977,1406.88 829.986,1406.88 829.995,1406.88 830.005,1406.88 830.014,1406.88 830.023,1406.88 830.032,1406.88 830.041,1406.88 830.05,1406.88 830.06,1406.88 830.069,1406.88 830.078,1406.88 830.087,1406.88 830.096,1406.88 830.106,1406.88 830.115,1406.88 830.124,1406.88 830.133,1406.88 830.142,1406.88 830.152,1406.88 830.161,1406.88 830.17,1406.88 830.179,1406.88 830.188,1406.88 830.197,1406.88 830.207,1406.88 830.216,1406.88 830.225,1406.88 830.234,1406.88 830.243,1406.88 830.253,1406.88 830.262,1406.88 830.271,1406.88 830.28,1406.88 830.289,1406.88 830.299,1406.88 830.308,1406.88 830.317,1406.88 830.326,1406.88 830.335,1406.88 830.345,1406.88 830.354,1406.88 830.363,1406.88 830.372,1406.88 830.381,1406.88 830.39,1406.88 830.4,1406.88 830.409,1406.88 830.418,1406.88 830.427,1406.88 830.436,1406.88 830.446,1406.88 830.455,1406.88 830.464,1406.88 830.473,1406.88 830.482,1406.88 830.492,1406.88 830.501,1406.88 830.51,1406.88 830.519,1406.88 830.528,1406.88 830.537,1406.88 830.547,1406.88 830.556,1406.88 830.565,1406.88 830.574,1406.88 830.583,1406.88 830.593,1406.88 830.602,1406.88 830.611,1406.88 830.62,1406.88 830.629,1406.88 830.639,1406.88 830.648,1406.88 830.657,1406.88 830.666,1406.88 830.675,1406.88 830.685,1406.88 830.694,1406.88 830.703,1406.88 830.712,1406.88 830.721,1406.88 830.73,1406.88 830.74,1406.88 830.749,1406.88 830.758,1406.88 830.767,1406.88 830.776,1406.88 830.786,1406.88 830.795,1406.88 830.804,1406.88 830.813,1406.88 830.822,1406.88 830.832,1406.88 830.841,1406.88 830.85,1406.88 830.859,1406.88 830.868,1406.88 830.877,1406.88 830.887,1406.88 830.896,1406.88 830.905,1406.88 830.914,1406.88 830.923,1406.88 830.933,1406.88 830.942,1406.88 830.951,1406.88 830.96,1406.88 830.969,1406.88 830.979,1406.88 830.988,1406.88 830.997,1406.88 831.006,1406.88 831.015,1406.88 831.025,1406.88 831.034,1406.88 831.043,1406.88 831.052,1406.88 831.061,1406.88 831.07,1406.88 831.08,1406.88 831.089,1406.88 831.098,1406.88 831.107,1406.88 831.116,1406.88 831.126,1406.88 831.135,1406.88 831.144,1406.88 831.153,1406.88 831.162,1406.88 831.172,1406.88 831.181,1406.88 831.19,1406.88 831.199,1406.88 831.208,1406.88 831.217,1406.88 831.227,1406.88 831.236,1406.88 831.245,1406.88 831.254,1406.88 831.263,1406.88 831.273,1406.88 831.282,1406.88 831.291,1406.88 831.3,1406.88 831.309,1406.88 831.319,1406.88 831.328,1406.88 831.337,1406.88 831.346,1406.88 831.355,1406.88 831.365,1406.88 831.374,1406.88 831.383,1406.88 831.392,1406.88 831.401,1406.88 831.41,1406.88 831.42,1406.88 831.429,1406.88 831.438,1406.88 831.447,1406.88 831.456,1406.88 831.466,1406.88 831.475,1406.88 831.484,1406.88 831.493,1406.88 831.502,1406.88 831.512,1406.88 831.521,1406.88 831.53,1406.88 831.539,1406.88 831.548,1406.88 831.557,1406.88 831.567,1406.88 831.576,1406.88 831.585,1406.88 831.594,1406.88 831.603,1406.88 831.613,1406.88 831.622,1406.88 831.631,1406.88 831.64,1406.88 831.649,1406.88 831.659,1406.88 831.668,1406.88 831.677,1406.88 831.686,1406.88 831.695,1406.88 831.705,1406.88 831.714,1406.88 831.723,1406.88 831.732,1406.88 831.741,1406.88 831.75,1406.88 831.76,1406.88 831.769,1406.88 831.778,1406.88 831.787,1406.88 831.796,1406.88 831.806,1406.88 831.815,1406.88 831.824,1406.88 831.833,1406.88 831.842,1406.88 831.852,1406.88 831.861,1406.88 831.87,1406.88 831.879,1406.88 831.888,1406.88 831.898,1406.88 831.907,1406.88 831.916,1406.88 831.925,1406.88 831.934,1406.88 831.943,1406.88 831.953,1406.88 831.962,1406.88 831.971,1406.88 831.98,1406.88 831.989,1406.88 831.999,1406.88 832.008,1406.88 832.017,1406.88 832.026,1406.88 832.035,1406.88 832.045,1406.88 832.054,1406.88 832.063,1406.88 832.072,1406.88 832.081,1406.88 832.09,1406.88 832.1,1406.88 832.109,1406.88 832.118,1406.88 832.127,1406.88 832.136,1406.88 832.146,1406.88 832.155,1406.88 832.164,1406.88 832.173,1406.88 832.182,1406.88 832.192,1406.88 832.201,1406.88 832.21,1406.88 832.219,1406.88 832.228,1406.88 832.238,1406.88 832.247,1406.88 832.256,1406.88 832.265,1406.88 832.274,1406.88 832.283,1406.88 832.293,1406.88 832.302,1406.88 832.311,1406.88 832.32,1406.88 832.329,1406.88 832.339,1406.88 832.348,1406.88 832.357,1406.88 832.366,1406.88 832.375,1406.88 832.385,1406.88 832.394,1406.88 832.403,1406.88 832.412,1406.88 832.421,1406.88 832.43,1406.88 832.44,1406.88 832.449,1406.88 832.458,1406.88 832.467,1406.88 832.476,1406.88 832.486,1406.88 832.495,1406.88 832.504,1406.88 832.513,1406.88 832.522,1406.88 832.532,1406.88 832.541,1406.88 832.55,1406.88 832.559,1406.88 832.568,1406.88 832.578,1406.88 832.587,1406.88 832.596,1406.88 832.605,1406.88 832.614,1406.88 832.623,1406.88 832.633,1406.88 832.642,1406.88 832.651,1406.88 832.66,1406.88 832.669,1406.88 832.679,1406.88 832.688,1406.88 832.697,1406.88 832.706,1406.88 832.715,1406.88 832.725,1406.88 832.734,1406.88 832.743,1406.88 832.752,1406.88 832.761,1406.88 832.77,1406.88 832.78,1406.88 832.789,1406.88 832.798,1406.88 832.807,1406.88 832.816,1406.88 832.826,1406.88 832.835,1406.88 832.844,1406.88 832.853,1406.88 832.862,1406.88 832.872,1406.88 832.881,1406.88 832.89,1406.88 832.899,1406.88 832.908,1406.88 832.918,1406.88 832.927,1406.88 832.936,1406.88 832.945,1406.88 832.954,1406.88 832.963,1406.88 832.973,1406.88 832.982,1406.88 832.991,1406.88 833,1406.88 833.009,1406.88 833.019,1406.88 833.028,1406.88 833.037,1406.88 833.046,1406.88 833.055,1406.88 833.065,1406.88 833.074,1406.88 833.083,1406.88 833.092,1406.88 833.101,1406.88 833.11,1406.88 833.12,1406.88 833.129,1406.88 833.138,1406.88 833.147,1406.88 833.156,1406.88 833.166,1406.88 833.175,1406.88 833.184,1406.88 833.193,1406.88 833.202,1406.88 833.212,1406.88 833.221,1406.88 833.23,1406.88 833.239,1406.88 833.248,1406.88 833.258,1406.88 833.267,1406.88 833.276,1406.88 833.285,1406.88 833.294,1406.88 833.303,1406.88 833.313,1406.88 833.322,1406.88 833.331,1406.88 833.34,1406.88 833.349,1406.88 833.359,1406.88 833.368,1406.88 833.377,1406.88 833.386,1406.88 833.395,1406.88 833.405,1406.88 833.414,1406.88 833.423,1406.88 833.432,1406.88 833.441,1406.88 833.45,1406.88 833.46,1406.88 833.469,1406.88 833.478,1406.88 833.487,1406.88 833.496,1406.88 833.506,1406.88 833.515,1406.88 833.524,1406.88 833.533,1406.88 833.542,1406.88 833.552,1406.88 833.561,1406.88 833.57,1406.88 833.579,1406.88 833.588,1406.88 833.598,1406.88 833.607,1406.88 833.616,1406.88 833.625,1406.88 833.634,1406.88 833.643,1406.88 833.653,1406.88 833.662,1406.88 833.671,1406.88 833.68,1406.88 833.689,1406.88 833.699,1406.88 833.708,1406.88 833.717,1406.88 833.726,1406.88 833.735,1406.88 833.745,1406.88 833.754,1406.88 833.763,1406.88 833.772,1406.88 833.781,1406.88 833.79,1406.88 833.8,1406.88 833.809,1406.88 833.818,1406.88 833.827,1406.88 833.836,1406.88 833.846,1406.88 833.855,1406.88 833.864,1406.88 833.873,1406.88 833.882,1406.88 833.892,1406.88 833.901,1406.88 833.91,1406.88 833.919,1406.88 833.928,1406.88 833.938,1406.88 833.947,1406.88 833.956,1406.88 833.965,1406.88 833.974,1406.88 833.983,1406.88 833.993,1406.88 834.002,1406.88 834.011,1406.88 834.02,1406.88 834.029,1406.88 834.039,1406.88 834.048,1406.88 834.057,1406.88 834.066,1406.88 834.075,1406.88 834.085,1406.88 834.094,1406.88 834.103,1406.88 834.112,1406.88 834.121,1406.88 834.13,1406.88 834.14,1406.88 834.149,1406.88 834.158,1406.88 834.167,1406.88 834.176,1406.88 834.186,1406.88 834.195,1406.88 834.204,1406.88 834.213,1406.88 834.222,1406.88 834.232,1406.88 834.241,1406.88 834.25,1406.88 834.259,1406.88 834.268,1406.88 834.278,1406.88 834.287,1406.88 834.296,1406.88 834.305,1406.88 834.314,1406.88 834.323,1406.88 834.333,1406.88 834.342,1406.88 834.351,1406.88 834.36,1406.88 834.369,1406.88 834.379,1406.88 834.388,1406.88 834.397,1406.88 834.406,1406.88 834.415,1406.88 834.425,1406.88 834.434,1406.88 834.443,1406.88 834.452,1406.88 834.461,1406.88 834.471,1406.88 834.48,1406.88 834.489,1406.88 834.498,1406.88 834.507,1406.88 834.516,1406.88 834.526,1406.88 834.535,1406.88 834.544,1406.88 834.553,1406.88 834.562,1406.88 834.572,1406.88 834.581,1406.88 834.59,1406.88 834.599,1406.88 834.608,1406.88 834.618,1406.88 834.627,1406.88 834.636,1406.88 834.645,1406.88 834.654,1406.88 834.663,1406.88 834.673,1406.88 834.682,1406.88 834.691,1406.88 834.7,1406.88 834.709,1406.88 834.719,1406.88 834.728,1406.88 834.737,1406.88 834.746,1406.88 834.755,1406.88 834.765,1406.88 834.774,1406.88 834.783,1406.88 834.792,1406.88 834.801,1406.88 834.811,1406.88 834.82,1406.88 834.829,1406.88 834.838,1406.88 834.847,1406.88 834.856,1406.88 834.866,1406.88 834.875,1406.88 834.884,1406.88 834.893,1406.88 834.902,1406.88 834.912,1406.88 834.921,1406.88 834.93,1406.88 834.939,1406.88 834.948,1406.88 834.958,1406.88 834.967,1406.88 834.976,1406.88 834.985,1406.88 834.994,1406.88 835.003,1406.88 835.013,1406.88 835.022,1406.88 835.031,1406.88 835.04,1406.88 835.049,1406.88 835.059,1406.88 835.068,1406.88 835.077,1406.88 835.086,1406.88 835.095,1406.88 835.105,1406.88 835.114,1406.88 835.123,1406.88 835.132,1406.88 835.141,1406.88 835.151,1406.88 835.16,1406.88 835.169,1406.88 835.178,1406.88 835.187,1406.88 835.196,1406.88 835.206,1406.88 835.215,1406.88 835.224,1406.88 835.233,1406.88 835.242,1406.88 835.252,1406.88 835.261,1406.88 835.27,1406.88 835.279,1406.88 835.288,1406.88 835.298,1406.88 835.307,1406.88 835.316,1406.88 835.325,1406.88 835.334,1406.88 835.343,1406.88 835.353,1406.88 835.362,1406.88 835.371,1406.88 835.38,1406.88 835.389,1406.88 835.399,1406.88 835.408,1406.88 835.417,1406.88 835.426,1406.88 835.435,1406.88 835.445,1406.88 835.454,1406.88 835.463,1406.88 835.472,1406.88 835.481,1406.88 835.491,1406.88 835.5,1406.88 835.509,1406.88 835.518,1406.88 835.527,1406.88 835.536,1406.88 835.546,1406.88 835.555,1406.88 835.564,1406.88 835.573,1406.88 835.582,1406.88 835.592,1406.88 835.601,1406.88 835.61,1406.88 835.619,1406.88 835.628,1406.88 835.638,1406.88 835.647,1406.88 835.656,1406.88 835.665,1406.88 835.674,1406.88 835.683,1406.88 835.693,1406.88 835.702,1406.88 835.711,1406.88 835.72,1406.88 835.729,1406.88 835.739,1406.88 835.748,1406.88 835.757,1406.88 835.766,1406.88 835.775,1406.88 835.785,1406.88 835.794,1406.88 835.803,1406.88 835.812,1406.88 835.821,1406.88 835.831,1406.88 835.84,1406.88 835.849,1406.88 835.858,1406.88 835.867,1406.88 835.876,1406.88 835.886,1406.88 835.895,1406.88 835.904,1406.88 835.913,1406.88 835.922,1406.88 835.932,1406.88 835.941,1406.88 835.95,1406.88 835.959,1406.88 835.968,1406.88 835.978,1406.88 835.987,1406.88 835.996,1406.88 836.005,1406.88 836.014,1406.88 836.023,1406.88 836.033,1406.88 836.042,1406.88 836.051,1406.88 836.06,1406.88 836.069,1406.88 836.079,1406.88 836.088,1406.88 836.097,1406.88 836.106,1406.88 836.115,1406.88 836.125,1406.88 836.134,1406.88 836.143,1406.88 836.152,1406.88 836.161,1406.88 836.171,1406.88 836.18,1406.88 836.189,1406.88 836.198,1406.88 836.207,1406.88 836.216,1406.88 836.226,1406.88 836.235,1406.88 836.244,1406.88 836.253,1406.88 836.262,1406.88 836.272,1406.88 836.281,1406.88 836.29,1406.88 836.299,1406.88 836.308,1406.88 836.318,1406.88 836.327,1406.88 836.336,1406.88 836.345,1406.88 836.354,1406.88 836.363,1406.88 836.373,1406.88 836.382,1406.88 836.391,1406.88 836.4,1406.88 836.409,1406.88 836.419,1406.88 836.428,1406.88 836.437,1406.88 836.446,1406.88 836.455,1406.88 836.465,1406.88 836.474,1406.88 836.483,1406.88 836.492,1406.88 836.501,1406.88 836.511,1406.88 836.52,1406.88 836.529,1406.88 836.538,1406.88 836.547,1406.88 836.556,1406.88 836.566,1406.88 836.575,1406.88 836.584,1406.88 836.593,1406.88 836.602,1406.88 836.612,1406.88 836.621,1406.88 836.63,1406.88 836.639,1406.88 836.648,1406.88 836.658,1406.88 836.667,1406.88 836.676,1406.88 836.685,1406.88 836.694,1406.88 836.703,1406.88 836.713,1406.88 836.722,1406.88 836.731,1406.88 836.74,1406.88 836.749,1406.88 836.759,1406.88 836.768,1406.88 836.777,1406.88 836.786,1406.88 836.795,1406.88 836.805,1406.88 836.814,1406.88 836.823,1406.88 836.832,1406.88 836.841,1406.88 836.851,1406.88 836.86,1406.88 836.869,1406.88 836.878,1406.88 836.887,1406.88 836.896,1406.88 836.906,1406.88 836.915,1406.88 836.924,1406.88 836.933,1406.88 836.942,1406.88 836.952,1406.88 836.961,1406.88 836.97,1406.88 836.979,1406.88 836.988,1406.88 836.998,1406.88 837.007,1406.88 837.016,1406.88 837.025,1406.88 837.034,1406.88 837.044,1406.88 837.053,1406.88 837.062,1406.88 837.071,1406.88 837.08,1406.88 837.089,1406.88 837.099,1406.88 837.108,1406.88 837.117,1406.88 837.126,1406.88 837.135,1406.88 837.145,1406.88 837.154,1406.88 837.163,1406.88 837.172,1406.88 837.181,1406.88 837.191,1406.88 837.2,1406.88 837.209,1406.88 837.218,1406.88 837.227,1406.88 837.236,1406.88 837.246,1406.88 837.255,1406.88 837.264,1406.88 837.273,1406.88 837.282,1406.88 837.292,1406.88 837.301,1406.88 837.31,1406.88 837.319,1406.88 837.328,1406.88 837.338,1406.88 837.347,1406.88 837.356,1406.88 837.365,1406.88 837.374,1406.88 837.384,1406.88 837.393,1406.88 837.402,1406.88 837.411,1406.88 837.42,1406.88 837.429,1406.88 837.439,1406.88 837.448,1406.88 837.457,1406.88 837.466,1406.88 837.475,1406.88 837.485,1406.88 837.494,1406.88 837.503,1406.88 837.512,1406.88 837.521,1406.88 837.531,1406.88 837.54,1406.88 837.549,1406.88 837.558,1406.88 837.567,1406.88 837.576,1406.88 837.586,1406.88 837.595,1406.88 837.604,1406.88 837.613,1406.88 837.622,1406.88 837.632,1406.88 837.641,1406.88 837.65,1406.88 837.659,1406.88 837.668,1406.88 837.678,1406.88 837.687,1406.88 837.696,1406.88 837.705,1406.88 837.714,1406.88 837.724,1406.88 837.733,1406.88 837.742,1406.88 837.751,1406.88 837.76,1406.88 837.769,1406.88 837.779,1406.88 837.788,1406.88 837.797,1406.88 837.806,1406.88 837.815,1406.88 837.825,1406.88 837.834,1406.88 837.843,1406.88 837.852,1406.88 837.861,1406.88 837.871,1406.88 837.88,1406.88 837.889,1406.88 837.898,1406.88 837.907,1406.88 837.916,1406.88 837.926,1406.88 837.935,1406.88 837.944,1406.88 837.953,1406.88 837.962,1406.88 837.972,1406.88 837.981,1406.88 837.99,1406.88 837.999,1406.88 838.008,1406.88 838.018,1406.88 838.027,1406.88 838.036,1406.88 838.045,1406.88 838.054,1406.88 838.064,1406.88 838.073,1406.88 838.082,1406.88 838.091,1406.88 838.1,1406.88 838.109,1406.88 838.119,1406.88 838.128,1406.88 838.137,1406.88 838.146,1406.88 838.155,1406.88 838.165,1406.88 838.174,1406.88 838.183,1406.88 838.192,1406.88 838.201,1406.88 838.211,1406.88 838.22,1406.88 838.229,1406.88 838.238,1406.88 838.247,1406.88 838.256,1406.88 838.266,1406.88 838.275,1406.88 838.284,1406.88 838.293,1406.88 838.302,1406.88 838.312,1406.88 838.321,1406.88 838.33,1406.88 838.339,1406.88 838.348,1406.88 838.358,1406.88 838.367,1406.88 838.376,1406.88 838.385,1406.88 838.394,1406.88 838.404,1406.88 838.413,1406.88 838.422,1406.88 838.431,1406.88 838.44,1406.88 838.449,1406.88 838.459,1406.88 838.468,1406.88 838.477,1406.88 838.486,1406.88 838.495,1406.88 838.505,1406.88 838.514,1406.88 838.523,1406.88 838.532,1406.88 838.541,1406.88 838.551,1406.88 838.56,1406.88 838.569,1406.88 838.578,1406.88 838.587,1406.88 838.596,1406.88 838.606,1406.88 838.615,1406.88 838.624,1406.88 838.633,1406.88 838.642,1406.88 838.652,1406.88 838.661,1406.88 838.67,1406.88 838.679,1406.88 838.688,1406.88 838.698,1406.88 838.707,1406.88 838.716,1406.88 838.725,1406.88 838.734,1406.88 838.744,1406.88 838.753,1406.88 838.762,1406.88 838.771,1406.88 838.78,1406.88 838.789,1406.88 838.799,1406.88 838.808,1406.88 838.817,1406.88 838.826,1406.88 838.835,1406.88 838.845,1406.88 838.854,1406.88 838.863,1406.88 838.872,1406.88 838.881,1406.88 838.891,1406.88 838.9,1406.88 838.909,1406.88 838.918,1406.88 838.927,1406.88 838.936,1406.88 838.946,1406.88 838.955,1406.88 838.964,1406.88 838.973,1406.88 838.982,1406.88 838.992,1406.88 839.001,1406.88 839.01,1406.88 839.019,1406.88 839.028,1406.88 839.038,1406.88 839.047,1406.88 839.056,1406.88 839.065,1406.88 839.074,1406.88 839.084,1406.88 839.093,1406.88 839.102,1406.88 839.111,1406.88 839.12,1406.88 839.129,1406.88 839.139,1406.88 839.148,1406.88 839.157,1406.88 839.166,1406.88 839.175,1406.88 839.185,1406.88 839.194,1406.88 839.203,1406.88 839.212,1406.88 839.221,1406.88 839.231,1406.88 839.24,1406.88 839.249,1406.88 839.258,1406.88 839.267,1406.88 839.277,1406.88 839.286,1406.88 839.295,1406.88 839.304,1406.88 839.313,1406.88 839.322,1406.88 839.332,1406.88 839.341,1406.88 839.35,1406.88 839.359,1406.88 839.368,1406.88 839.378,1406.88 839.387,1406.88 839.396,1406.88 839.405,1406.88 839.414,1406.88 839.424,1406.88 839.433,1406.88 839.442,1406.88 839.451,1406.88 839.46,1406.88 839.469,1406.88 839.479,1406.88 839.488,1406.88 839.497,1406.88 839.506,1406.88 839.515,1406.88 839.525,1406.88 839.534,1406.88 839.543,1406.88 839.552,1406.88 839.561,1406.88 839.571,1406.88 839.58,1406.88 839.589,1406.88 839.598,1406.88 839.607,1406.88 839.617,1406.88 839.626,1406.88 839.635,1406.88 839.644,1406.88 839.653,1406.88 839.662,1406.88 839.672,1406.88 839.681,1406.88 839.69,1406.88 839.699,1406.88 839.708,1406.88 839.718,1406.88 839.727,1406.88 839.736,1406.88 839.745,1406.88 839.754,1406.88 839.764,1406.88 839.773,1406.88 839.782,1406.88 839.791,1406.88 839.8,1406.88 839.809,1406.88 839.819,1406.88 839.828,1406.88 839.837,1406.88 839.846,1406.88 839.855,1406.88 839.865,1406.88 839.874,1406.88 839.883,1406.88 839.892,1406.88 839.901,1406.88 839.911,1406.88 839.92,1406.88 839.929,1406.88 839.938,1406.88 839.947,1406.88 839.957,1406.88 839.966,1406.88 839.975,1406.88 839.984,1406.88 839.993,1406.88 840.002,1406.88 840.012,1406.88 840.021,1406.88 840.03,1406.88 840.039,1406.88 840.048,1406.88 840.058,1406.88 840.067,1406.88 840.076,1406.88 840.085,1406.88 840.094,1406.88 840.104,1406.88 840.113,1406.88 840.122,1406.88 840.131,1406.88 840.14,1406.88 840.149,1406.88 840.159,1406.88 840.168,1406.88 840.177,1406.88 840.186,1406.88 840.195,1406.88 840.205,1406.88 840.214,1406.88 840.223,1406.88 840.232,1406.88 840.241,1406.88 840.251,1406.88 840.26,1406.88 840.269,1406.88 840.278,1406.88 840.287,1406.88 840.297,1406.88 840.306,1406.88 840.315,1406.88 840.324,1406.88 840.333,1406.88 840.342,1406.88 840.352,1406.88 840.361,1406.88 840.37,1406.88 840.379,1406.88 840.388,1406.88 840.398,1406.88 840.407,1406.88 840.416,1406.88 840.425,1406.88 840.434,1406.88 840.444,1406.88 840.453,1406.88 840.462,1406.88 840.471,1406.88 840.48,1406.88 840.489,1406.88 840.499,1406.88 840.508,1406.88 840.517,1406.88 840.526,1406.88 840.535,1406.88 840.545,1406.88 840.554,1406.88 840.563,1406.88 840.572,1406.88 840.581,1406.88 840.591,1406.88 840.6,1406.88 840.609,1406.88 840.618,1406.88 840.627,1406.88 840.637,1406.88 840.646,1406.88 840.655,1406.88 840.664,1406.88 840.673,1406.88 840.682,1406.88 840.692,1406.88 840.701,1406.88 840.71,1406.88 840.719,1406.88 840.728,1406.88 840.738,1406.88 840.747,1406.88 840.756,1406.88 840.765,1406.88 840.774,1406.88 840.784,1406.88 840.793,1406.88 840.802,1406.88 840.811,1406.88 840.82,1406.88 840.829,1406.88 840.839,1406.88 840.848,1406.88 840.857,1406.88 840.866,1406.88 840.875,1406.88 840.885,1406.88 840.894,1406.88 840.903,1406.88 840.912,1406.88 840.921,1406.88 840.931,1406.88 840.94,1406.88 840.949,1406.88 840.958,1406.88 840.967,1406.88 840.977,1406.88 840.986,1406.88 840.995,1406.88 841.004,1406.88 841.013,1406.88 841.022,1406.88 841.032,1406.88 841.041,1406.88 841.05,1406.88 841.059,1406.88 841.068,1406.88 841.078,1406.88 841.087,1406.88 841.096,1406.88 841.105,1406.88 841.114,1406.88 841.124,1406.88 841.133,1406.88 841.142,1406.88 841.151,1406.88 841.16,1406.88 841.169,1406.88 841.179,1406.88 841.188,1406.88 841.197,1406.88 841.206,1406.88 841.215,1406.88 841.225,1406.88 841.234,1406.88 841.243,1406.88 841.252,1406.88 841.261,1406.88 841.271,1406.88 841.28,1406.88 841.289,1406.88 841.298,1406.88 841.307,1406.88 841.317,1406.88 841.326,1406.88 841.335,1406.88 841.344,1406.88 841.353,1406.88 841.362,1406.88 841.372,1406.88 841.381,1406.88 841.39,1406.88 841.399,1406.88 841.408,1406.88 841.418,1406.88 841.427,1406.88 841.436,1406.88 841.445,1406.88 841.454,1406.88 841.464,1406.88 841.473,1406.88 841.482,1406.88 841.491,1406.88 841.5,1406.88 841.509,1406.88 841.519,1406.88 841.528,1406.88 841.537,1406.88 841.546,1406.88 841.555,1406.88 841.565,1406.88 841.574,1406.88 841.583,1406.88 841.592,1406.88 841.601,1406.88 841.611,1406.88 841.62,1406.88 841.629,1406.88 841.638,1406.88 841.647,1406.88 841.657,1406.88 841.666,1406.88 841.675,1406.88 841.684,1406.88 841.693,1406.88 841.702,1406.88 841.712,1406.88 841.721,1406.88 841.73,1406.88 841.739,1406.88 841.748,1406.88 841.758,1406.88 841.767,1406.88 841.776,1406.88 841.785,1406.88 841.794,1406.88 841.804,1406.88 841.813,1406.88 841.822,1406.88 841.831,1406.88 841.84,1406.88 841.85,1406.88 841.859,1406.88 841.868,1406.88 841.877,1406.88 841.886,1406.88 841.895,1406.88 841.905,1406.88 841.914,1406.88 841.923,1406.88 841.932,1406.88 841.941,1406.88 841.951,1406.88 841.96,1406.88 841.969,1406.88 841.978,1406.88 841.987,1406.88 841.997,1406.88 842.006,1406.88 842.015,1406.88 842.024,1406.88 842.033,1406.88 842.042,1406.88 842.052,1406.88 842.061,1406.88 842.07,1406.88 842.079,1406.88 842.088,1406.88 842.098,1406.88 842.107,1406.88 842.116,1406.88 842.125,1406.88 842.134,1406.88 842.144,1406.88 842.153,1406.88 842.162,1406.88 842.171,1406.88 842.18,1406.88 842.19,1406.88 842.199,1406.88 842.208,1406.88 842.217,1406.88 842.226,1406.88 842.235,1406.88 842.245,1406.88 842.254,1406.88 842.263,1406.88 842.272,1406.88 842.281,1406.88 842.291,1406.88 842.3,1406.88 842.309,1406.88 842.318,1406.88 842.327,1406.88 842.337,1406.88 842.346,1406.88 842.355,1406.88 842.364,1406.88 842.373,1406.88 842.382,1406.88 842.392,1406.88 842.401,1406.88 842.41,1406.88 842.419,1406.88 842.428,1406.88 842.438,1406.88 842.447,1406.88 842.456,1406.88 842.465,1406.88 842.474,1406.88 842.484,1406.88 842.493,1406.88 842.502,1406.88 842.511,1406.88 842.52,1406.88 842.53,1406.88 842.539,1406.88 842.548,1406.88 842.557,1406.88 842.566,1406.88 842.575,1406.88 842.585,1406.88 842.594,1406.88 842.603,1406.88 842.612,1406.88 842.621,1406.88 842.631,1406.88 842.64,1406.88 842.649,1406.88 842.658,1406.88 842.667,1406.88 842.677,1406.88 842.686,1406.88 842.695,1406.88 842.704,1406.88 842.713,1406.88 842.722,1406.88 842.732,1406.88 842.741,1406.88 842.75,1406.88 842.759,1406.88 842.768,1406.88 842.778,1406.88 842.787,1406.88 842.796,1406.88 842.805,1406.88 842.814,1406.88 842.824,1406.88 842.833,1406.88 842.842,1406.88 842.851,1406.88 842.86,1406.88 842.87,1406.88 842.879,1406.88 842.888,1406.88 842.897,1406.88 842.906,1406.88 842.915,1406.88 842.925,1406.88 842.934,1406.88 842.943,1406.88 842.952,1406.88 842.961,1406.88 842.971,1406.88 842.98,1406.88 842.989,1406.88 842.998,1406.88 843.007,1406.88 843.017,1406.88 843.026,1406.88 843.035,1406.88 843.044,1406.88 843.053,1406.88 843.062,1406.88 843.072,1406.88 843.081,1406.88 843.09,1406.88 843.099,1406.88 843.108,1406.88 843.118,1406.88 843.127,1406.88 843.136,1406.88 843.145,1406.88 843.154,1406.88 843.164,1406.88 843.173,1406.88 843.182,1406.88 843.191,1406.88 843.2,1406.88 843.21,1406.88 843.219,1406.88 843.228,1406.88 843.237,1406.88 843.246,1406.88 843.255,1406.88 843.265,1406.88 843.274,1406.88 843.283,1406.88 843.292,1406.88 843.301,1406.88 843.311,1406.88 843.32,1406.88 843.329,1406.88 843.338,1406.88 843.347,1406.88 843.357,1406.88 843.366,1406.88 843.375,1406.88 843.384,1406.88 843.393,1406.88 843.402,1406.88 843.412,1406.88 843.421,1406.88 843.43,1406.88 843.439,1406.88 843.448,1406.88 843.458,1406.88 843.467,1406.88 843.476,1406.88 843.485,1406.88 843.494,1406.88 843.504,1406.88 843.513,1406.88 843.522,1406.88 843.531,1406.88 843.54,1406.88 843.55,1406.88 843.559,1406.88 843.568,1406.88 843.577,1406.88 843.586,1406.88 843.595,1406.88 843.605,1406.88 843.614,1406.88 843.623,1406.88 843.632,1406.88 843.641,1406.88 843.651,1406.88 843.66,1406.88 843.669,1406.88 843.678,1406.88 843.687,1406.88 843.697,1406.88 843.706,1406.88 843.715,1406.88 843.724,1406.88 843.733,1406.88 843.742,1406.88 843.752,1406.88 843.761,1406.88 843.77,1406.88 843.779,1406.88 843.788,1406.88 843.798,1406.88 843.807,1406.88 843.816,1406.88 843.825,1406.88 843.834,1406.88 843.844,1406.88 843.853,1406.88 843.862,1406.88 843.871,1406.88 843.88,1406.88 843.89,1406.88 843.899,1406.88 843.908,1406.88 843.917,1406.88 843.926,1406.88 843.935,1406.88 843.945,1406.88 843.954,1406.88 843.963,1406.88 843.972,1406.88 843.981,1406.88 843.991,1406.88 844,1406.88 844.009,1406.88 844.018,1406.88 844.027,1406.88 844.037,1406.88 844.046,1406.88 844.055,1406.88 844.064,1406.88 844.073,1406.88 844.082,1406.88 844.092,1406.88 844.101,1406.88 844.11,1406.88 844.119,1406.88 844.128,1406.88 844.138,1406.88 844.147,1406.88 844.156,1406.88 844.165,1406.88 844.174,1406.88 844.184,1406.88 844.193,1406.88 844.202,1406.88 844.211,1406.88 844.22,1406.88 844.23,1406.88 844.239,1406.88 844.248,1406.88 844.257,1406.88 844.266,1406.88 844.275,1406.88 844.285,1406.88 844.294,1406.88 844.303,1406.88 844.312,1406.88 844.321,1406.88 844.331,1406.88 844.34,1406.88 844.349,1406.88 844.358,1406.88 844.367,1406.88 844.377,1406.88 844.386,1406.88 844.395,1406.88 844.404,1406.88 844.413,1406.88 844.423,1406.88 844.432,1406.88 844.441,1406.88 844.45,1406.88 844.459,1406.88 844.468,1406.88 844.478,1406.88 844.487,1406.88 844.496,1406.88 844.505,1406.88 844.514,1406.88 844.524,1406.88 844.533,1406.88 844.542,1406.88 844.551,1406.88 844.56,1406.88 844.57,1406.88 844.579,1406.88 844.588,1406.88 844.597,1406.88 844.606,1406.88 844.615,1406.88 844.625,1406.88 844.634,1406.88 844.643,1406.88 844.652,1406.88 844.661,1406.88 844.671,1406.88 844.68,1406.88 844.689,1406.88 844.698,1406.88 844.707,1406.88 844.717,1406.88 844.726,1406.88 844.735,1406.88 844.744,1406.88 844.753,1406.88 844.763,1406.88 844.772,1406.88 844.781,1406.88 844.79,1406.88 844.799,1406.88 844.808,1406.88 844.818,1406.88 844.827,1406.88 844.836,1406.88 844.845,1406.88 844.854,1406.88 844.864,1406.88 844.873,1406.88 844.882,1406.88 844.891,1406.88 844.9,1406.88 844.91,1406.88 844.919,1406.88 844.928,1406.88 844.937,1406.88 844.946,1406.88 844.955,1406.88 844.965,1406.88 844.974,1406.88 844.983,1406.88 844.992,1406.88 845.001,1406.88 845.011,1406.88 845.02,1406.88 845.029,1406.88 845.038,1406.88 845.047,1406.88 845.057,1406.88 845.066,1406.88 845.075,1406.88 845.084,1406.88 845.093,1406.88 845.103,1406.88 845.112,1406.88 845.121,1406.88 845.13,1406.88 845.139,1406.88 845.148,1406.88 845.158,1406.88 845.167,1406.88 845.176,1406.88 845.185,1406.88 845.194,1406.88 845.204,1406.88 845.213,1406.88 845.222,1406.88 845.231,1406.88 845.24,1406.88 845.25,1406.88 845.259,1406.88 845.268,1406.88 845.277,1406.88 845.286,1406.88 845.295,1406.88 845.305,1406.88 845.314,1406.88 845.323,1406.88 845.332,1406.88 845.341,1406.88 845.351,1406.88 845.36,1406.88 845.369,1406.88 845.378,1406.88 845.387,1406.88 845.397,1406.88 845.406,1406.88 845.415,1406.88 845.424,1406.88 845.433,1406.88 845.443,1406.88 845.452,1406.88 845.461,1406.88 845.47,1406.88 845.479,1406.88 845.488,1406.88 845.498,1406.88 845.507,1406.88 845.516,1406.88 845.525,1406.88 845.534,1406.88 845.544,1406.88 845.553,1406.88 845.562,1406.88 845.571,1406.88 845.58,1406.88 845.59,1406.88 845.599,1406.88 845.608,1406.88 845.617,1406.88 845.626,1406.88 845.635,1406.88 845.645,1406.88 845.654,1406.88 845.663,1406.88 845.672,1406.88 845.681,1406.88 845.691,1406.88 845.7,1406.88 845.709,1406.88 845.718,1406.88 845.727,1406.88 845.737,1406.88 845.746,1406.88 845.755,1406.88 845.764,1406.88 845.773,1406.88 845.783,1406.88 845.792,1406.88 845.801,1406.88 845.81,1406.88 845.819,1406.88 845.828,1406.88 845.838,1406.88 845.847,1406.88 845.856,1406.88 845.865,1406.88 845.874,1406.88 845.884,1406.88 845.893,1406.88 845.902,1406.88 845.911,1406.88 845.92,1406.88 845.93,1406.88 845.939,1406.88 845.948,1406.88 845.957,1406.88 845.966,1406.88 845.975,1406.88 845.985,1406.88 845.994,1406.88 846.003,1406.88 846.012,1406.88 846.021,1406.88 846.031,1406.88 846.04,1406.88 846.049,1406.88 846.058,1406.88 846.067,1406.88 846.077,1406.88 846.086,1406.88 846.095,1406.88 846.104,1406.88 846.113,1406.88 846.123,1406.88 846.132,1406.88 846.141,1406.88 846.15,1406.88 846.159,1406.88 846.168,1406.88 846.178,1406.88 846.187,1406.88 846.196,1406.88 846.205,1406.88 846.214,1406.88 846.224,1406.88 846.233,1406.88 846.242,1406.88 846.251,1406.88 846.26,1406.88 846.27,1406.88 846.279,1406.88 846.288,1406.88 846.297,1406.88 846.306,1406.88 846.315,1406.88 846.325,1406.88 846.334,1406.88 846.343,1406.88 846.352,1406.88 846.361,1406.88 846.371,1406.88 846.38,1406.88 846.389,1406.88 846.398,1406.88 846.407,1406.88 846.417,1406.88 846.426,1406.88 846.435,1406.88 846.444,1406.88 846.453,1406.88 846.463,1406.88 846.472,1406.88 846.481,1406.88 846.49,1406.88 846.499,1406.88 846.508,1406.88 846.518,1406.88 846.527,1406.88 846.536,1406.88 846.545,1406.88 846.554,1406.88 846.564,1406.88 846.573,1406.88 846.582,1406.88 846.591,1406.88 846.6,1406.88 846.61,1406.88 846.619,1406.88 846.628,1406.88 846.637,1406.88 846.646,1406.88 846.656,1406.88 846.665,1406.88 846.674,1406.88 846.683,1406.88 846.692,1406.88 846.701,1406.88 846.711,1406.88 846.72,1406.88 846.729,1406.88 846.738,1406.88 846.747,1406.88 846.757,1406.88 846.766,1406.88 846.775,1406.88 846.784,1406.88 846.793,1406.88 846.803,1406.88 846.812,1406.88 846.821,1406.88 846.83,1406.88 846.839,1406.88 846.848,1406.88 846.858,1406.88 846.867,1406.88 846.876,1406.88 846.885,1406.88 846.894,1406.88 846.904,1406.88 846.913,1406.88 846.922,1406.88 846.931,1406.88 846.94,1406.88 846.95,1406.88 846.959,1406.88 846.968,1406.88 846.977,1406.88 846.986,1406.88 846.996,1406.88 847.005,1406.88 847.014,1406.88 847.023,1406.88 847.032,1406.88 847.041,1406.88 847.051,1406.88 847.06,1406.88 847.069,1406.88 847.078,1406.88 847.087,1406.88 847.097,1406.88 847.106,1406.88 847.115,1406.88 847.124,1406.88 847.133,1406.88 847.143,1406.88 847.152,1406.88 847.161,1406.88 847.17,1406.88 847.179,1406.88 847.188,1406.88 847.198,1406.88 847.207,1406.88 847.216,1406.88 847.225,1406.88 847.234,1406.88 847.244,1406.88 847.253,1406.88 847.262,1406.88 847.271,1406.88 847.28,1406.88 847.29,1406.88 847.299,1406.88 847.308,1406.88 847.317,1406.88 847.326,1406.88 847.336,1406.88 847.345,1406.88 847.354,1406.88 847.363,1406.88 847.372,1406.88 847.381,1406.88 847.391,1406.88 847.4,1406.88 847.409,1406.88 847.418,1406.88 847.427,1406.88 847.437,1406.88 847.446,1406.88 847.455,1406.88 847.464,1406.88 847.473,1406.88 847.483,1406.88 847.492,1406.88 847.501,1406.88 847.51,1406.88 847.519,1406.88 847.528,1406.88 847.538,1406.88 847.547,1406.88 847.556,1406.88 847.565,1406.88 847.574,1406.88 847.584,1406.88 847.593,1406.88 847.602,1406.88 847.611,1406.88 847.62,1406.88 847.63,1406.88 847.639,1406.88 847.648,1406.88 847.657,1406.88 847.666,1406.88 847.676,1406.88 847.685,1406.88 847.694,1406.88 847.703,1406.88 847.712,1406.88 847.721,1406.88 847.731,1406.88 847.74,1406.88 847.749,1406.88 847.758,1406.88 847.767,1406.88 847.777,1406.88 847.786,1406.88 847.795,1406.88 847.804,1406.88 847.813,1406.88 847.823,1406.88 847.832,1406.88 847.841,1406.88 847.85,1406.88 847.859,1406.88 847.868,1406.88 847.878,1406.88 847.887,1406.88 847.896,1406.88 847.905,1406.88 847.914,1406.88 847.924,1406.88 847.933,1406.88 847.942,1406.88 847.951,1406.88 847.96,1406.88 847.97,1406.88 847.979,1406.88 847.988,1406.88 847.997,1406.88 848.006,1406.88 848.016,1406.88 848.025,1406.88 848.034,1406.88 848.043,1406.88 848.052,1406.88 848.061,1406.88 848.071,1406.88 848.08,1406.88 848.089,1406.88 848.098,1406.88 848.107,1406.88 848.117,1406.88 848.126,1406.88 848.135,1406.88 848.144,1406.88 848.153,1406.88 848.163,1406.88 848.172,1406.88 848.181,1406.88 848.19,1406.88 848.199,1406.88 848.208,1406.88 848.218,1406.88 848.227,1406.88 848.236,1406.88 848.245,1406.88 848.254,1406.88 848.264,1406.88 848.273,1406.88 848.282,1406.88 848.291,1406.88 848.3,1406.88 848.31,1406.88 848.319,1406.88 848.328,1406.88 848.337,1406.88 848.346,1406.88 848.356,1406.88 848.365,1406.88 848.374,1406.88 848.383,1406.88 848.392,1406.88 848.401,1406.88 848.411,1406.88 848.42,1406.88 848.429,1406.88 848.438,1406.88 848.447,1406.88 848.457,1406.88 848.466,1406.88 848.475,1406.88 848.484,1406.88 848.493,1406.88 848.503,1406.88 848.512,1406.88 848.521,1406.88 848.53,1406.88 848.539,1406.88 848.548,1406.88 848.558,1406.88 848.567,1406.88 848.576,1406.88 848.585,1406.88 848.594,1406.88 848.604,1406.88 848.613,1406.88 848.622,1406.88 848.631,1406.88 848.64,1406.88 848.65,1406.88 848.659,1406.88 848.668,1406.88 848.677,1406.88 848.686,1406.88 848.696,1406.88 848.705,1406.88 848.714,1406.88 848.723,1406.88 848.732,1406.88 848.741,1406.88 848.751,1406.88 848.76,1406.88 848.769,1406.88 848.778,1406.88 848.787,1406.88 848.797,1406.88 848.806,1406.88 848.815,1406.88 848.824,1406.88 848.833,1406.88 848.843,1406.88 848.852,1406.88 848.861,1406.88 848.87,1406.88 848.879,1406.88 848.888,1406.88 848.898,1406.88 848.907,1406.88 848.916,1406.88 848.925,1406.88 848.934,1406.88 848.944,1406.88 848.953,1406.88 848.962,1406.88 848.971,1406.88 848.98,1406.88 848.99,1406.88 848.999,1406.88 849.008,1406.88 849.017,1406.88 849.026,1406.88 849.036,1406.88 849.045,1406.88 849.054,1406.88 849.063,1406.88 849.072,1406.88 849.081,1406.88 849.091,1406.88 849.1,1406.88 849.109,1406.88 849.118,1406.88 849.127,1406.88 849.137,1406.88 849.146,1406.88 849.155,1406.88 849.164,1406.88 849.173,1406.88 849.183,1406.88 849.192,1406.88 849.201,1406.88 849.21,1406.88 849.219,1406.88 849.229,1406.88 849.238,1406.88 849.247,1406.88 849.256,1406.88 849.265,1406.88 849.274,1406.88 849.284,1406.88 849.293,1406.88 849.302,1406.88 849.311,1406.88 849.32,1406.88 849.33,1406.88 849.339,1406.88 849.348,1406.88 849.357,1406.88 849.366,1406.88 849.376,1406.88 849.385,1406.88 849.394,1406.88 849.403,1406.88 849.412,1406.88 849.421,1406.88 849.431,1406.88 849.44,1406.88 849.449,1406.88 849.458,1406.88 849.467,1406.88 849.477,1406.88 849.486,1406.88 849.495,1406.88 849.504,1406.88 849.513,1406.88 849.523,1406.88 849.532,1406.88 849.541,1406.88 849.55,1406.88 849.559,1406.88 849.569,1406.88 849.578,1406.88 849.587,1406.88 849.596,1406.88 849.605,1406.88 849.614,1406.88 849.624,1406.88 849.633,1406.88 849.642,1406.88 849.651,1406.88 849.66,1406.88 849.67,1406.88 849.679,1406.88 849.688,1406.88 849.697,1406.88 849.706,1406.88 849.716,1406.88 849.725,1406.88 849.734,1406.88 849.743,1406.88 849.752,1406.88 849.761,1406.88 849.771,1406.88 849.78,1406.88 849.789,1406.88 849.798,1406.88 849.807,1406.88 849.817,1406.88 849.826,1406.88 849.835,1406.88 849.844,1406.88 849.853,1406.88 849.863,1406.88 849.872,1406.88 849.881,1406.88 849.89,1406.88 849.899,1406.88 849.909,1406.88 849.918,1406.88 849.927,1406.88 849.936,1406.88 849.945,1406.88 849.954,1406.88 849.964,1406.88 849.973,1406.88 849.982,1406.88 849.991,1406.88 850,1406.88 850.01,1406.88 850.019,1406.88 850.028,1406.88 850.037,1406.88 850.046,1406.88 850.056,1406.88 850.065,1406.88 850.074,1406.88 850.083,1406.88 850.092,1406.88 850.101,1406.88 850.111,1406.88 850.12,1406.88 850.129,1406.88 850.138,1406.88 850.147,1406.88 850.157,1406.88 850.166,1406.88 850.175,1406.88 850.184,1406.88 850.193,1406.88 850.203,1406.88 850.212,1406.88 850.221,1406.88 850.23,1406.88 850.239,1406.88 850.249,1406.88 850.258,1406.88 850.267,1406.88 850.276,1406.88 850.285,1406.88 850.294,1406.88 850.304,1406.88 850.313,1406.88 850.322,1406.88 850.331,1406.88 850.34,1406.88 850.35,1406.88 850.359,1406.88 850.368,1406.88 850.377,1406.88 850.386,1406.88 850.396,1406.88 850.405,1406.88 850.414,1406.88 850.423,1406.88 850.432,1406.88 850.441,1406.88 850.451,1406.88 850.46,1406.88 850.469,1406.88 850.478,1406.88 850.487,1406.88 850.497,1406.88 850.506,1406.88 850.515,1406.88 850.524,1406.88 850.533,1406.88 850.543,1406.88 850.552,1406.88 850.561,1406.88 850.57,1406.88 850.579,1406.88 850.589,1406.88 850.598,1406.88 850.607,1406.88 850.616,1406.88 850.625,1406.88 850.634,1406.88 850.644,1406.88 850.653,1406.88 850.662,1406.88 850.671,1406.88 850.68,1406.88 850.69,1406.88 850.699,1406.88 850.708,1406.88 850.717,1406.88 850.726,1406.88 850.736,1406.88 850.745,1406.88 850.754,1406.88 850.763,1406.88 850.772,1406.88 850.781,1406.88 850.791,1406.88 850.8,1406.88 850.809,1406.88 850.818,1406.88 850.827,1406.88 850.837,1406.88 850.846,1406.88 850.855,1406.88 850.864,1406.88 850.873,1406.88 850.883,1406.88 850.892,1406.88 850.901,1406.88 850.91,1406.88 850.919,1406.88 850.929,1406.88 850.938,1406.88 850.947,1406.88 850.956,1406.88 850.965,1406.88 850.974,1406.88 850.984,1406.88 850.993,1406.88 851.002,1406.88 851.011,1406.88 851.02,1406.88 851.03,1406.88 851.039,1406.88 851.048,1406.88 851.057,1406.88 851.066,1406.88 851.076,1406.88 851.085,1406.88 851.094,1406.88 851.103,1406.88 851.112,1406.88 851.121,1406.88 851.131,1406.88 851.14,1406.88 851.149,1406.88 851.158,1406.88 851.167,1406.88 851.177,1406.88 851.186,1406.88 851.195,1406.88 851.204,1406.88 851.213,1406.88 851.223,1406.88 851.232,1406.88 851.241,1406.88 851.25,1406.88 851.259,1406.88 851.269,1406.88 851.278,1406.88 851.287,1406.88 851.296,1406.88 851.305,1406.88 851.314,1406.88 851.324,1406.88 851.333,1406.88 851.342,1406.88 851.351,1406.88 851.36,1406.88 851.37,1406.88 851.379,1406.88 851.388,1406.88 851.397,1406.88 851.406,1406.88 851.416,1406.88 851.425,1406.88 851.434,1406.88 851.443,1406.88 851.452,1406.88 851.461,1406.88 851.471,1406.88 851.48,1406.88 851.489,1406.88 851.498,1406.88 851.507,1406.88 851.517,1406.88 851.526,1406.88 851.535,1406.88 851.544,1406.88 851.553,1406.88 851.563,1406.88 851.572,1406.88 851.581,1406.88 851.59,1406.88 851.599,1406.88 851.609,1406.88 851.618,1406.88 851.627,1406.88 851.636,1406.88 851.645,1406.88 851.654,1406.88 851.664,1406.88 851.673,1406.88 851.682,1406.88 851.691,1406.88 851.7,1406.88 851.71,1406.88 851.719,1406.88 851.728,1406.88 851.737,1406.88 851.746,1406.88 851.756,1406.88 851.765,1406.88 851.774,1406.88 851.783,1406.88 851.792,1406.88 851.802,1406.88 851.811,1406.88 851.82,1406.88 851.829,1406.88 851.838,1406.88 851.847,1406.88 851.857,1406.88 851.866,1406.88 851.875,1406.88 851.884,1406.88 851.893,1406.88 851.903,1406.88 851.912,1406.88 851.921,1406.88 851.93,1406.88 851.939,1406.88 851.949,1406.88 851.958,1406.88 851.967,1406.88 851.976,1406.88 851.985,1406.88 851.994,1406.88 852.004,1406.88 852.013,1406.88 852.022,1406.88 852.031,1406.88 852.04,1406.88 852.05,1406.88 852.059,1406.88 852.068,1406.88 852.077,1406.88 852.086,1406.88 852.096,1406.88 852.105,1406.88 852.114,1406.88 852.123,1406.88 852.132,1406.88 852.142,1406.88 852.151,1406.88 852.16,1406.88 852.169,1406.88 852.178,1406.88 852.187,1406.88 852.197,1406.88 852.206,1406.88 852.215,1406.88 852.224,1406.88 852.233,1406.88 852.243,1406.88 852.252,1406.88 852.261,1406.88 852.27,1406.88 852.279,1406.88 852.289,1406.88 852.298,1406.88 852.307,1406.88 852.316,1406.88 852.325,1406.88 852.334,1406.88 852.344,1406.88 852.353,1406.88 852.362,1406.88 852.371,1406.88 852.38,1406.88 852.39,1406.88 852.399,1406.88 852.408,1406.88 852.417,1406.88 852.426,1406.88 852.436,1406.88 852.445,1406.88 852.454,1406.88 852.463,1406.88 852.472,1406.88 852.482,1406.88 852.491,1406.88 852.5,1406.88 852.509,1406.88 852.518,1406.88 852.527,1406.88 852.537,1406.88 852.546,1406.88 852.555,1406.88 852.564,1406.88 852.573,1406.88 852.583,1406.88 852.592,1406.88 852.601,1406.88 852.61,1406.88 852.619,1406.88 852.629,1406.88 852.638,1406.88 852.647,1406.88 852.656,1406.88 852.665,1406.88 852.674,1406.88 852.684,1406.88 852.693,1406.88 852.702,1406.88 852.711,1406.88 852.72,1406.88 852.73,1406.88 852.739,1406.88 852.748,1406.88 852.757,1406.88 852.766,1406.88 852.776,1406.88 852.785,1406.88 852.794,1406.88 852.803,1406.88 852.812,1406.88 852.822,1406.88 852.831,1406.88 852.84,1406.88 852.849,1406.88 852.858,1406.88 852.867,1406.88 852.877,1406.88 852.886,1406.88 852.895,1406.88 852.904,1406.88 852.913,1406.88 852.923,1406.88 852.932,1406.88 852.941,1406.88 852.95,1406.88 852.959,1406.88 852.969,1406.88 852.978,1406.88 852.987,1406.88 852.996,1406.88 853.005,1406.88 853.014,1406.88 853.024,1406.88 853.033,1406.88 853.042,1406.88 853.051,1406.88 853.06,1406.88 853.07,1406.88 853.079,1406.88 853.088,1406.88 853.097,1406.88 853.106,1406.88 853.116,1406.88 853.125,1406.88 853.134,1406.88 853.143,1406.88 853.152,1406.88 853.162,1406.88 853.171,1406.88 853.18,1406.88 853.189,1406.88 853.198,1406.88 853.207,1406.88 853.217,1406.88 853.226,1406.88 853.235,1406.88 853.244,1406.88 853.253,1406.88 853.263,1406.88 853.272,1406.88 853.281,1406.88 853.29,1406.88 853.299,1406.88 853.309,1406.88 853.318,1406.88 853.327,1406.88 853.336,1406.88 853.345,1406.88 853.354,1406.88 853.364,1406.88 853.373,1406.88 853.382,1406.88 853.391,1406.88 853.4,1406.88 853.41,1406.88 853.419,1406.88 853.428,1406.88 853.437,1406.88 853.446,1406.88 853.456,1406.88 853.465,1406.88 853.474,1406.88 853.483,1406.88 853.492,1406.88 853.502,1406.88 853.511,1406.88 853.52,1406.88 853.529,1406.88 853.538,1406.88 853.547,1406.88 853.557,1406.88 853.566,1406.88 853.575,1406.88 853.584,1406.88 853.593,1406.88 853.603,1406.88 853.612,1406.88 853.621,1406.88 853.63,1406.88 853.639,1406.88 853.649,1406.88 853.658,1406.88 853.667,1406.88 853.676,1406.88 853.685,1406.88 853.694,1406.88 853.704,1406.88 853.713,1406.88 853.722,1406.88 853.731,1406.88 853.74,1406.88 853.75,1406.88 853.759,1406.88 853.768,1406.88 853.777,1406.88 853.786,1406.88 853.796,1406.88 853.805,1406.88 853.814,1406.88 853.823,1406.88 853.832,1406.88 853.842,1406.88 853.851,1406.88 853.86,1406.88 853.869,1406.88 853.878,1406.88 853.887,1406.88 853.897,1406.88 853.906,1406.88 853.915,1406.88 853.924,1406.88 853.933,1406.88 853.943,1406.88 853.952,1406.88 853.961,1406.88 853.97,1406.88 853.979,1406.88 853.989,1406.88 853.998,1406.88 854.007,1406.88 854.016,1406.88 854.025,1406.88 854.035,1406.88 854.044,1406.88 854.053,1406.88 854.062,1406.88 854.071,1406.88 854.08,1406.88 854.09,1406.88 854.099,1406.88 854.108,1406.88 854.117,1406.88 854.126,1406.88 854.136,1406.88 854.145,1406.88 854.154,1406.88 854.163,1406.88 854.172,1406.88 854.182,1406.88 854.191,1406.88 854.2,1406.88 854.209,1406.88 854.218,1406.88 854.227,1406.88 854.237,1406.88 854.246,1406.88 854.255,1406.88 854.264,1406.88 854.273,1406.88 854.283,1406.88 854.292,1406.88 854.301,1406.88 854.31,1406.88 854.319,1406.88 854.329,1406.88 854.338,1406.88 854.347,1406.88 854.356,1406.88 854.365,1406.88 854.375,1406.88 854.384,1406.88 854.393,1406.88 854.402,1406.88 854.411,1406.88 854.42,1406.88 854.43,1406.88 854.439,1406.88 854.448,1406.88 854.457,1406.88 854.466,1406.88 854.476,1406.88 854.485,1406.88 854.494,1406.88 854.503,1406.88 854.512,1406.88 854.522,1406.88 854.531,1406.88 854.54,1406.88 854.549,1406.88 854.558,1406.88 854.567,1406.88 854.577,1406.88 854.586,1406.88 854.595,1406.88 854.604,1406.88 854.613,1406.88 854.623,1406.88 854.632,1406.88 854.641,1406.88 854.65,1406.88 854.659,1406.88 854.669,1406.88 854.678,1406.88 854.687,1406.88 854.696,1406.88 854.705,1406.88 854.715,1406.88 854.724,1406.88 854.733,1406.88 854.742,1406.88 854.751,1406.88 854.76,1406.88 854.77,1406.88 854.779,1406.88 854.788,1406.88 854.797,1406.88 854.806,1406.88 854.816,1406.88 854.825,1406.88 854.834,1406.88 854.843,1406.88 854.852,1406.88 854.862,1406.88 854.871,1406.88 854.88,1406.88 854.889,1406.88 854.898,1406.88 854.907,1406.88 854.917,1406.88 854.926,1406.88 854.935,1406.88 854.944,1406.88 854.953,1406.88 854.963,1406.88 854.972,1406.88 854.981,1406.88 854.99,1406.88 854.999,1406.88 855.009,1406.88 855.018,1406.88 855.027,1406.88 855.036,1406.88 855.045,1406.88 855.055,1406.88 855.064,1406.88 855.073,1406.88 855.082,1406.88 855.091,1406.88 855.1,1406.88 855.11,1406.88 855.119,1406.88 855.128,1406.88 855.137,1406.88 855.146,1406.88 855.156,1406.88 855.165,1406.88 855.174,1406.88 855.183,1406.88 855.192,1406.88 855.202,1406.88 855.211,1406.88 855.22,1406.88 855.229,1406.88 855.238,1406.88 855.247,1406.88 855.257,1406.88 855.266,1406.88 855.275,1406.88 855.284,1406.88 855.293,1406.88 855.303,1406.88 855.312,1406.88 855.321,1406.88 855.33,1406.88 855.339,1406.88 855.349,1406.88 855.358,1406.88 855.367,1406.88 855.376,1406.88 855.385,1406.88 855.395,1406.88 855.404,1406.88 855.413,1406.88 855.422,1406.88 855.431,1406.88 855.44,1406.88 855.45,1406.88 855.459,1406.88 855.468,1406.88 855.477,1406.88 855.486,1406.88 855.496,1406.88 855.505,1406.88 855.514,1406.88 855.523,1406.88 855.532,1406.88 855.542,1406.88 855.551,1406.88 855.56,1406.88 855.569,1406.88 855.578,1406.88 855.587,1406.88 855.597,1406.88 855.606,1406.88 855.615,1406.88 855.624,1406.88 855.633,1406.88 855.643,1406.88 855.652,1406.88 855.661,1406.88 855.67,1406.88 855.679,1406.88 855.689,1406.88 855.698,1406.88 855.707,1406.88 855.716,1406.88 855.725,1406.88 855.735,1406.88 855.744,1406.88 855.753,1406.88 855.762,1406.88 855.771,1406.88 855.78,1406.88 855.79,1406.88 855.799,1406.88 855.808,1406.88 855.817,1406.88 855.826,1406.88 855.836,1406.88 855.845,1406.88 855.854,1406.88 855.863,1406.88 855.872,1406.88 855.882,1406.88 855.891,1406.88 855.9,1406.88 855.909,1406.88 855.918,1406.88 855.927,1406.88 855.937,1406.88 855.946,1406.88 855.955,1406.88 855.964,1406.88 855.973,1406.88 855.983,1406.88 855.992,1406.88 856.001,1406.88 856.01,1406.88 856.019,1406.88 856.029,1406.88 856.038,1406.88 856.047,1406.88 856.056,1406.88 856.065,1406.88 856.075,1406.88 856.084,1406.88 856.093,1406.88 856.102,1406.88 856.111,1406.88 856.12,1406.88 856.13,1406.88 856.139,1406.88 856.148,1406.88 856.157,1406.88 856.166,1406.88 856.176,1406.88 856.185,1406.88 856.194,1406.88 856.203,1406.88 856.212,1406.88 856.222,1406.88 856.231,1406.88 856.24,1406.88 856.249,1406.88 856.258,1406.88 856.267,1406.88 856.277,1406.88 856.286,1406.88 856.295,1406.88 856.304,1406.88 856.313,1406.88 856.323,1406.88 856.332,1406.88 856.341,1406.88 856.35,1406.88 856.359,1406.88 856.369,1406.88 856.378,1406.88 856.387,1406.88 856.396,1406.88 856.405,1406.88 856.415,1406.88 856.424,1406.88 856.433,1406.88 856.442,1406.88 856.451,1406.88 856.46,1406.88 856.47,1406.88 856.479,1406.88 856.488,1406.88 856.497,1406.88 856.506,1406.88 856.516,1406.88 856.525,1406.88 856.534,1406.88 856.543,1406.88 856.552,1406.88 856.562,1406.88 856.571,1406.88 856.58,1406.88 856.589,1406.88 856.598,1406.88 856.608,1406.88 856.617,1406.88 856.626,1406.88 856.635,1406.88 856.644,1406.88 856.653,1406.88 856.663,1406.88 856.672,1406.88 856.681,1406.88 856.69,1406.88 856.699,1406.88 856.709,1406.88 856.718,1406.88 856.727,1406.88 856.736,1406.88 856.745,1406.88 856.755,1406.88 856.764,1406.88 856.773,1406.88 856.782,1406.88 856.791,1406.88 856.8,1406.88 856.81,1406.88 856.819,1406.88 856.828,1406.88 856.837,1406.88 856.846,1406.88 856.856,1406.88 856.865,1406.88 856.874,1406.88 856.883,1406.88 856.892,1406.88 856.902,1406.88 856.911,1406.88 856.92,1406.88 856.929,1406.88 856.938,1406.88 856.948,1406.88 856.957,1406.88 856.966,1406.88 856.975,1406.88 856.984,1406.88 856.993,1406.88 857.003,1406.88 857.012,1406.88 857.021,1406.88 857.03,1406.88 857.039,1406.88 857.049,1406.88 857.058,1406.88 857.067,1406.88 857.076,1406.88 857.085,1406.88 857.095,1406.88 857.104,1406.88 857.113,1406.88 857.122,1406.88 857.131,1406.88 857.14,1406.88 857.15,1406.88 857.159,1406.88 857.168,1406.88 857.177,1406.88 857.186,1406.88 857.196,1406.88 857.205,1406.88 857.214,1406.88 857.223,1406.88 857.232,1406.88 857.242,1406.88 857.251,1406.88 857.26,1406.88 857.269,1406.88 857.278,1406.88 857.288,1406.88 857.297,1406.88 857.306,1406.88 857.315,1406.88 857.324,1406.88 857.333,1406.88 857.343,1406.88 857.352,1406.88 857.361,1406.88 857.37,1406.88 857.379,1406.88 857.389,1406.88 857.398,1406.88 857.407,1406.88 857.416,1406.88 857.425,1406.88 857.435,1406.88 857.444,1406.88 857.453,1406.88 857.462,1406.88 857.471,1406.88 857.48,1406.88 857.49,1406.88 857.499,1406.88 857.508,1406.88 857.517,1406.88 857.526,1406.88 857.536,1406.88 857.545,1406.88 857.554,1406.88 857.563,1406.88 857.572,1406.88 857.582,1406.88 857.591,1406.88 857.6,1406.88 857.609,1406.88 857.618,1406.88 857.628,1406.88 857.637,1406.88 857.646,1406.88 857.655,1406.88 857.664,1406.88 857.673,1406.88 857.683,1406.88 857.692,1406.88 857.701,1406.88 857.71,1406.88 857.719,1406.88 857.729,1406.88 857.738,1406.88 857.747,1406.88 857.756,1406.88 857.765,1406.88 857.775,1406.88 857.784,1406.88 857.793,1406.88 857.802,1406.88 857.811,1406.88 857.82,1406.88 857.83,1406.88 857.839,1406.88 857.848,1406.88 857.857,1406.88 857.866,1406.88 857.876,1406.88 857.885,1406.88 857.894,1406.88 857.903,1406.88 857.912,1406.88 857.922,1406.88 857.931,1406.88 857.94,1406.88 857.949,1406.88 857.958,1406.88 857.968,1406.88 857.977,1406.88 857.986,1406.88 857.995,1406.88 858.004,1406.88 858.013,1406.88 858.023,1406.88 858.032,1406.88 858.041,1406.88 858.05,1406.88 858.059,1406.88 858.069,1406.88 858.078,1406.88 858.087,1406.88 858.096,1406.88 858.105,1406.88 858.115,1406.88 858.124,1406.88 858.133,1406.88 858.142,1406.88 858.151,1406.88 858.16,1406.88 858.17,1406.88 858.179,1406.88 858.188,1406.88 858.197,1406.88 858.206,1406.88 858.216,1406.88 858.225,1406.88 858.234,1406.88 858.243,1406.88 858.252,1406.88 858.262,1406.88 858.271,1406.88 858.28,1406.88 858.289,1406.88 858.298,1406.88 858.308,1406.88 858.317,1406.88 858.326,1406.88 858.335,1406.88 858.344,1406.88 858.353,1406.88 858.363,1406.88 858.372,1406.88 858.381,1406.88 858.39,1406.88 858.399,1406.88 858.409,1406.88 858.418,1406.88 858.427,1406.88 858.436,1406.88 858.445,1406.88 858.455,1406.88 858.464,1406.88 858.473,1406.88 858.482,1406.88 858.491,1406.88 858.5,1406.88 858.51,1406.88 858.519,1406.88 858.528,1406.88 858.537,1406.88 858.546,1406.88 858.556,1406.88 858.565,1406.88 858.574,1406.88 858.583,1406.88 858.592,1406.88 858.602,1406.88 858.611,1406.88 858.62,1406.88 858.629,1406.88 858.638,1406.88 858.648,1406.88 858.657,1406.88 858.666,1406.88 858.675,1406.88 858.684,1406.88 858.693,1406.88 858.703,1406.88 858.712,1406.88 858.721,1406.88 858.73,1406.88 858.739,1406.88 858.749,1406.88 858.758,1406.88 858.767,1406.88 858.776,1406.88 858.785,1406.88 858.795,1406.88 858.804,1406.88 858.813,1406.88 858.822,1406.88 858.831,1406.88 858.84,1406.88 858.85,1406.88 858.859,1406.88 858.868,1406.88 858.877,1406.88 858.886,1406.88 858.896,1406.88 858.905,1406.88 858.914,1406.88 858.923,1406.88 858.932,1406.88 858.942,1406.88 858.951,1406.88 858.96,1406.88 858.969,1406.88 858.978,1406.88 858.988,1406.88 858.997,1406.88 859.006,1406.88 859.015,1406.88 859.024,1406.88 859.033,1406.88 859.043,1406.88 859.052,1406.88 859.061,1406.88 859.07,1406.88 859.079,1406.88 859.089,1406.88 859.098,1406.88 859.107,1406.88 859.116,1406.88 859.125,1406.88 859.135,1406.88 859.144,1406.88 859.153,1406.88 859.162,1406.88 859.171,1406.88 859.181,1406.88 859.19,1406.88 859.199,1406.88 859.208,1406.88 859.217,1406.88 859.226,1406.88 859.236,1406.88 859.245,1406.88 859.254,1406.88 859.263,1406.88 859.272,1406.88 859.282,1406.88 859.291,1406.88 859.3,1406.88 859.309,1406.88 859.318,1406.88 859.328,1406.88 859.337,1406.88 859.346,1406.88 859.355,1406.88 859.364,1406.88 859.373,1406.88 859.383,1406.88 859.392,1406.88 859.401,1406.88 859.41,1406.88 859.419,1406.88 859.429,1406.88 859.438,1406.88 859.447,1406.88 859.456,1406.88 859.465,1406.88 859.475,1406.88 859.484,1406.88 859.493,1406.88 859.502,1406.88 859.511,1406.88 859.521,1406.88 859.53,1406.88 859.539,1406.88 859.548,1406.88 859.557,1406.88 859.566,1406.88 859.576,1406.88 859.585,1406.88 859.594,1406.88 859.603,1406.88 859.612,1406.88 859.622,1406.88 859.631,1406.88 859.64,1406.88 859.649,1406.88 859.658,1406.88 859.668,1406.88 859.677,1406.88 859.686,1406.88 859.695,1406.88 859.704,1406.88 859.713,1406.88 859.723,1406.88 859.732,1406.88 859.741,1406.88 859.75,1406.88 859.759,1406.88 859.769,1406.88 859.778,1406.88 859.787,1406.88 859.796,1406.88 859.805,1406.88 859.815,1406.88 859.824,1406.88 859.833,1406.88 859.842,1406.88 859.851,1406.88 859.861,1406.88 859.87,1406.88 859.879,1406.88 859.888,1406.88 859.897,1406.88 859.906,1406.88 859.916,1406.88 859.925,1406.88 859.934,1406.88 859.943,1406.88 859.952,1406.88 859.962,1406.88 859.971,1406.88 859.98,1406.88 859.989,1406.88 859.998,1406.88 860.008,1406.88 860.017,1406.88 860.026,1406.88 860.035,1406.88 860.044,1406.88 860.053,1406.88 860.063,1406.88 860.072,1406.88 860.081,1406.88 860.09,1406.88 860.099,1406.88 860.109,1406.88 860.118,1406.88 860.127,1406.88 860.136,1406.88 860.145,1406.88 860.155,1406.88 860.164,1406.88 860.173,1406.88 860.182,1406.88 860.191,1406.88 860.201,1406.88 860.21,1406.88 860.219,1406.88 860.228,1406.88 860.237,1406.88 860.246,1406.88 860.256,1406.88 860.265,1406.88 860.274,1406.88 860.283,1406.88 860.292,1406.88 860.302,1406.88 860.311,1406.88 860.32,1406.88 860.329,1406.88 860.338,1406.88 860.348,1406.88 860.357,1406.88 860.366,1406.88 860.375,1406.88 860.384,1406.88 860.393,1406.88 860.403,1406.88 860.412,1406.88 860.421,1406.88 860.43,1406.88 860.439,1406.88 860.449,1406.88 860.458,1406.88 860.467,1406.88 860.476,1406.88 860.485,1406.88 860.495,1406.88 860.504,1406.88 860.513,1406.88 860.522,1406.88 860.531,1406.88 860.541,1406.88 860.55,1406.88 860.559,1406.88 860.568,1406.88 860.577,1406.88 860.586,1406.88 860.596,1406.88 860.605,1406.88 860.614,1406.88 860.623,1406.88 860.632,1406.88 860.642,1406.88 860.651,1406.88 860.66,1406.88 860.669,1406.88 860.678,1406.88 860.688,1406.88 860.697,1406.88 860.706,1406.88 860.715,1406.88 860.724,1406.88 860.733,1406.88 860.743,1406.88 860.752,1406.88 860.761,1406.88 860.77,1406.88 860.779,1406.88 860.789,1406.88 860.798,1406.88 860.807,1406.88 860.816,1406.88 860.825,1406.88 860.835,1406.88 860.844,1406.88 860.853,1406.88 860.862,1406.88 860.871,1406.88 860.881,1406.88 860.89,1406.88 860.899,1406.88 860.908,1406.88 860.917,1406.88 860.926,1406.88 860.936,1406.88 860.945,1406.88 860.954,1406.88 860.963,1406.88 860.972,1406.88 860.982,1406.88 860.991,1406.88 861,1406.88 861.009,1406.88 861.018,1406.88 861.028,1406.88 861.037,1406.88 861.046,1406.88 861.055,1406.88 861.064,1406.88 861.073,1406.88 861.083,1406.88 861.092,1406.88 861.101,1406.88 861.11,1406.88 861.119,1406.88 861.129,1406.88 861.138,1406.88 861.147,1406.88 861.156,1406.88 861.165,1406.88 861.175,1406.88 861.184,1406.88 861.193,1406.88 861.202,1406.88 861.211,1406.88 861.221,1406.88 861.23,1406.88 861.239,1406.88 861.248,1406.88 861.257,1406.88 861.266,1406.88 861.276,1406.88 861.285,1406.88 861.294,1406.88 861.303,1406.88 861.312,1406.88 861.322,1406.88 861.331,1406.88 861.34,1406.88 861.349,1406.88 861.358,1406.88 861.368,1406.88 861.377,1406.88 861.386,1406.88 861.395,1406.88 861.404,1406.88 861.414,1406.88 861.423,1406.88 861.432,1406.88 861.441,1406.88 861.45,1406.88 861.459,1406.88 861.469,1406.88 861.478,1406.88 861.487,1406.88 861.496,1406.88 861.505,1406.88 861.515,1406.88 861.524,1406.88 861.533,1406.88 861.542,1406.88 861.551,1406.88 861.561,1406.88 861.57,1406.88 861.579,1406.88 861.588,1406.88 861.597,1406.88 861.606,1406.88 861.616,1406.88 861.625,1406.88 861.634,1406.88 861.643,1406.88 861.652,1406.88 861.662,1406.88 861.671,1406.88 861.68,1406.88 861.689,1406.88 861.698,1406.88 861.708,1406.88 861.717,1406.88 861.726,1406.88 861.735,1406.88 861.744,1406.88 861.754,1406.88 861.763,1406.88 861.772,1406.88 861.781,1406.88 861.79,1406.88 861.799,1406.88 861.809,1406.88 861.818,1406.88 861.827,1406.88 861.836,1406.88 861.845,1406.88 861.855,1406.88 861.864,1406.88 861.873,1406.88 861.882,1406.88 861.891,1406.88 861.901,1406.88 861.91,1406.88 861.919,1406.88 861.928,1406.88 861.937,1406.88 861.946,1406.88 861.956,1406.88 861.965,1406.88 861.974,1406.88 861.983,1406.88 861.992,1406.88 862.002,1406.88 862.011,1406.88 862.02,1406.88 862.029,1406.88 862.038,1406.88 862.048,1406.88 862.057,1406.88 862.066,1406.88 862.075,1406.88 862.084,1406.88 862.094,1406.88 862.103,1406.88 862.112,1406.88 862.121,1406.88 862.13,1406.88 862.139,1406.88 862.149,1406.88 862.158,1406.88 862.167,1406.88 862.176,1406.88 862.185,1406.88 862.195,1406.88 862.204,1406.88 862.213,1406.88 862.222,1406.88 862.231,1406.88 862.241,1406.88 862.25,1406.88 862.259,1406.88 862.268,1406.88 862.277,1406.88 862.286,1406.88 862.296,1406.88 862.305,1406.88 862.314,1406.88 862.323,1406.88 862.332,1406.88 862.342,1406.88 862.351,1406.88 862.36,1406.88 862.369,1406.88 862.378,1406.88 862.388,1406.88 862.397,1406.88 862.406,1406.88 862.415,1406.88 862.424,1406.88 862.434,1406.88 862.443,1406.88 862.452,1406.88 862.461,1406.88 862.47,1406.88 862.479,1406.88 862.489,1406.88 862.498,1406.88 862.507,1406.88 862.516,1406.88 862.525,1406.88 862.535,1406.88 862.544,1406.88 862.553,1406.88 862.562,1406.88 862.571,1406.88 862.581,1406.88 862.59,1406.88 862.599,1406.88 862.608,1406.88 862.617,1406.88 862.626,1406.88 862.636,1406.88 862.645,1406.88 862.654,1406.88 862.663,1406.88 862.672,1406.88 862.682,1406.88 862.691,1406.88 862.7,1406.88 862.709,1406.88 862.718,1406.88 862.728,1406.88 862.737,1406.88 862.746,1406.88 862.755,1406.88 862.764,1406.88 862.774,1406.88 862.783,1406.88 862.792,1406.88 862.801,1406.88 862.81,1406.88 862.819,1406.88 862.829,1406.88 862.838,1406.88 862.847,1406.88 862.856,1406.88 862.865,1406.88 862.875,1406.88 862.884,1406.88 862.893,1406.88 862.902,1406.88 862.911,1406.88 862.921,1406.88 862.93,1406.88 862.939,1406.88 862.948,1406.88 862.957,1406.88 862.966,1406.88 862.976,1406.88 862.985,1406.88 862.994,1406.88 863.003,1406.88 863.012,1406.88 863.022,1406.88 863.031,1406.88 863.04,1406.88 863.049,1406.88 863.058,1406.88 863.068,1406.88 863.077,1406.88 863.086,1406.88 863.095,1406.88 863.104,1406.88 863.114,1406.88 863.123,1406.88 863.132,1406.88 863.141,1406.88 863.15,1406.88 863.159,1406.88 863.169,1406.88 863.178,1406.88 863.187,1406.88 863.196,1406.88 863.205,1406.88 863.215,1406.88 863.224,1406.88 863.233,1406.88 863.242,1406.88 863.251,1406.88 863.261,1406.88 863.27,1406.88 863.279,1406.88 863.288,1406.88 863.297,1406.88 863.306,1406.88 863.316,1406.88 863.325,1406.88 863.334,1406.88 863.343,1406.88 863.352,1406.88 863.362,1406.88 863.371,1406.88 863.38,1406.88 863.389,1406.88 863.398,1406.88 863.408,1406.88 863.417,1406.88 863.426,1406.88 863.435,1406.88 863.444,1406.88 863.454,1406.88 863.463,1406.88 863.472,1406.88 863.481,1406.88 863.49,1406.88 863.499,1406.88 863.509,1406.88 863.518,1406.88 863.527,1406.88 863.536,1406.88 863.545,1406.88 863.555,1406.88 863.564,1406.88 863.573,1406.88 863.582,1406.88 863.591,1406.88 863.601,1406.88 863.61,1406.88 863.619,1406.88 863.628,1406.88 863.637,1406.88 863.646,1406.88 863.656,1406.88 863.665,1406.88 863.674,1406.88 863.683,1406.88 863.692,1406.88 863.702,1406.88 863.711,1406.88 863.72,1406.88 863.729,1406.88 863.738,1406.88 863.748,1406.88 863.757,1406.88 863.766,1406.88 863.775,1406.88 863.784,1406.88 863.794,1406.88 863.803,1406.88 863.812,1406.88 863.821,1406.88 863.83,1406.88 863.839,1406.88 863.849,1406.88 863.858,1406.88 863.867,1406.88 863.876,1406.88 863.885,1406.88 863.895,1406.88 863.904,1406.88 863.913,1406.88 863.922,1406.88 863.931,1406.88 863.941,1406.88 863.95,1406.88 863.959,1406.88 863.968,1406.88 863.977,1406.88 863.987,1406.88 863.996,1406.88 864.005,1406.88 864.014,1406.88 864.023,1406.88 864.032,1406.88 864.042,1406.88 864.051,1406.88 864.06,1406.88 864.069,1406.88 864.078,1406.88 864.088,1406.88 864.097,1406.88 864.106,1406.88 864.115,1406.88 864.124,1406.88 864.134,1406.88 864.143,1406.88 864.152,1406.88 864.161,1406.88 864.17,1406.88 864.179,1406.88 864.189,1406.88 864.198,1406.88 864.207,1406.88 864.216,1406.88 864.225,1406.88 864.235,1406.88 864.244,1406.88 864.253,1406.88 864.262,1406.88 864.271,1406.88 864.281,1406.88 864.29,1406.88 864.299,1406.88 864.308,1406.88 864.317,1406.88 864.327,1406.88 864.336,1406.88 864.345,1406.88 864.354,1406.88 864.363,1406.88 864.372,1406.88 864.382,1406.88 864.391,1406.88 864.4,1406.88 864.409,1406.88 864.418,1406.88 864.428,1406.88 864.437,1406.88 864.446,1406.88 864.455,1406.88 864.464,1406.88 864.474,1406.88 864.483,1406.88 864.492,1406.88 864.501,1406.88 864.51,1406.88 864.519,1406.88 864.529,1406.88 864.538,1406.88 864.547,1406.88 864.556,1406.88 864.565,1406.88 864.575,1406.88 864.584,1406.88 864.593,1406.88 864.602,1406.88 864.611,1406.88 864.621,1406.88 864.63,1406.88 864.639,1406.88 864.648,1406.88 864.657,1406.88 864.667,1406.88 864.676,1406.88 864.685,1406.88 864.694,1406.88 864.703,1406.88 864.712,1406.88 864.722,1406.88 864.731,1406.88 864.74,1406.88 864.749,1406.88 864.758,1406.88 864.768,1406.88 864.777,1406.88 864.786,1406.88 864.795,1406.88 864.804,1406.88 864.814,1406.88 864.823,1406.88 864.832,1406.88 864.841,1406.88 864.85,1406.88 864.859,1406.88 864.869,1406.88 864.878,1406.88 864.887,1406.88 864.896,1406.88 864.905,1406.88 864.915,1406.88 864.924,1406.88 864.933,1406.88 864.942,1406.88 864.951,1406.88 864.961,1406.88 864.97,1406.88 864.979,1406.88 864.988,1406.88 864.997,1406.88 865.007,1406.88 865.016,1406.88 865.025,1406.88 865.034,1406.88 865.043,1406.88 865.052,1406.88 865.062,1406.88 865.071,1406.88 865.08,1406.88 865.089,1406.88 865.098,1406.88 865.108,1406.88 865.117,1406.88 865.126,1406.88 865.135,1406.88 865.144,1406.88 865.154,1406.88 865.163,1406.88 865.172,1406.88 865.181,1406.88 865.19,1406.88 865.199,1406.88 865.209,1406.88 865.218,1406.88 865.227,1406.88 865.236,1406.88 865.245,1406.88 865.255,1406.88 865.264,1406.88 865.273,1406.88 865.282,1406.88 865.291,1406.88 865.301,1406.88 865.31,1406.88 865.319,1406.88 865.328,1406.88 865.337,1406.88 865.347,1406.88 865.356,1406.88 865.365,1406.88 865.374,1406.88 865.383,1406.88 865.392,1406.88 865.402,1406.88 865.411,1406.88 865.42,1406.88 865.429,1406.88 865.438,1406.88 865.448,1406.88 865.457,1406.88 865.466,1406.88 865.475,1406.88 865.484,1406.88 865.494,1406.88 865.503,1406.88 865.512,1406.88 865.521,1406.88 865.53,1406.88 865.539,1406.88 865.549,1406.88 865.558,1406.88 865.567,1406.88 865.576,1406.88 865.585,1406.88 865.595,1406.88 865.604,1406.88 865.613,1406.88 865.622,1406.88 865.631,1406.88 865.641,1406.88 865.65,1406.88 865.659,1406.88 865.668,1406.88 865.677,1406.88 865.687,1406.88 865.696,1406.88 865.705,1406.88 865.714,1406.88 865.723,1406.88 865.732,1406.88 865.742,1406.88 865.751,1406.88 865.76,1406.88 865.769,1406.88 865.778,1406.88 865.788,1406.88 865.797,1406.88 865.806,1406.88 865.815,1406.88 865.824,1406.88 865.834,1406.88 865.843,1406.88 865.852,1406.88 865.861,1406.88 865.87,1406.88 865.879,1406.88 865.889,1406.88 865.898,1406.88 865.907,1406.88 865.916,1406.88 865.925,1406.88 865.935,1406.88 865.944,1406.88 865.953,1406.88 865.962,1406.88 865.971,1406.88 865.981,1406.88 865.99,1406.88 865.999,1406.88 866.008,1406.88 866.017,1406.88 866.027,1406.88 866.036,1406.88 866.045,1406.88 866.054,1406.88 866.063,1406.88 866.072,1406.88 866.082,1406.88 866.091,1406.88 866.1,1406.88 866.109,1406.88 866.118,1406.88 866.128,1406.88 866.137,1406.88 866.146,1406.88 866.155,1406.88 866.164,1406.88 866.174,1406.88 866.183,1406.88 866.192,1406.88 866.201,1406.88 866.21,1406.88 866.219,1406.88 866.229,1406.88 866.238,1406.88 866.247,1406.88 866.256,1406.88 866.265,1406.88 866.275,1406.88 866.284,1406.88 866.293,1406.88 866.302,1406.88 866.311,1406.88 866.321,1406.88 866.33,1406.88 866.339,1406.88 866.348,1406.88 866.357,1406.88 866.367,1406.88 866.376,1406.88 866.385,1406.88 866.394,1406.88 866.403,1406.88 866.412,1406.88 866.422,1406.88 866.431,1406.88 866.44,1406.88 866.449,1406.88 866.458,1406.88 866.468,1406.88 866.477,1406.88 866.486,1406.88 866.495,1406.88 866.504,1406.88 866.514,1406.88 866.523,1406.88 866.532,1406.88 866.541,1406.88 866.55,1406.88 866.56,1406.88 866.569,1406.88 866.578,1406.88 866.587,1406.88 866.596,1406.88 866.605,1406.88 866.615,1406.88 866.624,1406.88 866.633,1406.88 866.642,1406.88 866.651,1406.88 866.661,1406.88 866.67,1406.88 866.679,1406.88 866.688,1406.88 866.697,1406.88 866.707,1406.88 866.716,1406.88 866.725,1406.88 866.734,1406.88 866.743,1406.88 866.752,1406.88 866.762,1406.88 866.771,1406.88 866.78,1406.88 866.789,1406.88 866.798,1406.88 866.808,1406.88 866.817,1406.88 866.826,1406.88 866.835,1406.88 866.844,1406.88 866.854,1406.88 866.863,1406.88 866.872,1406.88 866.881,1406.88 866.89,1406.88 866.9,1406.88 866.909,1406.88 866.918,1406.88 866.927,1406.88 866.936,1406.88 866.945,1406.88 866.955,1406.88 866.964,1406.88 866.973,1406.88 866.982,1406.88 866.991,1406.88 867.001,1406.88 867.01,1406.88 867.019,1406.88 867.028,1406.88 867.037,1406.88 867.047,1406.88 867.056,1406.88 867.065,1406.88 867.074,1406.88 867.083,1406.88 867.092,1406.88 867.102,1406.88 867.111,1406.88 867.12,1406.88 867.129,1406.88 867.138,1406.88 867.148,1406.88 867.157,1406.88 867.166,1406.88 867.175,1406.88 867.184,1406.88 867.194,1406.88 867.203,1406.88 867.212,1406.88 867.221,1406.88 867.23,1406.88 867.24,1406.88 867.249,1406.88 867.258,1406.88 867.267,1406.88 867.276,1406.88 867.285,1406.88 867.295,1406.88 867.304,1406.88 867.313,1406.88 867.322,1406.88 867.331,1406.88 867.341,1406.88 867.35,1406.88 867.359,1406.88 867.368,1406.88 867.377,1406.88 867.387,1406.88 867.396,1406.88 867.405,1406.88 867.414,1406.88 867.423,1406.88 867.432,1406.88 867.442,1406.88 867.451,1406.88 867.46,1406.88 867.469,1406.88 867.478,1406.88 867.488,1406.88 867.497,1406.88 867.506,1406.88 867.515,1406.88 867.524,1406.88 867.534,1406.88 867.543,1406.88 867.552,1406.88 867.561,1406.88 867.57,1406.88 867.58,1406.88 867.589,1406.88 867.598,1406.88 867.607,1406.88 867.616,1406.88 867.625,1406.88 867.635,1406.88 867.644,1406.88 867.653,1406.88 867.662,1406.88 867.671,1406.88 867.681,1406.88 867.69,1406.88 867.699,1406.88 867.708,1406.88 867.717,1406.88 867.727,1406.88 867.736,1406.88 867.745,1406.88 867.754,1406.88 867.763,1406.88 867.772,1406.88 867.782,1406.88 867.791,1406.88 867.8,1406.88 867.809,1406.88 867.818,1406.88 867.828,1406.88 867.837,1406.88 867.846,1406.88 867.855,1406.88 867.864,1406.88 867.874,1406.88 867.883,1406.88 867.892,1406.88 867.901,1406.88 867.91,1406.88 867.92,1406.88 867.929,1406.88 867.938,1406.88 867.947,1406.88 867.956,1406.88 867.965,1406.88 867.975,1406.88 867.984,1406.88 867.993,1406.88 868.002,1406.88 868.011,1406.88 868.021,1406.88 868.03,1406.88 868.039,1406.88 868.048,1406.88 868.057,1406.88 868.067,1406.88 868.076,1406.88 868.085,1406.88 868.094,1406.88 868.103,1406.88 868.112,1406.88 868.122,1406.88 868.131,1406.88 868.14,1406.88 868.149,1406.88 868.158,1406.88 868.168,1406.88 868.177,1406.88 868.186,1406.88 868.195,1406.88 868.204,1406.88 868.214,1406.88 868.223,1406.88 868.232,1406.88 868.241,1406.88 868.25,1406.88 868.26,1406.88 868.269,1406.88 868.278,1406.88 868.287,1406.88 868.296,1406.88 868.305,1406.88 868.315,1406.88 868.324,1406.88 868.333,1406.88 868.342,1406.88 868.351,1406.88 868.361,1406.88 868.37,1406.88 868.379,1406.88 868.388,1406.88 868.397,1406.88 868.407,1406.88 868.416,1406.88 868.425,1406.88 868.434,1406.88 868.443,1406.88 868.452,1406.88 868.462,1406.88 868.471,1406.88 868.48,1406.88 868.489,1406.88 868.498,1406.88 868.508,1406.88 868.517,1406.88 868.526,1406.88 868.535,1406.88 868.544,1406.88 868.554,1406.88 868.563,1406.88 868.572,1406.88 868.581,1406.88 868.59,1406.88 868.6,1406.88 868.609,1406.88 868.618,1406.88 868.627,1406.88 868.636,1406.88 868.645,1406.88 868.655,1406.88 868.664,1406.88 868.673,1406.88 868.682,1406.88 868.691,1406.88 868.701,1406.88 868.71,1406.88 868.719,1406.88 868.728,1406.88 868.737,1406.88 868.747,1406.88 868.756,1406.88 868.765,1406.88 868.774,1406.88 868.783,1406.88 868.793,1406.88 868.802,1406.88 868.811,1406.88 868.82,1406.88 868.829,1406.88 868.838,1406.88 868.848,1406.88 868.857,1406.88 868.866,1406.88 868.875,1406.88 868.884,1406.88 868.894,1406.88 868.903,1406.88 868.912,1406.88 868.921,1406.88 868.93,1406.88 868.94,1406.88 868.949,1406.88 868.958,1406.88 868.967,1406.88 868.976,1406.88 868.985,1406.88 868.995,1406.88 869.004,1406.88 869.013,1406.88 869.022,1406.88 869.031,1406.88 869.041,1406.88 869.05,1406.88 869.059,1406.88 869.068,1406.88 869.077,1406.88 869.087,1406.88 869.096,1406.88 869.105,1406.88 869.114,1406.88 869.123,1406.88 869.133,1406.88 869.142,1406.88 869.151,1406.88 869.16,1406.88 869.169,1406.88 869.178,1406.88 869.188,1406.88 869.197,1406.88 869.206,1406.88 869.215,1406.88 869.224,1406.88 869.234,1406.88 869.243,1406.88 869.252,1406.88 869.261,1406.88 869.27,1406.88 869.28,1406.88 869.289,1406.88 869.298,1406.88 869.307,1406.88 869.316,1406.88 869.325,1406.88 869.335,1406.88 869.344,1406.88 869.353,1406.88 869.362,1406.88 869.371,1406.88 869.381,1406.88 869.39,1406.88 869.399,1406.88 869.408,1406.88 869.417,1406.88 869.427,1406.88 869.436,1406.88 869.445,1406.88 869.454,1406.88 869.463,1406.88 869.473,1406.88 869.482,1406.88 869.491,1406.88 869.5,1406.88 869.509,1406.88 869.518,1406.88 869.528,1406.88 869.537,1406.88 869.546,1406.88 869.555,1406.88 869.564,1406.88 869.574,1406.88 869.583,1406.88 869.592,1406.88 869.601,1406.88 869.61,1406.88 869.62,1406.88 869.629,1406.88 869.638,1406.88 869.647,1406.88 869.656,1406.88 869.665,1406.88 869.675,1406.88 869.684,1406.88 869.693,1406.88 869.702,1406.88 869.711,1406.88 869.721,1406.88 869.73,1406.88 869.739,1406.88 869.748,1406.88 869.757,1406.88 869.767,1406.88 869.776,1406.88 869.785,1406.88 869.794,1406.88 869.803,1406.88 869.813,1406.88 869.822,1406.88 869.831,1406.88 869.84,1406.88 869.849,1406.88 869.858,1406.88 869.868,1406.88 869.877,1406.88 869.886,1406.88 869.895,1406.88 869.904,1406.88 869.914,1406.88 869.923,1406.88 869.932,1406.88 869.941,1406.88 869.95,1406.88 869.96,1406.88 869.969,1406.88 869.978,1406.88 869.987,1406.88 869.996,1406.88 870.005,1406.88 870.015,1406.88 870.024,1406.88 870.033,1406.88 870.042,1406.88 870.051,1406.88 870.061,1406.88 870.07,1406.88 870.079,1406.88 870.088,1406.88 870.097,1406.88 870.107,1406.88 870.116,1406.88 870.125,1406.88 870.134,1406.88 870.143,1406.88 870.153,1406.88 870.162,1406.88 870.171,1406.88 870.18,1406.88 870.189,1406.88 870.198,1406.88 870.208,1406.88 870.217,1406.88 870.226,1406.88 870.235,1406.88 870.244,1406.88 870.254,1406.88 870.263,1406.88 870.272,1406.88 870.281,1406.88 870.29,1406.88 870.3,1406.88 870.309,1406.88 870.318,1406.88 870.327,1406.88 870.336,1406.88 870.345,1406.88 870.355,1406.88 870.364,1406.88 870.373,1406.88 870.382,1406.88 870.391,1406.88 870.401,1406.88 870.41,1406.88 870.419,1406.88 870.428,1406.88 870.437,1406.88 870.447,1406.88 870.456,1406.88 870.465,1406.88 870.474,1406.88 870.483,1406.88 870.493,1406.88 870.502,1406.88 870.511,1406.88 870.52,1406.88 870.529,1406.88 870.538,1406.88 870.548,1406.88 870.557,1406.88 870.566,1406.88 870.575,1406.88 870.584,1406.88 870.594,1406.88 870.603,1406.88 870.612,1406.88 870.621,1406.88 870.63,1406.88 870.64,1406.88 870.649,1406.88 870.658,1406.88 870.667,1406.88 870.676,1406.88 870.685,1406.88 870.695,1406.88 870.704,1406.88 870.713,1406.88 870.722,1406.88 870.731,1406.88 870.741,1406.88 870.75,1406.88 870.759,1406.88 870.768,1406.88 870.777,1406.88 870.787,1406.88 870.796,1406.88 870.805,1406.88 870.814,1406.88 870.823,1406.88 870.833,1406.88 870.842,1406.88 870.851,1406.88 870.86,1406.88 870.869,1406.88 870.878,1406.88 870.888,1406.88 870.897,1406.88 870.906,1406.88 870.915,1406.88 870.924,1406.88 870.934,1406.88 870.943,1406.88 870.952,1406.88 870.961,1406.88 870.97,1406.88 870.98,1406.88 870.989,1406.88 870.998,1406.88 871.007,1406.88 871.016,1406.88 871.025,1406.88 871.035,1406.88 871.044,1406.88 871.053,1406.88 871.062,1406.88 871.071,1406.88 871.081,1406.88 871.09,1406.88 871.099,1406.88 871.108,1406.88 871.117,1406.88 871.127,1406.88 871.136,1406.88 871.145,1406.88 871.154,1406.88 871.163,1406.88 871.173,1406.88 871.182,1406.88 871.191,1406.88 871.2,1406.88 871.209,1406.88 871.218,1406.88 871.228,1406.88 871.237,1406.88 871.246,1406.88 871.255,1406.88 871.264,1406.88 871.274,1406.88 871.283,1406.88 871.292,1406.88 871.301,1406.88 871.31,1406.88 871.32,1406.88 871.329,1406.88 871.338,1406.88 871.347,1406.88 871.356,1406.88 871.366,1406.88 871.375,1406.88 871.384,1406.88 871.393,1406.88 871.402,1406.88 871.411,1406.88 871.421,1406.88 871.43,1406.88 871.439,1406.88 871.448,1406.88 871.457,1406.88 871.467,1406.88 871.476,1406.88 871.485,1406.88 871.494,1406.88 871.503,1406.88 871.513,1406.88 871.522,1406.88 871.531,1406.88 871.54,1406.88 871.549,1406.88 871.558,1406.88 871.568,1406.88 871.577,1406.88 871.586,1406.88 871.595,1406.88 871.604,1406.88 871.614,1406.88 871.623,1406.88 871.632,1406.88 871.641,1406.88 871.65,1406.88 871.66,1406.88 871.669,1406.88 871.678,1406.88 871.687,1406.88 871.696,1406.88 871.706,1406.88 871.715,1406.88 871.724,1406.88 871.733,1406.88 871.742,1406.88 871.751,1406.88 871.761,1406.88 871.77,1406.88 871.779,1406.88 871.788,1406.88 871.797,1406.88 871.807,1406.88 871.816,1406.88 871.825,1406.88 871.834,1406.88 871.843,1406.88 871.853,1406.88 871.862,1406.88 871.871,1406.88 871.88,1406.88 871.889,1406.88 871.898,1406.88 871.908,1406.88 871.917,1406.88 871.926,1406.88 871.935,1406.88 871.944,1406.88 871.954,1406.88 871.963,1406.88 871.972,1406.88 871.981,1406.88 871.99,1406.88 872,1406.88 872.009,1406.88 872.018,1406.88 872.027,1406.88 872.036,1406.88 872.046,1406.88 872.055,1406.88 872.064,1406.88 872.073,1406.88 872.082,1406.88 872.091,1406.88 872.101,1406.88 872.11,1406.88 872.119,1406.88 872.128,1406.88 872.137,1406.88 872.147,1406.88 872.156,1406.88 872.165,1406.88 872.174,1406.88 872.183,1406.88 872.193,1406.88 872.202,1406.88 872.211,1406.88 872.22,1406.88 872.229,1406.88 872.238,1406.88 872.248,1406.88 872.257,1406.88 872.266,1406.88 872.275,1406.88 872.284,1406.88 872.294,1406.88 872.303,1406.88 872.312,1406.88 872.321,1406.88 872.33,1406.88 872.34,1406.88 872.349,1406.88 872.358,1406.88 872.367,1406.88 872.376,1406.88 872.386,1406.88 872.395,1406.88 872.404,1406.88 872.413,1406.88 872.422,1406.88 872.431,1406.88 872.441,1406.88 872.45,1406.88 872.459,1406.88 872.468,1406.88 872.477,1406.88 872.487,1406.88 872.496,1406.88 872.505,1406.88 872.514,1406.88 872.523,1406.88 872.533,1406.88 872.542,1406.88 872.551,1406.88 872.56,1406.88 872.569,1406.88 872.578,1406.88 872.588,1406.88 872.597,1406.88 872.606,1406.88 872.615,1406.88 872.624,1406.88 872.634,1406.88 872.643,1406.88 872.652,1406.88 872.661,1406.88 872.67,1406.88 872.68,1406.88 872.689,1406.88 872.698,1406.88 872.707,1406.88 872.716,1406.88 872.726,1406.88 872.735,1406.88 872.744,1406.88 872.753,1406.88 872.762,1406.88 872.771,1406.88 872.781,1406.88 872.79,1406.88 872.799,1406.88 872.808,1406.88 872.817,1406.88 872.827,1406.88 872.836,1406.88 872.845,1406.88 872.854,1406.88 872.863,1406.88 872.873,1406.88 872.882,1406.88 872.891,1406.88 872.9,1406.88 872.909,1406.88 872.918,1406.88 872.928,1406.88 872.937,1406.88 872.946,1406.88 872.955,1406.88 872.964,1406.88 872.974,1406.88 872.983,1406.88 872.992,1406.88 873.001,1406.88 873.01,1406.88 873.02,1406.88 873.029,1406.88 873.038,1406.88 873.047,1406.88 873.056,1406.88 873.066,1406.88 873.075,1406.88 873.084,1406.88 873.093,1406.88 873.102,1406.88 873.111,1406.88 873.121,1406.88 873.13,1406.88 873.139,1406.88 873.148,1406.88 873.157,1406.88 873.167,1406.88 873.176,1406.88 873.185,1406.88 873.194,1406.88 873.203,1406.88 873.213,1406.88 873.222,1406.88 873.231,1406.88 873.24,1406.88 873.249,1406.88 873.258,1406.88 873.268,1406.88 873.277,1406.88 873.286,1406.88 873.295,1406.88 873.304,1406.88 873.314,1406.88 873.323,1406.88 873.332,1406.88 873.341,1406.88 873.35,1406.88 873.36,1406.88 873.369,1406.88 873.378,1406.88 873.387,1406.88 873.396,1406.88 873.406,1406.88 873.415,1406.88 873.424,1406.88 873.433,1406.88 873.442,1406.88 873.451,1406.88 873.461,1406.88 873.47,1406.88 873.479,1406.88 873.488,1406.88 873.497,1406.88 873.507,1406.88 873.516,1406.88 873.525,1406.88 873.534,1406.88 873.543,1406.88 873.553,1406.88 873.562,1406.88 873.571,1406.88 873.58,1406.88 873.589,1406.88 873.598,1406.88 873.608,1406.88 873.617,1406.88 873.626,1406.88 873.635,1406.88 873.644,1406.88 873.654,1406.88 873.663,1406.88 873.672,1406.88 873.681,1406.88 873.69,1406.88 873.7,1406.88 873.709,1406.88 873.718,1406.88 873.727,1406.88 873.736,1406.88 873.746,1406.88 873.755,1406.88 873.764,1406.88 873.773,1406.88 873.782,1406.88 873.791,1406.88 873.801,1406.88 873.81,1406.88 873.819,1406.88 873.828,1406.88 873.837,1406.88 873.847,1406.88 873.856,1406.88 873.865,1406.88 873.874,1406.88 873.883,1406.88 873.893,1406.88 873.902,1406.88 873.911,1406.88 873.92,1406.88 873.929,1406.88 873.939,1406.88 873.948,1406.88 873.957,1406.88 873.966,1406.88 873.975,1406.88 873.984,1406.88 873.994,1406.88 874.003,1406.88 874.012,1406.88 874.021,1406.88 874.03,1406.88 874.04,1406.88 874.049,1406.88 874.058,1406.88 874.067,1406.88 874.076,1406.88 874.086,1406.88 874.095,1406.88 874.104,1406.88 874.113,1406.88 874.122,1406.88 874.131,1406.88 874.141,1406.88 874.15,1406.88 874.159,1406.88 874.168,1406.88 874.177,1406.88 874.187,1406.88 874.196,1406.88 874.205,1406.88 874.214,1406.88 874.223,1406.88 874.233,1406.88 874.242,1406.88 874.251,1406.88 874.26,1406.88 874.269,1406.88 874.279,1406.88 874.288,1406.88 874.297,1406.88 874.306,1406.88 874.315,1406.88 874.324,1406.88 874.334,1406.88 874.343,1406.88 874.352,1406.88 874.361,1406.88 874.37,1406.88 874.38,1406.88 874.389,1406.88 874.398,1406.88 874.407,1406.88 874.416,1406.88 874.426,1406.88 874.435,1406.88 874.444,1406.88 874.453,1406.88 874.462,1406.88 874.471,1406.88 874.481,1406.88 874.49,1406.88 874.499,1406.88 874.508,1406.88 874.517,1406.88 874.527,1406.88 874.536,1406.88 874.545,1406.88 874.554,1406.88 874.563,1406.88 874.573,1406.88 874.582,1406.88 874.591,1406.88 874.6,1406.88 874.609,1406.88 874.619,1406.88 874.628,1406.88 874.637,1406.88 874.646,1406.88 874.655,1406.88 874.664,1406.88 874.674,1406.88 874.683,1406.88 874.692,1406.88 874.701,1406.88 874.71,1406.88 874.72,1406.88 874.729,1406.88 874.738,1406.88 874.747,1406.88 874.756,1406.88 874.766,1406.88 874.775,1406.88 874.784,1406.88 874.793,1406.88 874.802,1406.88 874.811,1406.88 874.821,1406.88 874.83,1406.88 874.839,1406.88 874.848,1406.88 874.857,1406.88 874.867,1406.88 874.876,1406.88 874.885,1406.88 874.894,1406.88 874.903,1406.88 874.913,1406.88 874.922,1406.88 874.931,1406.88 874.94,1406.88 874.949,1406.88 874.959,1406.88 874.968,1406.88 874.977,1406.88 874.986,1406.88 874.995,1406.88 875.004,1406.88 875.014,1406.88 875.023,1406.88 875.032,1406.88 875.041,1406.88 875.05,1406.88 875.06,1406.88 875.069,1406.88 875.078,1406.88 875.087,1406.88 875.096,1406.88 875.106,1406.88 875.115,1406.88 875.124,1406.88 875.133,1406.88 875.142,1406.88 875.151,1406.88 875.161,1406.88 875.17,1406.88 875.179,1406.88 875.188,1406.88 875.197,1406.88 875.207,1406.88 875.216,1406.88 875.225,1406.88 875.234,1406.88 875.243,1406.88 875.253,1406.88 875.262,1406.88 875.271,1406.88 875.28,1406.88 875.289,1406.88 875.299,1406.88 875.308,1406.88 875.317,1406.88 875.326,1406.88 875.335,1406.88 875.344,1406.88 875.354,1406.88 875.363,1406.88 875.372,1406.88 875.381,1406.88 875.39,1406.88 875.4,1406.88 875.409,1406.88 875.418,1406.88 875.427,1406.88 875.436,1406.88 875.446,1406.88 875.455,1406.88 875.464,1406.88 875.473,1406.88 875.482,1406.88 875.491,1406.88 875.501,1406.88 875.51,1406.88 875.519,1406.88 875.528,1406.88 875.537,1406.88 875.547,1406.88 875.556,1406.88 875.565,1406.88 875.574,1406.88 875.583,1406.88 875.593,1406.88 875.602,1406.88 875.611,1406.88 875.62,1406.88 875.629,1406.88 875.639,1406.88 875.648,1406.88 875.657,1406.88 875.666,1406.88 875.675,1406.88 875.684,1406.88 875.694,1406.88 875.703,1406.88 875.712,1406.88 875.721,1406.88 875.73,1406.88 875.74,1406.88 875.749,1406.88 875.758,1406.88 875.767,1406.88 875.776,1406.88 875.786,1406.88 875.795,1406.88 875.804,1406.88 875.813,1406.88 875.822,1406.88 875.831,1406.88 875.841,1406.88 875.85,1406.88 875.859,1406.88 875.868,1406.88 875.877,1406.88 875.887,1406.88 875.896,1406.88 875.905,1406.88 875.914,1406.88 875.923,1406.88 875.933,1406.88 875.942,1406.88 875.951,1406.88 875.96,1406.88 875.969,1406.88 875.979,1406.88 875.988,1406.88 875.997,1406.88 876.006,1406.88 876.015,1406.88 876.024,1406.88 876.034,1406.88 876.043,1406.88 876.052,1406.88 876.061,1406.88 876.07,1406.88 876.08,1406.88 876.089,1406.88 876.098,1406.88 876.107,1406.88 876.116,1406.88 876.126,1406.88 876.135,1406.88 876.144,1406.88 876.153,1406.88 876.162,1406.88 876.171,1406.88 876.181,1406.88 876.19,1406.88 876.199,1406.88 876.208,1406.88 876.217,1406.88 876.227,1406.88 876.236,1406.88 876.245,1406.88 876.254,1406.88 876.263,1406.88 876.273,1406.88 876.282,1406.88 876.291,1406.88 876.3,1406.88 876.309,1406.88 876.319,1406.88 876.328,1406.88 876.337,1406.88 876.346,1406.88 876.355,1406.88 876.364,1406.88 876.374,1406.88 876.383,1406.88 876.392,1406.88 876.401,1406.88 876.41,1406.88 876.42,1406.88 876.429,1406.88 876.438,1406.88 876.447,1406.88 876.456,1406.88 876.466,1406.88 876.475,1406.88 876.484,1406.88 876.493,1406.88 876.502,1406.88 876.512,1406.88 876.521,1406.88 876.53,1406.88 876.539,1406.88 876.548,1406.88 876.557,1406.88 876.567,1406.88 876.576,1406.88 876.585,1406.88 876.594,1406.88 876.603,1406.88 876.613,1406.88 876.622,1406.88 876.631,1406.88 876.64,1406.88 876.649,1406.88 876.659,1406.88 876.668,1406.88 876.677,1406.88 876.686,1406.88 876.695,1406.88 876.704,1406.88 876.714,1406.88 876.723,1406.88 876.732,1406.88 876.741,1406.88 876.75,1406.88 876.76,1406.88 876.769,1406.88 876.778,1406.88 876.787,1406.88 876.796,1406.88 876.806,1406.88 876.815,1406.88 876.824,1406.88 876.833,1406.88 876.842,1406.88 876.852,1406.88 876.861,1406.88 876.87,1406.88 876.879,1406.88 876.888,1406.88 876.897,1406.88 876.907,1406.88 876.916,1406.88 876.925,1406.88 876.934,1406.88 876.943,1406.88 876.953,1406.88 876.962,1406.88 876.971,1406.88 876.98,1406.88 876.989,1406.88 876.999,1406.88 877.008,1406.88 877.017,1406.88 877.026,1406.88 877.035,1406.88 877.044,1406.88 877.054,1406.88 877.063,1406.88 877.072,1406.88 877.081,1406.88 877.09,1406.88 877.1,1406.88 877.109,1406.88 877.118,1406.88 877.127,1406.88 877.136,1406.88 877.146,1406.88 877.155,1406.88 877.164,1406.88 877.173,1406.88 877.182,1406.88 877.192,1406.88 877.201,1406.88 877.21,1406.88 877.219,1406.88 877.228,1406.88 877.237,1406.88 877.247,1406.88 877.256,1406.88 877.265,1406.88 877.274,1406.88 877.283,1406.88 877.293,1406.88 877.302,1406.88 877.311,1406.88 877.32,1406.88 877.329,1406.88 877.339,1406.88 877.348,1406.88 877.357,1406.88 877.366,1406.88 877.375,1406.88 877.384,1406.88 877.394,1406.88 877.403,1406.88 877.412,1406.88 877.421,1406.88 877.43,1406.88 877.44,1406.88 877.449,1406.88 877.458,1406.88 877.467,1406.88 877.476,1406.88 877.486,1406.88 877.495,1406.88 877.504,1406.88 877.513,1406.88 877.522,1406.88 877.532,1406.88 877.541,1406.88 877.55,1406.88 877.559,1406.88 877.568,1406.88 877.577,1406.88 877.587,1406.88 877.596,1406.88 877.605,1406.88 877.614,1406.88 877.623,1406.88 877.633,1406.88 877.642,1406.88 877.651,1406.88 877.66,1406.88 877.669,1406.88 877.679,1406.88 877.688,1406.88 877.697,1406.88 877.706,1406.88 877.715,1406.88 877.724,1406.88 877.734,1406.88 877.743,1406.88 877.752,1406.88 877.761,1406.88 877.77,1406.88 877.78,1406.88 877.789,1406.88 877.798,1406.88 877.807,1406.88 877.816,1406.88 877.826,1406.88 877.835,1406.88 877.844,1406.88 877.853,1406.88 877.862,1406.88 877.872,1406.88 877.881,1406.88 877.89,1406.88 877.899,1406.88 877.908,1406.88 877.917,1406.88 877.927,1406.88 877.936,1406.88 877.945,1406.88 877.954,1406.88 877.963,1406.88 877.973,1406.88 877.982,1406.88 877.991,1406.88 878,1406.88 878.009,1406.88 878.019,1406.88 878.028,1406.88 878.037,1406.88 878.046,1406.88 878.055,1406.88 878.064,1406.88 878.074,1406.88 878.083,1406.88 878.092,1406.88 878.101,1406.88 878.11,1406.88 878.12,1406.88 878.129,1406.88 878.138,1406.88 878.147,1406.88 878.156,1406.88 878.166,1406.88 878.175,1406.88 878.184,1406.88 878.193,1406.88 878.202,1406.88 878.212,1406.88 878.221,1406.88 878.23,1406.88 878.239,1406.88 878.248,1406.88 878.257,1406.88 878.267,1406.88 878.276,1406.88 878.285,1406.88 878.294,1406.88 878.303,1406.88 878.313,1406.88 878.322,1406.88 878.331,1406.88 878.34,1406.88 878.349,1406.88 878.359,1406.88 878.368,1406.88 878.377,1406.88 878.386,1406.88 878.395,1406.88 878.404,1406.88 878.414,1406.88 878.423,1406.88 878.432,1406.88 878.441,1406.88 878.45,1406.88 878.46,1406.88 878.469,1406.88 878.478,1406.88 878.487,1406.88 878.496,1406.88 878.506,1406.88 878.515,1406.88 878.524,1406.88 878.533,1406.88 878.542,1406.88 878.552,1406.88 878.561,1406.88 878.57,1406.88 878.579,1406.88 878.588,1406.88 878.597,1406.88 878.607,1406.88 878.616,1406.88 878.625,1406.88 878.634,1406.88 878.643,1406.88 878.653,1406.88 878.662,1406.88 878.671,1406.88 878.68,1406.88 878.689,1406.88 878.699,1406.88 878.708,1406.88 878.717,1406.88 878.726,1406.88 878.735,1406.88 878.745,1406.88 878.754,1406.88 878.763,1406.88 878.772,1406.88 878.781,1406.88 878.79,1406.88 878.8,1406.88 878.809,1406.88 878.818,1406.88 878.827,1406.88 878.836,1406.88 878.846,1406.88 878.855,1406.88 878.864,1406.88 878.873,1406.88 878.882,1406.88 878.892,1406.88 878.901,1406.88 878.91,1406.88 878.919,1406.88 878.928,1406.88 878.937,1406.88 878.947,1406.88 878.956,1406.88 878.965,1406.88 878.974,1406.88 878.983,1406.88 878.993,1406.88 879.002,1406.88 879.011,1406.88 879.02,1406.88 879.029,1406.88 879.039,1406.88 879.048,1406.88 879.057,1406.88 879.066,1406.88 879.075,1406.88 879.085,1406.88 879.094,1406.88 879.103,1406.88 879.112,1406.88 879.121,1406.88 879.13,1406.88 879.14,1406.88 879.149,1406.88 879.158,1406.88 879.167,1406.88 879.176,1406.88 879.186,1406.88 879.195,1406.88 879.204,1406.88 879.213,1406.88 879.222,1406.88 879.232,1406.88 879.241,1406.88 879.25,1406.88 879.259,1406.88 879.268,1406.88 879.277,1406.88 879.287,1406.88 879.296,1406.88 879.305,1406.88 879.314,1406.88 879.323,1406.88 879.333,1406.88 879.342,1406.88 879.351,1406.88 879.36,1406.88 879.369,1406.88 879.379,1406.88 879.388,1406.88 879.397,1406.88 879.406,1406.88 879.415,1406.88 879.425,1406.88 879.434,1406.88 879.443,1406.88 879.452,1406.88 879.461,1406.88 879.47,1406.88 879.48,1406.88 879.489,1406.88 879.498,1406.88 879.507,1406.88 879.516,1406.88 879.526,1406.88 879.535,1406.88 879.544,1406.88 879.553,1406.88 879.562,1406.88 879.572,1406.88 879.581,1406.88 879.59,1406.88 879.599,1406.88 879.608,1406.88 879.617,1406.88 879.627,1406.88 879.636,1406.88 879.645,1406.88 879.654,1406.88 879.663,1406.88 879.673,1406.88 879.682,1406.88 879.691,1406.88 879.7,1406.88 879.709,1406.88 879.719,1406.88 879.728,1406.88 879.737,1406.88 879.746,1406.88 879.755,1406.88 879.765,1406.88 879.774,1406.88 879.783,1406.88 879.792,1406.88 879.801,1406.88 879.81,1406.88 879.82,1406.88 879.829,1406.88 879.838,1406.88 879.847,1406.88 879.856,1406.88 879.866,1406.88 879.875,1406.88 879.884,1406.88 879.893,1406.88 879.902,1406.88 879.912,1406.88 879.921,1406.88 879.93,1406.88 879.939,1406.88 879.948,1406.88 879.957,1406.88 879.967,1406.88 879.976,1406.88 879.985,1406.88 879.994,1406.88 880.003,1406.88 880.013,1406.88 880.022,1406.88 880.031,1406.88 880.04,1406.88 880.049,1406.88 880.059,1406.88 880.068,1406.88 880.077,1406.88 880.086,1406.88 880.095,1406.88 880.105,1406.88 880.114,1406.88 880.123,1406.88 880.132,1406.88 880.141,1406.88 880.15,1406.88 880.16,1406.88 880.169,1406.88 880.178,1406.88 880.187,1406.88 880.196,1406.88 880.206,1406.88 880.215,1406.88 880.224,1406.88 880.233,1406.88 880.242,1406.88 880.252,1406.88 880.261,1406.88 880.27,1406.88 880.279,1406.88 880.288,1406.88 880.297,1406.88 880.307,1406.88 880.316,1406.88 880.325,1406.88 880.334,1406.88 880.343,1406.88 880.353,1406.88 880.362,1406.88 880.371,1406.88 880.38,1406.88 880.389,1406.88 880.399,1406.88 880.408,1406.88 880.417,1406.88 880.426,1406.88 880.435,1406.88 880.445,1406.88 880.454,1406.88 880.463,1406.88 880.472,1406.88 880.481,1406.88 880.49,1406.88 880.5,1406.88 880.509,1406.88 880.518,1406.88 880.527,1406.88 880.536,1406.88 880.546,1406.88 880.555,1406.88 880.564,1406.88 880.573,1406.88 880.582,1406.88 880.592,1406.88 880.601,1406.88 880.61,1406.88 880.619,1406.88 880.628,1406.88 880.637,1406.88 880.647,1406.88 880.656,1406.88 880.665,1406.88 880.674,1406.88 880.683,1406.88 880.693,1406.88 880.702,1406.88 880.711,1406.88 880.72,1406.88 880.729,1406.88 880.739,1406.88 880.748,1406.88 880.757,1406.88 880.766,1406.88 880.775,1406.88 880.785,1406.88 880.794,1406.88 880.803,1406.88 880.812,1406.88 880.821,1406.88 880.83,1406.88 880.84,1406.88 880.849,1406.88 880.858,1406.88 880.867,1406.88 880.876,1406.88 880.886,1406.88 880.895,1406.88 880.904,1406.88 880.913,1406.88 880.922,1406.88 880.932,1406.88 880.941,1406.88 880.95,1406.88 880.959,1406.88 880.968,1406.88 880.977,1406.88 880.987,1406.88 880.996,1406.88 881.005,1406.88 881.014,1406.88 881.023,1406.88 881.033,1406.88 881.042,1406.88 881.051,1406.88 881.06,1406.88 881.069,1406.88 881.079,1406.88 881.088,1406.88 881.097,1406.88 881.106,1406.88 881.115,1406.88 881.125,1406.88 881.134,1406.88 881.143,1406.88 881.152,1406.88 881.161,1406.88 881.17,1406.88 881.18,1406.88 881.189,1406.88 881.198,1406.88 881.207,1406.88 881.216,1406.88 881.226,1406.88 881.235,1406.88 881.244,1406.88 881.253,1406.88 881.262,1406.88 881.272,1406.88 881.281,1406.88 881.29,1406.88 881.299,1406.88 881.308,1406.88 881.318,1406.88 881.327,1406.88 881.336,1406.88 881.345,1406.88 881.354,1406.88 881.363,1406.88 881.373,1406.88 881.382,1406.88 881.391,1406.88 881.4,1406.88 881.409,1406.88 881.419,1406.88 881.428,1406.88 881.437,1406.88 881.446,1406.88 881.455,1406.88 881.465,1406.88 881.474,1406.88 881.483,1406.88 881.492,1406.88 881.501,1406.88 881.51,1406.88 881.52,1406.88 881.529,1406.88 881.538,1406.88 881.547,1406.88 881.556,1406.88 881.566,1406.88 881.575,1406.88 881.584,1406.88 881.593,1406.88 881.602,1406.88 881.612,1406.88 881.621,1406.88 881.63,1406.88 881.639,1406.88 881.648,1406.88 881.658,1406.88 881.667,1406.88 881.676,1406.88 881.685,1406.88 881.694,1406.88 881.703,1406.88 881.713,1406.88 881.722,1406.88 881.731,1406.88 881.74,1406.88 881.749,1406.88 881.759,1406.88 881.768,1406.88 881.777,1406.88 881.786,1406.88 881.795,1406.88 881.805,1406.88 881.814,1406.88 881.823,1406.88 881.832,1406.88 881.841,1406.88 881.85,1406.88 881.86,1406.88 881.869,1406.88 881.878,1406.88 881.887,1406.88 881.896,1406.88 881.906,1406.88 881.915,1406.88 881.924,1406.88 881.933,1406.88 881.942,1406.88 881.952,1406.88 881.961,1406.88 881.97,1406.88 881.979,1406.88 881.988,1406.88 881.998,1406.88 882.007,1406.88 882.016,1406.88 882.025,1406.88 882.034,1406.88 882.043,1406.88 882.053,1406.88 882.062,1406.88 882.071,1406.88 882.08,1406.88 882.089,1406.88 882.099,1406.88 882.108,1406.88 882.117,1406.88 882.126,1406.88 882.135,1406.88 882.145,1406.88 882.154,1406.88 882.163,1406.88 882.172,1406.88 882.181,1406.88 882.19,1406.88 882.2,1406.88 882.209,1406.88 882.218,1406.88 882.227,1406.88 882.236,1406.88 882.246,1406.88 882.255,1406.88 882.264,1406.88 882.273,1406.88 882.282,1406.88 882.292,1406.88 882.301,1406.88 882.31,1406.88 882.319,1406.88 882.328,1406.88 882.338,1406.88 882.347,1406.88 882.356,1406.88 882.365,1406.88 882.374,1406.88 882.383,1406.88 882.393,1406.88 882.402,1406.88 882.411,1406.88 882.42,1406.88 882.429,1406.88 882.439,1406.88 882.448,1406.88 882.457,1406.88 882.466,1406.88 882.475,1406.88 882.485,1406.88 882.494,1406.88 882.503,1406.88 882.512,1406.88 882.521,1406.88 882.53,1406.88 882.54,1406.88 882.549,1406.88 882.558,1406.88 882.567,1406.88 882.576,1406.88 882.586,1406.88 882.595,1406.88 882.604,1406.88 882.613,1406.88 882.622,1406.88 882.632,1406.88 882.641,1406.88 882.65,1406.88 882.659,1406.88 882.668,1406.88 882.678,1406.88 882.687,1406.88 882.696,1406.88 882.705,1406.88 882.714,1406.88 882.723,1406.88 882.733,1406.88 882.742,1406.88 882.751,1406.88 882.76,1406.88 882.769,1406.88 882.779,1406.88 882.788,1406.88 882.797,1406.88 882.806,1406.88 882.815,1406.88 882.825,1406.88 882.834,1406.88 882.843,1406.88 882.852,1406.88 882.861,1406.88 882.87,1406.88 882.88,1406.88 882.889,1406.88 882.898,1406.88 882.907,1406.88 882.916,1406.88 882.926,1406.88 882.935,1406.88 882.944,1406.88 882.953,1406.88 882.962,1406.88 882.972,1406.88 882.981,1406.88 882.99,1406.88 882.999,1406.88 883.008,1406.88 883.018,1406.88 883.027,1406.88 883.036,1406.88 883.045,1406.88 883.054,1406.88 883.063,1406.88 883.073,1406.88 883.082,1406.88 883.091,1406.88 883.1,1406.88 883.109,1406.88 883.119,1406.88 883.128,1406.88 883.137,1406.88 883.146,1406.88 883.155,1406.88 883.165,1406.88 883.174,1406.88 883.183,1406.88 883.192,1406.88 883.201,1406.88 883.21,1406.88 883.22,1406.88 883.229,1406.88 883.238,1406.88 883.247,1406.88 883.256,1406.88 883.266,1406.88 883.275,1406.88 883.284,1406.88 883.293,1406.88 883.302,1406.88 883.312,1406.88 883.321,1406.88 883.33,1406.88 883.339,1406.88 883.348,1406.88 883.358,1406.88 883.367,1406.88 883.376,1406.88 883.385,1406.88 883.394,1406.88 883.403,1406.88 883.413,1406.88 883.422,1406.88 883.431,1406.88 883.44,1406.88 883.449,1406.88 883.459,1406.88 883.468,1406.88 883.477,1406.88 883.486,1406.88 883.495,1406.88 883.505,1406.88 883.514,1406.88 883.523,1406.88 883.532,1406.88 883.541,1406.88 883.55,1406.88 883.56,1406.88 883.569,1406.88 883.578,1406.88 883.587,1406.88 883.596,1406.88 883.606,1406.88 883.615,1406.88 883.624,1406.88 883.633,1406.88 883.642,1406.88 883.652,1406.88 883.661,1406.88 883.67,1406.88 883.679,1406.88 883.688,1406.88 883.698,1406.88 883.707,1406.88 883.716,1406.88 883.725,1406.88 883.734,1406.88 883.743,1406.88 883.753,1406.88 883.762,1406.88 883.771,1406.88 883.78,1406.88 883.789,1406.88 883.799,1406.88 883.808,1406.88 883.817,1406.88 883.826,1406.88 883.835,1406.88 883.845,1406.88 883.854,1406.88 883.863,1406.88 883.872,1406.88 883.881,1406.88 883.891,1406.88 883.9,1406.88 883.909,1406.88 883.918,1406.88 883.927,1406.88 883.936,1406.88 883.946,1406.88 883.955,1406.88 883.964,1406.88 883.973,1406.88 883.982,1406.88 883.992,1406.88 884.001,1406.88 884.01,1406.88 884.019,1406.88 884.028,1406.88 884.038,1406.88 884.047,1406.88 884.056,1406.88 884.065,1406.88 884.074,1406.88 884.083,1406.88 884.093,1406.88 884.102,1406.88 884.111,1406.88 884.12,1406.88 884.129,1406.88 884.139,1406.88 884.148,1406.88 884.157,1406.88 884.166,1406.88 884.175,1406.88 884.185,1406.88 884.194,1406.88 884.203,1406.88 884.212,1406.88 884.221,1406.88 884.231,1406.88 884.24,1406.88 884.249,1406.88 884.258,1406.88 884.267,1406.88 884.276,1406.88 884.286,1406.88 884.295,1406.88 884.304,1406.88 884.313,1406.88 884.322,1406.88 884.332,1406.88 884.341,1406.88 884.35,1406.88 884.359,1406.88 884.368,1406.88 884.378,1406.88 884.387,1406.88 884.396,1406.88 884.405,1406.88 884.414,1406.88 884.423,1406.88 884.433,1406.88 884.442,1406.88 884.451,1406.88 884.46,1406.88 884.469,1406.88 884.479,1406.88 884.488,1406.88 884.497,1406.88 884.506,1406.88 884.515,1406.88 884.525,1406.88 884.534,1406.88 884.543,1406.88 884.552,1406.88 884.561,1406.88 884.571,1406.88 884.58,1406.88 884.589,1406.88 884.598,1406.88 884.607,1406.88 884.616,1406.88 884.626,1406.88 884.635,1406.88 884.644,1406.88 884.653,1406.88 884.662,1406.88 884.672,1406.88 884.681,1406.88 884.69,1406.88 884.699,1406.88 884.708,1406.88 884.718,1406.88 884.727,1406.88 884.736,1406.88 884.745,1406.88 884.754,1406.88 884.763,1406.88 884.773,1406.88 884.782,1406.88 884.791,1406.88 884.8,1406.88 884.809,1406.88 884.819,1406.88 884.828,1406.88 884.837,1406.88 884.846,1406.88 884.855,1406.88 884.865,1406.88 884.874,1406.88 884.883,1406.88 884.892,1406.88 884.901,1406.88 884.911,1406.88 884.92,1406.88 884.929,1406.88 884.938,1406.88 884.947,1406.88 884.956,1406.88 884.966,1406.88 884.975,1406.88 884.984,1406.88 884.993,1406.88 885.002,1406.88 885.012,1406.88 885.021,1406.88 885.03,1406.88 885.039,1406.88 885.048,1406.88 885.058,1406.88 885.067,1406.88 885.076,1406.88 885.085,1406.88 885.094,1406.88 885.103,1406.88 885.113,1406.88 885.122,1406.88 885.131,1406.88 885.14,1406.88 885.149,1406.88 885.159,1406.88 885.168,1406.88 885.177,1406.88 885.186,1406.88 885.195,1406.88 885.205,1406.88 885.214,1406.88 885.223,1406.88 885.232,1406.88 885.241,1406.88 885.251,1406.88 885.26,1406.88 885.269,1406.88 885.278,1406.88 885.287,1406.88 885.296,1406.88 885.306,1406.88 885.315,1406.88 885.324,1406.88 885.333,1406.88 885.342,1406.88 885.352,1406.88 885.361,1406.88 885.37,1406.88 885.379,1406.88 885.388,1406.88 885.398,1406.88 885.407,1406.88 885.416,1406.88 885.425,1406.88 885.434,1406.88 885.443,1406.88 885.453,1406.88 885.462,1406.88 885.471,1406.88 885.48,1406.88 885.489,1406.88 885.499,1406.88 885.508,1406.88 885.517,1406.88 885.526,1406.88 885.535,1406.88 885.545,1406.88 885.554,1406.88 885.563,1406.88 885.572,1406.88 885.581,1406.88 885.591,1406.88 885.6,1406.88 885.609,1406.88 885.618,1406.88 885.627,1406.88 885.636,1406.88 885.646,1406.88 885.655,1406.88 885.664,1406.88 885.673,1406.88 885.682,1406.88 885.692,1406.88 885.701,1406.88 885.71,1406.88 885.719,1406.88 885.728,1406.88 885.738,1406.88 885.747,1406.88 885.756,1406.88 885.765,1406.88 885.774,1406.88 885.783,1406.88 885.793,1406.88 885.802,1406.88 885.811,1406.88 885.82,1406.88 885.829,1406.88 885.839,1406.88 885.848,1406.88 885.857,1406.88 885.866,1406.88 885.875,1406.88 885.885,1406.88 885.894,1406.88 885.903,1406.88 885.912,1406.88 885.921,1406.88 885.931,1406.88 885.94,1406.88 885.949,1406.88 885.958,1406.88 885.967,1406.88 885.976,1406.88 885.986,1406.88 885.995,1406.88 886.004,1406.88 886.013,1406.88 886.022,1406.88 886.032,1406.88 886.041,1406.88 886.05,1406.88 886.059,1406.88 886.068,1406.88 886.078,1406.88 886.087,1406.88 886.096,1406.88 886.105,1406.88 886.114,1406.88 886.124,1406.88 886.133,1406.88 886.142,1406.88 886.151,1406.88 886.16,1406.88 886.169,1406.88 886.179,1406.88 886.188,1406.88 886.197,1406.88 886.206,1406.88 886.215,1406.88 886.225,1406.88 886.234,1406.88 886.243,1406.88 886.252,1406.88 886.261,1406.88 886.271,1406.88 886.28,1406.88 886.289,1406.88 886.298,1406.88 886.307,1406.88 886.316,1406.88 886.326,1406.88 886.335,1406.88 886.344,1406.88 886.353,1406.88 886.362,1406.88 886.372,1406.88 886.381,1406.88 886.39,1406.88 886.399,1406.88 886.408,1406.88 886.418,1406.88 886.427,1406.88 886.436,1406.88 886.445,1406.88 886.454,1406.88 886.464,1406.88 886.473,1406.88 886.482,1406.88 886.491,1406.88 886.5,1406.88 886.509,1406.88 886.519,1406.88 886.528,1406.88 886.537,1406.88 886.546,1406.88 886.555,1406.88 886.565,1406.88 886.574,1406.88 886.583,1406.88 886.592,1406.88 886.601,1406.88 886.611,1406.88 886.62,1406.88 886.629,1406.88 886.638,1406.88 886.647,1406.88 886.656,1406.88 886.666,1406.88 886.675,1406.88 886.684,1406.88 886.693,1406.88 886.702,1406.88 886.712,1406.88 886.721,1406.88 886.73,1406.88 886.739,1406.88 886.748,1406.88 886.758,1406.88 886.767,1406.88 886.776,1406.88 886.785,1406.88 886.794,1406.88 886.804,1406.88 886.813,1406.88 886.822,1406.88 886.831,1406.88 886.84,1406.88 886.849,1406.88 886.859,1406.88 886.868,1406.88 886.877,1406.88 886.886,1406.88 886.895,1406.88 886.905,1406.88 886.914,1406.88 886.923,1406.88 886.932,1406.88 886.941,1406.88 886.951,1406.88 886.96,1406.88 886.969,1406.88 886.978,1406.88 886.987,1406.88 886.996,1406.88 887.006,1406.88 887.015,1406.88 887.024,1406.88 887.033,1406.88 887.042,1406.88 887.052,1406.88 887.061,1406.88 887.07,1406.88 887.079,1406.88 887.088,1406.88 887.098,1406.88 887.107,1406.88 887.116,1406.88 887.125,1406.88 887.134,1406.88 887.144,1406.88 887.153,1406.88 887.162,1406.88 887.171,1406.88 887.18,1406.88 887.189,1406.88 887.199,1406.88 887.208,1406.88 887.217,1406.88 887.226,1406.88 887.235,1406.88 887.245,1406.88 887.254,1406.88 887.263,1406.88 887.272,1406.88 887.281,1406.88 887.291,1406.88 887.3,1406.88 887.309,1406.88 887.318,1406.88 887.327,1406.88 887.336,1406.88 887.346,1406.88 887.355,1406.88 887.364,1406.88 887.373,1406.88 887.382,1406.88 887.392,1406.88 887.401,1406.88 887.41,1406.88 887.419,1406.88 887.428,1406.88 887.438,1406.88 887.447,1406.88 887.456,1406.88 887.465,1406.88 887.474,1406.88 887.484,1406.88 887.493,1406.88 887.502,1406.88 887.511,1406.88 887.52,1406.88 887.529,1406.88 887.539,1406.88 887.548,1406.88 887.557,1406.88 887.566,1406.88 887.575,1406.88 887.585,1406.88 887.594,1406.88 887.603,1406.88 887.612,1406.88 887.621,1406.88 887.631,1406.88 887.64,1406.88 887.649,1406.88 887.658,1406.88 887.667,1406.88 887.676,1406.88 887.686,1406.88 887.695,1406.88 887.704,1406.88 887.713,1406.88 887.722,1406.88 887.732,1406.88 887.741,1406.88 887.75,1406.88 887.759,1406.88 887.768,1406.88 887.778,1406.88 887.787,1406.88 887.796,1406.88 887.805,1406.88 887.814,1406.88 887.824,1406.88 887.833,1406.88 887.842,1406.88 887.851,1406.88 887.86,1406.88 887.869,1406.88 887.879,1406.88 887.888,1406.88 887.897,1406.88 887.906,1406.88 887.915,1406.88 887.925,1406.88 887.934,1406.88 887.943,1406.88 887.952,1406.88 887.961,1406.88 887.971,1406.88 887.98,1406.88 887.989,1406.88 887.998,1406.88 888.007,1406.88 888.016,1406.88 888.026,1406.88 888.035,1406.88 888.044,1406.88 888.053,1406.88 888.062,1406.88 888.072,1406.88 888.081,1406.88 888.09,1406.88 888.099,1406.88 888.108,1406.88 888.118,1406.88 888.127,1406.88 888.136,1406.88 888.145,1406.88 888.154,1406.88 888.164,1406.88 888.173,1406.88 888.182,1406.88 888.191,1406.88 888.2,1406.88 888.209,1406.88 888.219,1406.88 888.228,1406.88 888.237,1406.88 888.246,1406.88 888.255,1406.88 888.265,1406.88 888.274,1406.88 888.283,1406.88 888.292,1406.88 888.301,1406.88 888.311,1406.88 888.32,1406.88 888.329,1406.88 888.338,1406.88 888.347,1406.88 888.356,1406.88 888.366,1406.88 888.375,1406.88 888.384,1406.88 888.393,1406.88 888.402,1406.88 888.412,1406.88 888.421,1406.88 888.43,1406.88 888.439,1406.88 888.448,1406.88 888.458,1406.88 888.467,1406.88 888.476,1406.88 888.485,1406.88 888.494,1406.88 888.504,1406.88 888.513,1406.88 888.522,1406.88 888.531,1406.88 888.54,1406.88 888.549,1406.88 888.559,1406.88 888.568,1406.88 888.577,1406.88 888.586,1406.88 888.595,1406.88 888.605,1406.88 888.614,1406.88 888.623,1406.88 888.632,1406.88 888.641,1406.88 888.651,1406.88 888.66,1406.88 888.669,1406.88 888.678,1406.88 888.687,1406.88 888.697,1406.88 888.706,1406.88 888.715,1406.88 888.724,1406.88 888.733,1406.88 888.742,1406.88 888.752,1406.88 888.761,1406.88 888.77,1406.88 888.779,1406.88 888.788,1406.88 888.798,1406.88 888.807,1406.88 888.816,1406.88 888.825,1406.88 888.834,1406.88 888.844,1406.88 888.853,1406.88 888.862,1406.88 888.871,1406.88 888.88,1406.88 888.889,1406.88 888.899,1406.88 888.908,1406.88 888.917,1406.88 888.926,1406.88 888.935,1406.88 888.945,1406.88 888.954,1406.88 888.963,1406.88 888.972,1406.88 888.981,1406.88 888.991,1406.88 889,1406.88 889.009,1406.88 889.018,1406.88 889.027,1406.88 889.037,1406.88 889.046,1406.88 889.055,1406.88 889.064,1406.88 889.073,1406.88 889.082,1406.88 889.092,1406.88 889.101,1406.88 889.11,1406.88 889.119,1406.88 889.128,1406.88 889.138,1406.88 889.147,1406.88 889.156,1406.88 889.165,1406.88 889.174,1406.88 889.184,1406.88 889.193,1406.88 889.202,1406.88 889.211,1406.88 889.22,1406.88 889.229,1406.88 889.239,1406.88 889.248,1406.88 889.257,1406.88 889.266,1406.88 889.275,1406.88 889.285,1406.88 889.294,1406.88 889.303,1406.88 889.312,1406.88 889.321,1406.88 889.331,1406.88 889.34,1406.88 889.349,1406.88 889.358,1406.88 889.367,1406.88 889.377,1406.88 889.386,1406.88 889.395,1406.88 889.404,1406.88 889.413,1406.88 889.422,1406.88 889.432,1406.88 889.441,1406.88 889.45,1406.88 889.459,1406.88 889.468,1406.88 889.478,1406.88 889.487,1406.88 889.496,1406.88 889.505,1406.88 889.514,1406.88 889.524,1406.88 889.533,1406.88 889.542,1406.88 889.551,1406.88 889.56,1406.88 889.569,1406.88 889.579,1406.88 889.588,1406.88 889.597,1406.88 889.606,1406.88 889.615,1406.88 889.625,1406.88 889.634,1406.88 889.643,1406.88 889.652,1406.88 889.661,1406.88 889.671,1406.88 889.68,1406.88 889.689,1406.88 889.698,1406.88 889.707,1406.88 889.717,1406.88 889.726,1406.88 889.735,1406.88 889.744,1406.88 889.753,1406.88 889.762,1406.88 889.772,1406.88 889.781,1406.88 889.79,1406.88 889.799,1406.88 889.808,1406.88 889.818,1406.88 889.827,1406.88 889.836,1406.88 889.845,1406.88 889.854,1406.88 889.864,1406.88 889.873,1406.88 889.882,1406.88 889.891,1406.88 889.9,1406.88 889.909,1406.88 889.919,1406.88 889.928,1406.88 889.937,1406.88 889.946,1406.88 889.955,1406.88 889.965,1406.88 889.974,1406.88 889.983,1406.88 889.992,1406.88 890.001,1406.88 890.011,1406.88 890.02,1406.88 890.029,1406.88 890.038,1406.88 890.047,1406.88 890.057,1406.88 890.066,1406.88 890.075,1406.88 890.084,1406.88 890.093,1406.88 890.102,1406.88 890.112,1406.88 890.121,1406.88 890.13,1406.88 890.139,1406.88 890.148,1406.88 890.158,1406.88 890.167,1406.88 890.176,1406.88 890.185,1406.88 890.194,1406.88 890.204,1406.88 890.213,1406.88 890.222,1406.88 890.231,1406.88 890.24,1406.88 890.249,1406.88 890.259,1406.88 890.268,1406.88 890.277,1406.88 890.286,1406.88 890.295,1406.88 890.305,1406.88 890.314,1406.88 890.323,1406.88 890.332,1406.88 890.341,1406.88 890.351,1406.88 890.36,1406.88 890.369,1406.88 890.378,1406.88 890.387,1406.88 890.397,1406.88 890.406,1406.88 890.415,1406.88 890.424,1406.88 890.433,1406.88 890.442,1406.88 890.452,1406.88 890.461,1406.88 890.47,1406.88 890.479,1406.88 890.488,1406.88 890.498,1406.88 890.507,1406.88 890.516,1406.88 890.525,1406.88 890.534,1406.88 890.544,1406.88 890.553,1406.88 890.562,1406.88 890.571,1406.88 890.58,1406.88 890.589,1406.88 890.599,1406.88 890.608,1406.88 890.617,1406.88 890.626,1406.88 890.635,1406.88 890.645,1406.88 890.654,1406.88 890.663,1406.88 890.672,1406.88 890.681,1406.88 890.691,1406.88 890.7,1406.88 890.709,1406.88 890.718,1406.88 890.727,1406.88 890.737,1406.88 890.746,1406.88 890.755,1406.88 890.764,1406.88 890.773,1406.88 890.782,1406.88 890.792,1406.88 890.801,1406.88 890.81,1406.88 890.819,1406.88 890.828,1406.88 890.838,1406.88 890.847,1406.88 890.856,1406.88 890.865,1406.88 890.874,1406.88 890.884,1406.88 890.893,1406.88 890.902,1406.88 890.911,1406.88 890.92,1406.88 890.929,1406.88 890.939,1406.88 890.948,1406.88 890.957,1406.88 890.966,1406.88 890.975,1406.88 890.985,1406.88 890.994,1406.88 891.003,1406.88 891.012,1406.88 891.021,1406.88 891.031,1406.88 891.04,1406.88 891.049,1406.88 891.058,1406.88 891.067,1406.88 891.077,1406.88 891.086,1406.88 891.095,1406.88 891.104,1406.88 891.113,1406.88 891.122,1406.88 891.132,1406.88 891.141,1406.88 891.15,1406.88 891.159,1406.88 891.168,1406.88 891.178,1406.88 891.187,1406.88 891.196,1406.88 891.205,1406.88 891.214,1406.88 891.224,1406.88 891.233,1406.88 891.242,1406.88 891.251,1406.88 891.26,1406.88 891.27,1406.88 891.279,1406.88 891.288,1406.88 891.297,1406.88 891.306,1406.88 891.315,1406.88 891.325,1406.88 891.334,1406.88 891.343,1406.88 891.352,1406.88 891.361,1406.88 891.371,1406.88 891.38,1406.88 891.389,1406.88 891.398,1406.88 891.407,1406.88 891.417,1406.88 891.426,1406.88 891.435,1406.88 891.444,1406.88 891.453,1406.88 891.462,1406.88 891.472,1406.88 891.481,1406.88 891.49,1406.88 891.499,1406.88 891.508,1406.88 891.518,1406.88 891.527,1406.88 891.536,1406.88 891.545,1406.88 891.554,1406.88 891.564,1406.88 891.573,1406.88 891.582,1406.88 891.591,1406.88 891.6,1406.88 891.61,1406.88 891.619,1406.88 891.628,1406.88 891.637,1406.88 891.646,1406.88 891.655,1406.88 891.665,1406.88 891.674,1406.88 891.683,1406.88 891.692,1406.88 891.701,1406.88 891.711,1406.88 891.72,1406.88 891.729,1406.88 891.738,1406.88 891.747,1406.88 891.757,1406.88 891.766,1406.88 891.775,1406.88 891.784,1406.88 891.793,1406.88 891.802,1406.88 891.812,1406.88 891.821,1406.88 891.83,1406.88 891.839,1406.88 891.848,1406.88 891.858,1406.88 891.867,1406.88 891.876,1406.88 891.885,1406.88 891.894,1406.88 891.904,1406.88 891.913,1406.88 891.922,1406.88 891.931,1406.88 891.94,1406.88 891.95,1406.88 891.959,1406.88 891.968,1406.88 891.977,1406.88 891.986,1406.88 891.995,1406.88 892.005,1406.88 892.014,1406.88 892.023,1406.88 892.032,1406.88 892.041,1406.88 892.051,1406.88 892.06,1406.88 892.069,1406.88 892.078,1406.88 892.087,1406.88 892.097,1406.88 892.106,1406.88 892.115,1406.88 892.124,1406.88 892.133,1406.88 892.142,1406.88 892.152,1406.88 892.161,1406.88 892.17,1406.88 892.179,1406.88 892.188,1406.88 892.198,1406.88 892.207,1406.88 892.216,1406.88 892.225,1406.88 892.234,1406.88 892.244,1406.88 892.253,1406.88 892.262,1406.88 892.271,1406.88 892.28,1406.88 892.29,1406.88 892.299,1406.88 892.308,1406.88 892.317,1406.88 892.326,1406.88 892.335,1406.88 892.345,1406.88 892.354,1406.88 892.363,1406.88 892.372,1406.88 892.381,1406.88 892.391,1406.88 892.4,1406.88 892.409,1406.88 892.418,1406.88 892.427,1406.88 892.437,1406.88 892.446,1406.88 892.455,1406.88 892.464,1406.88 892.473,1406.88 892.482,1406.88 892.492,1406.88 892.501,1406.88 892.51,1406.88 892.519,1406.88 892.528,1406.88 892.538,1406.88 892.547,1406.88 892.556,1406.88 892.565,1406.88 892.574,1406.88 892.584,1406.88 892.593,1406.88 892.602,1406.88 892.611,1406.88 892.62,1406.88 892.63,1406.88 892.639,1406.88 892.648,1406.88 892.657,1406.88 892.666,1406.88 892.675,1406.88 892.685,1406.88 892.694,1406.88 892.703,1406.88 892.712,1406.88 892.721,1406.88 892.731,1406.88 892.74,1406.88 892.749,1406.88 892.758,1406.88 892.767,1406.88 892.777,1406.88 892.786,1406.88 892.795,1406.88 892.804,1406.88 892.813,1406.88 892.822,1406.88 892.832,1406.88 892.841,1406.88 892.85,1406.88 892.859,1406.88 892.868,1406.88 892.878,1406.88 892.887,1406.88 892.896,1406.88 892.905,1406.88 892.914,1406.88 892.924,1406.88 892.933,1406.88 892.942,1406.88 892.951,1406.88 892.96,1406.88 892.97,1406.88 892.979,1406.88 892.988,1406.88 892.997,1406.88 893.006,1406.88 893.015,1406.88 893.025,1406.88 893.034,1406.88 893.043,1406.88 893.052,1406.88 893.061,1406.88 893.071,1406.88 893.08,1406.88 893.089,1406.88 893.098,1406.88 893.107,1406.88 893.117,1406.88 893.126,1406.88 893.135,1406.88 893.144,1406.88 893.153,1406.88 893.162,1406.88 893.172,1406.88 893.181,1406.88 893.19,1406.88 893.199,1406.88 893.208,1406.88 893.218,1406.88 893.227,1406.88 893.236,1406.88 893.245,1406.88 893.254,1406.88 893.264,1406.88 893.273,1406.88 893.282,1406.88 893.291,1406.88 893.3,1406.88 893.31,1406.88 893.319,1406.88 893.328,1406.88 893.337,1406.88 893.346,1406.88 893.355,1406.88 893.365,1406.88 893.374,1406.88 893.383,1406.88 893.392,1406.88 893.401,1406.88 893.411,1406.88 893.42,1406.88 893.429,1406.88 893.438,1406.88 893.447,1406.88 893.457,1406.88 893.466,1406.88 893.475,1406.88 893.484,1406.88 893.493,1406.88 893.503,1406.88 893.512,1406.88 893.521,1406.88 893.53,1406.88 893.539,1406.88 893.548,1406.88 893.558,1406.88 893.567,1406.88 893.576,1406.88 893.585,1406.88 893.594,1406.88 893.604,1406.88 893.613,1406.88 893.622,1406.88 893.631,1406.88 893.64,1406.88 893.65,1406.88 893.659,1406.88 893.668,1406.88 893.677,1406.88 893.686,1406.88 893.695,1406.88 893.705,1406.88 893.714,1406.88 893.723,1406.88 893.732,1406.88 893.741,1406.88 893.751,1406.88 893.76,1406.88 893.769,1406.88 893.778,1406.88 893.787,1406.88 893.797,1406.88 893.806,1406.88 893.815,1406.88 893.824,1406.88 893.833,1406.88 893.843,1406.88 893.852,1406.88 893.861,1406.88 893.87,1406.88 893.879,1406.88 893.888,1406.88 893.898,1406.88 893.907,1406.88 893.916,1406.88 893.925,1406.88 893.934,1406.88 893.944,1406.88 893.953,1406.88 893.962,1406.88 893.971,1406.88 893.98,1406.88 893.99,1406.88 893.999,1406.88 894.008,1406.88 894.017,1406.88 894.026,1406.88 894.035,1406.88 894.045,1406.88 894.054,1406.88 894.063,1406.88 894.072,1406.88 894.081,1406.88 894.091,1406.88 894.1,1406.88 894.109,1406.88 894.118,1406.88 894.127,1406.88 894.137,1406.88 894.146,1406.88 894.155,1406.88 894.164,1406.88 894.173,1406.88 894.183,1406.88 894.192,1406.88 894.201,1406.88 894.21,1406.88 894.219,1406.88 894.228,1406.88 894.238,1406.88 894.247,1406.88 894.256,1406.88 894.265,1406.88 894.274,1406.88 894.284,1406.88 894.293,1406.88 894.302,1406.88 894.311,1406.88 894.32,1406.88 894.33,1406.88 894.339,1406.88 894.348,1406.88 894.357,1406.88 894.366,1406.88 894.375,1406.88 894.385,1406.88 894.394,1406.88 894.403,1406.88 894.412,1406.88 894.421,1406.88 894.431,1406.88 894.44,1406.88 894.449,1406.88 894.458,1406.88 894.467,1406.88 894.477,1406.88 894.486,1406.88 894.495,1406.88 894.504,1406.88 894.513,1406.88 894.523,1406.88 894.532,1406.88 894.541,1406.88 894.55,1406.88 894.559,1406.88 894.568,1406.88 894.578,1406.88 894.587,1406.88 894.596,1406.88 894.605,1406.88 894.614,1406.88 894.624,1406.88 894.633,1406.88 894.642,1406.88 894.651,1406.88 894.66,1406.88 894.67,1406.88 894.679,1406.88 894.688,1406.88 894.697,1406.88 894.706,1406.88 894.715,1406.88 894.725,1406.88 894.734,1406.88 894.743,1406.88 894.752,1406.88 894.761,1406.88 894.771,1406.88 894.78,1406.88 894.789,1406.88 894.798,1406.88 894.807,1406.88 894.817,1406.88 894.826,1406.88 894.835,1406.88 894.844,1406.88 894.853,1406.88 894.863,1406.88 894.872,1406.88 894.881,1406.88 894.89,1406.88 894.899,1406.88 894.908,1406.88 894.918,1406.88 894.927,1406.88 894.936,1406.88 894.945,1406.88 894.954,1406.88 894.964,1406.88 894.973,1406.88 894.982,1406.88 894.991,1406.88 895,1406.88 895.01,1406.88 895.019,1406.88 895.028,1406.88 895.037,1406.88 895.046,1406.88 895.055,1406.88 895.065,1406.88 895.074,1406.88 895.083,1406.88 895.092,1406.88 895.101,1406.88 895.111,1406.88 895.12,1406.88 895.129,1406.88 895.138,1406.88 895.147,1406.88 895.157,1406.88 895.166,1406.88 895.175,1406.88 895.184,1406.88 895.193,1406.88 895.203,1406.88 895.212,1406.88 895.221,1406.88 895.23,1406.88 895.239,1406.88 895.248,1406.88 895.258,1406.88 895.267,1406.88 895.276,1406.88 895.285,1406.88 895.294,1406.88 895.304,1406.88 895.313,1406.88 895.322,1406.88 895.331,1406.88 895.34,1406.88 895.35,1406.88 895.359,1406.88 895.368,1406.88 895.377,1406.88 895.386,1406.88 895.395,1406.88 895.405,1406.88 895.414,1406.88 895.423,1406.88 895.432,1406.88 895.441,1406.88 895.451,1406.88 895.46,1406.88 895.469,1406.88 895.478,1406.88 895.487,1406.88 895.497,1406.88 895.506,1406.88 895.515,1406.88 895.524,1406.88 895.533,1406.88 895.543,1406.88 895.552,1406.88 895.561,1406.88 895.57,1406.88 895.579,1406.88 895.588,1406.88 895.598,1406.88 895.607,1406.88 895.616,1406.88 895.625,1406.88 895.634,1406.88 895.644,1406.88 895.653,1406.88 895.662,1406.88 895.671,1406.88 895.68,1406.88 895.69,1406.88 895.699,1406.88 895.708,1406.88 895.717,1406.88 895.726,1406.88 895.735,1406.88 895.745,1406.88 895.754,1406.88 895.763,1406.88 895.772,1406.88 895.781,1406.88 895.791,1406.88 895.8,1406.88 895.809,1406.88 895.818,1406.88 895.827,1406.88 895.837,1406.88 895.846,1406.88 895.855,1406.88 895.864,1406.88 895.873,1406.88 895.883,1406.88 895.892,1406.88 895.901,1406.88 895.91,1406.88 895.919,1406.88 895.928,1406.88 895.938,1406.88 895.947,1406.88 895.956,1406.88 895.965,1406.88 895.974,1406.88 895.984,1406.88 895.993,1406.88 896.002,1406.88 896.011,1406.88 896.02,1406.88 896.03,1406.88 896.039,1406.88 896.048,1406.88 896.057,1406.88 896.066,1406.88 896.076,1406.88 896.085,1406.88 896.094,1406.88 896.103,1406.88 896.112,1406.88 896.121,1406.88 896.131,1406.88 896.14,1406.88 896.149,1406.88 896.158,1406.88 896.167,1406.88 896.177,1406.88 896.186,1406.88 896.195,1406.88 896.204,1406.88 896.213,1406.88 896.223,1406.88 896.232,1406.88 896.241,1406.88 896.25,1406.88 896.259,1406.88 896.268,1406.88 896.278,1406.88 896.287,1406.88 896.296,1406.88 896.305,1406.88 896.314,1406.88 896.324,1406.88 896.333,1406.88 896.342,1406.88 896.351,1406.88 896.36,1406.88 896.37,1406.88 896.379,1406.88 896.388,1406.88 896.397,1406.88 896.406,1406.88 896.416,1406.88 896.425,1406.88 896.434,1406.88 896.443,1406.88 896.452,1406.88 896.461,1406.88 896.471,1406.88 896.48,1406.88 896.489,1406.88 896.498,1406.88 896.507,1406.88 896.517,1406.88 896.526,1406.88 896.535,1406.88 896.544,1406.88 896.553,1406.88 896.563,1406.88 896.572,1406.88 896.581,1406.88 896.59,1406.88 896.599,1406.88 896.608,1406.88 896.618,1406.88 896.627,1406.88 896.636,1406.88 896.645,1406.88 896.654,1406.88 896.664,1406.88 896.673,1406.88 896.682,1406.88 896.691,1406.88 896.7,1406.88 896.71,1406.88 896.719,1406.88 896.728,1406.88 896.737,1406.88 896.746,1406.88 896.756,1406.88 896.765,1406.88 896.774,1406.88 896.783,1406.88 896.792,1406.88 896.801,1406.88 896.811,1406.88 896.82,1406.88 896.829,1406.88 896.838,1406.88 896.847,1406.88 896.857,1406.88 896.866,1406.88 896.875,1406.88 896.884,1406.88 896.893,1406.88 896.903,1406.88 896.912,1406.88 896.921,1406.88 896.93,1406.88 896.939,1406.88 896.948,1406.88 896.958,1406.88 896.967,1406.88 896.976,1406.88 896.985,1406.88 896.994,1406.88 897.004,1406.88 897.013,1406.88 897.022,1406.88 897.031,1406.88 897.04,1406.88 897.05,1406.88 897.059,1406.88 897.068,1406.88 897.077,1406.88 897.086,1406.88 897.096,1406.88 897.105,1406.88 897.114,1406.88 897.123,1406.88 897.132,1406.88 897.141,1406.88 897.151,1406.88 897.16,1406.88 897.169,1406.88 897.178,1406.88 897.187,1406.88 897.197,1406.88 897.206,1406.88 897.215,1406.88 897.224,1406.88 897.233,1406.88 897.243,1406.88 897.252,1406.88 897.261,1406.88 897.27,1406.88 897.279,1406.88 897.288,1406.88 897.298,1406.88 897.307,1406.88 897.316,1406.88 897.325,1406.88 897.334,1406.88 897.344,1406.88 897.353,1406.88 897.362,1406.88 897.371,1406.88 897.38,1406.88 897.39,1406.88 897.399,1406.88 897.408,1406.88 897.417,1406.88 897.426,1406.88 897.436,1406.88 897.445,1406.88 897.454,1406.88 897.463,1406.88 897.472,1406.88 897.481,1406.88 897.491,1406.88 897.5,1406.88 897.509,1406.88 897.518,1406.88 897.527,1406.88 897.537,1406.88 897.546,1406.88 897.555,1406.88 897.564,1406.88 897.573,1406.88 897.583,1406.88 897.592,1406.88 897.601,1406.88 897.61,1406.88 897.619,1406.88 897.628,1406.88 897.638,1406.88 897.647,1406.88 897.656,1406.88 897.665,1406.88 897.674,1406.88 897.684,1406.88 897.693,1406.88 897.702,1406.88 897.711,1406.88 897.72,1406.88 897.73,1406.88 897.739,1406.88 897.748,1406.88 897.757,1406.88 897.766,1406.88 897.776,1406.88 897.785,1406.88 897.794,1406.88 897.803,1406.88 897.812,1406.88 897.821,1406.88 897.831,1406.88 897.84,1406.88 897.849,1406.88 897.858,1406.88 897.867,1406.88 897.877,1406.88 897.886,1406.88 897.895,1406.88 897.904,1406.88 897.913,1406.88 897.923,1406.88 897.932,1406.88 897.941,1406.88 897.95,1406.88 897.959,1406.88 897.968,1406.88 897.978,1406.88 897.987,1406.88 897.996,1406.88 898.005,1406.88 898.014,1406.88 898.024,1406.88 898.033,1406.88 898.042,1406.88 898.051,1406.88 898.06,1406.88 898.07,1406.88 898.079,1406.88 898.088,1406.88 898.097,1406.88 898.106,1406.88 898.116,1406.88 898.125,1406.88 898.134,1406.88 898.143,1406.88 898.152,1406.88 898.161,1406.88 898.171,1406.88 898.18,1406.88 898.189,1406.88 898.198,1406.88 898.207,1406.88 898.217,1406.88 898.226,1406.88 898.235,1406.88 898.244,1406.88 898.253,1406.88 898.263,1406.88 898.272,1406.88 898.281,1406.88 898.29,1406.88 898.299,1406.88 898.308,1406.88 898.318,1406.88 898.327,1406.88 898.336,1406.88 898.345,1406.88 898.354,1406.88 898.364,1406.88 898.373,1406.88 898.382,1406.88 898.391,1406.88 898.4,1406.88 898.41,1406.88 898.419,1406.88 898.428,1406.88 898.437,1406.88 898.446,1406.88 898.456,1406.88 898.465,1406.88 898.474,1406.88 898.483,1406.88 898.492,1406.88 898.501,1406.88 898.511,1406.88 898.52,1406.88 898.529,1406.88 898.538,1406.88 898.547,1406.88 898.557,1406.88 898.566,1406.88 898.575,1406.88 898.584,1406.88 898.593,1406.88 898.603,1406.88 898.612,1406.88 898.621,1406.88 898.63,1406.88 898.639,1406.88 898.649,1406.88 898.658,1406.88 898.667,1406.88 898.676,1406.88 898.685,1406.88 898.694,1406.88 898.704,1406.88 898.713,1406.88 898.722,1406.88 898.731,1406.88 898.74,1406.88 898.75,1406.88 898.759,1406.88 898.768,1406.88 898.777,1406.88 898.786,1406.88 898.796,1406.88 898.805,1406.88 898.814,1406.88 898.823,1406.88 898.832,1406.88 898.841,1406.88 898.851,1406.88 898.86,1406.88 898.869,1406.88 898.878,1406.88 898.887,1406.88 898.897,1406.88 898.906,1406.88 898.915,1406.88 898.924,1406.88 898.933,1406.88 898.943,1406.88 898.952,1406.88 898.961,1406.88 898.97,1406.88 898.979,1406.88 898.989,1406.88 898.998,1406.88 899.007,1406.88 899.016,1406.88 899.025,1406.88 899.034,1406.88 899.044,1406.88 899.053,1406.88 899.062,1406.88 899.071,1406.88 899.08,1406.88 899.09,1406.88 899.099,1406.88 899.108,1406.88 899.117,1406.88 899.126,1406.88 899.136,1406.88 899.145,1406.88 899.154,1406.88 899.163,1406.88 899.172,1406.88 899.181,1406.88 899.191,1406.88 899.2,1406.88 899.209,1406.88 899.218,1406.88 899.227,1406.88 899.237,1406.88 899.246,1406.88 899.255,1406.88 899.264,1406.88 899.273,1406.88 899.283,1406.88 899.292,1406.88 899.301,1406.88 899.31,1406.88 899.319,1406.88 899.329,1406.88 899.338,1406.88 899.347,1406.88 899.356,1406.88 899.365,1406.88 899.374,1406.88 899.384,1406.88 899.393,1406.88 899.402,1406.88 899.411,1406.88 899.42,1406.88 899.43,1406.88 899.439,1406.88 899.448,1406.88 899.457,1406.88 899.466,1406.88 899.476,1406.88 899.485,1406.88 899.494,1406.88 899.503,1406.88 899.512,1406.88 899.521,1406.88 899.531,1406.88 899.54,1406.88 899.549,1406.88 899.558,1406.88 899.567,1406.88 899.577,1406.88 899.586,1406.88 899.595,1406.88 899.604,1406.88 899.613,1406.88 899.623,1406.88 899.632,1406.88 899.641,1406.88 899.65,1406.88 899.659,1406.88 899.669,1406.88 899.678,1406.88 899.687,1406.88 899.696,1406.88 899.705,1406.88 899.714,1406.88 899.724,1406.88 899.733,1406.88 899.742,1406.88 899.751,1406.88 899.76,1406.88 899.77,1406.88 899.779,1406.88 899.788,1406.88 899.797,1406.88 899.806,1406.88 899.816,1406.88 899.825,1406.88 899.834,1406.88 899.843,1406.88 899.852,1406.88 899.861,1406.88 899.871,1406.88 899.88,1406.88 899.889,1406.88 899.898,1406.88 899.907,1406.88 899.917,1406.88 899.926,1406.88 899.935,1406.88 899.944,1406.88 899.953,1406.88 899.963,1406.88 899.972,1406.88 899.981,1406.88 899.99,1406.88 899.999,1406.88 900.009,1406.88 900.018,1406.88 900.027,1406.88 900.036,1406.88 900.045,1406.88 900.054,1406.88 900.064,1406.88 900.073,1406.88 900.082,1406.88 900.091,1406.88 900.1,1406.88 900.11,1406.88 900.119,1406.88 900.128,1406.88 900.137,1406.88 900.146,1406.88 900.156,1406.88 900.165,1406.88 900.174,1406.88 900.183,1406.88 900.192,1406.88 900.201,1406.88 900.211,1406.88 900.22,1406.88 900.229,1406.88 900.238,1406.88 900.247,1406.88 900.257,1406.88 900.266,1406.88 900.275,1406.88 900.284,1406.88 900.293,1406.88 900.303,1406.88 900.312,1406.88 900.321,1406.88 900.33,1406.88 900.339,1406.88 900.349,1406.88 900.358,1406.88 900.367,1406.88 900.376,1406.88 900.385,1406.88 900.394,1406.88 900.404,1406.88 900.413,1406.88 900.422,1406.88 900.431,1406.88 900.44,1406.88 900.45,1406.88 900.459,1406.88 900.468,1406.88 900.477,1406.88 900.486,1406.88 900.496,1406.88 900.505,1406.88 900.514,1406.88 900.523,1406.88 900.532,1406.88 900.541,1406.88 900.551,1406.88 900.56,1406.88 900.569,1406.88 900.578,1406.88 900.587,1406.88 900.597,1406.88 900.606,1406.88 900.615,1406.88 900.624,1406.88 900.633,1406.88 900.643,1406.88 900.652,1406.88 900.661,1406.88 900.67,1406.88 900.679,1406.88 900.689,1406.88 900.698,1406.88 900.707,1406.88 900.716,1406.88 900.725,1406.88 900.734,1406.88 900.744,1406.88 900.753,1406.88 900.762,1406.88 900.771,1406.88 900.78,1406.88 900.79,1406.88 900.799,1406.88 900.808,1406.88 900.817,1406.88 900.826,1406.88 900.836,1406.88 900.845,1406.88 900.854,1406.88 900.863,1406.88 900.872,1406.88 900.882,1406.88 900.891,1406.88 900.9,1406.88 900.909,1406.88 900.918,1406.88 900.927,1406.88 900.937,1406.88 900.946,1406.88 900.955,1406.88 900.964,1406.88 900.973,1406.88 900.983,1406.88 900.992,1406.88 901.001,1406.88 901.01,1406.88 901.019,1406.88 901.029,1406.88 901.038,1406.88 901.047,1406.88 901.056,1406.88 901.065,1406.88 901.074,1406.88 901.084,1406.88 901.093,1406.88 901.102,1406.88 901.111,1406.88 901.12,1406.88 901.13,1406.88 901.139,1406.88 901.148,1406.88 901.157,1406.88 901.166,1406.88 901.176,1406.88 901.185,1406.88 901.194,1406.88 901.203,1406.88 901.212,1406.88 901.222,1406.88 901.231,1406.88 901.24,1406.88 901.249,1406.88 901.258,1406.88 901.267,1406.88 901.277,1406.88 901.286,1406.88 901.295,1406.88 901.304,1406.88 901.313,1406.88 901.323,1406.88 901.332,1406.88 901.341,1406.88 901.35,1406.88 901.359,1406.88 901.369,1406.88 901.378,1406.88 901.387,1406.88 901.396,1406.88 901.405,1406.88 901.414,1406.88 901.424,1406.88 901.433,1406.88 901.442,1406.88 901.451,1406.88 901.46,1406.88 901.47,1406.88 901.479,1406.88 901.488,1406.88 901.497,1406.88 901.506,1406.88 901.516,1406.88 901.525,1406.88 901.534,1406.88 901.543,1406.88 901.552,1406.88 901.562,1406.88 901.571,1406.88 901.58,1406.88 901.589,1406.88 901.598,1406.88 901.607,1406.88 901.617,1406.88 901.626,1406.88 901.635,1406.88 901.644,1406.88 901.653,1406.88 901.663,1406.88 901.672,1406.88 901.681,1406.88 901.69,1406.88 901.699,1406.88 901.709,1406.88 901.718,1406.88 901.727,1406.88 901.736,1406.88 901.745,1406.88 901.754,1406.88 901.764,1406.88 901.773,1406.88 901.782,1406.88 901.791,1406.88 901.8,1406.88 901.81,1406.88 901.819,1406.88 901.828,1406.88 901.837,1406.88 901.846,1406.88 901.856,1406.88 901.865,1406.88 901.874,1406.88 901.883,1406.88 901.892,1406.88 901.902,1406.88 901.911,1406.88 901.92,1406.88 901.929,1406.88 901.938,1406.88 901.947,1406.88 901.957,1406.88 901.966,1406.88 901.975,1406.88 901.984,1406.88 901.993,1406.88 902.003,1406.88 902.012,1406.88 902.021,1406.88 902.03,1406.88 902.039,1406.88 902.049,1406.88 902.058,1406.88 902.067,1406.88 902.076,1406.88 902.085,1406.88 902.094,1406.88 902.104,1406.88 902.113,1406.88 902.122,1406.88 902.131,1406.88 902.14,1406.88 902.15,1406.88 902.159,1406.88 902.168,1406.88 902.177,1406.88 902.186,1406.88 902.196,1406.88 902.205,1406.88 902.214,1406.88 902.223,1406.88 902.232,1406.88 902.242,1406.88 902.251,1406.88 902.26,1406.88 902.269,1406.88 902.278,1406.88 902.287,1406.88 902.297,1406.88 902.306,1406.88 902.315,1406.88 902.324,1406.88 902.333,1406.88 902.343,1406.88 902.352,1406.88 902.361,1406.88 902.37,1406.88 902.379,1406.88 902.389,1406.88 902.398,1406.88 902.407,1406.88 902.416,1406.88 902.425,1406.88 902.434,1406.88 902.444,1406.88 902.453,1406.88 902.462,1406.88 902.471,1406.88 902.48,1406.88 902.49,1406.88 902.499,1406.88 902.508,1406.88 902.517,1406.88 902.526,1406.88 902.536,1406.88 902.545,1406.88 902.554,1406.88 902.563,1406.88 902.572,1406.88 902.582,1406.88 902.591,1406.88 902.6,1406.88 902.609,1406.88 902.618,1406.88 902.627,1406.88 902.637,1406.88 902.646,1406.88 902.655,1406.88 902.664,1406.88 902.673,1406.88 902.683,1406.88 902.692,1406.88 902.701,1406.88 902.71,1406.88 902.719,1406.88 902.729,1406.88 902.738,1406.88 902.747,1406.88 902.756,1406.88 902.765,1406.88 902.774,1406.88 902.784,1406.88 902.793,1406.88 902.802,1406.88 902.811,1406.88 902.82,1406.88 902.83,1406.88 902.839,1406.88 902.848,1406.88 902.857,1406.88 902.866,1406.88 902.876,1406.88 902.885,1406.88 902.894,1406.88 902.903,1406.88 902.912,1406.88 902.922,1406.88 902.931,1406.88 902.94,1406.88 902.949,1406.88 902.958,1406.88 902.967,1406.88 902.977,1406.88 902.986,1406.88 902.995,1406.88 903.004,1406.88 903.013,1406.88 903.023,1406.88 903.032,1406.88 903.041,1406.88 903.05,1406.88 903.059,1406.88 903.069,1406.88 903.078,1406.88 903.087,1406.88 903.096,1406.88 903.105,1406.88 903.114,1406.88 903.124,1406.88 903.133,1406.88 903.142,1406.88 903.151,1406.88 903.16,1406.88 903.17,1406.88 903.179,1406.88 903.188,1406.88 903.197,1406.88 903.206,1406.88 903.216,1406.88 903.225,1406.88 903.234,1406.88 903.243,1406.88 903.252,1406.88 903.262,1406.88 903.271,1406.88 903.28,1406.88 903.289,1406.88 903.298,1406.88 903.307,1406.88 903.317,1406.88 903.326,1406.88 903.335,1406.88 903.344,1406.88 903.353,1406.88 903.363,1406.88 903.372,1406.88 903.381,1406.88 903.39,1406.88 903.399,1406.88 903.409,1406.88 903.418,1406.88 903.427,1406.88 903.436,1406.88 903.445,1406.88 903.455,1406.88 903.464,1406.88 903.473,1406.88 903.482,1406.88 903.491,1406.88 903.5,1406.88 903.51,1406.88 903.519,1406.88 903.528,1406.88 903.537,1406.88 903.546,1406.88 903.556,1406.88 903.565,1406.88 903.574,1406.88 903.583,1406.88 903.592,1406.88 903.602,1406.88 903.611,1406.88 903.62,1406.88 903.629,1406.88 903.638,1406.88 903.647,1406.88 903.657,1406.88 903.666,1406.88 903.675,1406.88 903.684,1406.88 903.693,1406.88 903.703,1406.88 903.712,1406.88 903.721,1406.88 903.73,1406.88 903.739,1406.88 903.749,1406.88 903.758,1406.88 903.767,1406.88 903.776,1406.88 903.785,1406.88 903.795,1406.88 903.804,1406.88 903.813,1406.88 903.822,1406.88 903.831,1406.88 903.84,1406.88 903.85,1406.88 903.859,1406.88 903.868,1406.88 903.877,1406.88 903.886,1406.88 903.896,1406.88 903.905,1406.88 903.914,1406.88 903.923,1406.88 903.932,1406.88 903.942,1406.88 903.951,1406.88 903.96,1406.88 903.969,1406.88 903.978,1406.88 903.987,1406.88 903.997,1406.88 904.006,1406.88 904.015,1406.88 904.024,1406.88 904.033,1406.88 904.043,1406.88 904.052,1406.88 904.061,1406.88 904.07,1406.88 904.079,1406.88 904.089,1406.88 904.098,1406.88 904.107,1406.88 904.116,1406.88 904.125,1406.88 904.135,1406.88 904.144,1406.88 904.153,1406.88 904.162,1406.88 904.171,1406.88 904.18,1406.88 904.19,1406.88 904.199,1406.88 904.208,1406.88 904.217,1406.88 904.226,1406.88 904.236,1406.88 904.245,1406.88 904.254,1406.88 904.263,1406.88 904.272,1406.88 904.282,1406.88 904.291,1406.88 904.3,1406.88 904.309,1406.88 904.318,1406.88 904.327,1406.88 904.337,1406.88 904.346,1406.88 904.355,1406.88 904.364,1406.88 904.373,1406.88 904.383,1406.88 904.392,1406.88 904.401,1406.88 904.41,1406.88 904.419,1406.88 904.429,1406.88 904.438,1406.88 904.447,1406.88 904.456,1406.88 904.465,1406.88 904.475,1406.88 904.484,1406.88 904.493,1406.88 904.502,1406.88 904.511,1406.88 904.52,1406.88 904.53,1406.88 904.539,1406.88 904.548,1406.88 904.557,1406.88 904.566,1406.88 904.576,1406.88 904.585,1406.88 904.594,1406.88 904.603,1406.88 904.612,1406.88 904.622,1406.88 904.631,1406.88 904.64,1406.88 904.649,1406.88 904.658,1406.88 904.667,1406.88 904.677,1406.88 904.686,1406.88 904.695,1406.88 904.704,1406.88 904.713,1406.88 904.723,1406.88 904.732,1406.88 904.741,1406.88 904.75,1406.88 904.759,1406.88 904.769,1406.88 904.778,1406.88 904.787,1406.88 904.796,1406.88 904.805,1406.88 904.815,1406.88 904.824,1406.88 904.833,1406.88 904.842,1406.88 904.851,1406.88 904.86,1406.88 904.87,1406.88 904.879,1406.88 904.888,1406.88 904.897,1406.88 904.906,1406.88 904.916,1406.88 904.925,1406.88 904.934,1406.88 904.943,1406.88 904.952,1406.88 904.962,1406.88 904.971,1406.88 904.98,1406.88 904.989,1406.88 904.998,1406.88 905.007,1406.88 905.017,1406.88 905.026,1406.88 905.035,1406.88 905.044,1406.88 905.053,1406.88 905.063,1406.88 905.072,1406.88 905.081,1406.88 905.09,1406.88 905.099,1406.88 905.109,1406.88 905.118,1406.88 905.127,1406.88 905.136,1406.88 905.145,1406.88 905.155,1406.88 905.164,1406.88 905.173,1406.88 905.182,1406.88 905.191,1406.88 905.2,1406.88 905.21,1406.88 905.219,1406.88 905.228,1406.88 905.237,1406.88 905.246,1406.88 905.256,1406.88 905.265,1406.88 905.274,1406.88 905.283,1406.88 905.292,1406.88 905.302,1406.88 905.311,1406.88 905.32,1406.88 905.329,1406.88 905.338,1406.88 905.347,1406.88 905.357,1406.88 905.366,1406.88 905.375,1406.88 905.384,1406.88 905.393,1406.88 905.403,1406.88 905.412,1406.88 905.421,1406.88 905.43,1406.88 905.439,1406.88 905.449,1406.88 905.458,1406.88 905.467,1406.88 905.476,1406.88 905.485,1406.88 905.495,1406.88 905.504,1406.88 905.513,1406.88 905.522,1406.88 905.531,1406.88 905.54,1406.88 905.55,1406.88 905.559,1406.88 905.568,1406.88 905.577,1406.88 905.586,1406.88 905.596,1406.88 905.605,1406.88 905.614,1406.88 905.623,1406.88 905.632,1406.88 905.642,1406.88 905.651,1406.88 905.66,1406.88 905.669,1406.88 905.678,1406.88 905.687,1406.88 905.697,1406.88 905.706,1406.88 905.715,1406.88 905.724,1406.88 905.733,1406.88 905.743,1406.88 905.752,1406.88 905.761,1406.88 905.77,1406.88 905.779,1406.88 905.789,1406.88 905.798,1406.88 905.807,1406.88 905.816,1406.88 905.825,1406.88 905.835,1406.88 905.844,1406.88 905.853,1406.88 905.862,1406.88 905.871,1406.88 905.88,1406.88 905.89,1406.88 905.899,1406.88 905.908,1406.88 905.917,1406.88 905.926,1406.88 905.936,1406.88 905.945,1406.88 905.954,1406.88 905.963,1406.88 905.972,1406.88 905.982,1406.88 905.991,1406.88 906,1406.88 906.009,1406.88 906.018,1406.88 906.028,1406.88 906.037,1406.88 906.046,1406.88 906.055,1406.88 906.064,1406.88 906.073,1406.88 906.083,1406.88 906.092,1406.88 906.101,1406.88 906.11,1406.88 906.119,1406.88 906.129,1406.88 906.138,1406.88 906.147,1406.88 906.156,1406.88 906.165,1406.88 906.175,1406.88 906.184,1406.88 906.193,1406.88 906.202,1406.88 906.211,1406.88 906.22,1406.88 906.23,1406.88 906.239,1406.88 906.248,1406.88 906.257,1406.88 906.266,1406.88 906.276,1406.88 906.285,1406.88 906.294,1406.88 906.303,1406.88 906.312,1406.88 906.322,1406.88 906.331,1406.88 906.34,1406.88 906.349,1406.88 906.358,1406.88 906.368,1406.88 906.377,1406.88 906.386,1406.88 906.395,1406.88 906.404,1406.88 906.413,1406.88 906.423,1406.88 906.432,1406.88 906.441,1406.88 906.45,1406.88 906.459,1406.88 906.469,1406.88 906.478,1406.88 906.487,1406.88 906.496,1406.88 906.505,1406.88 906.515,1406.88 906.524,1406.88 906.533,1406.88 906.542,1406.88 906.551,1406.88 906.56,1406.88 906.57,1406.88 906.579,1406.88 906.588,1406.88 906.597,1406.88 906.606,1406.88 906.616,1406.88 906.625,1406.88 906.634,1406.88 906.643,1406.88 906.652,1406.88 906.662,1406.88 906.671,1406.88 906.68,1406.88 906.689,1406.88 906.698,1406.88 906.708,1406.88 906.717,1406.88 906.726,1406.88 906.735,1406.88 906.744,1406.88 906.753,1406.88 906.763,1406.88 906.772,1406.88 906.781,1406.88 906.79,1406.88 906.799,1406.88 906.809,1406.88 906.818,1406.88 906.827,1406.88 906.836,1406.88 906.845,1406.88 906.855,1406.88 906.864,1406.88 906.873,1406.88 906.882,1406.88 906.891,1406.88 906.9,1406.88 906.91,1406.88 906.919,1406.88 906.928,1406.88 906.937,1406.88 906.946,1406.88 906.956,1406.88 906.965,1406.88 906.974,1406.88 906.983,1406.88 906.992,1406.88 907.002,1406.88 907.011,1406.88 907.02,1406.88 907.029,1406.88 907.038,1406.88 907.048,1406.88 907.057,1406.88 907.066,1406.88 907.075,1406.88 907.084,1406.88 907.093,1406.88 907.103,1406.88 907.112,1406.88 907.121,1406.88 907.13,1406.88 907.139,1406.88 907.149,1406.88 907.158,1406.88 907.167,1406.88 907.176,1406.88 907.185,1406.88 907.195,1406.88 907.204,1406.88 907.213,1406.88 907.222,1406.88 907.231,1406.88 907.24,1406.88 907.25,1406.88 907.259,1406.88 907.268,1406.88 907.277,1406.88 907.286,1406.88 907.296,1406.88 907.305,1406.88 907.314,1406.88 907.323,1406.88 907.332,1406.88 907.342,1406.88 907.351,1406.88 907.36,1406.88 907.369,1406.88 907.378,1406.88 907.388,1406.88 907.397,1406.88 907.406,1406.88 907.415,1406.88 907.424,1406.88 907.433,1406.88 907.443,1406.88 907.452,1406.88 907.461,1406.88 907.47,1406.88 907.479,1406.88 907.489,1406.88 907.498,1406.88 907.507,1406.88 907.516,1406.88 907.525,1406.88 907.535,1406.88 907.544,1406.88 907.553,1406.88 907.562,1406.88 907.571,1406.88 907.58,1406.88 907.59,1406.88 907.599,1406.88 907.608,1406.88 907.617,1406.88 907.626,1406.88 907.636,1406.88 907.645,1406.88 907.654,1406.88 907.663,1406.88 907.672,1406.88 907.682,1406.88 907.691,1406.88 907.7,1406.88 907.709,1406.88 907.718,1406.88 907.728,1406.88 907.737,1406.88 907.746,1406.88 907.755,1406.88 907.764,1406.88 907.773,1406.88 907.783,1406.88 907.792,1406.88 907.801,1406.88 907.81,1406.88 907.819,1406.88 907.829,1406.88 907.838,1406.88 907.847,1406.88 907.856,1406.88 907.865,1406.88 907.875,1406.88 907.884,1406.88 907.893,1406.88 907.902,1406.88 907.911,1406.88 907.92,1406.88 907.93,1406.88 907.939,1406.88 907.948,1406.88 907.957,1406.88 907.966,1406.88 907.976,1406.88 907.985,1406.88 907.994,1406.88 908.003,1406.88 908.012,1406.88 908.022,1406.88 908.031,1406.88 908.04,1406.88 908.049,1406.88 908.058,1406.88 908.068,1406.88 908.077,1406.88 908.086,1406.88 908.095,1406.88 908.104,1406.88 908.113,1406.88 908.123,1406.88 908.132,1406.88 908.141,1406.88 908.15,1406.88 908.159,1406.88 908.169,1406.88 908.178,1406.88 908.187,1406.88 908.196,1406.88 908.205,1406.88 908.215,1406.88 908.224,1406.88 908.233,1406.88 908.242,1406.88 908.251,1406.88 908.261,1406.88 908.27,1406.88 908.279,1406.88 908.288,1406.88 908.297,1406.88 908.306,1406.88 908.316,1406.88 908.325,1406.88 908.334,1406.88 908.343,1406.88 908.352,1406.88 908.362,1406.88 908.371,1406.88 908.38,1406.88 908.389,1406.88 908.398,1406.88 908.408,1406.88 908.417,1406.88 908.426,1406.88 908.435,1406.88 908.444,1406.88 908.453,1406.88 908.463,1406.88 908.472,1406.88 908.481,1406.88 908.49,1406.88 908.499,1406.88 908.509,1406.88 908.518,1406.88 908.527,1406.88 908.536,1406.88 908.545,1406.88 908.555,1406.88 908.564,1406.88 908.573,1406.88 908.582,1406.88 908.591,1406.88 908.601,1406.88 908.61,1406.88 908.619,1406.88 908.628,1406.88 908.637,1406.88 908.646,1406.88 908.656,1406.88 908.665,1406.88 908.674,1406.88 908.683,1406.88 908.692,1406.88 908.702,1406.88 908.711,1406.88 908.72,1406.88 908.729,1406.88 908.738,1406.88 908.748,1406.88 908.757,1406.88 908.766,1406.88 908.775,1406.88 908.784,1406.88 908.793,1406.88 908.803,1406.88 908.812,1406.88 908.821,1406.88 908.83,1406.88 908.839,1406.88 908.849,1406.88 908.858,1406.88 908.867,1406.88 908.876,1406.88 908.885,1406.88 908.895,1406.88 908.904,1406.88 908.913,1406.88 908.922,1406.88 908.931,1406.88 908.941,1406.88 908.95,1406.88 908.959,1406.88 908.968,1406.88 908.977,1406.88 908.986,1406.88 908.996,1406.88 909.005,1406.88 909.014,1406.88 909.023,1406.88 909.032,1406.88 909.042,1406.88 909.051,1406.88 909.06,1406.88 909.069,1406.88 909.078,1406.88 909.088,1406.88 909.097,1406.88 909.106,1406.88 909.115,1406.88 909.124,1406.88 909.133,1406.88 909.143,1406.88 909.152,1406.88 909.161,1406.88 909.17,1406.88 909.179,1406.88 909.189,1406.88 909.198,1406.88 909.207,1406.88 909.216,1406.88 909.225,1406.88 909.235,1406.88 909.244,1406.88 909.253,1406.88 909.262,1406.88 909.271,1406.88 909.281,1406.88 909.29,1406.88 909.299,1406.88 909.308,1406.88 909.317,1406.88 909.326,1406.88 909.336,1406.88 909.345,1406.88 909.354,1406.88 909.363,1406.88 909.372,1406.88 909.382,1406.88 909.391,1406.88 909.4,1406.88 909.409,1406.88 909.418,1406.88 909.428,1406.88 909.437,1406.88 909.446,1406.88 909.455,1406.88 909.464,1406.88 909.473,1406.88 909.483,1406.88 909.492,1406.88 909.501,1406.88 909.51,1406.88 909.519,1406.88 909.529,1406.88 909.538,1406.88 909.547,1406.88 909.556,1406.88 909.565,1406.88 909.575,1406.88 909.584,1406.88 909.593,1406.88 909.602,1406.88 909.611,1406.88 909.621,1406.88 909.63,1406.88 909.639,1406.88 909.648,1406.88 909.657,1406.88 909.666,1406.88 909.676,1406.88 909.685,1406.88 909.694,1406.88 909.703,1406.88 909.712,1406.88 909.722,1406.88 909.731,1406.88 909.74,1406.88 909.749,1406.88 909.758,1406.88 909.768,1406.88 909.777,1406.88 909.786,1406.88 909.795,1406.88 909.804,1406.88 909.813,1406.88 909.823,1406.88 909.832,1406.88 909.841,1406.88 909.85,1406.88 909.859,1406.88 909.869,1406.88 909.878,1406.88 909.887,1406.88 909.896,1406.88 909.905,1406.88 909.915,1406.88 909.924,1406.88 909.933,1406.88 909.942,1406.88 909.951,1406.88 909.961,1406.88 909.97,1406.88 909.979,1406.88 909.988,1406.88 909.997,1406.88 910.006,1406.88 910.016,1406.88 910.025,1406.88 910.034,1406.88 910.043,1406.88 910.052,1406.88 910.062,1406.88 910.071,1406.88 910.08,1406.88 910.089,1406.88 910.098,1406.88 910.108,1406.88 910.117,1406.88 910.126,1406.88 910.135,1406.88 910.144,1406.88 910.153,1406.88 910.163,1406.88 910.172,1406.88 910.181,1406.88 910.19,1406.88 910.199,1406.88 910.209,1406.88 910.218,1406.88 910.227,1406.88 910.236,1406.88 910.245,1406.88 910.255,1406.88 910.264,1406.88 910.273,1406.88 910.282,1406.88 910.291,1406.88 910.301,1406.88 910.31,1406.88 910.319,1406.88 910.328,1406.88 910.337,1406.88 910.346,1406.88 910.356,1406.88 910.365,1406.88 910.374,1406.88 910.383,1406.88 910.392,1406.88 910.402,1406.88 910.411,1406.88 910.42,1406.88 910.429,1406.88 910.438,1406.88 910.448,1406.88 910.457,1406.88 910.466,1406.88 910.475,1406.88 910.484,1406.88 910.493,1406.88 910.503,1406.88 910.512,1406.88 910.521,1406.88 910.53,1406.88 910.539,1406.88 910.549,1406.88 910.558,1406.88 910.567,1406.88 910.576,1406.88 910.585,1406.88 910.595,1406.88 910.604,1406.88 910.613,1406.88 910.622,1406.88 910.631,1406.88 910.641,1406.88 910.65,1406.88 910.659,1406.88 910.668,1406.88 910.677,1406.88 910.686,1406.88 910.696,1406.88 910.705,1406.88 910.714,1406.88 910.723,1406.88 910.732,1406.88 910.742,1406.88 910.751,1406.88 910.76,1406.88 910.769,1406.88 910.778,1406.88 910.788,1406.88 910.797,1406.88 910.806,1406.88 910.815,1406.88 910.824,1406.88 910.834,1406.88 910.843,1406.88 910.852,1406.88 910.861,1406.88 910.87,1406.88 910.879,1406.88 910.889,1406.88 910.898,1406.88 910.907,1406.88 910.916,1406.88 910.925,1406.88 910.935,1406.88 910.944,1406.88 910.953,1406.88 910.962,1406.88 910.971,1406.88 910.981,1406.88 910.99,1406.88 910.999,1406.88 911.008,1406.88 911.017,1406.88 911.026,1406.88 911.036,1406.88 911.045,1406.88 911.054,1406.88 911.063,1406.88 911.072,1406.88 911.082,1406.88 911.091,1406.88 911.1,1406.88 911.109,1406.88 911.118,1406.88 911.128,1406.88 911.137,1406.88 911.146,1406.88 911.155,1406.88 911.164,1406.88 911.174,1406.88 911.183,1406.88 911.192,1406.88 911.201,1406.88 911.21,1406.88 911.219,1406.88 911.229,1406.88 911.238,1406.88 911.247,1406.88 911.256,1406.88 911.265,1406.88 911.275,1406.88 911.284,1406.88 911.293,1406.88 911.302,1406.88 911.311,1406.88 911.321,1406.88 911.33,1406.88 911.339,1406.88 911.348,1406.88 911.357,1406.88 911.366,1406.88 911.376,1406.88 911.385,1406.88 911.394,1406.88 911.403,1406.88 911.412,1406.88 911.422,1406.88 911.431,1406.88 911.44,1406.88 911.449,1406.88 911.458,1406.88 911.468,1406.88 911.477,1406.88 911.486,1406.88 911.495,1406.88 911.504,1406.88 911.514,1406.88 911.523,1406.88 911.532,1406.88 911.541,1406.88 911.55,1406.88 911.559,1406.88 911.569,1406.88 911.578,1406.88 911.587,1406.88 911.596,1406.88 911.605,1406.88 911.615,1406.88 911.624,1406.88 911.633,1406.88 911.642,1406.88 911.651,1406.88 911.661,1406.88 911.67,1406.88 911.679,1406.88 911.688,1406.88 911.697,1406.88 911.706,1406.88 911.716,1406.88 911.725,1406.88 911.734,1406.88 911.743,1406.88 911.752,1406.88 911.762,1406.88 911.771,1406.88 911.78,1406.88 911.789,1406.88 911.798,1406.88 911.808,1406.88 911.817,1406.88 911.826,1406.88 911.835,1406.88 911.844,1406.88 911.854,1406.88 911.863,1406.88 911.872,1406.88 911.881,1406.88 911.89,1406.88 911.899,1406.88 911.909,1406.88 911.918,1406.88 911.927,1406.88 911.936,1406.88 911.945,1406.88 911.955,1406.88 911.964,1406.88 911.973,1406.88 911.982,1406.88 911.991,1406.88 912.001,1406.88 912.01,1406.88 912.019,1406.88 912.028,1406.88 912.037,1406.88 912.046,1406.88 912.056,1406.88 912.065,1406.88 912.074,1406.88 912.083,1406.88 912.092,1406.88 912.102,1406.88 912.111,1406.88 912.12,1406.88 912.129,1406.88 912.138,1406.88 912.148,1406.88 912.157,1406.88 912.166,1406.88 912.175,1406.88 912.184,1406.88 912.194,1406.88 912.203,1406.88 912.212,1406.88 912.221,1406.88 912.23,1406.88 912.239,1406.88 912.249,1406.88 912.258,1406.88 912.267,1406.88 912.276,1406.88 912.285,1406.88 912.295,1406.88 912.304,1406.88 912.313,1406.88 912.322,1406.88 912.331,1406.88 912.341,1406.88 912.35,1406.88 912.359,1406.88 912.368,1406.88 912.377,1406.88 912.386,1406.88 912.396,1406.88 912.405,1406.88 912.414,1406.88 912.423,1406.88 912.432,1406.88 912.442,1406.88 912.451,1406.88 912.46,1406.88 912.469,1406.88 912.478,1406.88 912.488,1406.88 912.497,1406.88 912.506,1406.88 912.515,1406.88 912.524,1406.88 912.534,1406.88 912.543,1406.88 912.552,1406.88 912.561,1406.88 912.57,1406.88 912.579,1406.88 912.589,1406.88 912.598,1406.88 912.607,1406.88 912.616,1406.88 912.625,1406.88 912.635,1406.88 912.644,1406.88 912.653,1406.88 912.662,1406.88 912.671,1406.88 912.681,1406.88 912.69,1406.88 912.699,1406.88 912.708,1406.88 912.717,1406.88 912.726,1406.88 912.736,1406.88 912.745,1406.88 912.754,1406.88 912.763,1406.88 912.772,1406.88 912.782,1406.88 912.791,1406.88 912.8,1406.88 912.809,1406.88 912.818,1406.88 912.828,1406.88 912.837,1406.88 912.846,1406.88 912.855,1406.88 912.864,1406.88 912.874,1406.88 912.883,1406.88 912.892,1406.88 912.901,1406.88 912.91,1406.88 912.919,1406.88 912.929,1406.88 912.938,1406.88 912.947,1406.88 912.956,1406.88 912.965,1406.88 912.975,1406.88 912.984,1406.88 912.993,1406.88 913.002,1406.88 913.011,1406.88 913.021,1406.88 913.03,1406.88 913.039,1406.88 913.048,1406.88 913.057,1406.88 913.066,1406.88 913.076,1406.88 913.085,1406.88 913.094,1406.88 913.103,1406.88 913.112,1406.88 913.122,1406.88 913.131,1406.88 913.14,1406.88 913.149,1406.88 913.158,1406.88 913.168,1406.88 913.177,1406.88 913.186,1406.88 913.195,1406.88 913.204,1406.88 913.214,1406.88 913.223,1406.88 913.232,1406.88 913.241,1406.88 913.25,1406.88 913.259,1406.88 913.269,1406.88 913.278,1406.88 913.287,1406.88 913.296,1406.88 913.305,1406.88 913.315,1406.88 913.324,1406.88 913.333,1406.88 913.342,1406.88 913.351,1406.88 913.361,1406.88 913.37,1406.88 913.379,1406.88 913.388,1406.88 913.397,1406.88 913.407,1406.88 913.416,1406.88 913.425,1406.88 913.434,1406.88 913.443,1406.88 913.452,1406.88 913.462,1406.88 913.471,1406.88 913.48,1406.88 913.489,1406.88 913.498,1406.88 913.508,1406.88 913.517,1406.88 913.526,1406.88 913.535,1406.88 913.544,1406.88 913.554,1406.88 913.563,1406.88 913.572,1406.88 913.581,1406.88 913.59,1406.88 913.599,1406.88 913.609,1406.88 913.618,1406.88 913.627,1406.88 913.636,1406.88 913.645,1406.88 913.655,1406.88 913.664,1406.88 913.673,1406.88 913.682,1406.88 913.691,1406.88 913.701,1406.88 913.71,1406.88 913.719,1406.88 913.728,1406.88 913.737,1406.88 913.747,1406.88 913.756,1406.88 913.765,1406.88 913.774,1406.88 913.783,1406.88 913.792,1406.88 913.802,1406.88 913.811,1406.88 913.82,1406.88 913.829,1406.88 913.838,1406.88 913.848,1406.88 913.857,1406.88 913.866,1406.88 913.875,1406.88 913.884,1406.88 913.894,1406.88 913.903,1406.88 913.912,1406.88 913.921,1406.88 913.93,1406.88 913.939,1406.88 913.949,1406.88 913.958,1406.88 913.967,1406.88 913.976,1406.88 913.985,1406.88 913.995,1406.88 914.004,1406.88 914.013,1406.88 914.022,1406.88 914.031,1406.88 914.041,1406.88 914.05,1406.88 914.059,1406.88 914.068,1406.88 914.077,1406.88 914.087,1406.88 914.096,1406.88 914.105,1406.88 914.114,1406.88 914.123,1406.88 914.132,1406.88 914.142,1406.88 914.151,1406.88 914.16,1406.88 914.169,1406.88 914.178,1406.88 914.188,1406.88 914.197,1406.88 914.206,1406.88 914.215,1406.88 914.224,1406.88 914.234,1406.88 914.243,1406.88 914.252,1406.88 914.261,1406.88 914.27,1406.88 914.279,1406.88 914.289,1406.88 914.298,1406.88 914.307,1406.88 914.316,1406.88 914.325,1406.88 914.335,1406.88 914.344,1406.88 914.353,1406.88 914.362,1406.88 914.371,1406.88 914.381,1406.88 914.39,1406.88 914.399,1406.88 914.408,1406.88 914.417,1406.88 914.427,1406.88 914.436,1406.88 914.445,1406.88 914.454,1406.88 914.463,1406.88 914.472,1406.88 914.482,1406.88 914.491,1406.88 914.5,1406.88 914.509,1406.88 914.518,1406.88 914.528,1406.88 914.537,1406.88 914.546,1406.88 914.555,1406.88 914.564,1406.88 914.574,1406.88 914.583,1406.88 914.592,1406.88 914.601,1406.88 914.61,1406.88 914.619,1406.88 914.629,1406.88 914.638,1406.88 914.647,1406.88 914.656,1406.88 914.665,1406.88 914.675,1406.88 914.684,1406.88 914.693,1406.88 914.702,1406.88 914.711,1406.88 914.721,1406.88 914.73,1406.88 914.739,1406.88 914.748,1406.88 914.757,1406.88 914.767,1406.88 914.776,1406.88 914.785,1406.88 914.794,1406.88 914.803,1406.88 914.812,1406.88 914.822,1406.88 914.831,1406.88 914.84,1406.88 914.849,1406.88 914.858,1406.88 914.868,1406.88 914.877,1406.88 914.886,1406.88 914.895,1406.88 914.904,1406.88 914.914,1406.88 914.923,1406.88 914.932,1406.88 914.941,1406.88 914.95,1406.88 914.959,1406.88 914.969,1406.88 914.978,1406.88 914.987,1406.88 914.996,1406.88 915.005,1406.88 915.015,1406.88 915.024,1406.88 915.033,1406.88 915.042,1406.88 915.051,1406.88 915.061,1406.88 915.07,1406.88 915.079,1406.88 915.088,1406.88 915.097,1406.88 915.107,1406.88 915.116,1406.88 915.125,1406.88 915.134,1406.88 915.143,1406.88 915.152,1406.88 915.162,1406.88 915.171,1406.88 915.18,1406.88 915.189,1406.88 915.198,1406.88 915.208,1406.88 915.217,1406.88 915.226,1406.88 915.235,1406.88 915.244,1406.88 915.254,1406.88 915.263,1406.88 915.272,1406.88 915.281,1406.88 915.29,1406.88 915.299,1406.88 915.309,1406.88 915.318,1406.88 915.327,1406.88 915.336,1406.88 915.345,1406.88 915.355,1406.88 915.364,1406.88 915.373,1406.88 915.382,1406.88 915.391,1406.88 915.401,1406.88 915.41,1406.88 915.419,1406.88 915.428,1406.88 915.437,1406.88 915.447,1406.88 915.456,1406.88 915.465,1406.88 915.474,1406.88 915.483,1406.88 915.492,1406.88 915.502,1406.88 915.511,1406.88 915.52,1406.88 915.529,1406.88 915.538,1406.88 915.548,1406.88 915.557,1406.88 915.566,1406.88 915.575,1406.88 915.584,1406.88 915.594,1406.88 915.603,1406.88 915.612,1406.88 915.621,1406.88 915.63,1406.88 915.64,1406.88 915.649,1406.88 915.658,1406.88 915.667,1406.88 915.676,1406.88 915.685,1406.88 915.695,1406.88 915.704,1406.88 915.713,1406.88 915.722,1406.88 915.731,1406.88 915.741,1406.88 915.75,1406.88 915.759,1406.88 915.768,1406.88 915.777,1406.88 915.787,1406.88 915.796,1406.88 915.805,1406.88 915.814,1406.88 915.823,1406.88 915.832,1406.88 915.842,1406.88 915.851,1406.88 915.86,1406.88 915.869,1406.88 915.878,1406.88 915.888,1406.88 915.897,1406.88 915.906,1406.88 915.915,1406.88 915.924,1406.88 915.934,1406.88 915.943,1406.88 915.952,1406.88 915.961,1406.88 915.97,1406.88 915.98,1406.88 915.989,1406.88 915.998,1406.88 916.007,1406.88 916.016,1406.88 916.025,1406.88 916.035,1406.88 916.044,1406.88 916.053,1406.88 916.062,1406.88 916.071,1406.88 916.081,1406.88 916.09,1406.88 916.099,1406.88 916.108,1406.88 916.117,1406.88 916.127,1406.88 916.136,1406.88 916.145,1406.88 916.154,1406.88 916.163,1406.88 916.172,1406.88 916.182,1406.88 916.191,1406.88 916.2,1406.88 916.209,1406.88 916.218,1406.88 916.228,1406.88 916.237,1406.88 916.246,1406.88 916.255,1406.88 916.264,1406.88 916.274,1406.88 916.283,1406.88 916.292,1406.88 916.301,1406.88 916.31,1406.88 916.32,1406.88 916.329,1406.88 916.338,1406.88 916.347,1406.88 916.356,1406.88 916.365,1406.88 916.375,1406.88 916.384,1406.88 916.393,1406.88 916.402,1406.88 916.411,1406.88 916.421,1406.88 916.43,1406.88 916.439,1406.88 916.448,1406.88 916.457,1406.88 916.467,1406.88 916.476,1406.88 916.485,1406.88 916.494,1406.88 916.503,1406.88 916.512,1406.88 916.522,1406.88 916.531,1406.88 916.54,1406.88 916.549,1406.88 916.558,1406.88 916.568,1406.88 916.577,1406.88 916.586,1406.88 916.595,1406.88 916.604,1406.88 916.614,1406.88 916.623,1406.88 916.632,1406.88 916.641,1406.88 916.65,1406.88 916.66,1406.88 916.669,1406.88 916.678,1406.88 916.687,1406.88 916.696,1406.88 916.705,1406.88 916.715,1406.88 916.724,1406.88 916.733,1406.88 916.742,1406.88 916.751,1406.88 916.761,1406.88 916.77,1406.88 916.779,1406.88 916.788,1406.88 916.797,1406.88 916.807,1406.88 916.816,1406.88 916.825,1406.88 916.834,1406.88 916.843,1406.88 916.852,1406.88 916.862,1406.88 916.871,1406.88 916.88,1406.88 916.889,1406.88 916.898,1406.88 916.908,1406.88 916.917,1406.88 916.926,1406.88 916.935,1406.88 916.944,1406.88 916.954,1406.88 916.963,1406.88 916.972,1406.88 916.981,1406.88 916.99,1406.88 917,1406.88 917.009,1406.88 917.018,1406.88 917.027,1406.88 917.036,1406.88 917.045,1406.88 917.055,1406.88 917.064,1406.88 917.073,1406.88 917.082,1406.88 917.091,1406.88 917.101,1406.88 917.11,1406.88 917.119,1406.88 917.128,1406.88 917.137,1406.88 917.147,1406.88 917.156,1406.88 917.165,1406.88 917.174,1406.88 917.183,1406.88 917.192,1406.88 917.202,1406.88 917.211,1406.88 917.22,1406.88 917.229,1406.88 917.238,1406.88 917.248,1406.88 917.257,1406.88 917.266,1406.88 917.275,1406.88 917.284,1406.88 917.294,1406.88 917.303,1406.88 917.312,1406.88 917.321,1406.88 917.33,1406.88 917.34,1406.88 917.349,1406.88 917.358,1406.88 917.367,1406.88 917.376,1406.88 917.385,1406.88 917.395,1406.88 917.404,1406.88 917.413,1406.88 917.422,1406.88 917.431,1406.88 917.441,1406.88 917.45,1406.88 917.459,1406.88 917.468,1406.88 917.477,1406.88 917.487,1406.88 917.496,1406.88 917.505,1406.88 917.514,1406.88 917.523,1406.88 917.532,1406.88 917.542,1406.88 917.551,1406.88 917.56,1406.88 917.569,1406.88 917.578,1406.88 917.588,1406.88 917.597,1406.88 917.606,1406.88 917.615,1406.88 917.624,1406.88 917.634,1406.88 917.643,1406.88 917.652,1406.88 917.661,1406.88 917.67,1406.88 917.68,1406.88 917.689,1406.88 917.698,1406.88 917.707,1406.88 917.716,1406.88 917.725,1406.88 917.735,1406.88 917.744,1406.88 917.753,1406.88 917.762,1406.88 917.771,1406.88 917.781,1406.88 917.79,1406.88 917.799,1406.88 917.808,1406.88 917.817,1406.88 917.827,1406.88 917.836,1406.88 917.845,1406.88 917.854,1406.88 917.863,1406.88 917.872,1406.88 917.882,1406.88 917.891,1406.88 917.9,1406.88 917.909,1406.88 917.918,1406.88 917.928,1406.88 917.937,1406.88 917.946,1406.88 917.955,1406.88 917.964,1406.88 917.974,1406.88 917.983,1406.88 917.992,1406.88 918.001,1406.88 918.01,1406.88 918.02,1406.88 918.029,1406.88 918.038,1406.88 918.047,1406.88 918.056,1406.88 918.065,1406.88 918.075,1406.88 918.084,1406.88 918.093,1406.88 918.102,1406.88 918.111,1406.88 918.121,1406.88 918.13,1406.88 918.139,1406.88 918.148,1406.88 918.157,1406.88 918.167,1406.88 918.176,1406.88 918.185,1406.88 918.194,1406.88 918.203,1406.88 918.213,1406.88 918.222,1406.88 918.231,1406.88 918.24,1406.88 918.249,1406.88 918.258,1406.88 918.268,1406.88 918.277,1406.88 918.286,1406.88 918.295,1406.88 918.304,1406.88 918.314,1406.88 918.323,1406.88 918.332,1406.88 918.341,1406.88 918.35,1406.88 918.36,1406.88 918.369,1406.88 918.378,1406.88 918.387,1406.88 918.396,1406.88 918.405,1406.88 918.415,1406.88 918.424,1406.88 918.433,1406.88 918.442,1406.88 918.451,1406.88 918.461,1406.88 918.47,1406.88 918.479,1406.88 918.488,1406.88 918.497,1406.88 918.507,1406.88 918.516,1406.88 918.525,1406.88 918.534,1406.88 918.543,1406.88 918.553,1406.88 918.562,1406.88 918.571,1406.88 918.58,1406.88 918.589,1406.88 918.598,1406.88 918.608,1406.88 918.617,1406.88 918.626,1406.88 918.635,1406.88 918.644,1406.88 918.654,1406.88 918.663,1406.88 918.672,1406.88 918.681,1406.88 918.69,1406.88 918.7,1406.88 918.709,1406.88 918.718,1406.88 918.727,1406.88 918.736,1406.88 918.745,1406.88 918.755,1406.88 918.764,1406.88 918.773,1406.88 918.782,1406.88 918.791,1406.88 918.801,1406.88 918.81,1406.88 918.819,1406.88 918.828,1406.88 918.837,1406.88 918.847,1406.88 918.856,1406.88 918.865,1406.88 918.874,1406.88 918.883,1406.88 918.893,1406.88 918.902,1406.88 918.911,1406.88 918.92,1406.88 918.929,1406.88 918.938,1406.88 918.948,1406.88 918.957,1406.88 918.966,1406.88 918.975,1406.88 918.984,1406.88 918.994,1406.88 919.003,1406.88 919.012,1406.88 919.021,1406.88 919.03,1406.88 919.04,1406.88 919.049,1406.88 919.058,1406.88 919.067,1406.88 919.076,1406.88 919.085,1406.88 919.095,1406.88 919.104,1406.88 919.113,1406.88 919.122,1406.88 919.131,1406.88 919.141,1406.88 919.15,1406.88 919.159,1406.88 919.168,1406.88 919.177,1406.88 919.187,1406.88 919.196,1406.88 919.205,1406.88 919.214,1406.88 919.223,1406.88 919.233,1406.88 919.242,1406.88 919.251,1406.88 919.26,1406.88 919.269,1406.88 919.278,1406.88 919.288,1406.88 919.297,1406.88 919.306,1406.88 919.315,1406.88 919.324,1406.88 919.334,1406.88 919.343,1406.88 919.352,1406.88 919.361,1406.88 919.37,1406.88 919.38,1406.88 919.389,1406.88 919.398,1406.88 919.407,1406.88 919.416,1406.88 919.425,1406.88 919.435,1406.88 919.444,1406.88 919.453,1406.88 919.462,1406.88 919.471,1406.88 919.481,1406.88 919.49,1406.88 919.499,1406.88 919.508,1406.88 919.517,1406.88 919.527,1406.88 919.536,1406.88 919.545,1406.88 919.554,1406.88 919.563,1406.88 919.573,1406.88 919.582,1406.88 919.591,1406.88 919.6,1406.88 919.609,1406.88 919.618,1406.88 919.628,1406.88 919.637,1406.88 919.646,1406.88 919.655,1406.88 919.664,1406.88 919.674,1406.88 919.683,1406.88 919.692,1406.88 919.701,1406.88 919.71,1406.88 919.72,1406.88 919.729,1406.88 919.738,1406.88 919.747,1406.88 919.756,1406.88 919.765,1406.88 919.775,1406.88 919.784,1406.88 919.793,1406.88 919.802,1406.88 919.811,1406.88 919.821,1406.88 919.83,1406.88 919.839,1406.88 919.848,1406.88 919.857,1406.88 919.867,1406.88 919.876,1406.88 919.885,1406.88 919.894,1406.88 919.903,1406.88 919.913,1406.88 919.922,1406.88 919.931,1406.88 919.94,1406.88 919.949,1406.88 919.958,1406.88 919.968,1406.88 919.977,1406.88 919.986,1406.88 919.995,1406.88 920.004,1406.88 920.014,1406.88 920.023,1406.88 920.032,1406.88 920.041,1406.88 920.05,1406.88 920.06,1406.88 920.069,1406.88 920.078,1406.88 920.087,1406.88 920.096,1406.88 920.105,1406.88 920.115,1406.88 920.124,1406.88 920.133,1406.88 920.142,1406.88 920.151,1406.88 920.161,1406.88 920.17,1406.88 920.179,1406.88 920.188,1406.88 920.197,1406.88 920.207,1406.88 920.216,1406.88 920.225,1406.88 920.234,1406.88 920.243,1406.88 920.253,1406.88 920.262,1406.88 920.271,1406.88 920.28,1406.88 920.289,1406.88 920.298,1406.88 920.308,1406.88 920.317,1406.88 920.326,1406.88 920.335,1406.88 920.344,1406.88 920.354,1406.88 920.363,1406.88 920.372,1406.88 920.381,1406.88 920.39,1406.88 920.4,1406.88 920.409,1406.88 920.418,1406.88 920.427,1406.88 920.436,1406.88 920.445,1406.88 920.455,1406.88 920.464,1406.88 920.473,1406.88 920.482,1406.88 920.491,1406.88 920.501,1406.88 920.51,1406.88 920.519,1406.88 920.528,1406.88 920.537,1406.88 920.547,1406.88 920.556,1406.88 920.565,1406.88 920.574,1406.88 920.583,1406.88 920.593,1406.88 920.602,1406.88 920.611,1406.88 920.62,1406.88 920.629,1406.88 920.638,1406.88 920.648,1406.88 920.657,1406.88 920.666,1406.88 920.675,1406.88 920.684,1406.88 920.694,1406.88 920.703,1406.88 920.712,1406.88 920.721,1406.88 920.73,1406.88 920.74,1406.88 920.749,1406.88 920.758,1406.88 920.767,1406.88 920.776,1406.88 920.786,1406.88 920.795,1406.88 920.804,1406.88 920.813,1406.88 920.822,1406.88 920.831,1406.88 920.841,1406.88 920.85,1406.88 920.859,1406.88 920.868,1406.88 920.877,1406.88 920.887,1406.88 920.896,1406.88 920.905,1406.88 920.914,1406.88 920.923,1406.88 920.933,1406.88 920.942,1406.88 920.951,1406.88 920.96,1406.88 920.969,1406.88 920.978,1406.88 920.988,1406.88 920.997,1406.88 921.006,1406.88 921.015,1406.88 921.024,1406.88 921.034,1406.88 921.043,1406.88 921.052,1406.88 921.061,1406.88 921.07,1406.88 921.08,1406.88 921.089,1406.88 921.098,1406.88 921.107,1406.88 921.116,1406.88 921.126,1406.88 921.135,1406.88 921.144,1406.88 921.153,1406.88 921.162,1406.88 921.171,1406.88 921.181,1406.88 921.19,1406.88 921.199,1406.88 921.208,1406.88 921.217,1406.88 921.227,1406.88 921.236,1406.88 921.245,1406.88 921.254,1406.88 921.263,1406.88 921.273,1406.88 921.282,1406.88 921.291,1406.88 921.3,1406.88 921.309,1406.88 921.318,1406.88 921.328,1406.88 921.337,1406.88 921.346,1406.88 921.355,1406.88 921.364,1406.88 921.374,1406.88 921.383,1406.88 921.392,1406.88 921.401,1406.88 921.41,1406.88 921.42,1406.88 921.429,1406.88 921.438,1406.88 921.447,1406.88 921.456,1406.88 921.466,1406.88 921.475,1406.88 921.484,1406.88 921.493,1406.88 921.502,1406.88 921.511,1406.88 921.521,1406.88 921.53,1406.88 921.539,1406.88 921.548,1406.88 921.557,1406.88 921.567,1406.88 921.576,1406.88 921.585,1406.88 921.594,1406.88 921.603,1406.88 921.613,1406.88 921.622,1406.88 921.631,1406.88 921.64,1406.88 921.649,1406.88 921.658,1406.88 921.668,1406.88 921.677,1406.88 921.686,1406.88 921.695,1406.88 921.704,1406.88 921.714,1406.88 921.723,1406.88 921.732,1406.88 921.741,1406.88 921.75,1406.88 921.76,1406.88 921.769,1406.88 921.778,1406.88 921.787,1406.88 921.796,1406.88 921.806,1406.88 921.815,1406.88 921.824,1406.88 921.833,1406.88 921.842,1406.88 921.851,1406.88 921.861,1406.88 921.87,1406.88 921.879,1406.88 921.888,1406.88 921.897,1406.88 921.907,1406.88 921.916,1406.88 921.925,1406.88 921.934,1406.88 921.943,1406.88 921.953,1406.88 921.962,1406.88 921.971,1406.88 921.98,1406.88 921.989,1406.88 921.998,1406.88 922.008,1406.88 922.017,1406.88 922.026,1406.88 922.035,1406.88 922.044,1406.88 922.054,1406.88 922.063,1406.88 922.072,1406.88 922.081,1406.88 922.09,1406.88 922.1,1406.88 922.109,1406.88 922.118,1406.88 922.127,1406.88 922.136,1406.88 922.146,1406.88 922.155,1406.88 922.164,1406.88 922.173,1406.88 922.182,1406.88 922.191,1406.88 922.201,1406.88 922.21,1406.88 922.219,1406.88 922.228,1406.88 922.237,1406.88 922.247,1406.88 922.256,1406.88 922.265,1406.88 922.274,1406.88 922.283,1406.88 922.293,1406.88 922.302,1406.88 922.311,1406.88 922.32,1406.88 922.329,1406.88 922.338,1406.88 922.348,1406.88 922.357,1406.88 922.366,1406.88 922.375,1406.88 922.384,1406.88 922.394,1406.88 922.403,1406.88 922.412,1406.88 922.421,1406.88 922.43,1406.88 922.44,1406.88 922.449,1406.88 922.458,1406.88 922.467,1406.88 922.476,1406.88 922.486,1406.88 922.495,1406.88 922.504,1406.88 922.513,1406.88 922.522,1406.88 922.531,1406.88 922.541,1406.88 922.55,1406.88 922.559,1406.88 922.568,1406.88 922.577,1406.88 922.587,1406.88 922.596,1406.88 922.605,1406.88 922.614,1406.88 922.623,1406.88 922.633,1406.88 922.642,1406.88 922.651,1406.88 922.66,1406.88 922.669,1406.88 922.678,1406.88 922.688,1406.88 922.697,1406.88 922.706,1406.88 922.715,1406.88 922.724,1406.88 922.734,1406.88 922.743,1406.88 922.752,1406.88 922.761,1406.88 922.77,1406.88 922.78,1406.88 922.789,1406.88 922.798,1406.88 922.807,1406.88 922.816,1406.88 922.826,1406.88 922.835,1406.88 922.844,1406.88 922.853,1406.88 922.862,1406.88 922.871,1406.88 922.881,1406.88 922.89,1406.88 922.899,1406.88 922.908,1406.88 922.917,1406.88 922.927,1406.88 922.936,1406.88 922.945,1406.88 922.954,1406.88 922.963,1406.88 922.973,1406.88 922.982,1406.88 922.991,1406.88 923,1406.88 923.009,1406.88 923.019,1406.88 923.028,1406.88 923.037,1406.88 923.046,1406.88 923.055,1406.88 923.064,1406.88 923.074,1406.88 923.083,1406.88 923.092,1406.88 923.101,1406.88 923.11,1406.88 923.12,1406.88 923.129,1406.88 923.138,1406.88 923.147,1406.88 923.156,1406.88 923.166,1406.88 923.175,1406.88 923.184,1406.88 923.193,1406.88 923.202,1406.88 923.211,1406.88 923.221,1406.88 923.23,1406.88 923.239,1406.88 923.248,1406.88 923.257,1406.88 923.267,1406.88 923.276,1406.88 923.285,1406.88 923.294,1406.88 923.303,1406.88 923.313,1406.88 923.322,1406.88 923.331,1406.88 923.34,1406.88 923.349,1406.88 923.359,1406.88 923.368,1406.88 923.377,1406.88 923.386,1406.88 923.395,1406.88 923.404,1406.88 923.414,1406.88 923.423,1406.88 923.432,1406.88 923.441,1406.88 923.45,1406.88 923.46,1406.88 923.469,1406.88 923.478,1406.88 923.487,1406.88 923.496,1406.88 923.506,1406.88 923.515,1406.88 923.524,1406.88 923.533,1406.88 923.542,1406.88 923.551,1406.88 923.561,1406.88 923.57,1406.88 923.579,1406.88 923.588,1406.88 923.597,1406.88 923.607,1406.88 923.616,1406.88 923.625,1406.88 923.634,1406.88 923.643,1406.88 923.653,1406.88 923.662,1406.88 923.671,1406.88 923.68,1406.88 923.689,1406.88 923.699,1406.88 923.708,1406.88 923.717,1406.88 923.726,1406.88 923.735,1406.88 923.744,1406.88 923.754,1406.88 923.763,1406.88 923.772,1406.88 923.781,1406.88 923.79,1406.88 923.8,1406.88 923.809,1406.88 923.818,1406.88 923.827,1406.88 923.836,1406.88 923.846,1406.88 923.855,1406.88 923.864,1406.88 923.873,1406.88 923.882,1406.88 923.891,1406.88 923.901,1406.88 923.91,1406.88 923.919,1406.88 923.928,1406.88 923.937,1406.88 923.947,1406.88 923.956,1406.88 923.965,1406.88 923.974,1406.88 923.983,1406.88 923.993,1406.88 924.002,1406.88 924.011,1406.88 924.02,1406.88 924.029,1406.88 924.039,1406.88 924.048,1406.88 924.057,1406.88 924.066,1406.88 924.075,1406.88 924.084,1406.88 924.094,1406.88 924.103,1406.88 924.112,1406.88 924.121,1406.88 924.13,1406.88 924.14,1406.88 924.149,1406.88 924.158,1406.88 924.167,1406.88 924.176,1406.88 924.186,1406.88 924.195,1406.88 924.204,1406.88 924.213,1406.88 924.222,1406.88 924.231,1406.88 924.241,1406.88 924.25,1406.88 924.259,1406.88 924.268,1406.88 924.277,1406.88 924.287,1406.88 924.296,1406.88 924.305,1406.88 924.314,1406.88 924.323,1406.88 924.333,1406.88 924.342,1406.88 924.351,1406.88 924.36,1406.88 924.369,1406.88 924.379,1406.88 924.388,1406.88 924.397,1406.88 924.406,1406.88 924.415,1406.88 924.424,1406.88 924.434,1406.88 924.443,1406.88 924.452,1406.88 924.461,1406.88 924.47,1406.88 924.48,1406.88 924.489,1406.88 924.498,1406.88 924.507,1406.88 924.516,1406.88 924.526,1406.88 924.535,1406.88 924.544,1406.88 924.553,1406.88 924.562,1406.88 924.571,1406.88 924.581,1406.88 924.59,1406.88 924.599,1406.88 924.608,1406.88 924.617,1406.88 924.627,1406.88 924.636,1406.88 924.645,1406.88 924.654,1406.88 924.663,1406.88 924.673,1406.88 924.682,1406.88 924.691,1406.88 924.7,1406.88 924.709,1406.88 924.719,1406.88 924.728,1406.88 924.737,1406.88 924.746,1406.88 924.755,1406.88 924.764,1406.88 924.774,1406.88 924.783,1406.88 924.792,1406.88 924.801,1406.88 924.81,1406.88 924.82,1406.88 924.829,1406.88 924.838,1406.88 924.847,1406.88 924.856,1406.88 924.866,1406.88 924.875,1406.88 924.884,1406.88 924.893,1406.88 924.902,1406.88 924.911,1406.88 924.921,1406.88 924.93,1406.88 924.939,1406.88 924.948,1406.88 924.957,1406.88 924.967,1406.88 924.976,1406.88 924.985,1406.88 924.994,1406.88 925.003,1406.88 925.013,1406.88 925.022,1406.88 925.031,1406.88 925.04,1406.88 925.049,1406.88 925.059,1406.88 925.068,1406.88 925.077,1406.88 925.086,1406.88 925.095,1406.88 925.104,1406.88 925.114,1406.88 925.123,1406.88 925.132,1406.88 925.141,1406.88 925.15,1406.88 925.16,1406.88 925.169,1406.88 925.178,1406.88 925.187,1406.88 925.196,1406.88 925.206,1406.88 925.215,1406.88 925.224,1406.88 925.233,1406.88 925.242,1406.88 925.251,1406.88 925.261,1406.88 925.27,1406.88 925.279,1406.88 925.288,1406.88 925.297,1406.88 925.307,1406.88 925.316,1406.88 925.325,1406.88 925.334,1406.88 925.343,1406.88 925.353,1406.88 925.362,1406.88 925.371,1406.88 925.38,1406.88 925.389,1406.88 925.399,1406.88 925.408,1406.88 925.417,1406.88 925.426,1406.88 925.435,1406.88 925.444,1406.88 925.454,1406.88 925.463,1406.88 925.472,1406.88 925.481,1406.88 925.49,1406.88 925.5,1406.88 925.509,1406.88 925.518,1406.88 925.527,1406.88 925.536,1406.88 925.546,1406.88 925.555,1406.88 925.564,1406.88 925.573,1406.88 925.582,1406.88 925.592,1406.88 925.601,1406.88 925.61,1406.88 925.619,1406.88 925.628,1406.88 925.637,1406.88 925.647,1406.88 925.656,1406.88 925.665,1406.88 925.674,1406.88 925.683,1406.88 925.693,1406.88 925.702,1406.88 925.711,1406.88 925.72,1406.88 925.729,1406.88 925.739,1406.88 925.748,1406.88 925.757,1406.88 925.766,1406.88 925.775,1406.88 925.784,1406.88 925.794,1406.88 925.803,1406.88 925.812,1406.88 925.821,1406.88 925.83,1406.88 925.84,1406.88 925.849,1406.88 925.858,1406.88 925.867,1406.88 925.876,1406.88 925.886,1406.88 925.895,1406.88 925.904,1406.88 925.913,1406.88 925.922,1406.88 925.932,1406.88 925.941,1406.88 925.95,1406.88 925.959,1406.88 925.968,1406.88 925.977,1406.88 925.987,1406.88 925.996,1406.88 926.005,1406.88 926.014,1406.88 926.023,1406.88 926.033,1406.88 926.042,1406.88 926.051,1406.88 926.06,1406.88 926.069,1406.88 926.079,1406.88 926.088,1406.88 926.097,1406.88 926.106,1406.88 926.115,1406.88 926.124,1406.88 926.134,1406.88 926.143,1406.88 926.152,1406.88 926.161,1406.88 926.17,1406.88 926.18,1406.88 926.189,1406.88 926.198,1406.88 926.207,1406.88 926.216,1406.88 926.226,1406.88 926.235,1406.88 926.244,1406.88 926.253,1406.88 926.262,1406.88 926.272,1406.88 926.281,1406.88 926.29,1406.88 926.299,1406.88 926.308,1406.88 926.317,1406.88 926.327,1406.88 926.336,1406.88 926.345,1406.88 926.354,1406.88 926.363,1406.88 926.373,1406.88 926.382,1406.88 926.391,1406.88 926.4,1406.88 926.409,1406.88 926.419,1406.88 926.428,1406.88 926.437,1406.88 926.446,1406.88 926.455,1406.88 926.464,1406.88 926.474,1406.88 926.483,1406.88 926.492,1406.88 926.501,1406.88 926.51,1406.88 926.52,1406.88 926.529,1406.88 926.538,1406.88 926.547,1406.88 926.556,1406.88 926.566,1406.88 926.575,1406.88 926.584,1406.88 926.593,1406.88 926.602,1406.88 926.612,1406.88 926.621,1406.88 926.63,1406.88 926.639,1406.88 926.648,1406.88 926.657,1406.88 926.667,1406.88 926.676,1406.88 926.685,1406.88 926.694,1406.88 926.703,1406.88 926.713,1406.88 926.722,1406.88 926.731,1406.88 926.74,1406.88 926.749,1406.88 926.759,1406.88 926.768,1406.88 926.777,1406.88 926.786,1406.88 926.795,1406.88 926.804,1406.88 926.814,1406.88 926.823,1406.88 926.832,1406.88 926.841,1406.88 926.85,1406.88 926.86,1406.88 926.869,1406.88 926.878,1406.88 926.887,1406.88 926.896,1406.88 926.906,1406.88 926.915,1406.88 926.924,1406.88 926.933,1406.88 926.942,1406.88 926.952,1406.88 926.961,1406.88 926.97,1406.88 926.979,1406.88 926.988,1406.88 926.997,1406.88 927.007,1406.88 927.016,1406.88 927.025,1406.88 927.034,1406.88 927.043,1406.88 927.053,1406.88 927.062,1406.88 927.071,1406.88 927.08,1406.88 927.089,1406.88 927.099,1406.88 927.108,1406.88 927.117,1406.88 927.126,1406.88 927.135,1406.88 927.144,1406.88 927.154,1406.88 927.163,1406.88 927.172,1406.88 927.181,1406.88 927.19,1406.88 927.2,1406.88 927.209,1406.88 927.218,1406.88 927.227,1406.88 927.236,1406.88 927.246,1406.88 927.255,1406.88 927.264,1406.88 927.273,1406.88 927.282,1406.88 927.292,1406.88 927.301,1406.88 927.31,1406.88 927.319,1406.88 927.328,1406.88 927.337,1406.88 927.347,1406.88 927.356,1406.88 927.365,1406.88 927.374,1406.88 927.383,1406.88 927.393,1406.88 927.402,1406.88 927.411,1406.88 927.42,1406.88 927.429,1406.88 927.439,1406.88 927.448,1406.88 927.457,1406.88 927.466,1406.88 927.475,1406.88 927.484,1406.88 927.494,1406.88 927.503,1406.88 927.512,1406.88 927.521,1406.88 927.53,1406.88 927.54,1406.88 927.549,1406.88 927.558,1406.88 927.567,1406.88 927.576,1406.88 927.586,1406.88 927.595,1406.88 927.604,1406.88 927.613,1406.88 927.622,1406.88 927.632,1406.88 927.641,1406.88 927.65,1406.88 927.659,1406.88 927.668,1406.88 927.677,1406.88 927.687,1406.88 927.696,1406.88 927.705,1406.88 927.714,1406.88 927.723,1406.88 927.733,1406.88 927.742,1406.88 927.751,1406.88 927.76,1406.88 927.769,1406.88 927.779,1406.88 927.788,1406.88 927.797,1406.88 927.806,1406.88 927.815,1406.88 927.824,1406.88 927.834,1406.88 927.843,1406.88 927.852,1406.88 927.861,1406.88 927.87,1406.88 927.88,1406.88 927.889,1406.88 927.898,1406.88 927.907,1406.88 927.916,1406.88 927.926,1406.88 927.935,1406.88 927.944,1406.88 927.953,1406.88 927.962,1406.88 927.972,1406.88 927.981,1406.88 927.99,1406.88 927.999,1406.88 928.008,1406.88 928.017,1406.88 928.027,1406.88 928.036,1406.88 928.045,1406.88 928.054,1406.88 928.063,1406.88 928.073,1406.88 928.082,1406.88 928.091,1406.88 928.1,1406.88 928.109,1406.88 928.119,1406.88 928.128,1406.88 928.137,1406.88 928.146,1406.88 928.155,1406.88 928.165,1406.88 928.174,1406.88 928.183,1406.88 928.192,1406.88 928.201,1406.88 928.21,1406.88 928.22,1406.88 928.229,1406.88 928.238,1406.88 928.247,1406.88 928.256,1406.88 928.266,1406.88 928.275,1406.88 928.284,1406.88 928.293,1406.88 928.302,1406.88 928.312,1406.88 928.321,1406.88 928.33,1406.88 928.339,1406.88 928.348,1406.88 928.357,1406.88 928.367,1406.88 928.376,1406.88 928.385,1406.88 928.394,1406.88 928.403,1406.88 928.413,1406.88 928.422,1406.88 928.431,1406.88 928.44,1406.88 928.449,1406.88 928.459,1406.88 928.468,1406.88 928.477,1406.88 928.486,1406.88 928.495,1406.88 928.505,1406.88 928.514,1406.88 928.523,1406.88 928.532,1406.88 928.541,1406.88 928.55,1406.88 928.56,1406.88 928.569,1406.88 928.578,1406.88 928.587,1406.88 928.596,1406.88 928.606,1406.88 928.615,1406.88 928.624,1406.88 928.633,1406.88 928.642,1406.88 928.652,1406.88 928.661,1406.88 928.67,1406.88 928.679,1406.88 928.688,1406.88 928.697,1406.88 928.707,1406.88 928.716,1406.88 928.725,1406.88 928.734,1406.88 928.743,1406.88 928.753,1406.88 928.762,1406.88 928.771,1406.88 928.78,1406.88 928.789,1406.88 928.799,1406.88 928.808,1406.88 928.817,1406.88 928.826,1406.88 928.835,1406.88 928.845,1406.88 928.854,1406.88 928.863,1406.88 928.872,1406.88 928.881,1406.88 928.89,1406.88 928.9,1406.88 928.909,1406.88 928.918,1406.88 928.927,1406.88 928.936,1406.88 928.946,1406.88 928.955,1406.88 928.964,1406.88 928.973,1406.88 928.982,1406.88 928.992,1406.88 929.001,1406.88 929.01,1406.88 929.019,1406.88 929.028,1406.88 929.037,1406.88 929.047,1406.88 929.056,1406.88 929.065,1406.88 929.074,1406.88 929.083,1406.88 929.093,1406.88 929.102,1406.88 929.111,1406.88 929.12,1406.88 929.129,1406.88 929.139,1406.88 929.148,1406.88 929.157,1406.88 929.166,1406.88 929.175,1406.88 929.185,1406.88 929.194,1406.88 929.203,1406.88 929.212,1406.88 929.221,1406.88 929.23,1406.88 929.24,1406.88 929.249,1406.88 929.258,1406.88 929.267,1406.88 929.276,1406.88 929.286,1406.88 929.295,1406.88 929.304,1406.88 929.313,1406.88 929.322,1406.88 929.332,1406.88 929.341,1406.88 929.35,1406.88 929.359,1406.88 929.368,1406.88 929.377,1406.88 929.387,1406.88 929.396,1406.88 929.405,1406.88 929.414,1406.88 929.423,1406.88 929.433,1406.88 929.442,1406.88 929.451,1406.88 929.46,1406.88 929.469,1406.88 929.479,1406.88 929.488,1406.88 929.497,1406.88 929.506,1406.88 929.515,1406.88 929.525,1406.88 929.534,1406.88 929.543,1406.88 929.552,1406.88 929.561,1406.88 929.57,1406.88 929.58,1406.88 929.589,1406.88 929.598,1406.88 929.607,1406.88 929.616,1406.88 929.626,1406.88 929.635,1406.88 929.644,1406.88 929.653,1406.88 929.662,1406.88 929.672,1406.88 929.681,1406.88 929.69,1406.88 929.699,1406.88 929.708,1406.88 929.717,1406.88 929.727,1406.88 929.736,1406.88 929.745,1406.88 929.754,1406.88 929.763,1406.88 929.773,1406.88 929.782,1406.88 929.791,1406.88 929.8,1406.88 929.809,1406.88 929.819,1406.88 929.828,1406.88 929.837,1406.88 929.846,1406.88 929.855,1406.88 929.865,1406.88 929.874,1406.88 929.883,1406.88 929.892,1406.88 929.901,1406.88 929.91,1406.88 929.92,1406.88 929.929,1406.88 929.938,1406.88 929.947,1406.88 929.956,1406.88 929.966,1406.88 929.975,1406.88 929.984,1406.88 929.993,1406.88 930.002,1406.88 930.012,1406.88 930.021,1406.88 930.03,1406.88 930.039,1406.88 930.048,1406.88 930.057,1406.88 930.067,1406.88 930.076,1406.88 930.085,1406.88 930.094,1406.88 930.103,1406.88 930.113,1406.88 930.122,1406.88 930.131,1406.88 930.14,1406.88 930.149,1406.88 930.159,1406.88 930.168,1406.88 930.177,1406.88 930.186,1406.88 930.195,1406.88 930.205,1406.88 930.214,1406.88 930.223,1406.88 930.232,1406.88 930.241,1406.88 930.25,1406.88 930.26,1406.88 930.269,1406.88 930.278,1406.88 930.287,1406.88 930.296,1406.88 930.306,1406.88 930.315,1406.88 930.324,1406.88 930.333,1406.88 930.342,1406.88 930.352,1406.88 930.361,1406.88 930.37,1406.88 930.379,1406.88 930.388,1406.88 930.397,1406.88 930.407,1406.88 930.416,1406.88 930.425,1406.88 930.434,1406.88 930.443,1406.88 930.453,1406.88 930.462,1406.88 930.471,1406.88 930.48,1406.88 930.489,1406.88 930.499,1406.88 930.508,1406.88 930.517,1406.88 930.526,1406.88 930.535,1406.88 930.545,1406.88 930.554,1406.88 930.563,1406.88 930.572,1406.88 930.581,1406.88 930.59,1406.88 930.6,1406.88 930.609,1406.88 930.618,1406.88 930.627,1406.88 930.636,1406.88 930.646,1406.88 930.655,1406.88 930.664,1406.88 930.673,1406.88 930.682,1406.88 930.692,1406.88 930.701,1406.88 930.71,1406.88 930.719,1406.88 930.728,1406.88 930.738,1406.88 930.747,1406.88 930.756,1406.88 930.765,1406.88 930.774,1406.88 930.783,1406.88 930.793,1406.88 930.802,1406.88 930.811,1406.88 930.82,1406.88 930.829,1406.88 930.839,1406.88 930.848,1406.88 930.857,1406.88 930.866,1406.88 930.875,1406.88 930.885,1406.88 930.894,1406.88 930.903,1406.88 930.912,1406.88 930.921,1406.88 930.93,1406.88 930.94,1406.88 930.949,1406.88 930.958,1406.88 930.967,1406.88 930.976,1406.88 930.986,1406.88 930.995,1406.88 931.004,1406.88 931.013,1406.88 931.022,1406.88 931.032,1406.88 931.041,1406.88 931.05,1406.88 931.059,1406.88 931.068,1406.88 931.078,1406.88 931.087,1406.88 931.096,1406.88 931.105,1406.88 931.114,1406.88 931.123,1406.88 931.133,1406.88 931.142,1406.88 931.151,1406.88 931.16,1406.88 931.169,1406.88 931.179,1406.88 931.188,1406.88 931.197,1406.88 931.206,1406.88 931.215,1406.88 931.225,1406.88 931.234,1406.88 931.243,1406.88 931.252,1406.88 931.261,1406.88 931.27,1406.88 931.28,1406.88 931.289,1406.88 931.298,1406.88 931.307,1406.88 931.316,1406.88 931.326,1406.88 931.335,1406.88 931.344,1406.88 931.353,1406.88 931.362,1406.88 931.372,1406.88 931.381,1406.88 931.39,1406.88 931.399,1406.88 931.408,1406.88 931.418,1406.88 931.427,1406.88 931.436,1406.88 931.445,1406.88 931.454,1406.88 931.463,1406.88 931.473,1406.88 931.482,1406.88 931.491,1406.88 931.5,1406.88 931.509,1406.88 931.519,1406.88 931.528,1406.88 931.537,1406.88 931.546,1406.88 931.555,1406.88 931.565,1406.88 931.574,1406.88 931.583,1406.88 931.592,1406.88 931.601,1406.88 931.61,1406.88 931.62,1406.88 931.629,1406.88 931.638,1406.88 931.647,1406.88 931.656,1406.88 931.666,1406.88 931.675,1406.88 931.684,1406.88 931.693,1406.88 931.702,1406.88 931.712,1406.88 931.721,1406.88 931.73,1406.88 931.739,1406.88 931.748,1406.88 931.758,1406.88 931.767,1406.88 931.776,1406.88 931.785,1406.88 931.794,1406.88 931.803,1406.88 931.813,1406.88 931.822,1406.88 931.831,1406.88 931.84,1406.88 931.849,1406.88 931.859,1406.88 931.868,1406.88 931.877,1406.88 931.886,1406.88 931.895,1406.88 931.905,1406.88 931.914,1406.88 931.923,1406.88 931.932,1406.88 931.941,1406.88 931.95,1406.88 931.96,1406.88 931.969,1406.88 931.978,1406.88 931.987,1406.88 931.996,1406.88 932.006,1406.88 932.015,1406.88 932.024,1406.88 932.033,1406.88 932.042,1406.88 932.052,1406.88 932.061,1406.88 932.07,1406.88 932.079,1406.88 932.088,1406.88 932.098,1406.88 932.107,1406.88 932.116,1406.88 932.125,1406.88 932.134,1406.88 932.143,1406.88 932.153,1406.88 932.162,1406.88 932.171,1406.88 932.18,1406.88 932.189,1406.88 932.199,1406.88 932.208,1406.88 932.217,1406.88 932.226,1406.88 932.235,1406.88 932.245,1406.88 932.254,1406.88 932.263,1406.88 932.272,1406.88 932.281,1406.88 932.29,1406.88 932.3,1406.88 932.309,1406.88 932.318,1406.88 932.327,1406.88 932.336,1406.88 932.346,1406.88 932.355,1406.88 932.364,1406.88 932.373,1406.88 932.382,1406.88 932.392,1406.88 932.401,1406.88 932.41,1406.88 932.419,1406.88 932.428,1406.88 932.438,1406.88 932.447,1406.88 932.456,1406.88 932.465,1406.88 932.474,1406.88 932.483,1406.88 932.493,1406.88 932.502,1406.88 932.511,1406.88 932.52,1406.88 932.529,1406.88 932.539,1406.88 932.548,1406.88 932.557,1406.88 932.566,1406.88 932.575,1406.88 932.585,1406.88 932.594,1406.88 932.603,1406.88 932.612,1406.88 932.621,1406.88 932.63,1406.88 932.64,1406.88 932.649,1406.88 932.658,1406.88 932.667,1406.88 932.676,1406.88 932.686,1406.88 932.695,1406.88 932.704,1406.88 932.713,1406.88 932.722,1406.88 932.732,1406.88 932.741,1406.88 932.75,1406.88 932.759,1406.88 932.768,1406.88 932.778,1406.88 932.787,1406.88 932.796,1406.88 932.805,1406.88 932.814,1406.88 932.823,1406.88 932.833,1406.88 932.842,1406.88 932.851,1406.88 932.86,1406.88 932.869,1406.88 932.879,1406.88 932.888,1406.88 932.897,1406.88 932.906,1406.88 932.915,1406.88 932.925,1406.88 932.934,1406.88 932.943,1406.88 932.952,1406.88 932.961,1406.88 932.971,1406.88 932.98,1406.88 932.989,1406.88 932.998,1406.88 933.007,1406.88 933.016,1406.88 933.026,1406.88 933.035,1406.88 933.044,1406.88 933.053,1406.88 933.062,1406.88 933.072,1406.88 933.081,1406.88 933.09,1406.88 933.099,1406.88 933.108,1406.88 933.118,1406.88 933.127,1406.88 933.136,1406.88 933.145,1406.88 933.154,1406.88 933.163,1406.88 933.173,1406.88 933.182,1406.88 933.191,1406.88 933.2,1406.88 933.209,1406.88 933.219,1406.88 933.228,1406.88 933.237,1406.88 933.246,1406.88 933.255,1406.88 933.265,1406.88 933.274,1406.88 933.283,1406.88 933.292,1406.88 933.301,1406.88 933.311,1406.88 933.32,1406.88 933.329,1406.88 933.338,1406.88 933.347,1406.88 933.356,1406.88 933.366,1406.88 933.375,1406.88 933.384,1406.88 933.393,1406.88 933.402,1406.88 933.412,1406.88 933.421,1406.88 933.43,1406.88 933.439,1406.88 933.448,1406.88 933.458,1406.88 933.467,1406.88 933.476,1406.88 933.485,1406.88 933.494,1406.88 933.503,1406.88 933.513,1406.88 933.522,1406.88 933.531,1406.88 933.54,1406.88 933.549,1406.88 933.559,1406.88 933.568,1406.88 933.577,1406.88 933.586,1406.88 933.595,1406.88 933.605,1406.88 933.614,1406.88 933.623,1406.88 933.632,1406.88 933.641,1406.88 933.651,1406.88 933.66,1406.88 933.669,1406.88 933.678,1406.88 933.687,1406.88 933.696,1406.88 933.706,1406.88 933.715,1406.88 933.724,1406.88 933.733,1406.88 933.742,1406.88 933.752,1406.88 933.761,1406.88 933.77,1406.88 933.779,1406.88 933.788,1406.88 933.798,1406.88 933.807,1406.88 933.816,1406.88 933.825,1406.88 933.834,1406.88 933.843,1406.88 933.853,1406.88 933.862,1406.88 933.871,1406.88 933.88,1406.88 933.889,1406.88 933.899,1406.88 933.908,1406.88 933.917,1406.88 933.926,1406.88 933.935,1406.88 933.945,1406.88 933.954,1406.88 933.963,1406.88 933.972,1406.88 933.981,1406.88 933.991,1406.88 934,1406.88 934.009,1406.88 934.018,1406.88 934.027,1406.88 934.036,1406.88 934.046,1406.88 934.055,1406.88 934.064,1406.88 934.073,1406.88 934.082,1406.88 934.092,1406.88 934.101,1406.88 934.11,1406.88 934.119,1406.88 934.128,1406.88 934.138,1406.88 934.147,1406.88 934.156,1406.88 934.165,1406.88 934.174,1406.88 934.183,1406.88 934.193,1406.88 934.202,1406.88 934.211,1406.88 934.22,1406.88 934.229,1406.88 934.239,1406.88 934.248,1406.88 934.257,1406.88 934.266,1406.88 934.275,1406.88 934.285,1406.88 934.294,1406.88 934.303,1406.88 934.312,1406.88 934.321,1406.88 934.331,1406.88 934.34,1406.88 934.349,1406.88 934.358,1406.88 934.367,1406.88 934.376,1406.88 934.386,1406.88 934.395,1406.88 934.404,1406.88 934.413,1406.88 934.422,1406.88 934.432,1406.88 934.441,1406.88 934.45,1406.88 934.459,1406.88 934.468,1406.88 934.478,1406.88 934.487,1406.88 934.496,1406.88 934.505,1406.88 934.514,1406.88 934.523,1406.88 934.533,1406.88 934.542,1406.88 934.551,1406.88 934.56,1406.88 934.569,1406.88 934.579,1406.88 934.588,1406.88 934.597,1406.88 934.606,1406.88 934.615,1406.88 934.625,1406.88 934.634,1406.88 934.643,1406.88 934.652,1406.88 934.661,1406.88 934.671,1406.88 934.68,1406.88 934.689,1406.88 934.698,1406.88 934.707,1406.88 934.716,1406.88 934.726,1406.88 934.735,1406.88 934.744,1406.88 934.753,1406.88 934.762,1406.88 934.772,1406.88 934.781,1406.88 934.79,1406.88 934.799,1406.88 934.808,1406.88 934.818,1406.88 934.827,1406.88 934.836,1406.88 934.845,1406.88 934.854,1406.88 934.863,1406.88 934.873,1406.88 934.882,1406.88 934.891,1406.88 934.9,1406.88 934.909,1406.88 934.919,1406.88 934.928,1406.88 934.937,1406.88 934.946,1406.88 934.955,1406.88 934.965,1406.88 934.974,1406.88 934.983,1406.88 934.992,1406.88 935.001,1406.88 935.011,1406.88 935.02,1406.88 935.029,1406.88 935.038,1406.88 935.047,1406.88 935.056,1406.88 935.066,1406.88 935.075,1406.88 935.084,1406.88 935.093,1406.88 935.102,1406.88 935.112,1406.88 935.121,1406.88 935.13,1406.88 935.139,1406.88 935.148,1406.88 935.158,1406.88 935.167,1406.88 935.176,1406.88 935.185,1406.88 935.194,1406.88 935.203,1406.88 935.213,1406.88 935.222,1406.88 935.231,1406.88 935.24,1406.88 935.249,1406.88 935.259,1406.88 935.268,1406.88 935.277,1406.88 935.286,1406.88 935.295,1406.88 935.305,1406.88 935.314,1406.88 935.323,1406.88 935.332,1406.88 935.341,1406.88 935.351,1406.88 935.36,1406.88 935.369,1406.88 935.378,1406.88 935.387,1406.88 935.396,1406.88 935.406,1406.88 935.415,1406.88 935.424,1406.88 935.433,1406.88 935.442,1406.88 935.452,1406.88 935.461,1406.88 935.47,1406.88 935.479,1406.88 935.488,1406.88 935.498,1406.88 935.507,1406.88 935.516,1406.88 935.525,1406.88 935.534,1406.88 935.544,1406.88 935.553,1406.88 935.562,1406.88 935.571,1406.88 935.58,1406.88 935.589,1406.88 935.599,1406.88 935.608,1406.88 935.617,1406.88 935.626,1406.88 935.635,1406.88 935.645,1406.88 935.654,1406.88 935.663,1406.88 935.672,1406.88 935.681,1406.88 935.691,1406.88 935.7,1406.88 935.709,1406.88 935.718,1406.88 935.727,1406.88 935.736,1406.88 935.746,1406.88 935.755,1406.88 935.764,1406.88 935.773,1406.88 935.782,1406.88 935.792,1406.88 935.801,1406.88 935.81,1406.88 935.819,1406.88 935.828,1406.88 935.838,1406.88 935.847,1406.88 935.856,1406.88 935.865,1406.88 935.874,1406.88 935.884,1406.88 935.893,1406.88 935.902,1406.88 935.911,1406.88 935.92,1406.88 935.929,1406.88 935.939,1406.88 935.948,1406.88 935.957,1406.88 935.966,1406.88 935.975,1406.88 935.985,1406.88 935.994,1406.88 936.003,1406.88 936.012,1406.88 936.021,1406.88 936.031,1406.88 936.04,1406.88 936.049,1406.88 936.058,1406.88 936.067,1406.88 936.076,1406.88 936.086,1406.88 936.095,1406.88 936.104,1406.88 936.113,1406.88 936.122,1406.88 936.132,1406.88 936.141,1406.88 936.15,1406.88 936.159,1406.88 936.168,1406.88 936.178,1406.88 936.187,1406.88 936.196,1406.88 936.205,1406.88 936.214,1406.88 936.224,1406.88 936.233,1406.88 936.242,1406.88 936.251,1406.88 936.26,1406.88 936.269,1406.88 936.279,1406.88 936.288,1406.88 936.297,1406.88 936.306,1406.88 936.315,1406.88 936.325,1406.88 936.334,1406.88 936.343,1406.88 936.352,1406.88 936.361,1406.88 936.371,1406.88 936.38,1406.88 936.389,1406.88 936.398,1406.88 936.407,1406.88 936.416,1406.88 936.426,1406.88 936.435,1406.88 936.444,1406.88 936.453,1406.88 936.462,1406.88 936.472,1406.88 936.481,1406.88 936.49,1406.88 936.499,1406.88 936.508,1406.88 936.518,1406.88 936.527,1406.88 936.536,1406.88 936.545,1406.88 936.554,1406.88 936.564,1406.88 936.573,1406.88 936.582,1406.88 936.591,1406.88 936.6,1406.88 936.609,1406.88 936.619,1406.88 936.628,1406.88 936.637,1406.88 936.646,1406.88 936.655,1406.88 936.665,1406.88 936.674,1406.88 936.683,1406.88 936.692,1406.88 936.701,1406.88 936.711,1406.88 936.72,1406.88 936.729,1406.88 936.738,1406.88 936.747,1406.88 936.756,1406.88 936.766,1406.88 936.775,1406.88 936.784,1406.88 936.793,1406.88 936.802,1406.88 936.812,1406.88 936.821,1406.88 936.83,1406.88 936.839,1406.88 936.848,1406.88 936.858,1406.88 936.867,1406.88 936.876,1406.88 936.885,1406.88 936.894,1406.88 936.904,1406.88 936.913,1406.88 936.922,1406.88 936.931,1406.88 936.94,1406.88 936.949,1406.88 936.959,1406.88 936.968,1406.88 936.977,1406.88 936.986,1406.88 936.995,1406.88 937.005,1406.88 937.014,1406.88 937.023,1406.88 937.032,1406.88 937.041,1406.88 937.051,1406.88 937.06,1406.88 937.069,1406.88 937.078,1406.88 937.087,1406.88 937.096,1406.88 937.106,1406.88 937.115,1406.88 937.124,1406.88 937.133,1406.88 937.142,1406.88 937.152,1406.88 937.161,1406.88 937.17,1406.88 937.179,1406.88 937.188,1406.88 937.198,1406.88 937.207,1406.88 937.216,1406.88 937.225,1406.88 937.234,1406.88 937.244,1406.88 937.253,1406.88 937.262,1406.88 937.271,1406.88 937.28,1406.88 937.289,1406.88 937.299,1406.88 937.308,1406.88 937.317,1406.88 937.326,1406.88 937.335,1406.88 937.345,1406.88 937.354,1406.88 937.363,1406.88 937.372,1406.88 937.381,1406.88 937.391,1406.88 937.4,1406.88 937.409,1406.88 937.418,1406.88 937.427,1406.88 937.436,1406.88 937.446,1406.88 937.455,1406.88 937.464,1406.88 937.473,1406.88 937.482,1406.88 937.492,1406.88 937.501,1406.88 937.51,1406.88 937.519,1406.88 937.528,1406.88 937.538,1406.88 937.547,1406.88 937.556,1406.88 937.565,1406.88 937.574,1406.88 937.584,1406.88 937.593,1406.88 937.602,1406.88 937.611,1406.88 937.62,1406.88 937.629,1406.88 937.639,1406.88 937.648,1406.88 937.657,1406.88 937.666,1406.88 937.675,1406.88 937.685,1406.88 937.694,1406.88 937.703,1406.88 937.712,1406.88 937.721,1406.88 937.731,1406.88 937.74,1406.88 937.749,1406.88 937.758,1406.88 937.767,1406.88 937.776,1406.88 937.786,1406.88 937.795,1406.88 937.804,1406.88 937.813,1406.88 937.822,1406.88 937.832,1406.88 937.841,1406.88 937.85,1406.88 937.859,1406.88 937.868,1406.88 937.878,1406.88 937.887,1406.88 937.896,1406.88 937.905,1406.88 937.914,1406.88 937.924,1406.88 937.933,1406.88 937.942,1406.88 937.951,1406.88 937.96,1406.88 937.969,1406.88 937.979,1406.88 937.988,1406.88 937.997,1406.88 938.006,1406.88 938.015,1406.88 938.025,1406.88 938.034,1406.88 938.043,1406.88 938.052,1406.88 938.061,1406.88 938.071,1406.88 938.08,1406.88 938.089,1406.88 938.098,1406.88 938.107,1406.88 938.117,1406.88 938.126,1406.88 938.135,1406.88 938.144,1406.88 938.153,1406.88 938.162,1406.88 938.172,1406.88 938.181,1406.88 938.19,1406.88 938.199,1406.88 938.208,1406.88 938.218,1406.88 938.227,1406.88 938.236,1406.88 938.245,1406.88 938.254,1406.88 938.264,1406.88 938.273,1406.88 938.282,1406.88 938.291,1406.88 938.3,1406.88 938.309,1406.88 938.319,1406.88 938.328,1406.88 938.337,1406.88 938.346,1406.88 938.355,1406.88 938.365,1406.88 938.374,1406.88 938.383,1406.88 938.392,1406.88 938.401,1406.88 938.411,1406.88 938.42,1406.88 938.429,1406.88 938.438,1406.88 938.447,1406.88 938.457,1406.88 938.466,1406.88 938.475,1406.88 938.484,1406.88 938.493,1406.88 938.502,1406.88 938.512,1406.88 938.521,1406.88 938.53,1406.88 938.539,1406.88 938.548,1406.88 938.558,1406.88 938.567,1406.88 938.576,1406.88 938.585,1406.88 938.594,1406.88 938.604,1406.88 938.613,1406.88 938.622,1406.88 938.631,1406.88 938.64,1406.88 938.649,1406.88 938.659,1406.88 938.668,1406.88 938.677,1406.88 938.686,1406.88 938.695,1406.88 938.705,1406.88 938.714,1406.88 938.723,1406.88 938.732,1406.88 938.741,1406.88 938.751,1406.88 938.76,1406.88 938.769,1406.88 938.778,1406.88 938.787,1406.88 938.797,1406.88 938.806,1406.88 938.815,1406.88 938.824,1406.88 938.833,1406.88 938.842,1406.88 938.852,1406.88 938.861,1406.88 938.87,1406.88 938.879,1406.88 938.888,1406.88 938.898,1406.88 938.907,1406.88 938.916,1406.88 938.925,1406.88 938.934,1406.88 938.944,1406.88 938.953,1406.88 938.962,1406.88 938.971,1406.88 938.98,1406.88 938.989,1406.88 938.999,1406.88 939.008,1406.88 939.017,1406.88 939.026,1406.88 939.035,1406.88 939.045,1406.88 939.054,1406.88 939.063,1406.88 939.072,1406.88 939.081,1406.88 939.091,1406.88 939.1,1406.88 939.109,1406.88 939.118,1406.88 939.127,1406.88 939.137,1406.88 939.146,1406.88 939.155,1406.88 939.164,1406.88 939.173,1406.88 939.182,1406.88 939.192,1406.88 939.201,1406.88 939.21,1406.88 939.219,1406.88 939.228,1406.88 939.238,1406.88 939.247,1406.88 939.256,1406.88 939.265,1406.88 939.274,1406.88 939.284,1406.88 939.293,1406.88 939.302,1406.88 939.311,1406.88 939.32,1406.88 939.329,1406.88 939.339,1406.88 939.348,1406.88 939.357,1406.88 939.366,1406.88 939.375,1406.88 939.385,1406.88 939.394,1406.88 939.403,1406.88 939.412,1406.88 939.421,1406.88 939.431,1406.88 939.44,1406.88 939.449,1406.88 939.458,1406.88 939.467,1406.88 939.477,1406.88 939.486,1406.88 939.495,1406.88 939.504,1406.88 939.513,1406.88 939.522,1406.88 939.532,1406.88 939.541,1406.88 939.55,1406.88 939.559,1406.88 939.568,1406.88 939.578,1406.88 939.587,1406.88 939.596,1406.88 939.605,1406.88 939.614,1406.88 939.624,1406.88 939.633,1406.88 939.642,1406.88 939.651,1406.88 939.66,1406.88 939.669,1406.88 939.679,1406.88 939.688,1406.88 939.697,1406.88 939.706,1406.88 939.715,1406.88 939.725,1406.88 939.734,1406.88 939.743,1406.88 939.752,1406.88 939.761,1406.88 939.771,1406.88 939.78,1406.88 939.789,1406.88 939.798,1406.88 939.807,1406.88 939.817,1406.88 939.826,1406.88 939.835,1406.88 939.844,1406.88 939.853,1406.88 939.862,1406.88 939.872,1406.88 939.881,1406.88 939.89,1406.88 939.899,1406.88 939.908,1406.88 939.918,1406.88 939.927,1406.88 939.936,1406.88 939.945,1406.88 939.954,1406.88 939.964,1406.88 939.973,1406.88 939.982,1406.88 939.991,1406.88 940,1406.88 940.009,1406.88 940.019,1406.88 940.028,1406.88 940.037,1406.88 940.046,1406.88 940.055,1406.88 940.065,1406.88 940.074,1406.88 940.083,1406.88 940.092,1406.88 940.101,1406.88 940.111,1406.88 940.12,1406.88 940.129,1406.88 940.138,1406.88 940.147,1406.88 940.157,1406.88 940.166,1406.88 940.175,1406.88 940.184,1406.88 940.193,1406.88 940.202,1406.88 940.212,1406.88 940.221,1406.88 940.23,1406.88 940.239,1406.88 940.248,1406.88 940.258,1406.88 940.267,1406.88 940.276,1406.88 940.285,1406.88 940.294,1406.88 940.304,1406.88 940.313,1406.88 940.322,1406.88 940.331,1406.88 940.34,1406.88 940.35,1406.88 940.359,1406.88 940.368,1406.88 940.377,1406.88 940.386,1406.88 940.395,1406.88 940.405,1406.88 940.414,1406.88 940.423,1406.88 940.432,1406.88 940.441,1406.88 940.451,1406.88 940.46,1406.88 940.469,1406.88 940.478,1406.88 940.487,1406.88 940.497,1406.88 940.506,1406.88 940.515,1406.88 940.524,1406.88 940.533,1406.88 940.542,1406.88 940.552,1406.88 940.561,1406.88 940.57,1406.88 940.579,1406.88 940.588,1406.88 940.598,1406.88 940.607,1406.88 940.616,1406.88 940.625,1406.88 940.634,1406.88 940.644,1406.88 940.653,1406.88 940.662,1406.88 940.671,1406.88 940.68,1406.88 940.69,1406.88 940.699,1406.88 940.708,1406.88 940.717,1406.88 940.726,1406.88 940.735,1406.88 940.745,1406.88 940.754,1406.88 940.763,1406.88 940.772,1406.88 940.781,1406.88 940.791,1406.88 940.8,1406.88 940.809,1406.88 940.818,1406.88 940.827,1406.88 940.837,1406.88 940.846,1406.88 940.855,1406.88 940.864,1406.88 940.873,1406.88 940.882,1406.88 940.892,1406.88 940.901,1406.88 940.91,1406.88 940.919,1406.88 940.928,1406.88 940.938,1406.88 940.947,1406.88 940.956,1406.88 940.965,1406.88 940.974,1406.88 940.984,1406.88 940.993,1406.88 941.002,1406.88 941.011,1406.88 941.02,1406.88 941.03,1406.88 941.039,1406.88 941.048,1406.88 941.057,1406.88 941.066,1406.88 941.075,1406.88 941.085,1406.88 941.094,1406.88 941.103,1406.88 941.112,1406.88 941.121,1406.88 941.131,1406.88 941.14,1406.88 941.149,1406.88 941.158,1406.88 941.167,1406.88 941.177,1406.88 941.186,1406.88 941.195,1406.88 941.204,1406.88 941.213,1406.88 941.222,1406.88 941.232,1406.88 941.241,1406.88 941.25,1406.88 941.259,1406.88 941.268,1406.88 941.278,1406.88 941.287,1406.88 941.296,1406.88 941.305,1406.88 941.314,1406.88 941.324,1406.88 941.333,1406.88 941.342,1406.88 941.351,1406.88 941.36,1406.88 941.37,1406.88 941.379,1406.88 941.388,1406.88 941.397,1406.88 941.406,1406.88 941.415,1406.88 941.425,1406.88 941.434,1406.88 941.443,1406.88 941.452,1406.88 941.461,1406.88 941.471,1406.88 941.48,1406.88 941.489,1406.88 941.498,1406.88 941.507,1406.88 941.517,1406.88 941.526,1406.88 941.535,1406.88 941.544,1406.88 941.553,1406.88 941.562,1406.88 941.572,1406.88 941.581,1406.88 941.59,1406.88 941.599,1406.88 941.608,1406.88 941.618,1406.88 941.627,1406.88 941.636,1406.88 941.645,1406.88 941.654,1406.88 941.664,1406.88 941.673,1406.88 941.682,1406.88 941.691,1406.88 941.7,1406.88 941.71,1406.88 941.719,1406.88 941.728,1406.88 941.737,1406.88 941.746,1406.88 941.755,1406.88 941.765,1406.88 941.774,1406.88 941.783,1406.88 941.792,1406.88 941.801,1406.88 941.811,1406.88 941.82,1406.88 941.829,1406.88 941.838,1406.88 941.847,1406.88 941.857,1406.88 941.866,1406.88 941.875,1406.88 941.884,1406.88 941.893,1406.88 941.902,1406.88 941.912,1406.88 941.921,1406.88 941.93,1406.88 941.939,1406.88 941.948,1406.88 941.958,1406.88 941.967,1406.88 941.976,1406.88 941.985,1406.88 941.994,1406.88 942.004,1406.88 942.013,1406.88 942.022,1406.88 942.031,1406.88 942.04,1406.88 942.05,1406.88 942.059,1406.88 942.068,1406.88 942.077,1406.88 942.086,1406.88 942.095,1406.88 942.105,1406.88 942.114,1406.88 942.123,1406.88 942.132,1406.88 942.141,1406.88 942.151,1406.88 942.16,1406.88 942.169,1406.88 942.178,1406.88 942.187,1406.88 942.197,1406.88 942.206,1406.88 942.215,1406.88 942.224,1406.88 942.233,1406.88 942.242,1406.88 942.252,1406.88 942.261,1406.88 942.27,1406.88 942.279,1406.88 942.288,1406.88 942.298,1406.88 942.307,1406.88 942.316,1406.88 942.325,1406.88 942.334,1406.88 942.344,1406.88 942.353,1406.88 942.362,1406.88 942.371,1406.88 942.38,1406.88 942.39,1406.88 942.399,1406.88 942.408,1406.88 942.417,1406.88 942.426,1406.88 942.435,1406.88 942.445,1406.88 942.454,1406.88 942.463,1406.88 942.472,1406.88 942.481,1406.88 942.491,1406.88 942.5,1406.88 942.509,1406.88 942.518,1406.88 942.527,1406.88 942.537,1406.88 942.546,1406.88 942.555,1406.88 942.564,1406.88 942.573,1406.88 942.582,1406.88 942.592,1406.88 942.601,1406.88 942.61,1406.88 942.619,1406.88 942.628,1406.88 942.638,1406.88 942.647,1406.88 942.656,1406.88 942.665,1406.88 942.674,1406.88 942.684,1406.88 942.693,1406.88 942.702,1406.88 942.711,1406.88 942.72,1406.88 942.73,1406.88 942.739,1406.88 942.748,1406.88 942.757,1406.88 942.766,1406.88 942.775,1406.88 942.785,1406.88 942.794,1406.88 942.803,1406.88 942.812,1406.88 942.821,1406.88 942.831,1406.88 942.84,1406.88 942.849,1406.88 942.858,1406.88 942.867,1406.88 942.877,1406.88 942.886,1406.88 942.895,1406.88 942.904,1406.88 942.913,1406.88 942.923,1406.88 942.932,1406.88 942.941,1406.88 942.95,1406.88 942.959,1406.88 942.968,1406.88 942.978,1406.88 942.987,1406.88 942.996,1406.88 943.005,1406.88 943.014,1406.88 943.024,1406.88 943.033,1406.88 943.042,1406.88 943.051,1406.88 943.06,1406.88 943.07,1406.88 943.079,1406.88 943.088,1406.88 943.097,1406.88 943.106,1406.88 943.115,1406.88 943.125,1406.88 943.134,1406.88 943.143,1406.88 943.152,1406.88 943.161,1406.88 943.171,1406.88 943.18,1406.88 943.189,1406.88 943.198,1406.88 943.207,1406.88 943.217,1406.88 943.226,1406.88 943.235,1406.88 943.244,1406.88 943.253,1406.88 943.263,1406.88 943.272,1406.88 943.281,1406.88 943.29,1406.88 943.299,1406.88 943.308,1406.88 943.318,1406.88 943.327,1406.88 943.336,1406.88 943.345,1406.88 943.354,1406.88 943.364,1406.88 943.373,1406.88 943.382,1406.88 943.391,1406.88 943.4,1406.88 943.41,1406.88 943.419,1406.88 943.428,1406.88 943.437,1406.88 943.446,1406.88 943.455,1406.88 943.465,1406.88 943.474,1406.88 943.483,1406.88 943.492,1406.88 943.501,1406.88 943.511,1406.88 943.52,1406.88 943.529,1406.88 943.538,1406.88 943.547,1406.88 943.557,1406.88 943.566,1406.88 943.575,1406.88 943.584,1406.88 943.593,1406.88 943.603,1406.88 943.612,1406.88 943.621,1406.88 943.63,1406.88 943.639,1406.88 943.648,1406.88 943.658,1406.88 943.667,1406.88 943.676,1406.88 943.685,1406.88 943.694,1406.88 943.704,1406.88 943.713,1406.88 943.722,1406.88 943.731,1406.88 943.74,1406.88 943.75,1406.88 943.759,1406.88 943.768,1406.88 943.777,1406.88 943.786,1406.88 943.795,1406.88 943.805,1406.88 943.814,1406.88 943.823,1406.88 943.832,1406.88 943.841,1406.88 943.851,1406.88 943.86,1406.88 943.869,1406.88 943.878,1406.88 943.887,1406.88 943.897,1406.88 943.906,1406.88 943.915,1406.88 943.924,1406.88 943.933,1406.88 943.943,1406.88 943.952,1406.88 943.961,1406.88 943.97,1406.88 943.979,1406.88 943.988,1406.88 943.998,1406.88 944.007,1406.88 944.016,1406.88 944.025,1406.88 944.034,1406.88 944.044,1406.88 944.053,1406.88 944.062,1406.88 944.071,1406.88 944.08,1406.88 944.09,1406.88 944.099,1406.88 944.108,1406.88 944.117,1406.88 944.126,1406.88 944.135,1406.88 944.145,1406.88 944.154,1406.88 944.163,1406.88 944.172,1406.88 944.181,1406.88 944.191,1406.88 944.2,1406.88 944.209,1406.88 944.218,1406.88 944.227,1406.88 944.237,1406.88 944.246,1406.88 944.255,1406.88 944.264,1406.88 944.273,1406.88 944.283,1406.88 944.292,1406.88 944.301,1406.88 944.31,1406.88 944.319,1406.88 944.328,1406.88 944.338,1406.88 944.347,1406.88 944.356,1406.88 944.365,1406.88 944.374,1406.88 944.384,1406.88 944.393,1406.88 944.402,1406.88 944.411,1406.88 944.42,1406.88 944.43,1406.88 944.439,1406.88 944.448,1406.88 944.457,1406.88 944.466,1406.88 944.475,1406.88 944.485,1406.88 944.494,1406.88 944.503,1406.88 944.512,1406.88 944.521,1406.88 944.531,1406.88 944.54,1406.88 944.549,1406.88 944.558,1406.88 944.567,1406.88 944.577,1406.88 944.586,1406.88 944.595,1406.88 944.604,1406.88 944.613,1406.88 944.623,1406.88 944.632,1406.88 944.641,1406.88 944.65,1406.88 944.659,1406.88 944.668,1406.88 944.678,1406.88 944.687,1406.88 944.696,1406.88 944.705,1406.88 944.714,1406.88 944.724,1406.88 944.733,1406.88 944.742,1406.88 944.751,1406.88 944.76,1406.88 944.77,1406.88 944.779,1406.88 944.788,1406.88 944.797,1406.88 944.806,1406.88 944.815,1406.88 944.825,1406.88 944.834,1406.88 944.843,1406.88 944.852,1406.88 944.861,1406.88 944.871,1406.88 944.88,1406.88 944.889,1406.88 944.898,1406.88 944.907,1406.88 944.917,1406.88 944.926,1406.88 944.935,1406.88 944.944,1406.88 944.953,1406.88 944.963,1406.88 944.972,1406.88 944.981,1406.88 944.99,1406.88 944.999,1406.88 945.008,1406.88 945.018,1406.88 945.027,1406.88 945.036,1406.88 945.045,1406.88 945.054,1406.88 945.064,1406.88 945.073,1406.88 945.082,1406.88 945.091,1406.88 945.1,1406.88 945.11,1406.88 945.119,1406.88 945.128,1406.88 945.137,1406.88 945.146,1406.88 945.155,1406.88 945.165,1406.88 945.174,1406.88 945.183,1406.88 945.192,1406.88 945.201,1406.88 945.211,1406.88 945.22,1406.88 945.229,1406.88 945.238,1406.88 945.247,1406.88 945.257,1406.88 945.266,1406.88 945.275,1406.88 945.284,1406.88 945.293,1406.88 945.303,1406.88 945.312,1406.88 945.321,1406.88 945.33,1406.88 945.339,1406.88 945.348,1406.88 945.358,1406.88 945.367,1406.88 945.376,1406.88 945.385,1406.88 945.394,1406.88 945.404,1406.88 945.413,1406.88 945.422,1406.88 945.431,1406.88 945.44,1406.88 945.45,1406.88 945.459,1406.88 945.468,1406.88 945.477,1406.88 945.486,1406.88 945.496,1406.88 945.505,1406.88 945.514,1406.88 945.523,1406.88 945.532,1406.88 945.541,1406.88 945.551,1406.88 945.56,1406.88 945.569,1406.88 945.578,1406.88 945.587,1406.88 945.597,1406.88 945.606,1406.88 945.615,1406.88 945.624,1406.88 945.633,1406.88 945.643,1406.88 945.652,1406.88 945.661,1406.88 945.67,1406.88 945.679,1406.88 945.688,1406.88 945.698,1406.88 945.707,1406.88 945.716,1406.88 945.725,1406.88 945.734,1406.88 945.744,1406.88 945.753,1406.88 945.762,1406.88 945.771,1406.88 945.78,1406.88 945.79,1406.88 945.799,1406.88 945.808,1406.88 945.817,1406.88 945.826,1406.88 945.836,1406.88 945.845,1406.88 945.854,1406.88 945.863,1406.88 945.872,1406.88 945.881,1406.88 945.891,1406.88 945.9,1406.88 945.909,1406.88 945.918,1406.88 945.927,1406.88 945.937,1406.88 945.946,1406.88 945.955,1406.88 945.964,1406.88 945.973,1406.88 945.983,1406.88 945.992,1406.88 946.001,1406.88 946.01,1406.88 946.019,1406.88 946.028,1406.88 946.038,1406.88 946.047,1406.88 946.056,1406.88 946.065,1406.88 946.074,1406.88 946.084,1406.88 946.093,1406.88 946.102,1406.88 946.111,1406.88 946.12,1406.88 946.13,1406.88 946.139,1406.88 946.148,1406.88 946.157,1406.88 946.166,1406.88 946.176,1406.88 946.185,1406.88 946.194,1406.88 946.203,1406.88 946.212,1406.88 946.221,1406.88 946.231,1406.88 946.24,1406.88 946.249,1406.88 946.258,1406.88 946.267,1406.88 946.277,1406.88 946.286,1406.88 946.295,1406.88 946.304,1406.88 946.313,1406.88 946.323,1406.88 946.332,1406.88 946.341,1406.88 946.35,1406.88 946.359,1406.88 946.368,1406.88 946.378,1406.88 946.387,1406.88 946.396,1406.88 946.405,1406.88 946.414,1406.88 946.424,1406.88 946.433,1406.88 946.442,1406.88 946.451,1406.88 946.46,1406.88 946.47,1406.88 946.479,1406.88 946.488,1406.88 946.497,1406.88 946.506,1406.88 946.516,1406.88 946.525,1406.88 946.534,1406.88 946.543,1406.88 946.552,1406.88 946.561,1406.88 946.571,1406.88 946.58,1406.88 946.589,1406.88 946.598,1406.88 946.607,1406.88 946.617,1406.88 946.626,1406.88 946.635,1406.88 946.644,1406.88 946.653,1406.88 946.663,1406.88 946.672,1406.88 946.681,1406.88 946.69,1406.88 946.699,1406.88 946.708,1406.88 946.718,1406.88 946.727,1406.88 946.736,1406.88 946.745,1406.88 946.754,1406.88 946.764,1406.88 946.773,1406.88 946.782,1406.88 946.791,1406.88 946.8,1406.88 946.81,1406.88 946.819,1406.88 946.828,1406.88 946.837,1406.88 946.846,1406.88 946.856,1406.88 946.865,1406.88 946.874,1406.88 946.883,1406.88 946.892,1406.88 946.901,1406.88 946.911,1406.88 946.92,1406.88 946.929,1406.88 946.938,1406.88 946.947,1406.88 946.957,1406.88 946.966,1406.88 946.975,1406.88 946.984,1406.88 946.993,1406.88 947.003,1406.88 947.012,1406.88 947.021,1406.88 947.03,1406.88 947.039,1406.88 947.048,1406.88 947.058,1406.88 947.067,1406.88 947.076,1406.88 947.085,1406.88 947.094,1406.88 947.104,1406.88 947.113,1406.88 947.122,1406.88 947.131,1406.88 947.14,1406.88 947.15,1406.88 947.159,1406.88 947.168,1406.88 947.177,1406.88 947.186,1406.88 947.196,1406.88 947.205,1406.88 947.214,1406.88 947.223,1406.88 947.232,1406.88 947.241,1406.88 947.251,1406.88 947.26,1406.88 947.269,1406.88 947.278,1406.88 947.287,1406.88 947.297,1406.88 947.306,1406.88 947.315,1406.88 947.324,1406.88 947.333,1406.88 947.343,1406.88 947.352,1406.88 947.361,1406.88 947.37,1406.88 947.379,1406.88 947.388,1406.88 947.398,1406.88 947.407,1406.88 947.416,1406.88 947.425,1406.88 947.434,1406.88 947.444,1406.88 947.453,1406.88 947.462,1406.88 947.471,1406.88 947.48,1406.88 947.49,1406.88 947.499,1406.88 947.508,1406.88 947.517,1406.88 947.526,1406.88 947.536,1406.88 947.545,1406.88 947.554,1406.88 947.563,1406.88 947.572,1406.88 947.581,1406.88 947.591,1406.88 947.6,1406.88 947.609,1406.88 947.618,1406.88 947.627,1406.88 947.637,1406.88 947.646,1406.88 947.655,1406.88 947.664,1406.88 947.673,1406.88 947.683,1406.88 947.692,1406.88 947.701,1406.88 947.71,1406.88 947.719,1406.88 947.729,1406.88 947.738,1406.88 947.747,1406.88 947.756,1406.88 947.765,1406.88 947.774,1406.88 947.784,1406.88 947.793,1406.88 947.802,1406.88 947.811,1406.88 947.82,1406.88 947.83,1406.88 947.839,1406.88 947.848,1406.88 947.857,1406.88 947.866,1406.88 947.876,1406.88 947.885,1406.88 947.894,1406.88 947.903,1406.88 947.912,1406.88 947.921,1406.88 947.931,1406.88 947.94,1406.88 947.949,1406.88 947.958,1406.88 947.967,1406.88 947.977,1406.88 947.986,1406.88 947.995,1406.88 948.004,1406.88 948.013,1406.88 948.023,1406.88 948.032,1406.88 948.041,1406.88 948.05,1406.88 948.059,1406.88 948.069,1406.88 948.078,1406.88 948.087,1406.88 948.096,1406.88 948.105,1406.88 948.114,1406.88 948.124,1406.88 948.133,1406.88 948.142,1406.88 948.151,1406.88 948.16,1406.88 948.17,1406.88 948.179,1406.88 948.188,1406.88 948.197,1406.88 948.206,1406.88 948.216,1406.88 948.225,1406.88 948.234,1406.88 948.243,1406.88 948.252,1406.88 948.261,1406.88 948.271,1406.88 948.28,1406.88 948.289,1406.88 948.298,1406.88 948.307,1406.88 948.317,1406.88 948.326,1406.88 948.335,1406.88 948.344,1406.88 948.353,1406.88 948.363,1406.88 948.372,1406.88 948.381,1406.88 948.39,1406.88 948.399,1406.88 948.409,1406.88 948.418,1406.88 948.427,1406.88 948.436,1406.88 948.445,1406.88 948.454,1406.88 948.464,1406.88 948.473,1406.88 948.482,1406.88 948.491,1406.88 948.5,1406.88 948.51,1406.88 948.519,1406.88 948.528,1406.88 948.537,1406.88 948.546,1406.88 948.556,1406.88 948.565,1406.88 948.574,1406.88 948.583,1406.88 948.592,1406.88 948.601,1406.88 948.611,1406.88 948.62,1406.88 948.629,1406.88 948.638,1406.88 948.647,1406.88 948.657,1406.88 948.666,1406.88 948.675,1406.88 948.684,1406.88 948.693,1406.88 948.703,1406.88 948.712,1406.88 948.721,1406.88 948.73,1406.88 948.739,1406.88 948.749,1406.88 948.758,1406.88 948.767,1406.88 948.776,1406.88 948.785,1406.88 948.794,1406.88 948.804,1406.88 948.813,1406.88 948.822,1406.88 948.831,1406.88 948.84,1406.88 948.85,1406.88 948.859,1406.88 948.868,1406.88 948.877,1406.88 948.886,1406.88 948.896,1406.88 948.905,1406.88 948.914,1406.88 948.923,1406.88 948.932,1406.88 948.941,1406.88 948.951,1406.88 948.96,1406.88 948.969,1406.88 948.978,1406.88 948.987,1406.88 948.997,1406.88 949.006,1406.88 949.015,1406.88 949.024,1406.88 949.033,1406.88 949.043,1406.88 949.052,1406.88 949.061,1406.88 949.07,1406.88 949.079,1406.88 949.089,1406.88 949.098,1406.88 949.107,1406.88 949.116,1406.88 949.125,1406.88 949.134,1406.88 949.144,1406.88 949.153,1406.88 949.162,1406.88 949.171,1406.88 949.18,1406.88 949.19,1406.88 949.199,1406.88 949.208,1406.88 949.217,1406.88 949.226,1406.88 949.236,1406.88 949.245,1406.88 949.254,1406.88 949.263,1406.88 949.272,1406.88 949.281,1406.88 949.291,1406.88 949.3,1406.88 949.309,1406.88 949.318,1406.88 949.327,1406.88 949.337,1406.88 949.346,1406.88 949.355,1406.88 949.364,1406.88 949.373,1406.88 949.383,1406.88 949.392,1406.88 949.401,1406.88 949.41,1406.88 949.419,1406.88 949.429,1406.88 949.438,1406.88 949.447,1406.88 949.456,1406.88 949.465,1406.88 949.474,1406.88 949.484,1406.88 949.493,1406.88 949.502,1406.88 949.511,1406.88 949.52,1406.88 949.53,1406.88 949.539,1406.88 949.548,1406.88 949.557,1406.88 949.566,1406.88 949.576,1406.88 949.585,1406.88 949.594,1406.88 949.603,1406.88 949.612,1406.88 949.621,1406.88 949.631,1406.88 949.64,1406.88 949.649,1406.88 949.658,1406.88 949.667,1406.88 949.677,1406.88 949.686,1406.88 949.695,1406.88 949.704,1406.88 949.713,1406.88 949.723,1406.88 949.732,1406.88 949.741,1406.88 949.75,1406.88 949.759,1406.88 949.769,1406.88 949.778,1406.88 949.787,1406.88 949.796,1406.88 949.805,1406.88 949.814,1406.88 949.824,1406.88 949.833,1406.88 949.842,1406.88 949.851,1406.88 949.86,1406.88 949.87,1406.88 949.879,1406.88 949.888,1406.88 949.897,1406.88 949.906,1406.88 949.916,1406.88 949.925,1406.88 949.934,1406.88 949.943,1406.88 949.952,1406.88 949.961,1406.88 949.971,1406.88 949.98,1406.88 949.989,1406.88 949.998,1406.88 950.007,1406.88 950.017,1406.88 950.026,1406.88 950.035,1406.88 950.044,1406.88 950.053,1406.88 950.063,1406.88 950.072,1406.88 950.081,1406.88 950.09,1406.88 950.099,1406.88 950.109,1406.88 950.118,1406.88 950.127,1406.88 950.136,1406.88 950.145,1406.88 950.154,1406.88 950.164,1406.88 950.173,1406.88 950.182,1406.88 950.191,1406.88 950.2,1406.88 950.21,1406.88 950.219,1406.88 950.228,1406.88 950.237,1406.88 950.246,1406.88 950.256,1406.88 950.265,1406.88 950.274,1406.88 950.283,1406.88 950.292,1406.88 950.302,1406.88 950.311,1406.88 950.32,1406.88 950.329,1406.88 950.338,1406.88 950.347,1406.88 950.357,1406.88 950.366,1406.88 950.375,1406.88 950.384,1406.88 950.393,1406.88 950.403,1406.88 950.412,1406.88 950.421,1406.88 950.43,1406.88 950.439,1406.88 950.449,1406.88 950.458,1406.88 950.467,1406.88 950.476,1406.88 950.485,1406.88 950.494,1406.88 950.504,1406.88 950.513,1406.88 950.522,1406.88 950.531,1406.88 950.54,1406.88 950.55,1406.88 950.559,1406.88 950.568,1406.88 950.577,1406.88 950.586,1406.88 950.596,1406.88 950.605,1406.88 950.614,1406.88 950.623,1406.88 950.632,1406.88 950.642,1406.88 950.651,1406.88 950.66,1406.88 950.669,1406.88 950.678,1406.88 950.687,1406.88 950.697,1406.88 950.706,1406.88 950.715,1406.88 950.724,1406.88 950.733,1406.88 950.743,1406.88 950.752,1406.88 950.761,1406.88 950.77,1406.88 950.779,1406.88 950.789,1406.88 950.798,1406.88 950.807,1406.88 950.816,1406.88 950.825,1406.88 950.834,1406.88 950.844,1406.88 950.853,1406.88 950.862,1406.88 950.871,1406.88 950.88,1406.88 950.89,1406.88 950.899,1406.88 950.908,1406.88 950.917,1406.88 950.926,1406.88 950.936,1406.88 950.945,1406.88 950.954,1406.88 950.963,1406.88 950.972,1406.88 950.982,1406.88 950.991,1406.88 951,1406.88 951.009,1406.88 951.018,1406.88 951.027,1406.88 951.037,1406.88 951.046,1406.88 951.055,1406.88 951.064,1406.88 951.073,1406.88 951.083,1406.88 951.092,1406.88 951.101,1406.88 951.11,1406.88 951.119,1406.88 951.129,1406.88 951.138,1406.88 951.147,1406.88 951.156,1406.88 951.165,1406.88 951.174,1406.88 951.184,1406.88 951.193,1406.88 951.202,1406.88 951.211,1406.88 951.22,1406.88 951.23,1406.88 951.239,1406.88 951.248,1406.88 951.257,1406.88 951.266,1406.88 951.276,1406.88 951.285,1406.88 951.294,1406.88 951.303,1406.88 951.312,1406.88 951.322,1406.88 951.331,1406.88 951.34,1406.88 951.349,1406.88 951.358,1406.88 951.367,1406.88 951.377,1406.88 951.386,1406.88 951.395,1406.88 951.404,1406.88 951.413,1406.88 951.423,1406.88 951.432,1406.88 951.441,1406.88 951.45,1406.88 951.459,1406.88 951.469,1406.88 951.478,1406.88 951.487,1406.88 951.496,1406.88 951.505,1406.88 951.514,1406.88 951.524,1406.88 951.533,1406.88 951.542,1406.88 951.551,1406.88 951.56,1406.88 951.57,1406.88 951.579,1406.88 951.588,1406.88 951.597,1406.88 951.606,1406.88 951.616,1406.88 951.625,1406.88 951.634,1406.88 951.643,1406.88 951.652,1406.88 951.662,1406.88 951.671,1406.88 951.68,1406.88 951.689,1406.88 951.698,1406.88 951.707,1406.88 951.717,1406.88 951.726,1406.88 951.735,1406.88 951.744,1406.88 951.753,1406.88 951.763,1406.88 951.772,1406.88 951.781,1406.88 951.79,1406.88 951.799,1406.88 951.809,1406.88 951.818,1406.88 951.827,1406.88 951.836,1406.88 951.845,1406.88 951.854,1406.88 951.864,1406.88 951.873,1406.88 951.882,1406.88 951.891,1406.88 951.9,1406.88 951.91,1406.88 951.919,1406.88 951.928,1406.88 951.937,1406.88 951.946,1406.88 951.956,1406.88 951.965,1406.88 951.974,1406.88 951.983,1406.88 951.992,1406.88 952.002,1406.88 952.011,1406.88 952.02,1406.88 952.029,1406.88 952.038,1406.88 952.047,1406.88 952.057,1406.88 952.066,1406.88 952.075,1406.88 952.084,1406.88 952.093,1406.88 952.103,1406.88 952.112,1406.88 952.121,1406.88 952.13,1406.88 952.139,1406.88 952.149,1406.88 952.158,1406.88 952.167,1406.88 952.176,1406.88 952.185,1406.88 952.194,1406.88 952.204,1406.88 952.213,1406.88 952.222,1406.88 952.231,1406.88 952.24,1406.88 952.25,1406.88 952.259,1406.88 952.268,1406.88 952.277,1406.88 952.286,1406.88 952.296,1406.88 952.305,1406.88 952.314,1406.88 952.323,1406.88 952.332,1406.88 952.342,1406.88 952.351,1406.88 952.36,1406.88 952.369,1406.88 952.378,1406.88 952.387,1406.88 952.397,1406.88 952.406,1406.88 952.415,1406.88 952.424,1406.88 952.433,1406.88 952.443,1406.88 952.452,1406.88 952.461,1406.88 952.47,1406.88 952.479,1406.88 952.489,1406.88 952.498,1406.88 952.507,1406.88 952.516,1406.88 952.525,1406.88 952.534,1406.88 952.544,1406.88 952.553,1406.88 952.562,1406.88 952.571,1406.88 952.58,1406.88 952.59,1406.88 952.599,1406.88 952.608,1406.88 952.617,1406.88 952.626,1406.88 952.636,1406.88 952.645,1406.88 952.654,1406.88 952.663,1406.88 952.672,1406.88 952.682,1406.88 952.691,1406.88 952.7,1406.88 952.709,1406.88 952.718,1406.88 952.727,1406.88 952.737,1406.88 952.746,1406.88 952.755,1406.88 952.764,1406.88 952.773,1406.88 952.783,1406.88 952.792,1406.88 952.801,1406.88 952.81,1406.88 952.819,1406.88 952.829,1406.88 952.838,1406.88 952.847,1406.88 952.856,1406.88 952.865,1406.88 952.875,1406.88 952.884,1406.88 952.893,1406.88 952.902,1406.88 952.911,1406.88 952.92,1406.88 952.93,1406.88 952.939,1406.88 952.948,1406.88 952.957,1406.88 952.966,1406.88 952.976,1406.88 952.985,1406.88 952.994,1406.88 953.003,1406.88 953.012,1406.88 953.022,1406.88 953.031,1406.88 953.04,1406.88 953.049,1406.88 953.058,1406.88 953.067,1406.88 953.077,1406.88 953.086,1406.88 953.095,1406.88 953.104,1406.88 953.113,1406.88 953.123,1406.88 953.132,1406.88 953.141,1406.88 953.15,1406.88 953.159,1406.88 953.169,1406.88 953.178,1406.88 953.187,1406.88 953.196,1406.88 953.205,1406.88 953.215,1406.88 953.224,1406.88 953.233,1406.88 953.242,1406.88 953.251,1406.88 953.26,1406.88 953.27,1406.88 953.279,1406.88 953.288,1406.88 953.297,1406.88 953.306,1406.88 953.316,1406.88 953.325,1406.88 953.334,1406.88 953.343,1406.88 953.352,1406.88 953.362,1406.88 953.371,1406.88 953.38,1406.88 953.389,1406.88 953.398,1406.88 953.407,1406.88 953.417,1406.88 953.426,1406.88 953.435,1406.88 953.444,1406.88 953.453,1406.88 953.463,1406.88 953.472,1406.88 953.481,1406.88 953.49,1406.88 953.499,1406.88 953.509,1406.88 953.518,1406.88 953.527,1406.88 953.536,1406.88 953.545,1406.88 953.555,1406.88 953.564,1406.88 953.573,1406.88 953.582,1406.88 953.591,1406.88 953.6,1406.88 953.61,1406.88 953.619,1406.88 953.628,1406.88 953.637,1406.88 953.646,1406.88 953.656,1406.88 953.665,1406.88 953.674,1406.88 953.683,1406.88 953.692,1406.88 953.702,1406.88 953.711,1406.88 953.72,1406.88 953.729,1406.88 953.738,1406.88 953.747,1406.88 953.757,1406.88 953.766,1406.88 953.775,1406.88 953.784,1406.88 953.793,1406.88 953.803,1406.88 953.812,1406.88 953.821,1406.88 953.83,1406.88 953.839,1406.88 953.849,1406.88 953.858,1406.88 953.867,1406.88 953.876,1406.88 953.885,1406.88 953.895,1406.88 953.904,1406.88 953.913,1406.88 953.922,1406.88 953.931,1406.88 953.94,1406.88 953.95,1406.88 953.959,1406.88 953.968,1406.88 953.977,1406.88 953.986,1406.88 953.996,1406.88 954.005,1406.88 954.014,1406.88 954.023,1406.88 954.032,1406.88 954.042,1406.88 954.051,1406.88 954.06,1406.88 954.069,1406.88 954.078,1406.88 954.087,1406.88 954.097,1406.88 954.106,1406.88 954.115,1406.88 954.124,1406.88 954.133,1406.88 954.143,1406.88 954.152,1406.88 954.161,1406.88 954.17,1406.88 954.179,1406.88 954.189,1406.88 954.198,1406.88 954.207,1406.88 954.216,1406.88 954.225,1406.88 954.235,1406.88 954.244,1406.88 954.253,1406.88 954.262,1406.88 954.271,1406.88 954.28,1406.88 954.29,1406.88 954.299,1406.88 954.308,1406.88 954.317,1406.88 954.326,1406.88 954.336,1406.88 954.345,1406.88 954.354,1406.88 954.363,1406.88 954.372,1406.88 954.382,1406.88 954.391,1406.88 954.4,1406.88 954.409,1406.88 954.418,1406.88 954.427,1406.88 954.437,1406.88 954.446,1406.88 954.455,1406.88 954.464,1406.88 954.473,1406.88 954.483,1406.88 954.492,1406.88 954.501,1406.88 954.51,1406.88 954.519,1406.88 954.529,1406.88 954.538,1406.88 954.547,1406.88 954.556,1406.88 954.565,1406.88 954.575,1406.88 954.584,1406.88 954.593,1406.88 954.602,1406.88 954.611,1406.88 954.62,1406.88 954.63,1406.88 954.639,1406.88 954.648,1406.88 954.657,1406.88 954.666,1406.88 954.676,1406.88 954.685,1406.88 954.694,1406.88 954.703,1406.88 954.712,1406.88 954.722,1406.88 954.731,1406.88 954.74,1406.88 954.749,1406.88 954.758,1406.88 954.767,1406.88 954.777,1406.88 954.786,1406.88 954.795,1406.88 954.804,1406.88 954.813,1406.88 954.823,1406.88 954.832,1406.88 954.841,1406.88 954.85,1406.88 954.859,1406.88 954.869,1406.88 954.878,1406.88 954.887,1406.88 954.896,1406.88 954.905,1406.88 954.915,1406.88 954.924,1406.88 954.933,1406.88 954.942,1406.88 954.951,1406.88 954.96,1406.88 954.97,1406.88 954.979,1406.88 954.988,1406.88 954.997,1406.88 955.006,1406.88 955.016,1406.88 955.025,1406.88 955.034,1406.88 955.043,1406.88 955.052,1406.88 955.062,1406.88 955.071,1406.88 955.08,1406.88 955.089,1406.88 955.098,1406.88 955.108,1406.88 955.117,1406.88 955.126,1406.88 955.135,1406.88 955.144,1406.88 955.153,1406.88 955.163,1406.88 955.172,1406.88 955.181,1406.88 955.19,1406.88 955.199,1406.88 955.209,1406.88 955.218,1406.88 955.227,1406.88 955.236,1406.88 955.245,1406.88 955.255,1406.88 955.264,1406.88 955.273,1406.88 955.282,1406.88 955.291,1406.88 955.3,1406.88 955.31,1406.88 955.319,1406.88 955.328,1406.88 955.337,1406.88 955.346,1406.88 955.356,1406.88 955.365,1406.88 955.374,1406.88 955.383,1406.88 955.392,1406.88 955.402,1406.88 955.411,1406.88 955.42,1406.88 955.429,1406.88 955.438,1406.88 955.448,1406.88 955.457,1406.88 955.466,1406.88 955.475,1406.88 955.484,1406.88 955.493,1406.88 955.503,1406.88 955.512,1406.88 955.521,1406.88 955.53,1406.88 955.539,1406.88 955.549,1406.88 955.558,1406.88 955.567,1406.88 955.576,1406.88 955.585,1406.88 955.595,1406.88 955.604,1406.88 955.613,1406.88 955.622,1406.88 955.631,1406.88 955.64,1406.88 955.65,1406.88 955.659,1406.88 955.668,1406.88 955.677,1406.88 955.686,1406.88 955.696,1406.88 955.705,1406.88 955.714,1406.88 955.723,1406.88 955.732,1406.88 955.742,1406.88 955.751,1406.88 955.76,1406.88 955.769,1406.88 955.778,1406.88 955.788,1406.88 955.797,1406.88 955.806,1406.88 955.815,1406.88 955.824,1406.88 955.833,1406.88 955.843,1406.88 955.852,1406.88 955.861,1406.88 955.87,1406.88 955.879,1406.88 955.889,1406.88 955.898,1406.88 955.907,1406.88 955.916,1406.88 955.925,1406.88 955.935,1406.88 955.944,1406.88 955.953,1406.88 955.962,1406.88 955.971,1406.88 955.98,1406.88 955.99,1406.88 955.999,1406.88 956.008,1406.88 956.017,1406.88 956.026,1406.88 956.036,1406.88 956.045,1406.88 956.054,1406.88 956.063,1406.88 956.072,1406.88 956.082,1406.88 956.091,1406.88 956.1,1406.88 956.109,1406.88 956.118,1406.88 956.128,1406.88 956.137,1406.88 956.146,1406.88 956.155,1406.88 956.164,1406.88 956.173,1406.88 956.183,1406.88 956.192,1406.88 956.201,1406.88 956.21,1406.88 956.219,1406.88 956.229,1406.88 956.238,1406.88 956.247,1406.88 956.256,1406.88 956.265,1406.88 956.275,1406.88 956.284,1406.88 956.293,1406.88 956.302,1406.88 956.311,1406.88 956.32,1406.88 956.33,1406.88 956.339,1406.88 956.348,1406.88 956.357,1406.88 956.366,1406.88 956.376,1406.88 956.385,1406.88 956.394,1406.88 956.403,1406.88 956.412,1406.88 956.422,1406.88 956.431,1406.88 956.44,1406.88 956.449,1406.88 956.458,1406.88 956.468,1406.88 956.477,1406.88 956.486,1406.88 956.495,1406.88 956.504,1406.88 956.513,1406.88 956.523,1406.88 956.532,1406.88 956.541,1406.88 956.55,1406.88 956.559,1406.88 956.569,1406.88 956.578,1406.88 956.587,1406.88 956.596,1406.88 956.605,1406.88 956.615,1406.88 956.624,1406.88 956.633,1406.88 956.642,1406.88 956.651,1406.88 956.66,1406.88 956.67,1406.88 956.679,1406.88 956.688,1406.88 956.697,1406.88 956.706,1406.88 956.716,1406.88 956.725,1406.88 956.734,1406.88 956.743,1406.88 956.752,1406.88 956.762,1406.88 956.771,1406.88 956.78,1406.88 956.789,1406.88 956.798,1406.88 956.808,1406.88 956.817,1406.88 956.826,1406.88 956.835,1406.88 956.844,1406.88 956.853,1406.88 956.863,1406.88 956.872,1406.88 956.881,1406.88 956.89,1406.88 956.899,1406.88 956.909,1406.88 956.918,1406.88 956.927,1406.88 956.936,1406.88 956.945,1406.88 956.955,1406.88 956.964,1406.88 956.973,1406.88 956.982,1406.88 956.991,1406.88 957,1406.88 957.01,1406.88 957.019,1406.88 957.028,1406.88 957.037,1406.88 957.046,1406.88 957.056,1406.88 957.065,1406.88 957.074,1406.88 957.083,1406.88 957.092,1406.88 957.102,1406.88 957.111,1406.88 957.12,1406.88 957.129,1406.88 957.138,1406.88 957.148,1406.88 957.157,1406.88 957.166,1406.88 957.175,1406.88 957.184,1406.88 957.193,1406.88 957.203,1406.88 957.212,1406.88 957.221,1406.88 957.23,1406.88 957.239,1406.88 957.249,1406.88 957.258,1406.88 957.267,1406.88 957.276,1406.88 957.285,1406.88 957.295,1406.88 957.304,1406.88 957.313,1406.88 957.322,1406.88 957.331,1406.88 957.34,1406.88 957.35,1406.88 957.359,1406.88 957.368,1406.88 957.377,1406.88 957.386,1406.88 957.396,1406.88 957.405,1406.88 957.414,1406.88 957.423,1406.88 957.432,1406.88 957.442,1406.88 957.451,1406.88 957.46,1406.88 957.469,1406.88 957.478,1406.88 957.488,1406.88 957.497,1406.88 957.506,1406.88 957.515,1406.88 957.524,1406.88 957.533,1406.88 957.543,1406.88 957.552,1406.88 957.561,1406.88 957.57,1406.88 957.579,1406.88 957.589,1406.88 957.598,1406.88 957.607,1406.88 957.616,1406.88 957.625,1406.88 957.635,1406.88 957.644,1406.88 957.653,1406.88 957.662,1406.88 957.671,1406.88 957.681,1406.88 957.69,1406.88 957.699,1406.88 957.708,1406.88 957.717,1406.88 957.726,1406.88 957.736,1406.88 957.745,1406.88 957.754,1406.88 957.763,1406.88 957.772,1406.88 957.782,1406.88 957.791,1406.88 957.8,1406.88 957.809,1406.88 957.818,1406.88 957.828,1406.88 957.837,1406.88 957.846,1406.88 957.855,1406.88 957.864,1406.88 957.873,1406.88 957.883,1406.88 957.892,1406.88 957.901,1406.88 957.91,1406.88 957.919,1406.88 957.929,1406.88 957.938,1406.88 957.947,1406.88 957.956,1406.88 957.965,1406.88 957.975,1406.88 957.984,1406.88 957.993,1406.88 958.002,1406.88 958.011,1406.88 958.021,1406.88 958.03,1406.88 958.039,1406.88 958.048,1406.88 958.057,1406.88 958.066,1406.88 958.076,1406.88 958.085,1406.88 958.094,1406.88 958.103,1406.88 958.112,1406.88 958.122,1406.88 958.131,1406.88 958.14,1406.88 958.149,1406.88 958.158,1406.88 958.168,1406.88 958.177,1406.88 958.186,1406.88 958.195,1406.88 958.204,1406.88 958.213,1406.88 958.223,1406.88 958.232,1406.88 958.241,1406.88 958.25,1406.88 958.259,1406.88 958.269,1406.88 958.278,1406.88 958.287,1406.88 958.296,1406.88 958.305,1406.88 958.315,1406.88 958.324,1406.88 958.333,1406.88 958.342,1406.88 958.351,1406.88 958.361,1406.88 958.37,1406.88 958.379,1406.88 958.388,1406.88 958.397,1406.88 958.406,1406.88 958.416,1406.88 958.425,1406.88 958.434,1406.88 958.443,1406.88 958.452,1406.88 958.462,1406.88 958.471,1406.88 958.48,1406.88 958.489,1406.88 958.498,1406.88 958.508,1406.88 958.517,1406.88 958.526,1406.88 958.535,1406.88 958.544,1406.88 958.553,1406.88 958.563,1406.88 958.572,1406.88 958.581,1406.88 958.59,1406.88 958.599,1406.88 958.609,1406.88 958.618,1406.88 958.627,1406.88 958.636,1406.88 958.645,1406.88 958.655,1406.88 958.664,1406.88 958.673,1406.88 958.682,1406.88 958.691,1406.88 958.701,1406.88 958.71,1406.88 958.719,1406.88 958.728,1406.88 958.737,1406.88 958.746,1406.88 958.756,1406.88 958.765,1406.88 958.774,1406.88 958.783,1406.88 958.792,1406.88 958.802,1406.88 958.811,1406.88 958.82,1406.88 958.829,1406.88 958.838,1406.88 958.848,1406.88 958.857,1406.88 958.866,1406.88 958.875,1406.88 958.884,1406.88 958.893,1406.88 958.903,1406.88 958.912,1406.88 958.921,1406.88 958.93,1406.88 958.939,1406.88 958.949,1406.88 958.958,1406.88 958.967,1406.88 958.976,1406.88 958.985,1406.88 958.995,1406.88 959.004,1406.88 959.013,1406.88 959.022,1406.88 959.031,1406.88 959.041,1406.88 959.05,1406.88 959.059,1406.88 959.068,1406.88 959.077,1406.88 959.086,1406.88 959.096,1406.88 959.105,1406.88 959.114,1406.88 959.123,1406.88 959.132,1406.88 959.142,1406.88 959.151,1406.88 959.16,1406.88 959.169,1406.88 959.178,1406.88 959.188,1406.88 959.197,1406.88 959.206,1406.88 959.215,1406.88 959.224,1406.88 959.233,1406.88 959.243,1406.88 959.252,1406.88 959.261,1406.88 959.27,1406.88 959.279,1406.88 959.289,1406.88 959.298,1406.88 959.307,1406.88 959.316,1406.88 959.325,1406.88 959.335,1406.88 959.344,1406.88 959.353,1406.88 959.362,1406.88 959.371,1406.88 959.381,1406.88 959.39,1406.88 959.399,1406.88 959.408,1406.88 959.417,1406.88 959.426,1406.88 959.436,1406.88 959.445,1406.88 959.454,1406.88 959.463,1406.88 959.472,1406.88 959.482,1406.88 959.491,1406.88 959.5,1406.88 959.509,1406.88 959.518,1406.88 959.528,1406.88 959.537,1406.88 959.546,1406.88 959.555,1406.88 959.564,1406.88 959.573,1406.88 959.583,1406.88 959.592,1406.88 959.601,1406.88 959.61,1406.88 959.619,1406.88 959.629,1406.88 959.638,1406.88 959.647,1406.88 959.656,1406.88 959.665,1406.88 959.675,1406.88 959.684,1406.88 959.693,1406.88 959.702,1406.88 959.711,1406.88 959.721,1406.88 959.73,1406.88 959.739,1406.88 959.748,1406.88 959.757,1406.88 959.766,1406.88 959.776,1406.88 959.785,1406.88 959.794,1406.88 959.803,1406.88 959.812,1406.88 959.822,1406.88 959.831,1406.88 959.84,1406.88 959.849,1406.88 959.858,1406.88 959.868,1406.88 959.877,1406.88 959.886,1406.88 959.895,1406.88 959.904,1406.88 959.913,1406.88 959.923,1406.88 959.932,1406.88 959.941,1406.88 959.95,1406.88 959.959,1406.88 959.969,1406.88 959.978,1406.88 959.987,1406.88 959.996,1406.88 960.005,1406.88 960.015,1406.88 960.024,1406.88 960.033,1406.88 960.042,1406.88 960.051,1406.88 960.061,1406.88 960.07,1406.88 960.079,1406.88 960.088,1406.88 960.097,1406.88 960.106,1406.88 960.116,1406.88 960.125,1406.88 960.134,1406.88 960.143,1406.88 960.152,1406.88 960.162,1406.88 960.171,1406.88 960.18,1406.88 960.189,1406.88 960.198,1406.88 960.208,1406.88 960.217,1406.88 960.226,1406.88 960.235,1406.88 960.244,1406.88 960.254,1406.88 960.263,1406.88 960.272,1406.88 960.281,1406.88 960.29,1406.88 960.299,1406.88 960.309,1406.88 960.318,1406.88 960.327,1406.88 960.336,1406.88 960.345,1406.88 960.355,1406.88 960.364,1406.88 960.373,1406.88 960.382,1406.88 960.391,1406.88 960.401,1406.88 960.41,1406.88 960.419,1406.88 960.428,1406.88 960.437,1406.88 960.446,1406.88 960.456,1406.88 960.465,1406.88 960.474,1406.88 960.483,1406.88 960.492,1406.88 960.502,1406.88 960.511,1406.88 960.52,1406.88 960.529,1406.88 960.538,1406.88 960.548,1406.88 960.557,1406.88 960.566,1406.88 960.575,1406.88 960.584,1406.88 960.594,1406.88 960.603,1406.88 960.612,1406.88 960.621,1406.88 960.63,1406.88 960.639,1406.88 960.649,1406.88 960.658,1406.88 960.667,1406.88 960.676,1406.88 960.685,1406.88 960.695,1406.88 960.704,1406.88 960.713,1406.88 960.722,1406.88 960.731,1406.88 960.741,1406.88 960.75,1406.88 960.759,1406.88 960.768,1406.88 960.777,1406.88 960.786,1406.88 960.796,1406.88 960.805,1406.88 960.814,1406.88 960.823,1406.88 960.832,1406.88 960.842,1406.88 960.851,1406.88 960.86,1406.88 960.869,1406.88 960.878,1406.88 960.888,1406.88 960.897,1406.88 960.906,1406.88 960.915,1406.88 960.924,1406.88 960.934,1406.88 960.943,1406.88 960.952,1406.88 960.961,1406.88 960.97,1406.88 960.979,1406.88 960.989,1406.88 960.998,1406.88 961.007,1406.88 961.016,1406.88 961.025,1406.88 961.035,1406.88 961.044,1406.88 961.053,1406.88 961.062,1406.88 961.071,1406.88 961.081,1406.88 961.09,1406.88 961.099,1406.88 961.108,1406.88 961.117,1406.88 961.126,1406.88 961.136,1406.88 961.145,1406.88 961.154,1406.88 961.163,1406.88 961.172,1406.88 961.182,1406.88 961.191,1406.88 961.2,1406.88 961.209,1406.88 961.218,1406.88 961.228,1406.88 961.237,1406.88 961.246,1406.88 961.255,1406.88 961.264,1406.88 961.274,1406.88 961.283,1406.88 961.292,1406.88 961.301,1406.88 961.31,1406.88 961.319,1406.88 961.329,1406.88 961.338,1406.88 961.347,1406.88 961.356,1406.88 961.365,1406.88 961.375,1406.88 961.384,1406.88 961.393,1406.88 961.402,1406.88 961.411,1406.88 961.421,1406.88 961.43,1406.88 961.439,1406.88 961.448,1406.88 961.457,1406.88 961.466,1406.88 961.476,1406.88 961.485,1406.88 961.494,1406.88 961.503,1406.88 961.512,1406.88 961.522,1406.88 961.531,1406.88 961.54,1406.88 961.549,1406.88 961.558,1406.88 961.568,1406.88 961.577,1406.88 961.586,1406.88 961.595,1406.88 961.604,1406.88 961.614,1406.88 961.623,1406.88 961.632,1406.88 961.641,1406.88 961.65,1406.88 961.659,1406.88 961.669,1406.88 961.678,1406.88 961.687,1406.88 961.696,1406.88 961.705,1406.88 961.715,1406.88 961.724,1406.88 961.733,1406.88 961.742,1406.88 961.751,1406.88 961.761,1406.88 961.77,1406.88 961.779,1406.88 961.788,1406.88 961.797,1406.88 961.806,1406.88 961.816,1406.88 961.825,1406.88 961.834,1406.88 961.843,1406.88 961.852,1406.88 961.862,1406.88 961.871,1406.88 961.88,1406.88 961.889,1406.88 961.898,1406.88 961.908,1406.88 961.917,1406.88 961.926,1406.88 961.935,1406.88 961.944,1406.88 961.954,1406.88 961.963,1406.88 961.972,1406.88 961.981,1406.88 961.99,1406.88 961.999,1406.88 962.009,1406.88 962.018,1406.88 962.027,1406.88 962.036,1406.88 962.045,1406.88 962.055,1406.88 962.064,1406.88 962.073,1406.88 962.082,1406.88 962.091,1406.88 962.101,1406.88 962.11,1406.88 962.119,1406.88 962.128,1406.88 962.137,1406.88 962.146,1406.88 962.156,1406.88 962.165,1406.88 962.174,1406.88 962.183,1406.88 962.192,1406.88 962.202,1406.88 962.211,1406.88 962.22,1406.88 962.229,1406.88 962.238,1406.88 962.248,1406.88 962.257,1406.88 962.266,1406.88 962.275,1406.88 962.284,1406.88 962.294,1406.88 962.303,1406.88 962.312,1406.88 962.321,1406.88 962.33,1406.88 962.339,1406.88 962.349,1406.88 962.358,1406.88 962.367,1406.88 962.376,1406.88 962.385,1406.88 962.395,1406.88 962.404,1406.88 962.413,1406.88 962.422,1406.88 962.431,1406.88 962.441,1406.88 962.45,1406.88 962.459,1406.88 962.468,1406.88 962.477,1406.88 962.487,1406.88 962.496,1406.88 962.505,1406.88 962.514,1406.88 962.523,1406.88 962.532,1406.88 962.542,1406.88 962.551,1406.88 962.56,1406.88 962.569,1406.88 962.578,1406.88 962.588,1406.88 962.597,1406.88 962.606,1406.88 962.615,1406.88 962.624,1406.88 962.634,1406.88 962.643,1406.88 962.652,1406.88 962.661,1406.88 962.67,1406.88 962.679,1406.88 962.689,1406.88 962.698,1406.88 962.707,1406.88 962.716,1406.88 962.725,1406.88 962.735,1406.88 962.744,1406.88 962.753,1406.88 962.762,1406.88 962.771,1406.88 962.781,1406.88 962.79,1406.88 962.799,1406.88 962.808,1406.88 962.817,1406.88 962.827,1406.88 962.836,1406.88 962.845,1406.88 962.854,1406.88 962.863,1406.88 962.872,1406.88 962.882,1406.88 962.891,1406.88 962.9,1406.88 962.909,1406.88 962.918,1406.88 962.928,1406.88 962.937,1406.88 962.946,1406.88 962.955,1406.88 962.964,1406.88 962.974,1406.88 962.983,1406.88 962.992,1406.88 963.001,1406.88 963.01,1406.88 963.019,1406.88 963.029,1406.88 963.038,1406.88 963.047,1406.88 963.056,1406.88 963.065,1406.88 963.075,1406.88 963.084,1406.88 963.093,1406.88 963.102,1406.88 963.111,1406.88 963.121,1406.88 963.13,1406.88 963.139,1406.88 963.148,1406.88 963.157,1406.88 963.167,1406.88 963.176,1406.88 963.185,1406.88 963.194,1406.88 963.203,1406.88 963.212,1406.88 963.222,1406.88 963.231,1406.88 963.24,1406.88 963.249,1406.88 963.258,1406.88 963.268,1406.88 963.277,1406.88 963.286,1406.88 963.295,1406.88 963.304,1406.88 963.314,1406.88 963.323,1406.88 963.332,1406.88 963.341,1406.88 963.35,1406.88 963.359,1406.88 963.369,1406.88 963.378,1406.88 963.387,1406.88 963.396,1406.88 963.405,1406.88 963.415,1406.88 963.424,1406.88 963.433,1406.88 963.442,1406.88 963.451,1406.88 963.461,1406.88 963.47,1406.88 963.479,1406.88 963.488,1406.88 963.497,1406.88 963.507,1406.88 963.516,1406.88 963.525,1406.88 963.534,1406.88 963.543,1406.88 963.552,1406.88 963.562,1406.88 963.571,1406.88 963.58,1406.88 963.589,1406.88 963.598,1406.88 963.608,1406.88 963.617,1406.88 963.626,1406.88 963.635,1406.88 963.644,1406.88 963.654,1406.88 963.663,1406.88 963.672,1406.88 963.681,1406.88 963.69,1406.88 963.699,1406.88 963.709,1406.88 963.718,1406.88 963.727,1406.88 963.736,1406.88 963.745,1406.88 963.755,1406.88 963.764,1406.88 963.773,1406.88 963.782,1406.88 963.791,1406.88 963.801,1406.88 963.81,1406.88 963.819,1406.88 963.828,1406.88 963.837,1406.88 963.847,1406.88 963.856,1406.88 963.865,1406.88 963.874,1406.88 963.883,1406.88 963.892,1406.88 963.902,1406.88 963.911,1406.88 963.92,1406.88 963.929,1406.88 963.938,1406.88 963.948,1406.88 963.957,1406.88 963.966,1406.88 963.975,1406.88 963.984,1406.88 963.994,1406.88 964.003,1406.88 964.012,1406.88 964.021,1406.88 964.03,1406.88 964.039,1406.88 964.049,1406.88 964.058,1406.88 964.067,1406.88 964.076,1406.88 964.085,1406.88 964.095,1406.88 964.104,1406.88 964.113,1406.88 964.122,1406.88 964.131,1406.88 964.141,1406.88 964.15,1406.88 964.159,1406.88 964.168,1406.88 964.177,1406.88 964.187,1406.88 964.196,1406.88 964.205,1406.88 964.214,1406.88 964.223,1406.88 964.232,1406.88 964.242,1406.88 964.251,1406.88 964.26,1406.88 964.269,1406.88 964.278,1406.88 964.288,1406.88 964.297,1406.88 964.306,1406.88 964.315,1406.88 964.324,1406.88 964.334,1406.88 964.343,1406.88 964.352,1406.88 964.361,1406.88 964.37,1406.88 964.379,1406.88 964.389,1406.88 964.398,1406.88 964.407,1406.88 964.416,1406.88 964.425,1406.88 964.435,1406.88 964.444,1406.88 964.453,1406.88 964.462,1406.88 964.471,1406.88 964.481,1406.88 964.49,1406.88 964.499,1406.88 964.508,1406.88 964.517,1406.88 964.527,1406.88 964.536,1406.88 964.545,1406.88 964.554,1406.88 964.563,1406.88 964.572,1406.88 964.582,1406.88 964.591,1406.88 964.6,1406.88 964.609,1406.88 964.618,1406.88 964.628,1406.88 964.637,1406.88 964.646,1406.88 964.655,1406.88 964.664,1406.88 964.674,1406.88 964.683,1406.88 964.692,1406.88 964.701,1406.88 964.71,1406.88 964.719,1406.88 964.729,1406.88 964.738,1406.88 964.747,1406.88 964.756,1406.88 964.765,1406.88 964.775,1406.88 964.784,1406.88 964.793,1406.88 964.802,1406.88 964.811,1406.88 964.821,1406.88 964.83,1406.88 964.839,1406.88 964.848,1406.88 964.857,1406.88 964.867,1406.88 964.876,1406.88 964.885,1406.88 964.894,1406.88 964.903,1406.88 964.912,1406.88 964.922,1406.88 964.931,1406.88 964.94,1406.88 964.949,1406.88 964.958,1406.88 964.968,1406.88 964.977,1406.88 964.986,1406.88 964.995,1406.88 965.004,1406.88 965.014,1406.88 965.023,1406.88 965.032,1406.88 965.041,1406.88 965.05,1406.88 965.06,1406.88 965.069,1406.88 965.078,1406.88 965.087,1406.88 965.096,1406.88 965.105,1406.88 965.115,1406.88 965.124,1406.88 965.133,1406.88 965.142,1406.88 965.151,1406.88 965.161,1406.88 965.17,1406.88 965.179,1406.88 965.188,1406.88 965.197,1406.88 965.207,1406.88 965.216,1406.88 965.225,1406.88 965.234,1406.88 965.243,1406.88 965.252,1406.88 965.262,1406.88 965.271,1406.88 965.28,1406.88 965.289,1406.88 965.298,1406.88 965.308,1406.88 965.317,1406.88 965.326,1406.88 965.335,1406.88 965.344,1406.88 965.354,1406.88 965.363,1406.88 965.372,1406.88 965.381,1406.88 965.39,1406.88 965.4,1406.88 965.409,1406.88 965.418,1406.88 965.427,1406.88 965.436,1406.88 965.445,1406.88 965.455,1406.88 965.464,1406.88 965.473,1406.88 965.482,1406.88 965.491,1406.88 965.501,1406.88 965.51,1406.88 965.519,1406.88 965.528,1406.88 965.537,1406.88 965.547,1406.88 965.556,1406.88 965.565,1406.88 965.574,1406.88 965.583,1406.88 965.592,1406.88 965.602,1406.88 965.611,1406.88 965.62,1406.88 965.629,1406.88 965.638,1406.88 965.648,1406.88 965.657,1406.88 965.666,1406.88 965.675,1406.88 965.684,1406.88 965.694,1406.88 965.703,1406.88 965.712,1406.88 965.721,1406.88 965.73,1406.88 965.74,1406.88 965.749,1406.88 965.758,1406.88 965.767,1406.88 965.776,1406.88 965.785,1406.88 965.795,1406.88 965.804,1406.88 965.813,1406.88 965.822,1406.88 965.831,1406.88 965.841,1406.88 965.85,1406.88 965.859,1406.88 965.868,1406.88 965.877,1406.88 965.887,1406.88 965.896,1406.88 965.905,1406.88 965.914,1406.88 965.923,1406.88 965.932,1406.88 965.942,1406.88 965.951,1406.88 965.96,1406.88 965.969,1406.88 965.978,1406.88 965.988,1406.88 965.997,1406.88 966.006,1406.88 966.015,1406.88 966.024,1406.88 966.034,1406.88 966.043,1406.88 966.052,1406.88 966.061,1406.88 966.07,1406.88 966.08,1406.88 966.089,1406.88 966.098,1406.88 966.107,1406.88 966.116,1406.88 966.125,1406.88 966.135,1406.88 966.144,1406.88 966.153,1406.88 966.162,1406.88 966.171,1406.88 966.181,1406.88 966.19,1406.88 966.199,1406.88 966.208,1406.88 966.217,1406.88 966.227,1406.88 966.236,1406.88 966.245,1406.88 966.254,1406.88 966.263,1406.88 966.272,1406.88 966.282,1406.88 966.291,1406.88 966.3,1406.88 966.309,1406.88 966.318,1406.88 966.328,1406.88 966.337,1406.88 966.346,1406.88 966.355,1406.88 966.364,1406.88 966.374,1406.88 966.383,1406.88 966.392,1406.88 966.401,1406.88 966.41,1406.88 966.42,1406.88 966.429,1406.88 966.438,1406.88 966.447,1406.88 966.456,1406.88 966.465,1406.88 966.475,1406.88 966.484,1406.88 966.493,1406.88 966.502,1406.88 966.511,1406.88 966.521,1406.88 966.53,1406.88 966.539,1406.88 966.548,1406.88 966.557,1406.88 966.567,1406.88 966.576,1406.88 966.585,1406.88 966.594,1406.88 966.603,1406.88 966.612,1406.88 966.622,1406.88 966.631,1406.88 966.64,1406.88 966.649,1406.88 966.658,1406.88 966.668,1406.88 966.677,1406.88 966.686,1406.88 966.695,1406.88 966.704,1406.88 966.714,1406.88 966.723,1406.88 966.732,1406.88 966.741,1406.88 966.75,1406.88 966.76,1406.88 966.769,1406.88 966.778,1406.88 966.787,1406.88 966.796,1406.88 966.805,1406.88 966.815,1406.88 966.824,1406.88 966.833,1406.88 966.842,1406.88 966.851,1406.88 966.861,1406.88 966.87,1406.88 966.879,1406.88 966.888,1406.88 966.897,1406.88 966.907,1406.88 966.916,1406.88 966.925,1406.88 966.934,1406.88 966.943,1406.88 966.952,1406.88 966.962,1406.88 966.971,1406.88 966.98,1406.88 966.989,1406.88 966.998,1406.88 967.008,1406.88 967.017,1406.88 967.026,1406.88 967.035,1406.88 967.044,1406.88 967.054,1406.88 967.063,1406.88 967.072,1406.88 967.081,1406.88 967.09,1406.88 967.1,1406.88 967.109,1406.88 967.118,1406.88 967.127,1406.88 967.136,1406.88 967.145,1406.88 967.155,1406.88 967.164,1406.88 967.173,1406.88 967.182,1406.88 967.191,1406.88 967.201,1406.88 967.21,1406.88 967.219,1406.88 967.228,1406.88 967.237,1406.88 967.247,1406.88 967.256,1406.88 967.265,1406.88 967.274,1406.88 967.283,1406.88 967.292,1406.88 967.302,1406.88 967.311,1406.88 967.32,1406.88 967.329,1406.88 967.338,1406.88 967.348,1406.88 967.357,1406.88 967.366,1406.88 967.375,1406.88 967.384,1406.88 967.394,1406.88 967.403,1406.88 967.412,1406.88 967.421,1406.88 967.43,1406.88 967.44,1406.88 967.449,1406.88 967.458,1406.88 967.467,1406.88 967.476,1406.88 967.485,1406.88 967.495,1406.88 967.504,1406.88 967.513,1406.88 967.522,1406.88 967.531,1406.88 967.541,1406.88 967.55,1406.88 967.559,1406.88 967.568,1406.88 967.577,1406.88 967.587,1406.88 967.596,1406.88 967.605,1406.88 967.614,1406.88 967.623,1406.88 967.633,1406.88 967.642,1406.88 967.651,1406.88 967.66,1406.88 967.669,1406.88 967.678,1406.88 967.688,1406.88 967.697,1406.88 967.706,1406.88 967.715,1406.88 967.724,1406.88 967.734,1406.88 967.743,1406.88 967.752,1406.88 967.761,1406.88 967.77,1406.88 967.78,1406.88 967.789,1406.88 967.798,1406.88 967.807,1406.88 967.816,1406.88 967.825,1406.88 967.835,1406.88 967.844,1406.88 967.853,1406.88 967.862,1406.88 967.871,1406.88 967.881,1406.88 967.89,1406.88 967.899,1406.88 967.908,1406.88 967.917,1406.88 967.927,1406.88 967.936,1406.88 967.945,1406.88 967.954,1406.88 967.963,1406.88 967.973,1406.88 967.982,1406.88 967.991,1406.88 968,1406.88 968.009,1406.88 968.018,1406.88 968.028,1406.88 968.037,1406.88 968.046,1406.88 968.055,1406.88 968.064,1406.88 968.074,1406.88 968.083,1406.88 968.092,1406.88 968.101,1406.88 968.11,1406.88 968.12,1406.88 968.129,1406.88 968.138,1406.88 968.147,1406.88 968.156,1406.88 968.165,1406.88 968.175,1406.88 968.184,1406.88 968.193,1406.88 968.202,1406.88 968.211,1406.88 968.221,1406.88 968.23,1406.88 968.239,1406.88 968.248,1406.88 968.257,1406.88 968.267,1406.88 968.276,1406.88 968.285,1406.88 968.294,1406.88 968.303,1406.88 968.313,1406.88 968.322,1406.88 968.331,1406.88 968.34,1406.88 968.349,1406.88 968.358,1406.88 968.368,1406.88 968.377,1406.88 968.386,1406.88 968.395,1406.88 968.404,1406.88 968.414,1406.88 968.423,1406.88 968.432,1406.88 968.441,1406.88 968.45,1406.88 968.46,1406.88 968.469,1406.88 968.478,1406.88 968.487,1406.88 968.496,1406.88 968.505,1406.88 968.515,1406.88 968.524,1406.88 968.533,1406.88 968.542,1406.88 968.551,1406.88 968.561,1406.88 968.57,1406.88 968.579,1406.88 968.588,1406.88 968.597,1406.88 968.607,1406.88 968.616,1406.88 968.625,1406.88 968.634,1406.88 968.643,1406.88 968.653,1406.88 968.662,1406.88 968.671,1406.88 968.68,1406.88 968.689,1406.88 968.698,1406.88 968.708,1406.88 968.717,1406.88 968.726,1406.88 968.735,1406.88 968.744,1406.88 968.754,1406.88 968.763,1406.88 968.772,1406.88 968.781,1406.88 968.79,1406.88 968.8,1406.88 968.809,1406.88 968.818,1406.88 968.827,1406.88 968.836,1406.88 968.845,1406.88 968.855,1406.88 968.864,1406.88 968.873,1406.88 968.882,1406.88 968.891,1406.88 968.901,1406.88 968.91,1406.88 968.919,1406.88 968.928,1406.88 968.937,1406.88 968.947,1406.88 968.956,1406.88 968.965,1406.88 968.974,1406.88 968.983,1406.88 968.993,1406.88 969.002,1406.88 969.011,1406.88 969.02,1406.88 969.029,1406.88 969.038,1406.88 969.048,1406.88 969.057,1406.88 969.066,1406.88 969.075,1406.88 969.084,1406.88 969.094,1406.88 969.103,1406.88 969.112,1406.88 969.121,1406.88 969.13,1406.88 969.14,1406.88 969.149,1406.88 969.158,1406.88 969.167,1406.88 969.176,1406.88 969.185,1406.88 969.195,1406.88 969.204,1406.88 969.213,1406.88 969.222,1406.88 969.231,1406.88 969.241,1406.88 969.25,1406.88 969.259,1406.88 969.268,1406.88 969.277,1406.88 969.287,1406.88 969.296,1406.88 969.305,1406.88 969.314,1406.88 969.323,1406.88 969.333,1406.88 969.342,1406.88 969.351,1406.88 969.36,1406.88 969.369,1406.88 969.378,1406.88 969.388,1406.88 969.397,1406.88 969.406,1406.88 969.415,1406.88 969.424,1406.88 969.434,1406.88 969.443,1406.88 969.452,1406.88 969.461,1406.88 969.47,1406.88 969.48,1406.88 969.489,1406.88 969.498,1406.88 969.507,1406.88 969.516,1406.88 969.525,1406.88 969.535,1406.88 969.544,1406.88 969.553,1406.88 969.562,1406.88 969.571,1406.88 969.581,1406.88 969.59,1406.88 969.599,1406.88 969.608,1406.88 969.617,1406.88 969.627,1406.88 969.636,1406.88 969.645,1406.88 969.654,1406.88 969.663,1406.88 969.673,1406.88 969.682,1406.88 969.691,1406.88 969.7,1406.88 969.709,1406.88 969.718,1406.88 969.728,1406.88 969.737,1406.88 969.746,1406.88 969.755,1406.88 969.764,1406.88 969.774,1406.88 969.783,1406.88 969.792,1406.88 969.801,1406.88 969.81,1406.88 969.82,1406.88 969.829,1406.88 969.838,1406.88 969.847,1406.88 969.856,1406.88 969.866,1406.88 969.875,1406.88 969.884,1406.88 969.893,1406.88 969.902,1406.88 969.911,1406.88 969.921,1406.88 969.93,1406.88 969.939,1406.88 969.948,1406.88 969.957,1406.88 969.967,1406.88 969.976,1406.88 969.985,1406.88 969.994,1406.88 970.003,1406.88 970.013,1406.88 970.022,1406.88 970.031,1406.88 970.04,1406.88 970.049,1406.88 970.058,1406.88 970.068,1406.88 970.077,1406.88 970.086,1406.88 970.095,1406.88 970.104,1406.88 970.114,1406.88 970.123,1406.88 970.132,1406.88 970.141,1406.88 970.15,1406.88 970.16,1406.88 970.169,1406.88 970.178,1406.88 970.187,1406.88 970.196,1406.88 970.206,1406.88 970.215,1406.88 970.224,1406.88 970.233,1406.88 970.242,1406.88 970.251,1406.88 970.261,1406.88 970.27,1406.88 970.279,1406.88 970.288,1406.88 970.297,1406.88 970.307,1406.88 970.316,1406.88 970.325,1406.88 970.334,1406.88 970.343,1406.88 970.353,1406.88 970.362,1406.88 970.371,1406.88 970.38,1406.88 970.389,1406.88 970.398,1406.88 970.408,1406.88 970.417,1406.88 970.426,1406.88 970.435,1406.88 970.444,1406.88 970.454,1406.88 970.463,1406.88 970.472,1406.88 970.481,1406.88 970.49,1406.88 970.5,1406.88 970.509,1406.88 970.518,1406.88 970.527,1406.88 970.536,1406.88 970.546,1406.88 970.555,1406.88 970.564,1406.88 970.573,1406.88 970.582,1406.88 970.591,1406.88 970.601,1406.88 970.61,1406.88 970.619,1406.88 970.628,1406.88 970.637,1406.88 970.647,1406.88 970.656,1406.88 970.665,1406.88 970.674,1406.88 970.683,1406.88 970.693,1406.88 970.702,1406.88 970.711,1406.88 970.72,1406.88 970.729,1406.88 970.738,1406.88 970.748,1406.88 970.757,1406.88 970.766,1406.88 970.775,1406.88 970.784,1406.88 970.794,1406.88 970.803,1406.88 970.812,1406.88 970.821,1406.88 970.83,1406.88 970.84,1406.88 970.849,1406.88 970.858,1406.88 970.867,1406.88 970.876,1406.88 970.886,1406.88 970.895,1406.88 970.904,1406.88 970.913,1406.88 970.922,1406.88 970.931,1406.88 970.941,1406.88 970.95,1406.88 970.959,1406.88 970.968,1406.88 970.977,1406.88 970.987,1406.88 970.996,1406.88 971.005,1406.88 971.014,1406.88 971.023,1406.88 971.033,1406.88 971.042,1406.88 971.051,1406.88 971.06,1406.88 971.069,1406.88 971.078,1406.88 971.088,1406.88 971.097,1406.88 971.106,1406.88 971.115,1406.88 971.124,1406.88 971.134,1406.88 971.143,1406.88 971.152,1406.88 971.161,1406.88 971.17,1406.88 971.18,1406.88 971.189,1406.88 971.198,1406.88 971.207,1406.88 971.216,1406.88 971.226,1406.88 971.235,1406.88 971.244,1406.88 971.253,1406.88 971.262,1406.88 971.271,1406.88 971.281,1406.88 971.29,1406.88 971.299,1406.88 971.308,1406.88 971.317,1406.88 971.327,1406.88 971.336,1406.88 971.345,1406.88 971.354,1406.88 971.363,1406.88 971.373,1406.88 971.382,1406.88 971.391,1406.88 971.4,1406.88 971.409,1406.88 971.418,1406.88 971.428,1406.88 971.437,1406.88 971.446,1406.88 971.455,1406.88 971.464,1406.88 971.474,1406.88 971.483,1406.88 971.492,1406.88 971.501,1406.88 971.51,1406.88 971.52,1406.88 971.529,1406.88 971.538,1406.88 971.547,1406.88 971.556,1406.88 971.566,1406.88 971.575,1406.88 971.584,1406.88 971.593,1406.88 971.602,1406.88 971.611,1406.88 971.621,1406.88 971.63,1406.88 971.639,1406.88 971.648,1406.88 971.657,1406.88 971.667,1406.88 971.676,1406.88 971.685,1406.88 971.694,1406.88 971.703,1406.88 971.713,1406.88 971.722,1406.88 971.731,1406.88 971.74,1406.88 971.749,1406.88 971.758,1406.88 971.768,1406.88 971.777,1406.88 971.786,1406.88 971.795,1406.88 971.804,1406.88 971.814,1406.88 971.823,1406.88 971.832,1406.88 971.841,1406.88 971.85,1406.88 971.86,1406.88 971.869,1406.88 971.878,1406.88 971.887,1406.88 971.896,1406.88 971.906,1406.88 971.915,1406.88 971.924,1406.88 971.933,1406.88 971.942,1406.88 971.951,1406.88 971.961,1406.88 971.97,1406.88 971.979,1406.88 971.988,1406.88 971.997,1406.88 972.007,1406.88 972.016,1406.88 972.025,1406.88 972.034,1406.88 972.043,1406.88 972.053,1406.88 972.062,1406.88 972.071,1406.88 972.08,1406.88 972.089,1406.88 972.098,1406.88 972.108,1406.88 972.117,1406.88 972.126,1406.88 972.135,1406.88 972.144,1406.88 972.154,1406.88 972.163,1406.88 972.172,1406.88 972.181,1406.88 972.19,1406.88 972.2,1406.88 972.209,1406.88 972.218,1406.88 972.227,1406.88 972.236,1406.88 972.246,1406.88 972.255,1406.88 972.264,1406.88 972.273,1406.88 972.282,1406.88 972.291,1406.88 972.301,1406.88 972.31,1406.88 972.319,1406.88 972.328,1406.88 972.337,1406.88 972.347,1406.88 972.356,1406.88 972.365,1406.88 972.374,1406.88 972.383,1406.88 972.393,1406.88 972.402,1406.88 972.411,1406.88 972.42,1406.88 972.429,1406.88 972.439,1406.88 972.448,1406.88 972.457,1406.88 972.466,1406.88 972.475,1406.88 972.484,1406.88 972.494,1406.88 972.503,1406.88 972.512,1406.88 972.521,1406.88 972.53,1406.88 972.54,1406.88 972.549,1406.88 972.558,1406.88 972.567,1406.88 972.576,1406.88 972.586,1406.88 972.595,1406.88 972.604,1406.88 972.613,1406.88 972.622,1406.88 972.631,1406.88 972.641,1406.88 972.65,1406.88 972.659,1406.88 972.668,1406.88 972.677,1406.88 972.687,1406.88 972.696,1406.88 972.705,1406.88 972.714,1406.88 972.723,1406.88 972.733,1406.88 972.742,1406.88 972.751,1406.88 972.76,1406.88 972.769,1406.88 972.779,1406.88 972.788,1406.88 972.797,1406.88 972.806,1406.88 972.815,1406.88 972.824,1406.88 972.834,1406.88 972.843,1406.88 972.852,1406.88 972.861,1406.88 972.87,1406.88 972.88,1406.88 972.889,1406.88 972.898,1406.88 972.907,1406.88 972.916,1406.88 972.926,1406.88 972.935,1406.88 972.944,1406.88 972.953,1406.88 972.962,1406.88 972.971,1406.88 972.981,1406.88 972.99,1406.88 972.999,1406.88 973.008,1406.88 973.017,1406.88 973.027,1406.88 973.036,1406.88 973.045,1406.88 973.054,1406.88 973.063,1406.88 973.073,1406.88 973.082,1406.88 973.091,1406.88 973.1,1406.88 973.109,1406.88 973.119,1406.88 973.128,1406.88 973.137,1406.88 973.146,1406.88 973.155,1406.88 973.164,1406.88 973.174,1406.88 973.183,1406.88 973.192,1406.88 973.201,1406.88 973.21,1406.88 973.22,1406.88 973.229,1406.88 973.238,1406.88 973.247,1406.88 973.256,1406.88 973.266,1406.88 973.275,1406.88 973.284,1406.88 973.293,1406.88 973.302,1406.88 973.311,1406.88 973.321,1406.88 973.33,1406.88 973.339,1406.88 973.348,1406.88 973.357,1406.88 973.367,1406.88 973.376,1406.88 973.385,1406.88 973.394,1406.88 973.403,1406.88 973.413,1406.88 973.422,1406.88 973.431,1406.88 973.44,1406.88 973.449,1406.88 973.459,1406.88 973.468,1406.88 973.477,1406.88 973.486,1406.88 973.495,1406.88 973.504,1406.88 973.514,1406.88 973.523,1406.88 973.532,1406.88 973.541,1406.88 973.55,1406.88 973.56,1406.88 973.569,1406.88 973.578,1406.88 973.587,1406.88 973.596,1406.88 973.606,1406.88 973.615,1406.88 973.624,1406.88 973.633,1406.88 973.642,1406.88 973.651,1406.88 973.661,1406.88 973.67,1406.88 973.679,1406.88 973.688,1406.88 973.697,1406.88 973.707,1406.88 973.716,1406.88 973.725,1406.88 973.734,1406.88 973.743,1406.88 973.753,1406.88 973.762,1406.88 973.771,1406.88 973.78,1406.88 973.789,1406.88 973.799,1406.88 973.808,1406.88 973.817,1406.88 973.826,1406.88 973.835,1406.88 973.844,1406.88 973.854,1406.88 973.863,1406.88 973.872,1406.88 973.881,1406.88 973.89,1406.88 973.9,1406.88 973.909,1406.88 973.918,1406.88 973.927,1406.88 973.936,1406.88 973.946,1406.88 973.955,1406.88 973.964,1406.88 973.973,1406.88 973.982,1406.88 973.991,1406.88 974.001,1406.88 974.01,1406.88 974.019,1406.88 974.028,1406.88 974.037,1406.88 974.047,1406.88 974.056,1406.88 974.065,1406.88 974.074,1406.88 974.083,1406.88 974.093,1406.88 974.102,1406.88 974.111,1406.88 974.12,1406.88 974.129,1406.88 974.139,1406.88 974.148,1406.88 974.157,1406.88 974.166,1406.88 974.175,1406.88 974.184,1406.88 974.194,1406.88 974.203,1406.88 974.212,1406.88 974.221,1406.88 974.23,1406.88 974.24,1406.88 974.249,1406.88 974.258,1406.88 974.267,1406.88 974.276,1406.88 974.286,1406.88 974.295,1406.88 974.304,1406.88 974.313,1406.88 974.322,1406.88 974.331,1406.88 974.341,1406.88 974.35,1406.88 974.359,1406.88 974.368,1406.88 974.377,1406.88 974.387,1406.88 974.396,1406.88 974.405,1406.88 974.414,1406.88 974.423,1406.88 974.433,1406.88 974.442,1406.88 974.451,1406.88 974.46,1406.88 974.469,1406.88 974.479,1406.88 974.488,1406.88 974.497,1406.88 974.506,1406.88 974.515,1406.88 974.524,1406.88 974.534,1406.88 974.543,1406.88 974.552,1406.88 974.561,1406.88 974.57,1406.88 974.58,1406.88 974.589,1406.88 974.598,1406.88 974.607,1406.88 974.616,1406.88 974.626,1406.88 974.635,1406.88 974.644,1406.88 974.653,1406.88 974.662,1406.88 974.671,1406.88 974.681,1406.88 974.69,1406.88 974.699,1406.88 974.708,1406.88 974.717,1406.88 974.727,1406.88 974.736,1406.88 974.745,1406.88 974.754,1406.88 974.763,1406.88 974.773,1406.88 974.782,1406.88 974.791,1406.88 974.8,1406.88 974.809,1406.88 974.819,1406.88 974.828,1406.88 974.837,1406.88 974.846,1406.88 974.855,1406.88 974.864,1406.88 974.874,1406.88 974.883,1406.88 974.892,1406.88 974.901,1406.88 974.91,1406.88 974.92,1406.88 974.929,1406.88 974.938,1406.88 974.947,1406.88 974.956,1406.88 974.966,1406.88 974.975,1406.88 974.984,1406.88 974.993,1406.88 975.002,1406.88 975.012,1406.88 975.021,1406.88 975.03,1406.88 975.039,1406.88 975.048,1406.88 975.057,1406.88 975.067,1406.88 975.076,1406.88 975.085,1406.88 975.094,1406.88 975.103,1406.88 975.113,1406.88 975.122,1406.88 975.131,1406.88 975.14,1406.88 975.149,1406.88 975.159,1406.88 975.168,1406.88 975.177,1406.88 975.186,1406.88 975.195,1406.88 975.204,1406.88 975.214,1406.88 975.223,1406.88 975.232,1406.88 975.241,1406.88 975.25,1406.88 975.26,1406.88 975.269,1406.88 975.278,1406.88 975.287,1406.88 975.296,1406.88 975.306,1406.88 975.315,1406.88 975.324,1406.88 975.333,1406.88 975.342,1406.88 975.352,1406.88 975.361,1406.88 975.37,1406.88 975.379,1406.88 975.388,1406.88 975.397,1406.88 975.407,1406.88 975.416,1406.88 975.425,1406.88 975.434,1406.88 975.443,1406.88 975.453,1406.88 975.462,1406.88 975.471,1406.88 975.48,1406.88 975.489,1406.88 975.499,1406.88 975.508,1406.88 975.517,1406.88 975.526,1406.88 975.535,1406.88 975.544,1406.88 975.554,1406.88 975.563,1406.88 975.572,1406.88 975.581,1406.88 975.59,1406.88 975.6,1406.88 975.609,1406.88 975.618,1406.88 975.627,1406.88 975.636,1406.88 975.646,1406.88 975.655,1406.88 975.664,1406.88 975.673,1406.88 975.682,1406.88 975.692,1406.88 975.701,1406.88 975.71,1406.88 975.719,1406.88 975.728,1406.88 975.737,1406.88 975.747,1406.88 975.756,1406.88 975.765,1406.88 975.774,1406.88 975.783,1406.88 975.793,1406.88 975.802,1406.88 975.811,1406.88 975.82,1406.88 975.829,1406.88 975.839,1406.88 975.848,1406.88 975.857,1406.88 975.866,1406.88 975.875,1406.88 975.884,1406.88 975.894,1406.88 975.903,1406.88 975.912,1406.88 975.921,1406.88 975.93,1406.88 975.94,1406.88 975.949,1406.88 975.958,1406.88 975.967,1406.88 975.976,1406.88 975.986,1406.88 975.995,1406.88 976.004,1406.88 976.013,1406.88 976.022,1406.88 976.032,1406.88 976.041,1406.88 976.05,1406.88 976.059,1406.88 976.068,1406.88 976.077,1406.88 976.087,1406.88 976.096,1406.88 976.105,1406.88 976.114,1406.88 976.123,1406.88 976.133,1406.88 976.142,1406.88 976.151,1406.88 976.16,1406.88 976.169,1406.88 976.179,1406.88 976.188,1406.88 976.197,1406.88 976.206,1406.88 976.215,1406.88 976.224,1406.88 976.234,1406.88 976.243,1406.88 976.252,1406.88 976.261,1406.88 976.27,1406.88 976.28,1406.88 976.289,1406.88 976.298,1406.88 976.307,1406.88 976.316,1406.88 976.326,1406.88 976.335,1406.88 976.344,1406.88 976.353,1406.88 976.362,1406.88 976.372,1406.88 976.381,1406.88 976.39,1406.88 976.399,1406.88 976.408,1406.88 976.417,1406.88 976.427,1406.88 976.436,1406.88 976.445,1406.88 976.454,1406.88 976.463,1406.88 976.473,1406.88 976.482,1406.88 976.491,1406.88 976.5,1406.88 976.509,1406.88 976.519,1406.88 976.528,1406.88 976.537,1406.88 976.546,1406.88 976.555,1406.88 976.564,1406.88 976.574,1406.88 976.583,1406.88 976.592,1406.88 976.601,1406.88 976.61,1406.88 976.62,1406.88 976.629,1406.88 976.638,1406.88 976.647,1406.88 976.656,1406.88 976.666,1406.88 976.675,1406.88 976.684,1406.88 976.693,1406.88 976.702,1406.88 976.712,1406.88 976.721,1406.88 976.73,1406.88 976.739,1406.88 976.748,1406.88 976.757,1406.88 976.767,1406.88 976.776,1406.88 976.785,1406.88 976.794,1406.88 976.803,1406.88 976.813,1406.88 976.822,1406.88 976.831,1406.88 976.84,1406.88 976.849,1406.88 976.859,1406.88 976.868,1406.88 976.877,1406.88 976.886,1406.88 976.895,1406.88 976.904,1406.88 976.914,1406.88 976.923,1406.88 976.932,1406.88 976.941,1406.88 976.95,1406.88 976.96,1406.88 976.969,1406.88 976.978,1406.88 976.987,1406.88 976.996,1406.88 977.006,1406.88 977.015,1406.88 977.024,1406.88 977.033,1406.88 977.042,1406.88 977.052,1406.88 977.061,1406.88 977.07,1406.88 977.079,1406.88 977.088,1406.88 977.097,1406.88 977.107,1406.88 977.116,1406.88 977.125,1406.88 977.134,1406.88 977.143,1406.88 977.153,1406.88 977.162,1406.88 977.171,1406.88 977.18,1406.88 977.189,1406.88 977.199,1406.88 977.208,1406.88 977.217,1406.88 977.226,1406.88 977.235,1406.88 977.245,1406.88 977.254,1406.88 977.263,1406.88 977.272,1406.88 977.281,1406.88 977.29,1406.88 977.3,1406.88 977.309,1406.88 977.318,1406.88 977.327,1406.88 977.336,1406.88 977.346,1406.88 977.355,1406.88 977.364,1406.88 977.373,1406.88 977.382,1406.88 977.392,1406.88 977.401,1406.88 977.41,1406.88 977.419,1406.88 977.428,1406.88 977.437,1406.88 977.447,1406.88 977.456,1406.88 977.465,1406.88 977.474,1406.88 977.483,1406.88 977.493,1406.88 977.502,1406.88 977.511,1406.88 977.52,1406.88 977.529,1406.88 977.539,1406.88 977.548,1406.88 977.557,1406.88 977.566,1406.88 977.575,1406.88 977.585,1406.88 977.594,1406.88 977.603,1406.88 977.612,1406.88 977.621,1406.88 977.63,1406.88 977.64,1406.88 977.649,1406.88 977.658,1406.88 977.667,1406.88 977.676,1406.88 977.686,1406.88 977.695,1406.88 977.704,1406.88 977.713,1406.88 977.722,1406.88 977.732,1406.88 977.741,1406.88 977.75,1406.88 977.759,1406.88 977.768,1406.88 977.777,1406.88 977.787,1406.88 977.796,1406.88 977.805,1406.88 977.814,1406.88 977.823,1406.88 977.833,1406.88 977.842,1406.88 977.851,1406.88 977.86,1406.88 977.869,1406.88 977.879,1406.88 977.888,1406.88 977.897,1406.88 977.906,1406.88 977.915,1406.88 977.925,1406.88 977.934,1406.88 977.943,1406.88 977.952,1406.88 977.961,1406.88 977.97,1406.88 977.98,1406.88 977.989,1406.88 977.998,1406.88 978.007,1406.88 978.016,1406.88 978.026,1406.88 978.035,1406.88 978.044,1406.88 978.053,1406.88 978.062,1406.88 978.072,1406.88 978.081,1406.88 978.09,1406.88 978.099,1406.88 978.108,1406.88 978.117,1406.88 978.127,1406.88 978.136,1406.88 978.145,1406.88 978.154,1406.88 978.163,1406.88 978.173,1406.88 978.182,1406.88 978.191,1406.88 978.2,1406.88 978.209,1406.88 978.219,1406.88 978.228,1406.88 978.237,1406.88 978.246,1406.88 978.255,1406.88 978.265,1406.88 978.274,1406.88 978.283,1406.88 978.292,1406.88 978.301,1406.88 978.31,1406.88 978.32,1406.88 978.329,1406.88 978.338,1406.88 978.347,1406.88 978.356,1406.88 978.366,1406.88 978.375,1406.88 978.384,1406.88 978.393,1406.88 978.402,1406.88 978.412,1406.88 978.421,1406.88 978.43,1406.88 978.439,1406.88 978.448,1406.88 978.457,1406.88 978.467,1406.88 978.476,1406.88 978.485,1406.88 978.494,1406.88 978.503,1406.88 978.513,1406.88 978.522,1406.88 978.531,1406.88 978.54,1406.88 978.549,1406.88 978.559,1406.88 978.568,1406.88 978.577,1406.88 978.586,1406.88 978.595,1406.88 978.605,1406.88 978.614,1406.88 978.623,1406.88 978.632,1406.88 978.641,1406.88 978.65,1406.88 978.66,1406.88 978.669,1406.88 978.678,1406.88 978.687,1406.88 978.696,1406.88 978.706,1406.88 978.715,1406.88 978.724,1406.88 978.733,1406.88 978.742,1406.88 978.752,1406.88 978.761,1406.88 978.77,1406.88 978.779,1406.88 978.788,1406.88 978.797,1406.88 978.807,1406.88 978.816,1406.88 978.825,1406.88 978.834,1406.88 978.843,1406.88 978.853,1406.88 978.862,1406.88 978.871,1406.88 978.88,1406.88 978.889,1406.88 978.899,1406.88 978.908,1406.88 978.917,1406.88 978.926,1406.88 978.935,1406.88 978.945,1406.88 978.954,1406.88 978.963,1406.88 978.972,1406.88 978.981,1406.88 978.99,1406.88 979,1406.88 979.009,1406.88 979.018,1406.88 979.027,1406.88 979.036,1406.88 979.046,1406.88 979.055,1406.88 979.064,1406.88 979.073,1406.88 979.082,1406.88 979.092,1406.88 979.101,1406.88 979.11,1406.88 979.119,1406.88 979.128,1406.88 979.137,1406.88 979.147,1406.88 979.156,1406.88 979.165,1406.88 979.174,1406.88 979.183,1406.88 979.193,1406.88 979.202,1406.88 979.211,1406.88 979.22,1406.88 979.229,1406.88 979.239,1406.88 979.248,1406.88 979.257,1406.88 979.266,1406.88 979.275,1406.88 979.285,1406.88 979.294,1406.88 979.303,1406.88 979.312,1406.88 979.321,1406.88 979.33,1406.88 979.34,1406.88 979.349,1406.88 979.358,1406.88 979.367,1406.88 979.376,1406.88 979.386,1406.88 979.395,1406.88 979.404,1406.88 979.413,1406.88 979.422,1406.88 979.432,1406.88 979.441,1406.88 979.45,1406.88 979.459,1406.88 979.468,1406.88 979.477,1406.88 979.487,1406.88 979.496,1406.88 979.505,1406.88 979.514,1406.88 979.523,1406.88 979.533,1406.88 979.542,1406.88 979.551,1406.88 979.56,1406.88 979.569,1406.88 979.579,1406.88 979.588,1406.88 979.597,1406.88 979.606,1406.88 979.615,1406.88 979.625,1406.88 979.634,1406.88 979.643,1406.88 979.652,1406.88 979.661,1406.88 979.67,1406.88 979.68,1406.88 979.689,1406.88 979.698,1406.88 979.707,1406.88 979.716,1406.88 979.726,1406.88 979.735,1406.88 979.744,1406.88 979.753,1406.88 979.762,1406.88 979.772,1406.88 979.781,1406.88 979.79,1406.88 979.799,1406.88 979.808,1406.88 979.818,1406.88 979.827,1406.88 979.836,1406.88 979.845,1406.88 979.854,1406.88 979.863,1406.88 979.873,1406.88 979.882,1406.88 979.891,1406.88 979.9,1406.88 979.909,1406.88 979.919,1406.88 979.928,1406.88 979.937,1406.88 979.946,1406.88 979.955,1406.88 979.965,1406.88 979.974,1406.88 979.983,1406.88 979.992,1406.88 980.001,1406.88 980.01,1406.88 980.02,1406.88 980.029,1406.88 980.038,1406.88 980.047,1406.88 980.056,1406.88 980.066,1406.88 980.075,1406.88 980.084,1406.88 980.093,1406.88 980.102,1406.88 980.112,1406.88 980.121,1406.88 980.13,1406.88 980.139,1406.88 980.148,1406.88 980.158,1406.88 980.167,1406.88 980.176,1406.88 980.185,1406.88 980.194,1406.88 980.203,1406.88 980.213,1406.88 980.222,1406.88 980.231,1406.88 980.24,1406.88 980.249,1406.88 980.259,1406.88 980.268,1406.88 980.277,1406.88 980.286,1406.88 980.295,1406.88 980.305,1406.88 980.314,1406.88 980.323,1406.88 980.332,1406.88 980.341,1406.88 980.35,1406.88 980.36,1406.88 980.369,1406.88 980.378,1406.88 980.387,1406.88 980.396,1406.88 980.406,1406.88 980.415,1406.88 980.424,1406.88 980.433,1406.88 980.442,1406.88 980.452,1406.88 980.461,1406.88 980.47,1406.88 980.479,1406.88 980.488,1406.88 980.498,1406.88 980.507,1406.88 980.516,1406.88 980.525,1406.88 980.534,1406.88 980.543,1406.88 980.553,1406.88 980.562,1406.88 980.571,1406.88 980.58,1406.88 980.589,1406.88 980.599,1406.88 980.608,1406.88 980.617,1406.88 980.626,1406.88 980.635,1406.88 980.645,1406.88 980.654,1406.88 980.663,1406.88 980.672,1406.88 980.681,1406.88 980.69,1406.88 980.7,1406.88 980.709,1406.88 980.718,1406.88 980.727,1406.88 980.736,1406.88 980.746,1406.88 980.755,1406.88 980.764,1406.88 980.773,1406.88 980.782,1406.88 980.792,1406.88 980.801,1406.88 980.81,1406.88 980.819,1406.88 980.828,1406.88 980.838,1406.88 980.847,1406.88 980.856,1406.88 980.865,1406.88 980.874,1406.88 980.883,1406.88 980.893,1406.88 980.902,1406.88 980.911,1406.88 980.92,1406.88 980.929,1406.88 980.939,1406.88 980.948,1406.88 980.957,1406.88 980.966,1406.88 980.975,1406.88 980.985,1406.88 980.994,1406.88 981.003,1406.88 981.012,1406.88 981.021,1406.88 981.03,1406.88 981.04,1406.88 981.049,1406.88 981.058,1406.88 981.067,1406.88 981.076,1406.88 981.086,1406.88 981.095,1406.88 981.104,1406.88 981.113,1406.88 981.122,1406.88 981.132,1406.88 981.141,1406.88 981.15,1406.88 981.159,1406.88 981.168,1406.88 981.178,1406.88 981.187,1406.88 981.196,1406.88 981.205,1406.88 981.214,1406.88 981.223,1406.88 981.233,1406.88 981.242,1406.88 981.251,1406.88 981.26,1406.88 981.269,1406.88 981.279,1406.88 981.288,1406.88 981.297,1406.88 981.306,1406.88 981.315,1406.88 981.325,1406.88 981.334,1406.88 981.343,1406.88 981.352,1406.88 981.361,1406.88 981.37,1406.88 981.38,1406.88 981.389,1406.88 981.398,1406.88 981.407,1406.88 981.416,1406.88 981.426,1406.88 981.435,1406.88 981.444,1406.88 981.453,1406.88 981.462,1406.88 981.472,1406.88 981.481,1406.88 981.49,1406.88 981.499,1406.88 981.508,1406.88 981.518,1406.88 981.527,1406.88 981.536,1406.88 981.545,1406.88 981.554,1406.88 981.563,1406.88 981.573,1406.88 981.582,1406.88 981.591,1406.88 981.6,1406.88 981.609,1406.88 981.619,1406.88 981.628,1406.88 981.637,1406.88 981.646,1406.88 981.655,1406.88 981.665,1406.88 981.674,1406.88 981.683,1406.88 981.692,1406.88 981.701,1406.88 981.71,1406.88 981.72,1406.88 981.729,1406.88 981.738,1406.88 981.747,1406.88 981.756,1406.88 981.766,1406.88 981.775,1406.88 981.784,1406.88 981.793,1406.88 981.802,1406.88 981.812,1406.88 981.821,1406.88 981.83,1406.88 981.839,1406.88 981.848,1406.88 981.858,1406.88 981.867,1406.88 981.876,1406.88 981.885,1406.88 981.894,1406.88 981.903,1406.88 981.913,1406.88 981.922,1406.88 981.931,1406.88 981.94,1406.88 981.949,1406.88 981.959,1406.88 981.968,1406.88 981.977,1406.88 981.986,1406.88 981.995,1406.88 982.005,1406.88 982.014,1406.88 982.023,1406.88 982.032,1406.88 982.041,1406.88 982.05,1406.88 982.06,1406.88 982.069,1406.88 982.078,1406.88 982.087,1406.88 982.096,1406.88 982.106,1406.88 982.115,1406.88 982.124,1406.88 982.133,1406.88 982.142,1406.88 982.152,1406.88 982.161,1406.88 982.17,1406.88 982.179,1406.88 982.188,1406.88 982.198,1406.88 982.207,1406.88 982.216,1406.88 982.225,1406.88 982.234,1406.88 982.243,1406.88 982.253,1406.88 982.262,1406.88 982.271,1406.88 982.28,1406.88 982.289,1406.88 982.299,1406.88 982.308,1406.88 982.317,1406.88 982.326,1406.88 982.335,1406.88 982.345,1406.88 982.354,1406.88 982.363,1406.88 982.372,1406.88 982.381,1406.88 982.391,1406.88 982.4,1406.88 982.409,1406.88 982.418,1406.88 982.427,1406.88 982.436,1406.88 982.446,1406.88 982.455,1406.88 982.464,1406.88 982.473,1406.88 982.482,1406.88 982.492,1406.88 982.501,1406.88 982.51,1406.88 982.519,1406.88 982.528,1406.88 982.538,1406.88 982.547,1406.88 982.556,1406.88 982.565,1406.88 982.574,1406.88 982.583,1406.88 982.593,1406.88 982.602,1406.88 982.611,1406.88 982.62,1406.88 982.629,1406.88 982.639,1406.88 982.648,1406.88 982.657,1406.88 982.666,1406.88 982.675,1406.88 982.685,1406.88 982.694,1406.88 982.703,1406.88 982.712,1406.88 982.721,1406.88 982.731,1406.88 982.74,1406.88 982.749,1406.88 982.758,1406.88 982.767,1406.88 982.776,1406.88 982.786,1406.88 982.795,1406.88 982.804,1406.88 982.813,1406.88 982.822,1406.88 982.832,1406.88 982.841,1406.88 982.85,1406.88 982.859,1406.88 982.868,1406.88 982.878,1406.88 982.887,1406.88 982.896,1406.88 982.905,1406.88 982.914,1406.88 982.923,1406.88 982.933,1406.88 982.942,1406.88 982.951,1406.88 982.96,1406.88 982.969,1406.88 982.979,1406.88 982.988,1406.88 982.997,1406.88 983.006,1406.88 983.015,1406.88 983.025,1406.88 983.034,1406.88 983.043,1406.88 983.052,1406.88 983.061,1406.88 983.071,1406.88 983.08,1406.88 983.089,1406.88 983.098,1406.88 983.107,1406.88 983.116,1406.88 983.126,1406.88 983.135,1406.88 983.144,1406.88 983.153,1406.88 983.162,1406.88 983.172,1406.88 983.181,1406.88 983.19,1406.88 983.199,1406.88 983.208,1406.88 983.218,1406.88 983.227,1406.88 983.236,1406.88 983.245,1406.88 983.254,1406.88 983.263,1406.88 983.273,1406.88 983.282,1406.88 983.291,1406.88 983.3,1406.88 983.309,1406.88 983.319,1406.88 983.328,1406.88 983.337,1406.88 983.346,1406.88 983.355,1406.88 983.365,1406.88 983.374,1406.88 983.383,1406.88 983.392,1406.88 983.401,1406.88 983.411,1406.88 983.42,1406.88 983.429,1406.88 983.438,1406.88 983.447,1406.88 983.456,1406.88 983.466,1406.88 983.475,1406.88 983.484,1406.88 983.493,1406.88 983.502,1406.88 983.512,1406.88 983.521,1406.88 983.53,1406.88 983.539,1406.88 983.548,1406.88 983.558,1406.88 983.567,1406.88 983.576,1406.88 983.585,1406.88 983.594,1406.88 983.603,1406.88 983.613,1406.88 983.622,1406.88 983.631,1406.88 983.64,1406.88 983.649,1406.88 983.659,1406.88 983.668,1406.88 983.677,1406.88 983.686,1406.88 983.695,1406.88 983.705,1406.88 983.714,1406.88 983.723,1406.88 983.732,1406.88 983.741,1406.88 983.751,1406.88 983.76,1406.88 983.769,1406.88 983.778,1406.88 983.787,1406.88 983.796,1406.88 983.806,1406.88 983.815,1406.88 983.824,1406.88 983.833,1406.88 983.842,1406.88 983.852,1406.88 983.861,1406.88 983.87,1406.88 983.879,1406.88 983.888,1406.88 983.898,1406.88 983.907,1406.88 983.916,1406.88 983.925,1406.88 983.934,1406.88 983.943,1406.88 983.953,1406.88 983.962,1406.88 983.971,1406.88 983.98,1406.88 983.989,1406.88 983.999,1406.88 984.008,1406.88 984.017,1406.88 984.026,1406.88 984.035,1406.88 984.045,1406.88 984.054,1406.88 984.063,1406.88 984.072,1406.88 984.081,1406.88 984.091,1406.88 984.1,1406.88 984.109,1406.88 984.118,1406.88 984.127,1406.88 984.136,1406.88 984.146,1406.88 984.155,1406.88 984.164,1406.88 984.173,1406.88 984.182,1406.88 984.192,1406.88 984.201,1406.88 984.21,1406.88 984.219,1406.88 984.228,1406.88 984.238,1406.88 984.247,1406.88 984.256,1406.88 984.265,1406.88 984.274,1406.88 984.283,1406.88 984.293,1406.88 984.302,1406.88 984.311,1406.88 984.32,1406.88 984.329,1406.88 984.339,1406.88 984.348,1406.88 984.357,1406.88 984.366,1406.88 984.375,1406.88 984.385,1406.88 984.394,1406.88 984.403,1406.88 984.412,1406.88 984.421,1406.88 984.431,1406.88 984.44,1406.88 984.449,1406.88 984.458,1406.88 984.467,1406.88 984.476,1406.88 984.486,1406.88 984.495,1406.88 984.504,1406.88 984.513,1406.88 984.522,1406.88 984.532,1406.88 984.541,1406.88 984.55,1406.88 984.559,1406.88 984.568,1406.88 984.578,1406.88 984.587,1406.88 984.596,1406.88 984.605,1406.88 984.614,1406.88 984.624,1406.88 984.633,1406.88 984.642,1406.88 984.651,1406.88 984.66,1406.88 984.669,1406.88 984.679,1406.88 984.688,1406.88 984.697,1406.88 984.706,1406.88 984.715,1406.88 984.725,1406.88 984.734,1406.88 984.743,1406.88 984.752,1406.88 984.761,1406.88 984.771,1406.88 984.78,1406.88 984.789,1406.88 984.798,1406.88 984.807,1406.88 984.816,1406.88 984.826,1406.88 984.835,1406.88 984.844,1406.88 984.853,1406.88 984.862,1406.88 984.872,1406.88 984.881,1406.88 984.89,1406.88 984.899,1406.88 984.908,1406.88 984.918,1406.88 984.927,1406.88 984.936,1406.88 984.945,1406.88 984.954,1406.88 984.964,1406.88 984.973,1406.88 984.982,1406.88 984.991,1406.88 985,1406.88 985.009,1406.88 985.019,1406.88 985.028,1406.88 985.037,1406.88 985.046,1406.88 985.055,1406.88 985.065,1406.88 985.074,1406.88 985.083,1406.88 985.092,1406.88 985.101,1406.88 985.111,1406.88 985.12,1406.88 985.129,1406.88 985.138,1406.88 985.147,1406.88 985.156,1406.88 985.166,1406.88 985.175,1406.88 985.184,1406.88 985.193,1406.88 985.202,1406.88 985.212,1406.88 985.221,1406.88 985.23,1406.88 985.239,1406.88 985.248,1406.88 985.258,1406.88 985.267,1406.88 985.276,1406.88 985.285,1406.88 985.294,1406.88 985.304,1406.88 985.313,1406.88 985.322,1406.88 985.331,1406.88 985.34,1406.88 985.349,1406.88 985.359,1406.88 985.368,1406.88 985.377,1406.88 985.386,1406.88 985.395,1406.88 985.405,1406.88 985.414,1406.88 985.423,1406.88 985.432,1406.88 985.441,1406.88 985.451,1406.88 985.46,1406.88 985.469,1406.88 985.478,1406.88 985.487,1406.88 985.496,1406.88 985.506,1406.88 985.515,1406.88 985.524,1406.88 985.533,1406.88 985.542,1406.88 985.552,1406.88 985.561,1406.88 985.57,1406.88 985.579,1406.88 985.588,1406.88 985.598,1406.88 985.607,1406.88 985.616,1406.88 985.625,1406.88 985.634,1406.88 985.644,1406.88 985.653,1406.88 985.662,1406.88 985.671,1406.88 985.68,1406.88 985.689,1406.88 985.699,1406.88 985.708,1406.88 985.717,1406.88 985.726,1406.88 985.735,1406.88 985.745,1406.88 985.754,1406.88 985.763,1406.88 985.772,1406.88 985.781,1406.88 985.791,1406.88 985.8,1406.88 985.809,1406.88 985.818,1406.88 985.827,1406.88 985.836,1406.88 985.846,1406.88 985.855,1406.88 985.864,1406.88 985.873,1406.88 985.882,1406.88 985.892,1406.88 985.901,1406.88 985.91,1406.88 985.919,1406.88 985.928,1406.88 985.938,1406.88 985.947,1406.88 985.956,1406.88 985.965,1406.88 985.974,1406.88 985.984,1406.88 985.993,1406.88 986.002,1406.88 986.011,1406.88 986.02,1406.88 986.029,1406.88 986.039,1406.88 986.048,1406.88 986.057,1406.88 986.066,1406.88 986.075,1406.88 986.085,1406.88 986.094,1406.88 986.103,1406.88 986.112,1406.88 986.121,1406.88 986.131,1406.88 986.14,1406.88 986.149,1406.88 986.158,1406.88 986.167,1406.88 986.176,1406.88 986.186,1406.88 986.195,1406.88 986.204,1406.88 986.213,1406.88 986.222,1406.88 986.232,1406.88 986.241,1406.88 986.25,1406.88 986.259,1406.88 986.268,1406.88 986.278,1406.88 986.287,1406.88 986.296,1406.88 986.305,1406.88 986.314,1406.88 986.324,1406.88 986.333,1406.88 986.342,1406.88 986.351,1406.88 986.36,1406.88 986.369,1406.88 986.379,1406.88 986.388,1406.88 986.397,1406.88 986.406,1406.88 986.415,1406.88 986.425,1406.88 986.434,1406.88 986.443,1406.88 986.452,1406.88 986.461,1406.88 986.471,1406.88 986.48,1406.88 986.489,1406.88 986.498,1406.88 986.507,1406.88 986.516,1406.88 986.526,1406.88 986.535,1406.88 986.544,1406.88 986.553,1406.88 986.562,1406.88 986.572,1406.88 986.581,1406.88 986.59,1406.88 986.599,1406.88 986.608,1406.88 986.618,1406.88 986.627,1406.88 986.636,1406.88 986.645,1406.88 986.654,1406.88 986.664,1406.88 986.673,1406.88 986.682,1406.88 986.691,1406.88 986.7,1406.88 986.709,1406.88 986.719,1406.88 986.728,1406.88 986.737,1406.88 986.746,1406.88 986.755,1406.88 986.765,1406.88 986.774,1406.88 986.783,1406.88 986.792,1406.88 986.801,1406.88 986.811,1406.88 986.82,1406.88 986.829,1406.88 986.838,1406.88 986.847,1406.88 986.856,1406.88 986.866,1406.88 986.875,1406.88 986.884,1406.88 986.893,1406.88 986.902,1406.88 986.912,1406.88 986.921,1406.88 986.93,1406.88 986.939,1406.88 986.948,1406.88 986.958,1406.88 986.967,1406.88 986.976,1406.88 986.985,1406.88 986.994,1406.88 987.004,1406.88 987.013,1406.88 987.022,1406.88 987.031,1406.88 987.04,1406.88 987.049,1406.88 987.059,1406.88 987.068,1406.88 987.077,1406.88 987.086,1406.88 987.095,1406.88 987.105,1406.88 987.114,1406.88 987.123,1406.88 987.132,1406.88 987.141,1406.88 987.151,1406.88 987.16,1406.88 987.169,1406.88 987.178,1406.88 987.187,1406.88 987.197,1406.88 987.206,1406.88 987.215,1406.88 987.224,1406.88 987.233,1406.88 987.242,1406.88 987.252,1406.88 987.261,1406.88 987.27,1406.88 987.279,1406.88 987.288,1406.88 987.298,1406.88 987.307,1406.88 987.316,1406.88 987.325,1406.88 987.334,1406.88 987.344,1406.88 987.353,1406.88 987.362,1406.88 987.371,1406.88 987.38,1406.88 987.389,1406.88 987.399,1406.88 987.408,1406.88 987.417,1406.88 987.426,1406.88 987.435,1406.88 987.445,1406.88 987.454,1406.88 987.463,1406.88 987.472,1406.88 987.481,1406.88 987.491,1406.88 987.5,1406.88 987.509,1406.88 987.518,1406.88 987.527,1406.88 987.537,1406.88 987.546,1406.88 987.555,1406.88 987.564,1406.88 987.573,1406.88 987.582,1406.88 987.592,1406.88 987.601,1406.88 987.61,1406.88 987.619,1406.88 987.628,1406.88 987.638,1406.88 987.647,1406.88 987.656,1406.88 987.665,1406.88 987.674,1406.88 987.684,1406.88 987.693,1406.88 987.702,1406.88 987.711,1406.88 987.72,1406.88 987.729,1406.88 987.739,1406.88 987.748,1406.88 987.757,1406.88 987.766,1406.88 987.775,1406.88 987.785,1406.88 987.794,1406.88 987.803,1406.88 987.812,1406.88 987.821,1406.88 987.831,1406.88 987.84,1406.88 987.849,1406.88 987.858,1406.88 987.867,1406.88 987.877,1406.88 987.886,1406.88 987.895,1406.88 987.904,1406.88 987.913,1406.88 987.922,1406.88 987.932,1406.88 987.941,1406.88 987.95,1406.88 987.959,1406.88 987.968,1406.88 987.978,1406.88 987.987,1406.88 987.996,1406.88 988.005,1406.88 988.014,1406.88 988.024,1406.88 988.033,1406.88 988.042,1406.88 988.051,1406.88 988.06,1406.88 988.069,1406.88 988.079,1406.88 988.088,1406.88 988.097,1406.88 988.106,1406.88 988.115,1406.88 988.125,1406.88 988.134,1406.88 988.143,1406.88 988.152,1406.88 988.161,1406.88 988.171,1406.88 988.18,1406.88 988.189,1406.88 988.198,1406.88 988.207,1406.88 988.217,1406.88 988.226,1406.88 988.235,1406.88 988.244,1406.88 988.253,1406.88 988.262,1406.88 988.272,1406.88 988.281,1406.88 988.29,1406.88 988.299,1406.88 988.308,1406.88 988.318,1406.88 988.327,1406.88 988.336,1406.88 988.345,1406.88 988.354,1406.88 988.364,1406.88 988.373,1406.88 988.382,1406.88 988.391,1406.88 988.4,1406.88 988.409,1406.88 988.419,1406.88 988.428,1406.88 988.437,1406.88 988.446,1406.88 988.455,1406.88 988.465,1406.88 988.474,1406.88 988.483,1406.88 988.492,1406.88 988.501,1406.88 988.511,1406.88 988.52,1406.88 988.529,1406.88 988.538,1406.88 988.547,1406.88 988.557,1406.88 988.566,1406.88 988.575,1406.88 988.584,1406.88 988.593,1406.88 988.602,1406.88 988.612,1406.88 988.621,1406.88 988.63,1406.88 988.639,1406.88 988.648,1406.88 988.658,1406.88 988.667,1406.88 988.676,1406.88 988.685,1406.88 988.694,1406.88 988.704,1406.88 988.713,1406.88 988.722,1406.88 988.731,1406.88 988.74,1406.88 988.749,1406.88 988.759,1406.88 988.768,1406.88 988.777,1406.88 988.786,1406.88 988.795,1406.88 988.805,1406.88 988.814,1406.88 988.823,1406.88 988.832,1406.88 988.841,1406.88 988.851,1406.88 988.86,1406.88 988.869,1406.88 988.878,1406.88 988.887,1406.88 988.897,1406.88 988.906,1406.88 988.915,1406.88 988.924,1406.88 988.933,1406.88 988.942,1406.88 988.952,1406.88 988.961,1406.88 988.97,1406.88 988.979,1406.88 988.988,1406.88 988.998,1406.88 989.007,1406.88 989.016,1406.88 989.025,1406.88 989.034,1406.88 989.044,1406.88 989.053,1406.88 989.062,1406.88 989.071,1406.88 989.08,1406.88 989.089,1406.88 989.099,1406.88 989.108,1406.88 989.117,1406.88 989.126,1406.88 989.135,1406.88 989.145,1406.88 989.154,1406.88 989.163,1406.88 989.172,1406.88 989.181,1406.88 989.191,1406.88 989.2,1406.88 989.209,1406.88 989.218,1406.88 989.227,1406.88 989.237,1406.88 989.246,1406.88 989.255,1406.88 989.264,1406.88 989.273,1406.88 989.282,1406.88 989.292,1406.88 989.301,1406.88 989.31,1406.88 989.319,1406.88 989.328,1406.88 989.338,1406.88 989.347,1406.88 989.356,1406.88 989.365,1406.88 989.374,1406.88 989.384,1406.88 989.393,1406.88 989.402,1406.88 989.411,1406.88 989.42,1406.88 989.429,1406.88 989.439,1406.88 989.448,1406.88 989.457,1406.88 989.466,1406.88 989.475,1406.88 989.485,1406.88 989.494,1406.88 989.503,1406.88 989.512,1406.88 989.521,1406.88 989.531,1406.88 989.54,1406.88 989.549,1406.88 989.558,1406.88 989.567,1406.88 989.577,1406.88 989.586,1406.88 989.595,1406.88 989.604,1406.88 989.613,1406.88 989.622,1406.88 989.632,1406.88 989.641,1406.88 989.65,1406.88 989.659,1406.88 989.668,1406.88 989.678,1406.88 989.687,1406.88 989.696,1406.88 989.705,1406.88 989.714,1406.88 989.724,1406.88 989.733,1406.88 989.742,1406.88 989.751,1406.88 989.76,1406.88 989.77,1406.88 989.779,1406.88 989.788,1406.88 989.797,1406.88 989.806,1406.88 989.815,1406.88 989.825,1406.88 989.834,1406.88 989.843,1406.88 989.852,1406.88 989.861,1406.88 989.871,1406.88 989.88,1406.88 989.889,1406.88 989.898,1406.88 989.907,1406.88 989.917,1406.88 989.926,1406.88 989.935,1406.88 989.944,1406.88 989.953,1406.88 989.962,1406.88 989.972,1406.88 989.981,1406.88 989.99,1406.88 989.999,1406.88 990.008,1406.88 990.018,1406.88 990.027,1406.88 990.036,1406.88 990.045,1406.88 990.054,1406.88 990.064,1406.88 990.073,1406.88 990.082,1406.88 990.091,1406.88 990.1,1406.88 990.11,1406.88 990.119,1406.88 990.128,1406.88 990.137,1406.88 990.146,1406.88 990.155,1406.88 990.165,1406.88 990.174,1406.88 990.183,1406.88 990.192,1406.88 990.201,1406.88 990.211,1406.88 990.22,1406.88 990.229,1406.88 990.238,1406.88 990.247,1406.88 990.257,1406.88 990.266,1406.88 990.275,1406.88 990.284,1406.88 990.293,1406.88 990.302,1406.88 990.312,1406.88 990.321,1406.88 990.33,1406.88 990.339,1406.88 990.348,1406.88 990.358,1406.88 990.367,1406.88 990.376,1406.88 990.385,1406.88 990.394,1406.88 990.404,1406.88 990.413,1406.88 990.422,1406.88 990.431,1406.88 990.44,1406.88 990.45,1406.88 990.459,1406.88 990.468,1406.88 990.477,1406.88 990.486,1406.88 990.495,1406.88 990.505,1406.88 990.514,1406.88 990.523,1406.88 990.532,1406.88 990.541,1406.88 990.551,1406.88 990.56,1406.88 990.569,1406.88 990.578,1406.88 990.587,1406.88 990.597,1406.88 990.606,1406.88 990.615,1406.88 990.624,1406.88 990.633,1406.88 990.642,1406.88 990.652,1406.88 990.661,1406.88 990.67,1406.88 990.679,1406.88 990.688,1406.88 990.698,1406.88 990.707,1406.88 990.716,1406.88 990.725,1406.88 990.734,1406.88 990.744,1406.88 990.753,1406.88 990.762,1406.88 990.771,1406.88 990.78,1406.88 990.79,1406.88 990.799,1406.88 990.808,1406.88 990.817,1406.88 990.826,1406.88 990.835,1406.88 990.845,1406.88 990.854,1406.88 990.863,1406.88 990.872,1406.88 990.881,1406.88 990.891,1406.88 990.9,1406.88 990.909,1406.88 990.918,1406.88 990.927,1406.88 990.937,1406.88 990.946,1406.88 990.955,1406.88 990.964,1406.88 990.973,1406.88 990.982,1406.88 990.992,1406.88 991.001,1406.88 991.01,1406.88 991.019,1406.88 991.028,1406.88 991.038,1406.88 991.047,1406.88 991.056,1406.88 991.065,1406.88 991.074,1406.88 991.084,1406.88 991.093,1406.88 991.102,1406.88 991.111,1406.88 991.12,1406.88 991.13,1406.88 991.139,1406.88 991.148,1406.88 991.157,1406.88 991.166,1406.88 991.175,1406.88 991.185,1406.88 991.194,1406.88 991.203,1406.88 991.212,1406.88 991.221,1406.88 991.231,1406.88 991.24,1406.88 991.249,1406.88 991.258,1406.88 991.267,1406.88 991.277,1406.88 991.286,1406.88 991.295,1406.88 991.304,1406.88 991.313,1406.88 991.322,1406.88 991.332,1406.88 991.341,1406.88 991.35,1406.88 991.359,1406.88 991.368,1406.88 991.378,1406.88 991.387,1406.88 991.396,1406.88 991.405,1406.88 991.414,1406.88 991.424,1406.88 991.433,1406.88 991.442,1406.88 991.451,1406.88 991.46,1406.88 991.47,1406.88 991.479,1406.88 991.488,1406.88 991.497,1406.88 991.506,1406.88 991.515,1406.88 991.525,1406.88 991.534,1406.88 991.543,1406.88 991.552,1406.88 991.561,1406.88 991.571,1406.88 991.58,1406.88 991.589,1406.88 991.598,1406.88 991.607,1406.88 991.617,1406.88 991.626,1406.88 991.635,1406.88 991.644,1406.88 991.653,1406.88 991.662,1406.88 991.672,1406.88 991.681,1406.88 991.69,1406.88 991.699,1406.88 991.708,1406.88 991.718,1406.88 991.727,1406.88 991.736,1406.88 991.745,1406.88 991.754,1406.88 991.764,1406.88 991.773,1406.88 991.782,1406.88 991.791,1406.88 991.8,1406.88 991.81,1406.88 991.819,1406.88 991.828,1406.88 991.837,1406.88 991.846,1406.88 991.855,1406.88 991.865,1406.88 991.874,1406.88 991.883,1406.88 991.892,1406.88 991.901,1406.88 991.911,1406.88 991.92,1406.88 991.929,1406.88 991.938,1406.88 991.947,1406.88 991.957,1406.88 991.966,1406.88 991.975,1406.88 991.984,1406.88 991.993,1406.88 992.002,1406.88 992.012,1406.88 992.021,1406.88 992.03,1406.88 992.039,1406.88 992.048,1406.88 992.058,1406.88 992.067,1406.88 992.076,1406.88 992.085,1406.88 992.094,1406.88 992.104,1406.88 992.113,1406.88 992.122,1406.88 992.131,1406.88 992.14,1406.88 992.15,1406.88 992.159,1406.88 992.168,1406.88 992.177,1406.88 992.186,1406.88 992.195,1406.88 992.205,1406.88 992.214,1406.88 992.223,1406.88 992.232,1406.88 992.241,1406.88 992.251,1406.88 992.26,1406.88 992.269,1406.88 992.278,1406.88 992.287,1406.88 992.297,1406.88 992.306,1406.88 992.315,1406.88 992.324,1406.88 992.333,1406.88 992.343,1406.88 992.352,1406.88 992.361,1406.88 992.37,1406.88 992.379,1406.88 992.388,1406.88 992.398,1406.88 992.407,1406.88 992.416,1406.88 992.425,1406.88 992.434,1406.88 992.444,1406.88 992.453,1406.88 992.462,1406.88 992.471,1406.88 992.48,1406.88 992.49,1406.88 992.499,1406.88 992.508,1406.88 992.517,1406.88 992.526,1406.88 992.535,1406.88 992.545,1406.88 992.554,1406.88 992.563,1406.88 992.572,1406.88 992.581,1406.88 992.591,1406.88 992.6,1406.88 992.609,1406.88 992.618,1406.88 992.627,1406.88 992.637,1406.88 992.646,1406.88 992.655,1406.88 992.664,1406.88 992.673,1406.88 992.683,1406.88 992.692,1406.88 992.701,1406.88 992.71,1406.88 992.719,1406.88 992.728,1406.88 992.738,1406.88 992.747,1406.88 992.756,1406.88 992.765,1406.88 992.774,1406.88 992.784,1406.88 992.793,1406.88 992.802,1406.88 992.811,1406.88 992.82,1406.88 992.83,1406.88 992.839,1406.88 992.848,1406.88 992.857,1406.88 992.866,1406.88 992.875,1406.88 992.885,1406.88 992.894,1406.88 992.903,1406.88 992.912,1406.88 992.921,1406.88 992.931,1406.88 992.94,1406.88 992.949,1406.88 992.958,1406.88 992.967,1406.88 992.977,1406.88 992.986,1406.88 992.995,1406.88 993.004,1406.88 993.013,1406.88 993.023,1406.88 993.032,1406.88 993.041,1406.88 993.05,1406.88 993.059,1406.88 993.068,1406.88 993.078,1406.88 993.087,1406.88 993.096,1406.88 993.105,1406.88 993.114,1406.88 993.124,1406.88 993.133,1406.88 993.142,1406.88 993.151,1406.88 993.16,1406.88 993.17,1406.88 993.179,1406.88 993.188,1406.88 993.197,1406.88 993.206,1406.88 993.215,1406.88 993.225,1406.88 993.234,1406.88 993.243,1406.88 993.252,1406.88 993.261,1406.88 993.271,1406.88 993.28,1406.88 993.289,1406.88 993.298,1406.88 993.307,1406.88 993.317,1406.88 993.326,1406.88 993.335,1406.88 993.344,1406.88 993.353,1406.88 993.363,1406.88 993.372,1406.88 993.381,1406.88 993.39,1406.88 993.399,1406.88 993.408,1406.88 993.418,1406.88 993.427,1406.88 993.436,1406.88 993.445,1406.88 993.454,1406.88 993.464,1406.88 993.473,1406.88 993.482,1406.88 993.491,1406.88 993.5,1406.88 993.51,1406.88 993.519,1406.88 993.528,1406.88 993.537,1406.88 993.546,1406.88 993.555,1406.88 993.565,1406.88 993.574,1406.88 993.583,1406.88 993.592,1406.88 993.601,1406.88 993.611,1406.88 993.62,1406.88 993.629,1406.88 993.638,1406.88 993.647,1406.88 993.657,1406.88 993.666,1406.88 993.675,1406.88 993.684,1406.88 993.693,1406.88 993.703,1406.88 993.712,1406.88 993.721,1406.88 993.73,1406.88 993.739,1406.88 993.748,1406.88 993.758,1406.88 993.767,1406.88 993.776,1406.88 993.785,1406.88 993.794,1406.88 993.804,1406.88 993.813,1406.88 993.822,1406.88 993.831,1406.88 993.84,1406.88 993.85,1406.88 993.859,1406.88 993.868,1406.88 993.877,1406.88 993.886,1406.88 993.895,1406.88 993.905,1406.88 993.914,1406.88 993.923,1406.88 993.932,1406.88 993.941,1406.88 993.951,1406.88 993.96,1406.88 993.969,1406.88 993.978,1406.88 993.987,1406.88 993.997,1406.88 994.006,1406.88 994.015,1406.88 994.024,1406.88 994.033,1406.88 994.043,1406.88 994.052,1406.88 994.061,1406.88 994.07,1406.88 994.079,1406.88 994.088,1406.88 994.098,1406.88 994.107,1406.88 994.116,1406.88 994.125,1406.88 994.134,1406.88 994.144,1406.88 994.153,1406.88 994.162,1406.88 994.171,1406.88 994.18,1406.88 994.19,1406.88 994.199,1406.88 994.208,1406.88 994.217,1406.88 994.226,1406.88 994.235,1406.88 994.245,1406.88 994.254,1406.88 994.263,1406.88 994.272,1406.88 994.281,1406.88 994.291,1406.88 994.3,1406.88 994.309,1406.88 994.318,1406.88 994.327,1406.88 994.337,1406.88 994.346,1406.88 994.355,1406.88 994.364,1406.88 994.373,1406.88 994.383,1406.88 994.392,1406.88 994.401,1406.88 994.41,1406.88 994.419,1406.88 994.428,1406.88 994.438,1406.88 994.447,1406.88 994.456,1406.88 994.465,1406.88 994.474,1406.88 994.484,1406.88 994.493,1406.88 994.502,1406.88 994.511,1406.88 994.52,1406.88 994.53,1406.88 994.539,1406.88 994.548,1406.88 994.557,1406.88 994.566,1406.88 994.576,1406.88 994.585,1406.88 994.594,1406.88 994.603,1406.88 994.612,1406.88 994.621,1406.88 994.631,1406.88 994.64,1406.88 994.649,1406.88 994.658,1406.88 994.667,1406.88 994.677,1406.88 994.686,1406.88 994.695,1406.88 994.704,1406.88 994.713,1406.88 994.723,1406.88 994.732,1406.88 994.741,1406.88 994.75,1406.88 994.759,1406.88 994.768,1406.88 994.778,1406.88 994.787,1406.88 994.796,1406.88 994.805,1406.88 994.814,1406.88 994.824,1406.88 994.833,1406.88 994.842,1406.88 994.851,1406.88 994.86,1406.88 994.87,1406.88 994.879,1406.88 994.888,1406.88 994.897,1406.88 994.906,1406.88 994.916,1406.88 994.925,1406.88 994.934,1406.88 994.943,1406.88 994.952,1406.88 994.961,1406.88 994.971,1406.88 994.98,1406.88 994.989,1406.88 994.998,1406.88 995.007,1406.88 995.017,1406.88 995.026,1406.88 995.035,1406.88 995.044,1406.88 995.053,1406.88 995.063,1406.88 995.072,1406.88 995.081,1406.88 995.09,1406.88 995.099,1406.88 995.108,1406.88 995.118,1406.88 995.127,1406.88 995.136,1406.88 995.145,1406.88 995.154,1406.88 995.164,1406.88 995.173,1406.88 995.182,1406.88 995.191,1406.88 995.2,1406.88 995.21,1406.88 995.219,1406.88 995.228,1406.88 995.237,1406.88 995.246,1406.88 995.256,1406.88 995.265,1406.88 995.274,1406.88 995.283,1406.88 995.292,1406.88 995.301,1406.88 995.311,1406.88 995.32,1406.88 995.329,1406.88 995.338,1406.88 995.347,1406.88 995.357,1406.88 995.366,1406.88 995.375,1406.88 995.384,1406.88 995.393,1406.88 995.403,1406.88 995.412,1406.88 995.421,1406.88 995.43,1406.88 995.439,1406.88 995.448,1406.88 995.458,1406.88 995.467,1406.88 995.476,1406.88 995.485,1406.88 995.494,1406.88 995.504,1406.88 995.513,1406.88 995.522,1406.88 995.531,1406.88 995.54,1406.88 995.55,1406.88 995.559,1406.88 995.568,1406.88 995.577,1406.88 995.586,1406.88 995.596,1406.88 995.605,1406.88 995.614,1406.88 995.623,1406.88 995.632,1406.88 995.641,1406.88 995.651,1406.88 995.66,1406.88 995.669,1406.88 995.678,1406.88 995.687,1406.88 995.697,1406.88 995.706,1406.88 995.715,1406.88 995.724,1406.88 995.733,1406.88 995.743,1406.88 995.752,1406.88 995.761,1406.88 995.77,1406.88 995.779,1406.88 995.788,1406.88 995.798,1406.88 995.807,1406.88 995.816,1406.88 995.825,1406.88 995.834,1406.88 995.844,1406.88 995.853,1406.88 995.862,1406.88 995.871,1406.88 995.88,1406.88 995.89,1406.88 995.899,1406.88 995.908,1406.88 995.917,1406.88 995.926,1406.88 995.936,1406.88 995.945,1406.88 995.954,1406.88 995.963,1406.88 995.972,1406.88 995.981,1406.88 995.991,1406.88 996,1406.88 996.009,1406.88 996.018,1406.88 996.027,1406.88 996.037,1406.88 996.046,1406.88 996.055,1406.88 996.064,1406.88 996.073,1406.88 996.083,1406.88 996.092,1406.88 996.101,1406.88 996.11,1406.88 996.119,1406.88 996.128,1406.88 996.138,1406.88 996.147,1406.88 996.156,1406.88 996.165,1406.88 996.174,1406.88 996.184,1406.88 996.193,1406.88 996.202,1406.88 996.211,1406.88 996.22,1406.88 996.23,1406.88 996.239,1406.88 996.248,1406.88 996.257,1406.88 996.266,1406.88 996.276,1406.88 996.285,1406.88 996.294,1406.88 996.303,1406.88 996.312,1406.88 996.321,1406.88 996.331,1406.88 996.34,1406.88 996.349,1406.88 996.358,1406.88 996.367,1406.88 996.377,1406.88 996.386,1406.88 996.395,1406.88 996.404,1406.88 996.413,1406.88 996.423,1406.88 996.432,1406.88 996.441,1406.88 996.45,1406.88 996.459,1406.88 996.468,1406.88 996.478,1406.88 996.487,1406.88 996.496,1406.88 996.505,1406.88 996.514,1406.88 996.524,1406.88 996.533,1406.88 996.542,1406.88 996.551,1406.88 996.56,1406.88 996.57,1406.88 996.579,1406.88 996.588,1406.88 996.597,1406.88 996.606,1406.88 996.616,1406.88 996.625,1406.88 996.634,1406.88 996.643,1406.88 996.652,1406.88 996.661,1406.88 996.671,1406.88 996.68,1406.88 996.689,1406.88 996.698,1406.88 996.707,1406.88 996.717,1406.88 996.726,1406.88 996.735,1406.88 996.744,1406.88 996.753,1406.88 996.763,1406.88 996.772,1406.88 996.781,1406.88 996.79,1406.88 996.799,1406.88 996.808,1406.88 996.818,1406.88 996.827,1406.88 996.836,1406.88 996.845,1406.88 996.854,1406.88 996.864,1406.88 996.873,1406.88 996.882,1406.88 996.891,1406.88 996.9,1406.88 996.91,1406.88 996.919,1406.88 996.928,1406.88 996.937,1406.88 996.946,1406.88 996.956,1406.88 996.965,1406.88 996.974,1406.88 996.983,1406.88 996.992,1406.88 997.001,1406.88 997.011,1406.88 997.02,1406.88 997.029,1406.88 997.038,1406.88 997.047,1406.88 997.057,1406.88 997.066,1406.88 997.075,1406.88 997.084,1406.88 997.093,1406.88 997.103,1406.88 997.112,1406.88 997.121,1406.88 997.13,1406.88 997.139,1406.88 997.149,1406.88 997.158,1406.88 997.167,1406.88 997.176,1406.88 997.185,1406.88 997.194,1406.88 997.204,1406.88 997.213,1406.88 997.222,1406.88 997.231,1406.88 997.24,1406.88 997.25,1406.88 997.259,1406.88 997.268,1406.88 997.277,1406.88 997.286,1406.88 997.296,1406.88 997.305,1406.88 997.314,1406.88 997.323,1406.88 997.332,1406.88 997.341,1406.88 997.351,1406.88 997.36,1406.88 997.369,1406.88 997.378,1406.88 997.387,1406.88 997.397,1406.88 997.406,1406.88 997.415,1406.88 997.424,1406.88 997.433,1406.88 997.443,1406.88 997.452,1406.88 997.461,1406.88 997.47,1406.88 997.479,1406.88 997.489,1406.88 997.498,1406.88 997.507,1406.88 997.516,1406.88 997.525,1406.88 997.534,1406.88 997.544,1406.88 997.553,1406.88 997.562,1406.88 997.571,1406.88 997.58,1406.88 997.59,1406.88 997.599,1406.88 997.608,1406.88 997.617,1406.88 997.626,1406.88 997.636,1406.88 997.645,1406.88 997.654,1406.88 997.663,1406.88 997.672,1406.88 997.681,1406.88 997.691,1406.88 997.7,1406.88 997.709,1406.88 997.718,1406.88 997.727,1406.88 997.737,1406.88 997.746,1406.88 997.755,1406.88 997.764,1406.88 997.773,1406.88 997.783,1406.88 997.792,1406.88 997.801,1406.88 997.81,1406.88 997.819,1406.88 997.829,1406.88 997.838,1406.88 997.847,1406.88 997.856,1406.88 997.865,1406.88 997.874,1406.88 997.884,1406.88 997.893,1406.88 997.902,1406.88 997.911,1406.88 997.92,1406.88 997.93,1406.88 997.939,1406.88 997.948,1406.88 997.957,1406.88 997.966,1406.88 997.976,1406.88 997.985,1406.88 997.994,1406.88 998.003,1406.88 998.012,1406.88 998.021,1406.88 998.031,1406.88 998.04,1406.88 998.049,1406.88 998.058,1406.88 998.067,1406.88 998.077,1406.88 998.086,1406.88 998.095,1406.88 998.104,1406.88 998.113,1406.88 998.123,1406.88 998.132,1406.88 998.141,1406.88 998.15,1406.88 998.159,1406.88 998.169,1406.88 998.178,1406.88 998.187,1406.88 998.196,1406.88 998.205,1406.88 998.214,1406.88 998.224,1406.88 998.233,1406.88 998.242,1406.88 998.251,1406.88 998.26,1406.88 998.27,1406.88 998.279,1406.88 998.288,1406.88 998.297,1406.88 998.306,1406.88 998.316,1406.88 998.325,1406.88 998.334,1406.88 998.343,1406.88 998.352,1406.88 998.361,1406.88 998.371,1406.88 998.38,1406.88 998.389,1406.88 998.398,1406.88 998.407,1406.88 998.417,1406.88 998.426,1406.88 998.435,1406.88 998.444,1406.88 998.453,1406.88 998.463,1406.88 998.472,1406.88 998.481,1406.88 998.49,1406.88 998.499,1406.88 998.509,1406.88 998.518,1406.88 998.527,1406.88 998.536,1406.88 998.545,1406.88 998.554,1406.88 998.564,1406.88 998.573,1406.88 998.582,1406.88 998.591,1406.88 998.6,1406.88 998.61,1406.88 998.619,1406.88 998.628,1406.88 998.637,1406.88 998.646,1406.88 998.656,1406.88 998.665,1406.88 998.674,1406.88 998.683,1406.88 998.692,1406.88 998.701,1406.88 998.711,1406.88 998.72,1406.88 998.729,1406.88 998.738,1406.88 998.747,1406.88 998.757,1406.88 998.766,1406.88 998.775,1406.88 998.784,1406.88 998.793,1406.88 998.803,1406.88 998.812,1406.88 998.821,1406.88 998.83,1406.88 998.839,1406.88 998.849,1406.88 998.858,1406.88 998.867,1406.88 998.876,1406.88 998.885,1406.88 998.894,1406.88 998.904,1406.88 998.913,1406.88 998.922,1406.88 998.931,1406.88 998.94,1406.88 998.95,1406.88 998.959,1406.88 998.968,1406.88 998.977,1406.88 998.986,1406.88 998.996,1406.88 999.005,1406.88 999.014,1406.88 999.023,1406.88 999.032,1406.88 999.041,1406.88 999.051,1406.88 999.06,1406.88 999.069,1406.88 999.078,1406.88 999.087,1406.88 999.097,1406.88 999.106,1406.88 999.115,1406.88 999.124,1406.88 999.133,1406.88 999.143,1406.88 999.152,1406.88 999.161,1406.88 999.17,1406.88 999.179,1406.88 999.189,1406.88 999.198,1406.88 999.207,1406.88 999.216,1406.88 999.225,1406.88 999.234,1406.88 999.244,1406.88 999.253,1406.88 999.262,1406.88 999.271,1406.88 999.28,1406.88 999.29,1406.88 999.299,1406.88 999.308,1406.88 999.317,1406.88 999.326,1406.88 999.336,1406.88 999.345,1406.88 999.354,1406.88 999.363,1406.88 999.372,1406.88 999.381,1406.88 999.391,1406.88 999.4,1406.88 999.409,1406.88 999.418,1406.88 999.427,1406.88 999.437,1406.88 999.446,1406.88 999.455,1406.88 999.464,1406.88 999.473,1406.88 999.483,1406.88 999.492,1406.88 999.501,1406.88 999.51,1406.88 999.519,1406.88 999.529,1406.88 999.538,1406.88 999.547,1406.88 999.556,1406.88 999.565,1406.88 999.574,1406.88 999.584,1406.88 999.593,1406.88 999.602,1406.88 999.611,1406.88 999.62,1406.88 999.63,1406.88 999.639,1406.88 999.648,1406.88 999.657,1406.88 999.666,1406.88 999.676,1406.88 999.685,1406.88 999.694,1406.88 999.703,1406.88 999.712,1406.88 999.722,1406.88 999.731,1406.88 999.74,1406.88 999.749,1406.88 999.758,1406.88 999.767,1406.88 999.777,1406.88 999.786,1406.88 999.795,1406.88 999.804,1406.88 999.813,1406.88 999.823,1406.88 999.832,1406.88 999.841,1406.88 999.85,1406.88 999.859,1406.88 999.869,1406.88 999.878,1406.88 999.887,1406.88 999.896,1406.88 999.905,1406.88 999.914,1406.88 999.924,1406.88 999.933,1406.88 999.942,1406.88 999.951,1406.88 999.96,1406.88 999.97,1406.88 999.979,1406.88 999.988,1406.88 999.997,1406.88 1000.01,1406.88 1000.02,1406.88 1000.02,1406.88 1000.03,1406.88 1000.04,1406.88 1000.05,1406.88 1000.06,1406.88 1000.07,1406.88 1000.08,1406.88 1000.09,1406.88 1000.1,1406.88 1000.11,1406.88 1000.12,1406.88 1000.13,1406.88 1000.14,1406.88 1000.14,1406.88 1000.15,1406.88 1000.16,1406.88 1000.17,1406.88 1000.18,1406.88 1000.19,1406.88 1000.2,1406.88 1000.21,1406.88 1000.22,1406.88 1000.23,1406.88 1000.24,1406.88 1000.25,1406.88 1000.25,1406.88 1000.26,1406.88 1000.27,1406.88 1000.28,1406.88 1000.29,1406.88 1000.3,1406.88 1000.31,1406.88 1000.32,1406.88 1000.33,1406.88 1000.34,1406.88 1000.35,1406.88 1000.36,1406.88 1000.36,1406.88 1000.37,1406.88 1000.38,1406.88 1000.39,1406.88 1000.4,1406.88 1000.41,1406.88 1000.42,1406.88 1000.43,1406.88 1000.44,1406.88 1000.45,1406.88 1000.46,1406.88 1000.47,1406.88 1000.48,1406.88 1000.48,1406.88 1000.49,1406.88 1000.5,1406.88 1000.51,1406.88 1000.52,1406.88 1000.53,1406.88 1000.54,1406.88 1000.55,1406.88 1000.56,1406.88 1000.57,1406.88 1000.58,1406.88 1000.59,1406.88 1000.59,1406.88 1000.6,1406.88 1000.61,1406.88 1000.62,1406.88 1000.63,1406.88 1000.64,1406.88 1000.65,1406.88 1000.66,1406.88 1000.67,1406.88 1000.68,1406.88 1000.69,1406.88 1000.7,1406.88 1000.7,1406.88 1000.71,1406.88 1000.72,1406.88 1000.73,1406.88 1000.74,1406.88 1000.75,1406.88 1000.76,1406.88 1000.77,1406.88 1000.78,1406.88 1000.79,1406.88 1000.8,1406.88 1000.81,1406.88 1000.82,1406.88 1000.82,1406.88 1000.83,1406.88 1000.84,1406.88 1000.85,1406.88 1000.86,1406.88 1000.87,1406.88 1000.88,1406.88 1000.89,1406.88 1000.9,1406.88 1000.91,1406.88 1000.92,1406.88 1000.93,1406.88 1000.93,1406.88 1000.94,1406.88 1000.95,1406.88 1000.96,1406.88 1000.97,1406.88 1000.98,1406.88 1000.99,1406.88 1001,1406.88 1001.01,1406.88 1001.02,1406.88 1001.03,1406.88 1001.04,1406.88 1001.04,1406.88 1001.05,1406.88 1001.06,1406.88 1001.07,1406.88 1001.08,1406.88 1001.09,1406.88 1001.1,1406.88 1001.11,1406.88 1001.12,1406.88 1001.13,1406.88 1001.14,1406.88 1001.15,1406.88 1001.16,1406.88 1001.16,1406.88 1001.17,1406.88 1001.18,1406.88 1001.19,1406.88 1001.2,1406.88 1001.21,1406.88 1001.22,1406.88 1001.23,1406.88 1001.24,1406.88 1001.25,1406.88 1001.26,1406.88 1001.27,1406.88 1001.27,1406.88 1001.28,1406.88 1001.29,1406.88 1001.3,1406.88 1001.31,1406.88 1001.32,1406.88 1001.33,1406.88 1001.34,1406.88 1001.35,1406.88 1001.36,1406.88 1001.37,1406.88 1001.38,1406.88 1001.38,1406.88 1001.39,1406.88 1001.4,1406.88 1001.41,1406.88 1001.42,1406.88 1001.43,1406.88 1001.44,1406.88 1001.45,1406.88 1001.46,1406.88 1001.47,1406.88 1001.48,1406.88 1001.49,1406.88 1001.5,1406.88 1001.5,1406.88 1001.51,1406.88 1001.52,1406.88 1001.53,1406.88 1001.54,1406.88 1001.55,1406.88 1001.56,1406.88 1001.57,1406.88 1001.58,1406.88 1001.59,1406.88 1001.6,1406.88 1001.61,1406.88 1001.61,1406.88 1001.62,1406.88 1001.63,1406.88 1001.64,1406.88 1001.65,1406.88 1001.66,1406.88 1001.67,1406.88 1001.68,1406.88 1001.69,1406.88 1001.7,1406.88 1001.71,1406.88 1001.72,1406.88 1001.72,1406.88 1001.73,1406.88 1001.74,1406.88 1001.75,1406.88 1001.76,1406.88 1001.77,1406.88 1001.78,1406.88 1001.79,1406.88 1001.8,1406.88 1001.81,1406.88 1001.82,1406.88 1001.83,1406.88 1001.84,1406.88 1001.84,1406.88 1001.85,1406.88 1001.86,1406.88 1001.87,1406.88 1001.88,1406.88 1001.89,1406.88 1001.9,1406.88 1001.91,1406.88 1001.92,1406.88 1001.93,1406.88 1001.94,1406.88 1001.95,1406.88 1001.95,1406.88 1001.96,1406.88 1001.97,1406.88 1001.98,1406.88 1001.99,1406.88 1002,1406.88 1002.01,1406.88 1002.02,1406.88 1002.03,1406.88 1002.04,1406.88 1002.05,1406.88 1002.06,1406.88 1002.06,1406.88 1002.07,1406.88 1002.08,1406.88 1002.09,1406.88 1002.1,1406.88 1002.11,1406.88 1002.12,1406.88 1002.13,1406.88 1002.14,1406.88 1002.15,1406.88 1002.16,1406.88 1002.17,1406.88 1002.18,1406.88 1002.18,1406.88 1002.19,1406.88 1002.2,1406.88 1002.21,1406.88 1002.22,1406.88 1002.23,1406.88 1002.24,1406.88 1002.25,1406.88 1002.26,1406.88 1002.27,1406.88 1002.28,1406.88 1002.29,1406.88 1002.29,1406.88 1002.3,1406.88 1002.31,1406.88 1002.32,1406.88 1002.33,1406.88 1002.34,1406.88 1002.35,1406.88 1002.36,1406.88 1002.37,1406.88 1002.38,1406.88 1002.39,1406.88 1002.4,1406.88 1002.4,1406.88 1002.41,1406.88 1002.42,1406.88 1002.43,1406.88 1002.44,1406.88 1002.45,1406.88 1002.46,1406.88 1002.47,1406.88 1002.48,1406.88 1002.49,1406.88 1002.5,1406.88 1002.51,1406.88 1002.52,1406.88 1002.52,1406.88 1002.53,1406.88 1002.54,1406.88 1002.55,1406.88 1002.56,1406.88 1002.57,1406.88 1002.58,1406.88 1002.59,1406.88 1002.6,1406.88 1002.61,1406.88 1002.62,1406.88 1002.63,1406.88 1002.63,1406.88 1002.64,1406.88 1002.65,1406.88 1002.66,1406.88 1002.67,1406.88 1002.68,1406.88 1002.69,1406.88 1002.7,1406.88 1002.71,1406.88 1002.72,1406.88 1002.73,1406.88 1002.74,1406.88 1002.74,1406.88 1002.75,1406.88 1002.76,1406.88 1002.77,1406.88 1002.78,1406.88 1002.79,1406.88 1002.8,1406.88 1002.81,1406.88 1002.82,1406.88 1002.83,1406.88 1002.84,1406.88 1002.85,1406.88 1002.86,1406.88 1002.86,1406.88 1002.87,1406.88 1002.88,1406.88 1002.89,1406.88 1002.9,1406.88 1002.91,1406.88 1002.92,1406.88 1002.93,1406.88 1002.94,1406.88 1002.95,1406.88 1002.96,1406.88 1002.97,1406.88 1002.97,1406.88 1002.98,1406.88 1002.99,1406.88 1003,1406.88 1003.01,1406.88 1003.02,1406.88 1003.03,1406.88 1003.04,1406.88 1003.05,1406.88 1003.06,1406.88 1003.07,1406.88 1003.08,1406.88 1003.08,1406.88 1003.09,1406.88 1003.1,1406.88 1003.11,1406.88 1003.12,1406.88 1003.13,1406.88 1003.14,1406.88 1003.15,1406.88 1003.16,1406.88 1003.17,1406.88 1003.18,1406.88 1003.19,1406.88 1003.2,1406.88 1003.2,1406.88 1003.21,1406.88 1003.22,1406.88 1003.23,1406.88 1003.24,1406.88 1003.25,1406.88 1003.26,1406.88 1003.27,1406.88 1003.28,1406.88 1003.29,1406.88 1003.3,1406.88 1003.31,1406.88 1003.31,1406.88 1003.32,1406.88 1003.33,1406.88 1003.34,1406.88 1003.35,1406.88 1003.36,1406.88 1003.37,1406.88 1003.38,1406.88 1003.39,1406.88 1003.4,1406.88 1003.41,1406.88 1003.42,1406.88 1003.42,1406.88 1003.43,1406.88 1003.44,1406.88 1003.45,1406.88 1003.46,1406.88 1003.47,1406.88 1003.48,1406.88 1003.49,1406.88 1003.5,1406.88 1003.51,1406.88 1003.52,1406.88 1003.53,1406.88 1003.54,1406.88 1003.54,1406.88 1003.55,1406.88 1003.56,1406.88 1003.57,1406.88 1003.58,1406.88 1003.59,1406.88 1003.6,1406.88 1003.61,1406.88 1003.62,1406.88 1003.63,1406.88 1003.64,1406.88 1003.65,1406.88 1003.65,1406.88 1003.66,1406.88 1003.67,1406.88 1003.68,1406.88 1003.69,1406.88 1003.7,1406.88 1003.71,1406.88 1003.72,1406.88 1003.73,1406.88 1003.74,1406.88 1003.75,1406.88 1003.76,1406.88 1003.76,1406.88 1003.77,1406.88 1003.78,1406.88 1003.79,1406.88 1003.8,1406.88 1003.81,1406.88 1003.82,1406.88 1003.83,1406.88 1003.84,1406.88 1003.85,1406.88 1003.86,1406.88 1003.87,1406.88 1003.88,1406.88 1003.88,1406.88 1003.89,1406.88 1003.9,1406.88 1003.91,1406.88 1003.92,1406.88 1003.93,1406.88 1003.94,1406.88 1003.95,1406.88 1003.96,1406.88 1003.97,1406.88 1003.98,1406.88 1003.99,1406.88 1003.99,1406.88 1004,1406.88 1004.01,1406.88 1004.02,1406.88 1004.03,1406.88 1004.04,1406.88 1004.05,1406.88 1004.06,1406.88 1004.07,1406.88 1004.08,1406.88 1004.09,1406.88 1004.1,1406.88 1004.1,1406.88 1004.11,1406.88 1004.12,1406.88 1004.13,1406.88 1004.14,1406.88 1004.15,1406.88 1004.16,1406.88 1004.17,1406.88 1004.18,1406.88 1004.19,1406.88 1004.2,1406.88 1004.21,1406.88 1004.22,1406.88 1004.22,1406.88 1004.23,1406.88 1004.24,1406.88 1004.25,1406.88 1004.26,1406.88 1004.27,1406.88 1004.28,1406.88 1004.29,1406.88 1004.3,1406.88 1004.31,1406.88 1004.32,1406.88 1004.33,1406.88 1004.33,1406.88 1004.34,1406.88 1004.35,1406.88 1004.36,1406.88 1004.37,1406.88 1004.38,1406.88 1004.39,1406.88 1004.4,1406.88 1004.41,1406.88 1004.42,1406.88 1004.43,1406.88 1004.44,1406.88 1004.44,1406.88 1004.45,1406.88 1004.46,1406.88 1004.47,1406.88 1004.48,1406.88 1004.49,1406.88 1004.5,1406.88 1004.51,1406.88 1004.52,1406.88 1004.53,1406.88 1004.54,1406.88 1004.55,1406.88 1004.56,1406.88 1004.56,1406.88 1004.57,1406.88 1004.58,1406.88 1004.59,1406.88 1004.6,1406.88 1004.61,1406.88 1004.62,1406.88 1004.63,1406.88 1004.64,1406.88 1004.65,1406.88 1004.66,1406.88 1004.67,1406.88 1004.67,1406.88 1004.68,1406.88 1004.69,1406.88 1004.7,1406.88 1004.71,1406.88 1004.72,1406.88 1004.73,1406.88 1004.74,1406.88 1004.75,1406.88 1004.76,1406.88 1004.77,1406.88 1004.78,1406.88 1004.78,1406.88 1004.79,1406.88 1004.8,1406.88 1004.81,1406.88 1004.82,1406.88 1004.83,1406.88 1004.84,1406.88 1004.85,1406.88 1004.86,1406.88 1004.87,1406.88 1004.88,1406.88 1004.89,1406.88 1004.9,1406.88 1004.9,1406.88 1004.91,1406.88 1004.92,1406.88 1004.93,1406.88 1004.94,1406.88 1004.95,1406.88 1004.96,1406.88 1004.97,1406.88 1004.98,1406.88 1004.99,1406.88 1005,1406.88 1005.01,1406.88 1005.01,1406.88 1005.02,1406.88 1005.03,1406.88 1005.04,1406.88 1005.05,1406.88 1005.06,1406.88 1005.07,1406.88 1005.08,1406.88 1005.09,1406.88 1005.1,1406.88 1005.11,1406.88 1005.12,1406.88 1005.12,1406.88 1005.13,1406.88 1005.14,1406.88 1005.15,1406.88 1005.16,1406.88 1005.17,1406.88 1005.18,1406.88 1005.19,1406.88 1005.2,1406.88 1005.21,1406.88 1005.22,1406.88 1005.23,1406.88 1005.24,1406.88 1005.24,1406.88 1005.25,1406.88 1005.26,1406.88 1005.27,1406.88 1005.28,1406.88 1005.29,1406.88 1005.3,1406.88 1005.31,1406.88 1005.32,1406.88 1005.33,1406.88 1005.34,1406.88 1005.35,1406.88 1005.35,1406.88 1005.36,1406.88 1005.37,1406.88 1005.38,1406.88 1005.39,1406.88 1005.4,1406.88 1005.41,1406.88 1005.42,1406.88 1005.43,1406.88 1005.44,1406.88 1005.45,1406.88 1005.46,1406.88 1005.46,1406.88 1005.47,1406.88 1005.48,1406.88 1005.49,1406.88 1005.5,1406.88 1005.51,1406.88 1005.52,1406.88 1005.53,1406.88 1005.54,1406.88 1005.55,1406.88 1005.56,1406.88 1005.57,1406.88 1005.58,1406.88 1005.58,1406.88 1005.59,1406.88 1005.6,1406.88 1005.61,1406.88 1005.62,1406.88 1005.63,1406.88 1005.64,1406.88 1005.65,1406.88 1005.66,1406.88 1005.67,1406.88 1005.68,1406.88 1005.69,1406.88 1005.69,1406.88 1005.7,1406.88 1005.71,1406.88 1005.72,1406.88 1005.73,1406.88 1005.74,1406.88 1005.75,1406.88 1005.76,1406.88 1005.77,1406.88 1005.78,1406.88 1005.79,1406.88 1005.8,1406.88 1005.8,1406.88 1005.81,1406.88 1005.82,1406.88 1005.83,1406.88 1005.84,1406.88 1005.85,1406.88 1005.86,1406.88 1005.87,1406.88 1005.88,1406.88 1005.89,1406.88 1005.9,1406.88 1005.91,1406.88 1005.92,1406.88 1005.92,1406.88 1005.93,1406.88 1005.94,1406.88 1005.95,1406.88 1005.96,1406.88 1005.97,1406.88 1005.98,1406.88 1005.99,1406.88 1006,1406.88 1006.01,1406.88 1006.02,1406.88 1006.03,1406.88 1006.03,1406.88 1006.04,1406.88 1006.05,1406.88 1006.06,1406.88 1006.07,1406.88 1006.08,1406.88 1006.09,1406.88 1006.1,1406.88 1006.11,1406.88 1006.12,1406.88 1006.13,1406.88 1006.14,1406.88 1006.14,1406.88 1006.15,1406.88 1006.16,1406.88 1006.17,1406.88 1006.18,1406.88 1006.19,1406.88 1006.2,1406.88 1006.21,1406.88 1006.22,1406.88 1006.23,1406.88 1006.24,1406.88 1006.25,1406.88 1006.26,1406.88 1006.26,1406.88 1006.27,1406.88 1006.28,1406.88 1006.29,1406.88 1006.3,1406.88 1006.31,1406.88 1006.32,1406.88 1006.33,1406.88 1006.34,1406.88 1006.35,1406.88 1006.36,1406.88 1006.37,1406.88 1006.37,1406.88 1006.38,1406.88 1006.39,1406.88 1006.4,1406.88 1006.41,1406.88 1006.42,1406.88 1006.43,1406.88 1006.44,1406.88 1006.45,1406.88 1006.46,1406.88 1006.47,1406.88 1006.48,1406.88 1006.48,1406.88 1006.49,1406.88 1006.5,1406.88 1006.51,1406.88 1006.52,1406.88 1006.53,1406.88 1006.54,1406.88 1006.55,1406.88 1006.56,1406.88 1006.57,1406.88 1006.58,1406.88 1006.59,1406.88 1006.6,1406.88 1006.6,1406.88 1006.61,1406.88 1006.62,1406.88 1006.63,1406.88 1006.64,1406.88 1006.65,1406.88 1006.66,1406.88 1006.67,1406.88 1006.68,1406.88 1006.69,1406.88 1006.7,1406.88 1006.71,1406.88 1006.71,1406.88 1006.72,1406.88 1006.73,1406.88 1006.74,1406.88 1006.75,1406.88 1006.76,1406.88 1006.77,1406.88 1006.78,1406.88 1006.79,1406.88 1006.8,1406.88 1006.81,1406.88 1006.82,1406.88 1006.82,1406.88 1006.83,1406.88 1006.84,1406.88 1006.85,1406.88 1006.86,1406.88 1006.87,1406.88 1006.88,1406.88 1006.89,1406.88 1006.9,1406.88 1006.91,1406.88 1006.92,1406.88 1006.93,1406.88 1006.94,1406.88 1006.94,1406.88 1006.95,1406.88 1006.96,1406.88 1006.97,1406.88 1006.98,1406.88 1006.99,1406.88 1007,1406.88 1007.01,1406.88 1007.02,1406.88 1007.03,1406.88 1007.04,1406.88 1007.05,1406.88 1007.05,1406.88 1007.06,1406.88 1007.07,1406.88 1007.08,1406.88 1007.09,1406.88 1007.1,1406.88 1007.11,1406.88 1007.12,1406.88 1007.13,1406.88 1007.14,1406.88 1007.15,1406.88 1007.16,1406.88 1007.16,1406.88 1007.17,1406.88 1007.18,1406.88 1007.19,1406.88 1007.2,1406.88 1007.21,1406.88 1007.22,1406.88 1007.23,1406.88 1007.24,1406.88 1007.25,1406.88 1007.26,1406.88 1007.27,1406.88 1007.28,1406.88 1007.28,1406.88 1007.29,1406.88 1007.3,1406.88 1007.31,1406.88 1007.32,1406.88 1007.33,1406.88 1007.34,1406.88 1007.35,1406.88 1007.36,1406.88 1007.37,1406.88 1007.38,1406.88 1007.39,1406.88 1007.39,1406.88 1007.4,1406.88 1007.41,1406.88 1007.42,1406.88 1007.43,1406.88 1007.44,1406.88 1007.45,1406.88 1007.46,1406.88 1007.47,1406.88 1007.48,1406.88 1007.49,1406.88 1007.5,1406.88 1007.5,1406.88 1007.51,1406.88 1007.52,1406.88 1007.53,1406.88 1007.54,1406.88 1007.55,1406.88 1007.56,1406.88 1007.57,1406.88 1007.58,1406.88 1007.59,1406.88 1007.6,1406.88 1007.61,1406.88 1007.62,1406.88 1007.62,1406.88 1007.63,1406.88 1007.64,1406.88 1007.65,1406.88 1007.66,1406.88 1007.67,1406.88 1007.68,1406.88 1007.69,1406.88 1007.7,1406.88 1007.71,1406.88 1007.72,1406.88 1007.73,1406.88 1007.73,1406.88 1007.74,1406.88 1007.75,1406.88 1007.76,1406.88 1007.77,1406.88 1007.78,1406.88 1007.79,1406.88 1007.8,1406.88 1007.81,1406.88 1007.82,1406.88 1007.83,1406.88 1007.84,1406.88 1007.84,1406.88 1007.85,1406.88 1007.86,1406.88 1007.87,1406.88 1007.88,1406.88 1007.89,1406.88 1007.9,1406.88 1007.91,1406.88 1007.92,1406.88 1007.93,1406.88 1007.94,1406.88 1007.95,1406.88 1007.96,1406.88 1007.96,1406.88 1007.97,1406.88 1007.98,1406.88 1007.99,1406.88 1008,1406.88 1008.01,1406.88 1008.02,1406.88 1008.03,1406.88 1008.04,1406.88 1008.05,1406.88 1008.06,1406.88 1008.07,1406.88 1008.07,1406.88 1008.08,1406.88 1008.09,1406.88 1008.1,1406.88 1008.11,1406.88 1008.12,1406.88 1008.13,1406.88 1008.14,1406.88 1008.15,1406.88 1008.16,1406.88 1008.17,1406.88 1008.18,1406.88 1008.18,1406.88 1008.19,1406.88 1008.2,1406.88 1008.21,1406.88 1008.22,1406.88 1008.23,1406.88 1008.24,1406.88 1008.25,1406.88 1008.26,1406.88 1008.27,1406.88 1008.28,1406.88 1008.29,1406.88 1008.3,1406.88 1008.3,1406.88 1008.31,1406.88 1008.32,1406.88 1008.33,1406.88 1008.34,1406.88 1008.35,1406.88 1008.36,1406.88 1008.37,1406.88 1008.38,1406.88 1008.39,1406.88 1008.4,1406.88 1008.41,1406.88 1008.41,1406.88 1008.42,1406.88 1008.43,1406.88 1008.44,1406.88 1008.45,1406.88 1008.46,1406.88 1008.47,1406.88 1008.48,1406.88 1008.49,1406.88 1008.5,1406.88 1008.51,1406.88 1008.52,1406.88 1008.52,1406.88 1008.53,1406.88 1008.54,1406.88 1008.55,1406.88 1008.56,1406.88 1008.57,1406.88 1008.58,1406.88 1008.59,1406.88 1008.6,1406.88 1008.61,1406.88 1008.62,1406.88 1008.63,1406.88 1008.64,1406.88 1008.64,1406.88 1008.65,1406.88 1008.66,1406.88 1008.67,1406.88 1008.68,1406.88 1008.69,1406.88 1008.7,1406.88 1008.71,1406.88 1008.72,1406.88 1008.73,1406.88 1008.74,1406.88 1008.75,1406.88 1008.75,1406.88 1008.76,1406.88 1008.77,1406.88 1008.78,1406.88 1008.79,1406.88 1008.8,1406.88 1008.81,1406.88 1008.82,1406.88 1008.83,1406.88 1008.84,1406.88 1008.85,1406.88 1008.86,1406.88 1008.86,1406.88 1008.87,1406.88 1008.88,1406.88 1008.89,1406.88 1008.9,1406.88 1008.91,1406.88 1008.92,1406.88 1008.93,1406.88 1008.94,1406.88 1008.95,1406.88 1008.96,1406.88 1008.97,1406.88 1008.98,1406.88 1008.98,1406.88 1008.99,1406.88 1009,1406.88 1009.01,1406.88 1009.02,1406.88 1009.03,1406.88 1009.04,1406.88 1009.05,1406.88 1009.06,1406.88 1009.07,1406.88 1009.08,1406.88 1009.09,1406.88 1009.09,1406.88 1009.1,1406.88 1009.11,1406.88 1009.12,1406.88 1009.13,1406.88 1009.14,1406.88 1009.15,1406.88 1009.16,1406.88 1009.17,1406.88 1009.18,1406.88 1009.19,1406.88 1009.2,1406.88 1009.2,1406.88 1009.21,1406.88 1009.22,1406.88 1009.23,1406.88 1009.24,1406.88 1009.25,1406.88 1009.26,1406.88 1009.27,1406.88 1009.28,1406.88 1009.29,1406.88 1009.3,1406.88 1009.31,1406.88 1009.32,1406.88 1009.32,1406.88 1009.33,1406.88 1009.34,1406.88 1009.35,1406.88 1009.36,1406.88 1009.37,1406.88 1009.38,1406.88 1009.39,1406.88 1009.4,1406.88 1009.41,1406.88 1009.42,1406.88 1009.43,1406.88 1009.43,1406.88 1009.44,1406.88 1009.45,1406.88 1009.46,1406.88 1009.47,1406.88 1009.48,1406.88 1009.49,1406.88 1009.5,1406.88 1009.51,1406.88 1009.52,1406.88 1009.53,1406.88 1009.54,1406.88 1009.54,1406.88 1009.55,1406.88 1009.56,1406.88 1009.57,1406.88 1009.58,1406.88 1009.59,1406.88 1009.6,1406.88 1009.61,1406.88 1009.62,1406.88 1009.63,1406.88 1009.64,1406.88 1009.65,1406.88 1009.66,1406.88 1009.66,1406.88 1009.67,1406.88 1009.68,1406.88 1009.69,1406.88 1009.7,1406.88 1009.71,1406.88 1009.72,1406.88 1009.73,1406.88 1009.74,1406.88 1009.75,1406.88 1009.76,1406.88 1009.77,1406.88 1009.77,1406.88 1009.78,1406.88 1009.79,1406.88 1009.8,1406.88 1009.81,1406.88 1009.82,1406.88 1009.83,1406.88 1009.84,1406.88 1009.85,1406.88 1009.86,1406.88 1009.87,1406.88 1009.88,1406.88 1009.88,1406.88 1009.89,1406.88 1009.9,1406.88 1009.91,1406.88 1009.92,1406.88 1009.93,1406.88 1009.94,1406.88 1009.95,1406.88 1009.96,1406.88 1009.97,1406.88 1009.98,1406.88 1009.99,1406.88 1010,1406.88 1010,1406.88 1010.01,1406.88 1010.02,1406.88 1010.03,1406.88 1010.04,1406.88 1010.05,1406.88 1010.06,1406.88 1010.07,1406.88 1010.08,1406.88 1010.09,1406.88 1010.1,1406.88 1010.11,1406.88 1010.11,1406.88 1010.12,1406.88 1010.13,1406.88 1010.14,1406.88 1010.15,1406.88 1010.16,1406.88 1010.17,1406.88 1010.18,1406.88 1010.19,1406.88 1010.2,1406.88 1010.21,1406.88 1010.22,1406.88 1010.22,1406.88 1010.23,1406.88 1010.24,1406.88 1010.25,1406.88 1010.26,1406.88 1010.27,1406.88 1010.28,1406.88 1010.29,1406.88 1010.3,1406.88 1010.31,1406.88 1010.32,1406.88 1010.33,1406.88 1010.34,1406.88 1010.34,1406.88 1010.35,1406.88 1010.36,1406.88 1010.37,1406.88 1010.38,1406.88 1010.39,1406.88 1010.4,1406.88 1010.41,1406.88 1010.42,1406.88 1010.43,1406.88 1010.44,1406.88 1010.45,1406.88 1010.45,1406.88 1010.46,1406.88 1010.47,1406.88 1010.48,1406.88 1010.49,1406.88 1010.5,1406.88 1010.51,1406.88 1010.52,1406.88 1010.53,1406.88 1010.54,1406.88 1010.55,1406.88 1010.56,1406.88 1010.56,1406.88 1010.57,1406.88 1010.58,1406.88 1010.59,1406.88 1010.6,1406.88 1010.61,1406.88 1010.62,1406.88 1010.63,1406.88 1010.64,1406.88 1010.65,1406.88 1010.66,1406.88 1010.67,1406.88 1010.68,1406.88 1010.68,1406.88 1010.69,1406.88 1010.7,1406.88 1010.71,1406.88 1010.72,1406.88 1010.73,1406.88 1010.74,1406.88 1010.75,1406.88 1010.76,1406.88 1010.77,1406.88 1010.78,1406.88 1010.79,1406.88 1010.79,1406.88 1010.8,1406.88 1010.81,1406.88 1010.82,1406.88 1010.83,1406.88 1010.84,1406.88 1010.85,1406.88 1010.86,1406.88 1010.87,1406.88 1010.88,1406.88 1010.89,1406.88 1010.9,1406.88 1010.9,1406.88 1010.91,1406.88 1010.92,1406.88 1010.93,1406.88 1010.94,1406.88 1010.95,1406.88 1010.96,1406.88 1010.97,1406.88 1010.98,1406.88 1010.99,1406.88 1011,1406.88 1011.01,1406.88 1011.02,1406.88 1011.02,1406.88 1011.03,1406.88 1011.04,1406.88 1011.05,1406.88 1011.06,1406.88 1011.07,1406.88 1011.08,1406.88 1011.09,1406.88 1011.1,1406.88 1011.11,1406.88 1011.12,1406.88 1011.13,1406.88 1011.13,1406.88 1011.14,1406.88 1011.15,1406.88 1011.16,1406.88 1011.17,1406.88 1011.18,1406.88 1011.19,1406.88 1011.2,1406.88 1011.21,1406.88 1011.22,1406.88 1011.23,1406.88 1011.24,1406.88 1011.24,1406.88 1011.25,1406.88 1011.26,1406.88 1011.27,1406.88 1011.28,1406.88 1011.29,1406.88 1011.3,1406.88 1011.31,1406.88 1011.32,1406.88 1011.33,1406.88 1011.34,1406.88 1011.35,1406.88 1011.36,1406.88 1011.36,1406.88 1011.37,1406.88 1011.38,1406.88 1011.39,1406.88 1011.4,1406.88 1011.41,1406.88 1011.42,1406.88 1011.43,1406.88 1011.44,1406.88 1011.45,1406.88 1011.46,1406.88 1011.47,1406.88 1011.47,1406.88 1011.48,1406.88 1011.49,1406.88 1011.5,1406.88 1011.51,1406.88 1011.52,1406.88 1011.53,1406.88 1011.54,1406.88 1011.55,1406.88 1011.56,1406.88 1011.57,1406.88 1011.58,1406.88 1011.58,1406.88 1011.59,1406.88 1011.6,1406.88 1011.61,1406.88 1011.62,1406.88 1011.63,1406.88 1011.64,1406.88 1011.65,1406.88 1011.66,1406.88 1011.67,1406.88 1011.68,1406.88 1011.69,1406.88 1011.7,1406.88 1011.7,1406.88 1011.71,1406.88 1011.72,1406.88 1011.73,1406.88 1011.74,1406.88 1011.75,1406.88 1011.76,1406.88 1011.77,1406.88 1011.78,1406.88 1011.79,1406.88 1011.8,1406.88 1011.81,1406.88 1011.81,1406.88 1011.82,1406.88 1011.83,1406.88 1011.84,1406.88 1011.85,1406.88 1011.86,1406.88 1011.87,1406.88 1011.88,1406.88 1011.89,1406.88 1011.9,1406.88 1011.91,1406.88 1011.92,1406.88 1011.92,1406.88 1011.93,1406.88 1011.94,1406.88 1011.95,1406.88 1011.96,1406.88 1011.97,1406.88 1011.98,1406.88 1011.99,1406.88 1012,1406.88 1012.01,1406.88 1012.02,1406.88 1012.03,1406.88 1012.04,1406.88 1012.04,1406.88 1012.05,1406.88 1012.06,1406.88 1012.07,1406.88 1012.08,1406.88 1012.09,1406.88 1012.1,1406.88 1012.11,1406.88 1012.12,1406.88 1012.13,1406.88 1012.14,1406.88 1012.15,1406.88 1012.15,1406.88 1012.16,1406.88 1012.17,1406.88 1012.18,1406.88 1012.19,1406.88 1012.2,1406.88 1012.21,1406.88 1012.22,1406.88 1012.23,1406.88 1012.24,1406.88 1012.25,1406.88 1012.26,1406.88 1012.26,1406.88 1012.27,1406.88 1012.28,1406.88 1012.29,1406.88 1012.3,1406.88 1012.31,1406.88 1012.32,1406.88 1012.33,1406.88 1012.34,1406.88 1012.35,1406.88 1012.36,1406.88 1012.37,1406.88 1012.38,1406.88 1012.38,1406.88 1012.39,1406.88 1012.4,1406.88 1012.41,1406.88 1012.42,1406.88 1012.43,1406.88 1012.44,1406.88 1012.45,1406.88 1012.46,1406.88 1012.47,1406.88 1012.48,1406.88 1012.49,1406.88 1012.49,1406.88 1012.5,1406.88 1012.51,1406.88 1012.52,1406.88 1012.53,1406.88 1012.54,1406.88 1012.55,1406.88 1012.56,1406.88 1012.57,1406.88 1012.58,1406.88 1012.59,1406.88 1012.6,1406.88 1012.6,1406.88 1012.61,1406.88 1012.62,1406.88 1012.63,1406.88 1012.64,1406.88 1012.65,1406.88 1012.66,1406.88 1012.67,1406.88 1012.68,1406.88 1012.69,1406.88 1012.7,1406.88 1012.71,1406.88 1012.72,1406.88 1012.72,1406.88 1012.73,1406.88 1012.74,1406.88 1012.75,1406.88 1012.76,1406.88 1012.77,1406.88 1012.78,1406.88 1012.79,1406.88 1012.8,1406.88 1012.81,1406.88 1012.82,1406.88 1012.83,1406.88 1012.83,1406.88 1012.84,1406.88 1012.85,1406.88 1012.86,1406.88 1012.87,1406.88 1012.88,1406.88 1012.89,1406.88 1012.9,1406.88 1012.91,1406.88 1012.92,1406.88 1012.93,1406.88 1012.94,1406.88 1012.94,1406.88 1012.95,1406.88 1012.96,1406.88 1012.97,1406.88 1012.98,1406.88 1012.99,1406.88 1013,1406.88 1013.01,1406.88 1013.02,1406.88 1013.03,1406.88 1013.04,1406.88 1013.05,1406.88 1013.06,1406.88 1013.06,1406.88 1013.07,1406.88 1013.08,1406.88 1013.09,1406.88 1013.1,1406.88 1013.11,1406.88 1013.12,1406.88 1013.13,1406.88 1013.14,1406.88 1013.15,1406.88 1013.16,1406.88 1013.17,1406.88 1013.17,1406.88 1013.18,1406.88 1013.19,1406.88 1013.2,1406.88 1013.21,1406.88 1013.22,1406.88 1013.23,1406.88 1013.24,1406.88 1013.25,1406.88 1013.26,1406.88 1013.27,1406.88 1013.28,1406.88 1013.28,1406.88 1013.29,1406.88 1013.3,1406.88 1013.31,1406.88 1013.32,1406.88 1013.33,1406.88 1013.34,1406.88 1013.35,1406.88 1013.36,1406.88 1013.37,1406.88 1013.38,1406.88 1013.39,1406.88 1013.4,1406.88 1013.4,1406.88 1013.41,1406.88 1013.42,1406.88 1013.43,1406.88 1013.44,1406.88 1013.45,1406.88 1013.46,1406.88 1013.47,1406.88 1013.48,1406.88 1013.49,1406.88 1013.5,1406.88 1013.51,1406.88 1013.51,1406.88 1013.52,1406.88 1013.53,1406.88 1013.54,1406.88 1013.55,1406.88 1013.56,1406.88 1013.57,1406.88 1013.58,1406.88 1013.59,1406.88 1013.6,1406.88 1013.61,1406.88 1013.62,1406.88 1013.62,1406.88 1013.63,1406.88 1013.64,1406.88 1013.65,1406.88 1013.66,1406.88 1013.67,1406.88 1013.68,1406.88 1013.69,1406.88 1013.7,1406.88 1013.71,1406.88 1013.72,1406.88 1013.73,1406.88 1013.74,1406.88 1013.74,1406.88 1013.75,1406.88 1013.76,1406.88 1013.77,1406.88 1013.78,1406.88 1013.79,1406.88 1013.8,1406.88 1013.81,1406.88 1013.82,1406.88 1013.83,1406.88 1013.84,1406.88 1013.85,1406.88 1013.85,1406.88 1013.86,1406.88 1013.87,1406.88 1013.88,1406.88 1013.89,1406.88 1013.9,1406.88 1013.91,1406.88 1013.92,1406.88 1013.93,1406.88 1013.94,1406.88 1013.95,1406.88 1013.96,1406.88 1013.96,1406.88 1013.97,1406.88 1013.98,1406.88 1013.99,1406.88 1014,1406.88 1014.01,1406.88 1014.02,1406.88 1014.03,1406.88 1014.04,1406.88 1014.05,1406.88 1014.06,1406.88 1014.07,1406.88 1014.08,1406.88 1014.08,1406.88 1014.09,1406.88 1014.1,1406.88 1014.11,1406.88 1014.12,1406.88 1014.13,1406.88 1014.14,1406.88 1014.15,1406.88 1014.16,1406.88 1014.17,1406.88 1014.18,1406.88 1014.19,1406.88 1014.19,1406.88 1014.2,1406.88 1014.21,1406.88 1014.22,1406.88 1014.23,1406.88 1014.24,1406.88 1014.25,1406.88 1014.26,1406.88 1014.27,1406.88 1014.28,1406.88 1014.29,1406.88 1014.3,1406.88 1014.3,1406.88 1014.31,1406.88 1014.32,1406.88 1014.33,1406.88 1014.34,1406.88 1014.35,1406.88 1014.36,1406.88 1014.37,1406.88 1014.38,1406.88 1014.39,1406.88 1014.4,1406.88 1014.41,1406.88 1014.42,1406.88 1014.42,1406.88 1014.43,1406.88 1014.44,1406.88 1014.45,1406.88 1014.46,1406.88 1014.47,1406.88 1014.48,1406.88 1014.49,1406.88 1014.5,1406.88 1014.51,1406.88 1014.52,1406.88 1014.53,1406.88 1014.53,1406.88 1014.54,1406.88 1014.55,1406.88 1014.56,1406.88 1014.57,1406.88 1014.58,1406.88 1014.59,1406.88 1014.6,1406.88 1014.61,1406.88 1014.62,1406.88 1014.63,1406.88 1014.64,1406.88 1014.64,1406.88 1014.65,1406.88 1014.66,1406.88 1014.67,1406.88 1014.68,1406.88 1014.69,1406.88 1014.7,1406.88 1014.71,1406.88 1014.72,1406.88 1014.73,1406.88 1014.74,1406.88 1014.75,1406.88 1014.76,1406.88 1014.76,1406.88 1014.77,1406.88 1014.78,1406.88 1014.79,1406.88 1014.8,1406.88 1014.81,1406.88 1014.82,1406.88 1014.83,1406.88 1014.84,1406.88 1014.85,1406.88 1014.86,1406.88 1014.87,1406.88 1014.87,1406.88 1014.88,1406.88 1014.89,1406.88 1014.9,1406.88 1014.91,1406.88 1014.92,1406.88 1014.93,1406.88 1014.94,1406.88 1014.95,1406.88 1014.96,1406.88 1014.97,1406.88 1014.98,1406.88 1014.98,1406.88 1014.99,1406.88 1015,1406.88 1015.01,1406.88 1015.02,1406.88 1015.03,1406.88 1015.04,1406.88 1015.05,1406.88 1015.06,1406.88 1015.07,1406.88 1015.08,1406.88 1015.09,1406.88 1015.1,1406.88 1015.1,1406.88 1015.11,1406.88 1015.12,1406.88 1015.13,1406.88 1015.14,1406.88 1015.15,1406.88 1015.16,1406.88 1015.17,1406.88 1015.18,1406.88 1015.19,1406.88 1015.2,1406.88 1015.21,1406.88 1015.21,1406.88 1015.22,1406.88 1015.23,1406.88 1015.24,1406.88 1015.25,1406.88 1015.26,1406.88 1015.27,1406.88 1015.28,1406.88 1015.29,1406.88 1015.3,1406.88 1015.31,1406.88 1015.32,1406.88 1015.32,1406.88 1015.33,1406.88 1015.34,1406.88 1015.35,1406.88 1015.36,1406.88 1015.37,1406.88 1015.38,1406.88 1015.39,1406.88 1015.4,1406.88 1015.41,1406.88 1015.42,1406.88 1015.43,1406.88 1015.44,1406.88 1015.44,1406.88 1015.45,1406.88 1015.46,1406.88 1015.47,1406.88 1015.48,1406.88 1015.49,1406.88 1015.5,1406.88 1015.51,1406.88 1015.52,1406.88 1015.53,1406.88 1015.54,1406.88 1015.55,1406.88 1015.55,1406.88 1015.56,1406.88 1015.57,1406.88 1015.58,1406.88 1015.59,1406.88 1015.6,1406.88 1015.61,1406.88 1015.62,1406.88 1015.63,1406.88 1015.64,1406.88 1015.65,1406.88 1015.66,1406.88 1015.66,1406.88 1015.67,1406.88 1015.68,1406.88 1015.69,1406.88 1015.7,1406.88 1015.71,1406.88 1015.72,1406.88 1015.73,1406.88 1015.74,1406.88 1015.75,1406.88 1015.76,1406.88 1015.77,1406.88 1015.78,1406.88 1015.78,1406.88 1015.79,1406.88 1015.8,1406.88 1015.81,1406.88 1015.82,1406.88 1015.83,1406.88 1015.84,1406.88 1015.85,1406.88 1015.86,1406.88 1015.87,1406.88 1015.88,1406.88 1015.89,1406.88 1015.89,1406.88 1015.9,1406.88 1015.91,1406.88 1015.92,1406.88 1015.93,1406.88 1015.94,1406.88 1015.95,1406.88 1015.96,1406.88 1015.97,1406.88 1015.98,1406.88 1015.99,1406.88 1016,1406.88 1016,1406.88 1016.01,1406.88 1016.02,1406.88 1016.03,1406.88 1016.04,1406.88 1016.05,1406.88 1016.06,1406.88 1016.07,1406.88 1016.08,1406.88 1016.09,1406.88 1016.1,1406.88 1016.11,1406.88 1016.12,1406.88 1016.12,1406.88 1016.13,1406.88 1016.14,1406.88 1016.15,1406.88 1016.16,1406.88 1016.17,1406.88 1016.18,1406.88 1016.19,1406.88 1016.2,1406.88 1016.21,1406.88 1016.22,1406.88 1016.23,1406.88 1016.23,1406.88 1016.24,1406.88 1016.25,1406.88 1016.26,1406.88 1016.27,1406.88 1016.28,1406.88 1016.29,1406.88 1016.3,1406.88 1016.31,1406.88 1016.32,1406.88 1016.33,1406.88 1016.34,1406.88 1016.34,1406.88 1016.35,1406.88 1016.36,1406.88 1016.37,1406.88 1016.38,1406.88 1016.39,1406.88 1016.4,1406.88 1016.41,1406.88 1016.42,1406.88 1016.43,1406.88 1016.44,1406.88 1016.45,1406.88 1016.46,1406.88 1016.46,1406.88 1016.47,1406.88 1016.48,1406.88 1016.49,1406.88 1016.5,1406.88 1016.51,1406.88 1016.52,1406.88 1016.53,1406.88 1016.54,1406.88 1016.55,1406.88 1016.56,1406.88 1016.57,1406.88 1016.57,1406.88 1016.58,1406.88 1016.59,1406.88 1016.6,1406.88 1016.61,1406.88 1016.62,1406.88 1016.63,1406.88 1016.64,1406.88 1016.65,1406.88 1016.66,1406.88 1016.67,1406.88 1016.68,1406.88 1016.68,1406.88 1016.69,1406.88 1016.7,1406.88 1016.71,1406.88 1016.72,1406.88 1016.73,1406.88 1016.74,1406.88 1016.75,1406.88 1016.76,1406.88 1016.77,1406.88 1016.78,1406.88 1016.79,1406.88 1016.8,1406.88 1016.8,1406.88 1016.81,1406.88 1016.82,1406.88 1016.83,1406.88 1016.84,1406.88 1016.85,1406.88 1016.86,1406.88 1016.87,1406.88 1016.88,1406.88 1016.89,1406.88 1016.9,1406.88 1016.91,1406.88 1016.91,1406.88 1016.92,1406.88 1016.93,1406.88 1016.94,1406.88 1016.95,1406.88 1016.96,1406.88 1016.97,1406.88 1016.98,1406.88 1016.99,1406.88 1017,1406.88 1017.01,1406.88 1017.02,1406.88 1017.02,1406.88 1017.03,1406.88 1017.04,1406.88 1017.05,1406.88 1017.06,1406.88 1017.07,1406.88 1017.08,1406.88 1017.09,1406.88 1017.1,1406.88 1017.11,1406.88 1017.12,1406.88 1017.13,1406.88 1017.14,1406.88 1017.14,1406.88 1017.15,1406.88 1017.16,1406.88 1017.17,1406.88 1017.18,1406.88 1017.19,1406.88 1017.2,1406.88 1017.21,1406.88 1017.22,1406.88 1017.23,1406.88 1017.24,1406.88 1017.25,1406.88 1017.25,1406.88 1017.26,1406.88 1017.27,1406.88 1017.28,1406.88 1017.29,1406.88 1017.3,1406.88 1017.31,1406.88 1017.32,1406.88 1017.33,1406.88 1017.34,1406.88 1017.35,1406.88 1017.36,1406.88 1017.36,1406.88 1017.37,1406.88 1017.38,1406.88 1017.39,1406.88 1017.4,1406.88 1017.41,1406.88 1017.42,1406.88 1017.43,1406.88 1017.44,1406.88 1017.45,1406.88 1017.46,1406.88 1017.47,1406.88 1017.48,1406.88 1017.48,1406.88 1017.49,1406.88 1017.5,1406.88 1017.51,1406.88 1017.52,1406.88 1017.53,1406.88 1017.54,1406.88 1017.55,1406.88 1017.56,1406.88 1017.57,1406.88 1017.58,1406.88 1017.59,1406.88 1017.59,1406.88 1017.6,1406.88 1017.61,1406.88 1017.62,1406.88 1017.63,1406.88 1017.64,1406.88 1017.65,1406.88 1017.66,1406.88 1017.67,1406.88 1017.68,1406.88 1017.69,1406.88 1017.7,1406.88 1017.7,1406.88 1017.71,1406.88 1017.72,1406.88 1017.73,1406.88 1017.74,1406.88 1017.75,1406.88 1017.76,1406.88 1017.77,1406.88 1017.78,1406.88 1017.79,1406.88 1017.8,1406.88 1017.81,1406.88 1017.82,1406.88 1017.82,1406.88 1017.83,1406.88 1017.84,1406.88 1017.85,1406.88 1017.86,1406.88 1017.87,1406.88 1017.88,1406.88 1017.89,1406.88 1017.9,1406.88 1017.91,1406.88 1017.92,1406.88 1017.93,1406.88 1017.93,1406.88 1017.94,1406.88 1017.95,1406.88 1017.96,1406.88 1017.97,1406.88 1017.98,1406.88 1017.99,1406.88 1018,1406.88 1018.01,1406.88 1018.02,1406.88 1018.03,1406.88 1018.04,1406.88 1018.04,1406.88 1018.05,1406.88 1018.06,1406.88 1018.07,1406.88 1018.08,1406.88 1018.09,1406.88 1018.1,1406.88 1018.11,1406.88 1018.12,1406.88 1018.13,1406.88 1018.14,1406.88 1018.15,1406.88 1018.16,1406.88 1018.16,1406.88 1018.17,1406.88 1018.18,1406.88 1018.19,1406.88 1018.2,1406.88 1018.21,1406.88 1018.22,1406.88 1018.23,1406.88 1018.24,1406.88 1018.25,1406.88 1018.26,1406.88 1018.27,1406.88 1018.27,1406.88 1018.28,1406.88 1018.29,1406.88 1018.3,1406.88 1018.31,1406.88 1018.32,1406.88 1018.33,1406.88 1018.34,1406.88 1018.35,1406.88 1018.36,1406.88 1018.37,1406.88 1018.38,1406.88 1018.38,1406.88 1018.39,1406.88 1018.4,1406.88 1018.41,1406.88 1018.42,1406.88 1018.43,1406.88 1018.44,1406.88 1018.45,1406.88 1018.46,1406.88 1018.47,1406.88 1018.48,1406.88 1018.49,1406.88 1018.5,1406.88 1018.5,1406.88 1018.51,1406.88 1018.52,1406.88 1018.53,1406.88 1018.54,1406.88 1018.55,1406.88 1018.56,1406.88 1018.57,1406.88 1018.58,1406.88 1018.59,1406.88 1018.6,1406.88 1018.61,1406.88 1018.61,1406.88 1018.62,1406.88 1018.63,1406.88 1018.64,1406.88 1018.65,1406.88 1018.66,1406.88 1018.67,1406.88 1018.68,1406.88 1018.69,1406.88 1018.7,1406.88 1018.71,1406.88 1018.72,1406.88 1018.72,1406.88 1018.73,1406.88 1018.74,1406.88 1018.75,1406.88 1018.76,1406.88 1018.77,1406.88 1018.78,1406.88 1018.79,1406.88 1018.8,1406.88 1018.81,1406.88 1018.82,1406.88 1018.83,1406.88 1018.84,1406.88 1018.84,1406.88 1018.85,1406.88 1018.86,1406.88 1018.87,1406.88 1018.88,1406.88 1018.89,1406.88 1018.9,1406.88 1018.91,1406.88 1018.92,1406.88 1018.93,1406.88 1018.94,1406.88 1018.95,1406.88 1018.95,1406.88 1018.96,1406.88 1018.97,1406.88 1018.98,1406.88 1018.99,1406.88 1019,1406.88 1019.01,1406.88 1019.02,1406.88 1019.03,1406.88 1019.04,1406.88 1019.05,1406.88 1019.06,1406.88 1019.06,1406.88 1019.07,1406.88 1019.08,1406.88 1019.09,1406.88 1019.1,1406.88 1019.11,1406.88 1019.12,1406.88 1019.13,1406.88 1019.14,1406.88 1019.15,1406.88 1019.16,1406.88 1019.17,1406.88 1019.18,1406.88 1019.18,1406.88 1019.19,1406.88 1019.2,1406.88 1019.21,1406.88 1019.22,1406.88 1019.23,1406.88 1019.24,1406.88 1019.25,1406.88 1019.26,1406.88 1019.27,1406.88 1019.28,1406.88 1019.29,1406.88 1019.29,1406.88 1019.3,1406.88 1019.31,1406.88 1019.32,1406.88 1019.33,1406.88 1019.34,1406.88 1019.35,1406.88 1019.36,1406.88 1019.37,1406.88 1019.38,1406.88 1019.39,1406.88 1019.4,1406.88 1019.4,1406.88 1019.41,1406.88 1019.42,1406.88 1019.43,1406.88 1019.44,1406.88 1019.45,1406.88 1019.46,1406.88 1019.47,1406.88 1019.48,1406.88 1019.49,1406.88 1019.5,1406.88 1019.51,1406.88 1019.52,1406.88 1019.52,1406.88 1019.53,1406.88 1019.54,1406.88 1019.55,1406.88 1019.56,1406.88 1019.57,1406.88 1019.58,1406.88 1019.59,1406.88 1019.6,1406.88 1019.61,1406.88 1019.62,1406.88 1019.63,1406.88 1019.63,1406.88 1019.64,1406.88 1019.65,1406.88 1019.66,1406.88 1019.67,1406.88 1019.68,1406.88 1019.69,1406.88 1019.7,1406.88 1019.71,1406.88 1019.72,1406.88 1019.73,1406.88 1019.74,1406.88 1019.74,1406.88 1019.75,1406.88 1019.76,1406.88 1019.77,1406.88 1019.78,1406.88 1019.79,1406.88 1019.8,1406.88 1019.81,1406.88 1019.82,1406.88 1019.83,1406.88 1019.84,1406.88 1019.85,1406.88 1019.86,1406.88 1019.86,1406.88 1019.87,1406.88 1019.88,1406.88 1019.89,1406.88 1019.9,1406.88 1019.91,1406.88 1019.92,1406.88 1019.93,1406.88 1019.94,1406.88 1019.95,1406.88 1019.96,1406.88 1019.97,1406.88 1019.97,1406.88 1019.98,1406.88 1019.99,1406.88 1020,1406.88 1020.01,1406.88 1020.02,1406.88 1020.03,1406.88 1020.04,1406.88 1020.05,1406.88 1020.06,1406.88 1020.07,1406.88 1020.08,1406.88 1020.08,1406.88 1020.09,1406.88 1020.1,1406.88 1020.11,1406.88 1020.12,1406.88 1020.13,1406.88 1020.14,1406.88 1020.15,1406.88 1020.16,1406.88 1020.17,1406.88 1020.18,1406.88 1020.19,1406.88 1020.2,1406.88 1020.2,1406.88 1020.21,1406.88 1020.22,1406.88 1020.23,1406.88 1020.24,1406.88 1020.25,1406.88 1020.26,1406.88 1020.27,1406.88 1020.28,1406.88 1020.29,1406.88 1020.3,1406.88 1020.31,1406.88 1020.31,1406.88 1020.32,1406.88 1020.33,1406.88 1020.34,1406.88 1020.35,1406.88 1020.36,1406.88 1020.37,1406.88 1020.38,1406.88 1020.39,1406.88 1020.4,1406.88 1020.41,1406.88 1020.42,1406.88 1020.42,1406.88 1020.43,1406.88 1020.44,1406.88 1020.45,1406.88 1020.46,1406.88 1020.47,1406.88 1020.48,1406.88 1020.49,1406.88 1020.5,1406.88 1020.51,1406.88 1020.52,1406.88 1020.53,1406.88 1020.54,1406.88 1020.54,1406.88 1020.55,1406.88 1020.56,1406.88 1020.57,1406.88 1020.58,1406.88 1020.59,1406.88 1020.6,1406.88 1020.61,1406.88 1020.62,1406.88 1020.63,1406.88 1020.64,1406.88 1020.65,1406.88 1020.65,1406.88 1020.66,1406.88 1020.67,1406.88 1020.68,1406.88 1020.69,1406.88 1020.7,1406.88 1020.71,1406.88 1020.72,1406.88 1020.73,1406.88 1020.74,1406.88 1020.75,1406.88 1020.76,1406.88 1020.76,1406.88 1020.77,1406.88 1020.78,1406.88 1020.79,1406.88 1020.8,1406.88 1020.81,1406.88 1020.82,1406.88 1020.83,1406.88 1020.84,1406.88 1020.85,1406.88 1020.86,1406.88 1020.87,1406.88 1020.88,1406.88 1020.88,1406.88 1020.89,1406.88 1020.9,1406.88 1020.91,1406.88 1020.92,1406.88 1020.93,1406.88 1020.94,1406.88 1020.95,1406.88 1020.96,1406.88 1020.97,1406.88 1020.98,1406.88 1020.99,1406.88 1020.99,1406.88 1021,1406.88 1021.01,1406.88 1021.02,1406.88 1021.03,1406.88 1021.04,1406.88 1021.05,1406.88 1021.06,1406.88 1021.07,1406.88 1021.08,1406.88 1021.09,1406.88 1021.1,1406.88 1021.1,1406.88 1021.11,1406.88 1021.12,1406.88 1021.13,1406.88 1021.14,1406.88 1021.15,1406.88 1021.16,1406.88 1021.17,1406.88 1021.18,1406.88 1021.19,1406.88 1021.2,1406.88 1021.21,1406.88 1021.22,1406.88 1021.22,1406.88 1021.23,1406.88 1021.24,1406.88 1021.25,1406.88 1021.26,1406.88 1021.27,1406.88 1021.28,1406.88 1021.29,1406.88 1021.3,1406.88 1021.31,1406.88 1021.32,1406.88 1021.33,1406.88 1021.33,1406.88 1021.34,1406.88 1021.35,1406.88 1021.36,1406.88 1021.37,1406.88 1021.38,1406.88 1021.39,1406.88 1021.4,1406.88 1021.41,1406.88 1021.42,1406.88 1021.43,1406.88 1021.44,1406.88 1021.44,1406.88 1021.45,1406.88 1021.46,1406.88 1021.47,1406.88 1021.48,1406.88 1021.49,1406.88 1021.5,1406.88 1021.51,1406.88 1021.52,1406.88 1021.53,1406.88 1021.54,1406.88 1021.55,1406.88 1021.56,1406.88 1021.56,1406.88 1021.57,1406.88 1021.58,1406.88 1021.59,1406.88 1021.6,1406.88 1021.61,1406.88 1021.62,1406.88 1021.63,1406.88 1021.64,1406.88 1021.65,1406.88 1021.66,1406.88 1021.67,1406.88 1021.67,1406.88 1021.68,1406.88 1021.69,1406.88 1021.7,1406.88 1021.71,1406.88 1021.72,1406.88 1021.73,1406.88 1021.74,1406.88 1021.75,1406.88 1021.76,1406.88 1021.77,1406.88 1021.78,1406.88 1021.78,1406.88 1021.79,1406.88 1021.8,1406.88 1021.81,1406.88 1021.82,1406.88 1021.83,1406.88 1021.84,1406.88 1021.85,1406.88 1021.86,1406.88 1021.87,1406.88 1021.88,1406.88 1021.89,1406.88 1021.9,1406.88 1021.9,1406.88 1021.91,1406.88 1021.92,1406.88 1021.93,1406.88 1021.94,1406.88 1021.95,1406.88 1021.96,1406.88 1021.97,1406.88 1021.98,1406.88 1021.99,1406.88 1022,1406.88 1022.01,1406.88 1022.01,1406.88 1022.02,1406.88 1022.03,1406.88 1022.04,1406.88 1022.05,1406.88 1022.06,1406.88 1022.07,1406.88 1022.08,1406.88 1022.09,1406.88 1022.1,1406.88 1022.11,1406.88 1022.12,1406.88 1022.12,1406.88 1022.13,1406.88 1022.14,1406.88 1022.15,1406.88 1022.16,1406.88 1022.17,1406.88 1022.18,1406.88 1022.19,1406.88 1022.2,1406.88 1022.21,1406.88 1022.22,1406.88 1022.23,1406.88 1022.24,1406.88 1022.24,1406.88 1022.25,1406.88 1022.26,1406.88 1022.27,1406.88 1022.28,1406.88 1022.29,1406.88 1022.3,1406.88 1022.31,1406.88 1022.32,1406.88 1022.33,1406.88 1022.34,1406.88 1022.35,1406.88 1022.35,1406.88 1022.36,1406.88 1022.37,1406.88 1022.38,1406.88 1022.39,1406.88 1022.4,1406.88 1022.41,1406.88 1022.42,1406.88 1022.43,1406.88 1022.44,1406.88 1022.45,1406.88 1022.46,1406.88 1022.46,1406.88 1022.47,1406.88 1022.48,1406.88 1022.49,1406.88 1022.5,1406.88 1022.51,1406.88 1022.52,1406.88 1022.53,1406.88 1022.54,1406.88 1022.55,1406.88 1022.56,1406.88 1022.57,1406.88 1022.58,1406.88 1022.58,1406.88 1022.59,1406.88 1022.6,1406.88 1022.61,1406.88 1022.62,1406.88 1022.63,1406.88 1022.64,1406.88 1022.65,1406.88 1022.66,1406.88 1022.67,1406.88 1022.68,1406.88 1022.69,1406.88 1022.69,1406.88 1022.7,1406.88 1022.71,1406.88 1022.72,1406.88 1022.73,1406.88 1022.74,1406.88 1022.75,1406.88 1022.76,1406.88 1022.77,1406.88 1022.78,1406.88 1022.79,1406.88 1022.8,1406.88 1022.8,1406.88 1022.81,1406.88 1022.82,1406.88 1022.83,1406.88 1022.84,1406.88 1022.85,1406.88 1022.86,1406.88 1022.87,1406.88 1022.88,1406.88 1022.89,1406.88 1022.9,1406.88 1022.91,1406.88 1022.92,1406.88 1022.92,1406.88 1022.93,1406.88 1022.94,1406.88 1022.95,1406.88 1022.96,1406.88 1022.97,1406.88 1022.98,1406.88 1022.99,1406.88 1023,1406.88 1023.01,1406.88 1023.02,1406.88 1023.03,1406.88 1023.03,1406.88 1023.04,1406.88 1023.05,1406.88 1023.06,1406.88 1023.07,1406.88 1023.08,1406.88 1023.09,1406.88 1023.1,1406.88 1023.11,1406.88 1023.12,1406.88 1023.13,1406.88 1023.14,1406.88 1023.15,1406.88 1023.15,1406.88 1023.16,1406.88 1023.17,1406.88 1023.18,1406.88 1023.19,1406.88 1023.2,1406.88 1023.21,1406.88 1023.22,1406.88 1023.23,1406.88 1023.24,1406.88 1023.25,1406.88 1023.26,1406.88 1023.26,1406.88 1023.27,1406.88 1023.28,1406.88 1023.29,1406.88 1023.3,1406.88 1023.31,1406.88 1023.32,1406.88 1023.33,1406.88 1023.34,1406.88 1023.35,1406.88 1023.36,1406.88 1023.37,1406.88 1023.37,1406.88 1023.38,1406.88 1023.39,1406.88 1023.4,1406.88 1023.41,1406.88 1023.42,1406.88 1023.43,1406.88 1023.44,1406.88 1023.45,1406.88 1023.46,1406.88 1023.47,1406.88 1023.48,1406.88 1023.49,1406.88 1023.49,1406.88 1023.5,1406.88 1023.51,1406.88 1023.52,1406.88 1023.53,1406.88 1023.54,1406.88 1023.55,1406.88 1023.56,1406.88 1023.57,1406.88 1023.58,1406.88 1023.59,1406.88 1023.6,1406.88 1023.6,1406.88 1023.61,1406.88 1023.62,1406.88 1023.63,1406.88 1023.64,1406.88 1023.65,1406.88 1023.66,1406.88 1023.67,1406.88 1023.68,1406.88 1023.69,1406.88 1023.7,1406.88 1023.71,1406.88 1023.71,1406.88 1023.72,1406.88 1023.73,1406.88 1023.74,1406.88 1023.75,1406.88 1023.76,1406.88 1023.77,1406.88 1023.78,1406.88 1023.79,1406.88 1023.8,1406.88 1023.81,1406.88 1023.82,1406.88 1023.83,1406.88 1023.83,1406.88 1023.84,1406.88 1023.85,1406.88 1023.86,1406.88 1023.87,1406.88 1023.88,1406.88 1023.89,1406.88 1023.9,1406.88 1023.91,1406.88 1023.92,1406.88 1023.93,1406.88 1023.94,1406.88 1023.94,1406.88 1023.95,1406.88 1023.96,1406.88 1023.97,1406.88 1023.98,1406.88 1023.99,1406.88 1024,1406.88 1024.01,1406.88 1024.02,1406.88 1024.03,1406.88 1024.04,1406.88 1024.05,1406.88 1024.05,1406.88 1024.06,1406.88 1024.07,1406.88 1024.08,1406.88 1024.09,1406.88 1024.1,1406.88 1024.11,1406.88 1024.12,1406.88 1024.13,1406.88 1024.14,1406.88 1024.15,1406.88 1024.16,1406.88 1024.17,1406.88 1024.17,1406.88 1024.18,1406.88 1024.19,1406.88 1024.2,1406.88 1024.21,1406.88 1024.22,1406.88 1024.23,1406.88 1024.24,1406.88 1024.25,1406.88 1024.26,1406.88 1024.27,1406.88 1024.28,1406.88 1024.28,1406.88 1024.29,1406.88 1024.3,1406.88 1024.31,1406.88 1024.32,1406.88 1024.33,1406.88 1024.34,1406.88 1024.35,1406.88 1024.36,1406.88 1024.37,1406.88 1024.38,1406.88 1024.39,1406.88 1024.39,1406.88 1024.4,1406.88 1024.41,1406.88 1024.42,1406.88 1024.43,1406.88 1024.44,1406.88 1024.45,1406.88 1024.46,1406.88 1024.47,1406.88 1024.48,1406.88 1024.49,1406.88 1024.5,1406.88 1024.51,1406.88 1024.51,1406.88 1024.52,1406.88 1024.53,1406.88 1024.54,1406.88 1024.55,1406.88 1024.56,1406.88 1024.57,1406.88 1024.58,1406.88 1024.59,1406.88 1024.6,1406.88 1024.61,1406.88 1024.62,1406.88 1024.62,1406.88 1024.63,1406.88 1024.64,1406.88 1024.65,1406.88 1024.66,1406.88 1024.67,1406.88 1024.68,1406.88 1024.69,1406.88 1024.7,1406.88 1024.71,1406.88 1024.72,1406.88 1024.73,1406.88 1024.73,1406.88 1024.74,1406.88 1024.75,1406.88 1024.76,1406.88 1024.77,1406.88 1024.78,1406.88 1024.79,1406.88 1024.8,1406.88 1024.81,1406.88 1024.82,1406.88 1024.83,1406.88 1024.84,1406.88 1024.85,1406.88 1024.85,1406.88 1024.86,1406.88 1024.87,1406.88 1024.88,1406.88 1024.89,1406.88 1024.9,1406.88 1024.91,1406.88 1024.92,1406.88 1024.93,1406.88 1024.94,1406.88 1024.95,1406.88 1024.96,1406.88 1024.96,1406.88 1024.97,1406.88 1024.98,1406.88 1024.99,1406.88 1025,1406.88 1025.01,1406.88 1025.02,1406.88 1025.03,1406.88 1025.04,1406.88 1025.05,1406.88 1025.06,1406.88 1025.07,1406.88 1025.07,1406.88 1025.08,1406.88 1025.09,1406.88 1025.1,1406.88 1025.11,1406.88 1025.12,1406.88 1025.13,1406.88 1025.14,1406.88 1025.15,1406.88 1025.16,1406.88 1025.17,1406.88 1025.18,1406.88 1025.19,1406.88 1025.19,1406.88 1025.2,1406.88 1025.21,1406.88 1025.22,1406.88 1025.23,1406.88 1025.24,1406.88 1025.25,1406.88 1025.26,1406.88 1025.27,1406.88 1025.28,1406.88 1025.29,1406.88 1025.3,1406.88 1025.3,1406.88 1025.31,1406.88 1025.32,1406.88 1025.33,1406.88 1025.34,1406.88 1025.35,1406.88 1025.36,1406.88 1025.37,1406.88 1025.38,1406.88 1025.39,1406.88 1025.4,1406.88 1025.41,1406.88 1025.41,1406.88 1025.42,1406.88 1025.43,1406.88 1025.44,1406.88 1025.45,1406.88 1025.46,1406.88 1025.47,1406.88 1025.48,1406.88 1025.49,1406.88 1025.5,1406.88 1025.51,1406.88 1025.52,1406.88 1025.53,1406.88 1025.53,1406.88 1025.54,1406.88 1025.55,1406.88 1025.56,1406.88 1025.57,1406.88 1025.58,1406.88 1025.59,1406.88 1025.6,1406.88 1025.61,1406.88 1025.62,1406.88 1025.63,1406.88 1025.64,1406.88 1025.64,1406.88 1025.65,1406.88 1025.66,1406.88 1025.67,1406.88 1025.68,1406.88 1025.69,1406.88 1025.7,1406.88 1025.71,1406.88 1025.72,1406.88 1025.73,1406.88 1025.74,1406.88 1025.75,1406.88 1025.75,1406.88 1025.76,1406.88 1025.77,1406.88 1025.78,1406.88 1025.79,1406.88 1025.8,1406.88 1025.81,1406.88 1025.82,1406.88 1025.83,1406.88 1025.84,1406.88 1025.85,1406.88 1025.86,1406.88 1025.87,1406.88 1025.87,1406.88 1025.88,1406.88 1025.89,1406.88 1025.9,1406.88 1025.91,1406.88 1025.92,1406.88 1025.93,1406.88 1025.94,1406.88 1025.95,1406.88 1025.96,1406.88 1025.97,1406.88 1025.98,1406.88 1025.98,1406.88 1025.99,1406.88 1026,1406.88 1026.01,1406.88 1026.02,1406.88 1026.03,1406.88 1026.04,1406.88 1026.05,1406.88 1026.06,1406.88 1026.07,1406.88 1026.08,1406.88 1026.09,1406.88 1026.09,1406.88 1026.1,1406.88 1026.11,1406.88 1026.12,1406.88 1026.13,1406.88 1026.14,1406.88 1026.15,1406.88 1026.16,1406.88 1026.17,1406.88 1026.18,1406.88 1026.19,1406.88 1026.2,1406.88 1026.21,1406.88 1026.21,1406.88 1026.22,1406.88 1026.23,1406.88 1026.24,1406.88 1026.25,1406.88 1026.26,1406.88 1026.27,1406.88 1026.28,1406.88 1026.29,1406.88 1026.3,1406.88 1026.31,1406.88 1026.32,1406.88 1026.32,1406.88 1026.33,1406.88 1026.34,1406.88 1026.35,1406.88 1026.36,1406.88 1026.37,1406.88 1026.38,1406.88 1026.39,1406.88 1026.4,1406.88 1026.41,1406.88 1026.42,1406.88 1026.43,1406.88 1026.43,1406.88 1026.44,1406.88 1026.45,1406.88 1026.46,1406.88 1026.47,1406.88 1026.48,1406.88 1026.49,1406.88 1026.5,1406.88 1026.51,1406.88 1026.52,1406.88 1026.53,1406.88 1026.54,1406.88 1026.55,1406.88 1026.55,1406.88 1026.56,1406.88 1026.57,1406.88 1026.58,1406.88 1026.59,1406.88 1026.6,1406.88 1026.61,1406.88 1026.62,1406.88 1026.63,1406.88 1026.64,1406.88 1026.65,1406.88 1026.66,1406.88 1026.66,1406.88 1026.67,1406.88 1026.68,1406.88 1026.69,1406.88 1026.7,1406.88 1026.71,1406.88 1026.72,1406.88 1026.73,1406.88 1026.74,1406.88 1026.75,1406.88 1026.76,1406.88 1026.77,1406.88 1026.77,1406.88 1026.78,1406.88 1026.79,1406.88 1026.8,1406.88 1026.81,1406.88 1026.82,1406.88 1026.83,1406.88 1026.84,1406.88 1026.85,1406.88 1026.86,1406.88 1026.87,1406.88 1026.88,1406.88 1026.89,1406.88 1026.89,1406.88 1026.9,1406.88 1026.91,1406.88 1026.92,1406.88 1026.93,1406.88 1026.94,1406.88 1026.95,1406.88 1026.96,1406.88 1026.97,1406.88 1026.98,1406.88 1026.99,1406.88 1027,1406.88 1027,1406.88 1027.01,1406.88 1027.02,1406.88 1027.03,1406.88 1027.04,1406.88 1027.05,1406.88 1027.06,1406.88 1027.07,1406.88 1027.08,1406.88 1027.09,1406.88 1027.1,1406.88 1027.11,1406.88 1027.11,1406.88 1027.12,1406.88 1027.13,1406.88 1027.14,1406.88 1027.15,1406.88 1027.16,1406.88 1027.17,1406.88 1027.18,1406.88 1027.19,1406.88 1027.2,1406.88 1027.21,1406.88 1027.22,1406.88 1027.23,1406.88 1027.23,1406.88 1027.24,1406.88 1027.25,1406.88 1027.26,1406.88 1027.27,1406.88 1027.28,1406.88 1027.29,1406.88 1027.3,1406.88 1027.31,1406.88 1027.32,1406.88 1027.33,1406.88 1027.34,1406.88 1027.34,1406.88 1027.35,1406.88 1027.36,1406.88 1027.37,1406.88 1027.38,1406.88 1027.39,1406.88 1027.4,1406.88 1027.41,1406.88 1027.42,1406.88 1027.43,1406.88 1027.44,1406.88 1027.45,1406.88 1027.45,1406.88 1027.46,1406.88 1027.47,1406.88 1027.48,1406.88 1027.49,1406.88 1027.5,1406.88 1027.51,1406.88 1027.52,1406.88 1027.53,1406.88 1027.54,1406.88 1027.55,1406.88 1027.56,1406.88 1027.57,1406.88 1027.57,1406.88 1027.58,1406.88 1027.59,1406.88 1027.6,1406.88 1027.61,1406.88 1027.62,1406.88 1027.63,1406.88 1027.64,1406.88 1027.65,1406.88 1027.66,1406.88 1027.67,1406.88 1027.68,1406.88 1027.68,1406.88 1027.69,1406.88 1027.7,1406.88 1027.71,1406.88 1027.72,1406.88 1027.73,1406.88 1027.74,1406.88 1027.75,1406.88 1027.76,1406.88 1027.77,1406.88 1027.78,1406.88 1027.79,1406.88 1027.79,1406.88 1027.8,1406.88 1027.81,1406.88 1027.82,1406.88 1027.83,1406.88 1027.84,1406.88 1027.85,1406.88 1027.86,1406.88 1027.87,1406.88 1027.88,1406.88 1027.89,1406.88 1027.9,1406.88 1027.91,1406.88 1027.91,1406.88 1027.92,1406.88 1027.93,1406.88 1027.94,1406.88 1027.95,1406.88 1027.96,1406.88 1027.97,1406.88 1027.98,1406.88 1027.99,1406.88 1028,1406.88 1028.01,1406.88 1028.02,1406.88 1028.02,1406.88 1028.03,1406.88 1028.04,1406.88 1028.05,1406.88 1028.06,1406.88 1028.07,1406.88 1028.08,1406.88 1028.09,1406.88 1028.1,1406.88 1028.11,1406.88 1028.12,1406.88 1028.13,1406.88 1028.13,1406.88 1028.14,1406.88 1028.15,1406.88 1028.16,1406.88 1028.17,1406.88 1028.18,1406.88 1028.19,1406.88 1028.2,1406.88 1028.21,1406.88 1028.22,1406.88 1028.23,1406.88 1028.24,1406.88 1028.25,1406.88 1028.25,1406.88 1028.26,1406.88 1028.27,1406.88 1028.28,1406.88 1028.29,1406.88 1028.3,1406.88 1028.31,1406.88 1028.32,1406.88 1028.33,1406.88 1028.34,1406.88 1028.35,1406.88 1028.36,1406.88 1028.36,1406.88 1028.37,1406.88 1028.38,1406.88 1028.39,1406.88 1028.4,1406.88 1028.41,1406.88 1028.42,1406.88 1028.43,1406.88 1028.44,1406.88 1028.45,1406.88 1028.46,1406.88 1028.47,1406.88 1028.47,1406.88 1028.48,1406.88 1028.49,1406.88 1028.5,1406.88 1028.51,1406.88 1028.52,1406.88 1028.53,1406.88 1028.54,1406.88 1028.55,1406.88 1028.56,1406.88 1028.57,1406.88 1028.58,1406.88 1028.59,1406.88 1028.59,1406.88 1028.6,1406.88 1028.61,1406.88 1028.62,1406.88 1028.63,1406.88 1028.64,1406.88 1028.65,1406.88 1028.66,1406.88 1028.67,1406.88 1028.68,1406.88 1028.69,1406.88 1028.7,1406.88 1028.7,1406.88 1028.71,1406.88 1028.72,1406.88 1028.73,1406.88 1028.74,1406.88 1028.75,1406.88 1028.76,1406.88 1028.77,1406.88 1028.78,1406.88 1028.79,1406.88 1028.8,1406.88 1028.81,1406.88 1028.81,1406.88 1028.82,1406.88 1028.83,1406.88 1028.84,1406.88 1028.85,1406.88 1028.86,1406.88 1028.87,1406.88 1028.88,1406.88 1028.89,1406.88 1028.9,1406.88 1028.91,1406.88 1028.92,1406.88 1028.93,1406.88 1028.93,1406.88 1028.94,1406.88 1028.95,1406.88 1028.96,1406.88 1028.97,1406.88 1028.98,1406.88 1028.99,1406.88 1029,1406.88 1029.01,1406.88 1029.02,1406.88 1029.03,1406.88 1029.04,1406.88 1029.04,1406.88 1029.05,1406.88 1029.06,1406.88 1029.07,1406.88 1029.08,1406.88 1029.09,1406.88 1029.1,1406.88 1029.11,1406.88 1029.12,1406.88 1029.13,1406.88 1029.14,1406.88 1029.15,1406.88 1029.15,1406.88 1029.16,1406.88 1029.17,1406.88 1029.18,1406.88 1029.19,1406.88 1029.2,1406.88 1029.21,1406.88 1029.22,1406.88 1029.23,1406.88 1029.24,1406.88 1029.25,1406.88 1029.26,1406.88 1029.27,1406.88 1029.27,1406.88 1029.28,1406.88 1029.29,1406.88 1029.3,1406.88 1029.31,1406.88 1029.32,1406.88 1029.33,1406.88 1029.34,1406.88 1029.35,1406.88 1029.36,1406.88 1029.37,1406.88 1029.38,1406.88 1029.38,1406.88 1029.39,1406.88 1029.4,1406.88 1029.41,1406.88 1029.42,1406.88 1029.43,1406.88 1029.44,1406.88 1029.45,1406.88 1029.46,1406.88 1029.47,1406.88 1029.48,1406.88 1029.49,1406.88 1029.49,1406.88 1029.5,1406.88 1029.51,1406.88 1029.52,1406.88 1029.53,1406.88 1029.54,1406.88 1029.55,1406.88 1029.56,1406.88 1029.57,1406.88 1029.58,1406.88 1029.59,1406.88 1029.6,1406.88 1029.61,1406.88 1029.61,1406.88 1029.62,1406.88 1029.63,1406.88 1029.64,1406.88 1029.65,1406.88 1029.66,1406.88 1029.67,1406.88 1029.68,1406.88 1029.69,1406.88 1029.7,1406.88 1029.71,1406.88 1029.72,1406.88 1029.72,1406.88 1029.73,1406.88 1029.74,1406.88 1029.75,1406.88 1029.76,1406.88 1029.77,1406.88 1029.78,1406.88 1029.79,1406.88 1029.8,1406.88 1029.81,1406.88 1029.82,1406.88 1029.83,1406.88 1029.83,1406.88 1029.84,1406.88 1029.85,1406.88 1029.86,1406.88 1029.87,1406.88 1029.88,1406.88 1029.89,1406.88 1029.9,1406.88 1029.91,1406.88 1029.92,1406.88 1029.93,1406.88 1029.94,1406.88 1029.95,1406.88 1029.95,1406.88 1029.96,1406.88 1029.97,1406.88 1029.98,1406.88 1029.99,1406.88 1030,1406.88 1030.01,1406.88 1030.02,1406.88 1030.03,1406.88 1030.04,1406.88 1030.05,1406.88 1030.06,1406.88 1030.06,1406.88 1030.07,1406.88 1030.08,1406.88 1030.09,1406.88 1030.1,1406.88 1030.11,1406.88 1030.12,1406.88 1030.13,1406.88 1030.14,1406.88 1030.15,1406.88 1030.16,1406.88 1030.17,1406.88 1030.17,1406.88 1030.18,1406.88 1030.19,1406.88 1030.2,1406.88 1030.21,1406.88 1030.22,1406.88 1030.23,1406.88 1030.24,1406.88 1030.25,1406.88 1030.26,1406.88 1030.27,1406.88 1030.28,1406.88 1030.29,1406.88 1030.29,1406.88 1030.3,1406.88 1030.31,1406.88 1030.32,1406.88 1030.33,1406.88 1030.34,1406.88 1030.35,1406.88 1030.36,1406.88 1030.37,1406.88 1030.38,1406.88 1030.39,1406.88 1030.4,1406.88 1030.4,1406.88 1030.41,1406.88 1030.42,1406.88 1030.43,1406.88 1030.44,1406.88 1030.45,1406.88 1030.46,1406.88 1030.47,1406.88 1030.48,1406.88 1030.49,1406.88 1030.5,1406.88 1030.51,1406.88 1030.51,1406.88 1030.52,1406.88 1030.53,1406.88 1030.54,1406.88 1030.55,1406.88 1030.56,1406.88 1030.57,1406.88 1030.58,1406.88 1030.59,1406.88 1030.6,1406.88 1030.61,1406.88 1030.62,1406.88 1030.63,1406.88 1030.63,1406.88 1030.64,1406.88 1030.65,1406.88 1030.66,1406.88 1030.67,1406.88 1030.68,1406.88 1030.69,1406.88 1030.7,1406.88 1030.71,1406.88 1030.72,1406.88 1030.73,1406.88 1030.74,1406.88 1030.74,1406.88 1030.75,1406.88 1030.76,1406.88 1030.77,1406.88 1030.78,1406.88 1030.79,1406.88 1030.8,1406.88 1030.81,1406.88 1030.82,1406.88 1030.83,1406.88 1030.84,1406.88 1030.85,1406.88 1030.85,1406.88 1030.86,1406.88 1030.87,1406.88 1030.88,1406.88 1030.89,1406.88 1030.9,1406.88 1030.91,1406.88 1030.92,1406.88 1030.93,1406.88 1030.94,1406.88 1030.95,1406.88 1030.96,1406.88 1030.97,1406.88 1030.97,1406.88 1030.98,1406.88 1030.99,1406.88 1031,1406.88 1031.01,1406.88 1031.02,1406.88 1031.03,1406.88 1031.04,1406.88 1031.05,1406.88 1031.06,1406.88 1031.07,1406.88 1031.08,1406.88 1031.08,1406.88 1031.09,1406.88 1031.1,1406.88 1031.11,1406.88 1031.12,1406.88 1031.13,1406.88 1031.14,1406.88 1031.15,1406.88 1031.16,1406.88 1031.17,1406.88 1031.18,1406.88 1031.19,1406.88 1031.19,1406.88 1031.2,1406.88 1031.21,1406.88 1031.22,1406.88 1031.23,1406.88 1031.24,1406.88 1031.25,1406.88 1031.26,1406.88 1031.27,1406.88 1031.28,1406.88 1031.29,1406.88 1031.3,1406.88 1031.31,1406.88 1031.31,1406.88 1031.32,1406.88 1031.33,1406.88 1031.34,1406.88 1031.35,1406.88 1031.36,1406.88 1031.37,1406.88 1031.38,1406.88 1031.39,1406.88 1031.4,1406.88 1031.41,1406.88 1031.42,1406.88 1031.42,1406.88 1031.43,1406.88 1031.44,1406.88 1031.45,1406.88 1031.46,1406.88 1031.47,1406.88 1031.48,1406.88 1031.49,1406.88 1031.5,1406.88 1031.51,1406.88 1031.52,1406.88 1031.53,1406.88 1031.53,1406.88 1031.54,1406.88 1031.55,1406.88 1031.56,1406.88 1031.57,1406.88 1031.58,1406.88 1031.59,1406.88 1031.6,1406.88 1031.61,1406.88 1031.62,1406.88 1031.63,1406.88 1031.64,1406.88 1031.65,1406.88 1031.65,1406.88 1031.66,1406.88 1031.67,1406.88 1031.68,1406.88 1031.69,1406.88 1031.7,1406.88 1031.71,1406.88 1031.72,1406.88 1031.73,1406.88 1031.74,1406.88 1031.75,1406.88 1031.76,1406.88 1031.76,1406.88 1031.77,1406.88 1031.78,1406.88 1031.79,1406.88 1031.8,1406.88 1031.81,1406.88 1031.82,1406.88 1031.83,1406.88 1031.84,1406.88 1031.85,1406.88 1031.86,1406.88 1031.87,1406.88 1031.87,1406.88 1031.88,1406.88 1031.89,1406.88 1031.9,1406.88 1031.91,1406.88 1031.92,1406.88 1031.93,1406.88 1031.94,1406.88 1031.95,1406.88 1031.96,1406.88 1031.97,1406.88 1031.98,1406.88 1031.99,1406.88 1031.99,1406.88 1032,1406.88 1032.01,1406.88 1032.02,1406.88 1032.03,1406.88 1032.04,1406.88 1032.05,1406.88 1032.06,1406.88 1032.07,1406.88 1032.08,1406.88 1032.09,1406.88 1032.1,1406.88 1032.1,1406.88 1032.11,1406.88 1032.12,1406.88 1032.13,1406.88 1032.14,1406.88 1032.15,1406.88 1032.16,1406.88 1032.17,1406.88 1032.18,1406.88 1032.19,1406.88 1032.2,1406.88 1032.21,1406.88 1032.21,1406.88 1032.22,1406.88 1032.23,1406.88 1032.24,1406.88 1032.25,1406.88 1032.26,1406.88 1032.27,1406.88 1032.28,1406.88 1032.29,1406.88 1032.3,1406.88 1032.31,1406.88 1032.32,1406.88 1032.33,1406.88 1032.33,1406.88 1032.34,1406.88 1032.35,1406.88 1032.36,1406.88 1032.37,1406.88 1032.38,1406.88 1032.39,1406.88 1032.4,1406.88 1032.41,1406.88 1032.42,1406.88 1032.43,1406.88 1032.44,1406.88 1032.44,1406.88 1032.45,1406.88 1032.46,1406.88 1032.47,1406.88 1032.48,1406.88 1032.49,1406.88 1032.5,1406.88 1032.51,1406.88 1032.52,1406.88 1032.53,1406.88 1032.54,1406.88 1032.55,1406.88 1032.55,1406.88 1032.56,1406.88 1032.57,1406.88 1032.58,1406.88 1032.59,1406.88 1032.6,1406.88 1032.61,1406.88 1032.62,1406.88 1032.63,1406.88 1032.64,1406.88 1032.65,1406.88 1032.66,1406.88 1032.67,1406.88 1032.67,1406.88 1032.68,1406.88 1032.69,1406.88 1032.7,1406.88 1032.71,1406.88 1032.72,1406.88 1032.73,1406.88 1032.74,1406.88 1032.75,1406.88 1032.76,1406.88 1032.77,1406.88 1032.78,1406.88 1032.78,1406.88 1032.79,1406.88 1032.8,1406.88 1032.81,1406.88 1032.82,1406.88 1032.83,1406.88 1032.84,1406.88 1032.85,1406.88 1032.86,1406.88 1032.87,1406.88 1032.88,1406.88 1032.89,1406.88 1032.89,1406.88 1032.9,1406.88 1032.91,1406.88 1032.92,1406.88 1032.93,1406.88 1032.94,1406.88 1032.95,1406.88 1032.96,1406.88 1032.97,1406.88 1032.98,1406.88 1032.99,1406.88 1033,1406.88 1033.01,1406.88 1033.01,1406.88 1033.02,1406.88 1033.03,1406.88 1033.04,1406.88 1033.05,1406.88 1033.06,1406.88 1033.07,1406.88 1033.08,1406.88 1033.09,1406.88 1033.1,1406.88 1033.11,1406.88 1033.12,1406.88 1033.12,1406.88 1033.13,1406.88 1033.14,1406.88 1033.15,1406.88 1033.16,1406.88 1033.17,1406.88 1033.18,1406.88 1033.19,1406.88 1033.2,1406.88 1033.21,1406.88 1033.22,1406.88 1033.23,1406.88 1033.23,1406.88 1033.24,1406.88 1033.25,1406.88 1033.26,1406.88 1033.27,1406.88 1033.28,1406.88 1033.29,1406.88 1033.3,1406.88 1033.31,1406.88 1033.32,1406.88 1033.33,1406.88 1033.34,1406.88 1033.35,1406.88 1033.35,1406.88 1033.36,1406.88 1033.37,1406.88 1033.38,1406.88 1033.39,1406.88 1033.4,1406.88 1033.41,1406.88 1033.42,1406.88 1033.43,1406.88 1033.44,1406.88 1033.45,1406.88 1033.46,1406.88 1033.46,1406.88 1033.47,1406.88 1033.48,1406.88 1033.49,1406.88 1033.5,1406.88 1033.51,1406.88 1033.52,1406.88 1033.53,1406.88 1033.54,1406.88 1033.55,1406.88 1033.56,1406.88 1033.57,1406.88 1033.57,1406.88 1033.58,1406.88 1033.59,1406.88 1033.6,1406.88 1033.61,1406.88 1033.62,1406.88 1033.63,1406.88 1033.64,1406.88 1033.65,1406.88 1033.66,1406.88 1033.67,1406.88 1033.68,1406.88 1033.69,1406.88 1033.69,1406.88 1033.7,1406.88 1033.71,1406.88 1033.72,1406.88 1033.73,1406.88 1033.74,1406.88 1033.75,1406.88 1033.76,1406.88 1033.77,1406.88 1033.78,1406.88 1033.79,1406.88 1033.8,1406.88 1033.8,1406.88 1033.81,1406.88 1033.82,1406.88 1033.83,1406.88 1033.84,1406.88 1033.85,1406.88 1033.86,1406.88 1033.87,1406.88 1033.88,1406.88 1033.89,1406.88 1033.9,1406.88 1033.91,1406.88 1033.91,1406.88 1033.92,1406.88 1033.93,1406.88 1033.94,1406.88 1033.95,1406.88 1033.96,1406.88 1033.97,1406.88 1033.98,1406.88 1033.99,1406.88 1034,1406.88 1034.01,1406.88 1034.02,1406.88 1034.03,1406.88 1034.03,1406.88 1034.04,1406.88 1034.05,1406.88 1034.06,1406.88 1034.07,1406.88 1034.08,1406.88 1034.09,1406.88 1034.1,1406.88 1034.11,1406.88 1034.12,1406.88 1034.13,1406.88 1034.14,1406.88 1034.14,1406.88 1034.15,1406.88 1034.16,1406.88 1034.17,1406.88 1034.18,1406.88 1034.19,1406.88 1034.2,1406.88 1034.21,1406.88 1034.22,1406.88 1034.23,1406.88 1034.24,1406.88 1034.25,1406.88 1034.25,1406.88 1034.26,1406.88 1034.27,1406.88 1034.28,1406.88 1034.29,1406.88 1034.3,1406.88 1034.31,1406.88 1034.32,1406.88 1034.33,1406.88 1034.34,1406.88 1034.35,1406.88 1034.36,1406.88 1034.37,1406.88 1034.37,1406.88 1034.38,1406.88 1034.39,1406.88 1034.4,1406.88 1034.41,1406.88 1034.42,1406.88 1034.43,1406.88 1034.44,1406.88 1034.45,1406.88 1034.46,1406.88 1034.47,1406.88 1034.48,1406.88 1034.48,1406.88 1034.49,1406.88 1034.5,1406.88 1034.51,1406.88 1034.52,1406.88 1034.53,1406.88 1034.54,1406.88 1034.55,1406.88 1034.56,1406.88 1034.57,1406.88 1034.58,1406.88 1034.59,1406.88 1034.59,1406.88 1034.6,1406.88 1034.61,1406.88 1034.62,1406.88 1034.63,1406.88 1034.64,1406.88 1034.65,1406.88 1034.66,1406.88 1034.67,1406.88 1034.68,1406.88 1034.69,1406.88 1034.7,1406.88 1034.71,1406.88 1034.71,1406.88 1034.72,1406.88 1034.73,1406.88 1034.74,1406.88 1034.75,1406.88 1034.76,1406.88 1034.77,1406.88 1034.78,1406.88 1034.79,1406.88 1034.8,1406.88 1034.81,1406.88 1034.82,1406.88 1034.82,1406.88 1034.83,1406.88 1034.84,1406.88 1034.85,1406.88 1034.86,1406.88 1034.87,1406.88 1034.88,1406.88 1034.89,1406.88 1034.9,1406.88 1034.91,1406.88 1034.92,1406.88 1034.93,1406.88 1034.93,1406.88 1034.94,1406.88 1034.95,1406.88 1034.96,1406.88 1034.97,1406.88 1034.98,1406.88 1034.99,1406.88 1035,1406.88 1035.01,1406.88 1035.02,1406.88 1035.03,1406.88 1035.04,1406.88 1035.05,1406.88 1035.05,1406.88 1035.06,1406.88 1035.07,1406.88 1035.08,1406.88 1035.09,1406.88 1035.1,1406.88 1035.11,1406.88 1035.12,1406.88 1035.13,1406.88 1035.14,1406.88 1035.15,1406.88 1035.16,1406.88 1035.16,1406.88 1035.17,1406.88 1035.18,1406.88 1035.19,1406.88 1035.2,1406.88 1035.21,1406.88 1035.22,1406.88 1035.23,1406.88 1035.24,1406.88 1035.25,1406.88 1035.26,1406.88 1035.27,1406.88 1035.27,1406.88 1035.28,1406.88 1035.29,1406.88 1035.3,1406.88 1035.31,1406.88 1035.32,1406.88 1035.33,1406.88 1035.34,1406.88 1035.35,1406.88 1035.36,1406.88 1035.37,1406.88 1035.38,1406.88 1035.39,1406.88 1035.39,1406.88 1035.4,1406.88 1035.41,1406.88 1035.42,1406.88 1035.43,1406.88 1035.44,1406.88 1035.45,1406.88 1035.46,1406.88 1035.47,1406.88 1035.48,1406.88 1035.49,1406.88 1035.5,1406.88 1035.5,1406.88 1035.51,1406.88 1035.52,1406.88 1035.53,1406.88 1035.54,1406.88 1035.55,1406.88 1035.56,1406.88 1035.57,1406.88 1035.58,1406.88 1035.59,1406.88 1035.6,1406.88 1035.61,1406.88 1035.61,1406.88 1035.62,1406.88 1035.63,1406.88 1035.64,1406.88 1035.65,1406.88 1035.66,1406.88 1035.67,1406.88 1035.68,1406.88 1035.69,1406.88 1035.7,1406.88 1035.71,1406.88 1035.72,1406.88 1035.73,1406.88 1035.73,1406.88 1035.74,1406.88 1035.75,1406.88 1035.76,1406.88 1035.77,1406.88 1035.78,1406.88 1035.79,1406.88 1035.8,1406.88 1035.81,1406.88 1035.82,1406.88 1035.83,1406.88 1035.84,1406.88 1035.84,1406.88 1035.85,1406.88 1035.86,1406.88 1035.87,1406.88 1035.88,1406.88 1035.89,1406.88 1035.9,1406.88 1035.91,1406.88 1035.92,1406.88 1035.93,1406.88 1035.94,1406.88 1035.95,1406.88 1035.95,1406.88 1035.96,1406.88 1035.97,1406.88 1035.98,1406.88 1035.99,1406.88 1036,1406.88 1036.01,1406.88 1036.02,1406.88 1036.03,1406.88 1036.04,1406.88 1036.05,1406.88 1036.06,1406.88 1036.07,1406.88 1036.07,1406.88 1036.08,1406.88 1036.09,1406.88 1036.1,1406.88 1036.11,1406.88 1036.12,1406.88 1036.13,1406.88 1036.14,1406.88 1036.15,1406.88 1036.16,1406.88 1036.17,1406.88 1036.18,1406.88 1036.18,1406.88 1036.19,1406.88 1036.2,1406.88 1036.21,1406.88 1036.22,1406.88 1036.23,1406.88 1036.24,1406.88 1036.25,1406.88 1036.26,1406.88 1036.27,1406.88 1036.28,1406.88 1036.29,1406.88 1036.29,1406.88 1036.3,1406.88 1036.31,1406.88 1036.32,1406.88 1036.33,1406.88 1036.34,1406.88 1036.35,1406.88 1036.36,1406.88 1036.37,1406.88 1036.38,1406.88 1036.39,1406.88 1036.4,1406.88 1036.41,1406.88 1036.41,1406.88 1036.42,1406.88 1036.43,1406.88 1036.44,1406.88 1036.45,1406.88 1036.46,1406.88 1036.47,1406.88 1036.48,1406.88 1036.49,1406.88 1036.5,1406.88 1036.51,1406.88 1036.52,1406.88 1036.52,1406.88 1036.53,1406.88 1036.54,1406.88 1036.55,1406.88 1036.56,1406.88 1036.57,1406.88 1036.58,1406.88 1036.59,1406.88 1036.6,1406.88 1036.61,1406.88 1036.62,1406.88 1036.63,1406.88 1036.63,1406.88 1036.64,1406.88 1036.65,1406.88 1036.66,1406.88 1036.67,1406.88 1036.68,1406.88 1036.69,1406.88 1036.7,1406.88 1036.71,1406.88 1036.72,1406.88 1036.73,1406.88 1036.74,1406.88 1036.75,1406.88 1036.75,1406.88 1036.76,1406.88 1036.77,1406.88 1036.78,1406.88 1036.79,1406.88 1036.8,1406.88 1036.81,1406.88 1036.82,1406.88 1036.83,1406.88 1036.84,1406.88 1036.85,1406.88 1036.86,1406.88 1036.86,1406.88 1036.87,1406.88 1036.88,1406.88 1036.89,1406.88 1036.9,1406.88 1036.91,1406.88 1036.92,1406.88 1036.93,1406.88 1036.94,1406.88 1036.95,1406.88 1036.96,1406.88 1036.97,1406.88 1036.97,1406.88 1036.98,1406.88 1036.99,1406.88 1037,1406.88 1037.01,1406.88 1037.02,1406.88 1037.03,1406.88 1037.04,1406.88 1037.05,1406.88 1037.06,1406.88 1037.07,1406.88 1037.08,1406.88 1037.09,1406.88 1037.09,1406.88 1037.1,1406.88 1037.11,1406.88 1037.12,1406.88 1037.13,1406.88 1037.14,1406.88 1037.15,1406.88 1037.16,1406.88 1037.17,1406.88 1037.18,1406.88 1037.19,1406.88 1037.2,1406.88 1037.2,1406.88 1037.21,1406.88 1037.22,1406.88 1037.23,1406.88 1037.24,1406.88 1037.25,1406.88 1037.26,1406.88 1037.27,1406.88 1037.28,1406.88 1037.29,1406.88 1037.3,1406.88 1037.31,1406.88 1037.31,1406.88 1037.32,1406.88 1037.33,1406.88 1037.34,1406.88 1037.35,1406.88 1037.36,1406.88 1037.37,1406.88 1037.38,1406.88 1037.39,1406.88 1037.4,1406.88 1037.41,1406.88 1037.42,1406.88 1037.43,1406.88 1037.43,1406.88 1037.44,1406.88 1037.45,1406.88 1037.46,1406.88 1037.47,1406.88 1037.48,1406.88 1037.49,1406.88 1037.5,1406.88 1037.51,1406.88 1037.52,1406.88 1037.53,1406.88 1037.54,1406.88 1037.54,1406.88 1037.55,1406.88 1037.56,1406.88 1037.57,1406.88 1037.58,1406.88 1037.59,1406.88 1037.6,1406.88 1037.61,1406.88 1037.62,1406.88 1037.63,1406.88 1037.64,1406.88 1037.65,1406.88 1037.65,1406.88 1037.66,1406.88 1037.67,1406.88 1037.68,1406.88 1037.69,1406.88 1037.7,1406.88 1037.71,1406.88 1037.72,1406.88 1037.73,1406.88 1037.74,1406.88 1037.75,1406.88 1037.76,1406.88 1037.77,1406.88 1037.77,1406.88 1037.78,1406.88 1037.79,1406.88 1037.8,1406.88 1037.81,1406.88 1037.82,1406.88 1037.83,1406.88 1037.84,1406.88 1037.85,1406.88 1037.86,1406.88 1037.87,1406.88 1037.88,1406.88 1037.88,1406.88 1037.89,1406.88 1037.9,1406.88 1037.91,1406.88 1037.92,1406.88 1037.93,1406.88 1037.94,1406.88 1037.95,1406.88 1037.96,1406.88 1037.97,1406.88 1037.98,1406.88 1037.99,1406.88 1037.99,1406.88 1038,1406.88 1038.01,1406.88 1038.02,1406.88 1038.03,1406.88 1038.04,1406.88 1038.05,1406.88 1038.06,1406.88 1038.07,1406.88 1038.08,1406.88 1038.09,1406.88 1038.1,1406.88 1038.11,1406.88 1038.11,1406.88 1038.12,1406.88 1038.13,1406.88 1038.14,1406.88 1038.15,1406.88 1038.16,1406.88 1038.17,1406.88 1038.18,1406.88 1038.19,1406.88 1038.2,1406.88 1038.21,1406.88 1038.22,1406.88 1038.22,1406.88 1038.23,1406.88 1038.24,1406.88 1038.25,1406.88 1038.26,1406.88 1038.27,1406.88 1038.28,1406.88 1038.29,1406.88 1038.3,1406.88 1038.31,1406.88 1038.32,1406.88 1038.33,1406.88 1038.33,1406.88 1038.34,1406.88 1038.35,1406.88 1038.36,1406.88 1038.37,1406.88 1038.38,1406.88 1038.39,1406.88 1038.4,1406.88 1038.41,1406.88 1038.42,1406.88 1038.43,1406.88 1038.44,1406.88 1038.45,1406.88 1038.45,1406.88 1038.46,1406.88 1038.47,1406.88 1038.48,1406.88 1038.49,1406.88 1038.5,1406.88 1038.51,1406.88 1038.52,1406.88 1038.53,1406.88 1038.54,1406.88 1038.55,1406.88 1038.56,1406.88 1038.56,1406.88 1038.57,1406.88 1038.58,1406.88 1038.59,1406.88 1038.6,1406.88 1038.61,1406.88 1038.62,1406.88 1038.63,1406.88 1038.64,1406.88 1038.65,1406.88 1038.66,1406.88 1038.67,1406.88 1038.67,1406.88 1038.68,1406.88 1038.69,1406.88 1038.7,1406.88 1038.71,1406.88 1038.72,1406.88 1038.73,1406.88 1038.74,1406.88 1038.75,1406.88 1038.76,1406.88 1038.77,1406.88 1038.78,1406.88 1038.79,1406.88 1038.79,1406.88 1038.8,1406.88 1038.81,1406.88 1038.82,1406.88 1038.83,1406.88 1038.84,1406.88 1038.85,1406.88 1038.86,1406.88 1038.87,1406.88 1038.88,1406.88 1038.89,1406.88 1038.9,1406.88 1038.9,1406.88 1038.91,1406.88 1038.92,1406.88 1038.93,1406.88 1038.94,1406.88 1038.95,1406.88 1038.96,1406.88 1038.97,1406.88 1038.98,1406.88 1038.99,1406.88 1039,1406.88 1039.01,1406.88 1039.01,1406.88 1039.02,1406.88 1039.03,1406.88 1039.04,1406.88 1039.05,1406.88 1039.06,1406.88 1039.07,1406.88 1039.08,1406.88 1039.09,1406.88 1039.1,1406.88 1039.11,1406.88 1039.12,1406.88 1039.13,1406.88 1039.13,1406.88 1039.14,1406.88 1039.15,1406.88 1039.16,1406.88 1039.17,1406.88 1039.18,1406.88 1039.19,1406.88 1039.2,1406.88 1039.21,1406.88 1039.22,1406.88 1039.23,1406.88 1039.24,1406.88 1039.24,1406.88 1039.25,1406.88 1039.26,1406.88 1039.27,1406.88 1039.28,1406.88 1039.29,1406.88 1039.3,1406.88 1039.31,1406.88 1039.32,1406.88 1039.33,1406.88 1039.34,1406.88 1039.35,1406.88 1039.35,1406.88 1039.36,1406.88 1039.37,1406.88 1039.38,1406.88 1039.39,1406.88 1039.4,1406.88 1039.41,1406.88 1039.42,1406.88 1039.43,1406.88 1039.44,1406.88 1039.45,1406.88 1039.46,1406.88 1039.47,1406.88 1039.47,1406.88 1039.48,1406.88 1039.49,1406.88 1039.5,1406.88 1039.51,1406.88 1039.52,1406.88 1039.53,1406.88 1039.54,1406.88 1039.55,1406.88 1039.56,1406.88 1039.57,1406.88 1039.58,1406.88 1039.58,1406.88 1039.59,1406.88 1039.6,1406.88 1039.61,1406.88 1039.62,1406.88 1039.63,1406.88 1039.64,1406.88 1039.65,1406.88 1039.66,1406.88 1039.67,1406.88 1039.68,1406.88 1039.69,1406.88 1039.69,1406.88 1039.7,1406.88 1039.71,1406.88 1039.72,1406.88 1039.73,1406.88 1039.74,1406.88 1039.75,1406.88 1039.76,1406.88 1039.77,1406.88 1039.78,1406.88 1039.79,1406.88 1039.8,1406.88 1039.81,1406.88 1039.81,1406.88 1039.82,1406.88 1039.83,1406.88 1039.84,1406.88 1039.85,1406.88 1039.86,1406.88 1039.87,1406.88 1039.88,1406.88 1039.89,1406.88 1039.9,1406.88 1039.91,1406.88 1039.92,1406.88 1039.92,1406.88 1039.93,1406.88 1039.94,1406.88 1039.95,1406.88 1039.96,1406.88 1039.97,1406.88 1039.98,1406.88 1039.99,1406.88 1040,1406.88 1040.01,1406.88 1040.02,1406.88 1040.03,1406.88 1040.03,1406.88 1040.04,1406.88 1040.05,1406.88 1040.06,1406.88 1040.07,1406.88 1040.08,1406.88 1040.09,1406.88 1040.1,1406.88 1040.11,1406.88 1040.12,1406.88 1040.13,1406.88 1040.14,1406.88 1040.15,1406.88 1040.15,1406.88 1040.16,1406.88 1040.17,1406.88 1040.18,1406.88 1040.19,1406.88 1040.2,1406.88 1040.21,1406.88 1040.22,1406.88 1040.23,1406.88 1040.24,1406.88 1040.25,1406.88 1040.26,1406.88 1040.26,1406.88 1040.27,1406.88 1040.28,1406.88 1040.29,1406.88 1040.3,1406.88 1040.31,1406.88 1040.32,1406.88 1040.33,1406.88 1040.34,1406.88 1040.35,1406.88 1040.36,1406.88 1040.37,1406.88 1040.37,1406.88 1040.38,1406.88 1040.39,1406.88 1040.4,1406.88 1040.41,1406.88 1040.42,1406.88 1040.43,1406.88 1040.44,1406.88 1040.45,1406.88 1040.46,1406.88 1040.47,1406.88 1040.48,1406.88 1040.49,1406.88 1040.49,1406.88 1040.5,1406.88 1040.51,1406.88 1040.52,1406.88 1040.53,1406.88 1040.54,1406.88 1040.55,1406.88 1040.56,1406.88 1040.57,1406.88 1040.58,1406.88 1040.59,1406.88 1040.6,1406.88 1040.6,1406.88 1040.61,1406.88 1040.62,1406.88 1040.63,1406.88 1040.64,1406.88 1040.65,1406.88 1040.66,1406.88 1040.67,1406.88 1040.68,1406.88 1040.69,1406.88 1040.7,1406.88 1040.71,1406.88 1040.71,1406.88 1040.72,1406.88 1040.73,1406.88 1040.74,1406.88 1040.75,1406.88 1040.76,1406.88 1040.77,1406.88 1040.78,1406.88 1040.79,1406.88 1040.8,1406.88 1040.81,1406.88 1040.82,1406.88 1040.83,1406.88 1040.83,1406.88 1040.84,1406.88 1040.85,1406.88 1040.86,1406.88 1040.87,1406.88 1040.88,1406.88 1040.89,1406.88 1040.9,1406.88 1040.91,1406.88 1040.92,1406.88 1040.93,1406.88 1040.94,1406.88 1040.94,1406.88 1040.95,1406.88 1040.96,1406.88 1040.97,1406.88 1040.98,1406.88 1040.99,1406.88 1041,1406.88 1041.01,1406.88 1041.02,1406.88 1041.03,1406.88 1041.04,1406.88 1041.05,1406.88 1041.05,1406.88 1041.06,1406.88 1041.07,1406.88 1041.08,1406.88 1041.09,1406.88 1041.1,1406.88 1041.11,1406.88 1041.12,1406.88 1041.13,1406.88 1041.14,1406.88 1041.15,1406.88 1041.16,1406.88 1041.17,1406.88 1041.17,1406.88 1041.18,1406.88 1041.19,1406.88 1041.2,1406.88 1041.21,1406.88 1041.22,1406.88 1041.23,1406.88 1041.24,1406.88 1041.25,1406.88 1041.26,1406.88 1041.27,1406.88 1041.28,1406.88 1041.28,1406.88 1041.29,1406.88 1041.3,1406.88 1041.31,1406.88 1041.32,1406.88 1041.33,1406.88 1041.34,1406.88 1041.35,1406.88 1041.36,1406.88 1041.37,1406.88 1041.38,1406.88 1041.39,1406.88 1041.39,1406.88 1041.4,1406.88 1041.41,1406.88 1041.42,1406.88 1041.43,1406.88 1041.44,1406.88 1041.45,1406.88 1041.46,1406.88 1041.47,1406.88 1041.48,1406.88 1041.49,1406.88 1041.5,1406.88 1041.51,1406.88 1041.51,1406.88 1041.52,1406.88 1041.53,1406.88 1041.54,1406.88 1041.55,1406.88 1041.56,1406.88 1041.57,1406.88 1041.58,1406.88 1041.59,1406.88 1041.6,1406.88 1041.61,1406.88 1041.62,1406.88 1041.62,1406.88 1041.63,1406.88 1041.64,1406.88 1041.65,1406.88 1041.66,1406.88 1041.67,1406.88 1041.68,1406.88 1041.69,1406.88 1041.7,1406.88 1041.71,1406.88 1041.72,1406.88 1041.73,1406.88 1041.73,1406.88 1041.74,1406.88 1041.75,1406.88 1041.76,1406.88 1041.77,1406.88 1041.78,1406.88 1041.79,1406.88 1041.8,1406.88 1041.81,1406.88 1041.82,1406.88 1041.83,1406.88 1041.84,1406.88 1041.85,1406.88 1041.85,1406.88 1041.86,1406.88 1041.87,1406.88 1041.88,1406.88 1041.89,1406.88 1041.9,1406.88 1041.91,1406.88 1041.92,1406.88 1041.93,1406.88 1041.94,1406.88 1041.95,1406.88 1041.96,1406.88 1041.96,1406.88 1041.97,1406.88 1041.98,1406.88 1041.99,1406.88 1042,1406.88 1042.01,1406.88 1042.02,1406.88 1042.03,1406.88 1042.04,1406.88 1042.05,1406.88 1042.06,1406.88 1042.07,1406.88 1042.07,1406.88 1042.08,1406.88 1042.09,1406.88 1042.1,1406.88 1042.11,1406.88 1042.12,1406.88 1042.13,1406.88 1042.14,1406.88 1042.15,1406.88 1042.16,1406.88 1042.17,1406.88 1042.18,1406.88 1042.19,1406.88 1042.19,1406.88 1042.2,1406.88 1042.21,1406.88 1042.22,1406.88 1042.23,1406.88 1042.24,1406.88 1042.25,1406.88 1042.26,1406.88 1042.27,1406.88 1042.28,1406.88 1042.29,1406.88 1042.3,1406.88 1042.3,1406.88 1042.31,1406.88 1042.32,1406.88 1042.33,1406.88 1042.34,1406.88 1042.35,1406.88 1042.36,1406.88 1042.37,1406.88 1042.38,1406.88 1042.39,1406.88 1042.4,1406.88 1042.41,1406.88 1042.41,1406.88 1042.42,1406.88 1042.43,1406.88 1042.44,1406.88 1042.45,1406.88 1042.46,1406.88 1042.47,1406.88 1042.48,1406.88 1042.49,1406.88 1042.5,1406.88 1042.51,1406.88 1042.52,1406.88 1042.53,1406.88 1042.53,1406.88 1042.54,1406.88 1042.55,1406.88 1042.56,1406.88 1042.57,1406.88 1042.58,1406.88 1042.59,1406.88 1042.6,1406.88 1042.61,1406.88 1042.62,1406.88 1042.63,1406.88 1042.64,1406.88 1042.64,1406.88 1042.65,1406.88 1042.66,1406.88 1042.67,1406.88 1042.68,1406.88 1042.69,1406.88 1042.7,1406.88 1042.71,1406.88 1042.72,1406.88 1042.73,1406.88 1042.74,1406.88 1042.75,1406.88 1042.75,1406.88 1042.76,1406.88 1042.77,1406.88 1042.78,1406.88 1042.79,1406.88 1042.8,1406.88 1042.81,1406.88 1042.82,1406.88 1042.83,1406.88 1042.84,1406.88 1042.85,1406.88 1042.86,1406.88 1042.87,1406.88 1042.87,1406.88 1042.88,1406.88 1042.89,1406.88 1042.9,1406.88 1042.91,1406.88 1042.92,1406.88 1042.93,1406.88 1042.94,1406.88 1042.95,1406.88 1042.96,1406.88 1042.97,1406.88 1042.98,1406.88 1042.98,1406.88 1042.99,1406.88 1043,1406.88 1043.01,1406.88 1043.02,1406.88 1043.03,1406.88 1043.04,1406.88 1043.05,1406.88 1043.06,1406.88 1043.07,1406.88 1043.08,1406.88 1043.09,1406.88 1043.09,1406.88 1043.1,1406.88 1043.11,1406.88 1043.12,1406.88 1043.13,1406.88 1043.14,1406.88 1043.15,1406.88 1043.16,1406.88 1043.17,1406.88 1043.18,1406.88 1043.19,1406.88 1043.2,1406.88 1043.21,1406.88 1043.21,1406.88 1043.22,1406.88 1043.23,1406.88 1043.24,1406.88 1043.25,1406.88 1043.26,1406.88 1043.27,1406.88 1043.28,1406.88 1043.29,1406.88 1043.3,1406.88 1043.31,1406.88 1043.32,1406.88 1043.32,1406.88 1043.33,1406.88 1043.34,1406.88 1043.35,1406.88 1043.36,1406.88 1043.37,1406.88 1043.38,1406.88 1043.39,1406.88 1043.4,1406.88 1043.41,1406.88 1043.42,1406.88 1043.43,1406.88 1043.43,1406.88 1043.44,1406.88 1043.45,1406.88 1043.46,1406.88 1043.47,1406.88 1043.48,1406.88 1043.49,1406.88 1043.5,1406.88 1043.51,1406.88 1043.52,1406.88 1043.53,1406.88 1043.54,1406.88 1043.55,1406.88 1043.55,1406.88 1043.56,1406.88 1043.57,1406.88 1043.58,1406.88 1043.59,1406.88 1043.6,1406.88 1043.61,1406.88 1043.62,1406.88 1043.63,1406.88 1043.64,1406.88 1043.65,1406.88 1043.66,1406.88 1043.66,1406.88 1043.67,1406.88 1043.68,1406.88 1043.69,1406.88 1043.7,1406.88 1043.71,1406.88 1043.72,1406.88 1043.73,1406.88 1043.74,1406.88 1043.75,1406.88 1043.76,1406.88 1043.77,1406.88 1043.77,1406.88 1043.78,1406.88 1043.79,1406.88 1043.8,1406.88 1043.81,1406.88 1043.82,1406.88 1043.83,1406.88 1043.84,1406.88 1043.85,1406.88 1043.86,1406.88 1043.87,1406.88 1043.88,1406.88 1043.89,1406.88 1043.89,1406.88 1043.9,1406.88 1043.91,1406.88 1043.92,1406.88 1043.93,1406.88 1043.94,1406.88 1043.95,1406.88 1043.96,1406.88 1043.97,1406.88 1043.98,1406.88 1043.99,1406.88 1044,1406.88 1044,1406.88 1044.01,1406.88 1044.02,1406.88 1044.03,1406.88 1044.04,1406.88 1044.05,1406.88 1044.06,1406.88 1044.07,1406.88 1044.08,1406.88 1044.09,1406.88 1044.1,1406.88 1044.11,1406.88 1044.11,1406.88 1044.12,1406.88 1044.13,1406.88 1044.14,1406.88 1044.15,1406.88 1044.16,1406.88 1044.17,1406.88 1044.18,1406.88 1044.19,1406.88 1044.2,1406.88 1044.21,1406.88 1044.22,1406.88 1044.23,1406.88 1044.23,1406.88 1044.24,1406.88 1044.25,1406.88 1044.26,1406.88 1044.27,1406.88 1044.28,1406.88 1044.29,1406.88 1044.3,1406.88 1044.31,1406.88 1044.32,1406.88 1044.33,1406.88 1044.34,1406.88 1044.34,1406.88 1044.35,1406.88 1044.36,1406.88 1044.37,1406.88 1044.38,1406.88 1044.39,1406.88 1044.4,1406.88 1044.41,1406.88 1044.42,1406.88 1044.43,1406.88 1044.44,1406.88 1044.45,1406.88 1044.45,1406.88 1044.46,1406.88 1044.47,1406.88 1044.48,1406.88 1044.49,1406.88 1044.5,1406.88 1044.51,1406.88 1044.52,1406.88 1044.53,1406.88 1044.54,1406.88 1044.55,1406.88 1044.56,1406.88 1044.57,1406.88 1044.57,1406.88 1044.58,1406.88 1044.59,1406.88 1044.6,1406.88 1044.61,1406.88 1044.62,1406.88 1044.63,1406.88 1044.64,1406.88 1044.65,1406.88 1044.66,1406.88 1044.67,1406.88 1044.68,1406.88 1044.68,1406.88 1044.69,1406.88 1044.7,1406.88 1044.71,1406.88 1044.72,1406.88 1044.73,1406.88 1044.74,1406.88 1044.75,1406.88 1044.76,1406.88 1044.77,1406.88 1044.78,1406.88 1044.79,1406.88 1044.79,1406.88 1044.8,1406.88 1044.81,1406.88 1044.82,1406.88 1044.83,1406.88 1044.84,1406.88 1044.85,1406.88 1044.86,1406.88 1044.87,1406.88 1044.88,1406.88 1044.89,1406.88 1044.9,1406.88 1044.91,1406.88 1044.91,1406.88 1044.92,1406.88 1044.93,1406.88 1044.94,1406.88 1044.95,1406.88 1044.96,1406.88 1044.97,1406.88 1044.98,1406.88 1044.99,1406.88 1045,1406.88 1045.01,1406.88 1045.02,1406.88 1045.02,1406.88 1045.03,1406.88 1045.04,1406.88 1045.05,1406.88 1045.06,1406.88 1045.07,1406.88 1045.08,1406.88 1045.09,1406.88 1045.1,1406.88 1045.11,1406.88 1045.12,1406.88 1045.13,1406.88 1045.13,1406.88 1045.14,1406.88 1045.15,1406.88 1045.16,1406.88 1045.17,1406.88 1045.18,1406.88 1045.19,1406.88 1045.2,1406.88 1045.21,1406.88 1045.22,1406.88 1045.23,1406.88 1045.24,1406.88 1045.25,1406.88 1045.25,1406.88 1045.26,1406.88 1045.27,1406.88 1045.28,1406.88 1045.29,1406.88 1045.3,1406.88 1045.31,1406.88 1045.32,1406.88 1045.33,1406.88 1045.34,1406.88 1045.35,1406.88 1045.36,1406.88 1045.36,1406.88 1045.37,1406.88 1045.38,1406.88 1045.39,1406.88 1045.4,1406.88 1045.41,1406.88 1045.42,1406.88 1045.43,1406.88 1045.44,1406.88 1045.45,1406.88 1045.46,1406.88 1045.47,1406.88 1045.47,1406.88 1045.48,1406.88 1045.49,1406.88 1045.5,1406.88 1045.51,1406.88 1045.52,1406.88 1045.53,1406.88 1045.54,1406.88 1045.55,1406.88 1045.56,1406.88 1045.57,1406.88 1045.58,1406.88 1045.59,1406.88 1045.59,1406.88 1045.6,1406.88 1045.61,1406.88 1045.62,1406.88 1045.63,1406.88 1045.64,1406.88 1045.65,1406.88 1045.66,1406.88 1045.67,1406.88 1045.68,1406.88 1045.69,1406.88 1045.7,1406.88 1045.7,1406.88 1045.71,1406.88 1045.72,1406.88 1045.73,1406.88 1045.74,1406.88 1045.75,1406.88 1045.76,1406.88 1045.77,1406.88 1045.78,1406.88 1045.79,1406.88 1045.8,1406.88 1045.81,1406.88 1045.81,1406.88 1045.82,1406.88 1045.83,1406.88 1045.84,1406.88 1045.85,1406.88 1045.86,1406.88 1045.87,1406.88 1045.88,1406.88 1045.89,1406.88 1045.9,1406.88 1045.91,1406.88 1045.92,1406.88 1045.93,1406.88 1045.93,1406.88 1045.94,1406.88 1045.95,1406.88 1045.96,1406.88 1045.97,1406.88 1045.98,1406.88 1045.99,1406.88 1046,1406.88 1046.01,1406.88 1046.02,1406.88 1046.03,1406.88 1046.04,1406.88 1046.04,1406.88 1046.05,1406.88 1046.06,1406.88 1046.07,1406.88 1046.08,1406.88 1046.09,1406.88 1046.1,1406.88 1046.11,1406.88 1046.12,1406.88 1046.13,1406.88 1046.14,1406.88 1046.15,1406.88 1046.15,1406.88 1046.16,1406.88 1046.17,1406.88 1046.18,1406.88 1046.19,1406.88 1046.2,1406.88 1046.21,1406.88 1046.22,1406.88 1046.23,1406.88 1046.24,1406.88 1046.25,1406.88 1046.26,1406.88 1046.27,1406.88 1046.27,1406.88 1046.28,1406.88 1046.29,1406.88 1046.3,1406.88 1046.31,1406.88 1046.32,1406.88 1046.33,1406.88 1046.34,1406.88 1046.35,1406.88 1046.36,1406.88 1046.37,1406.88 1046.38,1406.88 1046.38,1406.88 1046.39,1406.88 1046.4,1406.88 1046.41,1406.88 1046.42,1406.88 1046.43,1406.88 1046.44,1406.88 1046.45,1406.88 1046.46,1406.88 1046.47,1406.88 1046.48,1406.88 1046.49,1406.88 1046.49,1406.88 1046.5,1406.88 1046.51,1406.88 1046.52,1406.88 1046.53,1406.88 1046.54,1406.88 1046.55,1406.88 1046.56,1406.88 1046.57,1406.88 1046.58,1406.88 1046.59,1406.88 1046.6,1406.88 1046.61,1406.88 1046.61,1406.88 1046.62,1406.88 1046.63,1406.88 1046.64,1406.88 1046.65,1406.88 1046.66,1406.88 1046.67,1406.88 1046.68,1406.88 1046.69,1406.88 1046.7,1406.88 1046.71,1406.88 1046.72,1406.88 1046.72,1406.88 1046.73,1406.88 1046.74,1406.88 1046.75,1406.88 1046.76,1406.88 1046.77,1406.88 1046.78,1406.88 1046.79,1406.88 1046.8,1406.88 1046.81,1406.88 1046.82,1406.88 1046.83,1406.88 1046.83,1406.88 1046.84,1406.88 1046.85,1406.88 1046.86,1406.88 1046.87,1406.88 1046.88,1406.88 1046.89,1406.88 1046.9,1406.88 1046.91,1406.88 1046.92,1406.88 1046.93,1406.88 1046.94,1406.88 1046.95,1406.88 1046.95,1406.88 1046.96,1406.88 1046.97,1406.88 1046.98,1406.88 1046.99,1406.88 1047,1406.88 1047.01,1406.88 1047.02,1406.88 1047.03,1406.88 1047.04,1406.88 1047.05,1406.88 1047.06,1406.88 1047.06,1406.88 1047.07,1406.88 1047.08,1406.88 1047.09,1406.88 1047.1,1406.88 1047.11,1406.88 1047.12,1406.88 1047.13,1406.88 1047.14,1406.88 1047.15,1406.88 1047.16,1406.88 1047.17,1406.88 1047.17,1406.88 1047.18,1406.88 1047.19,1406.88 1047.2,1406.88 1047.21,1406.88 1047.22,1406.88 1047.23,1406.88 1047.24,1406.88 1047.25,1406.88 1047.26,1406.88 1047.27,1406.88 1047.28,1406.88 1047.29,1406.88 1047.29,1406.88 1047.3,1406.88 1047.31,1406.88 1047.32,1406.88 1047.33,1406.88 1047.34,1406.88 1047.35,1406.88 1047.36,1406.88 1047.37,1406.88 1047.38,1406.88 1047.39,1406.88 1047.4,1406.88 1047.4,1406.88 1047.41,1406.88 1047.42,1406.88 1047.43,1406.88 1047.44,1406.88 1047.45,1406.88 1047.46,1406.88 1047.47,1406.88 1047.48,1406.88 1047.49,1406.88 1047.5,1406.88 1047.51,1406.88 1047.52,1406.88 1047.52,1406.88 1047.53,1406.88 1047.54,1406.88 1047.55,1406.88 1047.56,1406.88 1047.57,1406.88 1047.58,1406.88 1047.59,1406.88 1047.6,1406.88 1047.61,1406.88 1047.62,1406.88 1047.63,1406.88 1047.63,1406.88 1047.64,1406.88 1047.65,1406.88 1047.66,1406.88 1047.67,1406.88 1047.68,1406.88 1047.69,1406.88 1047.7,1406.88 1047.71,1406.88 1047.72,1406.88 1047.73,1406.88 1047.74,1406.88 1047.74,1406.88 1047.75,1406.88 1047.76,1406.88 1047.77,1406.88 1047.78,1406.88 1047.79,1406.88 1047.8,1406.88 1047.81,1406.88 1047.82,1406.88 1047.83,1406.88 1047.84,1406.88 1047.85,1406.88 1047.86,1406.88 1047.86,1406.88 1047.87,1406.88 1047.88,1406.88 1047.89,1406.88 1047.9,1406.88 1047.91,1406.88 1047.92,1406.88 1047.93,1406.88 1047.94,1406.88 1047.95,1406.88 1047.96,1406.88 1047.97,1406.88 1047.97,1406.88 1047.98,1406.88 1047.99,1406.88 1048,1406.88 1048.01,1406.88 1048.02,1406.88 1048.03,1406.88 1048.04,1406.88 1048.05,1406.88 1048.06,1406.88 1048.07,1406.88 1048.08,1406.88 1048.08,1406.88 1048.09,1406.88 1048.1,1406.88 1048.11,1406.88 1048.12,1406.88 1048.13,1406.88 1048.14,1406.88 1048.15,1406.88 1048.16,1406.88 1048.17,1406.88 1048.18,1406.88 1048.19,1406.88 1048.2,1406.88 1048.2,1406.88 1048.21,1406.88 1048.22,1406.88 1048.23,1406.88 1048.24,1406.88 1048.25,1406.88 1048.26,1406.88 1048.27,1406.88 1048.28,1406.88 1048.29,1406.88 1048.3,1406.88 1048.31,1406.88 1048.31,1406.88 1048.32,1406.88 1048.33,1406.88 1048.34,1406.88 1048.35,1406.88 1048.36,1406.88 1048.37,1406.88 1048.38,1406.88 1048.39,1406.88 1048.4,1406.88 1048.41,1406.88 1048.42,1406.88 1048.42,1406.88 1048.43,1406.88 1048.44,1406.88 1048.45,1406.88 1048.46,1406.88 1048.47,1406.88 1048.48,1406.88 1048.49,1406.88 1048.5,1406.88 1048.51,1406.88 1048.52,1406.88 1048.53,1406.88 1048.54,1406.88 1048.54,1406.88 1048.55,1406.88 1048.56,1406.88 1048.57,1406.88 1048.58,1406.88 1048.59,1406.88 1048.6,1406.88 1048.61,1406.88 1048.62,1406.88 1048.63,1406.88 1048.64,1406.88 1048.65,1406.88 1048.65,1406.88 1048.66,1406.88 1048.67,1406.88 1048.68,1406.88 1048.69,1406.88 1048.7,1406.88 1048.71,1406.88 1048.72,1406.88 1048.73,1406.88 1048.74,1406.88 1048.75,1406.88 1048.76,1406.88 1048.76,1406.88 1048.77,1406.88 1048.78,1406.88 1048.79,1406.88 1048.8,1406.88 1048.81,1406.88 1048.82,1406.88 1048.83,1406.88 1048.84,1406.88 1048.85,1406.88 1048.86,1406.88 1048.87,1406.88 1048.88,1406.88 1048.88,1406.88 1048.89,1406.88 1048.9,1406.88 1048.91,1406.88 1048.92,1406.88 1048.93,1406.88 1048.94,1406.88 1048.95,1406.88 1048.96,1406.88 1048.97,1406.88 1048.98,1406.88 1048.99,1406.88 1048.99,1406.88 1049,1406.88 1049.01,1406.88 1049.02,1406.88 1049.03,1406.88 1049.04,1406.88 1049.05,1406.88 1049.06,1406.88 1049.07,1406.88 1049.08,1406.88 1049.09,1406.88 1049.1,1406.88 1049.1,1406.88 1049.11,1406.88 1049.12,1406.88 1049.13,1406.88 1049.14,1406.88 1049.15,1406.88 1049.16,1406.88 1049.17,1406.88 1049.18,1406.88 1049.19,1406.88 1049.2,1406.88 1049.21,1406.88 1049.22,1406.88 1049.22,1406.88 1049.23,1406.88 1049.24,1406.88 1049.25,1406.88 1049.26,1406.88 1049.27,1406.88 1049.28,1406.88 1049.29,1406.88 1049.3,1406.88 1049.31,1406.88 1049.32,1406.88 1049.33,1406.88 1049.33,1406.88 1049.34,1406.88 1049.35,1406.88 1049.36,1406.88 1049.37,1406.88 1049.38,1406.88 1049.39,1406.88 1049.4,1406.88 1049.41,1406.88 1049.42,1406.88 1049.43,1406.88 1049.44,1406.88 1049.44,1406.88 1049.45,1406.88 1049.46,1406.88 1049.47,1406.88 1049.48,1406.88 1049.49,1406.88 1049.5,1406.88 1049.51,1406.88 1049.52,1406.88 1049.53,1406.88 1049.54,1406.88 1049.55,1406.88 1049.56,1406.88 1049.56,1406.88 1049.57,1406.88 1049.58,1406.88 1049.59,1406.88 1049.6,1406.88 1049.61,1406.88 1049.62,1406.88 1049.63,1406.88 1049.64,1406.88 1049.65,1406.88 1049.66,1406.88 1049.67,1406.88 1049.67,1406.88 1049.68,1406.88 1049.69,1406.88 1049.7,1406.88 1049.71,1406.88 1049.72,1406.88 1049.73,1406.88 1049.74,1406.88 1049.75,1406.88 1049.76,1406.88 1049.77,1406.88 1049.78,1406.88 1049.78,1406.88 1049.79,1406.88 1049.8,1406.88 1049.81,1406.88 1049.82,1406.88 1049.83,1406.88 1049.84,1406.88 1049.85,1406.88 1049.86,1406.88 1049.87,1406.88 1049.88,1406.88 1049.89,1406.88 1049.9,1406.88 1049.9,1406.88 1049.91,1406.88 1049.92,1406.88 1049.93,1406.88 1049.94,1406.88 1049.95,1406.88 1049.96,1406.88 1049.97,1406.88 1049.98,1406.88 1049.99,1406.88 1050,1406.88 1050.01,1406.88 1050.01,1406.88 1050.02,1406.88 1050.03,1406.88 1050.04,1406.88 1050.05,1406.88 1050.06,1406.88 1050.07,1406.88 1050.08,1406.88 1050.09,1406.88 1050.1,1406.88 1050.11,1406.88 1050.12,1406.88 1050.12,1406.88 1050.13,1406.88 1050.14,1406.88 1050.15,1406.88 1050.16,1406.88 1050.17,1406.88 1050.18,1406.88 1050.19,1406.88 1050.2,1406.88 1050.21,1406.88 1050.22,1406.88 1050.23,1406.88 1050.24,1406.88 1050.24,1406.88 1050.25,1406.88 1050.26,1406.88 1050.27,1406.88 1050.28,1406.88 1050.29,1406.88 1050.3,1406.88 1050.31,1406.88 1050.32,1406.88 1050.33,1406.88 1050.34,1406.88 1050.35,1406.88 1050.35,1406.88 1050.36,1406.88 1050.37,1406.88 1050.38,1406.88 1050.39,1406.88 1050.4,1406.88 1050.41,1406.88 1050.42,1406.88 1050.43,1406.88 1050.44,1406.88 1050.45,1406.88 1050.46,1406.88 1050.46,1406.88 1050.47,1406.88 1050.48,1406.88 1050.49,1406.88 1050.5,1406.88 1050.51,1406.88 1050.52,1406.88 1050.53,1406.88 1050.54,1406.88 1050.55,1406.88 1050.56,1406.88 1050.57,1406.88 1050.58,1406.88 1050.58,1406.88 1050.59,1406.88 1050.6,1406.88 1050.61,1406.88 1050.62,1406.88 1050.63,1406.88 1050.64,1406.88 1050.65,1406.88 1050.66,1406.88 1050.67,1406.88 1050.68,1406.88 1050.69,1406.88 1050.69,1406.88 1050.7,1406.88 1050.71,1406.88 1050.72,1406.88 1050.73,1406.88 1050.74,1406.88 1050.75,1406.88 1050.76,1406.88 1050.77,1406.88 1050.78,1406.88 1050.79,1406.88 1050.8,1406.88 1050.8,1406.88 1050.81,1406.88 1050.82,1406.88 1050.83,1406.88 1050.84,1406.88 1050.85,1406.88 1050.86,1406.88 1050.87,1406.88 1050.88,1406.88 1050.89,1406.88 1050.9,1406.88 1050.91,1406.88 1050.92,1406.88 1050.92,1406.88 1050.93,1406.88 1050.94,1406.88 1050.95,1406.88 1050.96,1406.88 1050.97,1406.88 1050.98,1406.88 1050.99,1406.88 1051,1406.88 1051.01,1406.88 1051.02,1406.88 1051.03,1406.88 1051.03,1406.88 1051.04,1406.88 1051.05,1406.88 1051.06,1406.88 1051.07,1406.88 1051.08,1406.88 1051.09,1406.88 1051.1,1406.88 1051.11,1406.88 1051.12,1406.88 1051.13,1406.88 1051.14,1406.88 1051.14,1406.88 1051.15,1406.88 1051.16,1406.88 1051.17,1406.88 1051.18,1406.88 1051.19,1406.88 1051.2,1406.88 1051.21,1406.88 1051.22,1406.88 1051.23,1406.88 1051.24,1406.88 1051.25,1406.88 1051.26,1406.88 1051.26,1406.88 1051.27,1406.88 1051.28,1406.88 1051.29,1406.88 1051.3,1406.88 1051.31,1406.88 1051.32,1406.88 1051.33,1406.88 1051.34,1406.88 1051.35,1406.88 1051.36,1406.88 1051.37,1406.88 1051.37,1406.88 1051.38,1406.88 1051.39,1406.88 1051.4,1406.88 1051.41,1406.88 1051.42,1406.88 1051.43,1406.88 1051.44,1406.88 1051.45,1406.88 1051.46,1406.88 1051.47,1406.88 1051.48,1406.88 1051.48,1406.88 1051.49,1406.88 1051.5,1406.88 1051.51,1406.88 1051.52,1406.88 1051.53,1406.88 1051.54,1406.88 1051.55,1406.88 1051.56,1406.88 1051.57,1406.88 1051.58,1406.88 1051.59,1406.88 1051.6,1406.88 1051.6,1406.88 1051.61,1406.88 1051.62,1406.88 1051.63,1406.88 1051.64,1406.88 1051.65,1406.88 1051.66,1406.88 1051.67,1406.88 1051.68,1406.88 1051.69,1406.88 1051.7,1406.88 1051.71,1406.88 1051.71,1406.88 1051.72,1406.88 1051.73,1406.88 1051.74,1406.88 1051.75,1406.88 1051.76,1406.88 1051.77,1406.88 1051.78,1406.88 1051.79,1406.88 1051.8,1406.88 1051.81,1406.88 1051.82,1406.88 1051.82,1406.88 1051.83,1406.88 1051.84,1406.88 1051.85,1406.88 1051.86,1406.88 1051.87,1406.88 1051.88,1406.88 1051.89,1406.88 1051.9,1406.88 1051.91,1406.88 1051.92,1406.88 1051.93,1406.88 1051.94,1406.88 1051.94,1406.88 1051.95,1406.88 1051.96,1406.88 1051.97,1406.88 1051.98,1406.88 1051.99,1406.88 1052,1406.88 1052.01,1406.88 1052.02,1406.88 1052.03,1406.88 1052.04,1406.88 1052.05,1406.88 1052.05,1406.88 1052.06,1406.88 1052.07,1406.88 1052.08,1406.88 1052.09,1406.88 1052.1,1406.88 1052.11,1406.88 1052.12,1406.88 1052.13,1406.88 1052.14,1406.88 1052.15,1406.88 1052.16,1406.88 1052.16,1406.88 1052.17,1406.88 1052.18,1406.88 1052.19,1406.88 1052.2,1406.88 1052.21,1406.88 1052.22,1406.88 1052.23,1406.88 1052.24,1406.88 1052.25,1406.88 1052.26,1406.88 1052.27,1406.88 1052.28,1406.88 1052.28,1406.88 1052.29,1406.88 1052.3,1406.88 1052.31,1406.88 1052.32,1406.88 1052.33,1406.88 1052.34,1406.88 1052.35,1406.88 1052.36,1406.88 1052.37,1406.88 1052.38,1406.88 1052.39,1406.88 1052.39,1406.88 1052.4,1406.88 1052.41,1406.88 1052.42,1406.88 1052.43,1406.88 1052.44,1406.88 1052.45,1406.88 1052.46,1406.88 1052.47,1406.88 1052.48,1406.88 1052.49,1406.88 1052.5,1406.88 1052.5,1406.88 1052.51,1406.88 1052.52,1406.88 1052.53,1406.88 1052.54,1406.88 1052.55,1406.88 1052.56,1406.88 1052.57,1406.88 1052.58,1406.88 1052.59,1406.88 1052.6,1406.88 1052.61,1406.88 1052.62,1406.88 1052.62,1406.88 1052.63,1406.88 1052.64,1406.88 1052.65,1406.88 1052.66,1406.88 1052.67,1406.88 1052.68,1406.88 1052.69,1406.88 1052.7,1406.88 1052.71,1406.88 1052.72,1406.88 1052.73,1406.88 1052.73,1406.88 1052.74,1406.88 1052.75,1406.88 1052.76,1406.88 1052.77,1406.88 1052.78,1406.88 1052.79,1406.88 1052.8,1406.88 1052.81,1406.88 1052.82,1406.88 1052.83,1406.88 1052.84,1406.88 1052.84,1406.88 1052.85,1406.88 1052.86,1406.88 1052.87,1406.88 1052.88,1406.88 1052.89,1406.88 1052.9,1406.88 1052.91,1406.88 1052.92,1406.88 1052.93,1406.88 1052.94,1406.88 1052.95,1406.88 1052.96,1406.88 1052.96,1406.88 1052.97,1406.88 1052.98,1406.88 1052.99,1406.88 1053,1406.88 1053.01,1406.88 1053.02,1406.88 1053.03,1406.88 1053.04,1406.88 1053.05,1406.88 1053.06,1406.88 1053.07,1406.88 1053.07,1406.88 1053.08,1406.88 1053.09,1406.88 1053.1,1406.88 1053.11,1406.88 1053.12,1406.88 1053.13,1406.88 1053.14,1406.88 1053.15,1406.88 1053.16,1406.88 1053.17,1406.88 1053.18,1406.88 1053.18,1406.88 1053.19,1406.88 1053.2,1406.88 1053.21,1406.88 1053.22,1406.88 1053.23,1406.88 1053.24,1406.88 1053.25,1406.88 1053.26,1406.88 1053.27,1406.88 1053.28,1406.88 1053.29,1406.88 1053.3,1406.88 1053.3,1406.88 1053.31,1406.88 1053.32,1406.88 1053.33,1406.88 1053.34,1406.88 1053.35,1406.88 1053.36,1406.88 1053.37,1406.88 1053.38,1406.88 1053.39,1406.88 1053.4,1406.88 1053.41,1406.88 1053.41,1406.88 1053.42,1406.88 1053.43,1406.88 1053.44,1406.88 1053.45,1406.88 1053.46,1406.88 1053.47,1406.88 1053.48,1406.88 1053.49,1406.88 1053.5,1406.88 1053.51,1406.88 1053.52,1406.88 1053.52,1406.88 1053.53,1406.88 1053.54,1406.88 1053.55,1406.88 1053.56,1406.88 1053.57,1406.88 1053.58,1406.88 1053.59,1406.88 1053.6,1406.88 1053.61,1406.88 1053.62,1406.88 1053.63,1406.88 1053.64,1406.88 1053.64,1406.88 1053.65,1406.88 1053.66,1406.88 1053.67,1406.88 1053.68,1406.88 1053.69,1406.88 1053.7,1406.88 1053.71,1406.88 1053.72,1406.88 1053.73,1406.88 1053.74,1406.88 1053.75,1406.88 1053.75,1406.88 1053.76,1406.88 1053.77,1406.88 1053.78,1406.88 1053.79,1406.88 1053.8,1406.88 1053.81,1406.88 1053.82,1406.88 1053.83,1406.88 1053.84,1406.88 1053.85,1406.88 1053.86,1406.88 1053.86,1406.88 1053.87,1406.88 1053.88,1406.88 1053.89,1406.88 1053.9,1406.88 1053.91,1406.88 1053.92,1406.88 1053.93,1406.88 1053.94,1406.88 1053.95,1406.88 1053.96,1406.88 1053.97,1406.88 1053.98,1406.88 1053.98,1406.88 1053.99,1406.88 1054,1406.88 1054.01,1406.88 1054.02,1406.88 1054.03,1406.88 1054.04,1406.88 1054.05,1406.88 1054.06,1406.88 1054.07,1406.88 1054.08,1406.88 1054.09,1406.88 1054.09,1406.88 1054.1,1406.88 1054.11,1406.88 1054.12,1406.88 1054.13,1406.88 1054.14,1406.88 1054.15,1406.88 1054.16,1406.88 1054.17,1406.88 1054.18,1406.88 1054.19,1406.88 1054.2,1406.88 1054.2,1406.88 1054.21,1406.88 1054.22,1406.88 1054.23,1406.88 1054.24,1406.88 1054.25,1406.88 1054.26,1406.88 1054.27,1406.88 1054.28,1406.88 1054.29,1406.88 1054.3,1406.88 1054.31,1406.88 1054.32,1406.88 1054.32,1406.88 1054.33,1406.88 1054.34,1406.88 1054.35,1406.88 1054.36,1406.88 1054.37,1406.88 1054.38,1406.88 1054.39,1406.88 1054.4,1406.88 1054.41,1406.88 1054.42,1406.88 1054.43,1406.88 1054.43,1406.88 1054.44,1406.88 1054.45,1406.88 1054.46,1406.88 1054.47,1406.88 1054.48,1406.88 1054.49,1406.88 1054.5,1406.88 1054.51,1406.88 1054.52,1406.88 1054.53,1406.88 1054.54,1406.88 1054.54,1406.88 1054.55,1406.88 1054.56,1406.88 1054.57,1406.88 1054.58,1406.88 1054.59,1406.88 1054.6,1406.88 1054.61,1406.88 1054.62,1406.88 1054.63,1406.88 1054.64,1406.88 1054.65,1406.88 1054.66,1406.88 1054.66,1406.88 1054.67,1406.88 1054.68,1406.88 1054.69,1406.88 1054.7,1406.88 1054.71,1406.88 1054.72,1406.88 1054.73,1406.88 1054.74,1406.88 1054.75,1406.88 1054.76,1406.88 1054.77,1406.88 1054.77,1406.88 1054.78,1406.88 1054.79,1406.88 1054.8,1406.88 1054.81,1406.88 1054.82,1406.88 1054.83,1406.88 1054.84,1406.88 1054.85,1406.88 1054.86,1406.88 1054.87,1406.88 1054.88,1406.88 1054.88,1406.88 1054.89,1406.88 1054.9,1406.88 1054.91,1406.88 1054.92,1406.88 1054.93,1406.88 1054.94,1406.88 1054.95,1406.88 1054.96,1406.88 1054.97,1406.88 1054.98,1406.88 1054.99,1406.88 1055,1406.88 1055,1406.88 1055.01,1406.88 1055.02,1406.88 1055.03,1406.88 1055.04,1406.88 1055.05,1406.88 1055.06,1406.88 1055.07,1406.88 1055.08,1406.88 1055.09,1406.88 1055.1,1406.88 1055.11,1406.88 1055.11,1406.88 1055.12,1406.88 1055.13,1406.88 1055.14,1406.88 1055.15,1406.88 1055.16,1406.88 1055.17,1406.88 1055.18,1406.88 1055.19,1406.88 1055.2,1406.88 1055.21,1406.88 1055.22,1406.88 1055.22,1406.88 1055.23,1406.88 1055.24,1406.88 1055.25,1406.88 1055.26,1406.88 1055.27,1406.88 1055.28,1406.88 1055.29,1406.88 1055.3,1406.88 1055.31,1406.88 1055.32,1406.88 1055.33,1406.88 1055.34,1406.88 1055.34,1406.88 1055.35,1406.88 1055.36,1406.88 1055.37,1406.88 1055.38,1406.88 1055.39,1406.88 1055.4,1406.88 1055.41,1406.88 1055.42,1406.88 1055.43,1406.88 1055.44,1406.88 1055.45,1406.88 1055.45,1406.88 1055.46,1406.88 1055.47,1406.88 1055.48,1406.88 1055.49,1406.88 1055.5,1406.88 1055.51,1406.88 1055.52,1406.88 1055.53,1406.88 1055.54,1406.88 1055.55,1406.88 1055.56,1406.88 1055.56,1406.88 1055.57,1406.88 1055.58,1406.88 1055.59,1406.88 1055.6,1406.88 1055.61,1406.88 1055.62,1406.88 1055.63,1406.88 1055.64,1406.88 1055.65,1406.88 1055.66,1406.88 1055.67,1406.88 1055.68,1406.88 1055.68,1406.88 1055.69,1406.88 1055.7,1406.88 1055.71,1406.88 1055.72,1406.88 1055.73,1406.88 1055.74,1406.88 1055.75,1406.88 1055.76,1406.88 1055.77,1406.88 1055.78,1406.88 1055.79,1406.88 1055.79,1406.88 1055.8,1406.88 1055.81,1406.88 1055.82,1406.88 1055.83,1406.88 1055.84,1406.88 1055.85,1406.88 1055.86,1406.88 1055.87,1406.88 1055.88,1406.88 1055.89,1406.88 1055.9,1406.88 1055.9,1406.88 1055.91,1406.88 1055.92,1406.88 1055.93,1406.88 1055.94,1406.88 1055.95,1406.88 1055.96,1406.88 1055.97,1406.88 1055.98,1406.88 1055.99,1406.88 1056,1406.88 1056.01,1406.88 1056.02,1406.88 1056.02,1406.88 1056.03,1406.88 1056.04,1406.88 1056.05,1406.88 1056.06,1406.88 1056.07,1406.88 1056.08,1406.88 1056.09,1406.88 1056.1,1406.88 1056.11,1406.88 1056.12,1406.88 1056.13,1406.88 1056.13,1406.88 1056.14,1406.88 1056.15,1406.88 1056.16,1406.88 1056.17,1406.88 1056.18,1406.88 1056.19,1406.88 1056.2,1406.88 1056.21,1406.88 1056.22,1406.88 1056.23,1406.88 1056.24,1406.88 1056.24,1406.88 1056.25,1406.88 1056.26,1406.88 1056.27,1406.88 1056.28,1406.88 1056.29,1406.88 1056.3,1406.88 1056.31,1406.88 1056.32,1406.88 1056.33,1406.88 1056.34,1406.88 1056.35,1406.88 1056.36,1406.88 1056.36,1406.88 1056.37,1406.88 1056.38,1406.88 1056.39,1406.88 1056.4,1406.88 1056.41,1406.88 1056.42,1406.88 1056.43,1406.88 1056.44,1406.88 1056.45,1406.88 1056.46,1406.88 1056.47,1406.88 1056.47,1406.88 1056.48,1406.88 1056.49,1406.88 1056.5,1406.88 1056.51,1406.88 1056.52,1406.88 1056.53,1406.88 1056.54,1406.88 1056.55,1406.88 1056.56,1406.88 1056.57,1406.88 1056.58,1406.88 1056.58,1406.88 1056.59,1406.88 1056.6,1406.88 1056.61,1406.88 1056.62,1406.88 1056.63,1406.88 1056.64,1406.88 1056.65,1406.88 1056.66,1406.88 1056.67,1406.88 1056.68,1406.88 1056.69,1406.88 1056.7,1406.88 1056.7,1406.88 1056.71,1406.88 1056.72,1406.88 1056.73,1406.88 1056.74,1406.88 1056.75,1406.88 1056.76,1406.88 1056.77,1406.88 1056.78,1406.88 1056.79,1406.88 1056.8,1406.88 1056.81,1406.88 1056.81,1406.88 1056.82,1406.88 1056.83,1406.88 1056.84,1406.88 1056.85,1406.88 1056.86,1406.88 1056.87,1406.88 1056.88,1406.88 1056.89,1406.88 1056.9,1406.88 1056.91,1406.88 1056.92,1406.88 1056.92,1406.88 1056.93,1406.88 1056.94,1406.88 1056.95,1406.88 1056.96,1406.88 1056.97,1406.88 1056.98,1406.88 1056.99,1406.88 1057,1406.88 1057.01,1406.88 1057.02,1406.88 1057.03,1406.88 1057.04,1406.88 1057.04,1406.88 1057.05,1406.88 1057.06,1406.88 1057.07,1406.88 1057.08,1406.88 1057.09,1406.88 1057.1,1406.88 1057.11,1406.88 1057.12,1406.88 1057.13,1406.88 1057.14,1406.88 1057.15,1406.88 1057.15,1406.88 1057.16,1406.88 1057.17,1406.88 1057.18,1406.88 1057.19,1406.88 1057.2,1406.88 1057.21,1406.88 1057.22,1406.88 1057.23,1406.88 1057.24,1406.88 1057.25,1406.88 1057.26,1406.88 1057.26,1406.88 1057.27,1406.88 1057.28,1406.88 1057.29,1406.88 1057.3,1406.88 1057.31,1406.88 1057.32,1406.88 1057.33,1406.88 1057.34,1406.88 1057.35,1406.88 1057.36,1406.88 1057.37,1406.88 1057.38,1406.88 1057.38,1406.88 1057.39,1406.88 1057.4,1406.88 1057.41,1406.88 1057.42,1406.88 1057.43,1406.88 1057.44,1406.88 1057.45,1406.88 1057.46,1406.88 1057.47,1406.88 1057.48,1406.88 1057.49,1406.88 1057.49,1406.88 1057.5,1406.88 1057.51,1406.88 1057.52,1406.88 1057.53,1406.88 1057.54,1406.88 1057.55,1406.88 1057.56,1406.88 1057.57,1406.88 1057.58,1406.88 1057.59,1406.88 1057.6,1406.88 1057.6,1406.88 1057.61,1406.88 1057.62,1406.88 1057.63,1406.88 1057.64,1406.88 1057.65,1406.88 1057.66,1406.88 1057.67,1406.88 1057.68,1406.88 1057.69,1406.88 1057.7,1406.88 1057.71,1406.88 1057.72,1406.88 1057.72,1406.88 1057.73,1406.88 1057.74,1406.88 1057.75,1406.88 1057.76,1406.88 1057.77,1406.88 1057.78,1406.88 1057.79,1406.88 1057.8,1406.88 1057.81,1406.88 1057.82,1406.88 1057.83,1406.88 1057.83,1406.88 1057.84,1406.88 1057.85,1406.88 1057.86,1406.88 1057.87,1406.88 1057.88,1406.88 1057.89,1406.88 1057.9,1406.88 1057.91,1406.88 1057.92,1406.88 1057.93,1406.88 1057.94,1406.88 1057.94,1406.88 1057.95,1406.88 1057.96,1406.88 1057.97,1406.88 1057.98,1406.88 1057.99,1406.88 1058,1406.88 1058.01,1406.88 1058.02,1406.88 1058.03,1406.88 1058.04,1406.88 1058.05,1406.88 1058.06,1406.88 1058.06,1406.88 1058.07,1406.88 1058.08,1406.88 1058.09,1406.88 1058.1,1406.88 1058.11,1406.88 1058.12,1406.88 1058.13,1406.88 1058.14,1406.88 1058.15,1406.88 1058.16,1406.88 1058.17,1406.88 1058.17,1406.88 1058.18,1406.88 1058.19,1406.88 1058.2,1406.88 1058.21,1406.88 1058.22,1406.88 1058.23,1406.88 1058.24,1406.88 1058.25,1406.88 1058.26,1406.88 1058.27,1406.88 1058.28,1406.88 1058.28,1406.88 1058.29,1406.88 1058.3,1406.88 1058.31,1406.88 1058.32,1406.88 1058.33,1406.88 1058.34,1406.88 1058.35,1406.88 1058.36,1406.88 1058.37,1406.88 1058.38,1406.88 1058.39,1406.88 1058.4,1406.88 1058.4,1406.88 1058.41,1406.88 1058.42,1406.88 1058.43,1406.88 1058.44,1406.88 1058.45,1406.88 1058.46,1406.88 1058.47,1406.88 1058.48,1406.88 1058.49,1406.88 1058.5,1406.88 1058.51,1406.88 1058.51,1406.88 1058.52,1406.88 1058.53,1406.88 1058.54,1406.88 1058.55,1406.88 1058.56,1406.88 1058.57,1406.88 1058.58,1406.88 1058.59,1406.88 1058.6,1406.88 1058.61,1406.88 1058.62,1406.88 1058.62,1406.88 1058.63,1406.88 1058.64,1406.88 1058.65,1406.88 1058.66,1406.88 1058.67,1406.88 1058.68,1406.88 1058.69,1406.88 1058.7,1406.88 1058.71,1406.88 1058.72,1406.88 1058.73,1406.88 1058.74,1406.88 1058.74,1406.88 1058.75,1406.88 1058.76,1406.88 1058.77,1406.88 1058.78,1406.88 1058.79,1406.88 1058.8,1406.88 1058.81,1406.88 1058.82,1406.88 1058.83,1406.88 1058.84,1406.88 1058.85,1406.88 1058.85,1406.88 1058.86,1406.88 1058.87,1406.88 1058.88,1406.88 1058.89,1406.88 1058.9,1406.88 1058.91,1406.88 1058.92,1406.88 1058.93,1406.88 1058.94,1406.88 1058.95,1406.88 1058.96,1406.88 1058.96,1406.88 1058.97,1406.88 1058.98,1406.88 1058.99,1406.88 1059,1406.88 1059.01,1406.88 1059.02,1406.88 1059.03,1406.88 1059.04,1406.88 1059.05,1406.88 1059.06,1406.88 1059.07,1406.88 1059.08,1406.88 1059.08,1406.88 1059.09,1406.88 1059.1,1406.88 1059.11,1406.88 1059.12,1406.88 1059.13,1406.88 1059.14,1406.88 1059.15,1406.88 1059.16,1406.88 1059.17,1406.88 1059.18,1406.88 1059.19,1406.88 1059.19,1406.88 1059.2,1406.88 1059.21,1406.88 1059.22,1406.88 1059.23,1406.88 1059.24,1406.88 1059.25,1406.88 1059.26,1406.88 1059.27,1406.88 1059.28,1406.88 1059.29,1406.88 1059.3,1406.88 1059.3,1406.88 1059.31,1406.88 1059.32,1406.88 1059.33,1406.88 1059.34,1406.88 1059.35,1406.88 1059.36,1406.88 1059.37,1406.88 1059.38,1406.88 1059.39,1406.88 1059.4,1406.88 1059.41,1406.88 1059.42,1406.88 1059.42,1406.88 1059.43,1406.88 1059.44,1406.88 1059.45,1406.88 1059.46,1406.88 1059.47,1406.88 1059.48,1406.88 1059.49,1406.88 1059.5,1406.88 1059.51,1406.88 1059.52,1406.88 1059.53,1406.88 1059.53,1406.88 1059.54,1406.88 1059.55,1406.88 1059.56,1406.88 1059.57,1406.88 1059.58,1406.88 1059.59,1406.88 1059.6,1406.88 1059.61,1406.88 1059.62,1406.88 1059.63,1406.88 1059.64,1406.88 1059.64,1406.88 1059.65,1406.88 1059.66,1406.88 1059.67,1406.88 1059.68,1406.88 1059.69,1406.88 1059.7,1406.88 1059.71,1406.88 1059.72,1406.88 1059.73,1406.88 1059.74,1406.88 1059.75,1406.88 1059.76,1406.88 1059.76,1406.88 1059.77,1406.88 1059.78,1406.88 1059.79,1406.88 1059.8,1406.88 1059.81,1406.88 1059.82,1406.88 1059.83,1406.88 1059.84,1406.88 1059.85,1406.88 1059.86,1406.88 1059.87,1406.88 1059.87,1406.88 1059.88,1406.88 1059.89,1406.88 1059.9,1406.88 1059.91,1406.88 1059.92,1406.88 1059.93,1406.88 1059.94,1406.88 1059.95,1406.88 1059.96,1406.88 1059.97,1406.88 1059.98,1406.88 1059.98,1406.88 1059.99,1406.88 1060,1406.88 1060.01,1406.88 1060.02,1406.88 1060.03,1406.88 1060.04,1406.88 1060.05,1406.88 1060.06,1406.88 1060.07,1406.88 1060.08,1406.88 1060.09,1406.88 1060.1,1406.88 1060.1,1406.88 1060.11,1406.88 1060.12,1406.88 1060.13,1406.88 1060.14,1406.88 1060.15,1406.88 1060.16,1406.88 1060.17,1406.88 1060.18,1406.88 1060.19,1406.88 1060.2,1406.88 1060.21,1406.88 1060.21,1406.88 1060.22,1406.88 1060.23,1406.88 1060.24,1406.88 1060.25,1406.88 1060.26,1406.88 1060.27,1406.88 1060.28,1406.88 1060.29,1406.88 1060.3,1406.88 1060.31,1406.88 1060.32,1406.88 1060.32,1406.88 1060.33,1406.88 1060.34,1406.88 1060.35,1406.88 1060.36,1406.88 1060.37,1406.88 1060.38,1406.88 1060.39,1406.88 1060.4,1406.88 1060.41,1406.88 1060.42,1406.88 1060.43,1406.88 1060.44,1406.88 1060.44,1406.88 1060.45,1406.88 1060.46,1406.88 1060.47,1406.88 1060.48,1406.88 1060.49,1406.88 1060.5,1406.88 1060.51,1406.88 1060.52,1406.88 1060.53,1406.88 1060.54,1406.88 1060.55,1406.88 1060.55,1406.88 1060.56,1406.88 1060.57,1406.88 1060.58,1406.88 1060.59,1406.88 1060.6,1406.88 1060.61,1406.88 1060.62,1406.88 1060.63,1406.88 1060.64,1406.88 1060.65,1406.88 1060.66,1406.88 1060.66,1406.88 1060.67,1406.88 1060.68,1406.88 1060.69,1406.88 1060.7,1406.88 1060.71,1406.88 1060.72,1406.88 1060.73,1406.88 1060.74,1406.88 1060.75,1406.88 1060.76,1406.88 1060.77,1406.88 1060.78,1406.88 1060.78,1406.88 1060.79,1406.88 1060.8,1406.88 1060.81,1406.88 1060.82,1406.88 1060.83,1406.88 1060.84,1406.88 1060.85,1406.88 1060.86,1406.88 1060.87,1406.88 1060.88,1406.88 1060.89,1406.88 1060.89,1406.88 1060.9,1406.88 1060.91,1406.88 1060.92,1406.88 1060.93,1406.88 1060.94,1406.88 1060.95,1406.88 1060.96,1406.88 1060.97,1406.88 1060.98,1406.88 1060.99,1406.88 1061,1406.88 1061,1406.88 1061.01,1406.88 1061.02,1406.88 1061.03,1406.88 1061.04,1406.88 1061.05,1406.88 1061.06,1406.88 1061.07,1406.88 1061.08,1406.88 1061.09,1406.88 1061.1,1406.88 1061.11,1406.88 1061.12,1406.88 1061.12,1406.88 1061.13,1406.88 1061.14,1406.88 1061.15,1406.88 1061.16,1406.88 1061.17,1406.88 1061.18,1406.88 1061.19,1406.88 1061.2,1406.88 1061.21,1406.88 1061.22,1406.88 1061.23,1406.88 1061.23,1406.88 1061.24,1406.88 1061.25,1406.88 1061.26,1406.88 1061.27,1406.88 1061.28,1406.88 1061.29,1406.88 1061.3,1406.88 1061.31,1406.88 1061.32,1406.88 1061.33,1406.88 1061.34,1406.88 1061.34,1406.88 1061.35,1406.88 1061.36,1406.88 1061.37,1406.88 1061.38,1406.88 1061.39,1406.88 1061.4,1406.88 1061.41,1406.88 1061.42,1406.88 1061.43,1406.88 1061.44,1406.88 1061.45,1406.88 1061.46,1406.88 1061.46,1406.88 1061.47,1406.88 1061.48,1406.88 1061.49,1406.88 1061.5,1406.88 1061.51,1406.88 1061.52,1406.88 1061.53,1406.88 1061.54,1406.88 1061.55,1406.88 1061.56,1406.88 1061.57,1406.88 1061.57,1406.88 1061.58,1406.88 1061.59,1406.88 1061.6,1406.88 1061.61,1406.88 1061.62,1406.88 1061.63,1406.88 1061.64,1406.88 1061.65,1406.88 1061.66,1406.88 1061.67,1406.88 1061.68,1406.88 1061.68,1406.88 1061.69,1406.88 1061.7,1406.88 1061.71,1406.88 1061.72,1406.88 1061.73,1406.88 1061.74,1406.88 1061.75,1406.88 1061.76,1406.88 1061.77,1406.88 1061.78,1406.88 1061.79,1406.88 1061.8,1406.88 1061.8,1406.88 1061.81,1406.88 1061.82,1406.88 1061.83,1406.88 1061.84,1406.88 1061.85,1406.88 1061.86,1406.88 1061.87,1406.88 1061.88,1406.88 1061.89,1406.88 1061.9,1406.88 1061.91,1406.88 1061.91,1406.88 1061.92,1406.88 1061.93,1406.88 1061.94,1406.88 1061.95,1406.88 1061.96,1406.88 1061.97,1406.88 1061.98,1406.88 1061.99,1406.88 1062,1406.88 1062.01,1406.88 1062.02,1406.88 1062.02,1406.88 1062.03,1406.88 1062.04,1406.88 1062.05,1406.88 1062.06,1406.88 1062.07,1406.88 1062.08,1406.88 1062.09,1406.88 1062.1,1406.88 1062.11,1406.88 1062.12,1406.88 1062.13,1406.88 1062.14,1406.88 1062.14,1406.88 1062.15,1406.88 1062.16,1406.88 1062.17,1406.88 1062.18,1406.88 1062.19,1406.88 1062.2,1406.88 1062.21,1406.88 1062.22,1406.88 1062.23,1406.88 1062.24,1406.88 1062.25,1406.88 1062.25,1406.88 1062.26,1406.88 1062.27,1406.88 1062.28,1406.88 1062.29,1406.88 1062.3,1406.88 1062.31,1406.88 1062.32,1406.88 1062.33,1406.88 1062.34,1406.88 1062.35,1406.88 1062.36,1406.88 1062.36,1406.88 1062.37,1406.88 1062.38,1406.88 1062.39,1406.88 1062.4,1406.88 1062.41,1406.88 1062.42,1406.88 1062.43,1406.88 1062.44,1406.88 1062.45,1406.88 1062.46,1406.88 1062.47,1406.88 1062.48,1406.88 1062.48,1406.88 1062.49,1406.88 1062.5,1406.88 1062.51,1406.88 1062.52,1406.88 1062.53,1406.88 1062.54,1406.88 1062.55,1406.88 1062.56,1406.88 1062.57,1406.88 1062.58,1406.88 1062.59,1406.88 1062.59,1406.88 1062.6,1406.88 1062.61,1406.88 1062.62,1406.88 1062.63,1406.88 1062.64,1406.88 1062.65,1406.88 1062.66,1406.88 1062.67,1406.88 1062.68,1406.88 1062.69,1406.88 1062.7,1406.88 1062.7,1406.88 1062.71,1406.88 1062.72,1406.88 1062.73,1406.88 1062.74,1406.88 1062.75,1406.88 1062.76,1406.88 1062.77,1406.88 1062.78,1406.88 1062.79,1406.88 1062.8,1406.88 1062.81,1406.88 1062.82,1406.88 1062.82,1406.88 1062.83,1406.88 1062.84,1406.88 1062.85,1406.88 1062.86,1406.88 1062.87,1406.88 1062.88,1406.88 1062.89,1406.88 1062.9,1406.88 1062.91,1406.88 1062.92,1406.88 1062.93,1406.88 1062.93,1406.88 1062.94,1406.88 1062.95,1406.88 1062.96,1406.88 1062.97,1406.88 1062.98,1406.88 1062.99,1406.88 1063,1406.88 1063.01,1406.88 1063.02,1406.88 1063.03,1406.88 1063.04,1406.88 1063.04,1406.88 1063.05,1406.88 1063.06,1406.88 1063.07,1406.88 1063.08,1406.88 1063.09,1406.88 1063.1,1406.88 1063.11,1406.88 1063.12,1406.88 1063.13,1406.88 1063.14,1406.88 1063.15,1406.88 1063.16,1406.88 1063.16,1406.88 1063.17,1406.88 1063.18,1406.88 1063.19,1406.88 1063.2,1406.88 1063.21,1406.88 1063.22,1406.88 1063.23,1406.88 1063.24,1406.88 1063.25,1406.88 1063.26,1406.88 1063.27,1406.88 1063.27,1406.88 1063.28,1406.88 1063.29,1406.88 1063.3,1406.88 1063.31,1406.88 1063.32,1406.88 1063.33,1406.88 1063.34,1406.88 1063.35,1406.88 1063.36,1406.88 1063.37,1406.88 1063.38,1406.88 1063.38,1406.88 1063.39,1406.88 1063.4,1406.88 1063.41,1406.88 1063.42,1406.88 1063.43,1406.88 1063.44,1406.88 1063.45,1406.88 1063.46,1406.88 1063.47,1406.88 1063.48,1406.88 1063.49,1406.88 1063.5,1406.88 1063.5,1406.88 1063.51,1406.88 1063.52,1406.88 1063.53,1406.88 1063.54,1406.88 1063.55,1406.88 1063.56,1406.88 1063.57,1406.88 1063.58,1406.88 1063.59,1406.88 1063.6,1406.88 1063.61,1406.88 1063.61,1406.88 1063.62,1406.88 1063.63,1406.88 1063.64,1406.88 1063.65,1406.88 1063.66,1406.88 1063.67,1406.88 1063.68,1406.88 1063.69,1406.88 1063.7,1406.88 1063.71,1406.88 1063.72,1406.88 1063.72,1406.88 1063.73,1406.88 1063.74,1406.88 1063.75,1406.88 1063.76,1406.88 1063.77,1406.88 1063.78,1406.88 1063.79,1406.88 1063.8,1406.88 1063.81,1406.88 1063.82,1406.88 1063.83,1406.88 1063.84,1406.88 1063.84,1406.88 1063.85,1406.88 1063.86,1406.88 1063.87,1406.88 1063.88,1406.88 1063.89,1406.88 1063.9,1406.88 1063.91,1406.88 1063.92,1406.88 1063.93,1406.88 1063.94,1406.88 1063.95,1406.88 1063.95,1406.88 1063.96,1406.88 1063.97,1406.88 1063.98,1406.88 1063.99,1406.88 1064,1406.88 1064.01,1406.88 1064.02,1406.88 1064.03,1406.88 1064.04,1406.88 1064.05,1406.88 1064.06,1406.88 1064.06,1406.88 1064.07,1406.88 1064.08,1406.88 1064.09,1406.88 1064.1,1406.88 1064.11,1406.88 1064.12,1406.88 1064.13,1406.88 1064.14,1406.88 1064.15,1406.88 1064.16,1406.88 1064.17,1406.88 1064.18,1406.88 1064.18,1406.88 1064.19,1406.88 1064.2,1406.88 1064.21,1406.88 1064.22,1406.88 1064.23,1406.88 1064.24,1406.88 1064.25,1406.88 1064.26,1406.88 1064.27,1406.88 1064.28,1406.88 1064.29,1406.88 1064.29,1406.88 1064.3,1406.88 1064.31,1406.88 1064.32,1406.88 1064.33,1406.88 1064.34,1406.88 1064.35,1406.88 1064.36,1406.88 1064.37,1406.88 1064.38,1406.88 1064.39,1406.88 1064.4,1406.88 1064.4,1406.88 1064.41,1406.88 1064.42,1406.88 1064.43,1406.88 1064.44,1406.88 1064.45,1406.88 1064.46,1406.88 1064.47,1406.88 1064.48,1406.88 1064.49,1406.88 1064.5,1406.88 1064.51,1406.88 1064.52,1406.88 1064.52,1406.88 1064.53,1406.88 1064.54,1406.88 1064.55,1406.88 1064.56,1406.88 1064.57,1406.88 1064.58,1406.88 1064.59,1406.88 1064.6,1406.88 1064.61,1406.88 1064.62,1406.88 1064.63,1406.88 1064.63,1406.88 1064.64,1406.88 1064.65,1406.88 1064.66,1406.88 1064.67,1406.88 1064.68,1406.88 1064.69,1406.88 1064.7,1406.88 1064.71,1406.88 1064.72,1406.88 1064.73,1406.88 1064.74,1406.88 1064.74,1406.88 1064.75,1406.88 1064.76,1406.88 1064.77,1406.88 1064.78,1406.88 1064.79,1406.88 1064.8,1406.88 1064.81,1406.88 1064.82,1406.88 1064.83,1406.88 1064.84,1406.88 1064.85,1406.88 1064.86,1406.88 1064.86,1406.88 1064.87,1406.88 1064.88,1406.88 1064.89,1406.88 1064.9,1406.88 1064.91,1406.88 1064.92,1406.88 1064.93,1406.88 1064.94,1406.88 1064.95,1406.88 1064.96,1406.88 1064.97,1406.88 1064.97,1406.88 1064.98,1406.88 1064.99,1406.88 1065,1406.88 1065.01,1406.88 1065.02,1406.88 1065.03,1406.88 1065.04,1406.88 1065.05,1406.88 1065.06,1406.88 1065.07,1406.88 1065.08,1406.88 1065.08,1406.88 1065.09,1406.88 1065.1,1406.88 1065.11,1406.88 1065.12,1406.88 1065.13,1406.88 1065.14,1406.88 1065.15,1406.88 1065.16,1406.88 1065.17,1406.88 1065.18,1406.88 1065.19,1406.88 1065.2,1406.88 1065.2,1406.88 1065.21,1406.88 1065.22,1406.88 1065.23,1406.88 1065.24,1406.88 1065.25,1406.88 1065.26,1406.88 1065.27,1406.88 1065.28,1406.88 1065.29,1406.88 1065.3,1406.88 1065.31,1406.88 1065.31,1406.88 1065.32,1406.88 1065.33,1406.88 1065.34,1406.88 1065.35,1406.88 1065.36,1406.88 1065.37,1406.88 1065.38,1406.88 1065.39,1406.88 1065.4,1406.88 1065.41,1406.88 1065.42,1406.88 1065.42,1406.88 1065.43,1406.88 1065.44,1406.88 1065.45,1406.88 1065.46,1406.88 1065.47,1406.88 1065.48,1406.88 1065.49,1406.88 1065.5,1406.88 1065.51,1406.88 1065.52,1406.88 1065.53,1406.88 1065.54,1406.88 1065.54,1406.88 1065.55,1406.88 1065.56,1406.88 1065.57,1406.88 1065.58,1406.88 1065.59,1406.88 1065.6,1406.88 1065.61,1406.88 1065.62,1406.88 1065.63,1406.88 1065.64,1406.88 1065.65,1406.88 1065.65,1406.88 1065.66,1406.88 1065.67,1406.88 1065.68,1406.88 1065.69,1406.88 1065.7,1406.88 1065.71,1406.88 1065.72,1406.88 1065.73,1406.88 1065.74,1406.88 1065.75,1406.88 1065.76,1406.88 1065.76,1406.88 1065.77,1406.88 1065.78,1406.88 1065.79,1406.88 1065.8,1406.88 1065.81,1406.88 1065.82,1406.88 1065.83,1406.88 1065.84,1406.88 1065.85,1406.88 1065.86,1406.88 1065.87,1406.88 1065.88,1406.88 1065.88,1406.88 1065.89,1406.88 1065.9,1406.88 1065.91,1406.88 1065.92,1406.88 1065.93,1406.88 1065.94,1406.88 1065.95,1406.88 1065.96,1406.88 1065.97,1406.88 1065.98,1406.88 1065.99,1406.88 1065.99,1406.88 1066,1406.88 1066.01,1406.88 1066.02,1406.88 1066.03,1406.88 1066.04,1406.88 1066.05,1406.88 1066.06,1406.88 1066.07,1406.88 1066.08,1406.88 1066.09,1406.88 1066.1,1406.88 1066.1,1406.88 1066.11,1406.88 1066.12,1406.88 1066.13,1406.88 1066.14,1406.88 1066.15,1406.88 1066.16,1406.88 1066.17,1406.88 1066.18,1406.88 1066.19,1406.88 1066.2,1406.88 1066.21,1406.88 1066.22,1406.88 1066.22,1406.88 1066.23,1406.88 1066.24,1406.88 1066.25,1406.88 1066.26,1406.88 1066.27,1406.88 1066.28,1406.88 1066.29,1406.88 1066.3,1406.88 1066.31,1406.88 1066.32,1406.88 1066.33,1406.88 1066.33,1406.88 1066.34,1406.88 1066.35,1406.88 1066.36,1406.88 1066.37,1406.88 1066.38,1406.88 1066.39,1406.88 1066.4,1406.88 1066.41,1406.88 1066.42,1406.88 1066.43,1406.88 1066.44,1406.88 1066.44,1406.88 1066.45,1406.88 1066.46,1406.88 1066.47,1406.88 1066.48,1406.88 1066.49,1406.88 1066.5,1406.88 1066.51,1406.88 1066.52,1406.88 1066.53,1406.88 1066.54,1406.88 1066.55,1406.88 1066.56,1406.88 1066.56,1406.88 1066.57,1406.88 1066.58,1406.88 1066.59,1406.88 1066.6,1406.88 1066.61,1406.88 1066.62,1406.88 1066.63,1406.88 1066.64,1406.88 1066.65,1406.88 1066.66,1406.88 1066.67,1406.88 1066.67,1406.88 1066.68,1406.88 1066.69,1406.88 1066.7,1406.88 1066.71,1406.88 1066.72,1406.88 1066.73,1406.88 1066.74,1406.88 1066.75,1406.88 1066.76,1406.88 1066.77,1406.88 1066.78,1406.88 1066.78,1406.88 1066.79,1406.88 1066.8,1406.88 1066.81,1406.88 1066.82,1406.88 1066.83,1406.88 1066.84,1406.88 1066.85,1406.88 1066.86,1406.88 1066.87,1406.88 1066.88,1406.88 1066.89,1406.88 1066.9,1406.88 1066.9,1406.88 1066.91,1406.88 1066.92,1406.88 1066.93,1406.88 1066.94,1406.88 1066.95,1406.88 1066.96,1406.88 1066.97,1406.88 1066.98,1406.88 1066.99,1406.88 1067,1406.88 1067.01,1406.88 1067.01,1406.88 1067.02,1406.88 1067.03,1406.88 1067.04,1406.88 1067.05,1406.88 1067.06,1406.88 1067.07,1406.88 1067.08,1406.88 1067.09,1406.88 1067.1,1406.88 1067.11,1406.88 1067.12,1406.88 1067.12,1406.88 1067.13,1406.88 1067.14,1406.88 1067.15,1406.88 1067.16,1406.88 1067.17,1406.88 1067.18,1406.88 1067.19,1406.88 1067.2,1406.88 1067.21,1406.88 1067.22,1406.88 1067.23,1406.88 1067.24,1406.88 1067.24,1406.88 1067.25,1406.88 1067.26,1406.88 1067.27,1406.88 1067.28,1406.88 1067.29,1406.88 1067.3,1406.88 1067.31,1406.88 1067.32,1406.88 1067.33,1406.88 1067.34,1406.88 1067.35,1406.88 1067.35,1406.88 1067.36,1406.88 1067.37,1406.88 1067.38,1406.88 1067.39,1406.88 1067.4,1406.88 1067.41,1406.88 1067.42,1406.88 1067.43,1406.88 1067.44,1406.88 1067.45,1406.88 1067.46,1406.88 1067.46,1406.88 1067.47,1406.88 1067.48,1406.88 1067.49,1406.88 1067.5,1406.88 1067.51,1406.88 1067.52,1406.88 1067.53,1406.88 1067.54,1406.88 1067.55,1406.88 1067.56,1406.88 1067.57,1406.88 1067.58,1406.88 1067.58,1406.88 1067.59,1406.88 1067.6,1406.88 1067.61,1406.88 1067.62,1406.88 1067.63,1406.88 1067.64,1406.88 1067.65,1406.88 1067.66,1406.88 1067.67,1406.88 1067.68,1406.88 1067.69,1406.88 1067.69,1406.88 1067.7,1406.88 1067.71,1406.88 1067.72,1406.88 1067.73,1406.88 1067.74,1406.88 1067.75,1406.88 1067.76,1406.88 1067.77,1406.88 1067.78,1406.88 1067.79,1406.88 1067.8,1406.88 1067.8,1406.88 1067.81,1406.88 1067.82,1406.88 1067.83,1406.88 1067.84,1406.88 1067.85,1406.88 1067.86,1406.88 1067.87,1406.88 1067.88,1406.88 1067.89,1406.88 1067.9,1406.88 1067.91,1406.88 1067.92,1406.88 1067.92,1406.88 1067.93,1406.88 1067.94,1406.88 1067.95,1406.88 1067.96,1406.88 1067.97,1406.88 1067.98,1406.88 1067.99,1406.88 1068,1406.88 1068.01,1406.88 1068.02,1406.88 1068.03,1406.88 1068.03,1406.88 1068.04,1406.88 1068.05,1406.88 1068.06,1406.88 1068.07,1406.88 1068.08,1406.88 1068.09,1406.88 1068.1,1406.88 1068.11,1406.88 1068.12,1406.88 1068.13,1406.88 1068.14,1406.88 1068.14,1406.88 1068.15,1406.88 1068.16,1406.88 1068.17,1406.88 1068.18,1406.88 1068.19,1406.88 1068.2,1406.88 1068.21,1406.88 1068.22,1406.88 1068.23,1406.88 1068.24,1406.88 1068.25,1406.88 1068.26,1406.88 1068.26,1406.88 1068.27,1406.88 1068.28,1406.88 1068.29,1406.88 1068.3,1406.88 1068.31,1406.88 1068.32,1406.88 1068.33,1406.88 1068.34,1406.88 1068.35,1406.88 1068.36,1406.88 1068.37,1406.88 1068.37,1406.88 1068.38,1406.88 1068.39,1406.88 1068.4,1406.88 1068.41,1406.88 1068.42,1406.88 1068.43,1406.88 1068.44,1406.88 1068.45,1406.88 1068.46,1406.88 1068.47,1406.88 1068.48,1406.88 1068.48,1406.88 1068.49,1406.88 1068.5,1406.88 1068.51,1406.88 1068.52,1406.88 1068.53,1406.88 1068.54,1406.88 1068.55,1406.88 1068.56,1406.88 1068.57,1406.88 1068.58,1406.88 1068.59,1406.88 1068.6,1406.88 1068.6,1406.88 1068.61,1406.88 1068.62,1406.88 1068.63,1406.88 1068.64,1406.88 1068.65,1406.88 1068.66,1406.88 1068.67,1406.88 1068.68,1406.88 1068.69,1406.88 1068.7,1406.88 1068.71,1406.88 1068.71,1406.88 1068.72,1406.88 1068.73,1406.88 1068.74,1406.88 1068.75,1406.88 1068.76,1406.88 1068.77,1406.88 1068.78,1406.88 1068.79,1406.88 1068.8,1406.88 1068.81,1406.88 1068.82,1406.88 1068.82,1406.88 1068.83,1406.88 1068.84,1406.88 1068.85,1406.88 1068.86,1406.88 1068.87,1406.88 1068.88,1406.88 1068.89,1406.88 1068.9,1406.88 1068.91,1406.88 1068.92,1406.88 1068.93,1406.88 1068.94,1406.88 1068.94,1406.88 1068.95,1406.88 1068.96,1406.88 1068.97,1406.88 1068.98,1406.88 1068.99,1406.88 1069,1406.88 1069.01,1406.88 1069.02,1406.88 1069.03,1406.88 1069.04,1406.88 1069.05,1406.88 1069.05,1406.88 1069.06,1406.88 1069.07,1406.88 1069.08,1406.88 1069.09,1406.88 1069.1,1406.88 1069.11,1406.88 1069.12,1406.88 1069.13,1406.88 1069.14,1406.88 1069.15,1406.88 1069.16,1406.88 1069.16,1406.88 1069.17,1406.88 1069.18,1406.88 1069.19,1406.88 1069.2,1406.88 1069.21,1406.88 1069.22,1406.88 1069.23,1406.88 1069.24,1406.88 1069.25,1406.88 1069.26,1406.88 1069.27,1406.88 1069.28,1406.88 1069.28,1406.88 1069.29,1406.88 1069.3,1406.88 1069.31,1406.88 1069.32,1406.88 1069.33,1406.88 1069.34,1406.88 1069.35,1406.88 1069.36,1406.88 1069.37,1406.88 1069.38,1406.88 1069.39,1406.88 1069.39,1406.88 1069.4,1406.88 1069.41,1406.88 1069.42,1406.88 1069.43,1406.88 1069.44,1406.88 1069.45,1406.88 1069.46,1406.88 1069.47,1406.88 1069.48,1406.88 1069.49,1406.88 1069.5,1406.88 1069.5,1406.88 1069.51,1406.88 1069.52,1406.88 1069.53,1406.88 1069.54,1406.88 1069.55,1406.88 1069.56,1406.88 1069.57,1406.88 1069.58,1406.88 1069.59,1406.88 1069.6,1406.88 1069.61,1406.88 1069.62,1406.88 1069.62,1406.88 1069.63,1406.88 1069.64,1406.88 1069.65,1406.88 1069.66,1406.88 1069.67,1406.88 1069.68,1406.88 1069.69,1406.88 1069.7,1406.88 1069.71,1406.88 1069.72,1406.88 1069.73,1406.88 1069.73,1406.88 1069.74,1406.88 1069.75,1406.88 1069.76,1406.88 1069.77,1406.88 1069.78,1406.88 1069.79,1406.88 1069.8,1406.88 1069.81,1406.88 1069.82,1406.88 1069.83,1406.88 1069.84,1406.88 1069.84,1406.88 1069.85,1406.88 1069.86,1406.88 1069.87,1406.88 1069.88,1406.88 1069.89,1406.88 1069.9,1406.88 1069.91,1406.88 1069.92,1406.88 1069.93,1406.88 1069.94,1406.88 1069.95,1406.88 1069.96,1406.88 1069.96,1406.88 1069.97,1406.88 1069.98,1406.88 1069.99,1406.88 1070,1406.88 1070.01,1406.88 1070.02,1406.88 1070.03,1406.88 1070.04,1406.88 1070.05,1406.88 1070.06,1406.88 1070.07,1406.88 1070.07,1406.88 1070.08,1406.88 1070.09,1406.88 1070.1,1406.88 1070.11,1406.88 1070.12,1406.88 1070.13,1406.88 1070.14,1406.88 1070.15,1406.88 1070.16,1406.88 1070.17,1406.88 1070.18,1406.88 1070.18,1406.88 1070.19,1406.88 1070.2,1406.88 1070.21,1406.88 1070.22,1406.88 1070.23,1406.88 1070.24,1406.88 1070.25,1406.88 1070.26,1406.88 1070.27,1406.88 1070.28,1406.88 1070.29,1406.88 1070.3,1406.88 1070.3,1406.88 1070.31,1406.88 1070.32,1406.88 1070.33,1406.88 1070.34,1406.88 1070.35,1406.88 1070.36,1406.88 1070.37,1406.88 1070.38,1406.88 1070.39,1406.88 1070.4,1406.88 1070.41,1406.88 1070.41,1406.88 1070.42,1406.88 1070.43,1406.88 1070.44,1406.88 1070.45,1406.88 1070.46,1406.88 1070.47,1406.88 1070.48,1406.88 1070.49,1406.88 1070.5,1406.88 1070.51,1406.88 1070.52,1406.88 1070.52,1406.88 1070.53,1406.88 1070.54,1406.88 1070.55,1406.88 1070.56,1406.88 1070.57,1406.88 1070.58,1406.88 1070.59,1406.88 1070.6,1406.88 1070.61,1406.88 1070.62,1406.88 1070.63,1406.88 1070.64,1406.88 1070.64,1406.88 1070.65,1406.88 1070.66,1406.88 1070.67,1406.88 1070.68,1406.88 1070.69,1406.88 1070.7,1406.88 1070.71,1406.88 1070.72,1406.88 1070.73,1406.88 1070.74,1406.88 1070.75,1406.88 1070.75,1406.88 1070.76,1406.88 1070.77,1406.88 1070.78,1406.88 1070.79,1406.88 1070.8,1406.88 1070.81,1406.88 1070.82,1406.88 1070.83,1406.88 1070.84,1406.88 1070.85,1406.88 1070.86,1406.88 1070.86,1406.88 1070.87,1406.88 1070.88,1406.88 1070.89,1406.88 1070.9,1406.88 1070.91,1406.88 1070.92,1406.88 1070.93,1406.88 1070.94,1406.88 1070.95,1406.88 1070.96,1406.88 1070.97,1406.88 1070.98,1406.88 1070.98,1406.88 1070.99,1406.88 1071,1406.88 1071.01,1406.88 1071.02,1406.88 1071.03,1406.88 1071.04,1406.88 1071.05,1406.88 1071.06,1406.88 1071.07,1406.88 1071.08,1406.88 1071.09,1406.88 1071.09,1406.88 1071.1,1406.88 1071.11,1406.88 1071.12,1406.88 1071.13,1406.88 1071.14,1406.88 1071.15,1406.88 1071.16,1406.88 1071.17,1406.88 1071.18,1406.88 1071.19,1406.88 1071.2,1406.88 1071.2,1406.88 1071.21,1406.88 1071.22,1406.88 1071.23,1406.88 1071.24,1406.88 1071.25,1406.88 1071.26,1406.88 1071.27,1406.88 1071.28,1406.88 1071.29,1406.88 1071.3,1406.88 1071.31,1406.88 1071.32,1406.88 1071.32,1406.88 1071.33,1406.88 1071.34,1406.88 1071.35,1406.88 1071.36,1406.88 1071.37,1406.88 1071.38,1406.88 1071.39,1406.88 1071.4,1406.88 1071.41,1406.88 1071.42,1406.88 1071.43,1406.88 1071.43,1406.88 1071.44,1406.88 1071.45,1406.88 1071.46,1406.88 1071.47,1406.88 1071.48,1406.88 1071.49,1406.88 1071.5,1406.88 1071.51,1406.88 1071.52,1406.88 1071.53,1406.88 1071.54,1406.88 1071.54,1406.88 1071.55,1406.88 1071.56,1406.88 1071.57,1406.88 1071.58,1406.88 1071.59,1406.88 1071.6,1406.88 1071.61,1406.88 1071.62,1406.88 1071.63,1406.88 1071.64,1406.88 1071.65,1406.88 1071.66,1406.88 1071.66,1406.88 1071.67,1406.88 1071.68,1406.88 1071.69,1406.88 1071.7,1406.88 1071.71,1406.88 1071.72,1406.88 1071.73,1406.88 1071.74,1406.88 1071.75,1406.88 1071.76,1406.88 1071.77,1406.88 1071.77,1406.88 1071.78,1406.88 1071.79,1406.88 1071.8,1406.88 1071.81,1406.88 1071.82,1406.88 1071.83,1406.88 1071.84,1406.88 1071.85,1406.88 1071.86,1406.88 1071.87,1406.88 1071.88,1406.88 1071.88,1406.88 1071.89,1406.88 1071.9,1406.88 1071.91,1406.88 1071.92,1406.88 1071.93,1406.88 1071.94,1406.88 1071.95,1406.88 1071.96,1406.88 1071.97,1406.88 1071.98,1406.88 1071.99,1406.88 1072,1406.88 1072,1406.88 1072.01,1406.88 1072.02,1406.88 1072.03,1406.88 1072.04,1406.88 1072.05,1406.88 1072.06,1406.88 1072.07,1406.88 1072.08,1406.88 1072.09,1406.88 1072.1,1406.88 1072.11,1406.88 1072.11,1406.88 1072.12,1406.88 1072.13,1406.88 1072.14,1406.88 1072.15,1406.88 1072.16,1406.88 1072.17,1406.88 1072.18,1406.88 1072.19,1406.88 1072.2,1406.88 1072.21,1406.88 1072.22,1406.88 1072.23,1406.88 1072.23,1406.88 1072.24,1406.88 1072.25,1406.88 1072.26,1406.88 1072.27,1406.88 1072.28,1406.88 1072.29,1406.88 1072.3,1406.88 1072.31,1406.88 1072.32,1406.88 1072.33,1406.88 1072.34,1406.88 1072.34,1406.88 1072.35,1406.88 1072.36,1406.88 1072.37,1406.88 1072.38,1406.88 1072.39,1406.88 1072.4,1406.88 1072.41,1406.88 1072.42,1406.88 1072.43,1406.88 1072.44,1406.88 1072.45,1406.88 1072.45,1406.88 1072.46,1406.88 1072.47,1406.88 1072.48,1406.88 1072.49,1406.88 1072.5,1406.88 1072.51,1406.88 1072.52,1406.88 1072.53,1406.88 1072.54,1406.88 1072.55,1406.88 1072.56,1406.88 1072.57,1406.88 1072.57,1406.88 1072.58,1406.88 1072.59,1406.88 1072.6,1406.88 1072.61,1406.88 1072.62,1406.88 1072.63,1406.88 1072.64,1406.88 1072.65,1406.88 1072.66,1406.88 1072.67,1406.88 1072.68,1406.88 1072.68,1406.88 1072.69,1406.88 1072.7,1406.88 1072.71,1406.88 1072.72,1406.88 1072.73,1406.88 1072.74,1406.88 1072.75,1406.88 1072.76,1406.88 1072.77,1406.88 1072.78,1406.88 1072.79,1406.88 1072.79,1406.88 1072.8,1406.88 1072.81,1406.88 1072.82,1406.88 1072.83,1406.88 1072.84,1406.88 1072.85,1406.88 1072.86,1406.88 1072.87,1406.88 1072.88,1406.88 1072.89,1406.88 1072.9,1406.88 1072.91,1406.88 1072.91,1406.88 1072.92,1406.88 1072.93,1406.88 1072.94,1406.88 1072.95,1406.88 1072.96,1406.88 1072.97,1406.88 1072.98,1406.88 1072.99,1406.88 1073,1406.88 1073.01,1406.88 1073.02,1406.88 1073.02,1406.88 1073.03,1406.88 1073.04,1406.88 1073.05,1406.88 1073.06,1406.88 1073.07,1406.88 1073.08,1406.88 1073.09,1406.88 1073.1,1406.88 1073.11,1406.88 1073.12,1406.88 1073.13,1406.88 1073.13,1406.88 1073.14,1406.88 1073.15,1406.88 1073.16,1406.88 1073.17,1406.88 1073.18,1406.88 1073.19,1406.88 1073.2,1406.88 1073.21,1406.88 1073.22,1406.88 1073.23,1406.88 1073.24,1406.88 1073.25,1406.88 1073.25,1406.88 1073.26,1406.88 1073.27,1406.88 1073.28,1406.88 1073.29,1406.88 1073.3,1406.88 1073.31,1406.88 1073.32,1406.88 1073.33,1406.88 1073.34,1406.88 1073.35,1406.88 1073.36,1406.88 1073.36,1406.88 1073.37,1406.88 1073.38,1406.88 1073.39,1406.88 1073.4,1406.88 1073.41,1406.88 1073.42,1406.88 1073.43,1406.88 1073.44,1406.88 1073.45,1406.88 1073.46,1406.88 1073.47,1406.88 1073.47,1406.88 1073.48,1406.88 1073.49,1406.88 1073.5,1406.88 1073.51,1406.88 1073.52,1406.88 1073.53,1406.88 1073.54,1406.88 1073.55,1406.88 1073.56,1406.88 1073.57,1406.88 1073.58,1406.88 1073.59,1406.88 1073.59,1406.88 1073.6,1406.88 1073.61,1406.88 1073.62,1406.88 1073.63,1406.88 1073.64,1406.88 1073.65,1406.88 1073.66,1406.88 1073.67,1406.88 1073.68,1406.88 1073.69,1406.88 1073.7,1406.88 1073.7,1406.88 1073.71,1406.88 1073.72,1406.88 1073.73,1406.88 1073.74,1406.88 1073.75,1406.88 1073.76,1406.88 1073.77,1406.88 1073.78,1406.88 1073.79,1406.88 1073.8,1406.88 1073.81,1406.88 1073.81,1406.88 1073.82,1406.88 1073.83,1406.88 1073.84,1406.88 1073.85,1406.88 1073.86,1406.88 1073.87,1406.88 1073.88,1406.88 1073.89,1406.88 1073.9,1406.88 1073.91,1406.88 1073.92,1406.88 1073.93,1406.88 1073.93,1406.88 1073.94,1406.88 1073.95,1406.88 1073.96,1406.88 1073.97,1406.88 1073.98,1406.88 1073.99,1406.88 1074,1406.88 1074.01,1406.88 1074.02,1406.88 1074.03,1406.88 1074.04,1406.88 1074.04,1406.88 1074.05,1406.88 1074.06,1406.88 1074.07,1406.88 1074.08,1406.88 1074.09,1406.88 1074.1,1406.88 1074.11,1406.88 1074.12,1406.88 1074.13,1406.88 1074.14,1406.88 1074.15,1406.88 1074.15,1406.88 1074.16,1406.88 1074.17,1406.88 1074.18,1406.88 1074.19,1406.88 1074.2,1406.88 1074.21,1406.88 1074.22,1406.88 1074.23,1406.88 1074.24,1406.88 1074.25,1406.88 1074.26,1406.88 1074.27,1406.88 1074.27,1406.88 1074.28,1406.88 1074.29,1406.88 1074.3,1406.88 1074.31,1406.88 1074.32,1406.88 1074.33,1406.88 1074.34,1406.88 1074.35,1406.88 1074.36,1406.88 1074.37,1406.88 1074.38,1406.88 1074.38,1406.88 1074.39,1406.88 1074.4,1406.88 1074.41,1406.88 1074.42,1406.88 1074.43,1406.88 1074.44,1406.88 1074.45,1406.88 1074.46,1406.88 1074.47,1406.88 1074.48,1406.88 1074.49,1406.88 1074.49,1406.88 1074.5,1406.88 1074.51,1406.88 1074.52,1406.88 1074.53,1406.88 1074.54,1406.88 1074.55,1406.88 1074.56,1406.88 1074.57,1406.88 1074.58,1406.88 1074.59,1406.88 1074.6,1406.88 1074.61,1406.88 1074.61,1406.88 1074.62,1406.88 1074.63,1406.88 1074.64,1406.88 1074.65,1406.88 1074.66,1406.88 1074.67,1406.88 1074.68,1406.88 1074.69,1406.88 1074.7,1406.88 1074.71,1406.88 1074.72,1406.88 1074.72,1406.88 1074.73,1406.88 1074.74,1406.88 1074.75,1406.88 1074.76,1406.88 1074.77,1406.88 1074.78,1406.88 1074.79,1406.88 1074.8,1406.88 1074.81,1406.88 1074.82,1406.88 1074.83,1406.88 1074.83,1406.88 1074.84,1406.88 1074.85,1406.88 1074.86,1406.88 1074.87,1406.88 1074.88,1406.88 1074.89,1406.88 1074.9,1406.88 1074.91,1406.88 1074.92,1406.88 1074.93,1406.88 1074.94,1406.88 1074.95,1406.88 1074.95,1406.88 1074.96,1406.88 1074.97,1406.88 1074.98,1406.88 1074.99,1406.88 1075,1406.88 1075.01,1406.88 1075.02,1406.88 1075.03,1406.88 1075.04,1406.88 1075.05,1406.88 1075.06,1406.88 1075.06,1406.88 1075.07,1406.88 1075.08,1406.88 1075.09,1406.88 1075.1,1406.88 1075.11,1406.88 1075.12,1406.88 1075.13,1406.88 1075.14,1406.88 1075.15,1406.88 1075.16,1406.88 1075.17,1406.88 1075.17,1406.88 1075.18,1406.88 1075.19,1406.88 1075.2,1406.88 1075.21,1406.88 1075.22,1406.88 1075.23,1406.88 1075.24,1406.88 1075.25,1406.88 1075.26,1406.88 1075.27,1406.88 1075.28,1406.88 1075.29,1406.88 1075.29,1406.88 1075.3,1406.88 1075.31,1406.88 1075.32,1406.88 1075.33,1406.88 1075.34,1406.88 1075.35,1406.88 1075.36,1406.88 1075.37,1406.88 1075.38,1406.88 1075.39,1406.88 1075.4,1406.88 1075.4,1406.88 1075.41,1406.88 1075.42,1406.88 1075.43,1406.88 1075.44,1406.88 1075.45,1406.88 1075.46,1406.88 1075.47,1406.88 1075.48,1406.88 1075.49,1406.88 1075.5,1406.88 1075.51,1406.88 1075.51,1406.88 1075.52,1406.88 1075.53,1406.88 1075.54,1406.88 1075.55,1406.88 1075.56,1406.88 1075.57,1406.88 1075.58,1406.88 1075.59,1406.88 1075.6,1406.88 1075.61,1406.88 1075.62,1406.88 1075.63,1406.88 1075.63,1406.88 1075.64,1406.88 1075.65,1406.88 1075.66,1406.88 1075.67,1406.88 1075.68,1406.88 1075.69,1406.88 1075.7,1406.88 1075.71,1406.88 1075.72,1406.88 1075.73,1406.88 1075.74,1406.88 1075.74,1406.88 1075.75,1406.88 1075.76,1406.88 1075.77,1406.88 1075.78,1406.88 1075.79,1406.88 1075.8,1406.88 1075.81,1406.88 1075.82,1406.88 1075.83,1406.88 1075.84,1406.88 1075.85,1406.88 1075.85,1406.88 1075.86,1406.88 1075.87,1406.88 1075.88,1406.88 1075.89,1406.88 1075.9,1406.88 1075.91,1406.88 1075.92,1406.88 1075.93,1406.88 1075.94,1406.88 1075.95,1406.88 1075.96,1406.88 1075.97,1406.88 1075.97,1406.88 1075.98,1406.88 1075.99,1406.88 1076,1406.88 1076.01,1406.88 1076.02,1406.88 1076.03,1406.88 1076.04,1406.88 1076.05,1406.88 1076.06,1406.88 1076.07,1406.88 1076.08,1406.88 1076.08,1406.88 1076.09,1406.88 1076.1,1406.88 1076.11,1406.88 1076.12,1406.88 1076.13,1406.88 1076.14,1406.88 1076.15,1406.88 1076.16,1406.88 1076.17,1406.88 1076.18,1406.88 1076.19,1406.88 1076.19,1406.88 1076.2,1406.88 1076.21,1406.88 1076.22,1406.88 1076.23,1406.88 1076.24,1406.88 1076.25,1406.88 1076.26,1406.88 1076.27,1406.88 1076.28,1406.88 1076.29,1406.88 1076.3,1406.88 1076.31,1406.88 1076.31,1406.88 1076.32,1406.88 1076.33,1406.88 1076.34,1406.88 1076.35,1406.88 1076.36,1406.88 1076.37,1406.88 1076.38,1406.88 1076.39,1406.88 1076.4,1406.88 1076.41,1406.88 1076.42,1406.88 1076.42,1406.88 1076.43,1406.88 1076.44,1406.88 1076.45,1406.88 1076.46,1406.88 1076.47,1406.88 1076.48,1406.88 1076.49,1406.88 1076.5,1406.88 1076.51,1406.88 1076.52,1406.88 1076.53,1406.88 1076.53,1406.88 1076.54,1406.88 1076.55,1406.88 1076.56,1406.88 1076.57,1406.88 1076.58,1406.88 1076.59,1406.88 1076.6,1406.88 1076.61,1406.88 1076.62,1406.88 1076.63,1406.88 1076.64,1406.88 1076.65,1406.88 1076.65,1406.88 1076.66,1406.88 1076.67,1406.88 1076.68,1406.88 1076.69,1406.88 1076.7,1406.88 1076.71,1406.88 1076.72,1406.88 1076.73,1406.88 1076.74,1406.88 1076.75,1406.88 1076.76,1406.88 1076.76,1406.88 1076.77,1406.88 1076.78,1406.88 1076.79,1406.88 1076.8,1406.88 1076.81,1406.88 1076.82,1406.88 1076.83,1406.88 1076.84,1406.88 1076.85,1406.88 1076.86,1406.88 1076.87,1406.88 1076.87,1406.88 1076.88,1406.88 1076.89,1406.88 1076.9,1406.88 1076.91,1406.88 1076.92,1406.88 1076.93,1406.88 1076.94,1406.88 1076.95,1406.88 1076.96,1406.88 1076.97,1406.88 1076.98,1406.88 1076.99,1406.88 1076.99,1406.88 1077,1406.88 1077.01,1406.88 1077.02,1406.88 1077.03,1406.88 1077.04,1406.88 1077.05,1406.88 1077.06,1406.88 1077.07,1406.88 1077.08,1406.88 1077.09,1406.88 1077.1,1406.88 1077.1,1406.88 1077.11,1406.88 1077.12,1406.88 1077.13,1406.88 1077.14,1406.88 1077.15,1406.88 1077.16,1406.88 1077.17,1406.88 1077.18,1406.88 1077.19,1406.88 1077.2,1406.88 1077.21,1406.88 1077.21,1406.88 1077.22,1406.88 1077.23,1406.88 1077.24,1406.88 1077.25,1406.88 1077.26,1406.88 1077.27,1406.88 1077.28,1406.88 1077.29,1406.88 1077.3,1406.88 1077.31,1406.88 1077.32,1406.88 1077.33,1406.88 1077.33,1406.88 1077.34,1406.88 1077.35,1406.88 1077.36,1406.88 1077.37,1406.88 1077.38,1406.88 1077.39,1406.88 1077.4,1406.88 1077.41,1406.88 1077.42,1406.88 1077.43,1406.88 1077.44,1406.88 1077.44,1406.88 1077.45,1406.88 1077.46,1406.88 1077.47,1406.88 1077.48,1406.88 1077.49,1406.88 1077.5,1406.88 1077.51,1406.88 1077.52,1406.88 1077.53,1406.88 1077.54,1406.88 1077.55,1406.88 1077.55,1406.88 1077.56,1406.88 1077.57,1406.88 1077.58,1406.88 1077.59,1406.88 1077.6,1406.88 1077.61,1406.88 1077.62,1406.88 1077.63,1406.88 1077.64,1406.88 1077.65,1406.88 1077.66,1406.88 1077.67,1406.88 1077.67,1406.88 1077.68,1406.88 1077.69,1406.88 1077.7,1406.88 1077.71,1406.88 1077.72,1406.88 1077.73,1406.88 1077.74,1406.88 1077.75,1406.88 1077.76,1406.88 1077.77,1406.88 1077.78,1406.88 1077.78,1406.88 1077.79,1406.88 1077.8,1406.88 1077.81,1406.88 1077.82,1406.88 1077.83,1406.88 1077.84,1406.88 1077.85,1406.88 1077.86,1406.88 1077.87,1406.88 1077.88,1406.88 1077.89,1406.88 1077.89,1406.88 1077.9,1406.88 1077.91,1406.88 1077.92,1406.88 1077.93,1406.88 1077.94,1406.88 1077.95,1406.88 1077.96,1406.88 1077.97,1406.88 1077.98,1406.88 1077.99,1406.88 1078,1406.88 1078.01,1406.88 1078.01,1406.88 1078.02,1406.88 1078.03,1406.88 1078.04,1406.88 1078.05,1406.88 1078.06,1406.88 1078.07,1406.88 1078.08,1406.88 1078.09,1406.88 1078.1,1406.88 1078.11,1406.88 1078.12,1406.88 1078.12,1406.88 1078.13,1406.88 1078.14,1406.88 1078.15,1406.88 1078.16,1406.88 1078.17,1406.88 1078.18,1406.88 1078.19,1406.88 1078.2,1406.88 1078.21,1406.88 1078.22,1406.88 1078.23,1406.88 1078.23,1406.88 1078.24,1406.88 1078.25,1406.88 1078.26,1406.88 1078.27,1406.88 1078.28,1406.88 1078.29,1406.88 1078.3,1406.88 1078.31,1406.88 1078.32,1406.88 1078.33,1406.88 1078.34,1406.88 1078.35,1406.88 1078.35,1406.88 1078.36,1406.88 1078.37,1406.88 1078.38,1406.88 1078.39,1406.88 1078.4,1406.88 1078.41,1406.88 1078.42,1406.88 1078.43,1406.88 1078.44,1406.88 1078.45,1406.88 1078.46,1406.88 1078.46,1406.88 1078.47,1406.88 1078.48,1406.88 1078.49,1406.88 1078.5,1406.88 1078.51,1406.88 1078.52,1406.88 1078.53,1406.88 1078.54,1406.88 1078.55,1406.88 1078.56,1406.88 1078.57,1406.88 1078.57,1406.88 1078.58,1406.88 1078.59,1406.88 1078.6,1406.88 1078.61,1406.88 1078.62,1406.88 1078.63,1406.88 1078.64,1406.88 1078.65,1406.88 1078.66,1406.88 1078.67,1406.88 1078.68,1406.88 1078.69,1406.88 1078.69,1406.88 1078.7,1406.88 1078.71,1406.88 1078.72,1406.88 1078.73,1406.88 1078.74,1406.88 1078.75,1406.88 1078.76,1406.88 1078.77,1406.88 1078.78,1406.88 1078.79,1406.88 1078.8,1406.88 1078.8,1406.88 1078.81,1406.88 1078.82,1406.88 1078.83,1406.88 1078.84,1406.88 1078.85,1406.88 1078.86,1406.88 1078.87,1406.88 1078.88,1406.88 1078.89,1406.88 1078.9,1406.88 1078.91,1406.88 1078.91,1406.88 1078.92,1406.88 1078.93,1406.88 1078.94,1406.88 1078.95,1406.88 1078.96,1406.88 1078.97,1406.88 1078.98,1406.88 1078.99,1406.88 1079,1406.88 1079.01,1406.88 1079.02,1406.88 1079.03,1406.88 1079.03,1406.88 1079.04,1406.88 1079.05,1406.88 1079.06,1406.88 1079.07,1406.88 1079.08,1406.88 1079.09,1406.88 1079.1,1406.88 1079.11,1406.88 1079.12,1406.88 1079.13,1406.88 1079.14,1406.88 1079.14,1406.88 1079.15,1406.88 1079.16,1406.88 1079.17,1406.88 1079.18,1406.88 1079.19,1406.88 1079.2,1406.88 1079.21,1406.88 1079.22,1406.88 1079.23,1406.88 1079.24,1406.88 1079.25,1406.88 1079.25,1406.88 1079.26,1406.88 1079.27,1406.88 1079.28,1406.88 1079.29,1406.88 1079.3,1406.88 1079.31,1406.88 1079.32,1406.88 1079.33,1406.88 1079.34,1406.88 1079.35,1406.88 1079.36,1406.88 1079.37,1406.88 1079.37,1406.88 1079.38,1406.88 1079.39,1406.88 1079.4,1406.88 1079.41,1406.88 1079.42,1406.88 1079.43,1406.88 1079.44,1406.88 1079.45,1406.88 1079.46,1406.88 1079.47,1406.88 1079.48,1406.88 1079.48,1406.88 1079.49,1406.88 1079.5,1406.88 1079.51,1406.88 1079.52,1406.88 1079.53,1406.88 1079.54,1406.88 1079.55,1406.88 1079.56,1406.88 1079.57,1406.88 1079.58,1406.88 1079.59,1406.88 1079.59,1406.88 1079.6,1406.88 1079.61,1406.88 1079.62,1406.88 1079.63,1406.88 1079.64,1406.88 1079.65,1406.88 1079.66,1406.88 1079.67,1406.88 1079.68,1406.88 1079.69,1406.88 1079.7,1406.88 1079.71,1406.88 1079.71,1406.88 1079.72,1406.88 1079.73,1406.88 1079.74,1406.88 1079.75,1406.88 1079.76,1406.88 1079.77,1406.88 1079.78,1406.88 1079.79,1406.88 1079.8,1406.88 1079.81,1406.88 1079.82,1406.88 1079.82,1406.88 1079.83,1406.88 1079.84,1406.88 1079.85,1406.88 1079.86,1406.88 1079.87,1406.88 1079.88,1406.88 1079.89,1406.88 1079.9,1406.88 1079.91,1406.88 1079.92,1406.88 1079.93,1406.88 1079.93,1406.88 1079.94,1406.88 1079.95,1406.88 1079.96,1406.88 1079.97,1406.88 1079.98,1406.88 1079.99,1406.88 1080,1406.88 1080.01,1406.88 1080.02,1406.88 1080.03,1406.88 1080.04,1406.88 1080.05,1406.88 1080.05,1406.88 1080.06,1406.88 1080.07,1406.88 1080.08,1406.88 1080.09,1406.88 1080.1,1406.88 1080.11,1406.88 1080.12,1406.88 1080.13,1406.88 1080.14,1406.88 1080.15,1406.88 1080.16,1406.88 1080.16,1406.88 1080.17,1406.88 1080.18,1406.88 1080.19,1406.88 1080.2,1406.88 1080.21,1406.88 1080.22,1406.88 1080.23,1406.88 1080.24,1406.88 1080.25,1406.88 1080.26,1406.88 1080.27,1406.88 1080.27,1406.88 1080.28,1406.88 1080.29,1406.88 1080.3,1406.88 1080.31,1406.88 1080.32,1406.88 1080.33,1406.88 1080.34,1406.88 1080.35,1406.88 1080.36,1406.88 1080.37,1406.88 1080.38,1406.88 1080.39,1406.88 1080.39,1406.88 1080.4,1406.88 1080.41,1406.88 1080.42,1406.88 1080.43,1406.88 1080.44,1406.88 1080.45,1406.88 1080.46,1406.88 1080.47,1406.88 1080.48,1406.88 1080.49,1406.88 1080.5,1406.88 1080.5,1406.88 1080.51,1406.88 1080.52,1406.88 1080.53,1406.88 1080.54,1406.88 1080.55,1406.88 1080.56,1406.88 1080.57,1406.88 1080.58,1406.88 1080.59,1406.88 1080.6,1406.88 1080.61,1406.88 1080.61,1406.88 1080.62,1406.88 1080.63,1406.88 1080.64,1406.88 1080.65,1406.88 1080.66,1406.88 1080.67,1406.88 1080.68,1406.88 1080.69,1406.88 1080.7,1406.88 1080.71,1406.88 1080.72,1406.88 1080.73,1406.88 1080.73,1406.88 1080.74,1406.88 1080.75,1406.88 1080.76,1406.88 1080.77,1406.88 1080.78,1406.88 1080.79,1406.88 1080.8,1406.88 1080.81,1406.88 1080.82,1406.88 1080.83,1406.88 1080.84,1406.88 1080.84,1406.88 1080.85,1406.88 1080.86,1406.88 1080.87,1406.88 1080.88,1406.88 1080.89,1406.88 1080.9,1406.88 1080.91,1406.88 1080.92,1406.88 1080.93,1406.88 1080.94,1406.88 1080.95,1406.88 1080.95,1406.88 1080.96,1406.88 1080.97,1406.88 1080.98,1406.88 1080.99,1406.88 1081,1406.88 1081.01,1406.88 1081.02,1406.88 1081.03,1406.88 1081.04,1406.88 1081.05,1406.88 1081.06,1406.88 1081.07,1406.88 1081.07,1406.88 1081.08,1406.88 1081.09,1406.88 1081.1,1406.88 1081.11,1406.88 1081.12,1406.88 1081.13,1406.88 1081.14,1406.88 1081.15,1406.88 1081.16,1406.88 1081.17,1406.88 1081.18,1406.88 1081.18,1406.88 1081.19,1406.88 1081.2,1406.88 1081.21,1406.88 1081.22,1406.88 1081.23,1406.88 1081.24,1406.88 1081.25,1406.88 1081.26,1406.88 1081.27,1406.88 1081.28,1406.88 1081.29,1406.88 1081.29,1406.88 1081.3,1406.88 1081.31,1406.88 1081.32,1406.88 1081.33,1406.88 1081.34,1406.88 1081.35,1406.88 1081.36,1406.88 1081.37,1406.88 1081.38,1406.88 1081.39,1406.88 1081.4,1406.88 1081.41,1406.88 1081.41,1406.88 1081.42,1406.88 1081.43,1406.88 1081.44,1406.88 1081.45,1406.88 1081.46,1406.88 1081.47,1406.88 1081.48,1406.88 1081.49,1406.88 1081.5,1406.88 1081.51,1406.88 1081.52,1406.88 1081.52,1406.88 1081.53,1406.88 1081.54,1406.88 1081.55,1406.88 1081.56,1406.88 1081.57,1406.88 1081.58,1406.88 1081.59,1406.88 1081.6,1406.88 1081.61,1406.88 1081.62,1406.88 1081.63,1406.88 1081.63,1406.88 1081.64,1406.88 1081.65,1406.88 1081.66,1406.88 1081.67,1406.88 1081.68,1406.88 1081.69,1406.88 1081.7,1406.88 1081.71,1406.88 1081.72,1406.88 1081.73,1406.88 1081.74,1406.88 1081.75,1406.88 1081.75,1406.88 1081.76,1406.88 1081.77,1406.88 1081.78,1406.88 1081.79,1406.88 1081.8,1406.88 1081.81,1406.88 1081.82,1406.88 1081.83,1406.88 1081.84,1406.88 1081.85,1406.88 1081.86,1406.88 1081.86,1406.88 1081.87,1406.88 1081.88,1406.88 1081.89,1406.88 1081.9,1406.88 1081.91,1406.88 1081.92,1406.88 1081.93,1406.88 1081.94,1406.88 1081.95,1406.88 1081.96,1406.88 1081.97,1406.88 1081.97,1406.88 1081.98,1406.88 1081.99,1406.88 1082,1406.88 1082.01,1406.88 1082.02,1406.88 1082.03,1406.88 1082.04,1406.88 1082.05,1406.88 1082.06,1406.88 1082.07,1406.88 1082.08,1406.88 1082.09,1406.88 1082.09,1406.88 1082.1,1406.88 1082.11,1406.88 1082.12,1406.88 1082.13,1406.88 1082.14,1406.88 1082.15,1406.88 1082.16,1406.88 1082.17,1406.88 1082.18,1406.88 1082.19,1406.88 1082.2,1406.88 1082.2,1406.88 1082.21,1406.88 1082.22,1406.88 1082.23,1406.88 1082.24,1406.88 1082.25,1406.88 1082.26,1406.88 1082.27,1406.88 1082.28,1406.88 1082.29,1406.88 1082.3,1406.88 1082.31,1406.88 1082.31,1406.88 1082.32,1406.88 1082.33,1406.88 1082.34,1406.88 1082.35,1406.88 1082.36,1406.88 1082.37,1406.88 1082.38,1406.88 1082.39,1406.88 1082.4,1406.88 1082.41,1406.88 1082.42,1406.88 1082.43,1406.88 1082.43,1406.88 1082.44,1406.88 1082.45,1406.88 1082.46,1406.88 1082.47,1406.88 1082.48,1406.88 1082.49,1406.88 1082.5,1406.88 1082.51,1406.88 1082.52,1406.88 1082.53,1406.88 1082.54,1406.88 1082.54,1406.88 1082.55,1406.88 1082.56,1406.88 1082.57,1406.88 1082.58,1406.88 1082.59,1406.88 1082.6,1406.88 1082.61,1406.88 1082.62,1406.88 1082.63,1406.88 1082.64,1406.88 1082.65,1406.88 1082.65,1406.88 1082.66,1406.88 1082.67,1406.88 1082.68,1406.88 1082.69,1406.88 1082.7,1406.88 1082.71,1406.88 1082.72,1406.88 1082.73,1406.88 1082.74,1406.88 1082.75,1406.88 1082.76,1406.88 1082.77,1406.88 1082.77,1406.88 1082.78,1406.88 1082.79,1406.88 1082.8,1406.88 1082.81,1406.88 1082.82,1406.88 1082.83,1406.88 1082.84,1406.88 1082.85,1406.88 1082.86,1406.88 1082.87,1406.88 1082.88,1406.88 1082.88,1406.88 1082.89,1406.88 1082.9,1406.88 1082.91,1406.88 1082.92,1406.88 1082.93,1406.88 1082.94,1406.88 1082.95,1406.88 1082.96,1406.88 1082.97,1406.88 1082.98,1406.88 1082.99,1406.88 1082.99,1406.88 1083,1406.88 1083.01,1406.88 1083.02,1406.88 1083.03,1406.88 1083.04,1406.88 1083.05,1406.88 1083.06,1406.88 1083.07,1406.88 1083.08,1406.88 1083.09,1406.88 1083.1,1406.88 1083.11,1406.88 1083.11,1406.88 1083.12,1406.88 1083.13,1406.88 1083.14,1406.88 1083.15,1406.88 1083.16,1406.88 1083.17,1406.88 1083.18,1406.88 1083.19,1406.88 1083.2,1406.88 1083.21,1406.88 1083.22,1406.88 1083.22,1406.88 1083.23,1406.88 1083.24,1406.88 1083.25,1406.88 1083.26,1406.88 1083.27,1406.88 1083.28,1406.88 1083.29,1406.88 1083.3,1406.88 1083.31,1406.88 1083.32,1406.88 1083.33,1406.88 1083.33,1406.88 1083.34,1406.88 1083.35,1406.88 1083.36,1406.88 1083.37,1406.88 1083.38,1406.88 1083.39,1406.88 1083.4,1406.88 1083.41,1406.88 1083.42,1406.88 1083.43,1406.88 1083.44,1406.88 1083.45,1406.88 1083.45,1406.88 1083.46,1406.88 1083.47,1406.88 1083.48,1406.88 1083.49,1406.88 1083.5,1406.88 1083.51,1406.88 1083.52,1406.88 1083.53,1406.88 1083.54,1406.88 1083.55,1406.88 1083.56,1406.88 1083.56,1406.88 1083.57,1406.88 1083.58,1406.88 1083.59,1406.88 1083.6,1406.88 1083.61,1406.88 1083.62,1406.88 1083.63,1406.88 1083.64,1406.88 1083.65,1406.88 1083.66,1406.88 1083.67,1406.88 1083.67,1406.88 1083.68,1406.88 1083.69,1406.88 1083.7,1406.88 1083.71,1406.88 1083.72,1406.88 1083.73,1406.88 1083.74,1406.88 1083.75,1406.88 1083.76,1406.88 1083.77,1406.88 1083.78,1406.88 1083.79,1406.88 1083.79,1406.88 1083.8,1406.88 1083.81,1406.88 1083.82,1406.88 1083.83,1406.88 1083.84,1406.88 1083.85,1406.88 1083.86,1406.88 1083.87,1406.88 1083.88,1406.88 1083.89,1406.88 1083.9,1406.88 1083.9,1406.88 1083.91,1406.88 1083.92,1406.88 1083.93,1406.88 1083.94,1406.88 1083.95,1406.88 1083.96,1406.88 1083.97,1406.88 1083.98,1406.88 1083.99,1406.88 1084,1406.88 1084.01,1406.88 1084.01,1406.88 1084.02,1406.88 1084.03,1406.88 1084.04,1406.88 1084.05,1406.88 1084.06,1406.88 1084.07,1406.88 1084.08,1406.88 1084.09,1406.88 1084.1,1406.88 1084.11,1406.88 1084.12,1406.88 1084.13,1406.88 1084.13,1406.88 1084.14,1406.88 1084.15,1406.88 1084.16,1406.88 1084.17,1406.88 1084.18,1406.88 1084.19,1406.88 1084.2,1406.88 1084.21,1406.88 1084.22,1406.88 1084.23,1406.88 1084.24,1406.88 1084.24,1406.88 1084.25,1406.88 1084.26,1406.88 1084.27,1406.88 1084.28,1406.88 1084.29,1406.88 1084.3,1406.88 1084.31,1406.88 1084.32,1406.88 1084.33,1406.88 1084.34,1406.88 1084.35,1406.88 1084.35,1406.88 1084.36,1406.88 1084.37,1406.88 1084.38,1406.88 1084.39,1406.88 1084.4,1406.88 1084.41,1406.88 1084.42,1406.88 1084.43,1406.88 1084.44,1406.88 1084.45,1406.88 1084.46,1406.88 1084.47,1406.88 1084.47,1406.88 1084.48,1406.88 1084.49,1406.88 1084.5,1406.88 1084.51,1406.88 1084.52,1406.88 1084.53,1406.88 1084.54,1406.88 1084.55,1406.88 1084.56,1406.88 1084.57,1406.88 1084.58,1406.88 1084.58,1406.88 1084.59,1406.88 1084.6,1406.88 1084.61,1406.88 1084.62,1406.88 1084.63,1406.88 1084.64,1406.88 1084.65,1406.88 1084.66,1406.88 1084.67,1406.88 1084.68,1406.88 1084.69,1406.88 1084.69,1406.88 1084.7,1406.88 1084.71,1406.88 1084.72,1406.88 1084.73,1406.88 1084.74,1406.88 1084.75,1406.88 1084.76,1406.88 1084.77,1406.88 1084.78,1406.88 1084.79,1406.88 1084.8,1406.88 1084.81,1406.88 1084.81,1406.88 1084.82,1406.88 1084.83,1406.88 1084.84,1406.88 1084.85,1406.88 1084.86,1406.88 1084.87,1406.88 1084.88,1406.88 1084.89,1406.88 1084.9,1406.88 1084.91,1406.88 1084.92,1406.88 1084.92,1406.88 1084.93,1406.88 1084.94,1406.88 1084.95,1406.88 1084.96,1406.88 1084.97,1406.88 1084.98,1406.88 1084.99,1406.88 1085,1406.88 1085.01,1406.88 1085.02,1406.88 1085.03,1406.88 1085.03,1406.88 1085.04,1406.88 1085.05,1406.88 1085.06,1406.88 1085.07,1406.88 1085.08,1406.88 1085.09,1406.88 1085.1,1406.88 1085.11,1406.88 1085.12,1406.88 1085.13,1406.88 1085.14,1406.88 1085.15,1406.88 1085.15,1406.88 1085.16,1406.88 1085.17,1406.88 1085.18,1406.88 1085.19,1406.88 1085.2,1406.88 1085.21,1406.88 1085.22,1406.88 1085.23,1406.88 1085.24,1406.88 1085.25,1406.88 1085.26,1406.88 1085.26,1406.88 1085.27,1406.88 1085.28,1406.88 1085.29,1406.88 1085.3,1406.88 1085.31,1406.88 1085.32,1406.88 1085.33,1406.88 1085.34,1406.88 1085.35,1406.88 1085.36,1406.88 1085.37,1406.88 1085.37,1406.88 1085.38,1406.88 1085.39,1406.88 1085.4,1406.88 1085.41,1406.88 1085.42,1406.88 1085.43,1406.88 1085.44,1406.88 1085.45,1406.88 1085.46,1406.88 1085.47,1406.88 1085.48,1406.88 1085.49,1406.88 1085.49,1406.88 1085.5,1406.88 1085.51,1406.88 1085.52,1406.88 1085.53,1406.88 1085.54,1406.88 1085.55,1406.88 1085.56,1406.88 1085.57,1406.88 1085.58,1406.88 1085.59,1406.88 1085.6,1406.88 1085.6,1406.88 1085.61,1406.88 1085.62,1406.88 1085.63,1406.88 1085.64,1406.88 1085.65,1406.88 1085.66,1406.88 1085.67,1406.88 1085.68,1406.88 1085.69,1406.88 1085.7,1406.88 1085.71,1406.88 1085.71,1406.88 1085.72,1406.88 1085.73,1406.88 1085.74,1406.88 1085.75,1406.88 1085.76,1406.88 1085.77,1406.88 1085.78,1406.88 1085.79,1406.88 1085.8,1406.88 1085.81,1406.88 1085.82,1406.88 1085.83,1406.88 1085.83,1406.88 1085.84,1406.88 1085.85,1406.88 1085.86,1406.88 1085.87,1406.88 1085.88,1406.88 1085.89,1406.88 1085.9,1406.88 1085.91,1406.88 1085.92,1406.88 1085.93,1406.88 1085.94,1406.88 1085.94,1406.88 1085.95,1406.88 1085.96,1406.88 1085.97,1406.88 1085.98,1406.88 1085.99,1406.88 1086,1406.88 1086.01,1406.88 1086.02,1406.88 1086.03,1406.88 1086.04,1406.88 1086.05,1406.88 1086.05,1406.88 1086.06,1406.88 1086.07,1406.88 1086.08,1406.88 1086.09,1406.88 1086.1,1406.88 1086.11,1406.88 1086.12,1406.88 1086.13,1406.88 1086.14,1406.88 1086.15,1406.88 1086.16,1406.88 1086.17,1406.88 1086.17,1406.88 1086.18,1406.88 1086.19,1406.88 1086.2,1406.88 1086.21,1406.88 1086.22,1406.88 1086.23,1406.88 1086.24,1406.88 1086.25,1406.88 1086.26,1406.88 1086.27,1406.88 1086.28,1406.88 1086.28,1406.88 1086.29,1406.88 1086.3,1406.88 1086.31,1406.88 1086.32,1406.88 1086.33,1406.88 1086.34,1406.88 1086.35,1406.88 1086.36,1406.88 1086.37,1406.88 1086.38,1406.88 1086.39,1406.88 1086.39,1406.88 1086.4,1406.88 1086.41,1406.88 1086.42,1406.88 1086.43,1406.88 1086.44,1406.88 1086.45,1406.88 1086.46,1406.88 1086.47,1406.88 1086.48,1406.88 1086.49,1406.88 1086.5,1406.88 1086.51,1406.88 1086.51,1406.88 1086.52,1406.88 1086.53,1406.88 1086.54,1406.88 1086.55,1406.88 1086.56,1406.88 1086.57,1406.88 1086.58,1406.88 1086.59,1406.88 1086.6,1406.88 1086.61,1406.88 1086.62,1406.88 1086.62,1406.88 1086.63,1406.88 1086.64,1406.88 1086.65,1406.88 1086.66,1406.88 1086.67,1406.88 1086.68,1406.88 1086.69,1406.88 1086.7,1406.88 1086.71,1406.88 1086.72,1406.88 1086.73,1406.88 1086.73,1406.88 1086.74,1406.88 1086.75,1406.88 1086.76,1406.88 1086.77,1406.88 1086.78,1406.88 1086.79,1406.88 1086.8,1406.88 1086.81,1406.88 1086.82,1406.88 1086.83,1406.88 1086.84,1406.88 1086.85,1406.88 1086.85,1406.88 1086.86,1406.88 1086.87,1406.88 1086.88,1406.88 1086.89,1406.88 1086.9,1406.88 1086.91,1406.88 1086.92,1406.88 1086.93,1406.88 1086.94,1406.88 1086.95,1406.88 1086.96,1406.88 1086.96,1406.88 1086.97,1406.88 1086.98,1406.88 1086.99,1406.88 1087,1406.88 1087.01,1406.88 1087.02,1406.88 1087.03,1406.88 1087.04,1406.88 1087.05,1406.88 1087.06,1406.88 1087.07,1406.88 1087.07,1406.88 1087.08,1406.88 1087.09,1406.88 1087.1,1406.88 1087.11,1406.88 1087.12,1406.88 1087.13,1406.88 1087.14,1406.88 1087.15,1406.88 1087.16,1406.88 1087.17,1406.88 1087.18,1406.88 1087.19,1406.88 1087.19,1406.88 1087.2,1406.88 1087.21,1406.88 1087.22,1406.88 1087.23,1406.88 1087.24,1406.88 1087.25,1406.88 1087.26,1406.88 1087.27,1406.88 1087.28,1406.88 1087.29,1406.88 1087.3,1406.88 1087.3,1406.88 1087.31,1406.88 1087.32,1406.88 1087.33,1406.88 1087.34,1406.88 1087.35,1406.88 1087.36,1406.88 1087.37,1406.88 1087.38,1406.88 1087.39,1406.88 1087.4,1406.88 1087.41,1406.88 1087.41,1406.88 1087.42,1406.88 1087.43,1406.88 1087.44,1406.88 1087.45,1406.88 1087.46,1406.88 1087.47,1406.88 1087.48,1406.88 1087.49,1406.88 1087.5,1406.88 1087.51,1406.88 1087.52,1406.88 1087.53,1406.88 1087.53,1406.88 1087.54,1406.88 1087.55,1406.88 1087.56,1406.88 1087.57,1406.88 1087.58,1406.88 1087.59,1406.88 1087.6,1406.88 1087.61,1406.88 1087.62,1406.88 1087.63,1406.88 1087.64,1406.88 1087.64,1406.88 1087.65,1406.88 1087.66,1406.88 1087.67,1406.88 1087.68,1406.88 1087.69,1406.88 1087.7,1406.88 1087.71,1406.88 1087.72,1406.88 1087.73,1406.88 1087.74,1406.88 1087.75,1406.88 1087.75,1406.88 1087.76,1406.88 1087.77,1406.88 1087.78,1406.88 1087.79,1406.88 1087.8,1406.88 1087.81,1406.88 1087.82,1406.88 1087.83,1406.88 1087.84,1406.88 1087.85,1406.88 1087.86,1406.88 1087.87,1406.88 1087.87,1406.88 1087.88,1406.88 1087.89,1406.88 1087.9,1406.88 1087.91,1406.88 1087.92,1406.88 1087.93,1406.88 1087.94,1406.88 1087.95,1406.88 1087.96,1406.88 1087.97,1406.88 1087.98,1406.88 1087.98,1406.88 1087.99,1406.88 1088,1406.88 1088.01,1406.88 1088.02,1406.88 1088.03,1406.88 1088.04,1406.88 1088.05,1406.88 1088.06,1406.88 1088.07,1406.88 1088.08,1406.88 1088.09,1406.88 1088.09,1406.88 1088.1,1406.88 1088.11,1406.88 1088.12,1406.88 1088.13,1406.88 1088.14,1406.88 1088.15,1406.88 1088.16,1406.88 1088.17,1406.88 1088.18,1406.88 1088.19,1406.88 1088.2,1406.88 1088.21,1406.88 1088.21,1406.88 1088.22,1406.88 1088.23,1406.88 1088.24,1406.88 1088.25,1406.88 1088.26,1406.88 1088.27,1406.88 1088.28,1406.88 1088.29,1406.88 1088.3,1406.88 1088.31,1406.88 1088.32,1406.88 1088.32,1406.88 1088.33,1406.88 1088.34,1406.88 1088.35,1406.88 1088.36,1406.88 1088.37,1406.88 1088.38,1406.88 1088.39,1406.88 1088.4,1406.88 1088.41,1406.88 1088.42,1406.88 1088.43,1406.88 1088.43,1406.88 1088.44,1406.88 1088.45,1406.88 1088.46,1406.88 1088.47,1406.88 1088.48,1406.88 1088.49,1406.88 1088.5,1406.88 1088.51,1406.88 1088.52,1406.88 1088.53,1406.88 1088.54,1406.88 1088.55,1406.88 1088.55,1406.88 1088.56,1406.88 1088.57,1406.88 1088.58,1406.88 1088.59,1406.88 1088.6,1406.88 1088.61,1406.88 1088.62,1406.88 1088.63,1406.88 1088.64,1406.88 1088.65,1406.88 1088.66,1406.88 1088.66,1406.88 1088.67,1406.88 1088.68,1406.88 1088.69,1406.88 1088.7,1406.88 1088.71,1406.88 1088.72,1406.88 1088.73,1406.88 1088.74,1406.88 1088.75,1406.88 1088.76,1406.88 1088.77,1406.88 1088.77,1406.88 1088.78,1406.88 1088.79,1406.88 1088.8,1406.88 1088.81,1406.88 1088.82,1406.88 1088.83,1406.88 1088.84,1406.88 1088.85,1406.88 1088.86,1406.88 1088.87,1406.88 1088.88,1406.88 1088.89,1406.88 1088.89,1406.88 1088.9,1406.88 1088.91,1406.88 1088.92,1406.88 1088.93,1406.88 1088.94,1406.88 1088.95,1406.88 1088.96,1406.88 1088.97,1406.88 1088.98,1406.88 1088.99,1406.88 1089,1406.88 1089,1406.88 1089.01,1406.88 1089.02,1406.88 1089.03,1406.88 1089.04,1406.88 1089.05,1406.88 1089.06,1406.88 1089.07,1406.88 1089.08,1406.88 1089.09,1406.88 1089.1,1406.88 1089.11,1406.88 1089.11,1406.88 1089.12,1406.88 1089.13,1406.88 1089.14,1406.88 1089.15,1406.88 1089.16,1406.88 1089.17,1406.88 1089.18,1406.88 1089.19,1406.88 1089.2,1406.88 1089.21,1406.88 1089.22,1406.88 1089.23,1406.88 1089.23,1406.88 1089.24,1406.88 1089.25,1406.88 1089.26,1406.88 1089.27,1406.88 1089.28,1406.88 1089.29,1406.88 1089.3,1406.88 1089.31,1406.88 1089.32,1406.88 1089.33,1406.88 1089.34,1406.88 1089.34,1406.88 1089.35,1406.88 1089.36,1406.88 1089.37,1406.88 1089.38,1406.88 1089.39,1406.88 1089.4,1406.88 1089.41,1406.88 1089.42,1406.88 1089.43,1406.88 1089.44,1406.88 1089.45,1406.88 1089.45,1406.88 1089.46,1406.88 1089.47,1406.88 1089.48,1406.88 1089.49,1406.88 1089.5,1406.88 1089.51,1406.88 1089.52,1406.88 1089.53,1406.88 1089.54,1406.88 1089.55,1406.88 1089.56,1406.88 1089.57,1406.88 1089.57,1406.88 1089.58,1406.88 1089.59,1406.88 1089.6,1406.88 1089.61,1406.88 1089.62,1406.88 1089.63,1406.88 1089.64,1406.88 1089.65,1406.88 1089.66,1406.88 1089.67,1406.88 1089.68,1406.88 1089.68,1406.88 1089.69,1406.88 1089.7,1406.88 1089.71,1406.88 1089.72,1406.88 1089.73,1406.88 1089.74,1406.88 1089.75,1406.88 1089.76,1406.88 1089.77,1406.88 1089.78,1406.88 1089.79,1406.88 1089.79,1406.88 1089.8,1406.88 1089.81,1406.88 1089.82,1406.88 1089.83,1406.88 1089.84,1406.88 1089.85,1406.88 1089.86,1406.88 1089.87,1406.88 1089.88,1406.88 1089.89,1406.88 1089.9,1406.88 1089.91,1406.88 1089.91,1406.88 1089.92,1406.88 1089.93,1406.88 1089.94,1406.88 1089.95,1406.88 1089.96,1406.88 1089.97,1406.88 1089.98,1406.88 1089.99,1406.88 1090,1406.88 1090.01,1406.88 1090.02,1406.88 1090.02,1406.88 1090.03,1406.88 1090.04,1406.88 1090.05,1406.88 1090.06,1406.88 1090.07,1406.88 1090.08,1406.88 1090.09,1406.88 1090.1,1406.88 1090.11,1406.88 1090.12,1406.88 1090.13,1406.88 1090.13,1406.88 1090.14,1406.88 1090.15,1406.88 1090.16,1406.88 1090.17,1406.88 1090.18,1406.88 1090.19,1406.88 1090.2,1406.88 1090.21,1406.88 1090.22,1406.88 1090.23,1406.88 1090.24,1406.88 1090.25,1406.88 1090.25,1406.88 1090.26,1406.88 1090.27,1406.88 1090.28,1406.88 1090.29,1406.88 1090.3,1406.88 1090.31,1406.88 1090.32,1406.88 1090.33,1406.88 1090.34,1406.88 1090.35,1406.88 1090.36,1406.88 1090.36,1406.88 1090.37,1406.88 1090.38,1406.88 1090.39,1406.88 1090.4,1406.88 1090.41,1406.88 1090.42,1406.88 1090.43,1406.88 1090.44,1406.88 1090.45,1406.88 1090.46,1406.88 1090.47,1406.88 1090.47,1406.88 1090.48,1406.88 1090.49,1406.88 1090.5,1406.88 1090.51,1406.88 1090.52,1406.88 1090.53,1406.88 1090.54,1406.88 1090.55,1406.88 1090.56,1406.88 1090.57,1406.88 1090.58,1406.88 1090.59,1406.88 1090.59,1406.88 1090.6,1406.88 1090.61,1406.88 1090.62,1406.88 1090.63,1406.88 1090.64,1406.88 1090.65,1406.88 1090.66,1406.88 1090.67,1406.88 1090.68,1406.88 1090.69,1406.88 1090.7,1406.88 1090.7,1406.88 1090.71,1406.88 1090.72,1406.88 1090.73,1406.88 1090.74,1406.88 1090.75,1406.88 1090.76,1406.88 1090.77,1406.88 1090.78,1406.88 1090.79,1406.88 1090.8,1406.88 1090.81,1406.88 1090.81,1406.88 1090.82,1406.88 1090.83,1406.88 1090.84,1406.88 1090.85,1406.88 1090.86,1406.88 1090.87,1406.88 1090.88,1406.88 1090.89,1406.88 1090.9,1406.88 1090.91,1406.88 1090.92,1406.88 1090.93,1406.88 1090.93,1406.88 1090.94,1406.88 1090.95,1406.88 1090.96,1406.88 1090.97,1406.88 1090.98,1406.88 1090.99,1406.88 1091,1406.88 1091.01,1406.88 1091.02,1406.88 1091.03,1406.88 1091.04,1406.88 1091.04,1406.88 1091.05,1406.88 1091.06,1406.88 1091.07,1406.88 1091.08,1406.88 1091.09,1406.88 1091.1,1406.88 1091.11,1406.88 1091.12,1406.88 1091.13,1406.88 1091.14,1406.88 1091.15,1406.88 1091.15,1406.88 1091.16,1406.88 1091.17,1406.88 1091.18,1406.88 1091.19,1406.88 1091.2,1406.88 1091.21,1406.88 1091.22,1406.88 1091.23,1406.88 1091.24,1406.88 1091.25,1406.88 1091.26,1406.88 1091.27,1406.88 1091.27,1406.88 1091.28,1406.88 1091.29,1406.88 1091.3,1406.88 1091.31,1406.88 1091.32,1406.88 1091.33,1406.88 1091.34,1406.88 1091.35,1406.88 1091.36,1406.88 1091.37,1406.88 1091.38,1406.88 1091.38,1406.88 1091.39,1406.88 1091.4,1406.88 1091.41,1406.88 1091.42,1406.88 1091.43,1406.88 1091.44,1406.88 1091.45,1406.88 1091.46,1406.88 1091.47,1406.88 1091.48,1406.88 1091.49,1406.88 1091.49,1406.88 1091.5,1406.88 1091.51,1406.88 1091.52,1406.88 1091.53,1406.88 1091.54,1406.88 1091.55,1406.88 1091.56,1406.88 1091.57,1406.88 1091.58,1406.88 1091.59,1406.88 1091.6,1406.88 1091.61,1406.88 1091.61,1406.88 1091.62,1406.88 1091.63,1406.88 1091.64,1406.88 1091.65,1406.88 1091.66,1406.88 1091.67,1406.88 1091.68,1406.88 1091.69,1406.88 1091.7,1406.88 1091.71,1406.88 1091.72,1406.88 1091.72,1406.88 1091.73,1406.88 1091.74,1406.88 1091.75,1406.88 1091.76,1406.88 1091.77,1406.88 1091.78,1406.88 1091.79,1406.88 1091.8,1406.88 1091.81,1406.88 1091.82,1406.88 1091.83,1406.88 1091.83,1406.88 1091.84,1406.88 1091.85,1406.88 1091.86,1406.88 1091.87,1406.88 1091.88,1406.88 1091.89,1406.88 1091.9,1406.88 1091.91,1406.88 1091.92,1406.88 1091.93,1406.88 1091.94,1406.88 1091.95,1406.88 1091.95,1406.88 1091.96,1406.88 1091.97,1406.88 1091.98,1406.88 1091.99,1406.88 1092,1406.88 1092.01,1406.88 1092.02,1406.88 1092.03,1406.88 1092.04,1406.88 1092.05,1406.88 1092.06,1406.88 1092.06,1406.88 1092.07,1406.88 1092.08,1406.88 1092.09,1406.88 1092.1,1406.88 1092.11,1406.88 1092.12,1406.88 1092.13,1406.88 1092.14,1406.88 1092.15,1406.88 1092.16,1406.88 1092.17,1406.88 1092.17,1406.88 1092.18,1406.88 1092.19,1406.88 1092.2,1406.88 1092.21,1406.88 1092.22,1406.88 1092.23,1406.88 1092.24,1406.88 1092.25,1406.88 1092.26,1406.88 1092.27,1406.88 1092.28,1406.88 1092.29,1406.88 1092.29,1406.88 1092.3,1406.88 1092.31,1406.88 1092.32,1406.88 1092.33,1406.88 1092.34,1406.88 1092.35,1406.88 1092.36,1406.88 1092.37,1406.88 1092.38,1406.88 1092.39,1406.88 1092.4,1406.88 1092.4,1406.88 1092.41,1406.88 1092.42,1406.88 1092.43,1406.88 1092.44,1406.88 1092.45,1406.88 1092.46,1406.88 1092.47,1406.88 1092.48,1406.88 1092.49,1406.88 1092.5,1406.88 1092.51,1406.88 1092.51,1406.88 1092.52,1406.88 1092.53,1406.88 1092.54,1406.88 1092.55,1406.88 1092.56,1406.88 1092.57,1406.88 1092.58,1406.88 1092.59,1406.88 1092.6,1406.88 1092.61,1406.88 1092.62,1406.88 1092.63,1406.88 1092.63,1406.88 1092.64,1406.88 1092.65,1406.88 1092.66,1406.88 1092.67,1406.88 1092.68,1406.88 1092.69,1406.88 1092.7,1406.88 1092.71,1406.88 1092.72,1406.88 1092.73,1406.88 1092.74,1406.88 1092.74,1406.88 1092.75,1406.88 1092.76,1406.88 1092.77,1406.88 1092.78,1406.88 1092.79,1406.88 1092.8,1406.88 1092.81,1406.88 1092.82,1406.88 1092.83,1406.88 1092.84,1406.88 1092.85,1406.88 1092.85,1406.88 1092.86,1406.88 1092.87,1406.88 1092.88,1406.88 1092.89,1406.88 1092.9,1406.88 1092.91,1406.88 1092.92,1406.88 1092.93,1406.88 1092.94,1406.88 1092.95,1406.88 1092.96,1406.88 1092.97,1406.88 1092.97,1406.88 1092.98,1406.88 1092.99,1406.88 1093,1406.88 1093.01,1406.88 1093.02,1406.88 1093.03,1406.88 1093.04,1406.88 1093.05,1406.88 1093.06,1406.88 1093.07,1406.88 1093.08,1406.88 1093.08,1406.88 1093.09,1406.88 1093.1,1406.88 1093.11,1406.88 1093.12,1406.88 1093.13,1406.88 1093.14,1406.88 1093.15,1406.88 1093.16,1406.88 1093.17,1406.88 1093.18,1406.88 1093.19,1406.88 1093.19,1406.88 1093.2,1406.88 1093.21,1406.88 1093.22,1406.88 1093.23,1406.88 1093.24,1406.88 1093.25,1406.88 1093.26,1406.88 1093.27,1406.88 1093.28,1406.88 1093.29,1406.88 1093.3,1406.88 1093.31,1406.88 1093.31,1406.88 1093.32,1406.88 1093.33,1406.88 1093.34,1406.88 1093.35,1406.88 1093.36,1406.88 1093.37,1406.88 1093.38,1406.88 1093.39,1406.88 1093.4,1406.88 1093.41,1406.88 1093.42,1406.88 1093.42,1406.88 1093.43,1406.88 1093.44,1406.88 1093.45,1406.88 1093.46,1406.88 1093.47,1406.88 1093.48,1406.88 1093.49,1406.88 1093.5,1406.88 1093.51,1406.88 1093.52,1406.88 1093.53,1406.88 1093.53,1406.88 1093.54,1406.88 1093.55,1406.88 1093.56,1406.88 1093.57,1406.88 1093.58,1406.88 1093.59,1406.88 1093.6,1406.88 1093.61,1406.88 1093.62,1406.88 1093.63,1406.88 1093.64,1406.88 1093.65,1406.88 1093.65,1406.88 1093.66,1406.88 1093.67,1406.88 1093.68,1406.88 1093.69,1406.88 1093.7,1406.88 1093.71,1406.88 1093.72,1406.88 1093.73,1406.88 1093.74,1406.88 1093.75,1406.88 1093.76,1406.88 1093.76,1406.88 1093.77,1406.88 1093.78,1406.88 1093.79,1406.88 1093.8,1406.88 1093.81,1406.88 1093.82,1406.88 1093.83,1406.88 1093.84,1406.88 1093.85,1406.88 1093.86,1406.88 1093.87,1406.88 1093.87,1406.88 1093.88,1406.88 1093.89,1406.88 1093.9,1406.88 1093.91,1406.88 1093.92,1406.88 1093.93,1406.88 1093.94,1406.88 1093.95,1406.88 1093.96,1406.88 1093.97,1406.88 1093.98,1406.88 1093.99,1406.88 1093.99,1406.88 1094,1406.88 1094.01,1406.88 1094.02,1406.88 1094.03,1406.88 1094.04,1406.88 1094.05,1406.88 1094.06,1406.88 1094.07,1406.88 1094.08,1406.88 1094.09,1406.88 1094.1,1406.88 1094.1,1406.88 1094.11,1406.88 1094.12,1406.88 1094.13,1406.88 1094.14,1406.88 1094.15,1406.88 1094.16,1406.88 1094.17,1406.88 1094.18,1406.88 1094.19,1406.88 1094.2,1406.88 1094.21,1406.88 1094.21,1406.88 1094.22,1406.88 1094.23,1406.88 1094.24,1406.88 1094.25,1406.88 1094.26,1406.88 1094.27,1406.88 1094.28,1406.88 1094.29,1406.88 1094.3,1406.88 1094.31,1406.88 1094.32,1406.88 1094.33,1406.88 1094.33,1406.88 1094.34,1406.88 1094.35,1406.88 1094.36,1406.88 1094.37,1406.88 1094.38,1406.88 1094.39,1406.88 1094.4,1406.88 1094.41,1406.88 1094.42,1406.88 1094.43,1406.88 1094.44,1406.88 1094.44,1406.88 1094.45,1406.88 1094.46,1406.88 1094.47,1406.88 1094.48,1406.88 1094.49,1406.88 1094.5,1406.88 1094.51,1406.88 1094.52,1406.88 1094.53,1406.88 1094.54,1406.88 1094.55,1406.88 1094.55,1406.88 1094.56,1406.88 1094.57,1406.88 1094.58,1406.88 1094.59,1406.88 1094.6,1406.88 1094.61,1406.88 1094.62,1406.88 1094.63,1406.88 1094.64,1406.88 1094.65,1406.88 1094.66,1406.88 1094.67,1406.88 1094.67,1406.88 1094.68,1406.88 1094.69,1406.88 1094.7,1406.88 1094.71,1406.88 1094.72,1406.88 1094.73,1406.88 1094.74,1406.88 1094.75,1406.88 1094.76,1406.88 1094.77,1406.88 1094.78,1406.88 1094.78,1406.88 1094.79,1406.88 1094.8,1406.88 1094.81,1406.88 1094.82,1406.88 1094.83,1406.88 1094.84,1406.88 1094.85,1406.88 1094.86,1406.88 1094.87,1406.88 1094.88,1406.88 1094.89,1406.88 1094.89,1406.88 1094.9,1406.88 1094.91,1406.88 1094.92,1406.88 1094.93,1406.88 1094.94,1406.88 1094.95,1406.88 1094.96,1406.88 1094.97,1406.88 1094.98,1406.88 1094.99,1406.88 1095,1406.88 1095.01,1406.88 1095.01,1406.88 1095.02,1406.88 1095.03,1406.88 1095.04,1406.88 1095.05,1406.88 1095.06,1406.88 1095.07,1406.88 1095.08,1406.88 1095.09,1406.88 1095.1,1406.88 1095.11,1406.88 1095.12,1406.88 1095.12,1406.88 1095.13,1406.88 1095.14,1406.88 1095.15,1406.88 1095.16,1406.88 1095.17,1406.88 1095.18,1406.88 1095.19,1406.88 1095.2,1406.88 1095.21,1406.88 1095.22,1406.88 1095.23,1406.88 1095.23,1406.88 1095.24,1406.88 1095.25,1406.88 1095.26,1406.88 1095.27,1406.88 1095.28,1406.88 1095.29,1406.88 1095.3,1406.88 1095.31,1406.88 1095.32,1406.88 1095.33,1406.88 1095.34,1406.88 1095.35,1406.88 1095.35,1406.88 1095.36,1406.88 1095.37,1406.88 1095.38,1406.88 1095.39,1406.88 1095.4,1406.88 1095.41,1406.88 1095.42,1406.88 1095.43,1406.88 1095.44,1406.88 1095.45,1406.88 1095.46,1406.88 1095.46,1406.88 1095.47,1406.88 1095.48,1406.88 1095.49,1406.88 1095.5,1406.88 1095.51,1406.88 1095.52,1406.88 1095.53,1406.88 1095.54,1406.88 1095.55,1406.88 1095.56,1406.88 1095.57,1406.88 1095.57,1406.88 1095.58,1406.88 1095.59,1406.88 1095.6,1406.88 1095.61,1406.88 1095.62,1406.88 1095.63,1406.88 1095.64,1406.88 1095.65,1406.88 1095.66,1406.88 1095.67,1406.88 1095.68,1406.88 1095.69,1406.88 1095.69,1406.88 1095.7,1406.88 1095.71,1406.88 1095.72,1406.88 1095.73,1406.88 1095.74,1406.88 1095.75,1406.88 1095.76,1406.88 1095.77,1406.88 1095.78,1406.88 1095.79,1406.88 1095.8,1406.88 1095.8,1406.88 1095.81,1406.88 1095.82,1406.88 1095.83,1406.88 1095.84,1406.88 1095.85,1406.88 1095.86,1406.88 1095.87,1406.88 1095.88,1406.88 1095.89,1406.88 1095.9,1406.88 1095.91,1406.88 1095.91,1406.88 1095.92,1406.88 1095.93,1406.88 1095.94,1406.88 1095.95,1406.88 1095.96,1406.88 1095.97,1406.88 1095.98,1406.88 1095.99,1406.88 1096,1406.88 1096.01,1406.88 1096.02,1406.88 1096.03,1406.88 1096.03,1406.88 1096.04,1406.88 1096.05,1406.88 1096.06,1406.88 1096.07,1406.88 1096.08,1406.88 1096.09,1406.88 1096.1,1406.88 1096.11,1406.88 1096.12,1406.88 1096.13,1406.88 1096.14,1406.88 1096.14,1406.88 1096.15,1406.88 1096.16,1406.88 1096.17,1406.88 1096.18,1406.88 1096.19,1406.88 1096.2,1406.88 1096.21,1406.88 1096.22,1406.88 1096.23,1406.88 1096.24,1406.88 1096.25,1406.88 1096.25,1406.88 1096.26,1406.88 1096.27,1406.88 1096.28,1406.88 1096.29,1406.88 1096.3,1406.88 1096.31,1406.88 1096.32,1406.88 1096.33,1406.88 1096.34,1406.88 1096.35,1406.88 1096.36,1406.88 1096.37,1406.88 1096.37,1406.88 1096.38,1406.88 1096.39,1406.88 1096.4,1406.88 1096.41,1406.88 1096.42,1406.88 1096.43,1406.88 1096.44,1406.88 1096.45,1406.88 1096.46,1406.88 1096.47,1406.88 1096.48,1406.88 1096.48,1406.88 1096.49,1406.88 1096.5,1406.88 1096.51,1406.88 1096.52,1406.88 1096.53,1406.88 1096.54,1406.88 1096.55,1406.88 1096.56,1406.88 1096.57,1406.88 1096.58,1406.88 1096.59,1406.88 1096.59,1406.88 1096.6,1406.88 1096.61,1406.88 1096.62,1406.88 1096.63,1406.88 1096.64,1406.88 1096.65,1406.88 1096.66,1406.88 1096.67,1406.88 1096.68,1406.88 1096.69,1406.88 1096.7,1406.88 1096.71,1406.88 1096.71,1406.88 1096.72,1406.88 1096.73,1406.88 1096.74,1406.88 1096.75,1406.88 1096.76,1406.88 1096.77,1406.88 1096.78,1406.88 1096.79,1406.88 1096.8,1406.88 1096.81,1406.88 1096.82,1406.88 1096.82,1406.88 1096.83,1406.88 1096.84,1406.88 1096.85,1406.88 1096.86,1406.88 1096.87,1406.88 1096.88,1406.88 1096.89,1406.88 1096.9,1406.88 1096.91,1406.88 1096.92,1406.88 1096.93,1406.88 1096.94,1406.88 1096.94,1406.88 1096.95,1406.88 1096.96,1406.88 1096.97,1406.88 1096.98,1406.88 1096.99,1406.88 1097,1406.88 1097.01,1406.88 1097.02,1406.88 1097.03,1406.88 1097.04,1406.88 1097.05,1406.88 1097.05,1406.88 1097.06,1406.88 1097.07,1406.88 1097.08,1406.88 1097.09,1406.88 1097.1,1406.88 1097.11,1406.88 1097.12,1406.88 1097.13,1406.88 1097.14,1406.88 1097.15,1406.88 1097.16,1406.88 1097.16,1406.88 1097.17,1406.88 1097.18,1406.88 1097.19,1406.88 1097.2,1406.88 1097.21,1406.88 1097.22,1406.88 1097.23,1406.88 1097.24,1406.88 1097.25,1406.88 1097.26,1406.88 1097.27,1406.88 1097.28,1406.88 1097.28,1406.88 1097.29,1406.88 1097.3,1406.88 1097.31,1406.88 1097.32,1406.88 1097.33,1406.88 1097.34,1406.88 1097.35,1406.88 1097.36,1406.88 1097.37,1406.88 1097.38,1406.88 1097.39,1406.88 1097.39,1406.88 1097.4,1406.88 1097.41,1406.88 1097.42,1406.88 1097.43,1406.88 1097.44,1406.88 1097.45,1406.88 1097.46,1406.88 1097.47,1406.88 1097.48,1406.88 1097.49,1406.88 1097.5,1406.88 1097.5,1406.88 1097.51,1406.88 1097.52,1406.88 1097.53,1406.88 1097.54,1406.88 1097.55,1406.88 1097.56,1406.88 1097.57,1406.88 1097.58,1406.88 1097.59,1406.88 1097.6,1406.88 1097.61,1406.88 1097.62,1406.88 1097.62,1406.88 1097.63,1406.88 1097.64,1406.88 1097.65,1406.88 1097.66,1406.88 1097.67,1406.88 1097.68,1406.88 1097.69,1406.88 1097.7,1406.88 1097.71,1406.88 1097.72,1406.88 1097.73,1406.88 1097.73,1406.88 1097.74,1406.88 1097.75,1406.88 1097.76,1406.88 1097.77,1406.88 1097.78,1406.88 1097.79,1406.88 1097.8,1406.88 1097.81,1406.88 1097.82,1406.88 1097.83,1406.88 1097.84,1406.88 1097.84,1406.88 1097.85,1406.88 1097.86,1406.88 1097.87,1406.88 1097.88,1406.88 1097.89,1406.88 1097.9,1406.88 1097.91,1406.88 1097.92,1406.88 1097.93,1406.88 1097.94,1406.88 1097.95,1406.88 1097.96,1406.88 1097.96,1406.88 1097.97,1406.88 1097.98,1406.88 1097.99,1406.88 1098,1406.88 1098.01,1406.88 1098.02,1406.88 1098.03,1406.88 1098.04,1406.88 1098.05,1406.88 1098.06,1406.88 1098.07,1406.88 1098.07,1406.88 1098.08,1406.88 1098.09,1406.88 1098.1,1406.88 1098.11,1406.88 1098.12,1406.88 1098.13,1406.88 1098.14,1406.88 1098.15,1406.88 1098.16,1406.88 1098.17,1406.88 1098.18,1406.88 1098.18,1406.88 1098.19,1406.88 1098.2,1406.88 1098.21,1406.88 1098.22,1406.88 1098.23,1406.88 1098.24,1406.88 1098.25,1406.88 1098.26,1406.88 1098.27,1406.88 1098.28,1406.88 1098.29,1406.88 1098.3,1406.88 1098.3,1406.88 1098.31,1406.88 1098.32,1406.88 1098.33,1406.88 1098.34,1406.88 1098.35,1406.88 1098.36,1406.88 1098.37,1406.88 1098.38,1406.88 1098.39,1406.88 1098.4,1406.88 1098.41,1406.88 1098.41,1406.88 1098.42,1406.88 1098.43,1406.88 1098.44,1406.88 1098.45,1406.88 1098.46,1406.88 1098.47,1406.88 1098.48,1406.88 1098.49,1406.88 1098.5,1406.88 1098.51,1406.88 1098.52,1406.88 1098.52,1406.88 1098.53,1406.88 1098.54,1406.88 1098.55,1406.88 1098.56,1406.88 1098.57,1406.88 1098.58,1406.88 1098.59,1406.88 1098.6,1406.88 1098.61,1406.88 1098.62,1406.88 1098.63,1406.88 1098.64,1406.88 1098.64,1406.88 1098.65,1406.88 1098.66,1406.88 1098.67,1406.88 1098.68,1406.88 1098.69,1406.88 1098.7,1406.88 1098.71,1406.88 1098.72,1406.88 1098.73,1406.88 1098.74,1406.88 1098.75,1406.88 1098.75,1406.88 1098.76,1406.88 1098.77,1406.88 1098.78,1406.88 1098.79,1406.88 1098.8,1406.88 1098.81,1406.88 1098.82,1406.88 1098.83,1406.88 1098.84,1406.88 1098.85,1406.88 1098.86,1406.88 1098.86,1406.88 1098.87,1406.88 1098.88,1406.88 1098.89,1406.88 1098.9,1406.88 1098.91,1406.88 1098.92,1406.88 1098.93,1406.88 1098.94,1406.88 1098.95,1406.88 1098.96,1406.88 1098.97,1406.88 1098.98,1406.88 1098.98,1406.88 1098.99,1406.88 1099,1406.88 1099.01,1406.88 1099.02,1406.88 1099.03,1406.88 1099.04,1406.88 1099.05,1406.88 1099.06,1406.88 1099.07,1406.88 1099.08,1406.88 1099.09,1406.88 1099.09,1406.88 1099.1,1406.88 1099.11,1406.88 1099.12,1406.88 1099.13,1406.88 1099.14,1406.88 1099.15,1406.88 1099.16,1406.88 1099.17,1406.88 1099.18,1406.88 1099.19,1406.88 1099.2,1406.88 1099.2,1406.88 1099.21,1406.88 1099.22,1406.88 1099.23,1406.88 1099.24,1406.88 1099.25,1406.88 1099.26,1406.88 1099.27,1406.88 1099.28,1406.88 1099.29,1406.88 1099.3,1406.88 1099.31,1406.88 1099.32,1406.88 1099.32,1406.88 1099.33,1406.88 1099.34,1406.88 1099.35,1406.88 1099.36,1406.88 1099.37,1406.88 1099.38,1406.88 1099.39,1406.88 1099.4,1406.88 1099.41,1406.88 1099.42,1406.88 1099.43,1406.88 1099.43,1406.88 1099.44,1406.88 1099.45,1406.88 1099.46,1406.88 1099.47,1406.88 1099.48,1406.88 1099.49,1406.88 1099.5,1406.88 1099.51,1406.88 1099.52,1406.88 1099.53,1406.88 1099.54,1406.88 1099.54,1406.88 1099.55,1406.88 1099.56,1406.88 1099.57,1406.88 1099.58,1406.88 1099.59,1406.88 1099.6,1406.88 1099.61,1406.88 1099.62,1406.88 1099.63,1406.88 1099.64,1406.88 1099.65,1406.88 1099.66,1406.88 1099.66,1406.88 1099.67,1406.88 1099.68,1406.88 1099.69,1406.88 1099.7,1406.88 1099.71,1406.88 1099.72,1406.88 1099.73,1406.88 1099.74,1406.88 1099.75,1406.88 1099.76,1406.88 1099.77,1406.88 1099.77,1406.88 1099.78,1406.88 1099.79,1406.88 1099.8,1406.88 1099.81,1406.88 1099.82,1406.88 1099.83,1406.88 1099.84,1406.88 1099.85,1406.88 1099.86,1406.88 1099.87,1406.88 1099.88,1406.88 1099.88,1406.88 1099.89,1406.88 1099.9,1406.88 1099.91,1406.88 1099.92,1406.88 1099.93,1406.88 1099.94,1406.88 1099.95,1406.88 1099.96,1406.88 1099.97,1406.88 1099.98,1406.88 1099.99,1406.88 1100,1406.88 1100,1406.88 1100.01,1406.88 1100.02,1406.88 1100.03,1406.88 1100.04,1406.88 1100.05,1406.88 1100.06,1406.88 1100.07,1406.88 1100.08,1406.88 1100.09,1406.88 1100.1,1406.88 1100.11,1406.88 1100.11,1406.88 1100.12,1406.88 1100.13,1406.88 1100.14,1406.88 1100.15,1406.88 1100.16,1406.88 1100.17,1406.88 1100.18,1406.88 1100.19,1406.88 1100.2,1406.88 1100.21,1406.88 1100.22,1406.88 1100.22,1406.88 1100.23,1406.88 1100.24,1406.88 1100.25,1406.88 1100.26,1406.88 1100.27,1406.88 1100.28,1406.88 1100.29,1406.88 1100.3,1406.88 1100.31,1406.88 1100.32,1406.88 1100.33,1406.88 1100.34,1406.88 1100.34,1406.88 1100.35,1406.88 1100.36,1406.88 1100.37,1406.88 1100.38,1406.88 1100.39,1406.88 1100.4,1406.88 1100.41,1406.88 1100.42,1406.88 1100.43,1406.88 1100.44,1406.88 1100.45,1406.88 1100.45,1406.88 1100.46,1406.88 1100.47,1406.88 1100.48,1406.88 1100.49,1406.88 1100.5,1406.88 1100.51,1406.88 1100.52,1406.88 1100.53,1406.88 1100.54,1406.88 1100.55,1406.88 1100.56,1406.88 1100.56,1406.88 1100.57,1406.88 1100.58,1406.88 1100.59,1406.88 1100.6,1406.88 1100.61,1406.88 1100.62,1406.88 1100.63,1406.88 1100.64,1406.88 1100.65,1406.88 1100.66,1406.88 1100.67,1406.88 1100.68,1406.88 1100.68,1406.88 1100.69,1406.88 1100.7,1406.88 1100.71,1406.88 1100.72,1406.88 1100.73,1406.88 1100.74,1406.88 1100.75,1406.88 1100.76,1406.88 1100.77,1406.88 1100.78,1406.88 1100.79,1406.88 1100.79,1406.88 1100.8,1406.88 1100.81,1406.88 1100.82,1406.88 1100.83,1406.88 1100.84,1406.88 1100.85,1406.88 1100.86,1406.88 1100.87,1406.88 1100.88,1406.88 1100.89,1406.88 1100.9,1406.88 1100.9,1406.88 1100.91,1406.88 1100.92,1406.88 1100.93,1406.88 1100.94,1406.88 1100.95,1406.88 1100.96,1406.88 1100.97,1406.88 1100.98,1406.88 1100.99,1406.88 1101,1406.88 1101.01,1406.88 1101.02,1406.88 1101.02,1406.88 1101.03,1406.88 1101.04,1406.88 1101.05,1406.88 1101.06,1406.88 1101.07,1406.88 1101.08,1406.88 1101.09,1406.88 1101.1,1406.88 1101.11,1406.88 1101.12,1406.88 1101.13,1406.88 1101.13,1406.88 1101.14,1406.88 1101.15,1406.88 1101.16,1406.88 1101.17,1406.88 1101.18,1406.88 1101.19,1406.88 1101.2,1406.88 1101.21,1406.88 1101.22,1406.88 1101.23,1406.88 1101.24,1406.88 1101.24,1406.88 1101.25,1406.88 1101.26,1406.88 1101.27,1406.88 1101.28,1406.88 1101.29,1406.88 1101.3,1406.88 1101.31,1406.88 1101.32,1406.88 1101.33,1406.88 1101.34,1406.88 1101.35,1406.88 1101.36,1406.88 1101.36,1406.88 1101.37,1406.88 1101.38,1406.88 1101.39,1406.88 1101.4,1406.88 1101.41,1406.88 1101.42,1406.88 1101.43,1406.88 1101.44,1406.88 1101.45,1406.88 1101.46,1406.88 1101.47,1406.88 1101.47,1406.88 1101.48,1406.88 1101.49,1406.88 1101.5,1406.88 1101.51,1406.88 1101.52,1406.88 1101.53,1406.88 1101.54,1406.88 1101.55,1406.88 1101.56,1406.88 1101.57,1406.88 1101.58,1406.88 1101.58,1406.88 1101.59,1406.88 1101.6,1406.88 1101.61,1406.88 1101.62,1406.88 1101.63,1406.88 1101.64,1406.88 1101.65,1406.88 1101.66,1406.88 1101.67,1406.88 1101.68,1406.88 1101.69,1406.88 1101.7,1406.88 1101.7,1406.88 1101.71,1406.88 1101.72,1406.88 1101.73,1406.88 1101.74,1406.88 1101.75,1406.88 1101.76,1406.88 1101.77,1406.88 1101.78,1406.88 1101.79,1406.88 1101.8,1406.88 1101.81,1406.88 1101.81,1406.88 1101.82,1406.88 1101.83,1406.88 1101.84,1406.88 1101.85,1406.88 1101.86,1406.88 1101.87,1406.88 1101.88,1406.88 1101.89,1406.88 1101.9,1406.88 1101.91,1406.88 1101.92,1406.88 1101.92,1406.88 1101.93,1406.88 1101.94,1406.88 1101.95,1406.88 1101.96,1406.88 1101.97,1406.88 1101.98,1406.88 1101.99,1406.88 1102,1406.88 1102.01,1406.88 1102.02,1406.88 1102.03,1406.88 1102.04,1406.88 1102.04,1406.88 1102.05,1406.88 1102.06,1406.88 1102.07,1406.88 1102.08,1406.88 1102.09,1406.88 1102.1,1406.88 1102.11,1406.88 1102.12,1406.88 1102.13,1406.88 1102.14,1406.88 1102.15,1406.88 1102.15,1406.88 1102.16,1406.88 1102.17,1406.88 1102.18,1406.88 1102.19,1406.88 1102.2,1406.88 1102.21,1406.88 1102.22,1406.88 1102.23,1406.88 1102.24,1406.88 1102.25,1406.88 1102.26,1406.88 1102.26,1406.88 1102.27,1406.88 1102.28,1406.88 1102.29,1406.88 1102.3,1406.88 1102.31,1406.88 1102.32,1406.88 1102.33,1406.88 1102.34,1406.88 1102.35,1406.88 1102.36,1406.88 1102.37,1406.88 1102.38,1406.88 1102.38,1406.88 1102.39,1406.88 1102.4,1406.88 1102.41,1406.88 1102.42,1406.88 1102.43,1406.88 1102.44,1406.88 1102.45,1406.88 1102.46,1406.88 1102.47,1406.88 1102.48,1406.88 1102.49,1406.88 1102.49,1406.88 1102.5,1406.88 1102.51,1406.88 1102.52,1406.88 1102.53,1406.88 1102.54,1406.88 1102.55,1406.88 1102.56,1406.88 1102.57,1406.88 1102.58,1406.88 1102.59,1406.88 1102.6,1406.88 1102.6,1406.88 1102.61,1406.88 1102.62,1406.88 1102.63,1406.88 1102.64,1406.88 1102.65,1406.88 1102.66,1406.88 1102.67,1406.88 1102.68,1406.88 1102.69,1406.88 1102.7,1406.88 1102.71,1406.88 1102.72,1406.88 1102.72,1406.88 1102.73,1406.88 1102.74,1406.88 1102.75,1406.88 1102.76,1406.88 1102.77,1406.88 1102.78,1406.88 1102.79,1406.88 1102.8,1406.88 1102.81,1406.88 1102.82,1406.88 1102.83,1406.88 1102.83,1406.88 1102.84,1406.88 1102.85,1406.88 1102.86,1406.88 1102.87,1406.88 1102.88,1406.88 1102.89,1406.88 1102.9,1406.88 1102.91,1406.88 1102.92,1406.88 1102.93,1406.88 1102.94,1406.88 1102.94,1406.88 1102.95,1406.88 1102.96,1406.88 1102.97,1406.88 1102.98,1406.88 1102.99,1406.88 1103,1406.88 1103.01,1406.88 1103.02,1406.88 1103.03,1406.88 1103.04,1406.88 1103.05,1406.88 1103.06,1406.88 1103.06,1406.88 1103.07,1406.88 1103.08,1406.88 1103.09,1406.88 1103.1,1406.88 1103.11,1406.88 1103.12,1406.88 1103.13,1406.88 1103.14,1406.88 1103.15,1406.88 1103.16,1406.88 1103.17,1406.88 1103.17,1406.88 1103.18,1406.88 1103.19,1406.88 1103.2,1406.88 1103.21,1406.88 1103.22,1406.88 1103.23,1406.88 1103.24,1406.88 1103.25,1406.88 1103.26,1406.88 1103.27,1406.88 1103.28,1406.88 1103.28,1406.88 1103.29,1406.88 1103.3,1406.88 1103.31,1406.88 1103.32,1406.88 1103.33,1406.88 1103.34,1406.88 1103.35,1406.88 1103.36,1406.88 1103.37,1406.88 1103.38,1406.88 1103.39,1406.88 1103.4,1406.88 1103.4,1406.88 1103.41,1406.88 1103.42,1406.88 1103.43,1406.88 1103.44,1406.88 1103.45,1406.88 1103.46,1406.88 1103.47,1406.88 1103.48,1406.88 1103.49,1406.88 1103.5,1406.88 1103.51,1406.88 1103.51,1406.88 1103.52,1406.88 1103.53,1406.88 1103.54,1406.88 1103.55,1406.88 1103.56,1406.88 1103.57,1406.88 1103.58,1406.88 1103.59,1406.88 1103.6,1406.88 1103.61,1406.88 1103.62,1406.88 1103.62,1406.88 1103.63,1406.88 1103.64,1406.88 1103.65,1406.88 1103.66,1406.88 1103.67,1406.88 1103.68,1406.88 1103.69,1406.88 1103.7,1406.88 1103.71,1406.88 1103.72,1406.88 1103.73,1406.88 1103.74,1406.88 1103.74,1406.88 1103.75,1406.88 1103.76,1406.88 1103.77,1406.88 1103.78,1406.88 1103.79,1406.88 1103.8,1406.88 1103.81,1406.88 1103.82,1406.88 1103.83,1406.88 1103.84,1406.88 1103.85,1406.88 1103.85,1406.88 1103.86,1406.88 1103.87,1406.88 1103.88,1406.88 1103.89,1406.88 1103.9,1406.88 1103.91,1406.88 1103.92,1406.88 1103.93,1406.88 1103.94,1406.88 1103.95,1406.88 1103.96,1406.88 1103.96,1406.88 1103.97,1406.88 1103.98,1406.88 1103.99,1406.88 1104,1406.88 1104.01,1406.88 1104.02,1406.88 1104.03,1406.88 1104.04,1406.88 1104.05,1406.88 1104.06,1406.88 1104.07,1406.88 1104.08,1406.88 1104.08,1406.88 1104.09,1406.88 1104.1,1406.88 1104.11,1406.88 1104.12,1406.88 1104.13,1406.88 1104.14,1406.88 1104.15,1406.88 1104.16,1406.88 1104.17,1406.88 1104.18,1406.88 1104.19,1406.88 1104.19,1406.88 1104.2,1406.88 1104.21,1406.88 1104.22,1406.88 1104.23,1406.88 1104.24,1406.88 1104.25,1406.88 1104.26,1406.88 1104.27,1406.88 1104.28,1406.88 1104.29,1406.88 1104.3,1406.88 1104.3,1406.88 1104.31,1406.88 1104.32,1406.88 1104.33,1406.88 1104.34,1406.88 1104.35,1406.88 1104.36,1406.88 1104.37,1406.88 1104.38,1406.88 1104.39,1406.88 1104.4,1406.88 1104.41,1406.88 1104.42,1406.88 1104.42,1406.88 1104.43,1406.88 1104.44,1406.88 1104.45,1406.88 1104.46,1406.88 1104.47,1406.88 1104.48,1406.88 1104.49,1406.88 1104.5,1406.88 1104.51,1406.88 1104.52,1406.88 1104.53,1406.88 1104.53,1406.88 1104.54,1406.88 1104.55,1406.88 1104.56,1406.88 1104.57,1406.88 1104.58,1406.88 1104.59,1406.88 1104.6,1406.88 1104.61,1406.88 1104.62,1406.88 1104.63,1406.88 1104.64,1406.88 1104.64,1406.88 1104.65,1406.88 1104.66,1406.88 1104.67,1406.88 1104.68,1406.88 1104.69,1406.88 1104.7,1406.88 1104.71,1406.88 1104.72,1406.88 1104.73,1406.88 1104.74,1406.88 1104.75,1406.88 1104.76,1406.88 1104.76,1406.88 1104.77,1406.88 1104.78,1406.88 1104.79,1406.88 1104.8,1406.88 1104.81,1406.88 1104.82,1406.88 1104.83,1406.88 1104.84,1406.88 1104.85,1406.88 1104.86,1406.88 1104.87,1406.88 1104.87,1406.88 1104.88,1406.88 1104.89,1406.88 1104.9,1406.88 1104.91,1406.88 1104.92,1406.88 1104.93,1406.88 1104.94,1406.88 1104.95,1406.88 1104.96,1406.88 1104.97,1406.88 1104.98,1406.88 1104.98,1406.88 1104.99,1406.88 1105,1406.88 1105.01,1406.88 1105.02,1406.88 1105.03,1406.88 1105.04,1406.88 1105.05,1406.88 1105.06,1406.88 1105.07,1406.88 1105.08,1406.88 1105.09,1406.88 1105.1,1406.88 1105.1,1406.88 1105.11,1406.88 1105.12,1406.88 1105.13,1406.88 1105.14,1406.88 1105.15,1406.88 1105.16,1406.88 1105.17,1406.88 1105.18,1406.88 1105.19,1406.88 1105.2,1406.88 1105.21,1406.88 1105.21,1406.88 1105.22,1406.88 1105.23,1406.88 1105.24,1406.88 1105.25,1406.88 1105.26,1406.88 1105.27,1406.88 1105.28,1406.88 1105.29,1406.88 1105.3,1406.88 1105.31,1406.88 1105.32,1406.88 1105.32,1406.88 1105.33,1406.88 1105.34,1406.88 1105.35,1406.88 1105.36,1406.88 1105.37,1406.88 1105.38,1406.88 1105.39,1406.88 1105.4,1406.88 1105.41,1406.88 1105.42,1406.88 1105.43,1406.88 1105.44,1406.88 1105.44,1406.88 1105.45,1406.88 1105.46,1406.88 1105.47,1406.88 1105.48,1406.88 1105.49,1406.88 1105.5,1406.88 1105.51,1406.88 1105.52,1406.88 1105.53,1406.88 1105.54,1406.88 1105.55,1406.88 1105.55,1406.88 1105.56,1406.88 1105.57,1406.88 1105.58,1406.88 1105.59,1406.88 1105.6,1406.88 1105.61,1406.88 1105.62,1406.88 1105.63,1406.88 1105.64,1406.88 1105.65,1406.88 1105.66,1406.88 1105.66,1406.88 1105.67,1406.88 1105.68,1406.88 1105.69,1406.88 1105.7,1406.88 1105.71,1406.88 1105.72,1406.88 1105.73,1406.88 1105.74,1406.88 1105.75,1406.88 1105.76,1406.88 1105.77,1406.88 1105.78,1406.88 1105.78,1406.88 1105.79,1406.88 1105.8,1406.88 1105.81,1406.88 1105.82,1406.88 1105.83,1406.88 1105.84,1406.88 1105.85,1406.88 1105.86,1406.88 1105.87,1406.88 1105.88,1406.88 1105.89,1406.88 1105.89,1406.88 1105.9,1406.88 1105.91,1406.88 1105.92,1406.88 1105.93,1406.88 1105.94,1406.88 1105.95,1406.88 1105.96,1406.88 1105.97,1406.88 1105.98,1406.88 1105.99,1406.88 1106,1406.88 1106,1406.88 1106.01,1406.88 1106.02,1406.88 1106.03,1406.88 1106.04,1406.88 1106.05,1406.88 1106.06,1406.88 1106.07,1406.88 1106.08,1406.88 1106.09,1406.88 1106.1,1406.88 1106.11,1406.88 1106.12,1406.88 1106.12,1406.88 1106.13,1406.88 1106.14,1406.88 1106.15,1406.88 1106.16,1406.88 1106.17,1406.88 1106.18,1406.88 1106.19,1406.88 1106.2,1406.88 1106.21,1406.88 1106.22,1406.88 1106.23,1406.88 1106.23,1406.88 1106.24,1406.88 1106.25,1406.88 1106.26,1406.88 1106.27,1406.88 1106.28,1406.88 1106.29,1406.88 1106.3,1406.88 1106.31,1406.88 1106.32,1406.88 1106.33,1406.88 1106.34,1406.88 1106.34,1406.88 1106.35,1406.88 1106.36,1406.88 1106.37,1406.88 1106.38,1406.88 1106.39,1406.88 1106.4,1406.88 1106.41,1406.88 1106.42,1406.88 1106.43,1406.88 1106.44,1406.88 1106.45,1406.88 1106.46,1406.88 1106.46,1406.88 1106.47,1406.88 1106.48,1406.88 1106.49,1406.88 1106.5,1406.88 1106.51,1406.88 1106.52,1406.88 1106.53,1406.88 1106.54,1406.88 1106.55,1406.88 1106.56,1406.88 1106.57,1406.88 1106.57,1406.88 1106.58,1406.88 1106.59,1406.88 1106.6,1406.88 1106.61,1406.88 1106.62,1406.88 1106.63,1406.88 1106.64,1406.88 1106.65,1406.88 1106.66,1406.88 1106.67,1406.88 1106.68,1406.88 1106.68,1406.88 1106.69,1406.88 1106.7,1406.88 1106.71,1406.88 1106.72,1406.88 1106.73,1406.88 1106.74,1406.88 1106.75,1406.88 1106.76,1406.88 1106.77,1406.88 1106.78,1406.88 1106.79,1406.88 1106.8,1406.88 1106.8,1406.88 1106.81,1406.88 1106.82,1406.88 1106.83,1406.88 1106.84,1406.88 1106.85,1406.88 1106.86,1406.88 1106.87,1406.88 1106.88,1406.88 1106.89,1406.88 1106.9,1406.88 1106.91,1406.88 1106.91,1406.88 1106.92,1406.88 1106.93,1406.88 1106.94,1406.88 1106.95,1406.88 1106.96,1406.88 1106.97,1406.88 1106.98,1406.88 1106.99,1406.88 1107,1406.88 1107.01,1406.88 1107.02,1406.88 1107.02,1406.88 1107.03,1406.88 1107.04,1406.88 1107.05,1406.88 1107.06,1406.88 1107.07,1406.88 1107.08,1406.88 1107.09,1406.88 1107.1,1406.88 1107.11,1406.88 1107.12,1406.88 1107.13,1406.88 1107.14,1406.88 1107.14,1406.88 1107.15,1406.88 1107.16,1406.88 1107.17,1406.88 1107.18,1406.88 1107.19,1406.88 1107.2,1406.88 1107.21,1406.88 1107.22,1406.88 1107.23,1406.88 1107.24,1406.88 1107.25,1406.88 1107.25,1406.88 1107.26,1406.88 1107.27,1406.88 1107.28,1406.88 1107.29,1406.88 1107.3,1406.88 1107.31,1406.88 1107.32,1406.88 1107.33,1406.88 1107.34,1406.88 1107.35,1406.88 1107.36,1406.88 1107.36,1406.88 1107.37,1406.88 1107.38,1406.88 1107.39,1406.88 1107.4,1406.88 1107.41,1406.88 1107.42,1406.88 1107.43,1406.88 1107.44,1406.88 1107.45,1406.88 1107.46,1406.88 1107.47,1406.88 1107.48,1406.88 1107.48,1406.88 1107.49,1406.88 1107.5,1406.88 1107.51,1406.88 1107.52,1406.88 1107.53,1406.88 1107.54,1406.88 1107.55,1406.88 1107.56,1406.88 1107.57,1406.88 1107.58,1406.88 1107.59,1406.88 1107.59,1406.88 1107.6,1406.88 1107.61,1406.88 1107.62,1406.88 1107.63,1406.88 1107.64,1406.88 1107.65,1406.88 1107.66,1406.88 1107.67,1406.88 1107.68,1406.88 1107.69,1406.88 1107.7,1406.88 1107.7,1406.88 1107.71,1406.88 1107.72,1406.88 1107.73,1406.88 1107.74,1406.88 1107.75,1406.88 1107.76,1406.88 1107.77,1406.88 1107.78,1406.88 1107.79,1406.88 1107.8,1406.88 1107.81,1406.88 1107.82,1406.88 1107.82,1406.88 1107.83,1406.88 1107.84,1406.88 1107.85,1406.88 1107.86,1406.88 1107.87,1406.88 1107.88,1406.88 1107.89,1406.88 1107.9,1406.88 1107.91,1406.88 1107.92,1406.88 1107.93,1406.88 1107.93,1406.88 1107.94,1406.88 1107.95,1406.88 1107.96,1406.88 1107.97,1406.88 1107.98,1406.88 1107.99,1406.88 1108,1406.88 1108.01,1406.88 1108.02,1406.88 1108.03,1406.88 1108.04,1406.88 1108.04,1406.88 1108.05,1406.88 1108.06,1406.88 1108.07,1406.88 1108.08,1406.88 1108.09,1406.88 1108.1,1406.88 1108.11,1406.88 1108.12,1406.88 1108.13,1406.88 1108.14,1406.88 1108.15,1406.88 1108.16,1406.88 1108.16,1406.88 1108.17,1406.88 1108.18,1406.88 1108.19,1406.88 1108.2,1406.88 1108.21,1406.88 1108.22,1406.88 1108.23,1406.88 1108.24,1406.88 1108.25,1406.88 1108.26,1406.88 1108.27,1406.88 1108.27,1406.88 1108.28,1406.88 1108.29,1406.88 1108.3,1406.88 1108.31,1406.88 1108.32,1406.88 1108.33,1406.88 1108.34,1406.88 1108.35,1406.88 1108.36,1406.88 1108.37,1406.88 1108.38,1406.88 1108.38,1406.88 1108.39,1406.88 1108.4,1406.88 1108.41,1406.88 1108.42,1406.88 1108.43,1406.88 1108.44,1406.88 1108.45,1406.88 1108.46,1406.88 1108.47,1406.88 1108.48,1406.88 1108.49,1406.88 1108.5,1406.88 1108.5,1406.88 1108.51,1406.88 1108.52,1406.88 1108.53,1406.88 1108.54,1406.88 1108.55,1406.88 1108.56,1406.88 1108.57,1406.88 1108.58,1406.88 1108.59,1406.88 1108.6,1406.88 1108.61,1406.88 1108.61,1406.88 1108.62,1406.88 1108.63,1406.88 1108.64,1406.88 1108.65,1406.88 1108.66,1406.88 1108.67,1406.88 1108.68,1406.88 1108.69,1406.88 1108.7,1406.88 1108.71,1406.88 1108.72,1406.88 1108.72,1406.88 1108.73,1406.88 1108.74,1406.88 1108.75,1406.88 1108.76,1406.88 1108.77,1406.88 1108.78,1406.88 1108.79,1406.88 1108.8,1406.88 1108.81,1406.88 1108.82,1406.88 1108.83,1406.88 1108.84,1406.88 1108.84,1406.88 1108.85,1406.88 1108.86,1406.88 1108.87,1406.88 1108.88,1406.88 1108.89,1406.88 1108.9,1406.88 1108.91,1406.88 1108.92,1406.88 1108.93,1406.88 1108.94,1406.88 1108.95,1406.88 1108.95,1406.88 1108.96,1406.88 1108.97,1406.88 1108.98,1406.88 1108.99,1406.88 1109,1406.88 1109.01,1406.88 1109.02,1406.88 1109.03,1406.88 1109.04,1406.88 1109.05,1406.88 1109.06,1406.88 1109.06,1406.88 1109.07,1406.88 1109.08,1406.88 1109.09,1406.88 1109.1,1406.88 1109.11,1406.88 1109.12,1406.88 1109.13,1406.88 1109.14,1406.88 1109.15,1406.88 1109.16,1406.88 1109.17,1406.88 1109.18,1406.88 1109.18,1406.88 1109.19,1406.88 1109.2,1406.88 1109.21,1406.88 1109.22,1406.88 1109.23,1406.88 1109.24,1406.88 1109.25,1406.88 1109.26,1406.88 1109.27,1406.88 1109.28,1406.88 1109.29,1406.88 1109.29,1406.88 1109.3,1406.88 1109.31,1406.88 1109.32,1406.88 1109.33,1406.88 1109.34,1406.88 1109.35,1406.88 1109.36,1406.88 1109.37,1406.88 1109.38,1406.88 1109.39,1406.88 1109.4,1406.88 1109.4,1406.88 1109.41,1406.88 1109.42,1406.88 1109.43,1406.88 1109.44,1406.88 1109.45,1406.88 1109.46,1406.88 1109.47,1406.88 1109.48,1406.88 1109.49,1406.88 1109.5,1406.88 1109.51,1406.88 1109.52,1406.88 1109.52,1406.88 1109.53,1406.88 1109.54,1406.88 1109.55,1406.88 1109.56,1406.88 1109.57,1406.88 1109.58,1406.88 1109.59,1406.88 1109.6,1406.88 1109.61,1406.88 1109.62,1406.88 1109.63,1406.88 1109.63,1406.88 1109.64,1406.88 1109.65,1406.88 1109.66,1406.88 1109.67,1406.88 1109.68,1406.88 1109.69,1406.88 1109.7,1406.88 1109.71,1406.88 1109.72,1406.88 1109.73,1406.88 1109.74,1406.88 1109.74,1406.88 1109.75,1406.88 1109.76,1406.88 1109.77,1406.88 1109.78,1406.88 1109.79,1406.88 1109.8,1406.88 1109.81,1406.88 1109.82,1406.88 1109.83,1406.88 1109.84,1406.88 1109.85,1406.88 1109.86,1406.88 1109.86,1406.88 1109.87,1406.88 1109.88,1406.88 1109.89,1406.88 1109.9,1406.88 1109.91,1406.88 1109.92,1406.88 1109.93,1406.88 1109.94,1406.88 1109.95,1406.88 1109.96,1406.88 1109.97,1406.88 1109.97,1406.88 1109.98,1406.88 1109.99,1406.88 1110,1406.88 1110.01,1406.88 1110.02,1406.88 1110.03,1406.88 1110.04,1406.88 1110.05,1406.88 1110.06,1406.88 1110.07,1406.88 1110.08,1406.88 1110.08,1406.88 1110.09,1406.88 1110.1,1406.88 1110.11,1406.88 1110.12,1406.88 1110.13,1406.88 1110.14,1406.88 1110.15,1406.88 1110.16,1406.88 1110.17,1406.88 1110.18,1406.88 1110.19,1406.88 1110.2,1406.88 1110.2,1406.88 1110.21,1406.88 1110.22,1406.88 1110.23,1406.88 1110.24,1406.88 1110.25,1406.88 1110.26,1406.88 1110.27,1406.88 1110.28,1406.88 1110.29,1406.88 1110.3,1406.88 1110.31,1406.88 1110.31,1406.88 1110.32,1406.88 1110.33,1406.88 1110.34,1406.88 1110.35,1406.88 1110.36,1406.88 1110.37,1406.88 1110.38,1406.88 1110.39,1406.88 1110.4,1406.88 1110.41,1406.88 1110.42,1406.88 1110.42,1406.88 1110.43,1406.88 1110.44,1406.88 1110.45,1406.88 1110.46,1406.88 1110.47,1406.88 1110.48,1406.88 1110.49,1406.88 1110.5,1406.88 1110.51,1406.88 1110.52,1406.88 1110.53,1406.88 1110.54,1406.88 1110.54,1406.88 1110.55,1406.88 1110.56,1406.88 1110.57,1406.88 1110.58,1406.88 1110.59,1406.88 1110.6,1406.88 1110.61,1406.88 1110.62,1406.88 1110.63,1406.88 1110.64,1406.88 1110.65,1406.88 1110.65,1406.88 1110.66,1406.88 1110.67,1406.88 1110.68,1406.88 1110.69,1406.88 1110.7,1406.88 1110.71,1406.88 1110.72,1406.88 1110.73,1406.88 1110.74,1406.88 1110.75,1406.88 1110.76,1406.88 1110.76,1406.88 1110.77,1406.88 1110.78,1406.88 1110.79,1406.88 1110.8,1406.88 1110.81,1406.88 1110.82,1406.88 1110.83,1406.88 1110.84,1406.88 1110.85,1406.88 1110.86,1406.88 1110.87,1406.88 1110.88,1406.88 1110.88,1406.88 1110.89,1406.88 1110.9,1406.88 1110.91,1406.88 1110.92,1406.88 1110.93,1406.88 1110.94,1406.88 1110.95,1406.88 1110.96,1406.88 1110.97,1406.88 1110.98,1406.88 1110.99,1406.88 1110.99,1406.88 1111,1406.88 1111.01,1406.88 1111.02,1406.88 1111.03,1406.88 1111.04,1406.88 1111.05,1406.88 1111.06,1406.88 1111.07,1406.88 1111.08,1406.88 1111.09,1406.88 1111.1,1406.88 1111.1,1406.88 1111.11,1406.88 1111.12,1406.88 1111.13,1406.88 1111.14,1406.88 1111.15,1406.88 1111.16,1406.88 1111.17,1406.88 1111.18,1406.88 1111.19,1406.88 1111.2,1406.88 1111.21,1406.88 1111.22,1406.88 1111.22,1406.88 1111.23,1406.88 1111.24,1406.88 1111.25,1406.88 1111.26,1406.88 1111.27,1406.88 1111.28,1406.88 1111.29,1406.88 1111.3,1406.88 1111.31,1406.88 1111.32,1406.88 1111.33,1406.88 1111.33,1406.88 1111.34,1406.88 1111.35,1406.88 1111.36,1406.88 1111.37,1406.88 1111.38,1406.88 1111.39,1406.88 1111.4,1406.88 1111.41,1406.88 1111.42,1406.88 1111.43,1406.88 1111.44,1406.88 1111.44,1406.88 1111.45,1406.88 1111.46,1406.88 1111.47,1406.88 1111.48,1406.88 1111.49,1406.88 1111.5,1406.88 1111.51,1406.88 1111.52,1406.88 1111.53,1406.88 1111.54,1406.88 1111.55,1406.88 1111.56,1406.88 1111.56,1406.88 1111.57,1406.88 1111.58,1406.88 1111.59,1406.88 1111.6,1406.88 1111.61,1406.88 1111.62,1406.88 1111.63,1406.88 1111.64,1406.88 1111.65,1406.88 1111.66,1406.88 1111.67,1406.88 1111.67,1406.88 1111.68,1406.88 1111.69,1406.88 1111.7,1406.88 1111.71,1406.88 1111.72,1406.88 1111.73,1406.88 1111.74,1406.88 1111.75,1406.88 1111.76,1406.88 1111.77,1406.88 1111.78,1406.88 1111.78,1406.88 1111.79,1406.88 1111.8,1406.88 1111.81,1406.88 1111.82,1406.88 1111.83,1406.88 1111.84,1406.88 1111.85,1406.88 1111.86,1406.88 1111.87,1406.88 1111.88,1406.88 1111.89,1406.88 1111.9,1406.88 1111.9,1406.88 1111.91,1406.88 1111.92,1406.88 1111.93,1406.88 1111.94,1406.88 1111.95,1406.88 1111.96,1406.88 1111.97,1406.88 1111.98,1406.88 1111.99,1406.88 1112,1406.88 1112.01,1406.88 1112.01,1406.88 1112.02,1406.88 1112.03,1406.88 1112.04,1406.88 1112.05,1406.88 1112.06,1406.88 1112.07,1406.88 1112.08,1406.88 1112.09,1406.88 1112.1,1406.88 1112.11,1406.88 1112.12,1406.88 1112.12,1406.88 1112.13,1406.88 1112.14,1406.88 1112.15,1406.88 1112.16,1406.88 1112.17,1406.88 1112.18,1406.88 1112.19,1406.88 1112.2,1406.88 1112.21,1406.88 1112.22,1406.88 1112.23,1406.88 1112.24,1406.88 1112.24,1406.88 1112.25,1406.88 1112.26,1406.88 1112.27,1406.88 1112.28,1406.88 1112.29,1406.88 1112.3,1406.88 1112.31,1406.88 1112.32,1406.88 1112.33,1406.88 1112.34,1406.88 1112.35,1406.88 1112.35,1406.88 1112.36,1406.88 1112.37,1406.88 1112.38,1406.88 1112.39,1406.88 1112.4,1406.88 1112.41,1406.88 1112.42,1406.88 1112.43,1406.88 1112.44,1406.88 1112.45,1406.88 1112.46,1406.88 1112.46,1406.88 1112.47,1406.88 1112.48,1406.88 1112.49,1406.88 1112.5,1406.88 1112.51,1406.88 1112.52,1406.88 1112.53,1406.88 1112.54,1406.88 1112.55,1406.88 1112.56,1406.88 1112.57,1406.88 1112.58,1406.88 1112.58,1406.88 1112.59,1406.88 1112.6,1406.88 1112.61,1406.88 1112.62,1406.88 1112.63,1406.88 1112.64,1406.88 1112.65,1406.88 1112.66,1406.88 1112.67,1406.88 1112.68,1406.88 1112.69,1406.88 1112.69,1406.88 1112.7,1406.88 1112.71,1406.88 1112.72,1406.88 1112.73,1406.88 1112.74,1406.88 1112.75,1406.88 1112.76,1406.88 1112.77,1406.88 1112.78,1406.88 1112.79,1406.88 1112.8,1406.88 1112.8,1406.88 1112.81,1406.88 1112.82,1406.88 1112.83,1406.88 1112.84,1406.88 1112.85,1406.88 1112.86,1406.88 1112.87,1406.88 1112.88,1406.88 1112.89,1406.88 1112.9,1406.88 1112.91,1406.88 1112.92,1406.88 1112.92,1406.88 1112.93,1406.88 1112.94,1406.88 1112.95,1406.88 1112.96,1406.88 1112.97,1406.88 1112.98,1406.88 1112.99,1406.88 1113,1406.88 1113.01,1406.88 1113.02,1406.88 1113.03,1406.88 1113.03,1406.88 1113.04,1406.88 1113.05,1406.88 1113.06,1406.88 1113.07,1406.88 1113.08,1406.88 1113.09,1406.88 1113.1,1406.88 1113.11,1406.88 1113.12,1406.88 1113.13,1406.88 1113.14,1406.88 1113.14,1406.88 1113.15,1406.88 1113.16,1406.88 1113.17,1406.88 1113.18,1406.88 1113.19,1406.88 1113.2,1406.88 1113.21,1406.88 1113.22,1406.88 1113.23,1406.88 1113.24,1406.88 1113.25,1406.88 1113.26,1406.88 1113.26,1406.88 1113.27,1406.88 1113.28,1406.88 1113.29,1406.88 1113.3,1406.88 1113.31,1406.88 1113.32,1406.88 1113.33,1406.88 1113.34,1406.88 1113.35,1406.88 1113.36,1406.88 1113.37,1406.88 1113.37,1406.88 1113.38,1406.88 1113.39,1406.88 1113.4,1406.88 1113.41,1406.88 1113.42,1406.88 1113.43,1406.88 1113.44,1406.88 1113.45,1406.88 1113.46,1406.88 1113.47,1406.88 1113.48,1406.88 1113.48,1406.88 1113.49,1406.88 1113.5,1406.88 1113.51,1406.88 1113.52,1406.88 1113.53,1406.88 1113.54,1406.88 1113.55,1406.88 1113.56,1406.88 1113.57,1406.88 1113.58,1406.88 1113.59,1406.88 1113.6,1406.88 1113.6,1406.88 1113.61,1406.88 1113.62,1406.88 1113.63,1406.88 1113.64,1406.88 1113.65,1406.88 1113.66,1406.88 1113.67,1406.88 1113.68,1406.88 1113.69,1406.88 1113.7,1406.88 1113.71,1406.88 1113.71,1406.88 1113.72,1406.88 1113.73,1406.88 1113.74,1406.88 1113.75,1406.88 1113.76,1406.88 1113.77,1406.88 1113.78,1406.88 1113.79,1406.88 1113.8,1406.88 1113.81,1406.88 1113.82,1406.88 1113.82,1406.88 1113.83,1406.88 1113.84,1406.88 1113.85,1406.88 1113.86,1406.88 1113.87,1406.88 1113.88,1406.88 1113.89,1406.88 1113.9,1406.88 1113.91,1406.88 1113.92,1406.88 1113.93,1406.88 1113.94,1406.88 1113.94,1406.88 1113.95,1406.88 1113.96,1406.88 1113.97,1406.88 1113.98,1406.88 1113.99,1406.88 1114,1406.88 1114.01,1406.88 1114.02,1406.88 1114.03,1406.88 1114.04,1406.88 1114.05,1406.88 1114.05,1406.88 1114.06,1406.88 1114.07,1406.88 1114.08,1406.88 1114.09,1406.88 1114.1,1406.88 1114.11,1406.88 1114.12,1406.88 1114.13,1406.88 1114.14,1406.88 1114.15,1406.88 1114.16,1406.88 1114.16,1406.88 1114.17,1406.88 1114.18,1406.88 1114.19,1406.88 1114.2,1406.88 1114.21,1406.88 1114.22,1406.88 1114.23,1406.88 1114.24,1406.88 1114.25,1406.88 1114.26,1406.88 1114.27,1406.88 1114.28,1406.88 1114.28,1406.88 1114.29,1406.88 1114.3,1406.88 1114.31,1406.88 1114.32,1406.88 1114.33,1406.88 1114.34,1406.88 1114.35,1406.88 1114.36,1406.88 1114.37,1406.88 1114.38,1406.88 1114.39,1406.88 1114.39,1406.88 1114.4,1406.88 1114.41,1406.88 1114.42,1406.88 1114.43,1406.88 1114.44,1406.88 1114.45,1406.88 1114.46,1406.88 1114.47,1406.88 1114.48,1406.88 1114.49,1406.88 1114.5,1406.88 1114.5,1406.88 1114.51,1406.88 1114.52,1406.88 1114.53,1406.88 1114.54,1406.88 1114.55,1406.88 1114.56,1406.88 1114.57,1406.88 1114.58,1406.88 1114.59,1406.88 1114.6,1406.88 1114.61,1406.88 1114.62,1406.88 1114.62,1406.88 1114.63,1406.88 1114.64,1406.88 1114.65,1406.88 1114.66,1406.88 1114.67,1406.88 1114.68,1406.88 1114.69,1406.88 1114.7,1406.88 1114.71,1406.88 1114.72,1406.88 1114.73,1406.88 1114.73,1406.88 1114.74,1406.88 1114.75,1406.88 1114.76,1406.88 1114.77,1406.88 1114.78,1406.88 1114.79,1406.88 1114.8,1406.88 1114.81,1406.88 1114.82,1406.88 1114.83,1406.88 1114.84,1406.88 1114.84,1406.88 1114.85,1406.88 1114.86,1406.88 1114.87,1406.88 1114.88,1406.88 1114.89,1406.88 1114.9,1406.88 1114.91,1406.88 1114.92,1406.88 1114.93,1406.88 1114.94,1406.88 1114.95,1406.88 1114.96,1406.88 1114.96,1406.88 1114.97,1406.88 1114.98,1406.88 1114.99,1406.88 1115,1406.88 1115.01,1406.88 1115.02,1406.88 1115.03,1406.88 1115.04,1406.88 1115.05,1406.88 1115.06,1406.88 1115.07,1406.88 1115.07,1406.88 1115.08,1406.88 1115.09,1406.88 1115.1,1406.88 1115.11,1406.88 1115.12,1406.88 1115.13,1406.88 1115.14,1406.88 1115.15,1406.88 1115.16,1406.88 1115.17,1406.88 1115.18,1406.88 1115.18,1406.88 1115.19,1406.88 1115.2,1406.88 1115.21,1406.88 1115.22,1406.88 1115.23,1406.88 1115.24,1406.88 1115.25,1406.88 1115.26,1406.88 1115.27,1406.88 1115.28,1406.88 1115.29,1406.88 1115.3,1406.88 1115.3,1406.88 1115.31,1406.88 1115.32,1406.88 1115.33,1406.88 1115.34,1406.88 1115.35,1406.88 1115.36,1406.88 1115.37,1406.88 1115.38,1406.88 1115.39,1406.88 1115.4,1406.88 1115.41,1406.88 1115.41,1406.88 1115.42,1406.88 1115.43,1406.88 1115.44,1406.88 1115.45,1406.88 1115.46,1406.88 1115.47,1406.88 1115.48,1406.88 1115.49,1406.88 1115.5,1406.88 1115.51,1406.88 1115.52,1406.88 1115.52,1406.88 1115.53,1406.88 1115.54,1406.88 1115.55,1406.88 1115.56,1406.88 1115.57,1406.88 1115.58,1406.88 1115.59,1406.88 1115.6,1406.88 1115.61,1406.88 1115.62,1406.88 1115.63,1406.88 1115.64,1406.88 1115.64,1406.88 1115.65,1406.88 1115.66,1406.88 1115.67,1406.88 1115.68,1406.88 1115.69,1406.88 1115.7,1406.88 1115.71,1406.88 1115.72,1406.88 1115.73,1406.88 1115.74,1406.88 1115.75,1406.88 1115.75,1406.88 1115.76,1406.88 1115.77,1406.88 1115.78,1406.88 1115.79,1406.88 1115.8,1406.88 1115.81,1406.88 1115.82,1406.88 1115.83,1406.88 1115.84,1406.88 1115.85,1406.88 1115.86,1406.88 1115.86,1406.88 1115.87,1406.88 1115.88,1406.88 1115.89,1406.88 1115.9,1406.88 1115.91,1406.88 1115.92,1406.88 1115.93,1406.88 1115.94,1406.88 1115.95,1406.88 1115.96,1406.88 1115.97,1406.88 1115.98,1406.88 1115.98,1406.88 1115.99,1406.88 1116,1406.88 1116.01,1406.88 1116.02,1406.88 1116.03,1406.88 1116.04,1406.88 1116.05,1406.88 1116.06,1406.88 1116.07,1406.88 1116.08,1406.88 1116.09,1406.88 1116.09,1406.88 1116.1,1406.88 1116.11,1406.88 1116.12,1406.88 1116.13,1406.88 1116.14,1406.88 1116.15,1406.88 1116.16,1406.88 1116.17,1406.88 1116.18,1406.88 1116.19,1406.88 1116.2,1406.88 1116.2,1406.88 1116.21,1406.88 1116.22,1406.88 1116.23,1406.88 1116.24,1406.88 1116.25,1406.88 1116.26,1406.88 1116.27,1406.88 1116.28,1406.88 1116.29,1406.88 1116.3,1406.88 1116.31,1406.88 1116.32,1406.88 1116.32,1406.88 1116.33,1406.88 1116.34,1406.88 1116.35,1406.88 1116.36,1406.88 1116.37,1406.88 1116.38,1406.88 1116.39,1406.88 1116.4,1406.88 1116.41,1406.88 1116.42,1406.88 1116.43,1406.88 1116.43,1406.88 1116.44,1406.88 1116.45,1406.88 1116.46,1406.88 1116.47,1406.88 1116.48,1406.88 1116.49,1406.88 1116.5,1406.88 1116.51,1406.88 1116.52,1406.88 1116.53,1406.88 1116.54,1406.88 1116.54,1406.88 1116.55,1406.88 1116.56,1406.88 1116.57,1406.88 1116.58,1406.88 1116.59,1406.88 1116.6,1406.88 1116.61,1406.88 1116.62,1406.88 1116.63,1406.88 1116.64,1406.88 1116.65,1406.88 1116.66,1406.88 1116.66,1406.88 1116.67,1406.88 1116.68,1406.88 1116.69,1406.88 1116.7,1406.88 1116.71,1406.88 1116.72,1406.88 1116.73,1406.88 1116.74,1406.88 1116.75,1406.88 1116.76,1406.88 1116.77,1406.88 1116.77,1406.88 1116.78,1406.88 1116.79,1406.88 1116.8,1406.88 1116.81,1406.88 1116.82,1406.88 1116.83,1406.88 1116.84,1406.88 1116.85,1406.88 1116.86,1406.88 1116.87,1406.88 1116.88,1406.88 1116.88,1406.88 1116.89,1406.88 1116.9,1406.88 1116.91,1406.88 1116.92,1406.88 1116.93,1406.88 1116.94,1406.88 1116.95,1406.88 1116.96,1406.88 1116.97,1406.88 1116.98,1406.88 1116.99,1406.88 1117,1406.88 1117,1406.88 1117.01,1406.88 1117.02,1406.88 1117.03,1406.88 1117.04,1406.88 1117.05,1406.88 1117.06,1406.88 1117.07,1406.88 1117.08,1406.88 1117.09,1406.88 1117.1,1406.88 1117.11,1406.88 1117.11,1406.88 1117.12,1406.88 1117.13,1406.88 1117.14,1406.88 1117.15,1406.88 1117.16,1406.88 1117.17,1406.88 1117.18,1406.88 1117.19,1406.88 1117.2,1406.88 1117.21,1406.88 1117.22,1406.88 1117.22,1406.88 1117.23,1406.88 1117.24,1406.88 1117.25,1406.88 1117.26,1406.88 1117.27,1406.88 1117.28,1406.88 1117.29,1406.88 1117.3,1406.88 1117.31,1406.88 1117.32,1406.88 1117.33,1406.88 1117.34,1406.88 1117.34,1406.88 1117.35,1406.88 1117.36,1406.88 1117.37,1406.88 1117.38,1406.88 1117.39,1406.88 1117.4,1406.88 1117.41,1406.88 1117.42,1406.88 1117.43,1406.88 1117.44,1406.88 1117.45,1406.88 1117.45,1406.88 1117.46,1406.88 1117.47,1406.88 1117.48,1406.88 1117.49,1406.88 1117.5,1406.88 1117.51,1406.88 1117.52,1406.88 1117.53,1406.88 1117.54,1406.88 1117.55,1406.88 1117.56,1406.88 1117.56,1406.88 1117.57,1406.88 1117.58,1406.88 1117.59,1406.88 1117.6,1406.88 1117.61,1406.88 1117.62,1406.88 1117.63,1406.88 1117.64,1406.88 1117.65,1406.88 1117.66,1406.88 1117.67,1406.88 1117.68,1406.88 1117.68,1406.88 1117.69,1406.88 1117.7,1406.88 1117.71,1406.88 1117.72,1406.88 1117.73,1406.88 1117.74,1406.88 1117.75,1406.88 1117.76,1406.88 1117.77,1406.88 1117.78,1406.88 1117.79,1406.88 1117.79,1406.88 1117.8,1406.88 1117.81,1406.88 1117.82,1406.88 1117.83,1406.88 1117.84,1406.88 1117.85,1406.88 1117.86,1406.88 1117.87,1406.88 1117.88,1406.88 1117.89,1406.88 1117.9,1406.88 1117.9,1406.88 1117.91,1406.88 1117.92,1406.88 1117.93,1406.88 1117.94,1406.88 1117.95,1406.88 1117.96,1406.88 1117.97,1406.88 1117.98,1406.88 1117.99,1406.88 1118,1406.88 1118.01,1406.88 1118.02,1406.88 1118.02,1406.88 1118.03,1406.88 1118.04,1406.88 1118.05,1406.88 1118.06,1406.88 1118.07,1406.88 1118.08,1406.88 1118.09,1406.88 1118.1,1406.88 1118.11,1406.88 1118.12,1406.88 1118.13,1406.88 1118.13,1406.88 1118.14,1406.88 1118.15,1406.88 1118.16,1406.88 1118.17,1406.88 1118.18,1406.88 1118.19,1406.88 1118.2,1406.88 1118.21,1406.88 1118.22,1406.88 1118.23,1406.88 1118.24,1406.88 1118.24,1406.88 1118.25,1406.88 1118.26,1406.88 1118.27,1406.88 1118.28,1406.88 1118.29,1406.88 1118.3,1406.88 1118.31,1406.88 1118.32,1406.88 1118.33,1406.88 1118.34,1406.88 1118.35,1406.88 1118.36,1406.88 1118.36,1406.88 1118.37,1406.88 1118.38,1406.88 1118.39,1406.88 1118.4,1406.88 1118.41,1406.88 1118.42,1406.88 1118.43,1406.88 1118.44,1406.88 1118.45,1406.88 1118.46,1406.88 1118.47,1406.88 1118.47,1406.88 1118.48,1406.88 1118.49,1406.88 1118.5,1406.88 1118.51,1406.88 1118.52,1406.88 1118.53,1406.88 1118.54,1406.88 1118.55,1406.88 1118.56,1406.88 1118.57,1406.88 1118.58,1406.88 1118.58,1406.88 1118.59,1406.88 1118.6,1406.88 1118.61,1406.88 1118.62,1406.88 1118.63,1406.88 1118.64,1406.88 1118.65,1406.88 1118.66,1406.88 1118.67,1406.88 1118.68,1406.88 1118.69,1406.88 1118.7,1406.88 1118.7,1406.88 1118.71,1406.88 1118.72,1406.88 1118.73,1406.88 1118.74,1406.88 1118.75,1406.88 1118.76,1406.88 1118.77,1406.88 1118.78,1406.88 1118.79,1406.88 1118.8,1406.88 1118.81,1406.88 1118.81,1406.88 1118.82,1406.88 1118.83,1406.88 1118.84,1406.88 1118.85,1406.88 1118.86,1406.88 1118.87,1406.88 1118.88,1406.88 1118.89,1406.88 1118.9,1406.88 1118.91,1406.88 1118.92,1406.88 1118.92,1406.88 1118.93,1406.88 1118.94,1406.88 1118.95,1406.88 1118.96,1406.88 1118.97,1406.88 1118.98,1406.88 1118.99,1406.88 1119,1406.88 1119.01,1406.88 1119.02,1406.88 1119.03,1406.88 1119.04,1406.88 1119.04,1406.88 1119.05,1406.88 1119.06,1406.88 1119.07,1406.88 1119.08,1406.88 1119.09,1406.88 1119.1,1406.88 1119.11,1406.88 1119.12,1406.88 1119.13,1406.88 1119.14,1406.88 1119.15,1406.88 1119.15,1406.88 1119.16,1406.88 1119.17,1406.88 1119.18,1406.88 1119.19,1406.88 1119.2,1406.88 1119.21,1406.88 1119.22,1406.88 1119.23,1406.88 1119.24,1406.88 1119.25,1406.88 1119.26,1406.88 1119.26,1406.88 1119.27,1406.88 1119.28,1406.88 1119.29,1406.88 1119.3,1406.88 1119.31,1406.88 1119.32,1406.88 1119.33,1406.88 1119.34,1406.88 1119.35,1406.88 1119.36,1406.88 1119.37,1406.88 1119.38,1406.88 1119.38,1406.88 1119.39,1406.88 1119.4,1406.88 1119.41,1406.88 1119.42,1406.88 1119.43,1406.88 1119.44,1406.88 1119.45,1406.88 1119.46,1406.88 1119.47,1406.88 1119.48,1406.88 1119.49,1406.88 1119.49,1406.88 1119.5,1406.88 1119.51,1406.88 1119.52,1406.88 1119.53,1406.88 1119.54,1406.88 1119.55,1406.88 1119.56,1406.88 1119.57,1406.88 1119.58,1406.88 1119.59,1406.88 1119.6,1406.88 1119.6,1406.88 1119.61,1406.88 1119.62,1406.88 1119.63,1406.88 1119.64,1406.88 1119.65,1406.88 1119.66,1406.88 1119.67,1406.88 1119.68,1406.88 1119.69,1406.88 1119.7,1406.88 1119.71,1406.88 1119.72,1406.88 1119.72,1406.88 1119.73,1406.88 1119.74,1406.88 1119.75,1406.88 1119.76,1406.88 1119.77,1406.88 1119.78,1406.88 1119.79,1406.88 1119.8,1406.88 1119.81,1406.88 1119.82,1406.88 1119.83,1406.88 1119.83,1406.88 1119.84,1406.88 1119.85,1406.88 1119.86,1406.88 1119.87,1406.88 1119.88,1406.88 1119.89,1406.88 1119.9,1406.88 1119.91,1406.88 1119.92,1406.88 1119.93,1406.88 1119.94,1406.88 1119.94,1406.88 1119.95,1406.88 1119.96,1406.88 1119.97,1406.88 1119.98,1406.88 1119.99,1406.88 1120,1406.88 1120.01,1406.88 1120.02,1406.88 1120.03,1406.88 1120.04,1406.88 1120.05,1406.88 1120.06,1406.88 1120.06,1406.88 1120.07,1406.88 1120.08,1406.88 1120.09,1406.88 1120.1,1406.88 1120.11,1406.88 1120.12,1406.88 1120.13,1406.88 1120.14,1406.88 1120.15,1406.88 1120.16,1406.88 1120.17,1406.88 1120.17,1406.88 1120.18,1406.88 1120.19,1406.88 1120.2,1406.88 1120.21,1406.88 1120.22,1406.88 1120.23,1406.88 1120.24,1406.88 1120.25,1406.88 1120.26,1406.88 1120.27,1406.88 1120.28,1406.88 1120.28,1406.88 1120.29,1406.88 1120.3,1406.88 1120.31,1406.88 1120.32,1406.88 1120.33,1406.88 1120.34,1406.88 1120.35,1406.88 1120.36,1406.88 1120.37,1406.88 1120.38,1406.88 1120.39,1406.88 1120.4,1406.88 1120.4,1406.88 1120.41,1406.88 1120.42,1406.88 1120.43,1406.88 1120.44,1406.88 1120.45,1406.88 1120.46,1406.88 1120.47,1406.88 1120.48,1406.88 1120.49,1406.88 1120.5,1406.88 1120.51,1406.88 1120.51,1406.88 1120.52,1406.88 1120.53,1406.88 1120.54,1406.88 1120.55,1406.88 1120.56,1406.88 1120.57,1406.88 1120.58,1406.88 1120.59,1406.88 1120.6,1406.88 1120.61,1406.88 1120.62,1406.88 1120.62,1406.88 1120.63,1406.88 1120.64,1406.88 1120.65,1406.88 1120.66,1406.88 1120.67,1406.88 1120.68,1406.88 1120.69,1406.88 1120.7,1406.88 1120.71,1406.88 1120.72,1406.88 1120.73,1406.88 1120.74,1406.88 1120.74,1406.88 1120.75,1406.88 1120.76,1406.88 1120.77,1406.88 1120.78,1406.88 1120.79,1406.88 1120.8,1406.88 1120.81,1406.88 1120.82,1406.88 1120.83,1406.88 1120.84,1406.88 1120.85,1406.88 1120.85,1406.88 1120.86,1406.88 1120.87,1406.88 1120.88,1406.88 1120.89,1406.88 1120.9,1406.88 1120.91,1406.88 1120.92,1406.88 1120.93,1406.88 1120.94,1406.88 1120.95,1406.88 1120.96,1406.88 1120.96,1406.88 1120.97,1406.88 1120.98,1406.88 1120.99,1406.88 1121,1406.88 1121.01,1406.88 1121.02,1406.88 1121.03,1406.88 1121.04,1406.88 1121.05,1406.88 1121.06,1406.88 1121.07,1406.88 1121.08,1406.88 1121.08,1406.88 1121.09,1406.88 1121.1,1406.88 1121.11,1406.88 1121.12,1406.88 1121.13,1406.88 1121.14,1406.88 1121.15,1406.88 1121.16,1406.88 1121.17,1406.88 1121.18,1406.88 1121.19,1406.88 1121.19,1406.88 1121.2,1406.88 1121.21,1406.88 1121.22,1406.88 1121.23,1406.88 1121.24,1406.88 1121.25,1406.88 1121.26,1406.88 1121.27,1406.88 1121.28,1406.88 1121.29,1406.88 1121.3,1406.88 1121.3,1406.88 1121.31,1406.88 1121.32,1406.88 1121.33,1406.88 1121.34,1406.88 1121.35,1406.88 1121.36,1406.88 1121.37,1406.88 1121.38,1406.88 1121.39,1406.88 1121.4,1406.88 1121.41,1406.88 1121.42,1406.88 1121.42,1406.88 1121.43,1406.88 1121.44,1406.88 1121.45,1406.88 1121.46,1406.88 1121.47,1406.88 1121.48,1406.88 1121.49,1406.88 1121.5,1406.88 1121.51,1406.88 1121.52,1406.88 1121.53,1406.88 1121.53,1406.88 1121.54,1406.88 1121.55,1406.88 1121.56,1406.88 1121.57,1406.88 1121.58,1406.88 1121.59,1406.88 1121.6,1406.88 1121.61,1406.88 1121.62,1406.88 1121.63,1406.88 1121.64,1406.88 1121.65,1406.88 1121.65,1406.88 1121.66,1406.88 1121.67,1406.88 1121.68,1406.88 1121.69,1406.88 1121.7,1406.88 1121.71,1406.88 1121.72,1406.88 1121.73,1406.88 1121.74,1406.88 1121.75,1406.88 1121.76,1406.88 1121.76,1406.88 1121.77,1406.88 1121.78,1406.88 1121.79,1406.88 1121.8,1406.88 1121.81,1406.88 1121.82,1406.88 1121.83,1406.88 1121.84,1406.88 1121.85,1406.88 1121.86,1406.88 1121.87,1406.88 1121.87,1406.88 1121.88,1406.88 1121.89,1406.88 1121.9,1406.88 1121.91,1406.88 1121.92,1406.88 1121.93,1406.88 1121.94,1406.88 1121.95,1406.88 1121.96,1406.88 1121.97,1406.88 1121.98,1406.88 1121.99,1406.88 1121.99,1406.88 1122,1406.88 1122.01,1406.88 1122.02,1406.88 1122.03,1406.88 1122.04,1406.88 1122.05,1406.88 1122.06,1406.88 1122.07,1406.88 1122.08,1406.88 1122.09,1406.88 1122.1,1406.88 1122.1,1406.88 1122.11,1406.88 1122.12,1406.88 1122.13,1406.88 1122.14,1406.88 1122.15,1406.88 1122.16,1406.88 1122.17,1406.88 1122.18,1406.88 1122.19,1406.88 1122.2,1406.88 1122.21,1406.88 1122.21,1406.88 1122.22,1406.88 1122.23,1406.88 1122.24,1406.88 1122.25,1406.88 1122.26,1406.88 1122.27,1406.88 1122.28,1406.88 1122.29,1406.88 1122.3,1406.88 1122.31,1406.88 1122.32,1406.88 1122.33,1406.88 1122.33,1406.88 1122.34,1406.88 1122.35,1406.88 1122.36,1406.88 1122.37,1406.88 1122.38,1406.88 1122.39,1406.88 1122.4,1406.88 1122.41,1406.88 1122.42,1406.88 1122.43,1406.88 1122.44,1406.88 1122.44,1406.88 1122.45,1406.88 1122.46,1406.88 1122.47,1406.88 1122.48,1406.88 1122.49,1406.88 1122.5,1406.88 1122.51,1406.88 1122.52,1406.88 1122.53,1406.88 1122.54,1406.88 1122.55,1406.88 1122.55,1406.88 1122.56,1406.88 1122.57,1406.88 1122.58,1406.88 1122.59,1406.88 1122.6,1406.88 1122.61,1406.88 1122.62,1406.88 1122.63,1406.88 1122.64,1406.88 1122.65,1406.88 1122.66,1406.88 1122.67,1406.88 1122.67,1406.88 1122.68,1406.88 1122.69,1406.88 1122.7,1406.88 1122.71,1406.88 1122.72,1406.88 1122.73,1406.88 1122.74,1406.88 1122.75,1406.88 1122.76,1406.88 1122.77,1406.88 1122.78,1406.88 1122.78,1406.88 1122.79,1406.88 1122.8,1406.88 1122.81,1406.88 1122.82,1406.88 1122.83,1406.88 1122.84,1406.88 1122.85,1406.88 1122.86,1406.88 1122.87,1406.88 1122.88,1406.88 1122.89,1406.88 1122.89,1406.88 1122.9,1406.88 1122.91,1406.88 1122.92,1406.88 1122.93,1406.88 1122.94,1406.88 1122.95,1406.88 1122.96,1406.88 1122.97,1406.88 1122.98,1406.88 1122.99,1406.88 1123,1406.88 1123.01,1406.88 1123.01,1406.88 1123.02,1406.88 1123.03,1406.88 1123.04,1406.88 1123.05,1406.88 1123.06,1406.88 1123.07,1406.88 1123.08,1406.88 1123.09,1406.88 1123.1,1406.88 1123.11,1406.88 1123.12,1406.88 1123.12,1406.88 1123.13,1406.88 1123.14,1406.88 1123.15,1406.88 1123.16,1406.88 1123.17,1406.88 1123.18,1406.88 1123.19,1406.88 1123.2,1406.88 1123.21,1406.88 1123.22,1406.88 1123.23,1406.88 1123.23,1406.88 1123.24,1406.88 1123.25,1406.88 1123.26,1406.88 1123.27,1406.88 1123.28,1406.88 1123.29,1406.88 1123.3,1406.88 1123.31,1406.88 1123.32,1406.88 1123.33,1406.88 1123.34,1406.88 1123.35,1406.88 1123.35,1406.88 1123.36,1406.88 1123.37,1406.88 1123.38,1406.88 1123.39,1406.88 1123.4,1406.88 1123.41,1406.88 1123.42,1406.88 1123.43,1406.88 1123.44,1406.88 1123.45,1406.88 1123.46,1406.88 1123.46,1406.88 1123.47,1406.88 1123.48,1406.88 1123.49,1406.88 1123.5,1406.88 1123.51,1406.88 1123.52,1406.88 1123.53,1406.88 1123.54,1406.88 1123.55,1406.88 1123.56,1406.88 1123.57,1406.88 1123.57,1406.88 1123.58,1406.88 1123.59,1406.88 1123.6,1406.88 1123.61,1406.88 1123.62,1406.88 1123.63,1406.88 1123.64,1406.88 1123.65,1406.88 1123.66,1406.88 1123.67,1406.88 1123.68,1406.88 1123.69,1406.88 1123.69,1406.88 1123.7,1406.88 1123.71,1406.88 1123.72,1406.88 1123.73,1406.88 1123.74,1406.88 1123.75,1406.88 1123.76,1406.88 1123.77,1406.88 1123.78,1406.88 1123.79,1406.88 1123.8,1406.88 1123.8,1406.88 1123.81,1406.88 1123.82,1406.88 1123.83,1406.88 1123.84,1406.88 1123.85,1406.88 1123.86,1406.88 1123.87,1406.88 1123.88,1406.88 1123.89,1406.88 1123.9,1406.88 1123.91,1406.88 1123.91,1406.88 1123.92,1406.88 1123.93,1406.88 1123.94,1406.88 1123.95,1406.88 1123.96,1406.88 1123.97,1406.88 1123.98,1406.88 1123.99,1406.88 1124,1406.88 1124.01,1406.88 1124.02,1406.88 1124.03,1406.88 1124.03,1406.88 1124.04,1406.88 1124.05,1406.88 1124.06,1406.88 1124.07,1406.88 1124.08,1406.88 1124.09,1406.88 1124.1,1406.88 1124.11,1406.88 1124.12,1406.88 1124.13,1406.88 1124.14,1406.88 1124.14,1406.88 1124.15,1406.88 1124.16,1406.88 1124.17,1406.88 1124.18,1406.88 1124.19,1406.88 1124.2,1406.88 1124.21,1406.88 1124.22,1406.88 1124.23,1406.88 1124.24,1406.88 1124.25,1406.88 1124.25,1406.88 1124.26,1406.88 1124.27,1406.88 1124.28,1406.88 1124.29,1406.88 1124.3,1406.88 1124.31,1406.88 1124.32,1406.88 1124.33,1406.88 1124.34,1406.88 1124.35,1406.88 1124.36,1406.88 1124.37,1406.88 1124.37,1406.88 1124.38,1406.88 1124.39,1406.88 1124.4,1406.88 1124.41,1406.88 1124.42,1406.88 1124.43,1406.88 1124.44,1406.88 1124.45,1406.88 1124.46,1406.88 1124.47,1406.88 1124.48,1406.88 1124.48,1406.88 1124.49,1406.88 1124.5,1406.88 1124.51,1406.88 1124.52,1406.88 1124.53,1406.88 1124.54,1406.88 1124.55,1406.88 1124.56,1406.88 1124.57,1406.88 1124.58,1406.88 1124.59,1406.88 1124.59,1406.88 1124.6,1406.88 1124.61,1406.88 1124.62,1406.88 1124.63,1406.88 1124.64,1406.88 1124.65,1406.88 1124.66,1406.88 1124.67,1406.88 1124.68,1406.88 1124.69,1406.88 1124.7,1406.88 1124.71,1406.88 1124.71,1406.88 1124.72,1406.88 1124.73,1406.88 1124.74,1406.88 1124.75,1406.88 1124.76,1406.88 1124.77,1406.88 1124.78,1406.88 1124.79,1406.88 1124.8,1406.88 1124.81,1406.88 1124.82,1406.88 1124.82,1406.88 1124.83,1406.88 1124.84,1406.88 1124.85,1406.88 1124.86,1406.88 1124.87,1406.88 1124.88,1406.88 1124.89,1406.88 1124.9,1406.88 1124.91,1406.88 1124.92,1406.88 1124.93,1406.88 1124.93,1406.88 1124.94,1406.88 1124.95,1406.88 1124.96,1406.88 1124.97,1406.88 1124.98,1406.88 1124.99,1406.88 1125,1406.88 1125.01,1406.88 1125.02,1406.88 1125.03,1406.88 1125.04,1406.88 1125.05,1406.88 1125.05,1406.88 1125.06,1406.88 1125.07,1406.88 1125.08,1406.88 1125.09,1406.88 1125.1,1406.88 1125.11,1406.88 1125.12,1406.88 1125.13,1406.88 1125.14,1406.88 1125.15,1406.88 1125.16,1406.88 1125.16,1406.88 1125.17,1406.88 1125.18,1406.88 1125.19,1406.88 1125.2,1406.88 1125.21,1406.88 1125.22,1406.88 1125.23,1406.88 1125.24,1406.88 1125.25,1406.88 1125.26,1406.88 1125.27,1406.88 1125.27,1406.88 1125.28,1406.88 1125.29,1406.88 1125.3,1406.88 1125.31,1406.88 1125.32,1406.88 1125.33,1406.88 1125.34,1406.88 1125.35,1406.88 1125.36,1406.88 1125.37,1406.88 1125.38,1406.88 1125.39,1406.88 1125.39,1406.88 1125.4,1406.88 1125.41,1406.88 1125.42,1406.88 1125.43,1406.88 1125.44,1406.88 1125.45,1406.88 1125.46,1406.88 1125.47,1406.88 1125.48,1406.88 1125.49,1406.88 1125.5,1406.88 1125.5,1406.88 1125.51,1406.88 1125.52,1406.88 1125.53,1406.88 1125.54,1406.88 1125.55,1406.88 1125.56,1406.88 1125.57,1406.88 1125.58,1406.88 1125.59,1406.88 1125.6,1406.88 1125.61,1406.88 1125.61,1406.88 1125.62,1406.88 1125.63,1406.88 1125.64,1406.88 1125.65,1406.88 1125.66,1406.88 1125.67,1406.88 1125.68,1406.88 1125.69,1406.88 1125.7,1406.88 1125.71,1406.88 1125.72,1406.88 1125.73,1406.88 1125.73,1406.88 1125.74,1406.88 1125.75,1406.88 1125.76,1406.88 1125.77,1406.88 1125.78,1406.88 1125.79,1406.88 1125.8,1406.88 1125.81,1406.88 1125.82,1406.88 1125.83,1406.88 1125.84,1406.88 1125.84,1406.88 1125.85,1406.88 1125.86,1406.88 1125.87,1406.88 1125.88,1406.88 1125.89,1406.88 1125.9,1406.88 1125.91,1406.88 1125.92,1406.88 1125.93,1406.88 1125.94,1406.88 1125.95,1406.88 1125.95,1406.88 1125.96,1406.88 1125.97,1406.88 1125.98,1406.88 1125.99,1406.88 1126,1406.88 1126.01,1406.88 1126.02,1406.88 1126.03,1406.88 1126.04,1406.88 1126.05,1406.88 1126.06,1406.88 1126.07,1406.88 1126.07,1406.88 1126.08,1406.88 1126.09,1406.88 1126.1,1406.88 1126.11,1406.88 1126.12,1406.88 1126.13,1406.88 1126.14,1406.88 1126.15,1406.88 1126.16,1406.88 1126.17,1406.88 1126.18,1406.88 1126.18,1406.88 1126.19,1406.88 1126.2,1406.88 1126.21,1406.88 1126.22,1406.88 1126.23,1406.88 1126.24,1406.88 1126.25,1406.88 1126.26,1406.88 1126.27,1406.88 1126.28,1406.88 1126.29,1406.88 1126.29,1406.88 1126.3,1406.88 1126.31,1406.88 1126.32,1406.88 1126.33,1406.88 1126.34,1406.88 1126.35,1406.88 1126.36,1406.88 1126.37,1406.88 1126.38,1406.88 1126.39,1406.88 1126.4,1406.88 1126.41,1406.88 1126.41,1406.88 1126.42,1406.88 1126.43,1406.88 1126.44,1406.88 1126.45,1406.88 1126.46,1406.88 1126.47,1406.88 1126.48,1406.88 1126.49,1406.88 1126.5,1406.88 1126.51,1406.88 1126.52,1406.88 1126.52,1406.88 1126.53,1406.88 1126.54,1406.88 1126.55,1406.88 1126.56,1406.88 1126.57,1406.88 1126.58,1406.88 1126.59,1406.88 1126.6,1406.88 1126.61,1406.88 1126.62,1406.88 1126.63,1406.88 1126.63,1406.88 1126.64,1406.88 1126.65,1406.88 1126.66,1406.88 1126.67,1406.88 1126.68,1406.88 1126.69,1406.88 1126.7,1406.88 1126.71,1406.88 1126.72,1406.88 1126.73,1406.88 1126.74,1406.88 1126.75,1406.88 1126.75,1406.88 1126.76,1406.88 1126.77,1406.88 1126.78,1406.88 1126.79,1406.88 1126.8,1406.88 1126.81,1406.88 1126.82,1406.88 1126.83,1406.88 1126.84,1406.88 1126.85,1406.88 1126.86,1406.88 1126.86,1406.88 1126.87,1406.88 1126.88,1406.88 1126.89,1406.88 1126.9,1406.88 1126.91,1406.88 1126.92,1406.88 1126.93,1406.88 1126.94,1406.88 1126.95,1406.88 1126.96,1406.88 1126.97,1406.88 1126.97,1406.88 1126.98,1406.88 1126.99,1406.88 1127,1406.88 1127.01,1406.88 1127.02,1406.88 1127.03,1406.88 1127.04,1406.88 1127.05,1406.88 1127.06,1406.88 1127.07,1406.88 1127.08,1406.88 1127.09,1406.88 1127.09,1406.88 1127.1,1406.88 1127.11,1406.88 1127.12,1406.88 1127.13,1406.88 1127.14,1406.88 1127.15,1406.88 1127.16,1406.88 1127.17,1406.88 1127.18,1406.88 1127.19,1406.88 1127.2,1406.88 1127.2,1406.88 1127.21,1406.88 1127.22,1406.88 1127.23,1406.88 1127.24,1406.88 1127.25,1406.88 1127.26,1406.88 1127.27,1406.88 1127.28,1406.88 1127.29,1406.88 1127.3,1406.88 1127.31,1406.88 1127.31,1406.88 1127.32,1406.88 1127.33,1406.88 1127.34,1406.88 1127.35,1406.88 1127.36,1406.88 1127.37,1406.88 1127.38,1406.88 1127.39,1406.88 1127.4,1406.88 1127.41,1406.88 1127.42,1406.88 1127.43,1406.88 1127.43,1406.88 1127.44,1406.88 1127.45,1406.88 1127.46,1406.88 1127.47,1406.88 1127.48,1406.88 1127.49,1406.88 1127.5,1406.88 1127.51,1406.88 1127.52,1406.88 1127.53,1406.88 1127.54,1406.88 1127.54,1406.88 1127.55,1406.88 1127.56,1406.88 1127.57,1406.88 1127.58,1406.88 1127.59,1406.88 1127.6,1406.88 1127.61,1406.88 1127.62,1406.88 1127.63,1406.88 1127.64,1406.88 1127.65,1406.88 1127.65,1406.88 1127.66,1406.88 1127.67,1406.88 1127.68,1406.88 1127.69,1406.88 1127.7,1406.88 1127.71,1406.88 1127.72,1406.88 1127.73,1406.88 1127.74,1406.88 1127.75,1406.88 1127.76,1406.88 1127.77,1406.88 1127.77,1406.88 1127.78,1406.88 1127.79,1406.88 1127.8,1406.88 1127.81,1406.88 1127.82,1406.88 1127.83,1406.88 1127.84,1406.88 1127.85,1406.88 1127.86,1406.88 1127.87,1406.88 1127.88,1406.88 1127.88,1406.88 1127.89,1406.88 1127.9,1406.88 1127.91,1406.88 1127.92,1406.88 1127.93,1406.88 1127.94,1406.88 1127.95,1406.88 1127.96,1406.88 1127.97,1406.88 1127.98,1406.88 1127.99,1406.88 1127.99,1406.88 1128,1406.88 1128.01,1406.88 1128.02,1406.88 1128.03,1406.88 1128.04,1406.88 1128.05,1406.88 1128.06,1406.88 1128.07,1406.88 1128.08,1406.88 1128.09,1406.88 1128.1,1406.88 1128.11,1406.88 1128.11,1406.88 1128.12,1406.88 1128.13,1406.88 1128.14,1406.88 1128.15,1406.88 1128.16,1406.88 1128.17,1406.88 1128.18,1406.88 1128.19,1406.88 1128.2,1406.88 1128.21,1406.88 1128.22,1406.88 1128.22,1406.88 1128.23,1406.88 1128.24,1406.88 1128.25,1406.88 1128.26,1406.88 1128.27,1406.88 1128.28,1406.88 1128.29,1406.88 1128.3,1406.88 1128.31,1406.88 1128.32,1406.88 1128.33,1406.88 1128.33,1406.88 1128.34,1406.88 1128.35,1406.88 1128.36,1406.88 1128.37,1406.88 1128.38,1406.88 1128.39,1406.88 1128.4,1406.88 1128.41,1406.88 1128.42,1406.88 1128.43,1406.88 1128.44,1406.88 1128.45,1406.88 1128.45,1406.88 1128.46,1406.88 1128.47,1406.88 1128.48,1406.88 1128.49,1406.88 1128.5,1406.88 1128.51,1406.88 1128.52,1406.88 1128.53,1406.88 1128.54,1406.88 1128.55,1406.88 1128.56,1406.88 1128.56,1406.88 1128.57,1406.88 1128.58,1406.88 1128.59,1406.88 1128.6,1406.88 1128.61,1406.88 1128.62,1406.88 1128.63,1406.88 1128.64,1406.88 1128.65,1406.88 1128.66,1406.88 1128.67,1406.88 1128.67,1406.88 1128.68,1406.88 1128.69,1406.88 1128.7,1406.88 1128.71,1406.88 1128.72,1406.88 1128.73,1406.88 1128.74,1406.88 1128.75,1406.88 1128.76,1406.88 1128.77,1406.88 1128.78,1406.88 1128.79,1406.88 1128.79,1406.88 1128.8,1406.88 1128.81,1406.88 1128.82,1406.88 1128.83,1406.88 1128.84,1406.88 1128.85,1406.88 1128.86,1406.88 1128.87,1406.88 1128.88,1406.88 1128.89,1406.88 1128.9,1406.88 1128.9,1406.88 1128.91,1406.88 1128.92,1406.88 1128.93,1406.88 1128.94,1406.88 1128.95,1406.88 1128.96,1406.88 1128.97,1406.88 1128.98,1406.88 1128.99,1406.88 1129,1406.88 1129.01,1406.88 1129.01,1406.88 1129.02,1406.88 1129.03,1406.88 1129.04,1406.88 1129.05,1406.88 1129.06,1406.88 1129.07,1406.88 1129.08,1406.88 1129.09,1406.88 1129.1,1406.88 1129.11,1406.88 1129.12,1406.88 1129.13,1406.88 1129.13,1406.88 1129.14,1406.88 1129.15,1406.88 1129.16,1406.88 1129.17,1406.88 1129.18,1406.88 1129.19,1406.88 1129.2,1406.88 1129.21,1406.88 1129.22,1406.88 1129.23,1406.88 1129.24,1406.88 1129.24,1406.88 1129.25,1406.88 1129.26,1406.88 1129.27,1406.88 1129.28,1406.88 1129.29,1406.88 1129.3,1406.88 1129.31,1406.88 1129.32,1406.88 1129.33,1406.88 1129.34,1406.88 1129.35,1406.88 1129.35,1406.88 1129.36,1406.88 1129.37,1406.88 1129.38,1406.88 1129.39,1406.88 1129.4,1406.88 1129.41,1406.88 1129.42,1406.88 1129.43,1406.88 1129.44,1406.88 1129.45,1406.88 1129.46,1406.88 1129.47,1406.88 1129.47,1406.88 1129.48,1406.88 1129.49,1406.88 1129.5,1406.88 1129.51,1406.88 1129.52,1406.88 1129.53,1406.88 1129.54,1406.88 1129.55,1406.88 1129.56,1406.88 1129.57,1406.88 1129.58,1406.88 1129.58,1406.88 1129.59,1406.88 1129.6,1406.88 1129.61,1406.88 1129.62,1406.88 1129.63,1406.88 1129.64,1406.88 1129.65,1406.88 1129.66,1406.88 1129.67,1406.88 1129.68,1406.88 1129.69,1406.88 1129.69,1406.88 1129.7,1406.88 1129.71,1406.88 1129.72,1406.88 1129.73,1406.88 1129.74,1406.88 1129.75,1406.88 1129.76,1406.88 1129.77,1406.88 1129.78,1406.88 1129.79,1406.88 1129.8,1406.88 1129.81,1406.88 1129.81,1406.88 1129.82,1406.88 1129.83,1406.88 1129.84,1406.88 1129.85,1406.88 1129.86,1406.88 1129.87,1406.88 1129.88,1406.88 1129.89,1406.88 1129.9,1406.88 1129.91,1406.88 1129.92,1406.88 1129.92,1406.88 1129.93,1406.88 1129.94,1406.88 1129.95,1406.88 1129.96,1406.88 1129.97,1406.88 1129.98,1406.88 1129.99,1406.88 1130,1406.88 1130.01,1406.88 1130.02,1406.88 1130.03,1406.88 1130.03,1406.88 1130.04,1406.88 1130.05,1406.88 1130.06,1406.88 1130.07,1406.88 1130.08,1406.88 1130.09,1406.88 1130.1,1406.88 1130.11,1406.88 1130.12,1406.88 1130.13,1406.88 1130.14,1406.88 1130.15,1406.88 1130.15,1406.88 1130.16,1406.88 1130.17,1406.88 1130.18,1406.88 1130.19,1406.88 1130.2,1406.88 1130.21,1406.88 1130.22,1406.88 1130.23,1406.88 1130.24,1406.88 1130.25,1406.88 1130.26,1406.88 1130.26,1406.88 1130.27,1406.88 1130.28,1406.88 1130.29,1406.88 1130.3,1406.88 1130.31,1406.88 1130.32,1406.88 1130.33,1406.88 1130.34,1406.88 1130.35,1406.88 1130.36,1406.88 1130.37,1406.88 1130.37,1406.88 1130.38,1406.88 1130.39,1406.88 1130.4,1406.88 1130.41,1406.88 1130.42,1406.88 1130.43,1406.88 1130.44,1406.88 1130.45,1406.88 1130.46,1406.88 1130.47,1406.88 1130.48,1406.88 1130.49,1406.88 1130.49,1406.88 1130.5,1406.88 1130.51,1406.88 1130.52,1406.88 1130.53,1406.88 1130.54,1406.88 1130.55,1406.88 1130.56,1406.88 1130.57,1406.88 1130.58,1406.88 1130.59,1406.88 1130.6,1406.88 1130.6,1406.88 1130.61,1406.88 1130.62,1406.88 1130.63,1406.88 1130.64,1406.88 1130.65,1406.88 1130.66,1406.88 1130.67,1406.88 1130.68,1406.88 1130.69,1406.88 1130.7,1406.88 1130.71,1406.88 1130.71,1406.88 1130.72,1406.88 1130.73,1406.88 1130.74,1406.88 1130.75,1406.88 1130.76,1406.88 1130.77,1406.88 1130.78,1406.88 1130.79,1406.88 1130.8,1406.88 1130.81,1406.88 1130.82,1406.88 1130.83,1406.88 1130.83,1406.88 1130.84,1406.88 1130.85,1406.88 1130.86,1406.88 1130.87,1406.88 1130.88,1406.88 1130.89,1406.88 1130.9,1406.88 1130.91,1406.88 1130.92,1406.88 1130.93,1406.88 1130.94,1406.88 1130.94,1406.88 1130.95,1406.88 1130.96,1406.88 1130.97,1406.88 1130.98,1406.88 1130.99,1406.88 1131,1406.88 1131.01,1406.88 1131.02,1406.88 1131.03,1406.88 1131.04,1406.88 1131.05,1406.88 1131.05,1406.88 1131.06,1406.88 1131.07,1406.88 1131.08,1406.88 1131.09,1406.88 1131.1,1406.88 1131.11,1406.88 1131.12,1406.88 1131.13,1406.88 1131.14,1406.88 1131.15,1406.88 1131.16,1406.88 1131.17,1406.88 1131.17,1406.88 1131.18,1406.88 1131.19,1406.88 1131.2,1406.88 1131.21,1406.88 1131.22,1406.88 1131.23,1406.88 1131.24,1406.88 1131.25,1406.88 1131.26,1406.88 1131.27,1406.88 1131.28,1406.88 1131.28,1406.88 1131.29,1406.88 1131.3,1406.88 1131.31,1406.88 1131.32,1406.88 1131.33,1406.88 1131.34,1406.88 1131.35,1406.88 1131.36,1406.88 1131.37,1406.88 1131.38,1406.88 1131.39,1406.88 1131.39,1406.88 1131.4,1406.88 1131.41,1406.88 1131.42,1406.88 1131.43,1406.88 1131.44,1406.88 1131.45,1406.88 1131.46,1406.88 1131.47,1406.88 1131.48,1406.88 1131.49,1406.88 1131.5,1406.88 1131.51,1406.88 1131.51,1406.88 1131.52,1406.88 1131.53,1406.88 1131.54,1406.88 1131.55,1406.88 1131.56,1406.88 1131.57,1406.88 1131.58,1406.88 1131.59,1406.88 1131.6,1406.88 1131.61,1406.88 1131.62,1406.88 1131.62,1406.88 1131.63,1406.88 1131.64,1406.88 1131.65,1406.88 1131.66,1406.88 1131.67,1406.88 1131.68,1406.88 1131.69,1406.88 1131.7,1406.88 1131.71,1406.88 1131.72,1406.88 1131.73,1406.88 1131.73,1406.88 1131.74,1406.88 1131.75,1406.88 1131.76,1406.88 1131.77,1406.88 1131.78,1406.88 1131.79,1406.88 1131.8,1406.88 1131.81,1406.88 1131.82,1406.88 1131.83,1406.88 1131.84,1406.88 1131.85,1406.88 1131.85,1406.88 1131.86,1406.88 1131.87,1406.88 1131.88,1406.88 1131.89,1406.88 1131.9,1406.88 1131.91,1406.88 1131.92,1406.88 1131.93,1406.88 1131.94,1406.88 1131.95,1406.88 1131.96,1406.88 1131.96,1406.88 1131.97,1406.88 1131.98,1406.88 1131.99,1406.88 1132,1406.88 1132.01,1406.88 1132.02,1406.88 1132.03,1406.88 1132.04,1406.88 1132.05,1406.88 1132.06,1406.88 1132.07,1406.88 1132.07,1406.88 1132.08,1406.88 1132.09,1406.88 1132.1,1406.88 1132.11,1406.88 1132.12,1406.88 1132.13,1406.88 1132.14,1406.88 1132.15,1406.88 1132.16,1406.88 1132.17,1406.88 1132.18,1406.88 1132.19,1406.88 1132.19,1406.88 1132.2,1406.88 1132.21,1406.88 1132.22,1406.88 1132.23,1406.88 1132.24,1406.88 1132.25,1406.88 1132.26,1406.88 1132.27,1406.88 1132.28,1406.88 1132.29,1406.88 1132.3,1406.88 1132.3,1406.88 1132.31,1406.88 1132.32,1406.88 1132.33,1406.88 1132.34,1406.88 1132.35,1406.88 1132.36,1406.88 1132.37,1406.88 1132.38,1406.88 1132.39,1406.88 1132.4,1406.88 1132.41,1406.88 1132.41,1406.88 1132.42,1406.88 1132.43,1406.88 1132.44,1406.88 1132.45,1406.88 1132.46,1406.88 1132.47,1406.88 1132.48,1406.88 1132.49,1406.88 1132.5,1406.88 1132.51,1406.88 1132.52,1406.88 1132.53,1406.88 1132.53,1406.88 1132.54,1406.88 1132.55,1406.88 1132.56,1406.88 1132.57,1406.88 1132.58,1406.88 1132.59,1406.88 1132.6,1406.88 1132.61,1406.88 1132.62,1406.88 1132.63,1406.88 1132.64,1406.88 1132.64,1406.88 1132.65,1406.88 1132.66,1406.88 1132.67,1406.88 1132.68,1406.88 1132.69,1406.88 1132.7,1406.88 1132.71,1406.88 1132.72,1406.88 1132.73,1406.88 1132.74,1406.88 1132.75,1406.88 1132.75,1406.88 1132.76,1406.88 1132.77,1406.88 1132.78,1406.88 1132.79,1406.88 1132.8,1406.88 1132.81,1406.88 1132.82,1406.88 1132.83,1406.88 1132.84,1406.88 1132.85,1406.88 1132.86,1406.88 1132.87,1406.88 1132.87,1406.88 1132.88,1406.88 1132.89,1406.88 1132.9,1406.88 1132.91,1406.88 1132.92,1406.88 1132.93,1406.88 1132.94,1406.88 1132.95,1406.88 1132.96,1406.88 1132.97,1406.88 1132.98,1406.88 1132.98,1406.88 1132.99,1406.88 1133,1406.88 1133.01,1406.88 1133.02,1406.88 1133.03,1406.88 1133.04,1406.88 1133.05,1406.88 1133.06,1406.88 1133.07,1406.88 1133.08,1406.88 1133.09,1406.88 1133.09,1406.88 1133.1,1406.88 1133.11,1406.88 1133.12,1406.88 1133.13,1406.88 1133.14,1406.88 1133.15,1406.88 1133.16,1406.88 1133.17,1406.88 1133.18,1406.88 1133.19,1406.88 1133.2,1406.88 1133.21,1406.88 1133.21,1406.88 1133.22,1406.88 1133.23,1406.88 1133.24,1406.88 1133.25,1406.88 1133.26,1406.88 1133.27,1406.88 1133.28,1406.88 1133.29,1406.88 1133.3,1406.88 1133.31,1406.88 1133.32,1406.88 1133.32,1406.88 1133.33,1406.88 1133.34,1406.88 1133.35,1406.88 1133.36,1406.88 1133.37,1406.88 1133.38,1406.88 1133.39,1406.88 1133.4,1406.88 1133.41,1406.88 1133.42,1406.88 1133.43,1406.88 1133.43,1406.88 1133.44,1406.88 1133.45,1406.88 1133.46,1406.88 1133.47,1406.88 1133.48,1406.88 1133.49,1406.88 1133.5,1406.88 1133.51,1406.88 1133.52,1406.88 1133.53,1406.88 1133.54,1406.88 1133.55,1406.88 1133.55,1406.88 1133.56,1406.88 1133.57,1406.88 1133.58,1406.88 1133.59,1406.88 1133.6,1406.88 1133.61,1406.88 1133.62,1406.88 1133.63,1406.88 1133.64,1406.88 1133.65,1406.88 1133.66,1406.88 1133.66,1406.88 1133.67,1406.88 1133.68,1406.88 1133.69,1406.88 1133.7,1406.88 1133.71,1406.88 1133.72,1406.88 1133.73,1406.88 1133.74,1406.88 1133.75,1406.88 1133.76,1406.88 1133.77,1406.88 1133.77,1406.88 1133.78,1406.88 1133.79,1406.88 1133.8,1406.88 1133.81,1406.88 1133.82,1406.88 1133.83,1406.88 1133.84,1406.88 1133.85,1406.88 1133.86,1406.88 1133.87,1406.88 1133.88,1406.88 1133.89,1406.88 1133.89,1406.88 1133.9,1406.88 1133.91,1406.88 1133.92,1406.88 1133.93,1406.88 1133.94,1406.88 1133.95,1406.88 1133.96,1406.88 1133.97,1406.88 1133.98,1406.88 1133.99,1406.88 1134,1406.88 1134,1406.88 1134.01,1406.88 1134.02,1406.88 1134.03,1406.88 1134.04,1406.88 1134.05,1406.88 1134.06,1406.88 1134.07,1406.88 1134.08,1406.88 1134.09,1406.88 1134.1,1406.88 1134.11,1406.88 1134.11,1406.88 1134.12,1406.88 1134.13,1406.88 1134.14,1406.88 1134.15,1406.88 1134.16,1406.88 1134.17,1406.88 1134.18,1406.88 1134.19,1406.88 1134.2,1406.88 1134.21,1406.88 1134.22,1406.88 1134.23,1406.88 1134.23,1406.88 1134.24,1406.88 1134.25,1406.88 1134.26,1406.88 1134.27,1406.88 1134.28,1406.88 1134.29,1406.88 1134.3,1406.88 1134.31,1406.88 1134.32,1406.88 1134.33,1406.88 1134.34,1406.88 1134.34,1406.88 1134.35,1406.88 1134.36,1406.88 1134.37,1406.88 1134.38,1406.88 1134.39,1406.88 1134.4,1406.88 1134.41,1406.88 1134.42,1406.88 1134.43,1406.88 1134.44,1406.88 1134.45,1406.88 1134.45,1406.88 1134.46,1406.88 1134.47,1406.88 1134.48,1406.88 1134.49,1406.88 1134.5,1406.88 1134.51,1406.88 1134.52,1406.88 1134.53,1406.88 1134.54,1406.88 1134.55,1406.88 1134.56,1406.88 1134.57,1406.88 1134.57,1406.88 1134.58,1406.88 1134.59,1406.88 1134.6,1406.88 1134.61,1406.88 1134.62,1406.88 1134.63,1406.88 1134.64,1406.88 1134.65,1406.88 1134.66,1406.88 1134.67,1406.88 1134.68,1406.88 1134.68,1406.88 1134.69,1406.88 1134.7,1406.88 1134.71,1406.88 1134.72,1406.88 1134.73,1406.88 1134.74,1406.88 1134.75,1406.88 1134.76,1406.88 1134.77,1406.88 1134.78,1406.88 1134.79,1406.88 1134.79,1406.88 1134.8,1406.88 1134.81,1406.88 1134.82,1406.88 1134.83,1406.88 1134.84,1406.88 1134.85,1406.88 1134.86,1406.88 1134.87,1406.88 1134.88,1406.88 1134.89,1406.88 1134.9,1406.88 1134.91,1406.88 1134.91,1406.88 1134.92,1406.88 1134.93,1406.88 1134.94,1406.88 1134.95,1406.88 1134.96,1406.88 1134.97,1406.88 1134.98,1406.88 1134.99,1406.88 1135,1406.88 1135.01,1406.88 1135.02,1406.88 1135.02,1406.88 1135.03,1406.88 1135.04,1406.88 1135.05,1406.88 1135.06,1406.88 1135.07,1406.88 1135.08,1406.88 1135.09,1406.88 1135.1,1406.88 1135.11,1406.88 1135.12,1406.88 1135.13,1406.88 1135.13,1406.88 1135.14,1406.88 1135.15,1406.88 1135.16,1406.88 1135.17,1406.88 1135.18,1406.88 1135.19,1406.88 1135.2,1406.88 1135.21,1406.88 1135.22,1406.88 1135.23,1406.88 1135.24,1406.88 1135.25,1406.88 1135.25,1406.88 1135.26,1406.88 1135.27,1406.88 1135.28,1406.88 1135.29,1406.88 1135.3,1406.88 1135.31,1406.88 1135.32,1406.88 1135.33,1406.88 1135.34,1406.88 1135.35,1406.88 1135.36,1406.88 1135.36,1406.88 1135.37,1406.88 1135.38,1406.88 1135.39,1406.88 1135.4,1406.88 1135.41,1406.88 1135.42,1406.88 1135.43,1406.88 1135.44,1406.88 1135.45,1406.88 1135.46,1406.88 1135.47,1406.88 1135.47,1406.88 1135.48,1406.88 1135.49,1406.88 1135.5,1406.88 1135.51,1406.88 1135.52,1406.88 1135.53,1406.88 1135.54,1406.88 1135.55,1406.88 1135.56,1406.88 1135.57,1406.88 1135.58,1406.88 1135.59,1406.88 1135.59,1406.88 1135.6,1406.88 1135.61,1406.88 1135.62,1406.88 1135.63,1406.88 1135.64,1406.88 1135.65,1406.88 1135.66,1406.88 1135.67,1406.88 1135.68,1406.88 1135.69,1406.88 1135.7,1406.88 1135.7,1406.88 1135.71,1406.88 1135.72,1406.88 1135.73,1406.88 1135.74,1406.88 1135.75,1406.88 1135.76,1406.88 1135.77,1406.88 1135.78,1406.88 1135.79,1406.88 1135.8,1406.88 1135.81,1406.88 1135.81,1406.88 1135.82,1406.88 1135.83,1406.88 1135.84,1406.88 1135.85,1406.88 1135.86,1406.88 1135.87,1406.88 1135.88,1406.88 1135.89,1406.88 1135.9,1406.88 1135.91,1406.88 1135.92,1406.88 1135.93,1406.88 1135.93,1406.88 1135.94,1406.88 1135.95,1406.88 1135.96,1406.88 1135.97,1406.88 1135.98,1406.88 1135.99,1406.88 1136,1406.88 1136.01,1406.88 1136.02,1406.88 1136.03,1406.88 1136.04,1406.88 1136.04,1406.88 1136.05,1406.88 1136.06,1406.88 1136.07,1406.88 1136.08,1406.88 1136.09,1406.88 1136.1,1406.88 1136.11,1406.88 1136.12,1406.88 1136.13,1406.88 1136.14,1406.88 1136.15,1406.88 1136.15,1406.88 1136.16,1406.88 1136.17,1406.88 1136.18,1406.88 1136.19,1406.88 1136.2,1406.88 1136.21,1406.88 1136.22,1406.88 1136.23,1406.88 1136.24,1406.88 1136.25,1406.88 1136.26,1406.88 1136.27,1406.88 1136.27,1406.88 1136.28,1406.88 1136.29,1406.88 1136.3,1406.88 1136.31,1406.88 1136.32,1406.88 1136.33,1406.88 1136.34,1406.88 1136.35,1406.88 1136.36,1406.88 1136.37,1406.88 1136.38,1406.88 1136.38,1406.88 1136.39,1406.88 1136.4,1406.88 1136.41,1406.88 1136.42,1406.88 1136.43,1406.88 1136.44,1406.88 1136.45,1406.88 1136.46,1406.88 1136.47,1406.88 1136.48,1406.88 1136.49,1406.88 1136.49,1406.88 1136.5,1406.88 1136.51,1406.88 1136.52,1406.88 1136.53,1406.88 1136.54,1406.88 1136.55,1406.88 1136.56,1406.88 1136.57,1406.88 1136.58,1406.88 1136.59,1406.88 1136.6,1406.88 1136.61,1406.88 1136.61,1406.88 1136.62,1406.88 1136.63,1406.88 1136.64,1406.88 1136.65,1406.88 1136.66,1406.88 1136.67,1406.88 1136.68,1406.88 1136.69,1406.88 1136.7,1406.88 1136.71,1406.88 1136.72,1406.88 1136.72,1406.88 1136.73,1406.88 1136.74,1406.88 1136.75,1406.88 1136.76,1406.88 1136.77,1406.88 1136.78,1406.88 1136.79,1406.88 1136.8,1406.88 1136.81,1406.88 1136.82,1406.88 1136.83,1406.88 1136.83,1406.88 1136.84,1406.88 1136.85,1406.88 1136.86,1406.88 1136.87,1406.88 1136.88,1406.88 1136.89,1406.88 1136.9,1406.88 1136.91,1406.88 1136.92,1406.88 1136.93,1406.88 1136.94,1406.88 1136.95,1406.88 1136.95,1406.88 1136.96,1406.88 1136.97,1406.88 1136.98,1406.88 1136.99,1406.88 1137,1406.88 1137.01,1406.88 1137.02,1406.88 1137.03,1406.88 1137.04,1406.88 1137.05,1406.88 1137.06,1406.88 1137.06,1406.88 1137.07,1406.88 1137.08,1406.88 1137.09,1406.88 1137.1,1406.88 1137.11,1406.88 1137.12,1406.88 1137.13,1406.88 1137.14,1406.88 1137.15,1406.88 1137.16,1406.88 1137.17,1406.88 1137.17,1406.88 1137.18,1406.88 1137.19,1406.88 1137.2,1406.88 1137.21,1406.88 1137.22,1406.88 1137.23,1406.88 1137.24,1406.88 1137.25,1406.88 1137.26,1406.88 1137.27,1406.88 1137.28,1406.88 1137.29,1406.88 1137.29,1406.88 1137.3,1406.88 1137.31,1406.88 1137.32,1406.88 1137.33,1406.88 1137.34,1406.88 1137.35,1406.88 1137.36,1406.88 1137.37,1406.88 1137.38,1406.88 1137.39,1406.88 1137.4,1406.88 1137.4,1406.88 1137.41,1406.88 1137.42,1406.88 1137.43,1406.88 1137.44,1406.88 1137.45,1406.88 1137.46,1406.88 1137.47,1406.88 1137.48,1406.88 1137.49,1406.88 1137.5,1406.88 1137.51,1406.88 1137.51,1406.88 1137.52,1406.88 1137.53,1406.88 1137.54,1406.88 1137.55,1406.88 1137.56,1406.88 1137.57,1406.88 1137.58,1406.88 1137.59,1406.88 1137.6,1406.88 1137.61,1406.88 1137.62,1406.88 1137.63,1406.88 1137.63,1406.88 1137.64,1406.88 1137.65,1406.88 1137.66,1406.88 1137.67,1406.88 1137.68,1406.88 1137.69,1406.88 1137.7,1406.88 1137.71,1406.88 1137.72,1406.88 1137.73,1406.88 1137.74,1406.88 1137.74,1406.88 1137.75,1406.88 1137.76,1406.88 1137.77,1406.88 1137.78,1406.88 1137.79,1406.88 1137.8,1406.88 1137.81,1406.88 1137.82,1406.88 1137.83,1406.88 1137.84,1406.88 1137.85,1406.88 1137.85,1406.88 1137.86,1406.88 1137.87,1406.88 1137.88,1406.88 1137.89,1406.88 1137.9,1406.88 1137.91,1406.88 1137.92,1406.88 1137.93,1406.88 1137.94,1406.88 1137.95,1406.88 1137.96,1406.88 1137.97,1406.88 1137.97,1406.88 1137.98,1406.88 1137.99,1406.88 1138,1406.88 1138.01,1406.88 1138.02,1406.88 1138.03,1406.88 1138.04,1406.88 1138.05,1406.88 1138.06,1406.88 1138.07,1406.88 1138.08,1406.88 1138.08,1406.88 1138.09,1406.88 1138.1,1406.88 1138.11,1406.88 1138.12,1406.88 1138.13,1406.88 1138.14,1406.88 1138.15,1406.88 1138.16,1406.88 1138.17,1406.88 1138.18,1406.88 1138.19,1406.88 1138.19,1406.88 1138.2,1406.88 1138.21,1406.88 1138.22,1406.88 1138.23,1406.88 1138.24,1406.88 1138.25,1406.88 1138.26,1406.88 1138.27,1406.88 1138.28,1406.88 1138.29,1406.88 1138.3,1406.88 1138.31,1406.88 1138.31,1406.88 1138.32,1406.88 1138.33,1406.88 1138.34,1406.88 1138.35,1406.88 1138.36,1406.88 1138.37,1406.88 1138.38,1406.88 1138.39,1406.88 1138.4,1406.88 1138.41,1406.88 1138.42,1406.88 1138.42,1406.88 1138.43,1406.88 1138.44,1406.88 1138.45,1406.88 1138.46,1406.88 1138.47,1406.88 1138.48,1406.88 1138.49,1406.88 1138.5,1406.88 1138.51,1406.88 1138.52,1406.88 1138.53,1406.88 1138.53,1406.88 1138.54,1406.88 1138.55,1406.88 1138.56,1406.88 1138.57,1406.88 1138.58,1406.88 1138.59,1406.88 1138.6,1406.88 1138.61,1406.88 1138.62,1406.88 1138.63,1406.88 1138.64,1406.88 1138.65,1406.88 1138.65,1406.88 1138.66,1406.88 1138.67,1406.88 1138.68,1406.88 1138.69,1406.88 1138.7,1406.88 1138.71,1406.88 1138.72,1406.88 1138.73,1406.88 1138.74,1406.88 1138.75,1406.88 1138.76,1406.88 1138.76,1406.88 1138.77,1406.88 1138.78,1406.88 1138.79,1406.88 1138.8,1406.88 1138.81,1406.88 1138.82,1406.88 1138.83,1406.88 1138.84,1406.88 1138.85,1406.88 1138.86,1406.88 1138.87,1406.88 1138.87,1406.88 1138.88,1406.88 1138.89,1406.88 1138.9,1406.88 1138.91,1406.88 1138.92,1406.88 1138.93,1406.88 1138.94,1406.88 1138.95,1406.88 1138.96,1406.88 1138.97,1406.88 1138.98,1406.88 1138.99,1406.88 1138.99,1406.88 1139,1406.88 1139.01,1406.88 1139.02,1406.88 1139.03,1406.88 1139.04,1406.88 1139.05,1406.88 1139.06,1406.88 1139.07,1406.88 1139.08,1406.88 1139.09,1406.88 1139.1,1406.88 1139.1,1406.88 1139.11,1406.88 1139.12,1406.88 1139.13,1406.88 1139.14,1406.88 1139.15,1406.88 1139.16,1406.88 1139.17,1406.88 1139.18,1406.88 1139.19,1406.88 1139.2,1406.88 1139.21,1406.88 1139.21,1406.88 1139.22,1406.88 1139.23,1406.88 1139.24,1406.88 1139.25,1406.88 1139.26,1406.88 1139.27,1406.88 1139.28,1406.88 1139.29,1406.88 1139.3,1406.88 1139.31,1406.88 1139.32,1406.88 1139.33,1406.88 1139.33,1406.88 1139.34,1406.88 1139.35,1406.88 1139.36,1406.88 1139.37,1406.88 1139.38,1406.88 1139.39,1406.88 1139.4,1406.88 1139.41,1406.88 1139.42,1406.88 1139.43,1406.88 1139.44,1406.88 1139.44,1406.88 1139.45,1406.88 1139.46,1406.88 1139.47,1406.88 1139.48,1406.88 1139.49,1406.88 1139.5,1406.88 1139.51,1406.88 1139.52,1406.88 1139.53,1406.88 1139.54,1406.88 1139.55,1406.88 1139.55,1406.88 1139.56,1406.88 1139.57,1406.88 1139.58,1406.88 1139.59,1406.88 1139.6,1406.88 1139.61,1406.88 1139.62,1406.88 1139.63,1406.88 1139.64,1406.88 1139.65,1406.88 1139.66,1406.88 1139.67,1406.88 1139.67,1406.88 1139.68,1406.88 1139.69,1406.88 1139.7,1406.88 1139.71,1406.88 1139.72,1406.88 1139.73,1406.88 1139.74,1406.88 1139.75,1406.88 1139.76,1406.88 1139.77,1406.88 1139.78,1406.88 1139.78,1406.88 1139.79,1406.88 1139.8,1406.88 1139.81,1406.88 1139.82,1406.88 1139.83,1406.88 1139.84,1406.88 1139.85,1406.88 1139.86,1406.88 1139.87,1406.88 1139.88,1406.88 1139.89,1406.88 1139.89,1406.88 1139.9,1406.88 1139.91,1406.88 1139.92,1406.88 1139.93,1406.88 1139.94,1406.88 1139.95,1406.88 1139.96,1406.88 1139.97,1406.88 1139.98,1406.88 1139.99,1406.88 1140,1406.88 1140.01,1406.88 1140.01,1406.88 1140.02,1406.88 1140.03,1406.88 1140.04,1406.88 1140.05,1406.88 1140.06,1406.88 1140.07,1406.88 1140.08,1406.88 1140.09,1406.88 1140.1,1406.88 1140.11,1406.88 1140.12,1406.88 1140.12,1406.88 1140.13,1406.88 1140.14,1406.88 1140.15,1406.88 1140.16,1406.88 1140.17,1406.88 1140.18,1406.88 1140.19,1406.88 1140.2,1406.88 1140.21,1406.88 1140.22,1406.88 1140.23,1406.88 1140.23,1406.88 1140.24,1406.88 1140.25,1406.88 1140.26,1406.88 1140.27,1406.88 1140.28,1406.88 1140.29,1406.88 1140.3,1406.88 1140.31,1406.88 1140.32,1406.88 1140.33,1406.88 1140.34,1406.88 1140.35,1406.88 1140.35,1406.88 1140.36,1406.88 1140.37,1406.88 1140.38,1406.88 1140.39,1406.88 1140.4,1406.88 1140.41,1406.88 1140.42,1406.88 1140.43,1406.88 1140.44,1406.88 1140.45,1406.88 1140.46,1406.88 1140.46,1406.88 1140.47,1406.88 1140.48,1406.88 1140.49,1406.88 1140.5,1406.88 1140.51,1406.88 1140.52,1406.88 1140.53,1406.88 1140.54,1406.88 1140.55,1406.88 1140.56,1406.88 1140.57,1406.88 1140.57,1406.88 1140.58,1406.88 1140.59,1406.88 1140.6,1406.88 1140.61,1406.88 1140.62,1406.88 1140.63,1406.88 1140.64,1406.88 1140.65,1406.88 1140.66,1406.88 1140.67,1406.88 1140.68,1406.88 1140.69,1406.88 1140.69,1406.88 1140.7,1406.88 1140.71,1406.88 1140.72,1406.88 1140.73,1406.88 1140.74,1406.88 1140.75,1406.88 1140.76,1406.88 1140.77,1406.88 1140.78,1406.88 1140.79,1406.88 1140.8,1406.88 1140.8,1406.88 1140.81,1406.88 1140.82,1406.88 1140.83,1406.88 1140.84,1406.88 1140.85,1406.88 1140.86,1406.88 1140.87,1406.88 1140.88,1406.88 1140.89,1406.88 1140.9,1406.88 1140.91,1406.88 1140.91,1406.88 1140.92,1406.88 1140.93,1406.88 1140.94,1406.88 1140.95,1406.88 1140.96,1406.88 1140.97,1406.88 1140.98,1406.88 1140.99,1406.88 1141,1406.88 1141.01,1406.88 1141.02,1406.88 1141.03,1406.88 1141.03,1406.88 1141.04,1406.88 1141.05,1406.88 1141.06,1406.88 1141.07,1406.88 1141.08,1406.88 1141.09,1406.88 1141.1,1406.88 1141.11,1406.88 1141.12,1406.88 1141.13,1406.88 1141.14,1406.88 1141.14,1406.88 1141.15,1406.88 1141.16,1406.88 1141.17,1406.88 1141.18,1406.88 1141.19,1406.88 1141.2,1406.88 1141.21,1406.88 1141.22,1406.88 1141.23,1406.88 1141.24,1406.88 1141.25,1406.88 1141.25,1406.88 1141.26,1406.88 1141.27,1406.88 1141.28,1406.88 1141.29,1406.88 1141.3,1406.88 1141.31,1406.88 1141.32,1406.88 1141.33,1406.88 1141.34,1406.88 1141.35,1406.88 1141.36,1406.88 1141.37,1406.88 1141.37,1406.88 1141.38,1406.88 1141.39,1406.88 1141.4,1406.88 1141.41,1406.88 1141.42,1406.88 1141.43,1406.88 1141.44,1406.88 1141.45,1406.88 1141.46,1406.88 1141.47,1406.88 1141.48,1406.88 1141.48,1406.88 1141.49,1406.88 1141.5,1406.88 1141.51,1406.88 1141.52,1406.88 1141.53,1406.88 1141.54,1406.88 1141.55,1406.88 1141.56,1406.88 1141.57,1406.88 1141.58,1406.88 1141.59,1406.88 1141.59,1406.88 1141.6,1406.88 1141.61,1406.88 1141.62,1406.88 1141.63,1406.88 1141.64,1406.88 1141.65,1406.88 1141.66,1406.88 1141.67,1406.88 1141.68,1406.88 1141.69,1406.88 1141.7,1406.88 1141.71,1406.88 1141.71,1406.88 1141.72,1406.88 1141.73,1406.88 1141.74,1406.88 1141.75,1406.88 1141.76,1406.88 1141.77,1406.88 1141.78,1406.88 1141.79,1406.88 1141.8,1406.88 1141.81,1406.88 1141.82,1406.88 1141.82,1406.88 1141.83,1406.88 1141.84,1406.88 1141.85,1406.88 1141.86,1406.88 1141.87,1406.88 1141.88,1406.88 1141.89,1406.88 1141.9,1406.88 1141.91,1406.88 1141.92,1406.88 1141.93,1406.88 1141.93,1406.88 1141.94,1406.88 1141.95,1406.88 1141.96,1406.88 1141.97,1406.88 1141.98,1406.88 1141.99,1406.88 1142,1406.88 1142.01,1406.88 1142.02,1406.88 1142.03,1406.88 1142.04,1406.88 1142.05,1406.88 1142.05,1406.88 1142.06,1406.88 1142.07,1406.88 1142.08,1406.88 1142.09,1406.88 1142.1,1406.88 1142.11,1406.88 1142.12,1406.88 1142.13,1406.88 1142.14,1406.88 1142.15,1406.88 1142.16,1406.88 1142.16,1406.88 1142.17,1406.88 1142.18,1406.88 1142.19,1406.88 1142.2,1406.88 1142.21,1406.88 1142.22,1406.88 1142.23,1406.88 1142.24,1406.88 1142.25,1406.88 1142.26,1406.88 1142.27,1406.88 1142.27,1406.88 1142.28,1406.88 1142.29,1406.88 1142.3,1406.88 1142.31,1406.88 1142.32,1406.88 1142.33,1406.88 1142.34,1406.88 1142.35,1406.88 1142.36,1406.88 1142.37,1406.88 1142.38,1406.88 1142.39,1406.88 1142.39,1406.88 1142.4,1406.88 1142.41,1406.88 1142.42,1406.88 1142.43,1406.88 1142.44,1406.88 1142.45,1406.88 1142.46,1406.88 1142.47,1406.88 1142.48,1406.88 1142.49,1406.88 1142.5,1406.88 1142.5,1406.88 1142.51,1406.88 1142.52,1406.88 1142.53,1406.88 1142.54,1406.88 1142.55,1406.88 1142.56,1406.88 1142.57,1406.88 1142.58,1406.88 1142.59,1406.88 1142.6,1406.88 1142.61,1406.88 1142.61,1406.88 1142.62,1406.88 1142.63,1406.88 1142.64,1406.88 1142.65,1406.88 1142.66,1406.88 1142.67,1406.88 1142.68,1406.88 1142.69,1406.88 1142.7,1406.88 1142.71,1406.88 1142.72,1406.88 1142.73,1406.88 1142.73,1406.88 1142.74,1406.88 1142.75,1406.88 1142.76,1406.88 1142.77,1406.88 1142.78,1406.88 1142.79,1406.88 1142.8,1406.88 1142.81,1406.88 1142.82,1406.88 1142.83,1406.88 1142.84,1406.88 1142.84,1406.88 1142.85,1406.88 1142.86,1406.88 1142.87,1406.88 1142.88,1406.88 1142.89,1406.88 1142.9,1406.88 1142.91,1406.88 1142.92,1406.88 1142.93,1406.88 1142.94,1406.88 1142.95,1406.88 1142.95,1406.88 1142.96,1406.88 1142.97,1406.88 1142.98,1406.88 1142.99,1406.88 1143,1406.88 1143.01,1406.88 1143.02,1406.88 1143.03,1406.88 1143.04,1406.88 1143.05,1406.88 1143.06,1406.88 1143.07,1406.88 1143.07,1406.88 1143.08,1406.88 1143.09,1406.88 1143.1,1406.88 1143.11,1406.88 1143.12,1406.88 1143.13,1406.88 1143.14,1406.88 1143.15,1406.88 1143.16,1406.88 1143.17,1406.88 1143.18,1406.88 1143.18,1406.88 1143.19,1406.88 1143.2,1406.88 1143.21,1406.88 1143.22,1406.88 1143.23,1406.88 1143.24,1406.88 1143.25,1406.88 1143.26,1406.88 1143.27,1406.88 1143.28,1406.88 1143.29,1406.88 1143.29,1406.88 1143.3,1406.88 1143.31,1406.88 1143.32,1406.88 1143.33,1406.88 1143.34,1406.88 1143.35,1406.88 1143.36,1406.88 1143.37,1406.88 1143.38,1406.88 1143.39,1406.88 1143.4,1406.88 1143.41,1406.88 1143.41,1406.88 1143.42,1406.88 1143.43,1406.88 1143.44,1406.88 1143.45,1406.88 1143.46,1406.88 1143.47,1406.88 1143.48,1406.88 1143.49,1406.88 1143.5,1406.88 1143.51,1406.88 1143.52,1406.88 1143.52,1406.88 1143.53,1406.88 1143.54,1406.88 1143.55,1406.88 1143.56,1406.88 1143.57,1406.88 1143.58,1406.88 1143.59,1406.88 1143.6,1406.88 1143.61,1406.88 1143.62,1406.88 1143.63,1406.88 1143.63,1406.88 1143.64,1406.88 1143.65,1406.88 1143.66,1406.88 1143.67,1406.88 1143.68,1406.88 1143.69,1406.88 1143.7,1406.88 1143.71,1406.88 1143.72,1406.88 1143.73,1406.88 1143.74,1406.88 1143.75,1406.88 1143.75,1406.88 1143.76,1406.88 1143.77,1406.88 1143.78,1406.88 1143.79,1406.88 1143.8,1406.88 1143.81,1406.88 1143.82,1406.88 1143.83,1406.88 1143.84,1406.88 1143.85,1406.88 1143.86,1406.88 1143.86,1406.88 1143.87,1406.88 1143.88,1406.88 1143.89,1406.88 1143.9,1406.88 1143.91,1406.88 1143.92,1406.88 1143.93,1406.88 1143.94,1406.88 1143.95,1406.88 1143.96,1406.88 1143.97,1406.88 1143.97,1406.88 1143.98,1406.88 1143.99,1406.88 1144,1406.88 1144.01,1406.88 1144.02,1406.88 1144.03,1406.88 1144.04,1406.88 1144.05,1406.88 1144.06,1406.88 1144.07,1406.88 1144.08,1406.88 1144.09,1406.88 1144.09,1406.88 1144.1,1406.88 1144.11,1406.88 1144.12,1406.88 1144.13,1406.88 1144.14,1406.88 1144.15,1406.88 1144.16,1406.88 1144.17,1406.88 1144.18,1406.88 1144.19,1406.88 1144.2,1406.88 1144.2,1406.88 1144.21,1406.88 1144.22,1406.88 1144.23,1406.88 1144.24,1406.88 1144.25,1406.88 1144.26,1406.88 1144.27,1406.88 1144.28,1406.88 1144.29,1406.88 1144.3,1406.88 1144.31,1406.88 1144.31,1406.88 1144.32,1406.88 1144.33,1406.88 1144.34,1406.88 1144.35,1406.88 1144.36,1406.88 1144.37,1406.88 1144.38,1406.88 1144.39,1406.88 1144.4,1406.88 1144.41,1406.88 1144.42,1406.88 1144.43,1406.88 1144.43,1406.88 1144.44,1406.88 1144.45,1406.88 1144.46,1406.88 1144.47,1406.88 1144.48,1406.88 1144.49,1406.88 1144.5,1406.88 1144.51,1406.88 1144.52,1406.88 1144.53,1406.88 1144.54,1406.88 1144.54,1406.88 1144.55,1406.88 1144.56,1406.88 1144.57,1406.88 1144.58,1406.88 1144.59,1406.88 1144.6,1406.88 1144.61,1406.88 1144.62,1406.88 1144.63,1406.88 1144.64,1406.88 1144.65,1406.88 1144.65,1406.88 1144.66,1406.88 1144.67,1406.88 1144.68,1406.88 1144.69,1406.88 1144.7,1406.88 1144.71,1406.88 1144.72,1406.88 1144.73,1406.88 1144.74,1406.88 1144.75,1406.88 1144.76,1406.88 1144.77,1406.88 1144.77,1406.88 1144.78,1406.88 1144.79,1406.88 1144.8,1406.88 1144.81,1406.88 1144.82,1406.88 1144.83,1406.88 1144.84,1406.88 1144.85,1406.88 1144.86,1406.88 1144.87,1406.88 1144.88,1406.88 1144.88,1406.88 1144.89,1406.88 1144.9,1406.88 1144.91,1406.88 1144.92,1406.88 1144.93,1406.88 1144.94,1406.88 1144.95,1406.88 1144.96,1406.88 1144.97,1406.88 1144.98,1406.88 1144.99,1406.88 1144.99,1406.88 1145,1406.88 1145.01,1406.88 1145.02,1406.88 1145.03,1406.88 1145.04,1406.88 1145.05,1406.88 1145.06,1406.88 1145.07,1406.88 1145.08,1406.88 1145.09,1406.88 1145.1,1406.88 1145.11,1406.88 1145.11,1406.88 1145.12,1406.88 1145.13,1406.88 1145.14,1406.88 1145.15,1406.88 1145.16,1406.88 1145.17,1406.88 1145.18,1406.88 1145.19,1406.88 1145.2,1406.88 1145.21,1406.88 1145.22,1406.88 1145.22,1406.88 1145.23,1406.88 1145.24,1406.88 1145.25,1406.88 1145.26,1406.88 1145.27,1406.88 1145.28,1406.88 1145.29,1406.88 1145.3,1406.88 1145.31,1406.88 1145.32,1406.88 1145.33,1406.88 1145.33,1406.88 1145.34,1406.88 1145.35,1406.88 1145.36,1406.88 1145.37,1406.88 1145.38,1406.88 1145.39,1406.88 1145.4,1406.88 1145.41,1406.88 1145.42,1406.88 1145.43,1406.88 1145.44,1406.88 1145.45,1406.88 1145.45,1406.88 1145.46,1406.88 1145.47,1406.88 1145.48,1406.88 1145.49,1406.88 1145.5,1406.88 1145.51,1406.88 1145.52,1406.88 1145.53,1406.88 1145.54,1406.88 1145.55,1406.88 1145.56,1406.88 1145.56,1406.88 1145.57,1406.88 1145.58,1406.88 1145.59,1406.88 1145.6,1406.88 1145.61,1406.88 1145.62,1406.88 1145.63,1406.88 1145.64,1406.88 1145.65,1406.88 1145.66,1406.88 1145.67,1406.88 1145.67,1406.88 1145.68,1406.88 1145.69,1406.88 1145.7,1406.88 1145.71,1406.88 1145.72,1406.88 1145.73,1406.88 1145.74,1406.88 1145.75,1406.88 1145.76,1406.88 1145.77,1406.88 1145.78,1406.88 1145.79,1406.88 1145.79,1406.88 1145.8,1406.88 1145.81,1406.88 1145.82,1406.88 1145.83,1406.88 1145.84,1406.88 1145.85,1406.88 1145.86,1406.88 1145.87,1406.88 1145.88,1406.88 1145.89,1406.88 1145.9,1406.88 1145.9,1406.88 1145.91,1406.88 1145.92,1406.88 1145.93,1406.88 1145.94,1406.88 1145.95,1406.88 1145.96,1406.88 1145.97,1406.88 1145.98,1406.88 1145.99,1406.88 1146,1406.88 1146.01,1406.88 1146.01,1406.88 1146.02,1406.88 1146.03,1406.88 1146.04,1406.88 1146.05,1406.88 1146.06,1406.88 1146.07,1406.88 1146.08,1406.88 1146.09,1406.88 1146.1,1406.88 1146.11,1406.88 1146.12,1406.88 1146.13,1406.88 1146.13,1406.88 1146.14,1406.88 1146.15,1406.88 1146.16,1406.88 1146.17,1406.88 1146.18,1406.88 1146.19,1406.88 1146.2,1406.88 1146.21,1406.88 1146.22,1406.88 1146.23,1406.88 1146.24,1406.88 1146.24,1406.88 1146.25,1406.88 1146.26,1406.88 1146.27,1406.88 1146.28,1406.88 1146.29,1406.88 1146.3,1406.88 1146.31,1406.88 1146.32,1406.88 1146.33,1406.88 1146.34,1406.88 1146.35,1406.88 1146.36,1406.88 1146.36,1406.88 1146.37,1406.88 1146.38,1406.88 1146.39,1406.88 1146.4,1406.88 1146.41,1406.88 1146.42,1406.88 1146.43,1406.88 1146.44,1406.88 1146.45,1406.88 1146.46,1406.88 1146.47,1406.88 1146.47,1406.88 1146.48,1406.88 1146.49,1406.88 1146.5,1406.88 1146.51,1406.88 1146.52,1406.88 1146.53,1406.88 1146.54,1406.88 1146.55,1406.88 1146.56,1406.88 1146.57,1406.88 1146.58,1406.88 1146.58,1406.88 1146.59,1406.88 1146.6,1406.88 1146.61,1406.88 1146.62,1406.88 1146.63,1406.88 1146.64,1406.88 1146.65,1406.88 1146.66,1406.88 1146.67,1406.88 1146.68,1406.88 1146.69,1406.88 1146.7,1406.88 1146.7,1406.88 1146.71,1406.88 1146.72,1406.88 1146.73,1406.88 1146.74,1406.88 1146.75,1406.88 1146.76,1406.88 1146.77,1406.88 1146.78,1406.88 1146.79,1406.88 1146.8,1406.88 1146.81,1406.88 1146.81,1406.88 1146.82,1406.88 1146.83,1406.88 1146.84,1406.88 1146.85,1406.88 1146.86,1406.88 1146.87,1406.88 1146.88,1406.88 1146.89,1406.88 1146.9,1406.88 1146.91,1406.88 1146.92,1406.88 1146.92,1406.88 1146.93,1406.88 1146.94,1406.88 1146.95,1406.88 1146.96,1406.88 1146.97,1406.88 1146.98,1406.88 1146.99,1406.88 1147,1406.88 1147.01,1406.88 1147.02,1406.88 1147.03,1406.88 1147.04,1406.88 1147.04,1406.88 1147.05,1406.88 1147.06,1406.88 1147.07,1406.88 1147.08,1406.88 1147.09,1406.88 1147.1,1406.88 1147.11,1406.88 1147.12,1406.88 1147.13,1406.88 1147.14,1406.88 1147.15,1406.88 1147.15,1406.88 1147.16,1406.88 1147.17,1406.88 1147.18,1406.88 1147.19,1406.88 1147.2,1406.88 1147.21,1406.88 1147.22,1406.88 1147.23,1406.88 1147.24,1406.88 1147.25,1406.88 1147.26,1406.88 1147.26,1406.88 1147.27,1406.88 1147.28,1406.88 1147.29,1406.88 1147.3,1406.88 1147.31,1406.88 1147.32,1406.88 1147.33,1406.88 1147.34,1406.88 1147.35,1406.88 1147.36,1406.88 1147.37,1406.88 1147.38,1406.88 1147.38,1406.88 1147.39,1406.88 1147.4,1406.88 1147.41,1406.88 1147.42,1406.88 1147.43,1406.88 1147.44,1406.88 1147.45,1406.88 1147.46,1406.88 1147.47,1406.88 1147.48,1406.88 1147.49,1406.88 1147.49,1406.88 1147.5,1406.88 1147.51,1406.88 1147.52,1406.88 1147.53,1406.88 1147.54,1406.88 1147.55,1406.88 1147.56,1406.88 1147.57,1406.88 1147.58,1406.88 1147.59,1406.88 1147.6,1406.88 1147.6,1406.88 1147.61,1406.88 1147.62,1406.88 1147.63,1406.88 1147.64,1406.88 1147.65,1406.88 1147.66,1406.88 1147.67,1406.88 1147.68,1406.88 1147.69,1406.88 1147.7,1406.88 1147.71,1406.88 1147.72,1406.88 1147.72,1406.88 1147.73,1406.88 1147.74,1406.88 1147.75,1406.88 1147.76,1406.88 1147.77,1406.88 1147.78,1406.88 1147.79,1406.88 1147.8,1406.88 1147.81,1406.88 1147.82,1406.88 1147.83,1406.88 1147.83,1406.88 1147.84,1406.88 1147.85,1406.88 1147.86,1406.88 1147.87,1406.88 1147.88,1406.88 1147.89,1406.88 1147.9,1406.88 1147.91,1406.88 1147.92,1406.88 1147.93,1406.88 1147.94,1406.88 1147.94,1406.88 1147.95,1406.88 1147.96,1406.88 1147.97,1406.88 1147.98,1406.88 1147.99,1406.88 1148,1406.88 1148.01,1406.88 1148.02,1406.88 1148.03,1406.88 1148.04,1406.88 1148.05,1406.88 1148.06,1406.88 1148.06,1406.88 1148.07,1406.88 1148.08,1406.88 1148.09,1406.88 1148.1,1406.88 1148.11,1406.88 1148.12,1406.88 1148.13,1406.88 1148.14,1406.88 1148.15,1406.88 1148.16,1406.88 1148.17,1406.88 1148.17,1406.88 1148.18,1406.88 1148.19,1406.88 1148.2,1406.88 1148.21,1406.88 1148.22,1406.88 1148.23,1406.88 1148.24,1406.88 1148.25,1406.88 1148.26,1406.88 1148.27,1406.88 1148.28,1406.88 1148.28,1406.88 1148.29,1406.88 1148.3,1406.88 1148.31,1406.88 1148.32,1406.88 1148.33,1406.88 1148.34,1406.88 1148.35,1406.88 1148.36,1406.88 1148.37,1406.88 1148.38,1406.88 1148.39,1406.88 1148.4,1406.88 1148.4,1406.88 1148.41,1406.88 1148.42,1406.88 1148.43,1406.88 1148.44,1406.88 1148.45,1406.88 1148.46,1406.88 1148.47,1406.88 1148.48,1406.88 1148.49,1406.88 1148.5,1406.88 1148.51,1406.88 1148.51,1406.88 1148.52,1406.88 1148.53,1406.88 1148.54,1406.88 1148.55,1406.88 1148.56,1406.88 1148.57,1406.88 1148.58,1406.88 1148.59,1406.88 1148.6,1406.88 1148.61,1406.88 1148.62,1406.88 1148.62,1406.88 1148.63,1406.88 1148.64,1406.88 1148.65,1406.88 1148.66,1406.88 1148.67,1406.88 1148.68,1406.88 1148.69,1406.88 1148.7,1406.88 1148.71,1406.88 1148.72,1406.88 1148.73,1406.88 1148.74,1406.88 1148.74,1406.88 1148.75,1406.88 1148.76,1406.88 1148.77,1406.88 1148.78,1406.88 1148.79,1406.88 1148.8,1406.88 1148.81,1406.88 1148.82,1406.88 1148.83,1406.88 1148.84,1406.88 1148.85,1406.88 1148.85,1406.88 1148.86,1406.88 1148.87,1406.88 1148.88,1406.88 1148.89,1406.88 1148.9,1406.88 1148.91,1406.88 1148.92,1406.88 1148.93,1406.88 1148.94,1406.88 1148.95,1406.88 1148.96,1406.88 1148.96,1406.88 1148.97,1406.88 1148.98,1406.88 1148.99,1406.88 1149,1406.88 1149.01,1406.88 1149.02,1406.88 1149.03,1406.88 1149.04,1406.88 1149.05,1406.88 1149.06,1406.88 1149.07,1406.88 1149.08,1406.88 1149.08,1406.88 1149.09,1406.88 1149.1,1406.88 1149.11,1406.88 1149.12,1406.88 1149.13,1406.88 1149.14,1406.88 1149.15,1406.88 1149.16,1406.88 1149.17,1406.88 1149.18,1406.88 1149.19,1406.88 1149.19,1406.88 1149.2,1406.88 1149.21,1406.88 1149.22,1406.88 1149.23,1406.88 1149.24,1406.88 1149.25,1406.88 1149.26,1406.88 1149.27,1406.88 1149.28,1406.88 1149.29,1406.88 1149.3,1406.88 1149.3,1406.88 1149.31,1406.88 1149.32,1406.88 1149.33,1406.88 1149.34,1406.88 1149.35,1406.88 1149.36,1406.88 1149.37,1406.88 1149.38,1406.88 1149.39,1406.88 1149.4,1406.88 1149.41,1406.88 1149.42,1406.88 1149.42,1406.88 1149.43,1406.88 1149.44,1406.88 1149.45,1406.88 1149.46,1406.88 1149.47,1406.88 1149.48,1406.88 1149.49,1406.88 1149.5,1406.88 1149.51,1406.88 1149.52,1406.88 1149.53,1406.88 1149.53,1406.88 1149.54,1406.88 1149.55,1406.88 1149.56,1406.88 1149.57,1406.88 1149.58,1406.88 1149.59,1406.88 1149.6,1406.88 1149.61,1406.88 1149.62,1406.88 1149.63,1406.88 1149.64,1406.88 1149.64,1406.88 1149.65,1406.88 1149.66,1406.88 1149.67,1406.88 1149.68,1406.88 1149.69,1406.88 1149.7,1406.88 1149.71,1406.88 1149.72,1406.88 1149.73,1406.88 1149.74,1406.88 1149.75,1406.88 1149.76,1406.88 1149.76,1406.88 1149.77,1406.88 1149.78,1406.88 1149.79,1406.88 1149.8,1406.88 1149.81,1406.88 1149.82,1406.88 1149.83,1406.88 1149.84,1406.88 1149.85,1406.88 1149.86,1406.88 1149.87,1406.88 1149.87,1406.88 1149.88,1406.88 1149.89,1406.88 1149.9,1406.88 1149.91,1406.88 1149.92,1406.88 1149.93,1406.88 1149.94,1406.88 1149.95,1406.88 1149.96,1406.88 1149.97,1406.88 1149.98,1406.88 1149.98,1406.88 1149.99,1406.88 1150,1406.88 1150.01,1406.88 1150.02,1406.88 1150.03,1406.88 1150.04,1406.88 1150.05,1406.88 1150.06,1406.88 1150.07,1406.88 1150.08,1406.88 1150.09,1406.88 1150.1,1406.88 1150.1,1406.88 1150.11,1406.88 1150.12,1406.88 1150.13,1406.88 1150.14,1406.88 1150.15,1406.88 1150.16,1406.88 1150.17,1406.88 1150.18,1406.88 1150.19,1406.88 1150.2,1406.88 1150.21,1406.88 1150.21,1406.88 1150.22,1406.88 1150.23,1406.88 1150.24,1406.88 1150.25,1406.88 1150.26,1406.88 1150.27,1406.88 1150.28,1406.88 1150.29,1406.88 1150.3,1406.88 1150.31,1406.88 1150.32,1406.88 1150.32,1406.88 1150.33,1406.88 1150.34,1406.88 1150.35,1406.88 1150.36,1406.88 1150.37,1406.88 1150.38,1406.88 1150.39,1406.88 1150.4,1406.88 1150.41,1406.88 1150.42,1406.88 1150.43,1406.88 1150.44,1406.88 1150.44,1406.88 1150.45,1406.88 1150.46,1406.88 1150.47,1406.88 1150.48,1406.88 1150.49,1406.88 1150.5,1406.88 1150.51,1406.88 1150.52,1406.88 1150.53,1406.88 1150.54,1406.88 1150.55,1406.88 1150.55,1406.88 1150.56,1406.88 1150.57,1406.88 1150.58,1406.88 1150.59,1406.88 1150.6,1406.88 1150.61,1406.88 1150.62,1406.88 1150.63,1406.88 1150.64,1406.88 1150.65,1406.88 1150.66,1406.88 1150.66,1406.88 1150.67,1406.88 1150.68,1406.88 1150.69,1406.88 1150.7,1406.88 1150.71,1406.88 1150.72,1406.88 1150.73,1406.88 1150.74,1406.88 1150.75,1406.88 1150.76,1406.88 1150.77,1406.88 1150.78,1406.88 1150.78,1406.88 1150.79,1406.88 1150.8,1406.88 1150.81,1406.88 1150.82,1406.88 1150.83,1406.88 1150.84,1406.88 1150.85,1406.88 1150.86,1406.88 1150.87,1406.88 1150.88,1406.88 1150.89,1406.88 1150.89,1406.88 1150.9,1406.88 1150.91,1406.88 1150.92,1406.88 1150.93,1406.88 1150.94,1406.88 1150.95,1406.88 1150.96,1406.88 1150.97,1406.88 1150.98,1406.88 1150.99,1406.88 1151,1406.88 1151,1406.88 1151.01,1406.88 1151.02,1406.88 1151.03,1406.88 1151.04,1406.88 1151.05,1406.88 1151.06,1406.88 1151.07,1406.88 1151.08,1406.88 1151.09,1406.88 1151.1,1406.88 1151.11,1406.88 1151.12,1406.88 1151.12,1406.88 1151.13,1406.88 1151.14,1406.88 1151.15,1406.88 1151.16,1406.88 1151.17,1406.88 1151.18,1406.88 1151.19,1406.88 1151.2,1406.88 1151.21,1406.88 1151.22,1406.88 1151.23,1406.88 1151.23,1406.88 1151.24,1406.88 1151.25,1406.88 1151.26,1406.88 1151.27,1406.88 1151.28,1406.88 1151.29,1406.88 1151.3,1406.88 1151.31,1406.88 1151.32,1406.88 1151.33,1406.88 1151.34,1406.88 1151.34,1406.88 1151.35,1406.88 1151.36,1406.88 1151.37,1406.88 1151.38,1406.88 1151.39,1406.88 1151.4,1406.88 1151.41,1406.88 1151.42,1406.88 1151.43,1406.88 1151.44,1406.88 1151.45,1406.88 1151.46,1406.88 1151.46,1406.88 1151.47,1406.88 1151.48,1406.88 1151.49,1406.88 1151.5,1406.88 1151.51,1406.88 1151.52,1406.88 1151.53,1406.88 1151.54,1406.88 1151.55,1406.88 1151.56,1406.88 1151.57,1406.88 1151.57,1406.88 1151.58,1406.88 1151.59,1406.88 1151.6,1406.88 1151.61,1406.88 1151.62,1406.88 1151.63,1406.88 1151.64,1406.88 1151.65,1406.88 1151.66,1406.88 1151.67,1406.88 1151.68,1406.88 1151.68,1406.88 1151.69,1406.88 1151.7,1406.88 1151.71,1406.88 1151.72,1406.88 1151.73,1406.88 1151.74,1406.88 1151.75,1406.88 1151.76,1406.88 1151.77,1406.88 1151.78,1406.88 1151.79,1406.88 1151.8,1406.88 1151.8,1406.88 1151.81,1406.88 1151.82,1406.88 1151.83,1406.88 1151.84,1406.88 1151.85,1406.88 1151.86,1406.88 1151.87,1406.88 1151.88,1406.88 1151.89,1406.88 1151.9,1406.88 1151.91,1406.88 1151.91,1406.88 1151.92,1406.88 1151.93,1406.88 1151.94,1406.88 1151.95,1406.88 1151.96,1406.88 1151.97,1406.88 1151.98,1406.88 1151.99,1406.88 1152,1406.88 1152.01,1406.88 1152.02,1406.88 1152.02,1406.88 1152.03,1406.88 1152.04,1406.88 1152.05,1406.88 1152.06,1406.88 1152.07,1406.88 1152.08,1406.88 1152.09,1406.88 1152.1,1406.88 1152.11,1406.88 1152.12,1406.88 1152.13,1406.88 1152.14,1406.88 1152.14,1406.88 1152.15,1406.88 1152.16,1406.88 1152.17,1406.88 1152.18,1406.88 1152.19,1406.88 1152.2,1406.88 1152.21,1406.88 1152.22,1406.88 1152.23,1406.88 1152.24,1406.88 1152.25,1406.88 1152.25,1406.88 1152.26,1406.88 1152.27,1406.88 1152.28,1406.88 1152.29,1406.88 1152.3,1406.88 1152.31,1406.88 1152.32,1406.88 1152.33,1406.88 1152.34,1406.88 1152.35,1406.88 1152.36,1406.88 1152.36,1406.88 1152.37,1406.88 1152.38,1406.88 1152.39,1406.88 1152.4,1406.88 1152.41,1406.88 1152.42,1406.88 1152.43,1406.88 1152.44,1406.88 1152.45,1406.88 1152.46,1406.88 1152.47,1406.88 1152.48,1406.88 1152.48,1406.88 1152.49,1406.88 1152.5,1406.88 1152.51,1406.88 1152.52,1406.88 1152.53,1406.88 1152.54,1406.88 1152.55,1406.88 1152.56,1406.88 1152.57,1406.88 1152.58,1406.88 1152.59,1406.88 1152.59,1406.88 1152.6,1406.88 1152.61,1406.88 1152.62,1406.88 1152.63,1406.88 1152.64,1406.88 1152.65,1406.88 1152.66,1406.88 1152.67,1406.88 1152.68,1406.88 1152.69,1406.88 1152.7,1406.88 1152.7,1406.88 1152.71,1406.88 1152.72,1406.88 1152.73,1406.88 1152.74,1406.88 1152.75,1406.88 1152.76,1406.88 1152.77,1406.88 1152.78,1406.88 1152.79,1406.88 1152.8,1406.88 1152.81,1406.88 1152.82,1406.88 1152.82,1406.88 1152.83,1406.88 1152.84,1406.88 1152.85,1406.88 1152.86,1406.88 1152.87,1406.88 1152.88,1406.88 1152.89,1406.88 1152.9,1406.88 1152.91,1406.88 1152.92,1406.88 1152.93,1406.88 1152.93,1406.88 1152.94,1406.88 1152.95,1406.88 1152.96,1406.88 1152.97,1406.88 1152.98,1406.88 1152.99,1406.88 1153,1406.88 1153.01,1406.88 1153.02,1406.88 1153.03,1406.88 1153.04,1406.88 1153.04,1406.88 1153.05,1406.88 1153.06,1406.88 1153.07,1406.88 1153.08,1406.88 1153.09,1406.88 1153.1,1406.88 1153.11,1406.88 1153.12,1406.88 1153.13,1406.88 1153.14,1406.88 1153.15,1406.88 1153.16,1406.88 1153.16,1406.88 1153.17,1406.88 1153.18,1406.88 1153.19,1406.88 1153.2,1406.88 1153.21,1406.88 1153.22,1406.88 1153.23,1406.88 1153.24,1406.88 1153.25,1406.88 1153.26,1406.88 1153.27,1406.88 1153.27,1406.88 1153.28,1406.88 1153.29,1406.88 1153.3,1406.88 1153.31,1406.88 1153.32,1406.88 1153.33,1406.88 1153.34,1406.88 1153.35,1406.88 1153.36,1406.88 1153.37,1406.88 1153.38,1406.88 1153.38,1406.88 1153.39,1406.88 1153.4,1406.88 1153.41,1406.88 1153.42,1406.88 1153.43,1406.88 1153.44,1406.88 1153.45,1406.88 1153.46,1406.88 1153.47,1406.88 1153.48,1406.88 1153.49,1406.88 1153.5,1406.88 1153.5,1406.88 1153.51,1406.88 1153.52,1406.88 1153.53,1406.88 1153.54,1406.88 1153.55,1406.88 1153.56,1406.88 1153.57,1406.88 1153.58,1406.88 1153.59,1406.88 1153.6,1406.88 1153.61,1406.88 1153.61,1406.88 1153.62,1406.88 1153.63,1406.88 1153.64,1406.88 1153.65,1406.88 1153.66,1406.88 1153.67,1406.88 1153.68,1406.88 1153.69,1406.88 1153.7,1406.88 1153.71,1406.88 1153.72,1406.88 1153.72,1406.88 1153.73,1406.88 1153.74,1406.88 1153.75,1406.88 1153.76,1406.88 1153.77,1406.88 1153.78,1406.88 1153.79,1406.88 1153.8,1406.88 1153.81,1406.88 1153.82,1406.88 1153.83,1406.88 1153.84,1406.88 1153.84,1406.88 1153.85,1406.88 1153.86,1406.88 1153.87,1406.88 1153.88,1406.88 1153.89,1406.88 1153.9,1406.88 1153.91,1406.88 1153.92,1406.88 1153.93,1406.88 1153.94,1406.88 1153.95,1406.88 1153.95,1406.88 1153.96,1406.88 1153.97,1406.88 1153.98,1406.88 1153.99,1406.88 1154,1406.88 1154.01,1406.88 1154.02,1406.88 1154.03,1406.88 1154.04,1406.88 1154.05,1406.88 1154.06,1406.88 1154.06,1406.88 1154.07,1406.88 1154.08,1406.88 1154.09,1406.88 1154.1,1406.88 1154.11,1406.88 1154.12,1406.88 1154.13,1406.88 1154.14,1406.88 1154.15,1406.88 1154.16,1406.88 1154.17,1406.88 1154.18,1406.88 1154.18,1406.88 1154.19,1406.88 1154.2,1406.88 "/>
<polyline clip-path="url(#clip404)" style="stroke:#e26f46; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,1323.99 235.292,1324 235.301,1324 235.31,1324 235.32,1324 235.329,1324 235.338,1324 235.347,1324 235.356,1324 235.366,1324 235.375,1324 235.384,1324 235.393,1324 235.402,1324 235.412,1324 235.421,1324 235.43,1324 235.439,1324 235.448,1324.01 235.457,1324.01 235.467,1324.01 235.476,1324.01 235.485,1324.01 235.494,1324.01 235.503,1324.01 235.513,1324.01 235.522,1324.01 235.531,1324.01 235.54,1324.01 235.549,1324.01 235.559,1324.01 235.568,1324.01 235.577,1324.01 235.586,1324.01 235.595,1324.01 235.604,1324.01 235.614,1324.02 235.623,1324.02 235.632,1324.02 235.641,1324.02 235.65,1324.02 235.66,1324.02 235.669,1324.02 235.678,1324.02 235.687,1324.02 235.696,1324.02 235.706,1324.02 235.715,1324.02 235.724,1324.02 235.733,1324.02 235.742,1324.02 235.752,1324.02 235.761,1324.02 235.77,1324.03 235.779,1324.03 235.788,1324.03 235.797,1324.03 235.807,1324.03 235.816,1324.03 235.825,1324.03 235.834,1324.03 235.843,1324.03 235.853,1324.03 235.862,1324.03 235.871,1324.03 235.88,1324.03 235.889,1324.03 235.899,1324.03 235.908,1324.03 235.917,1324.03 235.926,1324.04 235.935,1324.04 235.944,1324.04 235.954,1324.04 235.963,1324.04 235.972,1324.04 235.981,1324.04 235.99,1324.04 236,1324.04 236.009,1324.04 236.018,1324.04 236.027,1324.04 236.036,1324.04 236.046,1324.04 236.055,1324.04 236.064,1324.04 236.073,1324.04 236.082,1324.05 236.092,1324.05 236.101,1324.05 236.11,1324.05 236.119,1324.05 236.128,1324.05 236.137,1324.05 236.147,1324.05 236.156,1324.05 236.165,1324.05 236.174,1324.05 236.183,1324.05 236.193,1324.05 236.202,1324.05 236.211,1324.05 236.22,1324.05 236.229,1324.05 236.239,1324.06 236.248,1324.06 236.257,1324.06 236.266,1324.06 236.275,1324.06 236.284,1324.06 236.294,1324.06 236.303,1324.06 236.312,1324.06 236.321,1324.06 236.33,1324.06 236.34,1324.06 236.349,1324.06 236.358,1324.06 236.367,1324.06 236.376,1324.06 236.386,1324.07 236.395,1324.07 236.404,1324.07 236.413,1324.07 236.422,1324.07 236.432,1324.07 236.441,1324.07 236.45,1324.07 236.459,1324.07 236.468,1324.07 236.477,1324.07 236.487,1324.07 236.496,1324.07 236.505,1324.07 236.514,1324.07 236.523,1324.07 236.533,1324.07 236.542,1324.08 236.551,1324.08 236.56,1324.08 236.569,1324.08 236.579,1324.08 236.588,1324.08 236.597,1324.08 236.606,1324.08 236.615,1324.08 236.624,1324.08 236.634,1324.08 236.643,1324.08 236.652,1324.08 236.661,1324.08 236.67,1324.08 236.68,1324.08 236.689,1324.09 236.698,1324.09 236.707,1324.09 236.716,1324.09 236.726,1324.09 236.735,1324.09 236.744,1324.09 236.753,1324.09 236.762,1324.09 236.772,1324.09 236.781,1324.09 236.79,1324.09 236.799,1324.09 236.808,1324.09 236.817,1324.09 236.827,1324.09 236.836,1324.1 236.845,1324.1 236.854,1324.1 236.863,1324.1 236.873,1324.1 236.882,1324.1 236.891,1324.1 236.9,1324.1 236.909,1324.1 236.919,1324.1 236.928,1324.1 236.937,1324.1 236.946,1324.1 236.955,1324.1 236.964,1324.1 236.974,1324.1 236.983,1324.11 236.992,1324.11 237.001,1324.11 237.01,1324.11 237.02,1324.11 237.029,1324.11 237.038,1324.11 237.047,1324.11 237.056,1324.11 237.066,1324.11 237.075,1324.11 237.084,1324.11 237.093,1324.11 237.102,1324.11 237.112,1324.11 237.121,1324.11 237.13,1324.12 237.139,1324.12 237.148,1324.12 237.157,1324.12 237.167,1324.12 237.176,1324.12 237.185,1324.12 237.194,1324.12 237.203,1324.12 237.213,1324.12 237.222,1324.12 237.231,1324.12 237.24,1324.12 237.249,1324.12 237.259,1324.12 237.268,1324.12 237.277,1324.13 237.286,1324.13 237.295,1324.13 237.304,1324.13 237.314,1324.13 237.323,1324.13 237.332,1324.13 237.341,1324.13 237.35,1324.13 237.36,1324.13 237.369,1324.13 237.378,1324.13 237.387,1324.13 237.396,1324.13 237.406,1324.13 237.415,1324.13 237.424,1324.13 237.433,1324.14 237.442,1324.14 237.452,1324.14 237.461,1324.14 237.47,1324.14 237.479,1324.14 237.488,1324.14 237.497,1324.14 237.507,1324.14 237.516,1324.14 237.525,1324.14 237.534,1324.14 237.543,1324.14 237.553,1324.14 237.562,1324.14 237.571,1324.14 237.58,1324.15 237.589,1324.15 237.599,1324.15 237.608,1324.15 237.617,1324.15 237.626,1324.15 237.635,1324.15 237.644,1324.15 237.654,1324.15 237.663,1324.15 237.672,1324.15 237.681,1324.15 237.69,1324.15 237.7,1324.15 237.709,1324.15 237.718,1324.15 237.727,1324.16 237.736,1324.16 237.746,1324.16 237.755,1324.16 237.764,1324.16 237.773,1324.16 237.782,1324.16 237.792,1324.16 237.801,1324.16 237.81,1324.16 237.819,1324.16 237.828,1324.16 237.837,1324.16 237.847,1324.16 237.856,1324.16 237.865,1324.16 237.874,1324.17 237.883,1324.17 237.893,1324.17 237.902,1324.17 237.911,1324.17 237.92,1324.17 237.929,1324.17 237.939,1324.17 237.948,1324.17 237.957,1324.17 237.966,1324.17 237.975,1324.17 237.985,1324.17 237.994,1324.17 238.003,1324.17 238.012,1324.17 238.021,1324.18 238.03,1324.18 238.04,1324.18 238.049,1324.18 238.058,1324.18 238.067,1324.18 238.076,1324.18 238.086,1324.18 238.095,1324.18 238.104,1324.18 238.113,1324.18 238.122,1324.18 238.132,1324.18 238.141,1324.18 238.15,1324.18 238.159,1324.18 238.168,1324.19 238.177,1324.19 238.187,1324.19 238.196,1324.19 238.205,1324.19 238.214,1324.19 238.223,1324.19 238.233,1324.19 238.242,1324.19 238.251,1324.19 238.26,1324.19 238.269,1324.19 238.279,1324.19 238.288,1324.19 238.297,1324.19 238.306,1324.19 238.315,1324.19 238.325,1324.2 238.334,1324.2 238.343,1324.2 238.352,1324.2 238.361,1324.2 238.37,1324.2 238.38,1324.2 238.389,1324.2 238.398,1324.2 238.407,1324.2 238.416,1324.2 238.426,1324.2 238.435,1324.2 238.444,1324.2 238.453,1324.2 238.462,1324.2 238.472,1324.21 238.481,1324.21 238.49,1324.21 238.499,1324.21 238.508,1324.21 238.517,1324.21 238.527,1324.21 238.536,1324.21 238.545,1324.21 238.554,1324.21 238.563,1324.21 238.573,1324.21 238.582,1324.21 238.591,1324.21 238.6,1324.21 238.609,1324.21 238.619,1324.22 238.628,1324.22 238.637,1324.22 238.646,1324.22 238.655,1324.22 238.665,1324.22 238.674,1324.22 238.683,1324.22 238.692,1324.22 238.701,1324.22 238.71,1324.22 238.72,1324.22 238.729,1324.22 238.738,1324.22 238.747,1324.22 238.756,1324.22 238.766,1324.23 238.775,1324.23 238.784,1324.23 238.793,1324.23 238.802,1324.23 238.812,1324.23 238.821,1324.23 238.83,1324.23 238.839,1324.23 238.848,1324.23 238.857,1324.23 238.867,1324.23 238.876,1324.23 238.885,1324.23 238.894,1324.23 238.903,1324.23 238.913,1324.24 238.922,1324.24 238.931,1324.24 238.94,1324.24 238.949,1324.24 238.959,1324.24 238.968,1324.24 238.977,1324.24 238.986,1324.24 238.995,1324.24 239.005,1324.24 239.014,1324.24 239.023,1324.24 239.032,1324.24 239.041,1324.24 239.05,1324.24 239.06,1324.24 239.069,1324.25 239.078,1324.25 239.087,1324.25 239.096,1324.25 239.106,1324.25 239.115,1324.25 239.124,1324.25 239.133,1324.25 239.142,1324.25 239.152,1324.25 239.161,1324.25 239.17,1324.25 239.179,1324.25 239.188,1324.25 239.197,1324.25 239.207,1324.25 239.216,1324.26 239.225,1324.26 239.234,1324.26 239.243,1324.26 239.253,1324.26 239.262,1324.26 239.271,1324.26 239.28,1324.26 239.289,1324.26 239.299,1324.26 239.308,1324.26 239.317,1324.26 239.326,1324.26 239.335,1324.26 239.345,1324.26 239.354,1324.26 239.363,1324.27 239.372,1324.27 239.381,1324.27 239.39,1324.27 239.4,1324.27 239.409,1324.27 239.418,1324.27 239.427,1324.27 239.436,1324.27 239.446,1324.27 239.455,1324.27 239.464,1324.27 239.473,1324.27 239.482,1324.27 239.492,1324.27 239.501,1324.27 239.51,1324.28 239.519,1324.28 239.528,1324.28 239.537,1324.28 239.547,1324.28 239.556,1324.28 239.565,1324.28 239.574,1324.28 239.583,1324.28 239.593,1324.28 239.602,1324.28 239.611,1324.28 239.62,1324.28 239.629,1324.28 239.639,1324.28 239.648,1324.28 239.657,1324.29 239.666,1324.29 239.675,1324.29 239.685,1324.29 239.694,1324.29 239.703,1324.29 239.712,1324.29 239.721,1324.29 239.73,1324.29 239.74,1324.29 239.749,1324.29 239.758,1324.29 239.767,1324.29 239.776,1324.29 239.786,1324.29 239.795,1324.29 239.804,1324.29 239.813,1324.3 239.822,1324.3 239.832,1324.3 239.841,1324.3 239.85,1324.3 239.859,1324.3 239.868,1324.3 239.877,1324.3 239.887,1324.3 239.896,1324.3 239.905,1324.3 239.914,1324.3 239.923,1324.3 239.933,1324.3 239.942,1324.3 239.951,1324.3 239.96,1324.31 239.969,1324.31 239.979,1324.31 239.988,1324.31 239.997,1324.31 240.006,1324.31 240.015,1324.31 240.025,1324.31 240.034,1324.31 240.043,1324.31 240.052,1324.31 240.061,1324.31 240.07,1324.31 240.08,1324.31 240.089,1324.31 240.098,1324.31 240.107,1324.32 240.116,1324.32 240.126,1324.32 240.135,1324.32 240.144,1324.32 240.153,1324.32 240.162,1324.32 240.172,1324.32 240.181,1324.32 240.19,1324.32 240.199,1324.32 240.208,1324.32 240.217,1324.32 240.227,1324.32 240.236,1324.32 240.245,1324.32 240.254,1324.33 240.263,1324.33 240.273,1324.33 240.282,1324.33 240.291,1324.33 240.3,1324.33 240.309,1324.33 240.319,1324.33 240.328,1324.33 240.337,1324.33 240.346,1324.33 240.355,1324.33 240.365,1324.33 240.374,1324.33 240.383,1324.33 240.392,1324.33 240.401,1324.34 240.41,1324.34 240.42,1324.34 240.429,1324.34 240.438,1324.34 240.447,1324.34 240.456,1324.34 240.466,1324.34 240.475,1324.34 240.484,1324.34 240.493,1324.34 240.502,1324.34 240.512,1324.34 240.521,1324.34 240.53,1324.34 240.539,1324.34 240.548,1324.34 240.558,1324.35 240.567,1324.35 240.576,1324.35 240.585,1324.35 240.594,1324.35 240.603,1324.35 240.613,1324.35 240.622,1324.35 240.631,1324.35 240.64,1324.35 240.649,1324.35 240.659,1324.35 240.668,1324.35 240.677,1324.35 240.686,1324.35 240.695,1324.35 240.705,1324.36 240.714,1324.36 240.723,1324.36 240.732,1324.36 240.741,1324.36 240.75,1324.36 240.76,1324.36 240.769,1324.36 240.778,1324.36 240.787,1324.36 240.796,1324.36 240.806,1324.36 240.815,1324.36 240.824,1324.36 240.833,1324.36 240.842,1324.36 240.852,1324.37 240.861,1324.37 240.87,1324.37 240.879,1324.37 240.888,1324.37 240.898,1324.37 240.907,1324.37 240.916,1324.37 240.925,1324.37 240.934,1324.37 240.943,1324.37 240.953,1324.37 240.962,1324.37 240.971,1324.37 240.98,1324.37 240.989,1324.37 240.999,1324.38 241.008,1324.38 241.017,1324.38 241.026,1324.38 241.035,1324.38 241.045,1324.38 241.054,1324.38 241.063,1324.38 241.072,1324.38 241.081,1324.38 241.09,1324.38 241.1,1324.38 241.109,1324.38 241.118,1324.38 241.127,1324.38 241.136,1324.38 241.146,1324.38 241.155,1324.39 241.164,1324.39 241.173,1324.39 241.182,1324.39 241.192,1324.39 241.201,1324.39 241.21,1324.39 241.219,1324.39 241.228,1324.39 241.238,1324.39 241.247,1324.39 241.256,1324.39 241.265,1324.39 241.274,1324.39 241.283,1324.39 241.293,1324.39 241.302,1324.4 241.311,1324.4 241.32,1324.4 241.329,1324.4 241.339,1324.4 241.348,1324.4 241.357,1324.4 241.366,1324.4 241.375,1324.4 241.385,1324.4 241.394,1324.4 241.403,1324.4 241.412,1324.4 241.421,1324.4 241.43,1324.4 241.44,1324.4 241.449,1324.41 241.458,1324.41 241.467,1324.41 241.476,1324.41 241.486,1324.41 241.495,1324.41 241.504,1324.41 241.513,1324.41 241.522,1324.41 241.532,1324.41 241.541,1324.41 241.55,1324.41 241.559,1324.41 241.568,1324.41 241.578,1324.41 241.587,1324.41 241.596,1324.42 241.605,1324.42 241.614,1324.42 241.623,1324.42 241.633,1324.42 241.642,1324.42 241.651,1324.42 241.66,1324.42 241.669,1324.42 241.679,1324.42 241.688,1324.42 241.697,1324.42 241.706,1324.42 241.715,1324.42 241.725,1324.42 241.734,1324.42 241.743,1324.43 241.752,1324.43 241.761,1324.43 241.77,1324.43 241.78,1324.43 241.789,1324.43 241.798,1324.43 241.807,1324.43 241.816,1324.43 241.826,1324.43 241.835,1324.43 241.844,1324.43 241.853,1324.43 241.862,1324.43 241.872,1324.43 241.881,1324.43 241.89,1324.43 241.899,1324.44 241.908,1324.44 241.918,1324.44 241.927,1324.44 241.936,1324.44 241.945,1324.44 241.954,1324.44 241.963,1324.44 241.973,1324.44 241.982,1324.44 241.991,1324.44 242,1324.44 242.009,1324.44 242.019,1324.44 242.028,1324.44 242.037,1324.44 242.046,1324.45 242.055,1324.45 242.065,1324.45 242.074,1324.45 242.083,1324.45 242.092,1324.45 242.101,1324.45 242.11,1324.45 242.12,1324.45 242.129,1324.45 242.138,1324.45 242.147,1324.45 242.156,1324.45 242.166,1324.45 242.175,1324.45 242.184,1324.45 242.193,1324.46 242.202,1324.46 242.212,1324.46 242.221,1324.46 242.23,1324.46 242.239,1324.46 242.248,1324.46 242.258,1324.46 242.267,1324.46 242.276,1324.46 242.285,1324.46 242.294,1324.46 242.303,1324.46 242.313,1324.46 242.322,1324.46 242.331,1324.46 242.34,1324.47 242.349,1324.47 242.359,1324.47 242.368,1324.47 242.377,1324.47 242.386,1324.47 242.395,1324.47 242.405,1324.47 242.414,1324.47 242.423,1324.47 242.432,1324.47 242.441,1324.47 242.45,1324.47 242.46,1324.47 242.469,1324.47 242.478,1324.47 242.487,1324.47 242.496,1324.48 242.506,1324.48 242.515,1324.48 242.524,1324.48 242.533,1324.48 242.542,1324.48 242.552,1324.48 242.561,1324.48 242.57,1324.48 242.579,1324.48 242.588,1324.48 242.598,1324.48 242.607,1324.48 242.616,1324.48 242.625,1324.48 242.634,1324.48 242.643,1324.49 242.653,1324.49 242.662,1324.49 242.671,1324.49 242.68,1324.49 242.689,1324.49 242.699,1324.49 242.708,1324.49 242.717,1324.49 242.726,1324.49 242.735,1324.49 242.745,1324.49 242.754,1324.49 242.763,1324.49 242.772,1324.49 242.781,1324.49 242.79,1324.5 242.8,1324.5 242.809,1324.5 242.818,1324.5 242.827,1324.5 242.836,1324.5 242.846,1324.5 242.855,1324.5 242.864,1324.5 242.873,1324.5 242.882,1324.5 242.892,1324.5 242.901,1324.5 242.91,1324.5 242.919,1324.5 242.928,1324.5 242.938,1324.51 242.947,1324.51 242.956,1324.51 242.965,1324.51 242.974,1324.51 242.983,1324.51 242.993,1324.51 243.002,1324.51 243.011,1324.51 243.02,1324.51 243.029,1324.51 243.039,1324.51 243.048,1324.51 243.057,1324.51 243.066,1324.51 243.075,1324.51 243.085,1324.51 243.094,1324.52 243.103,1324.52 243.112,1324.52 243.121,1324.52 243.131,1324.52 243.14,1324.52 243.149,1324.52 243.158,1324.52 243.167,1324.52 243.176,1324.52 243.186,1324.52 243.195,1324.52 243.204,1324.52 243.213,1324.52 243.222,1324.52 243.232,1324.52 243.241,1324.53 243.25,1324.53 243.259,1324.53 243.268,1324.53 243.278,1324.53 243.287,1324.53 243.296,1324.53 243.305,1324.53 243.314,1324.53 243.323,1324.53 243.333,1324.53 243.342,1324.53 243.351,1324.53 243.36,1324.53 243.369,1324.53 243.379,1324.53 243.388,1324.54 243.397,1324.54 243.406,1324.54 243.415,1324.54 243.425,1324.54 243.434,1324.54 243.443,1324.54 243.452,1324.54 243.461,1324.54 243.471,1324.54 243.48,1324.54 243.489,1324.54 243.498,1324.54 243.507,1324.54 243.516,1324.54 243.526,1324.54 243.535,1324.55 243.544,1324.55 243.553,1324.55 243.562,1324.55 243.572,1324.55 243.581,1324.55 243.59,1324.55 243.599,1324.55 243.608,1324.55 243.618,1324.55 243.627,1324.55 243.636,1324.55 243.645,1324.55 243.654,1324.55 243.663,1324.55 243.673,1324.55 243.682,1324.55 243.691,1324.56 243.7,1324.56 243.709,1324.56 243.719,1324.56 243.728,1324.56 243.737,1324.56 243.746,1324.56 243.755,1324.56 243.765,1324.56 243.774,1324.56 243.783,1324.56 243.792,1324.56 243.801,1324.56 243.811,1324.56 243.82,1324.56 243.829,1324.56 243.838,1324.57 243.847,1324.57 243.856,1324.57 243.866,1324.57 243.875,1324.57 243.884,1324.57 243.893,1324.57 243.902,1324.57 243.912,1324.57 243.921,1324.57 243.93,1324.57 243.939,1324.57 243.948,1324.57 243.958,1324.57 243.967,1324.57 243.976,1324.57 243.985,1324.58 243.994,1324.58 244.003,1324.58 244.013,1324.58 244.022,1324.58 244.031,1324.58 244.04,1324.58 244.049,1324.58 244.059,1324.58 244.068,1324.58 244.077,1324.58 244.086,1324.58 244.095,1324.58 244.105,1324.58 244.114,1324.58 244.123,1324.58 244.132,1324.59 244.141,1324.59 244.151,1324.59 244.16,1324.59 244.169,1324.59 244.178,1324.59 244.187,1324.59 244.196,1324.59 244.206,1324.59 244.215,1324.59 244.224,1324.59 244.233,1324.59 244.242,1324.59 244.252,1324.59 244.261,1324.59 244.27,1324.59 244.279,1324.59 244.288,1324.6 244.298,1324.6 244.307,1324.6 244.316,1324.6 244.325,1324.6 244.334,1324.6 244.343,1324.6 244.353,1324.6 244.362,1324.6 244.371,1324.6 244.38,1324.6 244.389,1324.6 244.399,1324.6 244.408,1324.6 244.417,1324.6 244.426,1324.6 244.435,1324.61 244.445,1324.61 244.454,1324.61 244.463,1324.61 244.472,1324.61 244.481,1324.61 244.491,1324.61 244.5,1324.61 244.509,1324.61 244.518,1324.61 244.527,1324.61 244.536,1324.61 244.546,1324.61 244.555,1324.61 244.564,1324.61 244.573,1324.61 244.582,1324.62 244.592,1324.62 244.601,1324.62 244.61,1324.62 244.619,1324.62 244.628,1324.62 244.638,1324.62 244.647,1324.62 244.656,1324.62 244.665,1324.62 244.674,1324.62 244.683,1324.62 244.693,1324.62 244.702,1324.62 244.711,1324.62 244.72,1324.62 244.729,1324.63 244.739,1324.63 244.748,1324.63 244.757,1324.63 244.766,1324.63 244.775,1324.63 244.785,1324.63 244.794,1324.63 244.803,1324.63 244.812,1324.63 244.821,1324.63 244.831,1324.63 244.84,1324.63 244.849,1324.63 244.858,1324.63 244.867,1324.63 244.876,1324.63 244.886,1324.64 244.895,1324.64 244.904,1324.64 244.913,1324.64 244.922,1324.64 244.932,1324.64 244.941,1324.64 244.95,1324.64 244.959,1324.64 244.968,1324.64 244.978,1324.64 244.987,1324.64 244.996,1324.64 245.005,1324.64 245.014,1324.64 245.023,1324.64 245.033,1324.65 245.042,1324.65 245.051,1324.65 245.06,1324.65 245.069,1324.65 245.079,1324.65 245.088,1324.65 245.097,1324.65 245.106,1324.65 245.115,1324.65 245.125,1324.65 245.134,1324.65 245.143,1324.65 245.152,1324.65 245.161,1324.65 245.171,1324.65 245.18,1324.66 245.189,1324.66 245.198,1324.66 245.207,1324.66 245.216,1324.66 245.226,1324.66 245.235,1324.66 245.244,1324.66 245.253,1324.66 245.262,1324.66 245.272,1324.66 245.281,1324.66 245.29,1324.66 245.299,1324.66 245.308,1324.66 245.318,1324.66 245.327,1324.67 245.336,1324.67 245.345,1324.67 245.354,1324.67 245.364,1324.67 245.373,1324.67 245.382,1324.67 245.391,1324.67 245.4,1324.67 245.409,1324.67 245.419,1324.67 245.428,1324.67 245.437,1324.67 245.446,1324.67 245.455,1324.67 245.465,1324.67 245.474,1324.67 245.483,1324.68 245.492,1324.68 245.501,1324.68 245.511,1324.68 245.52,1324.68 245.529,1324.68 245.538,1324.68 245.547,1324.68 245.556,1324.68 245.566,1324.68 245.575,1324.68 245.584,1324.68 245.593,1324.68 245.602,1324.68 245.612,1324.68 245.621,1324.68 245.63,1324.69 245.639,1324.69 245.648,1324.69 245.658,1324.69 245.667,1324.69 245.676,1324.69 245.685,1324.69 245.694,1324.69 245.704,1324.69 245.713,1324.69 245.722,1324.69 245.731,1324.69 245.74,1324.69 245.749,1324.69 245.759,1324.69 245.768,1324.69 245.777,1324.7 245.786,1324.7 245.795,1324.7 245.805,1324.7 245.814,1324.7 245.823,1324.7 245.832,1324.7 245.841,1324.7 245.851,1324.7 245.86,1324.7 245.869,1324.7 245.878,1324.7 245.887,1324.7 245.896,1324.7 245.906,1324.7 245.915,1324.7 245.924,1324.7 245.933,1324.71 245.942,1324.71 245.952,1324.71 245.961,1324.71 245.97,1324.71 245.979,1324.71 245.988,1324.71 245.998,1324.71 246.007,1324.71 246.016,1324.71 246.025,1324.71 246.034,1324.71 246.044,1324.71 246.053,1324.71 246.062,1324.71 246.071,1324.71 246.08,1324.72 246.089,1324.72 246.099,1324.72 246.108,1324.72 246.117,1324.72 246.126,1324.72 246.135,1324.72 246.145,1324.72 246.154,1324.72 246.163,1324.72 246.172,1324.72 246.181,1324.72 246.191,1324.72 246.2,1324.72 246.209,1324.72 246.218,1324.72 246.227,1324.73 246.236,1324.73 246.246,1324.73 246.255,1324.73 246.264,1324.73 246.273,1324.73 246.282,1324.73 246.292,1324.73 246.301,1324.73 246.31,1324.73 246.319,1324.73 246.328,1324.73 246.338,1324.73 246.347,1324.73 246.356,1324.73 246.365,1324.73 246.374,1324.74 246.384,1324.74 246.393,1324.74 246.402,1324.74 246.411,1324.74 246.42,1324.74 246.429,1324.74 246.439,1324.74 246.448,1324.74 246.457,1324.74 246.466,1324.74 246.475,1324.74 246.485,1324.74 246.494,1324.74 246.503,1324.74 246.512,1324.74 246.521,1324.74 246.531,1324.75 246.54,1324.75 246.549,1324.75 246.558,1324.75 246.567,1324.75 246.576,1324.75 246.586,1324.75 246.595,1324.75 246.604,1324.75 246.613,1324.75 246.622,1324.75 246.632,1324.75 246.641,1324.75 246.65,1324.75 246.659,1324.75 246.668,1324.75 246.678,1324.76 246.687,1324.76 246.696,1324.76 246.705,1324.76 246.714,1324.76 246.724,1324.76 246.733,1324.76 246.742,1324.76 246.751,1324.76 246.76,1324.76 246.769,1324.76 246.779,1324.76 246.788,1324.76 246.797,1324.76 246.806,1324.76 246.815,1324.76 246.825,1324.77 246.834,1324.77 246.843,1324.77 246.852,1324.77 246.861,1324.77 246.871,1324.77 246.88,1324.77 246.889,1324.77 246.898,1324.77 246.907,1324.77 246.916,1324.77 246.926,1324.77 246.935,1324.77 246.944,1324.77 246.953,1324.77 246.962,1324.77 246.972,1324.77 246.981,1324.78 246.99,1324.78 246.999,1324.78 247.008,1324.78 247.018,1324.78 247.027,1324.78 247.036,1324.78 247.045,1324.78 247.054,1324.78 247.064,1324.78 247.073,1324.78 247.082,1324.78 247.091,1324.78 247.1,1324.78 247.109,1324.78 247.119,1324.78 247.128,1324.79 247.137,1324.79 247.146,1324.79 247.155,1324.79 247.165,1324.79 247.174,1324.79 247.183,1324.79 247.192,1324.79 247.201,1324.79 247.211,1324.79 247.22,1324.79 247.229,1324.79 247.238,1324.79 247.247,1324.79 247.256,1324.79 247.266,1324.79 247.275,1324.8 247.284,1324.8 247.293,1324.8 247.302,1324.8 247.312,1324.8 247.321,1324.8 247.33,1324.8 247.339,1324.8 247.348,1324.8 247.358,1324.8 247.367,1324.8 247.376,1324.8 247.385,1324.8 247.394,1324.8 247.404,1324.8 247.413,1324.8 247.422,1324.8 247.431,1324.81 247.44,1324.81 247.449,1324.81 247.459,1324.81 247.468,1324.81 247.477,1324.81 247.486,1324.81 247.495,1324.81 247.505,1324.81 247.514,1324.81 247.523,1324.81 247.532,1324.81 247.541,1324.81 247.551,1324.81 247.56,1324.81 247.569,1324.81 247.578,1324.82 247.587,1324.82 247.596,1324.82 247.606,1324.82 247.615,1324.82 247.624,1324.82 247.633,1324.82 247.642,1324.82 247.652,1324.82 247.661,1324.82 247.67,1324.82 247.679,1324.82 247.688,1324.82 247.698,1324.82 247.707,1324.82 247.716,1324.82 247.725,1324.83 247.734,1324.83 247.744,1324.83 247.753,1324.83 247.762,1324.83 247.771,1324.83 247.78,1324.83 247.789,1324.83 247.799,1324.83 247.808,1324.83 247.817,1324.83 247.826,1324.83 247.835,1324.83 247.845,1324.83 247.854,1324.83 247.863,1324.83 247.872,1324.84 247.881,1324.84 247.891,1324.84 247.9,1324.84 247.909,1324.84 247.918,1324.84 247.927,1324.84 247.937,1324.84 247.946,1324.84 247.955,1324.84 247.964,1324.84 247.973,1324.84 247.982,1324.84 247.992,1324.84 248.001,1324.84 248.01,1324.84 248.019,1324.84 248.028,1324.85 248.038,1324.85 248.047,1324.85 248.056,1324.85 248.065,1324.85 248.074,1324.85 248.084,1324.85 248.093,1324.85 248.102,1324.85 248.111,1324.85 248.12,1324.85 248.129,1324.85 248.139,1324.85 248.148,1324.85 248.157,1324.85 248.166,1324.85 248.175,1324.86 248.185,1324.86 248.194,1324.86 248.203,1324.86 248.212,1324.86 248.221,1324.86 248.231,1324.86 248.24,1324.86 248.249,1324.86 248.258,1324.86 248.267,1324.86 248.277,1324.86 248.286,1324.86 248.295,1324.86 248.304,1324.86 248.313,1324.86 248.322,1324.87 248.332,1324.87 248.341,1324.87 248.35,1324.87 248.359,1324.87 248.368,1324.87 248.378,1324.87 248.387,1324.87 248.396,1324.87 248.405,1324.87 248.414,1324.87 248.424,1324.87 248.433,1324.87 248.442,1324.87 248.451,1324.87 248.46,1324.87 248.469,1324.87 248.479,1324.88 248.488,1324.88 248.497,1324.88 248.506,1324.88 248.515,1324.88 248.525,1324.88 248.534,1324.88 248.543,1324.88 248.552,1324.88 248.561,1324.88 248.571,1324.88 248.58,1324.88 248.589,1324.88 248.598,1324.88 248.607,1324.88 248.617,1324.88 248.626,1324.89 248.635,1324.89 248.644,1324.89 248.653,1324.89 248.662,1324.89 248.672,1324.89 248.681,1324.89 248.69,1324.89 248.699,1324.89 248.708,1324.89 248.718,1324.89 248.727,1324.89 248.736,1324.89 248.745,1324.89 248.754,1324.89 248.764,1324.89 248.773,1324.9 248.782,1324.9 248.791,1324.9 248.8,1324.9 248.809,1324.9 248.819,1324.9 248.828,1324.9 248.837,1324.9 248.846,1324.9 248.855,1324.9 248.865,1324.9 248.874,1324.9 248.883,1324.9 248.892,1324.9 248.901,1324.9 248.911,1324.9 248.92,1324.9 248.929,1324.91 248.938,1324.91 248.947,1324.91 248.957,1324.91 248.966,1324.91 248.975,1324.91 248.984,1324.91 248.993,1324.91 249.002,1324.91 249.012,1324.91 249.021,1324.91 249.03,1324.91 249.039,1324.91 249.048,1324.91 249.058,1324.91 249.067,1324.91 249.076,1324.92 249.085,1324.92 249.094,1324.92 249.104,1324.92 249.113,1324.92 249.122,1324.92 249.131,1324.92 249.14,1324.92 249.149,1324.92 249.159,1324.92 249.168,1324.92 249.177,1324.92 249.186,1324.92 249.195,1324.92 249.205,1324.92 249.214,1324.92 249.223,1324.93 249.232,1324.93 249.241,1324.93 249.251,1324.93 249.26,1324.93 249.269,1324.93 249.278,1324.93 249.287,1324.93 249.297,1324.93 249.306,1324.93 249.315,1324.93 249.324,1324.93 249.333,1324.93 249.342,1324.93 249.352,1324.93 249.361,1324.93 249.37,1324.93 249.379,1324.94 249.388,1324.94 249.398,1324.94 249.407,1324.94 249.416,1324.94 249.425,1324.94 249.434,1324.94 249.444,1324.94 249.453,1324.94 249.462,1324.94 249.471,1324.94 249.48,1324.94 249.489,1324.94 249.499,1324.94 249.508,1324.94 249.517,1324.94 249.526,1324.95 249.535,1324.95 249.545,1324.95 249.554,1324.95 249.563,1324.95 249.572,1324.95 249.581,1324.95 249.591,1324.95 249.6,1324.95 249.609,1324.95 249.618,1324.95 249.627,1324.95 249.637,1324.95 249.646,1324.95 249.655,1324.95 249.664,1324.95 249.673,1324.96 249.682,1324.96 249.692,1324.96 249.701,1324.96 249.71,1324.96 249.719,1324.96 249.728,1324.96 249.738,1324.96 249.747,1324.96 249.756,1324.96 249.765,1324.96 249.774,1324.96 249.784,1324.96 249.793,1324.96 249.802,1324.96 249.811,1324.96 249.82,1324.96 249.829,1324.97 249.839,1324.97 249.848,1324.97 249.857,1324.97 249.866,1324.97 249.875,1324.97 249.885,1324.97 249.894,1324.97 249.903,1324.97 249.912,1324.97 249.921,1324.97 249.931,1324.97 249.94,1324.97 249.949,1324.97 249.958,1324.97 249.967,1324.97 249.977,1324.98 249.986,1324.98 249.995,1324.98 250.004,1324.98 250.013,1324.98 250.022,1324.98 250.032,1324.98 250.041,1324.98 250.05,1324.98 250.059,1324.98 250.068,1324.98 250.078,1324.98 250.087,1324.98 250.096,1324.98 250.105,1324.98 250.114,1324.98 250.124,1324.99 250.133,1324.99 250.142,1324.99 250.151,1324.99 250.16,1324.99 250.169,1324.99 250.179,1324.99 250.188,1324.99 250.197,1324.99 250.206,1324.99 250.215,1324.99 250.225,1324.99 250.234,1324.99 250.243,1324.99 250.252,1324.99 250.261,1324.99 250.271,1324.99 250.28,1325 250.289,1325 250.298,1325 250.307,1325 250.317,1325 250.326,1325 250.335,1325 250.344,1325 250.353,1325 250.362,1325 250.372,1325 250.381,1325 250.39,1325 250.399,1325 250.408,1325 250.418,1325 250.427,1325.01 250.436,1325.01 250.445,1325.01 250.454,1325.01 250.464,1325.01 250.473,1325.01 250.482,1325.01 250.491,1325.01 250.5,1325.01 250.51,1325.01 250.519,1325.01 250.528,1325.01 250.537,1325.01 250.546,1325.01 250.555,1325.01 250.565,1325.01 250.574,1325.02 250.583,1325.02 250.592,1325.02 250.601,1325.02 250.611,1325.02 250.62,1325.02 250.629,1325.02 250.638,1325.02 250.647,1325.02 250.657,1325.02 250.666,1325.02 250.675,1325.02 250.684,1325.02 250.693,1325.02 250.702,1325.02 250.712,1325.02 250.721,1325.02 250.73,1325.03 250.739,1325.03 250.748,1325.03 250.758,1325.03 250.767,1325.03 250.776,1325.03 250.785,1325.03 250.794,1325.03 250.804,1325.03 250.813,1325.03 250.822,1325.03 250.831,1325.03 250.84,1325.03 250.85,1325.03 250.859,1325.03 250.868,1325.03 250.877,1325.04 250.886,1325.04 250.895,1325.04 250.905,1325.04 250.914,1325.04 250.923,1325.04 250.932,1325.04 250.941,1325.04 250.951,1325.04 250.96,1325.04 250.969,1325.04 250.978,1325.04 250.987,1325.04 250.997,1325.04 251.006,1325.04 251.015,1325.04 251.024,1325.05 251.033,1325.05 251.042,1325.05 251.052,1325.05 251.061,1325.05 251.07,1325.05 251.079,1325.05 251.088,1325.05 251.098,1325.05 251.107,1325.05 251.116,1325.05 251.125,1325.05 251.134,1325.05 251.144,1325.05 251.153,1325.05 251.162,1325.05 251.171,1325.05 251.18,1325.06 251.19,1325.06 251.199,1325.06 251.208,1325.06 251.217,1325.06 251.226,1325.06 251.235,1325.06 251.245,1325.06 251.254,1325.06 251.263,1325.06 251.272,1325.06 251.281,1325.06 251.291,1325.06 251.3,1325.06 251.309,1325.06 251.318,1325.06 251.327,1325.07 251.337,1325.07 251.346,1325.07 251.355,1325.07 251.364,1325.07 251.373,1325.07 251.382,1325.07 251.392,1325.07 251.401,1325.07 251.41,1325.07 251.419,1325.07 251.428,1325.07 251.438,1325.07 251.447,1325.07 251.456,1325.07 251.465,1325.07 251.474,1325.08 251.484,1325.08 251.493,1325.08 251.502,1325.08 251.511,1325.08 251.52,1325.08 251.53,1325.08 251.539,1325.08 251.548,1325.08 251.557,1325.08 251.566,1325.08 251.575,1325.08 251.585,1325.08 251.594,1325.08 251.603,1325.08 251.612,1325.08 251.621,1325.08 251.631,1325.09 251.64,1325.09 251.649,1325.09 251.658,1325.09 251.667,1325.09 251.677,1325.09 251.686,1325.09 251.695,1325.09 251.704,1325.09 251.713,1325.09 251.722,1325.09 251.732,1325.09 251.741,1325.09 251.75,1325.09 251.759,1325.09 251.768,1325.09 251.778,1325.1 251.787,1325.1 251.796,1325.1 251.805,1325.1 251.814,1325.1 251.824,1325.1 251.833,1325.1 251.842,1325.1 251.851,1325.1 251.86,1325.1 251.87,1325.1 251.879,1325.1 251.888,1325.1 251.897,1325.1 251.906,1325.1 251.915,1325.1 251.925,1325.1 251.934,1325.11 251.943,1325.11 251.952,1325.11 251.961,1325.11 251.971,1325.11 251.98,1325.11 251.989,1325.11 251.998,1325.11 252.007,1325.11 252.017,1325.11 252.026,1325.11 252.035,1325.11 252.044,1325.11 252.053,1325.11 252.062,1325.11 252.072,1325.11 252.081,1325.12 252.09,1325.12 252.099,1325.12 252.108,1325.12 252.118,1325.12 252.127,1325.12 252.136,1325.12 252.145,1325.12 252.154,1325.12 252.164,1325.12 252.173,1325.12 252.182,1325.12 252.191,1325.12 252.2,1325.12 252.21,1325.12 252.219,1325.12 252.228,1325.13 252.237,1325.13 252.246,1325.13 252.255,1325.13 252.265,1325.13 252.274,1325.13 252.283,1325.13 252.292,1325.13 252.301,1325.13 252.311,1325.13 252.32,1325.13 252.329,1325.13 252.338,1325.13 252.347,1325.13 252.357,1325.13 252.366,1325.13 252.375,1325.13 252.384,1325.14 252.393,1325.14 252.402,1325.14 252.412,1325.14 252.421,1325.14 252.43,1325.14 252.439,1325.14 252.448,1325.14 252.458,1325.14 252.467,1325.14 252.476,1325.14 252.485,1325.14 252.494,1325.14 252.504,1325.14 252.513,1325.14 252.522,1325.14 252.531,1325.15 252.54,1325.15 252.55,1325.15 252.559,1325.15 252.568,1325.15 252.577,1325.15 252.586,1325.15 252.595,1325.15 252.605,1325.15 252.614,1325.15 252.623,1325.15 252.632,1325.15 252.641,1325.15 252.651,1325.15 252.66,1325.15 252.669,1325.15 252.678,1325.16 252.687,1325.16 252.697,1325.16 252.706,1325.16 252.715,1325.16 252.724,1325.16 252.733,1325.16 252.743,1325.16 252.752,1325.16 252.761,1325.16 252.77,1325.16 252.779,1325.16 252.788,1325.16 252.798,1325.16 252.807,1325.16 252.816,1325.16 252.825,1325.16 252.834,1325.17 252.844,1325.17 252.853,1325.17 252.862,1325.17 252.871,1325.17 252.88,1325.17 252.89,1325.17 252.899,1325.17 252.908,1325.17 252.917,1325.17 252.926,1325.17 252.935,1325.17 252.945,1325.17 252.954,1325.17 252.963,1325.17 252.972,1325.17 252.981,1325.18 252.991,1325.18 253,1325.18 253.009,1325.18 253.018,1325.18 253.027,1325.18 253.037,1325.18 253.046,1325.18 253.055,1325.18 253.064,1325.18 253.073,1325.18 253.083,1325.18 253.092,1325.18 253.101,1325.18 253.11,1325.18 253.119,1325.18 253.128,1325.18 253.138,1325.19 253.147,1325.19 253.156,1325.19 253.165,1325.19 253.174,1325.19 253.184,1325.19 253.193,1325.19 253.202,1325.19 253.211,1325.19 253.22,1325.19 253.23,1325.19 253.239,1325.19 253.248,1325.19 253.257,1325.19 253.266,1325.19 253.275,1325.19 253.285,1325.2 253.294,1325.2 253.303,1325.2 253.312,1325.2 253.321,1325.2 253.331,1325.2 253.34,1325.2 253.349,1325.2 253.358,1325.2 253.367,1325.2 253.377,1325.2 253.386,1325.2 253.395,1325.2 253.404,1325.2 253.413,1325.2 253.423,1325.2 253.432,1325.21 253.441,1325.21 253.45,1325.21 253.459,1325.21 253.468,1325.21 253.478,1325.21 253.487,1325.21 253.496,1325.21 253.505,1325.21 253.514,1325.21 253.524,1325.21 253.533,1325.21 253.542,1325.21 253.551,1325.21 253.56,1325.21 253.57,1325.21 253.579,1325.21 253.588,1325.22 253.597,1325.22 253.606,1325.22 253.615,1325.22 253.625,1325.22 253.634,1325.22 253.643,1325.22 253.652,1325.22 253.661,1325.22 253.671,1325.22 253.68,1325.22 253.689,1325.22 253.698,1325.22 253.707,1325.22 253.717,1325.22 253.726,1325.22 253.735,1325.23 253.744,1325.23 253.753,1325.23 253.763,1325.23 253.772,1325.23 253.781,1325.23 253.79,1325.23 253.799,1325.23 253.808,1325.23 253.818,1325.23 253.827,1325.23 253.836,1325.23 253.845,1325.23 253.854,1325.23 253.864,1325.23 253.873,1325.23 253.882,1325.24 253.891,1325.24 253.9,1325.24 253.91,1325.24 253.919,1325.24 253.928,1325.24 253.937,1325.24 253.946,1325.24 253.955,1325.24 253.965,1325.24 253.974,1325.24 253.983,1325.24 253.992,1325.24 254.001,1325.24 254.011,1325.24 254.02,1325.24 254.029,1325.24 254.038,1325.25 254.047,1325.25 254.057,1325.25 254.066,1325.25 254.075,1325.25 254.084,1325.25 254.093,1325.25 254.103,1325.25 254.112,1325.25 254.121,1325.25 254.13,1325.25 254.139,1325.25 254.148,1325.25 254.158,1325.25 254.167,1325.25 254.176,1325.25 254.185,1325.26 254.194,1325.26 254.204,1325.26 254.213,1325.26 254.222,1325.26 254.231,1325.26 254.24,1325.26 254.25,1325.26 254.259,1325.26 254.268,1325.26 254.277,1325.26 254.286,1325.26 254.295,1325.26 254.305,1325.26 254.314,1325.26 254.323,1325.26 254.332,1325.26 254.341,1325.27 254.351,1325.27 254.36,1325.27 254.369,1325.27 254.378,1325.27 254.387,1325.27 254.397,1325.27 254.406,1325.27 254.415,1325.27 254.424,1325.27 254.433,1325.27 254.443,1325.27 254.452,1325.27 254.461,1325.27 254.47,1325.27 254.479,1325.27 254.488,1325.28 254.498,1325.28 254.507,1325.28 254.516,1325.28 254.525,1325.28 254.534,1325.28 254.544,1325.28 254.553,1325.28 254.562,1325.28 254.571,1325.28 254.58,1325.28 254.59,1325.28 254.599,1325.28 254.608,1325.28 254.617,1325.28 254.626,1325.28 254.635,1325.29 254.645,1325.29 254.654,1325.29 254.663,1325.29 254.672,1325.29 254.681,1325.29 254.691,1325.29 254.7,1325.29 254.709,1325.29 254.718,1325.29 254.727,1325.29 254.737,1325.29 254.746,1325.29 254.755,1325.29 254.764,1325.29 254.773,1325.29 254.783,1325.29 254.792,1325.3 254.801,1325.3 254.81,1325.3 254.819,1325.3 254.828,1325.3 254.838,1325.3 254.847,1325.3 254.856,1325.3 254.865,1325.3 254.874,1325.3 254.884,1325.3 254.893,1325.3 254.902,1325.3 254.911,1325.3 254.92,1325.3 254.93,1325.3 254.939,1325.31 254.948,1325.31 254.957,1325.31 254.966,1325.31 254.975,1325.31 254.985,1325.31 254.994,1325.31 255.003,1325.31 255.012,1325.31 255.021,1325.31 255.031,1325.31 255.04,1325.31 255.049,1325.31 255.058,1325.31 255.067,1325.31 255.077,1325.31 255.086,1325.31 255.095,1325.32 255.104,1325.32 255.113,1325.32 255.123,1325.32 255.132,1325.32 255.141,1325.32 255.15,1325.32 255.159,1325.32 255.168,1325.32 255.178,1325.32 255.187,1325.32 255.196,1325.32 255.205,1325.32 255.214,1325.32 255.224,1325.32 255.233,1325.32 255.242,1325.33 255.251,1325.33 255.26,1325.33 255.27,1325.33 255.279,1325.33 255.288,1325.33 255.297,1325.33 255.306,1325.33 255.316,1325.33 255.325,1325.33 255.334,1325.33 255.343,1325.33 255.352,1325.33 255.361,1325.33 255.371,1325.33 255.38,1325.33 255.389,1325.34 255.398,1325.34 255.407,1325.34 255.417,1325.34 255.426,1325.34 255.435,1325.34 255.444,1325.34 255.453,1325.34 255.463,1325.34 255.472,1325.34 255.481,1325.34 255.49,1325.34 255.499,1325.34 255.508,1325.34 255.518,1325.34 255.527,1325.34 255.536,1325.34 255.545,1325.35 255.554,1325.35 255.564,1325.35 255.573,1325.35 255.582,1325.35 255.591,1325.35 255.6,1325.35 255.61,1325.35 255.619,1325.35 255.628,1325.35 255.637,1325.35 255.646,1325.35 255.656,1325.35 255.665,1325.35 255.674,1325.35 255.683,1325.35 255.692,1325.36 255.701,1325.36 255.711,1325.36 255.72,1325.36 255.729,1325.36 255.738,1325.36 255.747,1325.36 255.757,1325.36 255.766,1325.36 255.775,1325.36 255.784,1325.36 255.793,1325.36 255.803,1325.36 255.812,1325.36 255.821,1325.36 255.83,1325.36 255.839,1325.36 255.848,1325.37 255.858,1325.37 255.867,1325.37 255.876,1325.37 255.885,1325.37 255.894,1325.37 255.904,1325.37 255.913,1325.37 255.922,1325.37 255.931,1325.37 255.94,1325.37 255.95,1325.37 255.959,1325.37 255.968,1325.37 255.977,1325.37 255.986,1325.37 255.996,1325.38 256.005,1325.38 256.014,1325.38 256.023,1325.38 256.032,1325.38 256.041,1325.38 256.051,1325.38 256.06,1325.38 256.069,1325.38 256.078,1325.38 256.087,1325.38 256.097,1325.38 256.106,1325.38 256.115,1325.38 256.124,1325.38 256.133,1325.38 256.143,1325.38 256.152,1325.39 256.161,1325.39 256.17,1325.39 256.179,1325.39 256.188,1325.39 256.198,1325.39 256.207,1325.39 256.216,1325.39 256.225,1325.39 256.234,1325.39 256.244,1325.39 256.253,1325.39 256.262,1325.39 256.271,1325.39 256.28,1325.39 256.29,1325.39 256.299,1325.4 256.308,1325.4 256.317,1325.4 256.326,1325.4 256.336,1325.4 256.345,1325.4 256.354,1325.4 256.363,1325.4 256.372,1325.4 256.381,1325.4 256.391,1325.4 256.4,1325.4 256.409,1325.4 256.418,1325.4 256.427,1325.4 256.437,1325.4 256.446,1325.41 256.455,1325.41 256.464,1325.41 256.473,1325.41 256.483,1325.41 256.492,1325.41 256.501,1325.41 256.51,1325.41 256.519,1325.41 256.528,1325.41 256.538,1325.41 256.547,1325.41 256.556,1325.41 256.565,1325.41 256.574,1325.41 256.584,1325.41 256.593,1325.41 256.602,1325.42 256.611,1325.42 256.62,1325.42 256.63,1325.42 256.639,1325.42 256.648,1325.42 256.657,1325.42 256.666,1325.42 256.676,1325.42 256.685,1325.42 256.694,1325.42 256.703,1325.42 256.712,1325.42 256.721,1325.42 256.731,1325.42 256.74,1325.42 256.749,1325.43 256.758,1325.43 256.767,1325.43 256.777,1325.43 256.786,1325.43 256.795,1325.43 256.804,1325.43 256.813,1325.43 256.823,1325.43 256.832,1325.43 256.841,1325.43 256.85,1325.43 256.859,1325.43 256.868,1325.43 256.878,1325.43 256.887,1325.43 256.896,1325.43 256.905,1325.44 256.914,1325.44 256.924,1325.44 256.933,1325.44 256.942,1325.44 256.951,1325.44 256.96,1325.44 256.97,1325.44 256.979,1325.44 256.988,1325.44 256.997,1325.44 257.006,1325.44 257.016,1325.44 257.025,1325.44 257.034,1325.44 257.043,1325.44 257.052,1325.45 257.061,1325.45 257.071,1325.45 257.08,1325.45 257.089,1325.45 257.098,1325.45 257.107,1325.45 257.117,1325.45 257.126,1325.45 257.135,1325.45 257.144,1325.45 257.153,1325.45 257.163,1325.45 257.172,1325.45 257.181,1325.45 257.19,1325.45 257.199,1325.45 257.208,1325.46 257.218,1325.46 257.227,1325.46 257.236,1325.46 257.245,1325.46 257.254,1325.46 257.264,1325.46 257.273,1325.46 257.282,1325.46 257.291,1325.46 257.3,1325.46 257.31,1325.46 257.319,1325.46 257.328,1325.46 257.337,1325.46 257.346,1325.46 257.356,1325.47 257.365,1325.47 257.374,1325.47 257.383,1325.47 257.392,1325.47 257.401,1325.47 257.411,1325.47 257.42,1325.47 257.429,1325.47 257.438,1325.47 257.447,1325.47 257.457,1325.47 257.466,1325.47 257.475,1325.47 257.484,1325.47 257.493,1325.47 257.503,1325.48 257.512,1325.48 257.521,1325.48 257.53,1325.48 257.539,1325.48 257.548,1325.48 257.558,1325.48 257.567,1325.48 257.576,1325.48 257.585,1325.48 257.594,1325.48 257.604,1325.48 257.613,1325.48 257.622,1325.48 257.631,1325.48 257.64,1325.48 257.65,1325.48 257.659,1325.49 257.668,1325.49 257.677,1325.49 257.686,1325.49 257.696,1325.49 257.705,1325.49 257.714,1325.49 257.723,1325.49 257.732,1325.49 257.741,1325.49 257.751,1325.49 257.76,1325.49 257.769,1325.49 257.778,1325.49 257.787,1325.49 257.797,1325.49 257.806,1325.5 257.815,1325.5 257.824,1325.5 257.833,1325.5 257.843,1325.5 257.852,1325.5 257.861,1325.5 257.87,1325.5 257.879,1325.5 257.889,1325.5 257.898,1325.5 257.907,1325.5 257.916,1325.5 257.925,1325.5 257.934,1325.5 257.944,1325.5 257.953,1325.5 257.962,1325.51 257.971,1325.51 257.98,1325.51 257.99,1325.51 257.999,1325.51 258.008,1325.51 258.017,1325.51 258.026,1325.51 258.036,1325.51 258.045,1325.51 258.054,1325.51 258.063,1325.51 258.072,1325.51 258.081,1325.51 258.091,1325.51 258.1,1325.51 258.109,1325.52 258.118,1325.52 258.127,1325.52 258.137,1325.52 258.146,1325.52 258.155,1325.52 258.164,1325.52 258.173,1325.52 258.183,1325.52 258.192,1325.52 258.201,1325.52 258.21,1325.52 258.219,1325.52 258.229,1325.52 258.238,1325.52 258.247,1325.52 258.256,1325.52 258.265,1325.53 258.274,1325.53 258.284,1325.53 258.293,1325.53 258.302,1325.53 258.311,1325.53 258.32,1325.53 258.33,1325.53 258.339,1325.53 258.348,1325.53 258.357,1325.53 258.366,1325.53 258.376,1325.53 258.385,1325.53 258.394,1325.53 258.403,1325.53 258.412,1325.54 258.421,1325.54 258.431,1325.54 258.44,1325.54 258.449,1325.54 258.458,1325.54 258.467,1325.54 258.477,1325.54 258.486,1325.54 258.495,1325.54 258.504,1325.54 258.513,1325.54 258.523,1325.54 258.532,1325.54 258.541,1325.54 258.55,1325.54 258.559,1325.54 258.569,1325.55 258.578,1325.55 258.587,1325.55 258.596,1325.55 258.605,1325.55 258.614,1325.55 258.624,1325.55 258.633,1325.55 258.642,1325.55 258.651,1325.55 258.66,1325.55 258.67,1325.55 258.679,1325.55 258.688,1325.55 258.697,1325.55 258.706,1325.55 258.716,1325.56 258.725,1325.56 258.734,1325.56 258.743,1325.56 258.752,1325.56 258.761,1325.56 258.771,1325.56 258.78,1325.56 258.789,1325.56 258.798,1325.56 258.807,1325.56 258.817,1325.56 258.826,1325.56 258.835,1325.56 258.844,1325.56 258.853,1325.56 258.863,1325.57 258.872,1325.57 258.881,1325.57 258.89,1325.57 258.899,1325.57 258.909,1325.57 258.918,1325.57 258.927,1325.57 258.936,1325.57 258.945,1325.57 258.954,1325.57 258.964,1325.57 258.973,1325.57 258.982,1325.57 258.991,1325.57 259,1325.57 259.01,1325.57 259.019,1325.58 259.028,1325.58 259.037,1325.58 259.046,1325.58 259.056,1325.58 259.065,1325.58 259.074,1325.58 259.083,1325.58 259.092,1325.58 259.101,1325.58 259.111,1325.58 259.12,1325.58 259.129,1325.58 259.138,1325.58 259.147,1325.58 259.157,1325.58 259.166,1325.59 259.175,1325.59 259.184,1325.59 259.193,1325.59 259.203,1325.59 259.212,1325.59 259.221,1325.59 259.23,1325.59 259.239,1325.59 259.249,1325.59 259.258,1325.59 259.267,1325.59 259.276,1325.59 259.285,1325.59 259.294,1325.59 259.304,1325.59 259.313,1325.59 259.322,1325.6 259.331,1325.6 259.34,1325.6 259.35,1325.6 259.359,1325.6 259.368,1325.6 259.377,1325.6 259.386,1325.6 259.396,1325.6 259.405,1325.6 259.414,1325.6 259.423,1325.6 259.432,1325.6 259.441,1325.6 259.451,1325.6 259.46,1325.6 259.469,1325.61 259.478,1325.61 259.487,1325.61 259.497,1325.61 259.506,1325.61 259.515,1325.61 259.524,1325.61 259.533,1325.61 259.543,1325.61 259.552,1325.61 259.561,1325.61 259.57,1325.61 259.579,1325.61 259.589,1325.61 259.598,1325.61 259.607,1325.61 259.616,1325.61 259.625,1325.62 259.634,1325.62 259.644,1325.62 259.653,1325.62 259.662,1325.62 259.671,1325.62 259.68,1325.62 259.69,1325.62 259.699,1325.62 259.708,1325.62 259.717,1325.62 259.726,1325.62 259.736,1325.62 259.745,1325.62 259.754,1325.62 259.763,1325.62 259.772,1325.63 259.781,1325.63 259.791,1325.63 259.8,1325.63 259.809,1325.63 259.818,1325.63 259.827,1325.63 259.837,1325.63 259.846,1325.63 259.855,1325.63 259.864,1325.63 259.873,1325.63 259.883,1325.63 259.892,1325.63 259.901,1325.63 259.91,1325.63 259.919,1325.63 259.929,1325.64 259.938,1325.64 259.947,1325.64 259.956,1325.64 259.965,1325.64 259.974,1325.64 259.984,1325.64 259.993,1325.64 260.002,1325.64 260.011,1325.64 260.02,1325.64 260.03,1325.64 260.039,1325.64 260.048,1325.64 260.057,1325.64 260.066,1325.64 260.076,1325.65 260.085,1325.65 260.094,1325.65 260.103,1325.65 260.112,1325.65 260.122,1325.65 260.131,1325.65 260.14,1325.65 260.149,1325.65 260.158,1325.65 260.167,1325.65 260.177,1325.65 260.186,1325.65 260.195,1325.65 260.204,1325.65 260.213,1325.65 260.223,1325.65 260.232,1325.66 260.241,1325.66 260.25,1325.66 260.259,1325.66 260.269,1325.66 260.278,1325.66 260.287,1325.66 260.296,1325.66 260.305,1325.66 260.314,1325.66 260.324,1325.66 260.333,1325.66 260.342,1325.66 260.351,1325.66 260.36,1325.66 260.37,1325.66 260.379,1325.67 260.388,1325.67 260.397,1325.67 260.406,1325.67 260.416,1325.67 260.425,1325.67 260.434,1325.67 260.443,1325.67 260.452,1325.67 260.462,1325.67 260.471,1325.67 260.48,1325.67 260.489,1325.67 260.498,1325.67 260.507,1325.67 260.517,1325.67 260.526,1325.67 260.535,1325.68 260.544,1325.68 260.553,1325.68 260.563,1325.68 260.572,1325.68 260.581,1325.68 260.59,1325.68 260.599,1325.68 260.609,1325.68 260.618,1325.68 260.627,1325.68 260.636,1325.68 260.645,1325.68 260.654,1325.68 260.664,1325.68 260.673,1325.68 260.682,1325.69 260.691,1325.69 260.7,1325.69 260.71,1325.69 260.719,1325.69 260.728,1325.69 260.737,1325.69 260.746,1325.69 260.756,1325.69 260.765,1325.69 260.774,1325.69 260.783,1325.69 260.792,1325.69 260.802,1325.69 260.811,1325.69 260.82,1325.69 260.829,1325.69 260.838,1325.7 260.847,1325.7 260.857,1325.7 260.866,1325.7 260.875,1325.7 260.884,1325.7 260.893,1325.7 260.903,1325.7 260.912,1325.7 260.921,1325.7 260.93,1325.7 260.939,1325.7 260.949,1325.7 260.958,1325.7 260.967,1325.7 260.976,1325.7 260.985,1325.71 260.994,1325.71 261.004,1325.71 261.013,1325.71 261.022,1325.71 261.031,1325.71 261.04,1325.71 261.05,1325.71 261.059,1325.71 261.068,1325.71 261.077,1325.71 261.086,1325.71 261.096,1325.71 261.105,1325.71 261.114,1325.71 261.123,1325.71 261.132,1325.71 261.142,1325.72 261.151,1325.72 261.16,1325.72 261.169,1325.72 261.178,1325.72 261.187,1325.72 261.197,1325.72 261.206,1325.72 261.215,1325.72 261.224,1325.72 261.233,1325.72 261.243,1325.72 261.252,1325.72 261.261,1325.72 261.27,1325.72 261.279,1325.72 261.289,1325.73 261.298,1325.73 261.307,1325.73 261.316,1325.73 261.325,1325.73 261.334,1325.73 261.344,1325.73 261.353,1325.73 261.362,1325.73 261.371,1325.73 261.38,1325.73 261.39,1325.73 261.399,1325.73 261.408,1325.73 261.417,1325.73 261.426,1325.73 261.436,1325.73 261.445,1325.74 261.454,1325.74 261.463,1325.74 261.472,1325.74 261.482,1325.74 261.491,1325.74 261.5,1325.74 261.509,1325.74 261.518,1325.74 261.527,1325.74 261.537,1325.74 261.546,1325.74 261.555,1325.74 261.564,1325.74 261.573,1325.74 261.583,1325.74 261.592,1325.75 261.601,1325.75 261.61,1325.75 261.619,1325.75 261.629,1325.75 261.638,1325.75 261.647,1325.75 261.656,1325.75 261.665,1325.75 261.674,1325.75 261.684,1325.75 261.693,1325.75 261.702,1325.75 261.711,1325.75 261.72,1325.75 261.73,1325.75 261.739,1325.76 261.748,1325.76 261.757,1325.76 261.766,1325.76 261.776,1325.76 261.785,1325.76 261.794,1325.76 261.803,1325.76 261.812,1325.76 261.822,1325.76 261.831,1325.76 261.84,1325.76 261.849,1325.76 261.858,1325.76 261.867,1325.76 261.877,1325.76 261.886,1325.76 261.895,1325.77 261.904,1325.77 261.913,1325.77 261.923,1325.77 261.932,1325.77 261.941,1325.77 261.95,1325.77 261.959,1325.77 261.969,1325.77 261.978,1325.77 261.987,1325.77 261.996,1325.77 262.005,1325.77 262.014,1325.77 262.024,1325.77 262.033,1325.77 262.042,1325.78 262.051,1325.78 262.06,1325.78 262.07,1325.78 262.079,1325.78 262.088,1325.78 262.097,1325.78 262.106,1325.78 262.116,1325.78 262.125,1325.78 262.134,1325.78 262.143,1325.78 262.152,1325.78 262.162,1325.78 262.171,1325.78 262.18,1325.78 262.189,1325.78 262.198,1325.79 262.207,1325.79 262.217,1325.79 262.226,1325.79 262.235,1325.79 262.244,1325.79 262.253,1325.79 262.263,1325.79 262.272,1325.79 262.281,1325.79 262.29,1325.79 262.299,1325.79 262.309,1325.79 262.318,1325.79 262.327,1325.79 262.336,1325.79 262.345,1325.8 262.354,1325.8 262.364,1325.8 262.373,1325.8 262.382,1325.8 262.391,1325.8 262.4,1325.8 262.41,1325.8 262.419,1325.8 262.428,1325.8 262.437,1325.8 262.446,1325.8 262.456,1325.8 262.465,1325.8 262.474,1325.8 262.483,1325.8 262.492,1325.8 262.502,1325.81 262.511,1325.81 262.52,1325.81 262.529,1325.81 262.538,1325.81 262.547,1325.81 262.557,1325.81 262.566,1325.81 262.575,1325.81 262.584,1325.81 262.593,1325.81 262.603,1325.81 262.612,1325.81 262.621,1325.81 262.63,1325.81 262.639,1325.81 262.649,1325.81 262.658,1325.82 262.667,1325.82 262.676,1325.82 262.685,1325.82 262.695,1325.82 262.704,1325.82 262.713,1325.82 262.722,1325.82 262.731,1325.82 262.74,1325.82 262.75,1325.82 262.759,1325.82 262.768,1325.82 262.777,1325.82 262.786,1325.82 262.796,1325.82 262.805,1325.83 262.814,1325.83 262.823,1325.83 262.832,1325.83 262.842,1325.83 262.851,1325.83 262.86,1325.83 262.869,1325.83 262.878,1325.83 262.887,1325.83 262.897,1325.83 262.906,1325.83 262.915,1325.83 262.924,1325.83 262.933,1325.83 262.943,1325.83 262.952,1325.83 262.961,1325.84 262.97,1325.84 262.979,1325.84 262.989,1325.84 262.998,1325.84 263.007,1325.84 263.016,1325.84 263.025,1325.84 263.035,1325.84 263.044,1325.84 263.053,1325.84 263.062,1325.84 263.071,1325.84 263.08,1325.84 263.09,1325.84 263.099,1325.84 263.108,1325.85 263.117,1325.85 263.126,1325.85 263.136,1325.85 263.145,1325.85 263.154,1325.85 263.163,1325.85 263.172,1325.85 263.182,1325.85 263.191,1325.85 263.2,1325.85 263.209,1325.85 263.218,1325.85 263.227,1325.85 263.237,1325.85 263.246,1325.85 263.255,1325.85 263.264,1325.86 263.273,1325.86 263.283,1325.86 263.292,1325.86 263.301,1325.86 263.31,1325.86 263.319,1325.86 263.329,1325.86 263.338,1325.86 263.347,1325.86 263.356,1325.86 263.365,1325.86 263.375,1325.86 263.384,1325.86 263.393,1325.86 263.402,1325.86 263.411,1325.87 263.42,1325.87 263.43,1325.87 263.439,1325.87 263.448,1325.87 263.457,1325.87 263.466,1325.87 263.476,1325.87 263.485,1325.87 263.494,1325.87 263.503,1325.87 263.512,1325.87 263.522,1325.87 263.531,1325.87 263.54,1325.87 263.549,1325.87 263.558,1325.87 263.567,1325.88 263.577,1325.88 263.586,1325.88 263.595,1325.88 263.604,1325.88 263.613,1325.88 263.623,1325.88 263.632,1325.88 263.641,1325.88 263.65,1325.88 263.659,1325.88 263.669,1325.88 263.678,1325.88 263.687,1325.88 263.696,1325.88 263.705,1325.88 263.715,1325.89 263.724,1325.89 263.733,1325.89 263.742,1325.89 263.751,1325.89 263.76,1325.89 263.77,1325.89 263.779,1325.89 263.788,1325.89 263.797,1325.89 263.806,1325.89 263.816,1325.89 263.825,1325.89 263.834,1325.89 263.843,1325.89 263.852,1325.89 263.862,1325.89 263.871,1325.9 263.88,1325.9 263.889,1325.9 263.898,1325.9 263.907,1325.9 263.917,1325.9 263.926,1325.9 263.935,1325.9 263.944,1325.9 263.953,1325.9 263.963,1325.9 263.972,1325.9 263.981,1325.9 263.99,1325.9 263.999,1325.9 264.009,1325.9 264.018,1325.91 264.027,1325.91 264.036,1325.91 264.045,1325.91 264.055,1325.91 264.064,1325.91 264.073,1325.91 264.082,1325.91 264.091,1325.91 264.1,1325.91 264.11,1325.91 264.119,1325.91 264.128,1325.91 264.137,1325.91 264.146,1325.91 264.156,1325.91 264.165,1325.91 264.174,1325.92 264.183,1325.92 264.192,1325.92 264.202,1325.92 264.211,1325.92 264.22,1325.92 264.229,1325.92 264.238,1325.92 264.247,1325.92 264.257,1325.92 264.266,1325.92 264.275,1325.92 264.284,1325.92 264.293,1325.92 264.303,1325.92 264.312,1325.92 264.321,1325.93 264.33,1325.93 264.339,1325.93 264.349,1325.93 264.358,1325.93 264.367,1325.93 264.376,1325.93 264.385,1325.93 264.395,1325.93 264.404,1325.93 264.413,1325.93 264.422,1325.93 264.431,1325.93 264.44,1325.93 264.45,1325.93 264.459,1325.93 264.468,1325.93 264.477,1325.94 264.486,1325.94 264.496,1325.94 264.505,1325.94 264.514,1325.94 264.523,1325.94 264.532,1325.94 264.542,1325.94 264.551,1325.94 264.56,1325.94 264.569,1325.94 264.578,1325.94 264.587,1325.94 264.597,1325.94 264.606,1325.94 264.615,1325.94 264.624,1325.95 264.633,1325.95 264.643,1325.95 264.652,1325.95 264.661,1325.95 264.67,1325.95 264.679,1325.95 264.689,1325.95 264.698,1325.95 264.707,1325.95 264.716,1325.95 264.725,1325.95 264.735,1325.95 264.744,1325.95 264.753,1325.95 264.762,1325.95 264.771,1325.95 264.78,1325.96 264.79,1325.96 264.799,1325.96 264.808,1325.96 264.817,1325.96 264.826,1325.96 264.836,1325.96 264.845,1325.96 264.854,1325.96 264.863,1325.96 264.872,1325.96 264.882,1325.96 264.891,1325.96 264.9,1325.96 264.909,1325.96 264.918,1325.96 264.927,1325.97 264.937,1325.97 264.946,1325.97 264.955,1325.97 264.964,1325.97 264.973,1325.97 264.983,1325.97 264.992,1325.97 265.001,1325.97 265.01,1325.97 265.019,1325.97 265.029,1325.97 265.038,1325.97 265.047,1325.97 265.056,1325.97 265.065,1325.97 265.075,1325.97 265.084,1325.98 265.093,1325.98 265.102,1325.98 265.111,1325.98 265.12,1325.98 265.13,1325.98 265.139,1325.98 265.148,1325.98 265.157,1325.98 265.166,1325.98 265.176,1325.98 265.185,1325.98 265.194,1325.98 265.203,1325.98 265.212,1325.98 265.222,1325.98 265.231,1325.99 265.24,1325.99 265.249,1325.99 265.258,1325.99 265.268,1325.99 265.277,1325.99 265.286,1325.99 265.295,1325.99 265.304,1325.99 265.313,1325.99 265.323,1325.99 265.332,1325.99 265.341,1325.99 265.35,1325.99 265.359,1325.99 265.369,1325.99 265.378,1325.99 265.387,1326 265.396,1326 265.405,1326 265.415,1326 265.424,1326 265.433,1326 265.442,1326 265.451,1326 265.46,1326 265.47,1326 265.479,1326 265.488,1326 265.497,1326 265.506,1326 265.516,1326 265.525,1326 265.534,1326 265.543,1326.01 265.552,1326.01 265.562,1326.01 265.571,1326.01 265.58,1326.01 265.589,1326.01 265.598,1326.01 265.608,1326.01 265.617,1326.01 265.626,1326.01 265.635,1326.01 265.644,1326.01 265.653,1326.01 265.663,1326.01 265.672,1326.01 265.681,1326.01 265.69,1326.02 265.699,1326.02 265.709,1326.02 265.718,1326.02 265.727,1326.02 265.736,1326.02 265.745,1326.02 265.755,1326.02 265.764,1326.02 265.773,1326.02 265.782,1326.02 265.791,1326.02 265.8,1326.02 265.81,1326.02 265.819,1326.02 265.828,1326.02 265.837,1326.02 265.846,1326.03 265.856,1326.03 265.865,1326.03 265.874,1326.03 265.883,1326.03 265.892,1326.03 265.902,1326.03 265.911,1326.03 265.92,1326.03 265.929,1326.03 265.938,1326.03 265.948,1326.03 265.957,1326.03 265.966,1326.03 265.975,1326.03 265.984,1326.03 265.993,1326.04 266.003,1326.04 266.012,1326.04 266.021,1326.04 266.03,1326.04 266.039,1326.04 266.049,1326.04 266.058,1326.04 266.067,1326.04 266.076,1326.04 266.085,1326.04 266.095,1326.04 266.104,1326.04 266.113,1326.04 266.122,1326.04 266.131,1326.04 266.14,1326.04 266.15,1326.05 266.159,1326.05 266.168,1326.05 266.177,1326.05 266.186,1326.05 266.196,1326.05 266.205,1326.05 266.214,1326.05 266.223,1326.05 266.232,1326.05 266.242,1326.05 266.251,1326.05 266.26,1326.05 266.269,1326.05 266.278,1326.05 266.288,1326.05 266.297,1326.06 266.306,1326.06 266.315,1326.06 266.324,1326.06 266.333,1326.06 266.343,1326.06 266.352,1326.06 266.361,1326.06 266.37,1326.06 266.379,1326.06 266.389,1326.06 266.398,1326.06 266.407,1326.06 266.416,1326.06 266.425,1326.06 266.435,1326.06 266.444,1326.06 266.453,1326.07 266.462,1326.07 266.471,1326.07 266.48,1326.07 266.49,1326.07 266.499,1326.07 266.508,1326.07 266.517,1326.07 266.526,1326.07 266.536,1326.07 266.545,1326.07 266.554,1326.07 266.563,1326.07 266.572,1326.07 266.582,1326.07 266.591,1326.07 266.6,1326.08 266.609,1326.08 266.618,1326.08 266.628,1326.08 266.637,1326.08 266.646,1326.08 266.655,1326.08 266.664,1326.08 266.673,1326.08 266.683,1326.08 266.692,1326.08 266.701,1326.08 266.71,1326.08 266.719,1326.08 266.729,1326.08 266.738,1326.08 266.747,1326.08 266.756,1326.09 266.765,1326.09 266.775,1326.09 266.784,1326.09 266.793,1326.09 266.802,1326.09 266.811,1326.09 266.82,1326.09 266.83,1326.09 266.839,1326.09 266.848,1326.09 266.857,1326.09 266.866,1326.09 266.876,1326.09 266.885,1326.09 266.894,1326.09 266.903,1326.09 266.912,1326.1 266.922,1326.1 266.931,1326.1 266.94,1326.1 266.949,1326.1 266.958,1326.1 266.968,1326.1 266.977,1326.1 266.986,1326.1 266.995,1326.1 267.004,1326.1 267.013,1326.1 267.023,1326.1 267.032,1326.1 267.041,1326.1 267.05,1326.1 267.059,1326.11 267.069,1326.11 267.078,1326.11 267.087,1326.11 267.096,1326.11 267.105,1326.11 267.115,1326.11 267.124,1326.11 267.133,1326.11 267.142,1326.11 267.151,1326.11 267.16,1326.11 267.17,1326.11 267.179,1326.11 267.188,1326.11 267.197,1326.11 267.206,1326.11 267.216,1326.12 267.225,1326.12 267.234,1326.12 267.243,1326.12 267.252,1326.12 267.262,1326.12 267.271,1326.12 267.28,1326.12 267.289,1326.12 267.298,1326.12 267.308,1326.12 267.317,1326.12 267.326,1326.12 267.335,1326.12 267.344,1326.12 267.353,1326.12 267.363,1326.13 267.372,1326.13 267.381,1326.13 267.39,1326.13 267.399,1326.13 267.409,1326.13 267.418,1326.13 267.427,1326.13 267.436,1326.13 267.445,1326.13 267.455,1326.13 267.464,1326.13 267.473,1326.13 267.482,1326.13 267.491,1326.13 267.501,1326.13 267.51,1326.13 267.519,1326.14 267.528,1326.14 267.537,1326.14 267.546,1326.14 267.556,1326.14 267.565,1326.14 267.574,1326.14 267.583,1326.14 267.592,1326.14 267.602,1326.14 267.611,1326.14 267.62,1326.14 267.629,1326.14 267.638,1326.14 267.648,1326.14 267.657,1326.14 267.666,1326.15 267.675,1326.15 267.684,1326.15 267.693,1326.15 267.703,1326.15 267.712,1326.15 267.721,1326.15 267.73,1326.15 267.739,1326.15 267.749,1326.15 267.758,1326.15 267.767,1326.15 267.776,1326.15 267.785,1326.15 267.795,1326.15 267.804,1326.15 267.813,1326.15 267.822,1326.16 267.831,1326.16 267.841,1326.16 267.85,1326.16 267.859,1326.16 267.868,1326.16 267.877,1326.16 267.886,1326.16 267.896,1326.16 267.905,1326.16 267.914,1326.16 267.923,1326.16 267.932,1326.16 267.942,1326.16 267.951,1326.16 267.96,1326.16 267.969,1326.16 267.978,1326.17 267.988,1326.17 267.997,1326.17 268.006,1326.17 268.015,1326.17 268.024,1326.17 268.033,1326.17 268.043,1326.17 268.052,1326.17 268.061,1326.17 268.07,1326.17 268.079,1326.17 268.089,1326.17 268.098,1326.17 268.107,1326.17 268.116,1326.17 268.125,1326.18 268.135,1326.18 268.144,1326.18 268.153,1326.18 268.162,1326.18 268.171,1326.18 268.181,1326.18 268.19,1326.18 268.199,1326.18 268.208,1326.18 268.217,1326.18 268.226,1326.18 268.236,1326.18 268.245,1326.18 268.254,1326.18 268.263,1326.18 268.272,1326.18 268.282,1326.19 268.291,1326.19 268.3,1326.19 268.309,1326.19 268.318,1326.19 268.328,1326.19 268.337,1326.19 268.346,1326.19 268.355,1326.19 268.364,1326.19 268.373,1326.19 268.383,1326.19 268.392,1326.19 268.401,1326.19 268.41,1326.19 268.419,1326.19 268.429,1326.2 268.438,1326.2 268.447,1326.2 268.456,1326.2 268.465,1326.2 268.475,1326.2 268.484,1326.2 268.493,1326.2 268.502,1326.2 268.511,1326.2 268.521,1326.2 268.53,1326.2 268.539,1326.2 268.548,1326.2 268.557,1326.2 268.566,1326.2 268.576,1326.2 268.585,1326.21 268.594,1326.21 268.603,1326.21 268.612,1326.21 268.622,1326.21 268.631,1326.21 268.64,1326.21 268.649,1326.21 268.658,1326.21 268.668,1326.21 268.677,1326.21 268.686,1326.21 268.695,1326.21 268.704,1326.21 268.713,1326.21 268.723,1326.21 268.732,1326.22 268.741,1326.22 268.75,1326.22 268.759,1326.22 268.769,1326.22 268.778,1326.22 268.787,1326.22 268.796,1326.22 268.805,1326.22 268.815,1326.22 268.824,1326.22 268.833,1326.22 268.842,1326.22 268.851,1326.22 268.861,1326.22 268.87,1326.22 268.879,1326.22 268.888,1326.23 268.897,1326.23 268.906,1326.23 268.916,1326.23 268.925,1326.23 268.934,1326.23 268.943,1326.23 268.952,1326.23 268.962,1326.23 268.971,1326.23 268.98,1326.23 268.989,1326.23 268.998,1326.23 269.008,1326.23 269.017,1326.23 269.026,1326.23 269.035,1326.23 269.044,1326.24 269.053,1326.24 269.063,1326.24 269.072,1326.24 269.081,1326.24 269.09,1326.24 269.099,1326.24 269.109,1326.24 269.118,1326.24 269.127,1326.24 269.136,1326.24 269.145,1326.24 269.155,1326.24 269.164,1326.24 269.173,1326.24 269.182,1326.24 269.191,1326.25 269.201,1326.25 269.21,1326.25 269.219,1326.25 269.228,1326.25 269.237,1326.25 269.246,1326.25 269.256,1326.25 269.265,1326.25 269.274,1326.25 269.283,1326.25 269.292,1326.25 269.302,1326.25 269.311,1326.25 269.32,1326.25 269.329,1326.25 269.338,1326.25 269.348,1326.26 269.357,1326.26 269.366,1326.26 269.375,1326.26 269.384,1326.26 269.393,1326.26 269.403,1326.26 269.412,1326.26 269.421,1326.26 269.43,1326.26 269.439,1326.26 269.449,1326.26 269.458,1326.26 269.467,1326.26 269.476,1326.26 269.485,1326.26 269.495,1326.27 269.504,1326.27 269.513,1326.27 269.522,1326.27 269.531,1326.27 269.541,1326.27 269.55,1326.27 269.559,1326.27 269.568,1326.27 269.577,1326.27 269.586,1326.27 269.596,1326.27 269.605,1326.27 269.614,1326.27 269.623,1326.27 269.632,1326.27 269.642,1326.27 269.651,1326.28 269.66,1326.28 269.669,1326.28 269.678,1326.28 269.688,1326.28 269.697,1326.28 269.706,1326.28 269.715,1326.28 269.724,1326.28 269.733,1326.28 269.743,1326.28 269.752,1326.28 269.761,1326.28 269.77,1326.28 269.779,1326.28 269.789,1326.28 269.798,1326.28 269.807,1326.29 269.816,1326.29 269.825,1326.29 269.835,1326.29 269.844,1326.29 269.853,1326.29 269.862,1326.29 269.871,1326.29 269.881,1326.29 269.89,1326.29 269.899,1326.29 269.908,1326.29 269.917,1326.29 269.926,1326.29 269.936,1326.29 269.945,1326.29 269.954,1326.3 269.963,1326.3 269.972,1326.3 269.982,1326.3 269.991,1326.3 270,1326.3 270.009,1326.3 270.018,1326.3 270.028,1326.3 270.037,1326.3 270.046,1326.3 270.055,1326.3 270.064,1326.3 270.074,1326.3 270.083,1326.3 270.092,1326.3 270.101,1326.3 270.11,1326.31 270.119,1326.31 270.129,1326.31 270.138,1326.31 270.147,1326.31 270.156,1326.31 270.165,1326.31 270.175,1326.31 270.184,1326.31 270.193,1326.31 270.202,1326.31 270.211,1326.31 270.221,1326.31 270.23,1326.31 270.239,1326.31 270.248,1326.31 270.257,1326.32 270.266,1326.32 270.276,1326.32 270.285,1326.32 270.294,1326.32 270.303,1326.32 270.312,1326.32 270.322,1326.32 270.331,1326.32 270.34,1326.32 270.349,1326.32 270.358,1326.32 270.368,1326.32 270.377,1326.32 270.386,1326.32 270.395,1326.32 270.404,1326.32 270.414,1326.33 270.423,1326.33 270.432,1326.33 270.441,1326.33 270.45,1326.33 270.459,1326.33 270.469,1326.33 270.478,1326.33 270.487,1326.33 270.496,1326.33 270.505,1326.33 270.515,1326.33 270.524,1326.33 270.533,1326.33 270.542,1326.33 270.551,1326.33 270.561,1326.33 270.57,1326.34 270.579,1326.34 270.588,1326.34 270.597,1326.34 270.606,1326.34 270.616,1326.34 270.625,1326.34 270.634,1326.34 270.643,1326.34 270.652,1326.34 270.662,1326.34 270.671,1326.34 270.68,1326.34 270.689,1326.34 270.698,1326.34 270.708,1326.34 270.717,1326.35 270.726,1326.35 270.735,1326.35 270.744,1326.35 270.754,1326.35 270.763,1326.35 270.772,1326.35 270.781,1326.35 270.79,1326.35 270.799,1326.35 270.809,1326.35 270.818,1326.35 270.827,1326.35 270.836,1326.35 270.845,1326.35 270.855,1326.35 270.864,1326.35 270.873,1326.36 270.882,1326.36 270.891,1326.36 270.901,1326.36 270.91,1326.36 270.919,1326.36 270.928,1326.36 270.937,1326.36 270.946,1326.36 270.956,1326.36 270.965,1326.36 270.974,1326.36 270.983,1326.36 270.992,1326.36 271.002,1326.36 271.011,1326.36 271.02,1326.36 271.029,1326.37 271.038,1326.37 271.048,1326.37 271.057,1326.37 271.066,1326.37 271.075,1326.37 271.084,1326.37 271.094,1326.37 271.103,1326.37 271.112,1326.37 271.121,1326.37 271.13,1326.37 271.139,1326.37 271.149,1326.37 271.158,1326.37 271.167,1326.37 271.176,1326.38 271.185,1326.38 271.195,1326.38 271.204,1326.38 271.213,1326.38 271.222,1326.38 271.231,1326.38 271.241,1326.38 271.25,1326.38 271.259,1326.38 271.268,1326.38 271.277,1326.38 271.286,1326.38 271.296,1326.38 271.305,1326.38 271.314,1326.38 271.323,1326.38 271.332,1326.39 271.342,1326.39 271.351,1326.39 271.36,1326.39 271.369,1326.39 271.378,1326.39 271.388,1326.39 271.397,1326.39 271.406,1326.39 271.415,1326.39 271.424,1326.39 271.434,1326.39 271.443,1326.39 271.452,1326.39 271.461,1326.39 271.47,1326.39 271.479,1326.4 271.489,1326.4 271.498,1326.4 271.507,1326.4 271.516,1326.4 271.525,1326.4 271.535,1326.4 271.544,1326.4 271.553,1326.4 271.562,1326.4 271.571,1326.4 271.581,1326.4 271.59,1326.4 271.599,1326.4 271.608,1326.4 271.617,1326.4 271.626,1326.4 271.636,1326.41 271.645,1326.41 271.654,1326.41 271.663,1326.41 271.672,1326.41 271.682,1326.41 271.691,1326.41 271.7,1326.41 271.709,1326.41 271.718,1326.41 271.728,1326.41 271.737,1326.41 271.746,1326.41 271.755,1326.41 271.764,1326.41 271.774,1326.41 271.783,1326.41 271.792,1326.42 271.801,1326.42 271.81,1326.42 271.819,1326.42 271.829,1326.42 271.838,1326.42 271.847,1326.42 271.856,1326.42 271.865,1326.42 271.875,1326.42 271.884,1326.42 271.893,1326.42 271.902,1326.42 271.911,1326.42 271.921,1326.42 271.93,1326.42 271.939,1326.43 271.948,1326.43 271.957,1326.43 271.966,1326.43 271.976,1326.43 271.985,1326.43 271.994,1326.43 272.003,1326.43 272.012,1326.43 272.022,1326.43 272.031,1326.43 272.04,1326.43 272.049,1326.43 272.058,1326.43 272.068,1326.43 272.077,1326.43 272.086,1326.43 272.095,1326.44 272.104,1326.44 272.114,1326.44 272.123,1326.44 272.132,1326.44 272.141,1326.44 272.15,1326.44 272.159,1326.44 272.169,1326.44 272.178,1326.44 272.187,1326.44 272.196,1326.44 272.205,1326.44 272.215,1326.44 272.224,1326.44 272.233,1326.44 272.242,1326.44 272.251,1326.45 272.261,1326.45 272.27,1326.45 272.279,1326.45 272.288,1326.45 272.297,1326.45 272.306,1326.45 272.316,1326.45 272.325,1326.45 272.334,1326.45 272.343,1326.45 272.352,1326.45 272.362,1326.45 272.371,1326.45 272.38,1326.45 272.389,1326.45 272.398,1326.46 272.408,1326.46 272.417,1326.46 272.426,1326.46 272.435,1326.46 272.444,1326.46 272.454,1326.46 272.463,1326.46 272.472,1326.46 272.481,1326.46 272.49,1326.46 272.499,1326.46 272.509,1326.46 272.518,1326.46 272.527,1326.46 272.536,1326.46 272.545,1326.46 272.555,1326.47 272.564,1326.47 272.573,1326.47 272.582,1326.47 272.591,1326.47 272.601,1326.47 272.61,1326.47 272.619,1326.47 272.628,1326.47 272.637,1326.47 272.647,1326.47 272.656,1326.47 272.665,1326.47 272.674,1326.47 272.683,1326.47 272.692,1326.47 272.702,1326.48 272.711,1326.48 272.72,1326.48 272.729,1326.48 272.738,1326.48 272.748,1326.48 272.757,1326.48 272.766,1326.48 272.775,1326.48 272.784,1326.48 272.794,1326.48 272.803,1326.48 272.812,1326.48 272.821,1326.48 272.83,1326.48 272.839,1326.48 272.849,1326.48 272.858,1326.49 272.867,1326.49 272.876,1326.49 272.885,1326.49 272.895,1326.49 272.904,1326.49 272.913,1326.49 272.922,1326.49 272.931,1326.49 272.941,1326.49 272.95,1326.49 272.959,1326.49 272.968,1326.49 272.977,1326.49 272.987,1326.49 272.996,1326.49 273.005,1326.49 273.014,1326.5 273.023,1326.5 273.032,1326.5 273.042,1326.5 273.051,1326.5 273.06,1326.5 273.069,1326.5 273.078,1326.5 273.088,1326.5 273.097,1326.5 273.106,1326.5 273.115,1326.5 273.124,1326.5 273.134,1326.5 273.143,1326.5 273.152,1326.5 273.161,1326.51 273.17,1326.51 273.179,1326.51 273.189,1326.51 273.198,1326.51 273.207,1326.51 273.216,1326.51 273.225,1326.51 273.235,1326.51 273.244,1326.51 273.253,1326.51 273.262,1326.51 273.271,1326.51 273.281,1326.51 273.29,1326.51 273.299,1326.51 273.308,1326.51 273.317,1326.52 273.327,1326.52 273.336,1326.52 273.345,1326.52 273.354,1326.52 273.363,1326.52 273.372,1326.52 273.382,1326.52 273.391,1326.52 273.4,1326.52 273.409,1326.52 273.418,1326.52 273.428,1326.52 273.437,1326.52 273.446,1326.52 273.455,1326.52 273.464,1326.52 273.474,1326.53 273.483,1326.53 273.492,1326.53 273.501,1326.53 273.51,1326.53 273.519,1326.53 273.529,1326.53 273.538,1326.53 273.547,1326.53 273.556,1326.53 273.565,1326.53 273.575,1326.53 273.584,1326.53 273.593,1326.53 273.602,1326.53 273.611,1326.53 273.621,1326.54 273.63,1326.54 273.639,1326.54 273.648,1326.54 273.657,1326.54 273.667,1326.54 273.676,1326.54 273.685,1326.54 273.694,1326.54 273.703,1326.54 273.712,1326.54 273.722,1326.54 273.731,1326.54 273.74,1326.54 273.749,1326.54 273.758,1326.54 273.768,1326.54 273.777,1326.55 273.786,1326.55 273.795,1326.55 273.804,1326.55 273.814,1326.55 273.823,1326.55 273.832,1326.55 273.841,1326.55 273.85,1326.55 273.859,1326.55 273.869,1326.55 273.878,1326.55 273.887,1326.55 273.896,1326.55 273.905,1326.55 273.915,1326.55 273.924,1326.55 273.933,1326.56 273.942,1326.56 273.951,1326.56 273.961,1326.56 273.97,1326.56 273.979,1326.56 273.988,1326.56 273.997,1326.56 274.007,1326.56 274.016,1326.56 274.025,1326.56 274.034,1326.56 274.043,1326.56 274.052,1326.56 274.062,1326.56 274.071,1326.56 274.08,1326.57 274.089,1326.57 274.098,1326.57 274.108,1326.57 274.117,1326.57 274.126,1326.57 274.135,1326.57 274.144,1326.57 274.154,1326.57 274.163,1326.57 274.172,1326.57 274.181,1326.57 274.19,1326.57 274.199,1326.57 274.209,1326.57 274.218,1326.57 274.227,1326.57 274.236,1326.58 274.245,1326.58 274.255,1326.58 274.264,1326.58 274.273,1326.58 274.282,1326.58 274.291,1326.58 274.301,1326.58 274.31,1326.58 274.319,1326.58 274.328,1326.58 274.337,1326.58 274.347,1326.58 274.356,1326.58 274.365,1326.58 274.374,1326.58 274.383,1326.58 274.392,1326.59 274.402,1326.59 274.411,1326.59 274.42,1326.59 274.429,1326.59 274.438,1326.59 274.448,1326.59 274.457,1326.59 274.466,1326.59 274.475,1326.59 274.484,1326.59 274.494,1326.59 274.503,1326.59 274.512,1326.59 274.521,1326.59 274.53,1326.59 274.539,1326.6 274.549,1326.6 274.558,1326.6 274.567,1326.6 274.576,1326.6 274.585,1326.6 274.595,1326.6 274.604,1326.6 274.613,1326.6 274.622,1326.6 274.631,1326.6 274.641,1326.6 274.65,1326.6 274.659,1326.6 274.668,1326.6 274.677,1326.6 274.687,1326.6 274.696,1326.61 274.705,1326.61 274.714,1326.61 274.723,1326.61 274.732,1326.61 274.742,1326.61 274.751,1326.61 274.76,1326.61 274.769,1326.61 274.778,1326.61 274.788,1326.61 274.797,1326.61 274.806,1326.61 274.815,1326.61 274.824,1326.61 274.834,1326.61 274.843,1326.61 274.852,1326.62 274.861,1326.62 274.87,1326.62 274.88,1326.62 274.889,1326.62 274.898,1326.62 274.907,1326.62 274.916,1326.62 274.925,1326.62 274.935,1326.62 274.944,1326.62 274.953,1326.62 274.962,1326.62 274.971,1326.62 274.981,1326.62 274.99,1326.62 274.999,1326.63 275.008,1326.63 275.017,1326.63 275.027,1326.63 275.036,1326.63 275.045,1326.63 275.054,1326.63 275.063,1326.63 275.072,1326.63 275.082,1326.63 275.091,1326.63 275.1,1326.63 275.109,1326.63 275.118,1326.63 275.128,1326.63 275.137,1326.63 275.146,1326.63 275.155,1326.64 275.164,1326.64 275.174,1326.64 275.183,1326.64 275.192,1326.64 275.201,1326.64 275.21,1326.64 275.22,1326.64 275.229,1326.64 275.238,1326.64 275.247,1326.64 275.256,1326.64 275.265,1326.64 275.275,1326.64 275.284,1326.64 275.293,1326.64 275.302,1326.64 275.311,1326.65 275.321,1326.65 275.33,1326.65 275.339,1326.65 275.348,1326.65 275.357,1326.65 275.367,1326.65 275.376,1326.65 275.385,1326.65 275.394,1326.65 275.403,1326.65 275.412,1326.65 275.422,1326.65 275.431,1326.65 275.44,1326.65 275.449,1326.65 275.458,1326.66 275.468,1326.66 275.477,1326.66 275.486,1326.66 275.495,1326.66 275.504,1326.66 275.514,1326.66 275.523,1326.66 275.532,1326.66 275.541,1326.66 275.55,1326.66 275.56,1326.66 275.569,1326.66 275.578,1326.66 275.587,1326.66 275.596,1326.66 275.605,1326.66 275.615,1326.67 275.624,1326.67 275.633,1326.67 275.642,1326.67 275.651,1326.67 275.661,1326.67 275.67,1326.67 275.679,1326.67 275.688,1326.67 275.697,1326.67 275.707,1326.67 275.716,1326.67 275.725,1326.67 275.734,1326.67 275.743,1326.67 275.752,1326.67 275.762,1326.67 275.771,1326.68 275.78,1326.68 275.789,1326.68 275.798,1326.68 275.808,1326.68 275.817,1326.68 275.826,1326.68 275.835,1326.68 275.844,1326.68 275.854,1326.68 275.863,1326.68 275.872,1326.68 275.881,1326.68 275.89,1326.68 275.9,1326.68 275.909,1326.68 275.918,1326.69 275.927,1326.69 275.936,1326.69 275.945,1326.69 275.955,1326.69 275.964,1326.69 275.973,1326.69 275.982,1326.69 275.991,1326.69 276.001,1326.69 276.01,1326.69 276.019,1326.69 276.028,1326.69 276.037,1326.69 276.047,1326.69 276.056,1326.69 276.065,1326.69 276.074,1326.7 276.083,1326.7 276.092,1326.7 276.102,1326.7 276.111,1326.7 276.12,1326.7 276.129,1326.7 276.138,1326.7 276.148,1326.7 276.157,1326.7 276.166,1326.7 276.175,1326.7 276.184,1326.7 276.194,1326.7 276.203,1326.7 276.212,1326.7 276.221,1326.7 276.23,1326.71 276.24,1326.71 276.249,1326.71 276.258,1326.71 276.267,1326.71 276.276,1326.71 276.285,1326.71 276.295,1326.71 276.304,1326.71 276.313,1326.71 276.322,1326.71 276.331,1326.71 276.341,1326.71 276.35,1326.71 276.359,1326.71 276.368,1326.71 276.377,1326.72 276.387,1326.72 276.396,1326.72 276.405,1326.72 276.414,1326.72 276.423,1326.72 276.432,1326.72 276.442,1326.72 276.451,1326.72 276.46,1326.72 276.469,1326.72 276.478,1326.72 276.488,1326.72 276.497,1326.72 276.506,1326.72 276.515,1326.72 276.524,1326.72 276.534,1326.73 276.543,1326.73 276.552,1326.73 276.561,1326.73 276.57,1326.73 276.58,1326.73 276.589,1326.73 276.598,1326.73 276.607,1326.73 276.616,1326.73 276.625,1326.73 276.635,1326.73 276.644,1326.73 276.653,1326.73 276.662,1326.73 276.671,1326.73 276.681,1326.73 276.69,1326.74 276.699,1326.74 276.708,1326.74 276.717,1326.74 276.727,1326.74 276.736,1326.74 276.745,1326.74 276.754,1326.74 276.763,1326.74 276.772,1326.74 276.782,1326.74 276.791,1326.74 276.8,1326.74 276.809,1326.74 276.818,1326.74 276.828,1326.74 276.837,1326.74 276.846,1326.75 276.855,1326.75 276.864,1326.75 276.874,1326.75 276.883,1326.75 276.892,1326.75 276.901,1326.75 276.91,1326.75 276.92,1326.75 276.929,1326.75 276.938,1326.75 276.947,1326.75 276.956,1326.75 276.965,1326.75 276.975,1326.75 276.984,1326.75 276.993,1326.76 277.002,1326.76 277.011,1326.76 277.021,1326.76 277.03,1326.76 277.039,1326.76 277.048,1326.76 277.057,1326.76 277.067,1326.76 277.076,1326.76 277.085,1326.76 277.094,1326.76 277.103,1326.76 277.112,1326.76 277.122,1326.76 277.131,1326.76 277.14,1326.76 277.149,1326.77 277.158,1326.77 277.168,1326.77 277.177,1326.77 277.186,1326.77 277.195,1326.77 277.204,1326.77 277.214,1326.77 277.223,1326.77 277.232,1326.77 277.241,1326.77 277.25,1326.77 277.26,1326.77 277.269,1326.77 277.278,1326.77 277.287,1326.77 277.296,1326.77 277.305,1326.78 277.315,1326.78 277.324,1326.78 277.333,1326.78 277.342,1326.78 277.351,1326.78 277.361,1326.78 277.37,1326.78 277.379,1326.78 277.388,1326.78 277.397,1326.78 277.407,1326.78 277.416,1326.78 277.425,1326.78 277.434,1326.78 277.443,1326.78 277.453,1326.79 277.462,1326.79 277.471,1326.79 277.48,1326.79 277.489,1326.79 277.498,1326.79 277.508,1326.79 277.517,1326.79 277.526,1326.79 277.535,1326.79 277.544,1326.79 277.554,1326.79 277.563,1326.79 277.572,1326.79 277.581,1326.79 277.59,1326.79 277.6,1326.79 277.609,1326.8 277.618,1326.8 277.627,1326.8 277.636,1326.8 277.645,1326.8 277.655,1326.8 277.664,1326.8 277.673,1326.8 277.682,1326.8 277.691,1326.8 277.701,1326.8 277.71,1326.8 277.719,1326.8 277.728,1326.8 277.737,1326.8 277.747,1326.8 277.756,1326.8 277.765,1326.81 277.774,1326.81 277.783,1326.81 277.793,1326.81 277.802,1326.81 277.811,1326.81 277.82,1326.81 277.829,1326.81 277.838,1326.81 277.848,1326.81 277.857,1326.81 277.866,1326.81 277.875,1326.81 277.884,1326.81 277.894,1326.81 277.903,1326.81 277.912,1326.81 277.921,1326.82 277.93,1326.82 277.94,1326.82 277.949,1326.82 277.958,1326.82 277.967,1326.82 277.976,1326.82 277.985,1326.82 277.995,1326.82 278.004,1326.82 278.013,1326.82 278.022,1326.82 278.031,1326.82 278.041,1326.82 278.05,1326.82 278.059,1326.82 278.068,1326.83 278.077,1326.83 278.087,1326.83 278.096,1326.83 278.105,1326.83 278.114,1326.83 278.123,1326.83 278.133,1326.83 278.142,1326.83 278.151,1326.83 278.16,1326.83 278.169,1326.83 278.178,1326.83 278.188,1326.83 278.197,1326.83 278.206,1326.83 278.215,1326.83 278.224,1326.84 278.234,1326.84 278.243,1326.84 278.252,1326.84 278.261,1326.84 278.27,1326.84 278.28,1326.84 278.289,1326.84 278.298,1326.84 278.307,1326.84 278.316,1326.84 278.325,1326.84 278.335,1326.84 278.344,1326.84 278.353,1326.84 278.362,1326.84 278.371,1326.84 278.381,1326.85 278.39,1326.85 278.399,1326.85 278.408,1326.85 278.417,1326.85 278.427,1326.85 278.436,1326.85 278.445,1326.85 278.454,1326.85 278.463,1326.85 278.473,1326.85 278.482,1326.85 278.491,1326.85 278.5,1326.85 278.509,1326.85 278.518,1326.85 278.528,1326.86 278.537,1326.86 278.546,1326.86 278.555,1326.86 278.564,1326.86 278.574,1326.86 278.583,1326.86 278.592,1326.86 278.601,1326.86 278.61,1326.86 278.62,1326.86 278.629,1326.86 278.638,1326.86 278.647,1326.86 278.656,1326.86 278.665,1326.86 278.675,1326.86 278.684,1326.87 278.693,1326.87 278.702,1326.87 278.711,1326.87 278.721,1326.87 278.73,1326.87 278.739,1326.87 278.748,1326.87 278.757,1326.87 278.767,1326.87 278.776,1326.87 278.785,1326.87 278.794,1326.87 278.803,1326.87 278.813,1326.87 278.822,1326.87 278.831,1326.87 278.84,1326.88 278.849,1326.88 278.858,1326.88 278.868,1326.88 278.877,1326.88 278.886,1326.88 278.895,1326.88 278.904,1326.88 278.914,1326.88 278.923,1326.88 278.932,1326.88 278.941,1326.88 278.95,1326.88 278.96,1326.88 278.969,1326.88 278.978,1326.88 278.987,1326.88 278.996,1326.89 279.005,1326.89 279.015,1326.89 279.024,1326.89 279.033,1326.89 279.042,1326.89 279.051,1326.89 279.061,1326.89 279.07,1326.89 279.079,1326.89 279.088,1326.89 279.097,1326.89 279.107,1326.89 279.116,1326.89 279.125,1326.89 279.134,1326.89 279.143,1326.9 279.153,1326.9 279.162,1326.9 279.171,1326.9 279.18,1326.9 279.189,1326.9 279.198,1326.9 279.208,1326.9 279.217,1326.9 279.226,1326.9 279.235,1326.9 279.244,1326.9 279.254,1326.9 279.263,1326.9 279.272,1326.9 279.281,1326.9 279.29,1326.9 279.3,1326.91 279.309,1326.91 279.318,1326.91 279.327,1326.91 279.336,1326.91 279.345,1326.91 279.355,1326.91 279.364,1326.91 279.373,1326.91 279.382,1326.91 279.391,1326.91 279.401,1326.91 279.41,1326.91 279.419,1326.91 279.428,1326.91 279.437,1326.91 279.447,1326.91 279.456,1326.92 279.465,1326.92 279.474,1326.92 279.483,1326.92 279.493,1326.92 279.502,1326.92 279.511,1326.92 279.52,1326.92 279.529,1326.92 279.538,1326.92 279.548,1326.92 279.557,1326.92 279.566,1326.92 279.575,1326.92 279.584,1326.92 279.594,1326.92 279.603,1326.93 279.612,1326.93 279.621,1326.93 279.63,1326.93 279.64,1326.93 279.649,1326.93 279.658,1326.93 279.667,1326.93 279.676,1326.93 279.685,1326.93 279.695,1326.93 279.704,1326.93 279.713,1326.93 279.722,1326.93 279.731,1326.93 279.741,1326.93 279.75,1326.93 279.759,1326.94 279.768,1326.94 279.777,1326.94 279.787,1326.94 279.796,1326.94 279.805,1326.94 279.814,1326.94 279.823,1326.94 279.833,1326.94 279.842,1326.94 279.851,1326.94 279.86,1326.94 279.869,1326.94 279.878,1326.94 279.888,1326.94 279.897,1326.94 279.906,1326.94 279.915,1326.95 279.924,1326.95 279.934,1326.95 279.943,1326.95 279.952,1326.95 279.961,1326.95 279.97,1326.95 279.98,1326.95 279.989,1326.95 279.998,1326.95 280.007,1326.95 280.016,1326.95 280.026,1326.95 280.035,1326.95 280.044,1326.95 280.053,1326.95 280.062,1326.95 280.071,1326.96 280.081,1326.96 280.09,1326.96 280.099,1326.96 280.108,1326.96 280.117,1326.96 280.127,1326.96 280.136,1326.96 280.145,1326.96 280.154,1326.96 280.163,1326.96 280.173,1326.96 280.182,1326.96 280.191,1326.96 280.2,1326.96 280.209,1326.96 280.218,1326.97 280.228,1326.97 280.237,1326.97 280.246,1326.97 280.255,1326.97 280.264,1326.97 280.274,1326.97 280.283,1326.97 280.292,1326.97 280.301,1326.97 280.31,1326.97 280.32,1326.97 280.329,1326.97 280.338,1326.97 280.347,1326.97 280.356,1326.97 280.366,1326.97 280.375,1326.98 280.384,1326.98 280.393,1326.98 280.402,1326.98 280.411,1326.98 280.421,1326.98 280.43,1326.98 280.439,1326.98 280.448,1326.98 280.457,1326.98 280.467,1326.98 280.476,1326.98 280.485,1326.98 280.494,1326.98 280.503,1326.98 280.513,1326.98 280.522,1326.98 280.531,1326.99 280.54,1326.99 280.549,1326.99 280.558,1326.99 280.568,1326.99 280.577,1326.99 280.586,1326.99 280.595,1326.99 280.604,1326.99 280.614,1326.99 280.623,1326.99 280.632,1326.99 280.641,1326.99 280.65,1326.99 280.66,1326.99 280.669,1326.99 280.678,1326.99 280.687,1327 280.696,1327 280.706,1327 280.715,1327 280.724,1327 280.733,1327 280.742,1327 280.751,1327 280.761,1327 280.77,1327 280.779,1327 280.788,1327 280.797,1327 280.807,1327 280.816,1327 280.825,1327 280.834,1327.01 280.843,1327.01 280.853,1327.01 280.862,1327.01 280.871,1327.01 280.88,1327.01 280.889,1327.01 280.898,1327.01 280.908,1327.01 280.917,1327.01 280.926,1327.01 280.935,1327.01 280.944,1327.01 280.954,1327.01 280.963,1327.01 280.972,1327.01 280.981,1327.01 280.99,1327.02 281,1327.02 281.009,1327.02 281.018,1327.02 281.027,1327.02 281.036,1327.02 281.046,1327.02 281.055,1327.02 281.064,1327.02 281.073,1327.02 281.082,1327.02 281.091,1327.02 281.101,1327.02 281.11,1327.02 281.119,1327.02 281.128,1327.02 281.137,1327.02 281.147,1327.03 281.156,1327.03 281.165,1327.03 281.174,1327.03 281.183,1327.03 281.193,1327.03 281.202,1327.03 281.211,1327.03 281.22,1327.03 281.229,1327.03 281.238,1327.03 281.248,1327.03 281.257,1327.03 281.266,1327.03 281.275,1327.03 281.284,1327.03 281.294,1327.03 281.303,1327.04 281.312,1327.04 281.321,1327.04 281.33,1327.04 281.34,1327.04 281.349,1327.04 281.358,1327.04 281.367,1327.04 281.376,1327.04 281.386,1327.04 281.395,1327.04 281.404,1327.04 281.413,1327.04 281.422,1327.04 281.431,1327.04 281.441,1327.04 281.45,1327.05 281.459,1327.05 281.468,1327.05 281.477,1327.05 281.487,1327.05 281.496,1327.05 281.505,1327.05 281.514,1327.05 281.523,1327.05 281.533,1327.05 281.542,1327.05 281.551,1327.05 281.56,1327.05 281.569,1327.05 281.578,1327.05 281.588,1327.05 281.597,1327.05 281.606,1327.06 281.615,1327.06 281.624,1327.06 281.634,1327.06 281.643,1327.06 281.652,1327.06 281.661,1327.06 281.67,1327.06 281.68,1327.06 281.689,1327.06 281.698,1327.06 281.707,1327.06 281.716,1327.06 281.726,1327.06 281.735,1327.06 281.744,1327.06 281.753,1327.06 281.762,1327.07 281.771,1327.07 281.781,1327.07 281.79,1327.07 281.799,1327.07 281.808,1327.07 281.817,1327.07 281.827,1327.07 281.836,1327.07 281.845,1327.07 281.854,1327.07 281.863,1327.07 281.873,1327.07 281.882,1327.07 281.891,1327.07 281.9,1327.07 281.909,1327.07 281.918,1327.08 281.928,1327.08 281.937,1327.08 281.946,1327.08 281.955,1327.08 281.964,1327.08 281.974,1327.08 281.983,1327.08 281.992,1327.08 282.001,1327.08 282.01,1327.08 282.02,1327.08 282.029,1327.08 282.038,1327.08 282.047,1327.08 282.056,1327.08 282.066,1327.08 282.075,1327.09 282.084,1327.09 282.093,1327.09 282.102,1327.09 282.111,1327.09 282.121,1327.09 282.13,1327.09 282.139,1327.09 282.148,1327.09 282.157,1327.09 282.167,1327.09 282.176,1327.09 282.185,1327.09 282.194,1327.09 282.203,1327.09 282.213,1327.09 282.222,1327.1 282.231,1327.1 282.24,1327.1 282.249,1327.1 282.259,1327.1 282.268,1327.1 282.277,1327.1 282.286,1327.1 282.295,1327.1 282.304,1327.1 282.314,1327.1 282.323,1327.1 282.332,1327.1 282.341,1327.1 282.35,1327.1 282.36,1327.1 282.369,1327.1 282.378,1327.11 282.387,1327.11 282.396,1327.11 282.406,1327.11 282.415,1327.11 282.424,1327.11 282.433,1327.11 282.442,1327.11 282.451,1327.11 282.461,1327.11 282.47,1327.11 282.479,1327.11 282.488,1327.11 282.497,1327.11 282.507,1327.11 282.516,1327.11 282.525,1327.11 282.534,1327.12 282.543,1327.12 282.553,1327.12 282.562,1327.12 282.571,1327.12 282.58,1327.12 282.589,1327.12 282.599,1327.12 282.608,1327.12 282.617,1327.12 282.626,1327.12 282.635,1327.12 282.644,1327.12 282.654,1327.12 282.663,1327.12 282.672,1327.12 282.681,1327.12 282.69,1327.13 282.7,1327.13 282.709,1327.13 282.718,1327.13 282.727,1327.13 282.736,1327.13 282.746,1327.13 282.755,1327.13 282.764,1327.13 282.773,1327.13 282.782,1327.13 282.791,1327.13 282.801,1327.13 282.81,1327.13 282.819,1327.13 282.828,1327.13 282.837,1327.14 282.847,1327.14 282.856,1327.14 282.865,1327.14 282.874,1327.14 282.883,1327.14 282.893,1327.14 282.902,1327.14 282.911,1327.14 282.92,1327.14 282.929,1327.14 282.939,1327.14 282.948,1327.14 282.957,1327.14 282.966,1327.14 282.975,1327.14 282.984,1327.14 282.994,1327.15 283.003,1327.15 283.012,1327.15 283.021,1327.15 283.03,1327.15 283.04,1327.15 283.049,1327.15 283.058,1327.15 283.067,1327.15 283.076,1327.15 283.086,1327.15 283.095,1327.15 283.104,1327.15 283.113,1327.15 283.122,1327.15 283.131,1327.15 283.141,1327.15 283.15,1327.16 283.159,1327.16 283.168,1327.16 283.177,1327.16 283.187,1327.16 283.196,1327.16 283.205,1327.16 283.214,1327.16 283.223,1327.16 283.233,1327.16 283.242,1327.16 283.251,1327.16 283.26,1327.16 283.269,1327.16 283.279,1327.16 283.288,1327.16 283.297,1327.16 283.306,1327.17 283.315,1327.17 283.324,1327.17 283.334,1327.17 283.343,1327.17 283.352,1327.17 283.361,1327.17 283.37,1327.17 283.38,1327.17 283.389,1327.17 283.398,1327.17 283.407,1327.17 283.416,1327.17 283.426,1327.17 283.435,1327.17 283.444,1327.17 283.453,1327.17 283.462,1327.18 283.471,1327.18 283.481,1327.18 283.49,1327.18 283.499,1327.18 283.508,1327.18 283.517,1327.18 283.527,1327.18 283.536,1327.18 283.545,1327.18 283.554,1327.18 283.563,1327.18 283.573,1327.18 283.582,1327.18 283.591,1327.18 283.6,1327.18 283.609,1327.19 283.619,1327.19 283.628,1327.19 283.637,1327.19 283.646,1327.19 283.655,1327.19 283.664,1327.19 283.674,1327.19 283.683,1327.19 283.692,1327.19 283.701,1327.19 283.71,1327.19 283.72,1327.19 283.729,1327.19 283.738,1327.19 283.747,1327.19 283.756,1327.19 283.766,1327.2 283.775,1327.2 283.784,1327.2 283.793,1327.2 283.802,1327.2 283.811,1327.2 283.821,1327.2 283.83,1327.2 283.839,1327.2 283.848,1327.2 283.857,1327.2 283.867,1327.2 283.876,1327.2 283.885,1327.2 283.894,1327.2 283.903,1327.2 283.913,1327.2 283.922,1327.21 283.931,1327.21 283.94,1327.21 283.949,1327.21 283.959,1327.21 283.968,1327.21 283.977,1327.21 283.986,1327.21 283.995,1327.21 284.004,1327.21 284.014,1327.21 284.023,1327.21 284.032,1327.21 284.041,1327.21 284.05,1327.21 284.06,1327.21 284.069,1327.21 284.078,1327.22 284.087,1327.22 284.096,1327.22 284.106,1327.22 284.115,1327.22 284.124,1327.22 284.133,1327.22 284.142,1327.22 284.151,1327.22 284.161,1327.22 284.17,1327.22 284.179,1327.22 284.188,1327.22 284.197,1327.22 284.207,1327.22 284.216,1327.22 284.225,1327.22 284.234,1327.23 284.243,1327.23 284.253,1327.23 284.262,1327.23 284.271,1327.23 284.28,1327.23 284.289,1327.23 284.299,1327.23 284.308,1327.23 284.317,1327.23 284.326,1327.23 284.335,1327.23 284.344,1327.23 284.354,1327.23 284.363,1327.23 284.372,1327.23 284.381,1327.24 284.39,1327.24 284.4,1327.24 284.409,1327.24 284.418,1327.24 284.427,1327.24 284.436,1327.24 284.446,1327.24 284.455,1327.24 284.464,1327.24 284.473,1327.24 284.482,1327.24 284.491,1327.24 284.501,1327.24 284.51,1327.24 284.519,1327.24 284.528,1327.24 284.537,1327.25 284.547,1327.25 284.556,1327.25 284.565,1327.25 284.574,1327.25 284.583,1327.25 284.593,1327.25 284.602,1327.25 284.611,1327.25 284.62,1327.25 284.629,1327.25 284.639,1327.25 284.648,1327.25 284.657,1327.25 284.666,1327.25 284.675,1327.25 284.684,1327.25 284.694,1327.26 284.703,1327.26 284.712,1327.26 284.721,1327.26 284.73,1327.26 284.74,1327.26 284.749,1327.26 284.758,1327.26 284.767,1327.26 284.776,1327.26 284.786,1327.26 284.795,1327.26 284.804,1327.26 284.813,1327.26 284.822,1327.26 284.832,1327.26 284.841,1327.26 284.85,1327.27 284.859,1327.27 284.868,1327.27 284.877,1327.27 284.887,1327.27 284.896,1327.27 284.905,1327.27 284.914,1327.27 284.923,1327.27 284.933,1327.27 284.942,1327.27 284.951,1327.27 284.96,1327.27 284.969,1327.27 284.979,1327.27 284.988,1327.27 284.997,1327.27 285.006,1327.28 285.015,1327.28 285.024,1327.28 285.034,1327.28 285.043,1327.28 285.052,1327.28 285.061,1327.28 285.07,1327.28 285.08,1327.28 285.089,1327.28 285.098,1327.28 285.107,1327.28 285.116,1327.28 285.126,1327.28 285.135,1327.28 285.144,1327.28 285.153,1327.29 285.162,1327.29 285.172,1327.29 285.181,1327.29 285.19,1327.29 285.199,1327.29 285.208,1327.29 285.217,1327.29 285.227,1327.29 285.236,1327.29 285.245,1327.29 285.254,1327.29 285.263,1327.29 285.273,1327.29 285.282,1327.29 285.291,1327.29 285.3,1327.29 285.309,1327.3 285.319,1327.3 285.328,1327.3 285.337,1327.3 285.346,1327.3 285.355,1327.3 285.364,1327.3 285.374,1327.3 285.383,1327.3 285.392,1327.3 285.401,1327.3 285.41,1327.3 285.42,1327.3 285.429,1327.3 285.438,1327.3 285.447,1327.3 285.456,1327.3 285.466,1327.31 285.475,1327.31 285.484,1327.31 285.493,1327.31 285.502,1327.31 285.512,1327.31 285.521,1327.31 285.53,1327.31 285.539,1327.31 285.548,1327.31 285.557,1327.31 285.567,1327.31 285.576,1327.31 285.585,1327.31 285.594,1327.31 285.603,1327.31 285.613,1327.31 285.622,1327.32 285.631,1327.32 285.64,1327.32 285.649,1327.32 285.659,1327.32 285.668,1327.32 285.677,1327.32 285.686,1327.32 285.695,1327.32 285.704,1327.32 285.714,1327.32 285.723,1327.32 285.732,1327.32 285.741,1327.32 285.75,1327.32 285.76,1327.32 285.769,1327.32 285.778,1327.33 285.787,1327.33 285.796,1327.33 285.806,1327.33 285.815,1327.33 285.824,1327.33 285.833,1327.33 285.842,1327.33 285.852,1327.33 285.861,1327.33 285.87,1327.33 285.879,1327.33 285.888,1327.33 285.897,1327.33 285.907,1327.33 285.916,1327.33 285.925,1327.34 285.934,1327.34 285.943,1327.34 285.953,1327.34 285.962,1327.34 285.971,1327.34 285.98,1327.34 285.989,1327.34 285.999,1327.34 286.008,1327.34 286.017,1327.34 286.026,1327.34 286.035,1327.34 286.044,1327.34 286.054,1327.34 286.063,1327.34 286.072,1327.34 286.081,1327.35 286.09,1327.35 286.1,1327.35 286.109,1327.35 286.118,1327.35 286.127,1327.35 286.136,1327.35 286.146,1327.35 286.155,1327.35 286.164,1327.35 286.173,1327.35 286.182,1327.35 286.192,1327.35 286.201,1327.35 286.21,1327.35 286.219,1327.35 286.228,1327.35 286.237,1327.36 286.247,1327.36 286.256,1327.36 286.265,1327.36 286.274,1327.36 286.283,1327.36 286.293,1327.36 286.302,1327.36 286.311,1327.36 286.32,1327.36 286.329,1327.36 286.339,1327.36 286.348,1327.36 286.357,1327.36 286.366,1327.36 286.375,1327.36 286.384,1327.36 286.394,1327.37 286.403,1327.37 286.412,1327.37 286.421,1327.37 286.43,1327.37 286.44,1327.37 286.449,1327.37 286.458,1327.37 286.467,1327.37 286.476,1327.37 286.486,1327.37 286.495,1327.37 286.504,1327.37 286.513,1327.37 286.522,1327.37 286.532,1327.37 286.541,1327.37 286.55,1327.38 286.559,1327.38 286.568,1327.38 286.577,1327.38 286.587,1327.38 286.596,1327.38 286.605,1327.38 286.614,1327.38 286.623,1327.38 286.633,1327.38 286.642,1327.38 286.651,1327.38 286.66,1327.38 286.669,1327.38 286.679,1327.38 286.688,1327.38 286.697,1327.38 286.706,1327.39 286.715,1327.39 286.724,1327.39 286.734,1327.39 286.743,1327.39 286.752,1327.39 286.761,1327.39 286.77,1327.39 286.78,1327.39 286.789,1327.39 286.798,1327.39 286.807,1327.39 286.816,1327.39 286.826,1327.39 286.835,1327.39 286.844,1327.39 286.853,1327.4 286.862,1327.4 286.872,1327.4 286.881,1327.4 286.89,1327.4 286.899,1327.4 286.908,1327.4 286.917,1327.4 286.927,1327.4 286.936,1327.4 286.945,1327.4 286.954,1327.4 286.963,1327.4 286.973,1327.4 286.982,1327.4 286.991,1327.4 287,1327.4 287.009,1327.41 287.019,1327.41 287.028,1327.41 287.037,1327.41 287.046,1327.41 287.055,1327.41 287.064,1327.41 287.074,1327.41 287.083,1327.41 287.092,1327.41 287.101,1327.41 287.11,1327.41 287.12,1327.41 287.129,1327.41 287.138,1327.41 287.147,1327.41 287.156,1327.41 287.166,1327.42 287.175,1327.42 287.184,1327.42 287.193,1327.42 287.202,1327.42 287.212,1327.42 287.221,1327.42 287.23,1327.42 287.239,1327.42 287.248,1327.42 287.257,1327.42 287.267,1327.42 287.276,1327.42 287.285,1327.42 287.294,1327.42 287.303,1327.42 287.313,1327.42 287.322,1327.43 287.331,1327.43 287.34,1327.43 287.349,1327.43 287.359,1327.43 287.368,1327.43 287.377,1327.43 287.386,1327.43 287.395,1327.43 287.405,1327.43 287.414,1327.43 287.423,1327.43 287.432,1327.43 287.441,1327.43 287.45,1327.43 287.46,1327.43 287.469,1327.43 287.478,1327.44 287.487,1327.44 287.496,1327.44 287.506,1327.44 287.515,1327.44 287.524,1327.44 287.533,1327.44 287.542,1327.44 287.552,1327.44 287.561,1327.44 287.57,1327.44 287.579,1327.44 287.588,1327.44 287.597,1327.44 287.607,1327.44 287.616,1327.44 287.625,1327.44 287.634,1327.45 287.643,1327.45 287.653,1327.45 287.662,1327.45 287.671,1327.45 287.68,1327.45 287.689,1327.45 287.699,1327.45 287.708,1327.45 287.717,1327.45 287.726,1327.45 287.735,1327.45 287.745,1327.45 287.754,1327.45 287.763,1327.45 287.772,1327.45 287.781,1327.46 287.79,1327.46 287.8,1327.46 287.809,1327.46 287.818,1327.46 287.827,1327.46 287.836,1327.46 287.846,1327.46 287.855,1327.46 287.864,1327.46 287.873,1327.46 287.882,1327.46 287.892,1327.46 287.901,1327.46 287.91,1327.46 287.919,1327.46 287.928,1327.46 287.937,1327.47 287.947,1327.47 287.956,1327.47 287.965,1327.47 287.974,1327.47 287.983,1327.47 287.993,1327.47 288.002,1327.47 288.011,1327.47 288.02,1327.47 288.029,1327.47 288.039,1327.47 288.048,1327.47 288.057,1327.47 288.066,1327.47 288.075,1327.47 288.085,1327.47 288.094,1327.48 288.103,1327.48 288.112,1327.48 288.121,1327.48 288.13,1327.48 288.14,1327.48 288.149,1327.48 288.158,1327.48 288.167,1327.48 288.176,1327.48 288.186,1327.48 288.195,1327.48 288.204,1327.48 288.213,1327.48 288.222,1327.48 288.232,1327.48 288.241,1327.48 288.25,1327.49 288.259,1327.49 288.268,1327.49 288.277,1327.49 288.287,1327.49 288.296,1327.49 288.305,1327.49 288.314,1327.49 288.323,1327.49 288.333,1327.49 288.342,1327.49 288.351,1327.49 288.36,1327.49 288.369,1327.49 288.379,1327.49 288.388,1327.49 288.397,1327.49 288.406,1327.5 288.415,1327.5 288.425,1327.5 288.434,1327.5 288.443,1327.5 288.452,1327.5 288.461,1327.5 288.47,1327.5 288.48,1327.5 288.489,1327.5 288.498,1327.5 288.507,1327.5 288.516,1327.5 288.526,1327.5 288.535,1327.5 288.544,1327.5 288.553,1327.5 288.562,1327.51 288.572,1327.51 288.581,1327.51 288.59,1327.51 288.599,1327.51 288.608,1327.51 288.617,1327.51 288.627,1327.51 288.636,1327.51 288.645,1327.51 288.654,1327.51 288.663,1327.51 288.673,1327.51 288.682,1327.51 288.691,1327.51 288.7,1327.51 288.709,1327.51 288.719,1327.52 288.728,1327.52 288.737,1327.52 288.746,1327.52 288.755,1327.52 288.765,1327.52 288.774,1327.52 288.783,1327.52 288.792,1327.52 288.801,1327.52 288.81,1327.52 288.82,1327.52 288.829,1327.52 288.838,1327.52 288.847,1327.52 288.856,1327.52 288.866,1327.53 288.875,1327.53 288.884,1327.53 288.893,1327.53 288.902,1327.53 288.912,1327.53 288.921,1327.53 288.93,1327.53 288.939,1327.53 288.948,1327.53 288.957,1327.53 288.967,1327.53 288.976,1327.53 288.985,1327.53 288.994,1327.53 289.003,1327.53 289.013,1327.53 289.022,1327.54 289.031,1327.54 289.04,1327.54 289.049,1327.54 289.059,1327.54 289.068,1327.54 289.077,1327.54 289.086,1327.54 289.095,1327.54 289.105,1327.54 289.114,1327.54 289.123,1327.54 289.132,1327.54 289.141,1327.54 289.15,1327.54 289.16,1327.54 289.169,1327.54 289.178,1327.55 289.187,1327.55 289.196,1327.55 289.206,1327.55 289.215,1327.55 289.224,1327.55 289.233,1327.55 289.242,1327.55 289.252,1327.55 289.261,1327.55 289.27,1327.55 289.279,1327.55 289.288,1327.55 289.297,1327.55 289.307,1327.55 289.316,1327.55 289.325,1327.55 289.334,1327.56 289.343,1327.56 289.353,1327.56 289.362,1327.56 289.371,1327.56 289.38,1327.56 289.389,1327.56 289.399,1327.56 289.408,1327.56 289.417,1327.56 289.426,1327.56 289.435,1327.56 289.445,1327.56 289.454,1327.56 289.463,1327.56 289.472,1327.56 289.481,1327.56 289.49,1327.57 289.5,1327.57 289.509,1327.57 289.518,1327.57 289.527,1327.57 289.536,1327.57 289.546,1327.57 289.555,1327.57 289.564,1327.57 289.573,1327.57 289.582,1327.57 289.592,1327.57 289.601,1327.57 289.61,1327.57 289.619,1327.57 289.628,1327.57 289.638,1327.57 289.647,1327.58 289.656,1327.58 289.665,1327.58 289.674,1327.58 289.683,1327.58 289.693,1327.58 289.702,1327.58 289.711,1327.58 289.72,1327.58 289.729,1327.58 289.739,1327.58 289.748,1327.58 289.757,1327.58 289.766,1327.58 289.775,1327.58 289.785,1327.58 289.794,1327.58 289.803,1327.59 289.812,1327.59 289.821,1327.59 289.83,1327.59 289.84,1327.59 289.849,1327.59 289.858,1327.59 289.867,1327.59 289.876,1327.59 289.886,1327.59 289.895,1327.59 289.904,1327.59 289.913,1327.59 289.922,1327.59 289.932,1327.59 289.941,1327.59 289.95,1327.59 289.959,1327.6 289.968,1327.6 289.978,1327.6 289.987,1327.6 289.996,1327.6 290.005,1327.6 290.014,1327.6 290.023,1327.6 290.033,1327.6 290.042,1327.6 290.051,1327.6 290.06,1327.6 290.069,1327.6 290.079,1327.6 290.088,1327.6 290.097,1327.6 290.106,1327.61 290.115,1327.61 290.125,1327.61 290.134,1327.61 290.143,1327.61 290.152,1327.61 290.161,1327.61 290.17,1327.61 290.18,1327.61 290.189,1327.61 290.198,1327.61 290.207,1327.61 290.216,1327.61 290.226,1327.61 290.235,1327.61 290.244,1327.61 290.253,1327.61 290.262,1327.62 290.272,1327.62 290.281,1327.62 290.29,1327.62 290.299,1327.62 290.308,1327.62 290.318,1327.62 290.327,1327.62 290.336,1327.62 290.345,1327.62 290.354,1327.62 290.363,1327.62 290.373,1327.62 290.382,1327.62 290.391,1327.62 290.4,1327.62 290.409,1327.62 290.419,1327.63 290.428,1327.63 290.437,1327.63 290.446,1327.63 290.455,1327.63 290.465,1327.63 290.474,1327.63 290.483,1327.63 290.492,1327.63 290.501,1327.63 290.51,1327.63 290.52,1327.63 290.529,1327.63 290.538,1327.63 290.547,1327.63 290.556,1327.63 290.566,1327.63 290.575,1327.64 290.584,1327.64 290.593,1327.64 290.602,1327.64 290.612,1327.64 290.621,1327.64 290.63,1327.64 290.639,1327.64 290.648,1327.64 290.658,1327.64 290.667,1327.64 290.676,1327.64 290.685,1327.64 290.694,1327.64 290.703,1327.64 290.713,1327.64 290.722,1327.64 290.731,1327.65 290.74,1327.65 290.749,1327.65 290.759,1327.65 290.768,1327.65 290.777,1327.65 290.786,1327.65 290.795,1327.65 290.805,1327.65 290.814,1327.65 290.823,1327.65 290.832,1327.65 290.841,1327.65 290.85,1327.65 290.86,1327.65 290.869,1327.65 290.878,1327.65 290.887,1327.66 290.896,1327.66 290.906,1327.66 290.915,1327.66 290.924,1327.66 290.933,1327.66 290.942,1327.66 290.952,1327.66 290.961,1327.66 290.97,1327.66 290.979,1327.66 290.988,1327.66 290.998,1327.66 291.007,1327.66 291.016,1327.66 291.025,1327.66 291.034,1327.66 291.043,1327.67 291.053,1327.67 291.062,1327.67 291.071,1327.67 291.08,1327.67 291.089,1327.67 291.099,1327.67 291.108,1327.67 291.117,1327.67 291.126,1327.67 291.135,1327.67 291.145,1327.67 291.154,1327.67 291.163,1327.67 291.172,1327.67 291.181,1327.67 291.19,1327.67 291.2,1327.68 291.209,1327.68 291.218,1327.68 291.227,1327.68 291.236,1327.68 291.246,1327.68 291.255,1327.68 291.264,1327.68 291.273,1327.68 291.282,1327.68 291.292,1327.68 291.301,1327.68 291.31,1327.68 291.319,1327.68 291.328,1327.68 291.338,1327.68 291.347,1327.68 291.356,1327.69 291.365,1327.69 291.374,1327.69 291.383,1327.69 291.393,1327.69 291.402,1327.69 291.411,1327.69 291.42,1327.69 291.429,1327.69 291.439,1327.69 291.448,1327.69 291.457,1327.69 291.466,1327.69 291.475,1327.69 291.485,1327.69 291.494,1327.69 291.503,1327.7 291.512,1327.7 291.521,1327.7 291.53,1327.7 291.54,1327.7 291.549,1327.7 291.558,1327.7 291.567,1327.7 291.576,1327.7 291.586,1327.7 291.595,1327.7 291.604,1327.7 291.613,1327.7 291.622,1327.7 291.632,1327.7 291.641,1327.7 291.65,1327.7 291.659,1327.71 291.668,1327.71 291.678,1327.71 291.687,1327.71 291.696,1327.71 291.705,1327.71 291.714,1327.71 291.723,1327.71 291.733,1327.71 291.742,1327.71 291.751,1327.71 291.76,1327.71 291.769,1327.71 291.779,1327.71 291.788,1327.71 291.797,1327.71 291.806,1327.71 291.815,1327.72 291.825,1327.72 291.834,1327.72 291.843,1327.72 291.852,1327.72 291.861,1327.72 291.87,1327.72 291.88,1327.72 291.889,1327.72 291.898,1327.72 291.907,1327.72 291.916,1327.72 291.926,1327.72 291.935,1327.72 291.944,1327.72 291.953,1327.72 291.962,1327.72 291.972,1327.73 291.981,1327.73 291.99,1327.73 291.999,1327.73 292.008,1327.73 292.018,1327.73 292.027,1327.73 292.036,1327.73 292.045,1327.73 292.054,1327.73 292.063,1327.73 292.073,1327.73 292.082,1327.73 292.091,1327.73 292.1,1327.73 292.109,1327.73 292.119,1327.73 292.128,1327.74 292.137,1327.74 292.146,1327.74 292.155,1327.74 292.165,1327.74 292.174,1327.74 292.183,1327.74 292.192,1327.74 292.201,1327.74 292.211,1327.74 292.22,1327.74 292.229,1327.74 292.238,1327.74 292.247,1327.74 292.256,1327.74 292.266,1327.74 292.275,1327.74 292.284,1327.75 292.293,1327.75 292.302,1327.75 292.312,1327.75 292.321,1327.75 292.33,1327.75 292.339,1327.75 292.348,1327.75 292.358,1327.75 292.367,1327.75 292.376,1327.75 292.385,1327.75 292.394,1327.75 292.403,1327.75 292.413,1327.75 292.422,1327.75 292.431,1327.75 292.44,1327.76 292.449,1327.76 292.459,1327.76 292.468,1327.76 292.477,1327.76 292.486,1327.76 292.495,1327.76 292.505,1327.76 292.514,1327.76 292.523,1327.76 292.532,1327.76 292.541,1327.76 292.551,1327.76 292.56,1327.76 292.569,1327.76 292.578,1327.76 292.587,1327.76 292.596,1327.77 292.606,1327.77 292.615,1327.77 292.624,1327.77 292.633,1327.77 292.642,1327.77 292.652,1327.77 292.661,1327.77 292.67,1327.77 292.679,1327.77 292.688,1327.77 292.698,1327.77 292.707,1327.77 292.716,1327.77 292.725,1327.77 292.734,1327.77 292.743,1327.77 292.753,1327.78 292.762,1327.78 292.771,1327.78 292.78,1327.78 292.789,1327.78 292.799,1327.78 292.808,1327.78 292.817,1327.78 292.826,1327.78 292.835,1327.78 292.845,1327.78 292.854,1327.78 292.863,1327.78 292.872,1327.78 292.881,1327.78 292.891,1327.78 292.9,1327.78 292.909,1327.79 292.918,1327.79 292.927,1327.79 292.936,1327.79 292.946,1327.79 292.955,1327.79 292.964,1327.79 292.973,1327.79 292.982,1327.79 292.992,1327.79 293.001,1327.79 293.01,1327.79 293.019,1327.79 293.028,1327.79 293.038,1327.79 293.047,1327.79 293.056,1327.79 293.065,1327.8 293.074,1327.8 293.083,1327.8 293.093,1327.8 293.102,1327.8 293.111,1327.8 293.12,1327.8 293.129,1327.8 293.139,1327.8 293.148,1327.8 293.157,1327.8 293.166,1327.8 293.175,1327.8 293.185,1327.8 293.194,1327.8 293.203,1327.8 293.212,1327.81 293.221,1327.81 293.231,1327.81 293.24,1327.81 293.249,1327.81 293.258,1327.81 293.267,1327.81 293.276,1327.81 293.286,1327.81 293.295,1327.81 293.304,1327.81 293.313,1327.81 293.322,1327.81 293.332,1327.81 293.341,1327.81 293.35,1327.81 293.359,1327.81 293.368,1327.82 293.378,1327.82 293.387,1327.82 293.396,1327.82 293.405,1327.82 293.414,1327.82 293.423,1327.82 293.433,1327.82 293.442,1327.82 293.451,1327.82 293.46,1327.82 293.469,1327.82 293.479,1327.82 293.488,1327.82 293.497,1327.82 293.506,1327.82 293.515,1327.82 293.525,1327.83 293.534,1327.83 293.543,1327.83 293.552,1327.83 293.561,1327.83 293.571,1327.83 293.58,1327.83 293.589,1327.83 293.598,1327.83 293.607,1327.83 293.616,1327.83 293.626,1327.83 293.635,1327.83 293.644,1327.83 293.653,1327.83 293.662,1327.83 293.672,1327.83 293.681,1327.84 293.69,1327.84 293.699,1327.84 293.708,1327.84 293.718,1327.84 293.727,1327.84 293.736,1327.84 293.745,1327.84 293.754,1327.84 293.763,1327.84 293.773,1327.84 293.782,1327.84 293.791,1327.84 293.8,1327.84 293.809,1327.84 293.819,1327.84 293.828,1327.84 293.837,1327.85 293.846,1327.85 293.855,1327.85 293.865,1327.85 293.874,1327.85 293.883,1327.85 293.892,1327.85 293.901,1327.85 293.911,1327.85 293.92,1327.85 293.929,1327.85 293.938,1327.85 293.947,1327.85 293.956,1327.85 293.966,1327.85 293.975,1327.85 293.984,1327.85 293.993,1327.86 294.002,1327.86 294.012,1327.86 294.021,1327.86 294.03,1327.86 294.039,1327.86 294.048,1327.86 294.058,1327.86 294.067,1327.86 294.076,1327.86 294.085,1327.86 294.094,1327.86 294.103,1327.86 294.113,1327.86 294.122,1327.86 294.131,1327.86 294.14,1327.86 294.149,1327.87 294.159,1327.87 294.168,1327.87 294.177,1327.87 294.186,1327.87 294.195,1327.87 294.205,1327.87 294.214,1327.87 294.223,1327.87 294.232,1327.87 294.241,1327.87 294.251,1327.87 294.26,1327.87 294.269,1327.87 294.278,1327.87 294.287,1327.87 294.296,1327.87 294.306,1327.88 294.315,1327.88 294.324,1327.88 294.333,1327.88 294.342,1327.88 294.352,1327.88 294.361,1327.88 294.37,1327.88 294.379,1327.88 294.388,1327.88 294.398,1327.88 294.407,1327.88 294.416,1327.88 294.425,1327.88 294.434,1327.88 294.443,1327.88 294.453,1327.88 294.462,1327.89 294.471,1327.89 294.48,1327.89 294.489,1327.89 294.499,1327.89 294.508,1327.89 294.517,1327.89 294.526,1327.89 294.535,1327.89 294.545,1327.89 294.554,1327.89 294.563,1327.89 294.572,1327.89 294.581,1327.89 294.591,1327.89 294.6,1327.89 294.609,1327.89 294.618,1327.9 294.627,1327.9 294.636,1327.9 294.646,1327.9 294.655,1327.9 294.664,1327.9 294.673,1327.9 294.682,1327.9 294.692,1327.9 294.701,1327.9 294.71,1327.9 294.719,1327.9 294.728,1327.9 294.738,1327.9 294.747,1327.9 294.756,1327.9 294.765,1327.9 294.774,1327.91 294.784,1327.91 294.793,1327.91 294.802,1327.91 294.811,1327.91 294.82,1327.91 294.829,1327.91 294.839,1327.91 294.848,1327.91 294.857,1327.91 294.866,1327.91 294.875,1327.91 294.885,1327.91 294.894,1327.91 294.903,1327.91 294.912,1327.91 294.921,1327.91 294.931,1327.92 294.94,1327.92 294.949,1327.92 294.958,1327.92 294.967,1327.92 294.976,1327.92 294.986,1327.92 294.995,1327.92 295.004,1327.92 295.013,1327.92 295.022,1327.92 295.032,1327.92 295.041,1327.92 295.05,1327.92 295.059,1327.92 295.068,1327.92 295.078,1327.92 295.087,1327.93 295.096,1327.93 295.105,1327.93 295.114,1327.93 295.124,1327.93 295.133,1327.93 295.142,1327.93 295.151,1327.93 295.16,1327.93 295.169,1327.93 295.179,1327.93 295.188,1327.93 295.197,1327.93 295.206,1327.93 295.215,1327.93 295.225,1327.93 295.234,1327.93 295.243,1327.94 295.252,1327.94 295.261,1327.94 295.271,1327.94 295.28,1327.94 295.289,1327.94 295.298,1327.94 295.307,1327.94 295.316,1327.94 295.326,1327.94 295.335,1327.94 295.344,1327.94 295.353,1327.94 295.362,1327.94 295.372,1327.94 295.381,1327.94 295.39,1327.94 295.399,1327.95 295.408,1327.95 295.418,1327.95 295.427,1327.95 295.436,1327.95 295.445,1327.95 295.454,1327.95 295.464,1327.95 295.473,1327.95 295.482,1327.95 295.491,1327.95 295.5,1327.95 295.509,1327.95 295.519,1327.95 295.528,1327.95 295.537,1327.95 295.546,1327.95 295.555,1327.96 295.565,1327.96 295.574,1327.96 295.583,1327.96 295.592,1327.96 295.601,1327.96 295.611,1327.96 295.62,1327.96 295.629,1327.96 295.638,1327.96 295.647,1327.96 295.656,1327.96 295.666,1327.96 295.675,1327.96 295.684,1327.96 295.693,1327.96 295.702,1327.97 295.712,1327.97 295.721,1327.97 295.73,1327.97 295.739,1327.97 295.748,1327.97 295.758,1327.97 295.767,1327.97 295.776,1327.97 295.785,1327.97 295.794,1327.97 295.804,1327.97 295.813,1327.97 295.822,1327.97 295.831,1327.97 295.84,1327.97 295.849,1327.97 295.859,1327.98 295.868,1327.98 295.877,1327.98 295.886,1327.98 295.895,1327.98 295.905,1327.98 295.914,1327.98 295.923,1327.98 295.932,1327.98 295.941,1327.98 295.951,1327.98 295.96,1327.98 295.969,1327.98 295.978,1327.98 295.987,1327.98 295.996,1327.98 296.006,1327.98 296.015,1327.99 296.024,1327.99 296.033,1327.99 296.042,1327.99 296.052,1327.99 296.061,1327.99 296.07,1327.99 296.079,1327.99 296.088,1327.99 296.098,1327.99 296.107,1327.99 296.116,1327.99 296.125,1327.99 296.134,1327.99 296.144,1327.99 296.153,1327.99 296.162,1327.99 296.171,1328 296.18,1328 296.189,1328 296.199,1328 296.208,1328 296.217,1328 296.226,1328 296.235,1328 296.245,1328 296.254,1328 296.263,1328 296.272,1328 296.281,1328 296.291,1328 296.3,1328 296.309,1328 296.318,1328 296.327,1328.01 296.336,1328.01 296.346,1328.01 296.355,1328.01 296.364,1328.01 296.373,1328.01 296.382,1328.01 296.392,1328.01 296.401,1328.01 296.41,1328.01 296.419,1328.01 296.428,1328.01 296.438,1328.01 296.447,1328.01 296.456,1328.01 296.465,1328.01 296.474,1328.01 296.484,1328.02 296.493,1328.02 296.502,1328.02 296.511,1328.02 296.52,1328.02 296.529,1328.02 296.539,1328.02 296.548,1328.02 296.557,1328.02 296.566,1328.02 296.575,1328.02 296.585,1328.02 296.594,1328.02 296.603,1328.02 296.612,1328.02 296.621,1328.02 296.631,1328.02 296.64,1328.03 296.649,1328.03 296.658,1328.03 296.667,1328.03 296.676,1328.03 296.686,1328.03 296.695,1328.03 296.704,1328.03 296.713,1328.03 296.722,1328.03 296.732,1328.03 296.741,1328.03 296.75,1328.03 296.759,1328.03 296.768,1328.03 296.778,1328.03 296.787,1328.03 296.796,1328.04 296.805,1328.04 296.814,1328.04 296.824,1328.04 296.833,1328.04 296.842,1328.04 296.851,1328.04 296.86,1328.04 296.869,1328.04 296.879,1328.04 296.888,1328.04 296.897,1328.04 296.906,1328.04 296.915,1328.04 296.925,1328.04 296.934,1328.04 296.943,1328.04 296.952,1328.05 296.961,1328.05 296.971,1328.05 296.98,1328.05 296.989,1328.05 296.998,1328.05 297.007,1328.05 297.017,1328.05 297.026,1328.05 297.035,1328.05 297.044,1328.05 297.053,1328.05 297.062,1328.05 297.072,1328.05 297.081,1328.05 297.09,1328.05 297.099,1328.05 297.108,1328.06 297.118,1328.06 297.127,1328.06 297.136,1328.06 297.145,1328.06 297.154,1328.06 297.164,1328.06 297.173,1328.06 297.182,1328.06 297.191,1328.06 297.2,1328.06 297.209,1328.06 297.219,1328.06 297.228,1328.06 297.237,1328.06 297.246,1328.06 297.255,1328.06 297.265,1328.07 297.274,1328.07 297.283,1328.07 297.292,1328.07 297.301,1328.07 297.311,1328.07 297.32,1328.07 297.329,1328.07 297.338,1328.07 297.347,1328.07 297.357,1328.07 297.366,1328.07 297.375,1328.07 297.384,1328.07 297.393,1328.07 297.402,1328.07 297.412,1328.07 297.421,1328.08 297.43,1328.08 297.439,1328.08 297.448,1328.08 297.458,1328.08 297.467,1328.08 297.476,1328.08 297.485,1328.08 297.494,1328.08 297.504,1328.08 297.513,1328.08 297.522,1328.08 297.531,1328.08 297.54,1328.08 297.549,1328.08 297.559,1328.08 297.568,1328.08 297.577,1328.09 297.586,1328.09 297.595,1328.09 297.605,1328.09 297.614,1328.09 297.623,1328.09 297.632,1328.09 297.641,1328.09 297.651,1328.09 297.66,1328.09 297.669,1328.09 297.678,1328.09 297.687,1328.09 297.697,1328.09 297.706,1328.09 297.715,1328.09 297.724,1328.09 297.733,1328.1 297.742,1328.1 297.752,1328.1 297.761,1328.1 297.77,1328.1 297.779,1328.1 297.788,1328.1 297.798,1328.1 297.807,1328.1 297.816,1328.1 297.825,1328.1 297.834,1328.1 297.844,1328.1 297.853,1328.1 297.862,1328.1 297.871,1328.1 297.88,1328.1 297.889,1328.11 297.899,1328.11 297.908,1328.11 297.917,1328.11 297.926,1328.11 297.935,1328.11 297.945,1328.11 297.954,1328.11 297.963,1328.11 297.972,1328.11 297.981,1328.11 297.991,1328.11 298,1328.11 298.009,1328.11 298.018,1328.11 298.027,1328.11 298.037,1328.11 298.046,1328.12 298.055,1328.12 298.064,1328.12 298.073,1328.12 298.082,1328.12 298.092,1328.12 298.101,1328.12 298.11,1328.12 298.119,1328.12 298.128,1328.12 298.138,1328.12 298.147,1328.12 298.156,1328.12 298.165,1328.12 298.174,1328.12 298.184,1328.12 298.193,1328.12 298.202,1328.13 298.211,1328.13 298.22,1328.13 298.229,1328.13 298.239,1328.13 298.248,1328.13 298.257,1328.13 298.266,1328.13 298.275,1328.13 298.285,1328.13 298.294,1328.13 298.303,1328.13 298.312,1328.13 298.321,1328.13 298.331,1328.13 298.34,1328.13 298.349,1328.13 298.358,1328.14 298.367,1328.14 298.377,1328.14 298.386,1328.14 298.395,1328.14 298.404,1328.14 298.413,1328.14 298.422,1328.14 298.432,1328.14 298.441,1328.14 298.45,1328.14 298.459,1328.14 298.468,1328.14 298.478,1328.14 298.487,1328.14 298.496,1328.14 298.505,1328.14 298.514,1328.15 298.524,1328.15 298.533,1328.15 298.542,1328.15 298.551,1328.15 298.56,1328.15 298.569,1328.15 298.579,1328.15 298.588,1328.15 298.597,1328.15 298.606,1328.15 298.615,1328.15 298.625,1328.15 298.634,1328.15 298.643,1328.15 298.652,1328.15 298.661,1328.15 298.671,1328.16 298.68,1328.16 298.689,1328.16 298.698,1328.16 298.707,1328.16 298.717,1328.16 298.726,1328.16 298.735,1328.16 298.744,1328.16 298.753,1328.16 298.762,1328.16 298.772,1328.16 298.781,1328.16 298.79,1328.16 298.799,1328.16 298.808,1328.16 298.818,1328.16 298.827,1328.17 298.836,1328.17 298.845,1328.17 298.854,1328.17 298.864,1328.17 298.873,1328.17 298.882,1328.17 298.891,1328.17 298.9,1328.17 298.909,1328.17 298.919,1328.17 298.928,1328.17 298.937,1328.17 298.946,1328.17 298.955,1328.17 298.965,1328.17 298.974,1328.17 298.983,1328.18 298.992,1328.18 299.001,1328.18 299.011,1328.18 299.02,1328.18 299.029,1328.18 299.038,1328.18 299.047,1328.18 299.057,1328.18 299.066,1328.18 299.075,1328.18 299.084,1328.18 299.093,1328.18 299.102,1328.18 299.112,1328.18 299.121,1328.18 299.13,1328.18 299.139,1328.19 299.148,1328.19 299.158,1328.19 299.167,1328.19 299.176,1328.19 299.185,1328.19 299.194,1328.19 299.204,1328.19 299.213,1328.19 299.222,1328.19 299.231,1328.19 299.24,1328.19 299.249,1328.19 299.259,1328.19 299.268,1328.19 299.277,1328.19 299.286,1328.19 299.295,1328.2 299.305,1328.2 299.314,1328.2 299.323,1328.2 299.332,1328.2 299.341,1328.2 299.351,1328.2 299.36,1328.2 299.369,1328.2 299.378,1328.2 299.387,1328.2 299.397,1328.2 299.406,1328.2 299.415,1328.2 299.424,1328.2 299.433,1328.2 299.442,1328.2 299.452,1328.21 299.461,1328.21 299.47,1328.21 299.479,1328.21 299.488,1328.21 299.498,1328.21 299.507,1328.21 299.516,1328.21 299.525,1328.21 299.534,1328.21 299.544,1328.21 299.553,1328.21 299.562,1328.21 299.571,1328.21 299.58,1328.21 299.59,1328.21 299.599,1328.21 299.608,1328.22 299.617,1328.22 299.626,1328.22 299.635,1328.22 299.645,1328.22 299.654,1328.22 299.663,1328.22 299.672,1328.22 299.681,1328.22 299.691,1328.22 299.7,1328.22 299.709,1328.22 299.718,1328.22 299.727,1328.22 299.737,1328.22 299.746,1328.22 299.755,1328.22 299.764,1328.23 299.773,1328.23 299.782,1328.23 299.792,1328.23 299.801,1328.23 299.81,1328.23 299.819,1328.23 299.828,1328.23 299.838,1328.23 299.847,1328.23 299.856,1328.23 299.865,1328.23 299.874,1328.23 299.884,1328.23 299.893,1328.23 299.902,1328.23 299.911,1328.23 299.92,1328.24 299.93,1328.24 299.939,1328.24 299.948,1328.24 299.957,1328.24 299.966,1328.24 299.975,1328.24 299.985,1328.24 299.994,1328.24 300.003,1328.24 300.012,1328.24 300.021,1328.24 300.031,1328.24 300.04,1328.24 300.049,1328.24 300.058,1328.24 300.067,1328.24 300.077,1328.25 300.086,1328.25 300.095,1328.25 300.104,1328.25 300.113,1328.25 300.122,1328.25 300.132,1328.25 300.141,1328.25 300.15,1328.25 300.159,1328.25 300.168,1328.25 300.178,1328.25 300.187,1328.25 300.196,1328.25 300.205,1328.25 300.214,1328.25 300.224,1328.25 300.233,1328.26 300.242,1328.26 300.251,1328.26 300.26,1328.26 300.27,1328.26 300.279,1328.26 300.288,1328.26 300.297,1328.26 300.306,1328.26 300.315,1328.26 300.325,1328.26 300.334,1328.26 300.343,1328.26 300.352,1328.26 300.361,1328.26 300.371,1328.26 300.38,1328.26 300.389,1328.27 300.398,1328.27 300.407,1328.27 300.417,1328.27 300.426,1328.27 300.435,1328.27 300.444,1328.27 300.453,1328.27 300.462,1328.27 300.472,1328.27 300.481,1328.27 300.49,1328.27 300.499,1328.27 300.508,1328.27 300.518,1328.27 300.527,1328.27 300.536,1328.27 300.545,1328.28 300.554,1328.28 300.564,1328.28 300.573,1328.28 300.582,1328.28 300.591,1328.28 300.6,1328.28 300.61,1328.28 300.619,1328.28 300.628,1328.28 300.637,1328.28 300.646,1328.28 300.655,1328.28 300.665,1328.28 300.674,1328.28 300.683,1328.28 300.692,1328.28 300.701,1328.29 300.711,1328.29 300.72,1328.29 300.729,1328.29 300.738,1328.29 300.747,1328.29 300.757,1328.29 300.766,1328.29 300.775,1328.29 300.784,1328.29 300.793,1328.29 300.802,1328.29 300.812,1328.29 300.821,1328.29 300.83,1328.29 300.839,1328.29 300.848,1328.29 300.858,1328.3 300.867,1328.3 300.876,1328.3 300.885,1328.3 300.894,1328.3 300.904,1328.3 300.913,1328.3 300.922,1328.3 300.931,1328.3 300.94,1328.3 300.95,1328.3 300.959,1328.3 300.968,1328.3 300.977,1328.3 300.986,1328.3 300.995,1328.3 301.005,1328.3 301.014,1328.31 301.023,1328.31 301.032,1328.31 301.041,1328.31 301.051,1328.31 301.06,1328.31 301.069,1328.31 301.078,1328.31 301.087,1328.31 301.097,1328.31 301.106,1328.31 301.115,1328.31 301.124,1328.31 301.133,1328.31 301.142,1328.31 301.152,1328.31 301.161,1328.31 301.17,1328.32 301.179,1328.32 301.188,1328.32 301.198,1328.32 301.207,1328.32 301.216,1328.32 301.225,1328.32 301.234,1328.32 301.244,1328.32 301.253,1328.32 301.262,1328.32 301.271,1328.32 301.28,1328.32 301.29,1328.32 301.299,1328.32 301.308,1328.32 301.317,1328.32 301.326,1328.33 301.335,1328.33 301.345,1328.33 301.354,1328.33 301.363,1328.33 301.372,1328.33 301.381,1328.33 301.391,1328.33 301.4,1328.33 301.409,1328.33 301.418,1328.33 301.427,1328.33 301.437,1328.33 301.446,1328.33 301.455,1328.33 301.464,1328.33 301.473,1328.33 301.482,1328.34 301.492,1328.34 301.501,1328.34 301.51,1328.34 301.519,1328.34 301.528,1328.34 301.538,1328.34 301.547,1328.34 301.556,1328.34 301.565,1328.34 301.574,1328.34 301.584,1328.34 301.593,1328.34 301.602,1328.34 301.611,1328.34 301.62,1328.34 301.63,1328.34 301.639,1328.35 301.648,1328.35 301.657,1328.35 301.666,1328.35 301.675,1328.35 301.685,1328.35 301.694,1328.35 301.703,1328.35 301.712,1328.35 301.721,1328.35 301.731,1328.35 301.74,1328.35 301.749,1328.35 301.758,1328.35 301.767,1328.35 301.777,1328.35 301.786,1328.35 301.795,1328.36 301.804,1328.36 301.813,1328.36 301.822,1328.36 301.832,1328.36 301.841,1328.36 301.85,1328.36 301.859,1328.36 301.868,1328.36 301.878,1328.36 301.887,1328.36 301.896,1328.36 301.905,1328.36 301.914,1328.36 301.924,1328.36 301.933,1328.36 301.942,1328.36 301.951,1328.36 301.96,1328.37 301.97,1328.37 301.979,1328.37 301.988,1328.37 301.997,1328.37 302.006,1328.37 302.015,1328.37 302.025,1328.37 302.034,1328.37 302.043,1328.37 302.052,1328.37 302.061,1328.37 302.071,1328.37 302.08,1328.37 302.089,1328.37 302.098,1328.37 302.107,1328.37 302.117,1328.38 302.126,1328.38 302.135,1328.38 302.144,1328.38 302.153,1328.38 302.163,1328.38 302.172,1328.38 302.181,1328.38 302.19,1328.38 302.199,1328.38 302.208,1328.38 302.218,1328.38 302.227,1328.38 302.236,1328.38 302.245,1328.38 302.254,1328.38 302.264,1328.38 302.273,1328.39 302.282,1328.39 302.291,1328.39 302.3,1328.39 302.31,1328.39 302.319,1328.39 302.328,1328.39 302.337,1328.39 302.346,1328.39 302.355,1328.39 302.365,1328.39 302.374,1328.39 302.383,1328.39 302.392,1328.39 302.401,1328.39 302.411,1328.39 302.42,1328.39 302.429,1328.4 302.438,1328.4 302.447,1328.4 302.457,1328.4 302.466,1328.4 302.475,1328.4 302.484,1328.4 302.493,1328.4 302.503,1328.4 302.512,1328.4 302.521,1328.4 302.53,1328.4 302.539,1328.4 302.548,1328.4 302.558,1328.4 302.567,1328.4 302.576,1328.4 302.585,1328.41 302.594,1328.41 302.604,1328.41 302.613,1328.41 302.622,1328.41 302.631,1328.41 302.64,1328.41 302.65,1328.41 302.659,1328.41 302.668,1328.41 302.677,1328.41 302.686,1328.41 302.695,1328.41 302.705,1328.41 302.714,1328.41 302.723,1328.41 302.732,1328.41 302.741,1328.42 302.751,1328.42 302.76,1328.42 302.769,1328.42 302.778,1328.42 302.787,1328.42 302.797,1328.42 302.806,1328.42 302.815,1328.42 302.824,1328.42 302.833,1328.42 302.843,1328.42 302.852,1328.42 302.861,1328.42 302.87,1328.42 302.879,1328.42 302.888,1328.42 302.898,1328.43 302.907,1328.43 302.916,1328.43 302.925,1328.43 302.934,1328.43 302.944,1328.43 302.953,1328.43 302.962,1328.43 302.971,1328.43 302.98,1328.43 302.99,1328.43 302.999,1328.43 303.008,1328.43 303.017,1328.43 303.026,1328.43 303.035,1328.43 303.045,1328.43 303.054,1328.44 303.063,1328.44 303.072,1328.44 303.081,1328.44 303.091,1328.44 303.1,1328.44 303.109,1328.44 303.118,1328.44 303.127,1328.44 303.137,1328.44 303.146,1328.44 303.155,1328.44 303.164,1328.44 303.173,1328.44 303.183,1328.44 303.192,1328.44 303.201,1328.44 303.21,1328.45 303.219,1328.45 303.228,1328.45 303.238,1328.45 303.247,1328.45 303.256,1328.45 303.265,1328.45 303.274,1328.45 303.284,1328.45 303.293,1328.45 303.302,1328.45 303.311,1328.45 303.32,1328.45 303.33,1328.45 303.339,1328.45 303.348,1328.45 303.357,1328.45 303.366,1328.46 303.375,1328.46 303.385,1328.46 303.394,1328.46 303.403,1328.46 303.412,1328.46 303.421,1328.46 303.431,1328.46 303.44,1328.46 303.449,1328.46 303.458,1328.46 303.467,1328.46 303.477,1328.46 303.486,1328.46 303.495,1328.46 303.504,1328.46 303.513,1328.46 303.523,1328.47 303.532,1328.47 303.541,1328.47 303.55,1328.47 303.559,1328.47 303.568,1328.47 303.578,1328.47 303.587,1328.47 303.596,1328.47 303.605,1328.47 303.614,1328.47 303.624,1328.47 303.633,1328.47 303.642,1328.47 303.651,1328.47 303.66,1328.47 303.67,1328.47 303.679,1328.48 303.688,1328.48 303.697,1328.48 303.706,1328.48 303.715,1328.48 303.725,1328.48 303.734,1328.48 303.743,1328.48 303.752,1328.48 303.761,1328.48 303.771,1328.48 303.78,1328.48 303.789,1328.48 303.798,1328.48 303.807,1328.48 303.817,1328.48 303.826,1328.48 303.835,1328.49 303.844,1328.49 303.853,1328.49 303.863,1328.49 303.872,1328.49 303.881,1328.49 303.89,1328.49 303.899,1328.49 303.908,1328.49 303.918,1328.49 303.927,1328.49 303.936,1328.49 303.945,1328.49 303.954,1328.49 303.964,1328.49 303.973,1328.49 303.982,1328.49 303.991,1328.5 304,1328.5 304.01,1328.5 304.019,1328.5 304.028,1328.5 304.037,1328.5 304.046,1328.5 304.055,1328.5 304.065,1328.5 304.074,1328.5 304.083,1328.5 304.092,1328.5 304.101,1328.5 304.111,1328.5 304.12,1328.5 304.129,1328.5 304.138,1328.5 304.147,1328.51 304.157,1328.51 304.166,1328.51 304.175,1328.51 304.184,1328.51 304.193,1328.51 304.203,1328.51 304.212,1328.51 304.221,1328.51 304.23,1328.51 304.239,1328.51 304.248,1328.51 304.258,1328.51 304.267,1328.51 304.276,1328.51 304.285,1328.51 304.294,1328.51 304.304,1328.52 304.313,1328.52 304.322,1328.52 304.331,1328.52 304.34,1328.52 304.35,1328.52 304.359,1328.52 304.368,1328.52 304.377,1328.52 304.386,1328.52 304.395,1328.52 304.405,1328.52 304.414,1328.52 304.423,1328.52 304.432,1328.52 304.441,1328.52 304.451,1328.52 304.46,1328.53 304.469,1328.53 304.478,1328.53 304.487,1328.53 304.497,1328.53 304.506,1328.53 304.515,1328.53 304.524,1328.53 304.533,1328.53 304.543,1328.53 304.552,1328.53 304.561,1328.53 304.57,1328.53 304.579,1328.53 304.588,1328.53 304.598,1328.53 304.607,1328.53 304.616,1328.53 304.625,1328.54 304.634,1328.54 304.644,1328.54 304.653,1328.54 304.662,1328.54 304.671,1328.54 304.68,1328.54 304.69,1328.54 304.699,1328.54 304.708,1328.54 304.717,1328.54 304.726,1328.54 304.736,1328.54 304.745,1328.54 304.754,1328.54 304.763,1328.54 304.772,1328.54 304.781,1328.55 304.791,1328.55 304.8,1328.55 304.809,1328.55 304.818,1328.55 304.827,1328.55 304.837,1328.55 304.846,1328.55 304.855,1328.55 304.864,1328.55 304.873,1328.55 304.883,1328.55 304.892,1328.55 304.901,1328.55 304.91,1328.55 304.919,1328.55 304.928,1328.55 304.938,1328.56 304.947,1328.56 304.956,1328.56 304.965,1328.56 304.974,1328.56 304.984,1328.56 304.993,1328.56 305.002,1328.56 305.011,1328.56 305.02,1328.56 305.03,1328.56 305.039,1328.56 305.048,1328.56 305.057,1328.56 305.066,1328.56 305.076,1328.56 305.085,1328.56 305.094,1328.57 305.103,1328.57 305.112,1328.57 305.121,1328.57 305.131,1328.57 305.14,1328.57 305.149,1328.57 305.158,1328.57 305.167,1328.57 305.177,1328.57 305.186,1328.57 305.195,1328.57 305.204,1328.57 305.213,1328.57 305.223,1328.57 305.232,1328.57 305.241,1328.57 305.25,1328.58 305.259,1328.58 305.268,1328.58 305.278,1328.58 305.287,1328.58 305.296,1328.58 305.305,1328.58 305.314,1328.58 305.324,1328.58 305.333,1328.58 305.342,1328.58 305.351,1328.58 305.36,1328.58 305.37,1328.58 305.379,1328.58 305.388,1328.58 305.397,1328.58 305.406,1328.59 305.416,1328.59 305.425,1328.59 305.434,1328.59 305.443,1328.59 305.452,1328.59 305.461,1328.59 305.471,1328.59 305.48,1328.59 305.489,1328.59 305.498,1328.59 305.507,1328.59 305.517,1328.59 305.526,1328.59 305.535,1328.59 305.544,1328.59 305.553,1328.59 305.563,1328.6 305.572,1328.6 305.581,1328.6 305.59,1328.6 305.599,1328.6 305.608,1328.6 305.618,1328.6 305.627,1328.6 305.636,1328.6 305.645,1328.6 305.654,1328.6 305.664,1328.6 305.673,1328.6 305.682,1328.6 305.691,1328.6 305.7,1328.6 305.71,1328.6 305.719,1328.61 305.728,1328.61 305.737,1328.61 305.746,1328.61 305.756,1328.61 305.765,1328.61 305.774,1328.61 305.783,1328.61 305.792,1328.61 305.801,1328.61 305.811,1328.61 305.82,1328.61 305.829,1328.61 305.838,1328.61 305.847,1328.61 305.857,1328.61 305.866,1328.61 305.875,1328.62 305.884,1328.62 305.893,1328.62 305.903,1328.62 305.912,1328.62 305.921,1328.62 305.93,1328.62 305.939,1328.62 305.948,1328.62 305.958,1328.62 305.967,1328.62 305.976,1328.62 305.985,1328.62 305.994,1328.62 306.004,1328.62 306.013,1328.62 306.022,1328.62 306.031,1328.63 306.04,1328.63 306.05,1328.63 306.059,1328.63 306.068,1328.63 306.077,1328.63 306.086,1328.63 306.096,1328.63 306.105,1328.63 306.114,1328.63 306.123,1328.63 306.132,1328.63 306.141,1328.63 306.151,1328.63 306.16,1328.63 306.169,1328.63 306.178,1328.63 306.187,1328.64 306.197,1328.64 306.206,1328.64 306.215,1328.64 306.224,1328.64 306.233,1328.64 306.243,1328.64 306.252,1328.64 306.261,1328.64 306.27,1328.64 306.279,1328.64 306.288,1328.64 306.298,1328.64 306.307,1328.64 306.316,1328.64 306.325,1328.64 306.334,1328.64 306.344,1328.64 306.353,1328.65 306.362,1328.65 306.371,1328.65 306.38,1328.65 306.39,1328.65 306.399,1328.65 306.408,1328.65 306.417,1328.65 306.426,1328.65 306.436,1328.65 306.445,1328.65 306.454,1328.65 306.463,1328.65 306.472,1328.65 306.481,1328.65 306.491,1328.65 306.5,1328.65 306.509,1328.66 306.518,1328.66 306.527,1328.66 306.537,1328.66 306.546,1328.66 306.555,1328.66 306.564,1328.66 306.573,1328.66 306.583,1328.66 306.592,1328.66 306.601,1328.66 306.61,1328.66 306.619,1328.66 306.628,1328.66 306.638,1328.66 306.647,1328.66 306.656,1328.66 306.665,1328.67 306.674,1328.67 306.684,1328.67 306.693,1328.67 306.702,1328.67 306.711,1328.67 306.72,1328.67 306.73,1328.67 306.739,1328.67 306.748,1328.67 306.757,1328.67 306.766,1328.67 306.776,1328.67 306.785,1328.67 306.794,1328.67 306.803,1328.67 306.812,1328.67 306.821,1328.68 306.831,1328.68 306.84,1328.68 306.849,1328.68 306.858,1328.68 306.867,1328.68 306.877,1328.68 306.886,1328.68 306.895,1328.68 306.904,1328.68 306.913,1328.68 306.923,1328.68 306.932,1328.68 306.941,1328.68 306.95,1328.68 306.959,1328.68 306.969,1328.68 306.978,1328.69 306.987,1328.69 306.996,1328.69 307.005,1328.69 307.014,1328.69 307.024,1328.69 307.033,1328.69 307.042,1328.69 307.051,1328.69 307.06,1328.69 307.07,1328.69 307.079,1328.69 307.088,1328.69 307.097,1328.69 307.106,1328.69 307.116,1328.69 307.125,1328.69 307.134,1328.7 307.143,1328.7 307.152,1328.7 307.161,1328.7 307.171,1328.7 307.18,1328.7 307.189,1328.7 307.198,1328.7 307.207,1328.7 307.217,1328.7 307.226,1328.7 307.235,1328.7 307.244,1328.7 307.253,1328.7 307.263,1328.7 307.272,1328.7 307.281,1328.7 307.29,1328.71 307.299,1328.71 307.309,1328.71 307.318,1328.71 307.327,1328.71 307.336,1328.71 307.345,1328.71 307.354,1328.71 307.364,1328.71 307.373,1328.71 307.382,1328.71 307.391,1328.71 307.4,1328.71 307.41,1328.71 307.419,1328.71 307.428,1328.71 307.437,1328.71 307.446,1328.72 307.456,1328.72 307.465,1328.72 307.474,1328.72 307.483,1328.72 307.492,1328.72 307.501,1328.72 307.511,1328.72 307.52,1328.72 307.529,1328.72 307.538,1328.72 307.547,1328.72 307.557,1328.72 307.566,1328.72 307.575,1328.72 307.584,1328.72 307.593,1328.72 307.603,1328.73 307.612,1328.73 307.621,1328.73 307.63,1328.73 307.639,1328.73 307.649,1328.73 307.658,1328.73 307.667,1328.73 307.676,1328.73 307.685,1328.73 307.694,1328.73 307.704,1328.73 307.713,1328.73 307.722,1328.73 307.731,1328.73 307.74,1328.73 307.75,1328.73 307.759,1328.73 307.768,1328.74 307.777,1328.74 307.786,1328.74 307.796,1328.74 307.805,1328.74 307.814,1328.74 307.823,1328.74 307.832,1328.74 307.841,1328.74 307.851,1328.74 307.86,1328.74 307.869,1328.74 307.878,1328.74 307.887,1328.74 307.897,1328.74 307.906,1328.74 307.915,1328.74 307.924,1328.75 307.933,1328.75 307.943,1328.75 307.952,1328.75 307.961,1328.75 307.97,1328.75 307.979,1328.75 307.989,1328.75 307.998,1328.75 308.007,1328.75 308.016,1328.75 308.025,1328.75 308.034,1328.75 308.044,1328.75 308.053,1328.75 308.062,1328.75 308.071,1328.75 308.08,1328.76 308.09,1328.76 308.099,1328.76 308.108,1328.76 308.117,1328.76 308.126,1328.76 308.136,1328.76 308.145,1328.76 308.154,1328.76 308.163,1328.76 308.172,1328.76 308.181,1328.76 308.191,1328.76 308.2,1328.76 308.209,1328.76 308.218,1328.76 308.227,1328.76 308.237,1328.77 308.246,1328.77 308.255,1328.77 308.264,1328.77 308.273,1328.77 308.283,1328.77 308.292,1328.77 308.301,1328.77 308.31,1328.77 308.319,1328.77 308.329,1328.77 308.338,1328.77 308.347,1328.77 308.356,1328.77 308.365,1328.77 308.374,1328.77 308.384,1328.77 308.393,1328.78 308.402,1328.78 308.411,1328.78 308.42,1328.78 308.43,1328.78 308.439,1328.78 308.448,1328.78 308.457,1328.78 308.466,1328.78 308.476,1328.78 308.485,1328.78 308.494,1328.78 308.503,1328.78 308.512,1328.78 308.521,1328.78 308.531,1328.78 308.54,1328.78 308.549,1328.79 308.558,1328.79 308.567,1328.79 308.577,1328.79 308.586,1328.79 308.595,1328.79 308.604,1328.79 308.613,1328.79 308.623,1328.79 308.632,1328.79 308.641,1328.79 308.65,1328.79 308.659,1328.79 308.669,1328.79 308.678,1328.79 308.687,1328.79 308.696,1328.79 308.705,1328.8 308.714,1328.8 308.724,1328.8 308.733,1328.8 308.742,1328.8 308.751,1328.8 308.76,1328.8 308.77,1328.8 308.779,1328.8 308.788,1328.8 308.797,1328.8 308.806,1328.8 308.816,1328.8 308.825,1328.8 308.834,1328.8 308.843,1328.8 308.852,1328.8 308.861,1328.8 308.871,1328.81 308.88,1328.81 308.889,1328.81 308.898,1328.81 308.907,1328.81 308.917,1328.81 308.926,1328.81 308.935,1328.81 308.944,1328.81 308.953,1328.81 308.963,1328.81 308.972,1328.81 308.981,1328.81 308.99,1328.81 308.999,1328.81 309.009,1328.81 309.018,1328.81 309.027,1328.82 309.036,1328.82 309.045,1328.82 309.054,1328.82 309.064,1328.82 309.073,1328.82 309.082,1328.82 309.091,1328.82 309.1,1328.82 309.11,1328.82 309.119,1328.82 309.128,1328.82 309.137,1328.82 309.146,1328.82 309.156,1328.82 309.165,1328.82 309.174,1328.82 309.183,1328.83 309.192,1328.83 309.201,1328.83 309.211,1328.83 309.22,1328.83 309.229,1328.83 309.238,1328.83 309.247,1328.83 309.257,1328.83 309.266,1328.83 309.275,1328.83 309.284,1328.83 309.293,1328.83 309.303,1328.83 309.312,1328.83 309.321,1328.83 309.33,1328.83 309.339,1328.84 309.349,1328.84 309.358,1328.84 309.367,1328.84 309.376,1328.84 309.385,1328.84 309.394,1328.84 309.404,1328.84 309.413,1328.84 309.422,1328.84 309.431,1328.84 309.44,1328.84 309.45,1328.84 309.459,1328.84 309.468,1328.84 309.477,1328.84 309.486,1328.84 309.496,1328.85 309.505,1328.85 309.514,1328.85 309.523,1328.85 309.532,1328.85 309.542,1328.85 309.551,1328.85 309.56,1328.85 309.569,1328.85 309.578,1328.85 309.587,1328.85 309.597,1328.85 309.606,1328.85 309.615,1328.85 309.624,1328.85 309.633,1328.85 309.643,1328.85 309.652,1328.86 309.661,1328.86 309.67,1328.86 309.679,1328.86 309.689,1328.86 309.698,1328.86 309.707,1328.86 309.716,1328.86 309.725,1328.86 309.734,1328.86 309.744,1328.86 309.753,1328.86 309.762,1328.86 309.771,1328.86 309.78,1328.86 309.79,1328.86 309.799,1328.86 309.808,1328.87 309.817,1328.87 309.826,1328.87 309.836,1328.87 309.845,1328.87 309.854,1328.87 309.863,1328.87 309.872,1328.87 309.882,1328.87 309.891,1328.87 309.9,1328.87 309.909,1328.87 309.918,1328.87 309.927,1328.87 309.937,1328.87 309.946,1328.87 309.955,1328.87 309.964,1328.87 309.973,1328.88 309.983,1328.88 309.992,1328.88 310.001,1328.88 310.01,1328.88 310.019,1328.88 310.029,1328.88 310.038,1328.88 310.047,1328.88 310.056,1328.88 310.065,1328.88 310.074,1328.88 310.084,1328.88 310.093,1328.88 310.102,1328.88 310.111,1328.88 310.12,1328.88 310.13,1328.89 310.139,1328.89 310.148,1328.89 310.157,1328.89 310.166,1328.89 310.176,1328.89 310.185,1328.89 310.194,1328.89 310.203,1328.89 310.212,1328.89 310.222,1328.89 310.231,1328.89 310.24,1328.89 310.249,1328.89 310.258,1328.89 310.267,1328.89 310.277,1328.89 310.286,1328.9 310.295,1328.9 310.304,1328.9 310.313,1328.9 310.323,1328.9 310.332,1328.9 310.341,1328.9 310.35,1328.9 310.359,1328.9 310.369,1328.9 310.378,1328.9 310.387,1328.9 310.396,1328.9 310.405,1328.9 310.414,1328.9 310.424,1328.9 310.433,1328.9 310.442,1328.91 310.451,1328.91 310.46,1328.91 310.47,1328.91 310.479,1328.91 310.488,1328.91 310.497,1328.91 310.506,1328.91 310.516,1328.91 310.525,1328.91 310.534,1328.91 310.543,1328.91 310.552,1328.91 310.562,1328.91 310.571,1328.91 310.58,1328.91 310.589,1328.91 310.598,1328.92 310.607,1328.92 310.617,1328.92 310.626,1328.92 310.635,1328.92 310.644,1328.92 310.653,1328.92 310.663,1328.92 310.672,1328.92 310.681,1328.92 310.69,1328.92 310.699,1328.92 310.709,1328.92 310.718,1328.92 310.727,1328.92 310.736,1328.92 310.745,1328.92 310.754,1328.93 310.764,1328.93 310.773,1328.93 310.782,1328.93 310.791,1328.93 310.8,1328.93 310.81,1328.93 310.819,1328.93 310.828,1328.93 310.837,1328.93 310.846,1328.93 310.856,1328.93 310.865,1328.93 310.874,1328.93 310.883,1328.93 310.892,1328.93 310.902,1328.93 310.911,1328.93 310.92,1328.94 310.929,1328.94 310.938,1328.94 310.947,1328.94 310.957,1328.94 310.966,1328.94 310.975,1328.94 310.984,1328.94 310.993,1328.94 311.003,1328.94 311.012,1328.94 311.021,1328.94 311.03,1328.94 311.039,1328.94 311.049,1328.94 311.058,1328.94 311.067,1328.94 311.076,1328.95 311.085,1328.95 311.094,1328.95 311.104,1328.95 311.113,1328.95 311.122,1328.95 311.131,1328.95 311.14,1328.95 311.15,1328.95 311.159,1328.95 311.168,1328.95 311.177,1328.95 311.186,1328.95 311.196,1328.95 311.205,1328.95 311.214,1328.95 311.223,1328.95 311.232,1328.96 311.242,1328.96 311.251,1328.96 311.26,1328.96 311.269,1328.96 311.278,1328.96 311.287,1328.96 311.297,1328.96 311.306,1328.96 311.315,1328.96 311.324,1328.96 311.333,1328.96 311.343,1328.96 311.352,1328.96 311.361,1328.96 311.37,1328.96 311.379,1328.96 311.389,1328.97 311.398,1328.97 311.407,1328.97 311.416,1328.97 311.425,1328.97 311.434,1328.97 311.444,1328.97 311.453,1328.97 311.462,1328.97 311.471,1328.97 311.48,1328.97 311.49,1328.97 311.499,1328.97 311.508,1328.97 311.517,1328.97 311.526,1328.97 311.536,1328.97 311.545,1328.98 311.554,1328.98 311.563,1328.98 311.572,1328.98 311.582,1328.98 311.591,1328.98 311.6,1328.98 311.609,1328.98 311.618,1328.98 311.627,1328.98 311.637,1328.98 311.646,1328.98 311.655,1328.98 311.664,1328.98 311.673,1328.98 311.683,1328.98 311.692,1328.98 311.701,1328.99 311.71,1328.99 311.719,1328.99 311.729,1328.99 311.738,1328.99 311.747,1328.99 311.756,1328.99 311.765,1328.99 311.774,1328.99 311.784,1328.99 311.793,1328.99 311.802,1328.99 311.811,1328.99 311.82,1328.99 311.83,1328.99 311.839,1328.99 311.848,1328.99 311.857,1328.99 311.866,1329 311.876,1329 311.885,1329 311.894,1329 311.903,1329 311.912,1329 311.922,1329 311.931,1329 311.94,1329 311.949,1329 311.958,1329 311.967,1329 311.977,1329 311.986,1329 311.995,1329 312.004,1329 312.013,1329 312.023,1329.01 312.032,1329.01 312.041,1329.01 312.05,1329.01 312.059,1329.01 312.069,1329.01 312.078,1329.01 312.087,1329.01 312.096,1329.01 312.105,1329.01 312.115,1329.01 312.124,1329.01 312.133,1329.01 312.142,1329.01 312.151,1329.01 312.16,1329.01 312.17,1329.01 312.179,1329.02 312.188,1329.02 312.197,1329.02 312.206,1329.02 312.216,1329.02 312.225,1329.02 312.234,1329.02 312.243,1329.02 312.252,1329.02 312.262,1329.02 312.271,1329.02 312.28,1329.02 312.289,1329.02 312.298,1329.02 312.307,1329.02 312.317,1329.02 312.326,1329.02 312.335,1329.03 312.344,1329.03 312.353,1329.03 312.363,1329.03 312.372,1329.03 312.381,1329.03 312.39,1329.03 312.399,1329.03 312.409,1329.03 312.418,1329.03 312.427,1329.03 312.436,1329.03 312.445,1329.03 312.455,1329.03 312.464,1329.03 312.473,1329.03 312.482,1329.03 312.491,1329.04 312.5,1329.04 312.51,1329.04 312.519,1329.04 312.528,1329.04 312.537,1329.04 312.546,1329.04 312.556,1329.04 312.565,1329.04 312.574,1329.04 312.583,1329.04 312.592,1329.04 312.602,1329.04 312.611,1329.04 312.62,1329.04 312.629,1329.04 312.638,1329.04 312.647,1329.04 312.657,1329.05 312.666,1329.05 312.675,1329.05 312.684,1329.05 312.693,1329.05 312.703,1329.05 312.712,1329.05 312.721,1329.05 312.73,1329.05 312.739,1329.05 312.749,1329.05 312.758,1329.05 312.767,1329.05 312.776,1329.05 312.785,1329.05 312.795,1329.05 312.804,1329.05 312.813,1329.06 312.822,1329.06 312.831,1329.06 312.84,1329.06 312.85,1329.06 312.859,1329.06 312.868,1329.06 312.877,1329.06 312.886,1329.06 312.896,1329.06 312.905,1329.06 312.914,1329.06 312.923,1329.06 312.932,1329.06 312.942,1329.06 312.951,1329.06 312.96,1329.06 312.969,1329.07 312.978,1329.07 312.987,1329.07 312.997,1329.07 313.006,1329.07 313.015,1329.07 313.024,1329.07 313.033,1329.07 313.043,1329.07 313.052,1329.07 313.061,1329.07 313.07,1329.07 313.079,1329.07 313.089,1329.07 313.098,1329.07 313.107,1329.07 313.116,1329.07 313.125,1329.08 313.135,1329.08 313.144,1329.08 313.153,1329.08 313.162,1329.08 313.171,1329.08 313.18,1329.08 313.19,1329.08 313.199,1329.08 313.208,1329.08 313.217,1329.08 313.226,1329.08 313.236,1329.08 313.245,1329.08 313.254,1329.08 313.263,1329.08 313.272,1329.08 313.282,1329.09 313.291,1329.09 313.3,1329.09 313.309,1329.09 313.318,1329.09 313.327,1329.09 313.337,1329.09 313.346,1329.09 313.355,1329.09 313.364,1329.09 313.373,1329.09 313.383,1329.09 313.392,1329.09 313.401,1329.09 313.41,1329.09 313.419,1329.09 313.429,1329.09 313.438,1329.09 313.447,1329.1 313.456,1329.1 313.465,1329.1 313.475,1329.1 313.484,1329.1 313.493,1329.1 313.502,1329.1 313.511,1329.1 313.52,1329.1 313.53,1329.1 313.539,1329.1 313.548,1329.1 313.557,1329.1 313.566,1329.1 313.576,1329.1 313.585,1329.1 313.594,1329.1 313.603,1329.11 313.612,1329.11 313.622,1329.11 313.631,1329.11 313.64,1329.11 313.649,1329.11 313.658,1329.11 313.667,1329.11 313.677,1329.11 313.686,1329.11 313.695,1329.11 313.704,1329.11 313.713,1329.11 313.723,1329.11 313.732,1329.11 313.741,1329.11 313.75,1329.11 313.759,1329.12 313.769,1329.12 313.778,1329.12 313.787,1329.12 313.796,1329.12 313.805,1329.12 313.815,1329.12 313.824,1329.12 313.833,1329.12 313.842,1329.12 313.851,1329.12 313.86,1329.12 313.87,1329.12 313.879,1329.12 313.888,1329.12 313.897,1329.12 313.906,1329.12 313.916,1329.13 313.925,1329.13 313.934,1329.13 313.943,1329.13 313.952,1329.13 313.962,1329.13 313.971,1329.13 313.98,1329.13 313.989,1329.13 313.998,1329.13 314.007,1329.13 314.017,1329.13 314.026,1329.13 314.035,1329.13 314.044,1329.13 314.053,1329.13 314.063,1329.13 314.072,1329.14 314.081,1329.14 314.09,1329.14 314.099,1329.14 314.109,1329.14 314.118,1329.14 314.127,1329.14 314.136,1329.14 314.145,1329.14 314.155,1329.14 314.164,1329.14 314.173,1329.14 314.182,1329.14 314.191,1329.14 314.2,1329.14 314.21,1329.14 314.219,1329.14 314.228,1329.14 314.237,1329.15 314.246,1329.15 314.256,1329.15 314.265,1329.15 314.274,1329.15 314.283,1329.15 314.292,1329.15 314.302,1329.15 314.311,1329.15 314.32,1329.15 314.329,1329.15 314.338,1329.15 314.348,1329.15 314.357,1329.15 314.366,1329.15 314.375,1329.15 314.384,1329.15 314.393,1329.16 314.403,1329.16 314.412,1329.16 314.421,1329.16 314.43,1329.16 314.439,1329.16 314.449,1329.16 314.458,1329.16 314.467,1329.16 314.476,1329.16 314.485,1329.16 314.495,1329.16 314.504,1329.16 314.513,1329.16 314.522,1329.16 314.531,1329.16 314.54,1329.16 314.55,1329.17 314.559,1329.17 314.568,1329.17 314.577,1329.17 314.586,1329.17 314.596,1329.17 314.605,1329.17 314.614,1329.17 314.623,1329.17 314.632,1329.17 314.642,1329.17 314.651,1329.17 314.66,1329.17 314.669,1329.17 314.678,1329.17 314.688,1329.17 314.697,1329.17 314.706,1329.18 314.715,1329.18 314.724,1329.18 314.733,1329.18 314.743,1329.18 314.752,1329.18 314.761,1329.18 314.77,1329.18 314.779,1329.18 314.789,1329.18 314.798,1329.18 314.807,1329.18 314.816,1329.18 314.825,1329.18 314.835,1329.18 314.844,1329.18 314.853,1329.18 314.862,1329.19 314.871,1329.19 314.88,1329.19 314.89,1329.19 314.899,1329.19 314.908,1329.19 314.917,1329.19 314.926,1329.19 314.936,1329.19 314.945,1329.19 314.954,1329.19 314.963,1329.19 314.972,1329.19 314.982,1329.19 314.991,1329.19 315,1329.19 315.009,1329.19 315.018,1329.19 315.028,1329.2 315.037,1329.2 315.046,1329.2 315.055,1329.2 315.064,1329.2 315.073,1329.2 315.083,1329.2 315.092,1329.2 315.101,1329.2 315.11,1329.2 315.119,1329.2 315.129,1329.2 315.138,1329.2 315.147,1329.2 315.156,1329.2 315.165,1329.2 315.175,1329.2 315.184,1329.21 315.193,1329.21 315.202,1329.21 315.211,1329.21 315.22,1329.21 315.23,1329.21 315.239,1329.21 315.248,1329.21 315.257,1329.21 315.266,1329.21 315.276,1329.21 315.285,1329.21 315.294,1329.21 315.303,1329.21 315.312,1329.21 315.322,1329.21 315.331,1329.21 315.34,1329.22 315.349,1329.22 315.358,1329.22 315.368,1329.22 315.377,1329.22 315.386,1329.22 315.395,1329.22 315.404,1329.22 315.413,1329.22 315.423,1329.22 315.432,1329.22 315.441,1329.22 315.45,1329.22 315.459,1329.22 315.469,1329.22 315.478,1329.22 315.487,1329.22 315.496,1329.23 315.505,1329.23 315.515,1329.23 315.524,1329.23 315.533,1329.23 315.542,1329.23 315.551,1329.23 315.56,1329.23 315.57,1329.23 315.579,1329.23 315.588,1329.23 315.597,1329.23 315.606,1329.23 315.616,1329.23 315.625,1329.23 315.634,1329.23 315.643,1329.23 315.652,1329.23 315.662,1329.24 315.671,1329.24 315.68,1329.24 315.689,1329.24 315.698,1329.24 315.708,1329.24 315.717,1329.24 315.726,1329.24 315.735,1329.24 315.744,1329.24 315.753,1329.24 315.763,1329.24 315.772,1329.24 315.781,1329.24 315.79,1329.24 315.799,1329.24 315.809,1329.24 315.818,1329.25 315.827,1329.25 315.836,1329.25 315.845,1329.25 315.855,1329.25 315.864,1329.25 315.873,1329.25 315.882,1329.25 315.891,1329.25 315.9,1329.25 315.91,1329.25 315.919,1329.25 315.928,1329.25 315.937,1329.25 315.946,1329.25 315.956,1329.25 315.965,1329.25 315.974,1329.26 315.983,1329.26 315.992,1329.26 316.002,1329.26 316.011,1329.26 316.02,1329.26 316.029,1329.26 316.038,1329.26 316.048,1329.26 316.057,1329.26 316.066,1329.26 316.075,1329.26 316.084,1329.26 316.093,1329.26 316.103,1329.26 316.112,1329.26 316.121,1329.26 316.13,1329.27 316.139,1329.27 316.149,1329.27 316.158,1329.27 316.167,1329.27 316.176,1329.27 316.185,1329.27 316.195,1329.27 316.204,1329.27 316.213,1329.27 316.222,1329.27 316.231,1329.27 316.24,1329.27 316.25,1329.27 316.259,1329.27 316.268,1329.27 316.277,1329.27 316.286,1329.27 316.296,1329.28 316.305,1329.28 316.314,1329.28 316.323,1329.28 316.332,1329.28 316.342,1329.28 316.351,1329.28 316.36,1329.28 316.369,1329.28 316.378,1329.28 316.388,1329.28 316.397,1329.28 316.406,1329.28 316.415,1329.28 316.424,1329.28 316.433,1329.28 316.443,1329.28 316.452,1329.29 316.461,1329.29 316.47,1329.29 316.479,1329.29 316.489,1329.29 316.498,1329.29 316.507,1329.29 316.516,1329.29 316.525,1329.29 316.535,1329.29 316.544,1329.29 316.553,1329.29 316.562,1329.29 316.571,1329.29 316.58,1329.29 316.59,1329.29 316.599,1329.29 316.608,1329.3 316.617,1329.3 316.626,1329.3 316.636,1329.3 316.645,1329.3 316.654,1329.3 316.663,1329.3 316.672,1329.3 316.682,1329.3 316.691,1329.3 316.7,1329.3 316.709,1329.3 316.718,1329.3 316.728,1329.3 316.737,1329.3 316.746,1329.3 316.755,1329.3 316.764,1329.31 316.773,1329.31 316.783,1329.31 316.792,1329.31 316.801,1329.31 316.81,1329.31 316.819,1329.31 316.829,1329.31 316.838,1329.31 316.847,1329.31 316.856,1329.31 316.865,1329.31 316.875,1329.31 316.884,1329.31 316.893,1329.31 316.902,1329.31 316.911,1329.31 316.921,1329.31 316.93,1329.32 316.939,1329.32 316.948,1329.32 316.957,1329.32 316.966,1329.32 316.976,1329.32 316.985,1329.32 316.994,1329.32 317.003,1329.32 317.012,1329.32 317.022,1329.32 317.031,1329.32 317.04,1329.32 317.049,1329.32 317.058,1329.32 317.068,1329.32 317.077,1329.32 317.086,1329.33 317.095,1329.33 317.104,1329.33 317.113,1329.33 317.123,1329.33 317.132,1329.33 317.141,1329.33 317.15,1329.33 317.159,1329.33 317.169,1329.33 317.178,1329.33 317.187,1329.33 317.196,1329.33 317.205,1329.33 317.215,1329.33 317.224,1329.33 317.233,1329.33 317.242,1329.34 317.251,1329.34 317.261,1329.34 317.27,1329.34 317.279,1329.34 317.288,1329.34 317.297,1329.34 317.306,1329.34 317.316,1329.34 317.325,1329.34 317.334,1329.34 317.343,1329.34 317.352,1329.34 317.362,1329.34 317.371,1329.34 317.38,1329.34 317.389,1329.34 317.398,1329.35 317.408,1329.35 317.417,1329.35 317.426,1329.35 317.435,1329.35 317.444,1329.35 317.453,1329.35 317.463,1329.35 317.472,1329.35 317.481,1329.35 317.49,1329.35 317.499,1329.35 317.509,1329.35 317.518,1329.35 317.527,1329.35 317.536,1329.35 317.545,1329.35 317.555,1329.35 317.564,1329.36 317.573,1329.36 317.582,1329.36 317.591,1329.36 317.601,1329.36 317.61,1329.36 317.619,1329.36 317.628,1329.36 317.637,1329.36 317.646,1329.36 317.656,1329.36 317.665,1329.36 317.674,1329.36 317.683,1329.36 317.692,1329.36 317.702,1329.36 317.711,1329.36 317.72,1329.37 317.729,1329.37 317.738,1329.37 317.748,1329.37 317.757,1329.37 317.766,1329.37 317.775,1329.37 317.784,1329.37 317.793,1329.37 317.803,1329.37 317.812,1329.37 317.821,1329.37 317.83,1329.37 317.839,1329.37 317.849,1329.37 317.858,1329.37 317.867,1329.37 317.876,1329.38 317.885,1329.38 317.895,1329.38 317.904,1329.38 317.913,1329.38 317.922,1329.38 317.931,1329.38 317.941,1329.38 317.95,1329.38 317.959,1329.38 317.968,1329.38 317.977,1329.38 317.986,1329.38 317.996,1329.38 318.005,1329.38 318.014,1329.38 318.023,1329.38 318.032,1329.39 318.042,1329.39 318.051,1329.39 318.06,1329.39 318.069,1329.39 318.078,1329.39 318.088,1329.39 318.097,1329.39 318.106,1329.39 318.115,1329.39 318.124,1329.39 318.133,1329.39 318.143,1329.39 318.152,1329.39 318.161,1329.39 318.17,1329.39 318.179,1329.39 318.189,1329.39 318.198,1329.4 318.207,1329.4 318.216,1329.4 318.225,1329.4 318.235,1329.4 318.244,1329.4 318.253,1329.4 318.262,1329.4 318.271,1329.4 318.281,1329.4 318.29,1329.4 318.299,1329.4 318.308,1329.4 318.317,1329.4 318.326,1329.4 318.336,1329.4 318.345,1329.4 318.354,1329.41 318.363,1329.41 318.372,1329.41 318.382,1329.41 318.391,1329.41 318.4,1329.41 318.409,1329.41 318.418,1329.41 318.428,1329.41 318.437,1329.41 318.446,1329.41 318.455,1329.41 318.464,1329.41 318.473,1329.41 318.483,1329.41 318.492,1329.41 318.501,1329.41 318.51,1329.42 318.519,1329.42 318.529,1329.42 318.538,1329.42 318.547,1329.42 318.556,1329.42 318.565,1329.42 318.575,1329.42 318.584,1329.42 318.593,1329.42 318.602,1329.42 318.611,1329.42 318.621,1329.42 318.63,1329.42 318.639,1329.42 318.648,1329.42 318.657,1329.42 318.666,1329.43 318.676,1329.43 318.685,1329.43 318.694,1329.43 318.703,1329.43 318.712,1329.43 318.722,1329.43 318.731,1329.43 318.74,1329.43 318.749,1329.43 318.758,1329.43 318.768,1329.43 318.777,1329.43 318.786,1329.43 318.795,1329.43 318.804,1329.43 318.813,1329.43 318.823,1329.43 318.832,1329.44 318.841,1329.44 318.85,1329.44 318.859,1329.44 318.869,1329.44 318.878,1329.44 318.887,1329.44 318.896,1329.44 318.905,1329.44 318.915,1329.44 318.924,1329.44 318.933,1329.44 318.942,1329.44 318.951,1329.44 318.961,1329.44 318.97,1329.44 318.979,1329.44 318.988,1329.45 318.997,1329.45 319.006,1329.45 319.016,1329.45 319.025,1329.45 319.034,1329.45 319.043,1329.45 319.052,1329.45 319.062,1329.45 319.071,1329.45 319.08,1329.45 319.089,1329.45 319.098,1329.45 319.108,1329.45 319.117,1329.45 319.126,1329.45 319.135,1329.45 319.144,1329.46 319.153,1329.46 319.163,1329.46 319.172,1329.46 319.181,1329.46 319.19,1329.46 319.199,1329.46 319.209,1329.46 319.218,1329.46 319.227,1329.46 319.236,1329.46 319.245,1329.46 319.255,1329.46 319.264,1329.46 319.273,1329.46 319.282,1329.46 319.291,1329.46 319.301,1329.46 319.31,1329.47 319.319,1329.47 319.328,1329.47 319.337,1329.47 319.346,1329.47 319.356,1329.47 319.365,1329.47 319.374,1329.47 319.383,1329.47 319.392,1329.47 319.402,1329.47 319.411,1329.47 319.42,1329.47 319.429,1329.47 319.438,1329.47 319.448,1329.47 319.457,1329.47 319.466,1329.48 319.475,1329.48 319.484,1329.48 319.494,1329.48 319.503,1329.48 319.512,1329.48 319.521,1329.48 319.53,1329.48 319.539,1329.48 319.549,1329.48 319.558,1329.48 319.567,1329.48 319.576,1329.48 319.585,1329.48 319.595,1329.48 319.604,1329.48 319.613,1329.48 319.622,1329.49 319.631,1329.49 319.641,1329.49 319.65,1329.49 319.659,1329.49 319.668,1329.49 319.677,1329.49 319.686,1329.49 319.696,1329.49 319.705,1329.49 319.714,1329.49 319.723,1329.49 319.732,1329.49 319.742,1329.49 319.751,1329.49 319.76,1329.49 319.769,1329.49 319.778,1329.5 319.788,1329.5 319.797,1329.5 319.806,1329.5 319.815,1329.5 319.824,1329.5 319.834,1329.5 319.843,1329.5 319.852,1329.5 319.861,1329.5 319.87,1329.5 319.879,1329.5 319.889,1329.5 319.898,1329.5 319.907,1329.5 319.916,1329.5 319.925,1329.5 319.935,1329.5 319.944,1329.51 319.953,1329.51 319.962,1329.51 319.971,1329.51 319.981,1329.51 319.99,1329.51 319.999,1329.51 320.008,1329.51 320.017,1329.51 320.026,1329.51 320.036,1329.51 320.045,1329.51 320.054,1329.51 320.063,1329.51 320.072,1329.51 320.082,1329.51 320.091,1329.51 320.1,1329.52 320.109,1329.52 320.118,1329.52 320.128,1329.52 320.137,1329.52 320.146,1329.52 320.155,1329.52 320.164,1329.52 320.174,1329.52 320.183,1329.52 320.192,1329.52 320.201,1329.52 320.21,1329.52 320.219,1329.52 320.229,1329.52 320.238,1329.52 320.247,1329.52 320.256,1329.53 320.265,1329.53 320.275,1329.53 320.284,1329.53 320.293,1329.53 320.302,1329.53 320.311,1329.53 320.321,1329.53 320.33,1329.53 320.339,1329.53 320.348,1329.53 320.357,1329.53 320.366,1329.53 320.376,1329.53 320.385,1329.53 320.394,1329.53 320.403,1329.53 320.412,1329.53 320.422,1329.54 320.431,1329.54 320.44,1329.54 320.449,1329.54 320.458,1329.54 320.468,1329.54 320.477,1329.54 320.486,1329.54 320.495,1329.54 320.504,1329.54 320.514,1329.54 320.523,1329.54 320.532,1329.54 320.541,1329.54 320.55,1329.54 320.559,1329.54 320.569,1329.54 320.578,1329.55 320.587,1329.55 320.596,1329.55 320.605,1329.55 320.615,1329.55 320.624,1329.55 320.633,1329.55 320.642,1329.55 320.651,1329.55 320.661,1329.55 320.67,1329.55 320.679,1329.55 320.688,1329.55 320.697,1329.55 320.706,1329.55 320.716,1329.55 320.725,1329.55 320.734,1329.56 320.743,1329.56 320.752,1329.56 320.762,1329.56 320.771,1329.56 320.78,1329.56 320.789,1329.56 320.798,1329.56 320.808,1329.56 320.817,1329.56 320.826,1329.56 320.835,1329.56 320.844,1329.56 320.854,1329.56 320.863,1329.56 320.872,1329.56 320.881,1329.56 320.89,1329.56 320.899,1329.57 320.909,1329.57 320.918,1329.57 320.927,1329.57 320.936,1329.57 320.945,1329.57 320.955,1329.57 320.964,1329.57 320.973,1329.57 320.982,1329.57 320.991,1329.57 321.001,1329.57 321.01,1329.57 321.019,1329.57 321.028,1329.57 321.037,1329.57 321.046,1329.57 321.056,1329.58 321.065,1329.58 321.074,1329.58 321.083,1329.58 321.092,1329.58 321.102,1329.58 321.111,1329.58 321.12,1329.58 321.129,1329.58 321.138,1329.58 321.148,1329.58 321.157,1329.58 321.166,1329.58 321.175,1329.58 321.184,1329.58 321.194,1329.58 321.203,1329.58 321.212,1329.59 321.221,1329.59 321.23,1329.59 321.239,1329.59 321.249,1329.59 321.258,1329.59 321.267,1329.59 321.276,1329.59 321.285,1329.59 321.295,1329.59 321.304,1329.59 321.313,1329.59 321.322,1329.59 321.331,1329.59 321.341,1329.59 321.35,1329.59 321.359,1329.59 321.368,1329.6 321.377,1329.6 321.386,1329.6 321.396,1329.6 321.405,1329.6 321.414,1329.6 321.423,1329.6 321.432,1329.6 321.442,1329.6 321.451,1329.6 321.46,1329.6 321.469,1329.6 321.478,1329.6 321.488,1329.6 321.497,1329.6 321.506,1329.6 321.515,1329.6 321.524,1329.6 321.534,1329.61 321.543,1329.61 321.552,1329.61 321.561,1329.61 321.57,1329.61 321.579,1329.61 321.589,1329.61 321.598,1329.61 321.607,1329.61 321.616,1329.61 321.625,1329.61 321.635,1329.61 321.644,1329.61 321.653,1329.61 321.662,1329.61 321.671,1329.61 321.681,1329.61 321.69,1329.62 321.699,1329.62 321.708,1329.62 321.717,1329.62 321.727,1329.62 321.736,1329.62 321.745,1329.62 321.754,1329.62 321.763,1329.62 321.772,1329.62 321.782,1329.62 321.791,1329.62 321.8,1329.62 321.809,1329.62 321.818,1329.62 321.828,1329.62 321.837,1329.62 321.846,1329.63 321.855,1329.63 321.864,1329.63 321.874,1329.63 321.883,1329.63 321.892,1329.63 321.901,1329.63 321.91,1329.63 321.919,1329.63 321.929,1329.63 321.938,1329.63 321.947,1329.63 321.956,1329.63 321.965,1329.63 321.975,1329.63 321.984,1329.63 321.993,1329.63 322.002,1329.63 322.011,1329.64 322.021,1329.64 322.03,1329.64 322.039,1329.64 322.048,1329.64 322.057,1329.64 322.067,1329.64 322.076,1329.64 322.085,1329.64 322.094,1329.64 322.103,1329.64 322.112,1329.64 322.122,1329.64 322.131,1329.64 322.14,1329.64 322.149,1329.64 322.158,1329.64 322.168,1329.65 322.177,1329.65 322.186,1329.65 322.195,1329.65 322.204,1329.65 322.214,1329.65 322.223,1329.65 322.232,1329.65 322.241,1329.65 322.25,1329.65 322.259,1329.65 322.269,1329.65 322.278,1329.65 322.287,1329.65 322.296,1329.65 322.305,1329.65 322.315,1329.65 322.324,1329.66 322.333,1329.66 322.342,1329.66 322.351,1329.66 322.361,1329.66 322.37,1329.66 322.379,1329.66 322.388,1329.66 322.397,1329.66 322.407,1329.66 322.416,1329.66 322.425,1329.66 322.434,1329.66 322.443,1329.66 322.452,1329.66 322.462,1329.66 322.471,1329.66 322.48,1329.66 322.489,1329.67 322.498,1329.67 322.508,1329.67 322.517,1329.67 322.526,1329.67 322.535,1329.67 322.544,1329.67 322.554,1329.67 322.563,1329.67 322.572,1329.67 322.581,1329.67 322.59,1329.67 322.599,1329.67 322.609,1329.67 322.618,1329.67 322.627,1329.67 322.636,1329.67 322.645,1329.68 322.655,1329.68 322.664,1329.68 322.673,1329.68 322.682,1329.68 322.691,1329.68 322.701,1329.68 322.71,1329.68 322.719,1329.68 322.728,1329.68 322.737,1329.68 322.747,1329.68 322.756,1329.68 322.765,1329.68 322.774,1329.68 322.783,1329.68 322.792,1329.68 322.802,1329.69 322.811,1329.69 322.82,1329.69 322.829,1329.69 322.838,1329.69 322.848,1329.69 322.857,1329.69 322.866,1329.69 322.875,1329.69 322.884,1329.69 322.894,1329.69 322.903,1329.69 322.912,1329.69 322.921,1329.69 322.93,1329.69 322.939,1329.69 322.949,1329.69 322.958,1329.69 322.967,1329.7 322.976,1329.7 322.985,1329.7 322.995,1329.7 323.004,1329.7 323.013,1329.7 323.022,1329.7 323.031,1329.7 323.041,1329.7 323.05,1329.7 323.059,1329.7 323.068,1329.7 323.077,1329.7 323.087,1329.7 323.096,1329.7 323.105,1329.7 323.114,1329.7 323.123,1329.71 323.132,1329.71 323.142,1329.71 323.151,1329.71 323.16,1329.71 323.169,1329.71 323.178,1329.71 323.188,1329.71 323.197,1329.71 323.206,1329.71 323.215,1329.71 323.224,1329.71 323.234,1329.71 323.243,1329.71 323.252,1329.71 323.261,1329.71 323.27,1329.71 323.279,1329.72 323.289,1329.72 323.298,1329.72 323.307,1329.72 323.316,1329.72 323.325,1329.72 323.335,1329.72 323.344,1329.72 323.353,1329.72 323.362,1329.72 323.371,1329.72 323.381,1329.72 323.39,1329.72 323.399,1329.72 323.408,1329.72 323.417,1329.72 323.427,1329.72 323.436,1329.72 323.445,1329.73 323.454,1329.73 323.463,1329.73 323.472,1329.73 323.482,1329.73 323.491,1329.73 323.5,1329.73 323.509,1329.73 323.518,1329.73 323.528,1329.73 323.537,1329.73 323.546,1329.73 323.555,1329.73 323.564,1329.73 323.574,1329.73 323.583,1329.73 323.592,1329.73 323.601,1329.74 323.61,1329.74 323.619,1329.74 323.629,1329.74 323.638,1329.74 323.647,1329.74 323.656,1329.74 323.665,1329.74 323.675,1329.74 323.684,1329.74 323.693,1329.74 323.702,1329.74 323.711,1329.74 323.721,1329.74 323.73,1329.74 323.739,1329.74 323.748,1329.74 323.757,1329.75 323.767,1329.75 323.776,1329.75 323.785,1329.75 323.794,1329.75 323.803,1329.75 323.812,1329.75 323.822,1329.75 323.831,1329.75 323.84,1329.75 323.849,1329.75 323.858,1329.75 323.868,1329.75 323.877,1329.75 323.886,1329.75 323.895,1329.75 323.904,1329.75 323.914,1329.75 323.923,1329.76 323.932,1329.76 323.941,1329.76 323.95,1329.76 323.959,1329.76 323.969,1329.76 323.978,1329.76 323.987,1329.76 323.996,1329.76 324.005,1329.76 324.015,1329.76 324.024,1329.76 324.033,1329.76 324.042,1329.76 324.051,1329.76 324.061,1329.76 324.07,1329.76 324.079,1329.77 324.088,1329.77 324.097,1329.77 324.107,1329.77 324.116,1329.77 324.125,1329.77 324.134,1329.77 324.143,1329.77 324.152,1329.77 324.162,1329.77 324.171,1329.77 324.18,1329.77 324.189,1329.77 324.198,1329.77 324.208,1329.77 324.217,1329.77 324.226,1329.77 324.235,1329.78 324.244,1329.78 324.254,1329.78 324.263,1329.78 324.272,1329.78 324.281,1329.78 324.29,1329.78 324.3,1329.78 324.309,1329.78 324.318,1329.78 324.327,1329.78 324.336,1329.78 324.345,1329.78 324.355,1329.78 324.364,1329.78 324.373,1329.78 324.382,1329.78 324.391,1329.78 324.401,1329.79 324.41,1329.79 324.419,1329.79 324.428,1329.79 324.437,1329.79 324.447,1329.79 324.456,1329.79 324.465,1329.79 324.474,1329.79 324.483,1329.79 324.492,1329.79 324.502,1329.79 324.511,1329.79 324.52,1329.79 324.529,1329.79 324.538,1329.79 324.548,1329.79 324.557,1329.8 324.566,1329.8 324.575,1329.8 324.584,1329.8 324.594,1329.8 324.603,1329.8 324.612,1329.8 324.621,1329.8 324.63,1329.8 324.64,1329.8 324.649,1329.8 324.658,1329.8 324.667,1329.8 324.676,1329.8 324.685,1329.8 324.695,1329.8 324.704,1329.8 324.713,1329.8 324.722,1329.81 324.731,1329.81 324.741,1329.81 324.75,1329.81 324.759,1329.81 324.768,1329.81 324.777,1329.81 324.787,1329.81 324.796,1329.81 324.805,1329.81 324.814,1329.81 324.823,1329.81 324.832,1329.81 324.842,1329.81 324.851,1329.81 324.86,1329.81 324.869,1329.81 324.878,1329.82 324.888,1329.82 324.897,1329.82 324.906,1329.82 324.915,1329.82 324.924,1329.82 324.934,1329.82 324.943,1329.82 324.952,1329.82 324.961,1329.82 324.97,1329.82 324.98,1329.82 324.989,1329.82 324.998,1329.82 325.007,1329.82 325.016,1329.82 325.025,1329.82 325.035,1329.83 325.044,1329.83 325.053,1329.83 325.062,1329.83 325.071,1329.83 325.081,1329.83 325.09,1329.83 325.099,1329.83 325.108,1329.83 325.117,1329.83 325.127,1329.83 325.136,1329.83 325.145,1329.83 325.154,1329.83 325.163,1329.83 325.172,1329.83 325.182,1329.83 325.191,1329.83 325.2,1329.84 325.209,1329.84 325.218,1329.84 325.228,1329.84 325.237,1329.84 325.246,1329.84 325.255,1329.84 325.264,1329.84 325.274,1329.84 325.283,1329.84 325.292,1329.84 325.301,1329.84 325.31,1329.84 325.32,1329.84 325.329,1329.84 325.338,1329.84 325.347,1329.84 325.356,1329.85 325.365,1329.85 325.375,1329.85 325.384,1329.85 325.393,1329.85 325.402,1329.85 325.411,1329.85 325.421,1329.85 325.43,1329.85 325.439,1329.85 325.448,1329.85 325.457,1329.85 325.467,1329.85 325.476,1329.85 325.485,1329.85 325.494,1329.85 325.503,1329.85 325.512,1329.86 325.522,1329.86 325.531,1329.86 325.54,1329.86 325.549,1329.86 325.558,1329.86 325.568,1329.86 325.577,1329.86 325.586,1329.86 325.595,1329.86 325.604,1329.86 325.614,1329.86 325.623,1329.86 325.632,1329.86 325.641,1329.86 325.65,1329.86 325.66,1329.86 325.669,1329.86 325.678,1329.87 325.687,1329.87 325.696,1329.87 325.705,1329.87 325.715,1329.87 325.724,1329.87 325.733,1329.87 325.742,1329.87 325.751,1329.87 325.761,1329.87 325.77,1329.87 325.779,1329.87 325.788,1329.87 325.797,1329.87 325.807,1329.87 325.816,1329.87 325.825,1329.87 325.834,1329.88 325.843,1329.88 325.852,1329.88 325.862,1329.88 325.871,1329.88 325.88,1329.88 325.889,1329.88 325.898,1329.88 325.908,1329.88 325.917,1329.88 325.926,1329.88 325.935,1329.88 325.944,1329.88 325.954,1329.88 325.963,1329.88 325.972,1329.88 325.981,1329.88 325.99,1329.88 326,1329.89 326.009,1329.89 326.018,1329.89 326.027,1329.89 326.036,1329.89 326.045,1329.89 326.055,1329.89 326.064,1329.89 326.073,1329.89 326.082,1329.89 326.091,1329.89 326.101,1329.89 326.11,1329.89 326.119,1329.89 326.128,1329.89 326.137,1329.89 326.147,1329.89 326.156,1329.9 326.165,1329.9 326.174,1329.9 326.183,1329.9 326.192,1329.9 326.202,1329.9 326.211,1329.9 326.22,1329.9 326.229,1329.9 326.238,1329.9 326.248,1329.9 326.257,1329.9 326.266,1329.9 326.275,1329.9 326.284,1329.9 326.294,1329.9 326.303,1329.9 326.312,1329.91 326.321,1329.91 326.33,1329.91 326.34,1329.91 326.349,1329.91 326.358,1329.91 326.367,1329.91 326.376,1329.91 326.385,1329.91 326.395,1329.91 326.404,1329.91 326.413,1329.91 326.422,1329.91 326.431,1329.91 326.441,1329.91 326.45,1329.91 326.459,1329.91 326.468,1329.91 326.477,1329.92 326.487,1329.92 326.496,1329.92 326.505,1329.92 326.514,1329.92 326.523,1329.92 326.532,1329.92 326.542,1329.92 326.551,1329.92 326.56,1329.92 326.569,1329.92 326.578,1329.92 326.588,1329.92 326.597,1329.92 326.606,1329.92 326.615,1329.92 326.624,1329.92 326.634,1329.93 326.643,1329.93 326.652,1329.93 326.661,1329.93 326.67,1329.93 326.68,1329.93 326.689,1329.93 326.698,1329.93 326.707,1329.93 326.716,1329.93 326.725,1329.93 326.735,1329.93 326.744,1329.93 326.753,1329.93 326.762,1329.93 326.771,1329.93 326.781,1329.93 326.79,1329.94 326.799,1329.94 326.808,1329.94 326.817,1329.94 326.827,1329.94 326.836,1329.94 326.845,1329.94 326.854,1329.94 326.863,1329.94 326.873,1329.94 326.882,1329.94 326.891,1329.94 326.9,1329.94 326.909,1329.94 326.918,1329.94 326.928,1329.94 326.937,1329.94 326.946,1329.94 326.955,1329.95 326.964,1329.95 326.974,1329.95 326.983,1329.95 326.992,1329.95 327.001,1329.95 327.01,1329.95 327.02,1329.95 327.029,1329.95 327.038,1329.95 327.047,1329.95 327.056,1329.95 327.065,1329.95 327.075,1329.95 327.084,1329.95 327.093,1329.95 327.102,1329.95 327.111,1329.96 327.121,1329.96 327.13,1329.96 327.139,1329.96 327.148,1329.96 327.157,1329.96 327.167,1329.96 327.176,1329.96 327.185,1329.96 327.194,1329.96 327.203,1329.96 327.213,1329.96 327.222,1329.96 327.231,1329.96 327.24,1329.96 327.249,1329.96 327.258,1329.96 327.268,1329.96 327.277,1329.97 327.286,1329.97 327.295,1329.97 327.304,1329.97 327.314,1329.97 327.323,1329.97 327.332,1329.97 327.341,1329.97 327.35,1329.97 327.36,1329.97 327.369,1329.97 327.378,1329.97 327.387,1329.97 327.396,1329.97 327.405,1329.97 327.415,1329.97 327.424,1329.97 327.433,1329.98 327.442,1329.98 327.451,1329.98 327.461,1329.98 327.47,1329.98 327.479,1329.98 327.488,1329.98 327.497,1329.98 327.507,1329.98 327.516,1329.98 327.525,1329.98 327.534,1329.98 327.543,1329.98 327.553,1329.98 327.562,1329.98 327.571,1329.98 327.58,1329.98 327.589,1329.99 327.598,1329.99 327.608,1329.99 327.617,1329.99 327.626,1329.99 327.635,1329.99 327.644,1329.99 327.654,1329.99 327.663,1329.99 327.672,1329.99 327.681,1329.99 327.69,1329.99 327.7,1329.99 327.709,1329.99 327.718,1329.99 327.727,1329.99 327.736,1329.99 327.745,1329.99 327.755,1330 327.764,1330 327.773,1330 327.782,1330 327.791,1330 327.801,1330 327.81,1330 327.819,1330 327.828,1330 327.837,1330 327.847,1330 327.856,1330 327.865,1330 327.874,1330 327.883,1330 327.893,1330 327.902,1330 327.911,1330.01 327.92,1330.01 327.929,1330.01 327.938,1330.01 327.948,1330.01 327.957,1330.01 327.966,1330.01 327.975,1330.01 327.984,1330.01 327.994,1330.01 328.003,1330.01 328.012,1330.01 328.021,1330.01 328.03,1330.01 328.04,1330.01 328.049,1330.01 328.058,1330.01 328.067,1330.01 328.076,1330.02 328.085,1330.02 328.095,1330.02 328.104,1330.02 328.113,1330.02 328.122,1330.02 328.131,1330.02 328.141,1330.02 328.15,1330.02 328.159,1330.02 328.168,1330.02 328.177,1330.02 328.187,1330.02 328.196,1330.02 328.205,1330.02 328.214,1330.02 328.223,1330.02 328.233,1330.03 328.242,1330.03 328.251,1330.03 328.26,1330.03 328.269,1330.03 328.278,1330.03 328.288,1330.03 328.297,1330.03 328.306,1330.03 328.315,1330.03 328.324,1330.03 328.334,1330.03 328.343,1330.03 328.352,1330.03 328.361,1330.03 328.37,1330.03 328.38,1330.03 328.389,1330.04 328.398,1330.04 328.407,1330.04 328.416,1330.04 328.425,1330.04 328.435,1330.04 328.444,1330.04 328.453,1330.04 328.462,1330.04 328.471,1330.04 328.481,1330.04 328.49,1330.04 328.499,1330.04 328.508,1330.04 328.517,1330.04 328.527,1330.04 328.536,1330.04 328.545,1330.04 328.554,1330.05 328.563,1330.05 328.573,1330.05 328.582,1330.05 328.591,1330.05 328.6,1330.05 328.609,1330.05 328.618,1330.05 328.628,1330.05 328.637,1330.05 328.646,1330.05 328.655,1330.05 328.664,1330.05 328.674,1330.05 328.683,1330.05 328.692,1330.05 328.701,1330.05 328.71,1330.06 328.72,1330.06 328.729,1330.06 328.738,1330.06 328.747,1330.06 328.756,1330.06 328.765,1330.06 328.775,1330.06 328.784,1330.06 328.793,1330.06 328.802,1330.06 328.811,1330.06 328.821,1330.06 328.83,1330.06 328.839,1330.06 328.848,1330.06 328.857,1330.06 328.867,1330.06 328.876,1330.07 328.885,1330.07 328.894,1330.07 328.903,1330.07 328.913,1330.07 328.922,1330.07 328.931,1330.07 328.94,1330.07 328.949,1330.07 328.958,1330.07 328.968,1330.07 328.977,1330.07 328.986,1330.07 328.995,1330.07 329.004,1330.07 329.014,1330.07 329.023,1330.07 329.032,1330.08 329.041,1330.08 329.05,1330.08 329.06,1330.08 329.069,1330.08 329.078,1330.08 329.087,1330.08 329.096,1330.08 329.106,1330.08 329.115,1330.08 329.124,1330.08 329.133,1330.08 329.142,1330.08 329.151,1330.08 329.161,1330.08 329.17,1330.08 329.179,1330.08 329.188,1330.08 329.197,1330.09 329.207,1330.09 329.216,1330.09 329.225,1330.09 329.234,1330.09 329.243,1330.09 329.253,1330.09 329.262,1330.09 329.271,1330.09 329.28,1330.09 329.289,1330.09 329.298,1330.09 329.308,1330.09 329.317,1330.09 329.326,1330.09 329.335,1330.09 329.344,1330.09 329.354,1330.1 329.363,1330.1 329.372,1330.1 329.381,1330.1 329.39,1330.1 329.4,1330.1 329.409,1330.1 329.418,1330.1 329.427,1330.1 329.436,1330.1 329.446,1330.1 329.455,1330.1 329.464,1330.1 329.473,1330.1 329.482,1330.1 329.491,1330.1 329.501,1330.1 329.51,1330.11 329.519,1330.11 329.528,1330.11 329.537,1330.11 329.547,1330.11 329.556,1330.11 329.565,1330.11 329.574,1330.11 329.583,1330.11 329.593,1330.11 329.602,1330.11 329.611,1330.11 329.62,1330.11 329.629,1330.11 329.638,1330.11 329.648,1330.11 329.657,1330.11 329.666,1330.11 329.675,1330.12 329.684,1330.12 329.694,1330.12 329.703,1330.12 329.712,1330.12 329.721,1330.12 329.73,1330.12 329.74,1330.12 329.749,1330.12 329.758,1330.12 329.767,1330.12 329.776,1330.12 329.786,1330.12 329.795,1330.12 329.804,1330.12 329.813,1330.12 329.822,1330.12 329.831,1330.13 329.841,1330.13 329.85,1330.13 329.859,1330.13 329.868,1330.13 329.877,1330.13 329.887,1330.13 329.896,1330.13 329.905,1330.13 329.914,1330.13 329.923,1330.13 329.933,1330.13 329.942,1330.13 329.951,1330.13 329.96,1330.13 329.969,1330.13 329.978,1330.13 329.988,1330.13 329.997,1330.14 330.006,1330.14 330.015,1330.14 330.024,1330.14 330.034,1330.14 330.043,1330.14 330.052,1330.14 330.061,1330.14 330.07,1330.14 330.08,1330.14 330.089,1330.14 330.098,1330.14 330.107,1330.14 330.116,1330.14 330.126,1330.14 330.135,1330.14 330.144,1330.14 330.153,1330.15 330.162,1330.15 330.171,1330.15 330.181,1330.15 330.19,1330.15 330.199,1330.15 330.208,1330.15 330.217,1330.15 330.227,1330.15 330.236,1330.15 330.245,1330.15 330.254,1330.15 330.263,1330.15 330.273,1330.15 330.282,1330.15 330.291,1330.15 330.3,1330.15 330.309,1330.15 330.318,1330.16 330.328,1330.16 330.337,1330.16 330.346,1330.16 330.355,1330.16 330.364,1330.16 330.374,1330.16 330.383,1330.16 330.392,1330.16 330.401,1330.16 330.41,1330.16 330.42,1330.16 330.429,1330.16 330.438,1330.16 330.447,1330.16 330.456,1330.16 330.466,1330.16 330.475,1330.17 330.484,1330.17 330.493,1330.17 330.502,1330.17 330.511,1330.17 330.521,1330.17 330.53,1330.17 330.539,1330.17 330.548,1330.17 330.557,1330.17 330.567,1330.17 330.576,1330.17 330.585,1330.17 330.594,1330.17 330.603,1330.17 330.613,1330.17 330.622,1330.17 330.631,1330.18 330.64,1330.18 330.649,1330.18 330.658,1330.18 330.668,1330.18 330.677,1330.18 330.686,1330.18 330.695,1330.18 330.704,1330.18 330.714,1330.18 330.723,1330.18 330.732,1330.18 330.741,1330.18 330.75,1330.18 330.76,1330.18 330.769,1330.18 330.778,1330.18 330.787,1330.18 330.796,1330.19 330.806,1330.19 330.815,1330.19 330.824,1330.19 330.833,1330.19 330.842,1330.19 330.851,1330.19 330.861,1330.19 330.87,1330.19 330.879,1330.19 330.888,1330.19 330.897,1330.19 330.907,1330.19 330.916,1330.19 330.925,1330.19 330.934,1330.19 330.943,1330.19 330.953,1330.2 330.962,1330.2 330.971,1330.2 330.98,1330.2 330.989,1330.2 330.998,1330.2 331.008,1330.2 331.017,1330.2 331.026,1330.2 331.035,1330.2 331.044,1330.2 331.054,1330.2 331.063,1330.2 331.072,1330.2 331.081,1330.2 331.09,1330.2 331.1,1330.2 331.109,1330.2 331.118,1330.21 331.127,1330.21 331.136,1330.21 331.146,1330.21 331.155,1330.21 331.164,1330.21 331.173,1330.21 331.182,1330.21 331.191,1330.21 331.201,1330.21 331.21,1330.21 331.219,1330.21 331.228,1330.21 331.237,1330.21 331.247,1330.21 331.256,1330.21 331.265,1330.21 331.274,1330.21 331.283,1330.21 331.293,1330.21 331.302,1330.22 331.311,1330.22 331.32,1330.22 331.329,1330.22 331.338,1330.22 331.348,1330.22 331.357,1330.22 331.366,1330.22 331.375,1330.22 331.384,1330.22 331.394,1330.22 331.403,1330.22 331.412,1330.22 331.421,1330.22 331.43,1330.22 331.44,1330.22 331.449,1330.22 331.458,1330.22 331.467,1330.22 331.476,1330.22 331.486,1330.23 331.495,1330.23 331.504,1330.23 331.513,1330.23 331.522,1330.23 331.531,1330.23 331.541,1330.23 331.55,1330.23 331.559,1330.23 331.568,1330.23 331.577,1330.23 331.587,1330.23 331.596,1330.23 331.605,1330.23 331.614,1330.23 331.623,1330.23 331.633,1330.23 331.642,1330.23 331.651,1330.23 331.66,1330.23 331.669,1330.23 331.679,1330.23 331.688,1330.23 331.697,1330.24 331.706,1330.24 331.715,1330.24 331.724,1330.24 331.734,1330.24 331.743,1330.24 331.752,1330.24 331.761,1330.24 331.77,1330.24 331.78,1330.24 331.789,1330.24 331.798,1330.24 331.807,1330.24 331.816,1330.24 331.826,1330.24 331.835,1330.24 331.844,1330.24 331.853,1330.24 331.862,1330.24 331.871,1330.24 331.881,1330.24 331.89,1330.24 331.899,1330.24 331.908,1330.24 331.917,1330.24 331.927,1330.25 331.936,1330.25 331.945,1330.25 331.954,1330.25 331.963,1330.25 331.973,1330.25 331.982,1330.25 331.991,1330.25 332,1330.25 332.009,1330.25 332.019,1330.25 332.028,1330.25 332.037,1330.25 332.046,1330.25 332.055,1330.25 332.064,1330.25 332.074,1330.25 332.083,1330.25 332.092,1330.25 332.101,1330.25 332.11,1330.25 332.12,1330.25 332.129,1330.25 332.138,1330.25 332.147,1330.25 332.156,1330.25 332.166,1330.25 332.175,1330.25 332.184,1330.25 332.193,1330.26 332.202,1330.26 332.211,1330.26 332.221,1330.26 332.23,1330.26 332.239,1330.26 332.248,1330.26 332.257,1330.26 332.267,1330.26 332.276,1330.26 332.285,1330.26 332.294,1330.26 332.303,1330.26 332.313,1330.26 332.322,1330.26 332.331,1330.26 332.34,1330.26 332.349,1330.26 332.359,1330.26 332.368,1330.26 332.377,1330.26 332.386,1330.26 332.395,1330.26 332.404,1330.26 332.414,1330.26 332.423,1330.26 332.432,1330.26 332.441,1330.26 332.45,1330.26 332.46,1330.26 332.469,1330.26 332.478,1330.26 332.487,1330.26 332.496,1330.26 332.506,1330.26 332.515,1330.27 332.524,1330.27 332.533,1330.27 332.542,1330.27 332.551,1330.27 332.561,1330.27 332.57,1330.27 332.579,1330.27 332.588,1330.27 332.597,1330.27 332.607,1330.27 332.616,1330.27 332.625,1330.27 332.634,1330.27 332.643,1330.27 332.653,1330.27 332.662,1330.27 332.671,1330.27 332.68,1330.27 332.689,1330.27 332.699,1330.27 332.708,1330.27 332.717,1330.27 332.726,1330.27 332.735,1330.27 332.744,1330.27 332.754,1330.27 332.763,1330.27 332.772,1330.27 332.781,1330.27 332.79,1330.27 332.8,1330.27 332.809,1330.27 332.818,1330.27 332.827,1330.27 332.836,1330.27 332.846,1330.27 332.855,1330.27 332.864,1330.27 332.873,1330.27 332.882,1330.27 332.891,1330.27 332.901,1330.27 332.91,1330.27 332.919,1330.27 332.928,1330.27 332.937,1330.28 332.947,1330.28 332.956,1330.28 332.965,1330.28 332.974,1330.28 332.983,1330.28 332.993,1330.28 333.002,1330.28 333.011,1330.28 333.02,1330.28 333.029,1330.28 333.039,1330.28 333.048,1330.28 333.057,1330.28 333.066,1330.28 333.075,1330.28 333.084,1330.28 333.094,1330.28 333.103,1330.28 333.112,1330.28 333.121,1330.28 333.13,1330.28 333.14,1330.28 333.149,1330.28 333.158,1330.28 333.167,1330.28 333.176,1330.28 333.186,1330.28 333.195,1330.28 333.204,1330.28 333.213,1330.28 333.222,1330.28 333.231,1330.28 333.241,1330.28 333.25,1330.28 333.259,1330.28 333.268,1330.28 333.277,1330.28 333.287,1330.28 333.296,1330.28 333.305,1330.28 333.314,1330.28 333.323,1330.28 333.333,1330.28 333.342,1330.28 333.351,1330.28 333.36,1330.28 333.369,1330.28 333.379,1330.28 333.388,1330.28 333.397,1330.28 333.406,1330.28 333.415,1330.28 333.424,1330.28 333.434,1330.28 333.443,1330.28 333.452,1330.28 333.461,1330.28 333.47,1330.28 333.48,1330.28 333.489,1330.28 333.498,1330.28 333.507,1330.28 333.516,1330.28 333.526,1330.28 333.535,1330.28 333.544,1330.28 333.553,1330.28 333.562,1330.28 333.571,1330.28 333.581,1330.28 333.59,1330.28 333.599,1330.28 333.608,1330.28 333.617,1330.28 333.627,1330.28 333.636,1330.28 333.645,1330.28 333.654,1330.28 333.663,1330.28 333.673,1330.28 333.682,1330.28 333.691,1330.28 333.7,1330.28 333.709,1330.28 333.719,1330.28 333.728,1330.28 333.737,1330.28 333.746,1330.28 333.755,1330.28 333.764,1330.28 333.774,1330.28 333.783,1330.28 333.792,1330.28 333.801,1330.28 333.81,1330.28 333.82,1330.28 333.829,1330.28 333.838,1330.28 333.847,1330.28 333.856,1330.28 333.866,1330.28 333.875,1330.28 333.884,1330.28 333.893,1330.28 333.902,1330.28 333.911,1330.28 333.921,1330.28 333.93,1330.28 333.939,1330.28 333.948,1330.28 333.957,1330.28 333.967,1330.28 333.976,1330.28 333.985,1330.28 333.994,1330.28 334.003,1330.28 334.013,1330.28 334.022,1330.28 334.031,1330.28 334.04,1330.28 334.049,1330.28 334.059,1330.28 334.068,1330.28 334.077,1330.28 334.086,1330.28 334.095,1330.28 334.104,1330.28 334.114,1330.28 334.123,1330.28 334.132,1330.28 334.141,1330.28 334.15,1330.28 334.16,1330.28 334.169,1330.28 334.178,1330.28 334.187,1330.28 334.196,1330.28 334.206,1330.28 334.215,1330.28 334.224,1330.28 334.233,1330.28 334.242,1330.28 334.252,1330.28 334.261,1330.28 334.27,1330.28 334.279,1330.28 334.288,1330.28 334.297,1330.28 334.307,1330.28 334.316,1330.28 334.325,1330.28 334.334,1330.28 334.343,1330.28 334.353,1330.28 334.362,1330.28 334.371,1330.28 334.38,1330.28 334.389,1330.28 334.399,1330.28 334.408,1330.28 334.417,1330.28 334.426,1330.28 334.435,1330.28 334.444,1330.28 334.454,1330.28 334.463,1330.28 334.472,1330.28 334.481,1330.28 334.49,1330.28 334.5,1330.28 334.509,1330.28 334.518,1330.28 334.527,1330.28 334.536,1330.28 334.546,1330.28 334.555,1330.28 334.564,1330.28 334.573,1330.28 334.582,1330.28 334.592,1330.28 334.601,1330.28 334.61,1330.28 334.619,1330.28 334.628,1330.28 334.637,1330.28 334.647,1330.28 334.656,1330.28 334.665,1330.28 334.674,1330.28 334.683,1330.28 334.693,1330.28 334.702,1330.28 334.711,1330.28 334.72,1330.28 334.729,1330.28 334.739,1330.28 334.748,1330.28 334.757,1330.28 334.766,1330.28 334.775,1330.28 334.784,1330.28 334.794,1330.27 334.803,1330.27 334.812,1330.27 334.821,1330.27 334.83,1330.27 334.84,1330.27 334.849,1330.27 334.858,1330.27 334.867,1330.27 334.876,1330.27 334.886,1330.27 334.895,1330.27 334.904,1330.27 334.913,1330.27 334.922,1330.27 334.932,1330.27 334.941,1330.27 334.95,1330.27 334.959,1330.27 334.968,1330.27 334.977,1330.27 334.987,1330.27 334.996,1330.27 335.005,1330.27 335.014,1330.27 335.023,1330.27 335.033,1330.27 335.042,1330.27 335.051,1330.27 335.06,1330.27 335.069,1330.27 335.079,1330.27 335.088,1330.27 335.097,1330.27 335.106,1330.27 335.115,1330.27 335.124,1330.27 335.134,1330.27 335.143,1330.27 335.152,1330.27 335.161,1330.27 335.17,1330.27 335.18,1330.27 335.189,1330.27 335.198,1330.27 335.207,1330.27 335.216,1330.27 335.226,1330.27 335.235,1330.26 335.244,1330.26 335.253,1330.26 335.262,1330.26 335.272,1330.26 335.281,1330.26 335.29,1330.26 335.299,1330.26 335.308,1330.26 335.317,1330.26 335.327,1330.26 335.336,1330.26 335.345,1330.26 335.354,1330.26 335.363,1330.26 335.373,1330.26 335.382,1330.26 335.391,1330.26 335.4,1330.26 335.409,1330.26 335.419,1330.26 335.428,1330.26 335.437,1330.26 335.446,1330.26 335.455,1330.26 335.464,1330.26 335.474,1330.26 335.483,1330.26 335.492,1330.26 335.501,1330.26 335.51,1330.26 335.52,1330.26 335.529,1330.26 335.538,1330.26 335.547,1330.26 335.556,1330.26 335.566,1330.25 335.575,1330.25 335.584,1330.25 335.593,1330.25 335.602,1330.25 335.612,1330.25 335.621,1330.25 335.63,1330.25 335.639,1330.25 335.648,1330.25 335.657,1330.25 335.667,1330.25 335.676,1330.25 335.685,1330.25 335.694,1330.25 335.703,1330.25 335.713,1330.25 335.722,1330.25 335.731,1330.25 335.74,1330.25 335.749,1330.25 335.759,1330.25 335.768,1330.25 335.777,1330.25 335.786,1330.25 335.795,1330.25 335.804,1330.25 335.814,1330.25 335.823,1330.25 335.832,1330.25 335.841,1330.25 335.85,1330.24 335.86,1330.24 335.869,1330.24 335.878,1330.24 335.887,1330.24 335.896,1330.24 335.906,1330.24 335.915,1330.24 335.924,1330.24 335.933,1330.24 335.942,1330.24 335.952,1330.24 335.961,1330.24 335.97,1330.24 335.979,1330.24 335.988,1330.24 335.997,1330.24 336.007,1330.24 336.016,1330.24 336.025,1330.24 336.034,1330.24 336.043,1330.24 336.053,1330.24 336.062,1330.24 336.071,1330.24 336.08,1330.24 336.089,1330.24 336.099,1330.23 336.108,1330.23 336.117,1330.23 336.126,1330.23 336.135,1330.23 336.144,1330.23 336.154,1330.23 336.163,1330.23 336.172,1330.23 336.181,1330.23 336.19,1330.23 336.2,1330.23 336.209,1330.23 336.218,1330.23 336.227,1330.23 336.236,1330.23 336.246,1330.23 336.255,1330.23 336.264,1330.23 336.273,1330.23 336.282,1330.23 336.292,1330.23 336.301,1330.23 336.31,1330.23 336.319,1330.22 336.328,1330.22 336.337,1330.22 336.347,1330.22 336.356,1330.22 336.365,1330.22 336.374,1330.22 336.383,1330.22 336.393,1330.22 336.402,1330.22 336.411,1330.22 336.42,1330.22 336.429,1330.22 336.439,1330.22 336.448,1330.22 336.457,1330.22 336.466,1330.22 336.475,1330.22 336.485,1330.22 336.494,1330.22 336.503,1330.22 336.512,1330.22 336.521,1330.21 336.53,1330.21 336.54,1330.21 336.549,1330.21 336.558,1330.21 336.567,1330.21 336.576,1330.21 336.586,1330.21 336.595,1330.21 336.604,1330.21 336.613,1330.21 336.622,1330.21 336.632,1330.21 336.641,1330.21 336.65,1330.21 336.659,1330.21 336.668,1330.21 336.677,1330.21 336.687,1330.21 336.696,1330.21 336.705,1330.21 336.714,1330.2 336.723,1330.2 336.733,1330.2 336.742,1330.2 336.751,1330.2 336.76,1330.2 336.769,1330.2 336.779,1330.2 336.788,1330.2 336.797,1330.2 336.806,1330.2 336.815,1330.2 336.825,1330.2 336.834,1330.2 336.843,1330.2 336.852,1330.2 336.861,1330.2 336.87,1330.2 336.88,1330.2 336.889,1330.2 336.898,1330.19 336.907,1330.19 336.916,1330.19 336.926,1330.19 336.935,1330.19 336.944,1330.19 336.953,1330.19 336.962,1330.19 336.972,1330.19 336.981,1330.19 336.99,1330.19 336.999,1330.19 337.008,1330.19 337.017,1330.19 337.027,1330.19 337.036,1330.19 337.045,1330.19 337.054,1330.19 337.063,1330.18 337.073,1330.18 337.082,1330.18 337.091,1330.18 337.1,1330.18 337.109,1330.18 337.119,1330.18 337.128,1330.18 337.137,1330.18 337.146,1330.18 337.155,1330.18 337.165,1330.18 337.174,1330.18 337.183,1330.18 337.192,1330.18 337.201,1330.18 337.21,1330.18 337.22,1330.18 337.229,1330.17 337.238,1330.17 337.247,1330.17 337.256,1330.17 337.266,1330.17 337.275,1330.17 337.284,1330.17 337.293,1330.17 337.302,1330.17 337.312,1330.17 337.321,1330.17 337.33,1330.17 337.339,1330.17 337.348,1330.17 337.357,1330.17 337.367,1330.17 337.376,1330.17 337.385,1330.16 337.394,1330.16 337.403,1330.16 337.413,1330.16 337.422,1330.16 337.431,1330.16 337.44,1330.16 337.449,1330.16 337.459,1330.16 337.468,1330.16 337.477,1330.16 337.486,1330.16 337.495,1330.16 337.505,1330.16 337.514,1330.16 337.523,1330.16 337.532,1330.15 337.541,1330.15 337.55,1330.15 337.56,1330.15 337.569,1330.15 337.578,1330.15 337.587,1330.15 337.596,1330.15 337.606,1330.15 337.615,1330.15 337.624,1330.15 337.633,1330.15 337.642,1330.15 337.652,1330.15 337.661,1330.15 337.67,1330.15 337.679,1330.14 337.688,1330.14 337.697,1330.14 337.707,1330.14 337.716,1330.14 337.725,1330.14 337.734,1330.14 337.743,1330.14 337.753,1330.14 337.762,1330.14 337.771,1330.14 337.78,1330.14 337.789,1330.14 337.799,1330.14 337.808,1330.14 337.817,1330.13 337.826,1330.13 337.835,1330.13 337.845,1330.13 337.854,1330.13 337.863,1330.13 337.872,1330.13 337.881,1330.13 337.89,1330.13 337.9,1330.13 337.909,1330.13 337.918,1330.13 337.927,1330.13 337.936,1330.13 337.946,1330.13 337.955,1330.12 337.964,1330.12 337.973,1330.12 337.982,1330.12 337.992,1330.12 338.001,1330.12 338.01,1330.12 338.019,1330.12 338.028,1330.12 338.037,1330.12 338.047,1330.12 338.056,1330.12 338.065,1330.12 338.074,1330.12 338.083,1330.11 338.093,1330.11 338.102,1330.11 338.111,1330.11 338.12,1330.11 338.129,1330.11 338.139,1330.11 338.148,1330.11 338.157,1330.11 338.166,1330.11 338.175,1330.11 338.185,1330.11 338.194,1330.11 338.203,1330.11 338.212,1330.1 338.221,1330.1 338.23,1330.1 338.24,1330.1 338.249,1330.1 338.258,1330.1 338.267,1330.1 338.276,1330.1 338.286,1330.1 338.295,1330.1 338.304,1330.1 338.313,1330.1 338.322,1330.1 338.332,1330.09 338.341,1330.09 338.35,1330.09 338.359,1330.09 338.368,1330.09 338.377,1330.09 338.387,1330.09 338.396,1330.09 338.405,1330.09 338.414,1330.09 338.423,1330.09 338.433,1330.09 338.442,1330.09 338.451,1330.08 338.46,1330.08 338.469,1330.08 338.479,1330.08 338.488,1330.08 338.497,1330.08 338.506,1330.08 338.515,1330.08 338.525,1330.08 338.534,1330.08 338.543,1330.08 338.552,1330.08 338.561,1330.08 338.57,1330.07 338.58,1330.07 338.589,1330.07 338.598,1330.07 338.607,1330.07 338.616,1330.07 338.626,1330.07 338.635,1330.07 338.644,1330.07 338.653,1330.07 338.662,1330.07 338.672,1330.07 338.681,1330.07 338.69,1330.06 338.699,1330.06 338.708,1330.06 338.717,1330.06 338.727,1330.06 338.736,1330.06 338.745,1330.06 338.754,1330.06 338.763,1330.06 338.773,1330.06 338.782,1330.06 338.791,1330.06 338.8,1330.05 338.809,1330.05 338.819,1330.05 338.828,1330.05 338.837,1330.05 338.846,1330.05 338.855,1330.05 338.865,1330.05 338.874,1330.05 338.883,1330.05 338.892,1330.05 338.901,1330.05 338.91,1330.04 338.92,1330.04 338.929,1330.04 338.938,1330.04 338.947,1330.04 338.956,1330.04 338.966,1330.04 338.975,1330.04 338.984,1330.04 338.993,1330.04 339.002,1330.04 339.012,1330.04 339.021,1330.03 339.03,1330.03 339.039,1330.03 339.048,1330.03 339.058,1330.03 339.067,1330.03 339.076,1330.03 339.085,1330.03 339.094,1330.03 339.103,1330.03 339.113,1330.03 339.122,1330.03 339.131,1330.02 339.14,1330.02 339.149,1330.02 339.159,1330.02 339.168,1330.02 339.177,1330.02 339.186,1330.02 339.195,1330.02 339.205,1330.02 339.214,1330.02 339.223,1330.02 339.232,1330.01 339.241,1330.01 339.25,1330.01 339.26,1330.01 339.269,1330.01 339.278,1330.01 339.287,1330.01 339.296,1330.01 339.306,1330.01 339.315,1330.01 339.324,1330.01 339.333,1330 339.342,1330 339.352,1330 339.361,1330 339.37,1330 339.379,1330 339.388,1330 339.398,1330 339.407,1330 339.416,1330 339.425,1330 339.434,1329.99 339.443,1329.99 339.453,1329.99 339.462,1329.99 339.471,1329.99 339.48,1329.99 339.489,1329.99 339.499,1329.99 339.508,1329.99 339.517,1329.99 339.526,1329.99 339.535,1329.98 339.545,1329.98 339.554,1329.98 339.563,1329.98 339.572,1329.98 339.581,1329.98 339.59,1329.98 339.6,1329.98 339.609,1329.98 339.618,1329.98 339.627,1329.98 339.636,1329.97 339.646,1329.97 339.655,1329.97 339.664,1329.97 339.673,1329.97 339.682,1329.97 339.692,1329.97 339.701,1329.97 339.71,1329.97 339.719,1329.97 339.728,1329.96 339.738,1329.96 339.747,1329.96 339.756,1329.96 339.765,1329.96 339.774,1329.96 339.783,1329.96 339.793,1329.96 339.802,1329.96 339.811,1329.96 339.82,1329.96 339.829,1329.95 339.839,1329.95 339.848,1329.95 339.857,1329.95 339.866,1329.95 339.875,1329.95 339.885,1329.95 339.894,1329.95 339.903,1329.95 339.912,1329.95 339.921,1329.94 339.93,1329.94 339.94,1329.94 339.949,1329.94 339.958,1329.94 339.967,1329.94 339.976,1329.94 339.986,1329.94 339.995,1329.94 340.004,1329.94 340.013,1329.93 340.022,1329.93 340.032,1329.93 340.041,1329.93 340.05,1329.93 340.059,1329.93 340.068,1329.93 340.078,1329.93 340.087,1329.93 340.096,1329.93 340.105,1329.92 340.114,1329.92 340.123,1329.92 340.133,1329.92 340.142,1329.92 340.151,1329.92 340.16,1329.92 340.169,1329.92 340.179,1329.92 340.188,1329.92 340.197,1329.91 340.206,1329.91 340.215,1329.91 340.225,1329.91 340.234,1329.91 340.243,1329.91 340.252,1329.91 340.261,1329.91 340.27,1329.91 340.28,1329.91 340.289,1329.9 340.298,1329.9 340.307,1329.9 340.316,1329.9 340.326,1329.9 340.335,1329.9 340.344,1329.9 340.353,1329.9 340.362,1329.9 340.372,1329.89 340.381,1329.89 340.39,1329.89 340.399,1329.89 340.408,1329.89 340.418,1329.89 340.427,1329.89 340.436,1329.89 340.445,1329.89 340.454,1329.89 340.463,1329.88 340.473,1329.88 340.482,1329.88 340.491,1329.88 340.5,1329.88 340.509,1329.88 340.519,1329.88 340.528,1329.88 340.537,1329.88 340.546,1329.87 340.555,1329.87 340.565,1329.87 340.574,1329.87 340.583,1329.87 340.592,1329.87 340.601,1329.87 340.61,1329.87 340.62,1329.87 340.629,1329.87 340.638,1329.86 340.647,1329.86 340.656,1329.86 340.666,1329.86 340.675,1329.86 340.684,1329.86 340.693,1329.86 340.702,1329.86 340.712,1329.86 340.721,1329.85 340.73,1329.85 340.739,1329.85 340.748,1329.85 340.758,1329.85 340.767,1329.85 340.776,1329.85 340.785,1329.85 340.794,1329.85 340.803,1329.84 340.813,1329.84 340.822,1329.84 340.831,1329.84 340.84,1329.84 340.849,1329.84 340.859,1329.84 340.868,1329.84 340.877,1329.84 340.886,1329.83 340.895,1329.83 340.905,1329.83 340.914,1329.83 340.923,1329.83 340.932,1329.83 340.941,1329.83 340.95,1329.83 340.96,1329.83 340.969,1329.82 340.978,1329.82 340.987,1329.82 340.996,1329.82 341.006,1329.82 341.015,1329.82 341.024,1329.82 341.033,1329.82 341.042,1329.82 341.052,1329.81 341.061,1329.81 341.07,1329.81 341.079,1329.81 341.088,1329.81 341.098,1329.81 341.107,1329.81 341.116,1329.81 341.125,1329.8 341.134,1329.8 341.143,1329.8 341.153,1329.8 341.162,1329.8 341.171,1329.8 341.18,1329.8 341.189,1329.8 341.199,1329.8 341.208,1329.79 341.217,1329.79 341.226,1329.79 341.235,1329.79 341.245,1329.79 341.254,1329.79 341.263,1329.79 341.272,1329.79 341.281,1329.79 341.29,1329.78 341.3,1329.78 341.309,1329.78 341.318,1329.78 341.327,1329.78 341.336,1329.78 341.346,1329.78 341.355,1329.78 341.364,1329.77 341.373,1329.77 341.382,1329.77 341.392,1329.77 341.401,1329.77 341.41,1329.77 341.419,1329.77 341.428,1329.77 341.438,1329.77 341.447,1329.76 341.456,1329.76 341.465,1329.76 341.474,1329.76 341.483,1329.76 341.493,1329.76 341.502,1329.76 341.511,1329.76 341.52,1329.75 341.529,1329.75 341.539,1329.75 341.548,1329.75 341.557,1329.75 341.566,1329.75 341.575,1329.75 341.585,1329.75 341.594,1329.74 341.603,1329.74 341.612,1329.74 341.621,1329.74 341.631,1329.74 341.64,1329.74 341.649,1329.74 341.658,1329.74 341.667,1329.74 341.676,1329.73 341.686,1329.73 341.695,1329.73 341.704,1329.73 341.713,1329.73 341.722,1329.73 341.732,1329.73 341.741,1329.73 341.75,1329.72 341.759,1329.72 341.768,1329.72 341.778,1329.72 341.787,1329.72 341.796,1329.72 341.805,1329.72 341.814,1329.72 341.823,1329.71 341.833,1329.71 341.842,1329.71 341.851,1329.71 341.86,1329.71 341.869,1329.71 341.879,1329.71 341.888,1329.71 341.897,1329.7 341.906,1329.7 341.915,1329.7 341.925,1329.7 341.934,1329.7 341.943,1329.7 341.952,1329.7 341.961,1329.7 341.971,1329.69 341.98,1329.69 341.989,1329.69 341.998,1329.69 342.007,1329.69 342.016,1329.69 342.026,1329.69 342.035,1329.69 342.044,1329.68 342.053,1329.68 342.062,1329.68 342.072,1329.68 342.081,1329.68 342.09,1329.68 342.099,1329.68 342.108,1329.68 342.118,1329.67 342.127,1329.67 342.136,1329.67 342.145,1329.67 342.154,1329.67 342.163,1329.67 342.173,1329.67 342.182,1329.67 342.191,1329.66 342.2,1329.66 342.209,1329.66 342.219,1329.66 342.228,1329.66 342.237,1329.66 342.246,1329.66 342.255,1329.65 342.265,1329.65 342.274,1329.65 342.283,1329.65 342.292,1329.65 342.301,1329.65 342.311,1329.65 342.32,1329.65 342.329,1329.64 342.338,1329.64 342.347,1329.64 342.356,1329.64 342.366,1329.64 342.375,1329.64 342.384,1329.64 342.393,1329.64 342.402,1329.63 342.412,1329.63 342.421,1329.63 342.43,1329.63 342.439,1329.63 342.448,1329.63 342.458,1329.63 342.467,1329.62 342.476,1329.62 342.485,1329.62 342.494,1329.62 342.503,1329.62 342.513,1329.62 342.522,1329.62 342.531,1329.62 342.54,1329.61 342.549,1329.61 342.559,1329.61 342.568,1329.61 342.577,1329.61 342.586,1329.61 342.595,1329.61 342.605,1329.6 342.614,1329.6 342.623,1329.6 342.632,1329.6 342.641,1329.6 342.651,1329.6 342.66,1329.6 342.669,1329.6 342.678,1329.59 342.687,1329.59 342.696,1329.59 342.706,1329.59 342.715,1329.59 342.724,1329.59 342.733,1329.59 342.742,1329.58 342.752,1329.58 342.761,1329.58 342.77,1329.58 342.779,1329.58 342.788,1329.58 342.798,1329.58 342.807,1329.58 342.816,1329.57 342.825,1329.57 342.834,1329.57 342.843,1329.57 342.853,1329.57 342.862,1329.57 342.871,1329.57 342.88,1329.56 342.889,1329.56 342.899,1329.56 342.908,1329.56 342.917,1329.56 342.926,1329.56 342.935,1329.56 342.945,1329.55 342.954,1329.55 342.963,1329.55 342.972,1329.55 342.981,1329.55 342.991,1329.55 343,1329.55 343.009,1329.55 343.018,1329.54 343.027,1329.54 343.036,1329.54 343.046,1329.54 343.055,1329.54 343.064,1329.54 343.073,1329.54 343.082,1329.53 343.092,1329.53 343.101,1329.53 343.11,1329.53 343.119,1329.53 343.128,1329.53 343.138,1329.53 343.147,1329.52 343.156,1329.52 343.165,1329.52 343.174,1329.52 343.183,1329.52 343.193,1329.52 343.202,1329.52 343.211,1329.51 343.22,1329.51 343.229,1329.51 343.239,1329.51 343.248,1329.51 343.257,1329.51 343.266,1329.51 343.275,1329.5 343.285,1329.5 343.294,1329.5 343.303,1329.5 343.312,1329.5 343.321,1329.5 343.331,1329.5 343.34,1329.49 343.349,1329.49 343.358,1329.49 343.367,1329.49 343.376,1329.49 343.386,1329.49 343.395,1329.49 343.404,1329.48 343.413,1329.48 343.422,1329.48 343.432,1329.48 343.441,1329.48 343.45,1329.48 343.459,1329.48 343.468,1329.47 343.478,1329.47 343.487,1329.47 343.496,1329.47 343.505,1329.47 343.514,1329.47 343.523,1329.47 343.533,1329.46 343.542,1329.46 343.551,1329.46 343.56,1329.46 343.569,1329.46 343.579,1329.46 343.588,1329.46 343.597,1329.45 343.606,1329.45 343.615,1329.45 343.625,1329.45 343.634,1329.45 343.643,1329.45 343.652,1329.45 343.661,1329.44 343.671,1329.44 343.68,1329.44 343.689,1329.44 343.698,1329.44 343.707,1329.44 343.716,1329.44 343.726,1329.43 343.735,1329.43 343.744,1329.43 343.753,1329.43 343.762,1329.43 343.772,1329.43 343.781,1329.42 343.79,1329.42 343.799,1329.42 343.808,1329.42 343.818,1329.42 343.827,1329.42 343.836,1329.42 343.845,1329.41 343.854,1329.41 343.864,1329.41 343.873,1329.41 343.882,1329.41 343.891,1329.41 343.9,1329.41 343.909,1329.4 343.919,1329.4 343.928,1329.4 343.937,1329.4 343.946,1329.4 343.955,1329.4 343.965,1329.4 343.974,1329.39 343.983,1329.39 343.992,1329.39 344.001,1329.39 344.011,1329.39 344.02,1329.39 344.029,1329.38 344.038,1329.38 344.047,1329.38 344.056,1329.38 344.066,1329.38 344.075,1329.38 344.084,1329.38 344.093,1329.37 344.102,1329.37 344.112,1329.37 344.121,1329.37 344.13,1329.37 344.139,1329.37 344.148,1329.37 344.158,1329.36 344.167,1329.36 344.176,1329.36 344.185,1329.36 344.194,1329.36 344.204,1329.36 344.213,1329.35 344.222,1329.35 344.231,1329.35 344.24,1329.35 344.249,1329.35 344.259,1329.35 344.268,1329.35 344.277,1329.34 344.286,1329.34 344.295,1329.34 344.305,1329.34 344.314,1329.34 344.323,1329.34 344.332,1329.33 344.341,1329.33 344.351,1329.33 344.36,1329.33 344.369,1329.33 344.378,1329.33 344.387,1329.33 344.396,1329.32 344.406,1329.32 344.415,1329.32 344.424,1329.32 344.433,1329.32 344.442,1329.32 344.452,1329.31 344.461,1329.31 344.47,1329.31 344.479,1329.31 344.488,1329.31 344.498,1329.31 344.507,1329.31 344.516,1329.3 344.525,1329.3 344.534,1329.3 344.544,1329.3 344.553,1329.3 344.562,1329.3 344.571,1329.29 344.58,1329.29 344.589,1329.29 344.599,1329.29 344.608,1329.29 344.617,1329.29 344.626,1329.28 344.635,1329.28 344.645,1329.28 344.654,1329.28 344.663,1329.28 344.672,1329.28 344.681,1329.28 344.691,1329.27 344.7,1329.27 344.709,1329.27 344.718,1329.27 344.727,1329.27 344.736,1329.27 344.746,1329.26 344.755,1329.26 344.764,1329.26 344.773,1329.26 344.782,1329.26 344.792,1329.26 344.801,1329.25 344.81,1329.25 344.819,1329.25 344.828,1329.25 344.838,1329.25 344.847,1329.25 344.856,1329.25 344.865,1329.24 344.874,1329.24 344.884,1329.24 344.893,1329.24 344.902,1329.24 344.911,1329.24 344.92,1329.23 344.929,1329.23 344.939,1329.23 344.948,1329.23 344.957,1329.23 344.966,1329.23 344.975,1329.22 344.985,1329.22 344.994,1329.22 345.003,1329.22 345.012,1329.22 345.021,1329.22 345.031,1329.21 345.04,1329.21 345.049,1329.21 345.058,1329.21 345.067,1329.21 345.076,1329.21 345.086,1329.2 345.095,1329.2 345.104,1329.2 345.113,1329.2 345.122,1329.2 345.132,1329.2 345.141,1329.2 345.15,1329.19 345.159,1329.19 345.168,1329.19 345.178,1329.19 345.187,1329.19 345.196,1329.19 345.205,1329.18 345.214,1329.18 345.224,1329.18 345.233,1329.18 345.242,1329.18 345.251,1329.18 345.26,1329.17 345.269,1329.17 345.279,1329.17 345.288,1329.17 345.297,1329.17 345.306,1329.17 345.315,1329.16 345.325,1329.16 345.334,1329.16 345.343,1329.16 345.352,1329.16 345.361,1329.16 345.371,1329.15 345.38,1329.15 345.389,1329.15 345.398,1329.15 345.407,1329.15 345.416,1329.15 345.426,1329.14 345.435,1329.14 345.444,1329.14 345.453,1329.14 345.462,1329.14 345.472,1329.14 345.481,1329.13 345.49,1329.13 345.499,1329.13 345.508,1329.13 345.518,1329.13 345.527,1329.13 345.536,1329.12 345.545,1329.12 345.554,1329.12 345.564,1329.12 345.573,1329.12 345.582,1329.12 345.591,1329.11 345.6,1329.11 345.609,1329.11 345.619,1329.11 345.628,1329.11 345.637,1329.11 345.646,1329.1 345.655,1329.1 345.665,1329.1 345.674,1329.1 345.683,1329.1 345.692,1329.1 345.701,1329.09 345.711,1329.09 345.72,1329.09 345.729,1329.09 345.738,1329.09 345.747,1329.09 345.756,1329.08 345.766,1329.08 345.775,1329.08 345.784,1329.08 345.793,1329.08 345.802,1329.08 345.812,1329.07 345.821,1329.07 345.83,1329.07 345.839,1329.07 345.848,1329.07 345.858,1329.07 345.867,1329.06 345.876,1329.06 345.885,1329.06 345.894,1329.06 345.904,1329.06 345.913,1329.05 345.922,1329.05 345.931,1329.05 345.94,1329.05 345.949,1329.05 345.959,1329.05 345.968,1329.04 345.977,1329.04 345.986,1329.04 345.995,1329.04 346.005,1329.04 346.014,1329.04 346.023,1329.03 346.032,1329.03 346.041,1329.03 346.051,1329.03 346.06,1329.03 346.069,1329.03 346.078,1329.02 346.087,1329.02 346.096,1329.02 346.106,1329.02 346.115,1329.02 346.124,1329.02 346.133,1329.01 346.142,1329.01 346.152,1329.01 346.161,1329.01 346.17,1329.01 346.179,1329 346.188,1329 346.198,1329 346.207,1329 346.216,1329 346.225,1329 346.234,1328.99 346.244,1328.99 346.253,1328.99 346.262,1328.99 346.271,1328.99 346.28,1328.99 346.289,1328.98 346.299,1328.98 346.308,1328.98 346.317,1328.98 346.326,1328.98 346.335,1328.98 346.345,1328.97 346.354,1328.97 346.363,1328.97 346.372,1328.97 346.381,1328.97 346.391,1328.96 346.4,1328.96 346.409,1328.96 346.418,1328.96 346.427,1328.96 346.437,1328.96 346.446,1328.95 346.455,1328.95 346.464,1328.95 346.473,1328.95 346.482,1328.95 346.492,1328.95 346.501,1328.94 346.51,1328.94 346.519,1328.94 346.528,1328.94 346.538,1328.94 346.547,1328.93 346.556,1328.93 346.565,1328.93 346.574,1328.93 346.584,1328.93 346.593,1328.93 346.602,1328.92 346.611,1328.92 346.62,1328.92 346.629,1328.92 346.639,1328.92 346.648,1328.92 346.657,1328.91 346.666,1328.91 346.675,1328.91 346.685,1328.91 346.694,1328.91 346.703,1328.9 346.712,1328.9 346.721,1328.9 346.731,1328.9 346.74,1328.9 346.749,1328.9 346.758,1328.89 346.767,1328.89 346.777,1328.89 346.786,1328.89 346.795,1328.89 346.804,1328.88 346.813,1328.88 346.822,1328.88 346.832,1328.88 346.841,1328.88 346.85,1328.88 346.859,1328.87 346.868,1328.87 346.878,1328.87 346.887,1328.87 346.896,1328.87 346.905,1328.86 346.914,1328.86 346.924,1328.86 346.933,1328.86 346.942,1328.86 346.951,1328.86 346.96,1328.85 346.969,1328.85 346.979,1328.85 346.988,1328.85 346.997,1328.85 347.006,1328.84 347.015,1328.84 347.025,1328.84 347.034,1328.84 347.043,1328.84 347.052,1328.84 347.061,1328.83 347.071,1328.83 347.08,1328.83 347.089,1328.83 347.098,1328.83 347.107,1328.82 347.117,1328.82 347.126,1328.82 347.135,1328.82 347.144,1328.82 347.153,1328.82 347.162,1328.81 347.172,1328.81 347.181,1328.81 347.19,1328.81 347.199,1328.81 347.208,1328.8 347.218,1328.8 347.227,1328.8 347.236,1328.8 347.245,1328.8 347.254,1328.8 347.264,1328.79 347.273,1328.79 347.282,1328.79 347.291,1328.79 347.3,1328.79 347.309,1328.78 347.319,1328.78 347.328,1328.78 347.337,1328.78 347.346,1328.78 347.355,1328.77 347.365,1328.77 347.374,1328.77 347.383,1328.77 347.392,1328.77 347.401,1328.77 347.411,1328.76 347.42,1328.76 347.429,1328.76 347.438,1328.76 347.447,1328.76 347.457,1328.75 347.466,1328.75 347.475,1328.75 347.484,1328.75 347.493,1328.75 347.502,1328.75 347.512,1328.74 347.521,1328.74 347.53,1328.74 347.539,1328.74 347.548,1328.74 347.558,1328.73 347.567,1328.73 347.576,1328.73 347.585,1328.73 347.594,1328.73 347.604,1328.72 347.613,1328.72 347.622,1328.72 347.631,1328.72 347.64,1328.72 347.649,1328.72 347.659,1328.71 347.668,1328.71 347.677,1328.71 347.686,1328.71 347.695,1328.71 347.705,1328.7 347.714,1328.7 347.723,1328.7 347.732,1328.7 347.741,1328.7 347.751,1328.69 347.76,1328.69 347.769,1328.69 347.778,1328.69 347.787,1328.69 347.797,1328.68 347.806,1328.68 347.815,1328.68 347.824,1328.68 347.833,1328.68 347.842,1328.68 347.852,1328.67 347.861,1328.67 347.87,1328.67 347.879,1328.67 347.888,1328.67 347.898,1328.66 347.907,1328.66 347.916,1328.66 347.925,1328.66 347.934,1328.66 347.944,1328.65 347.953,1328.65 347.962,1328.65 347.971,1328.65 347.98,1328.65 347.989,1328.64 347.999,1328.64 348.008,1328.64 348.017,1328.64 348.026,1328.64 348.035,1328.64 348.045,1328.63 348.054,1328.63 348.063,1328.63 348.072,1328.63 348.081,1328.63 348.091,1328.62 348.1,1328.62 348.109,1328.62 348.118,1328.62 348.127,1328.62 348.137,1328.61 348.146,1328.61 348.155,1328.61 348.164,1328.61 348.173,1328.61 348.182,1328.6 348.192,1328.6 348.201,1328.6 348.21,1328.6 348.219,1328.6 348.228,1328.59 348.238,1328.59 348.247,1328.59 348.256,1328.59 348.265,1328.59 348.274,1328.59 348.284,1328.58 348.293,1328.58 348.302,1328.58 348.311,1328.58 348.32,1328.58 348.329,1328.57 348.339,1328.57 348.348,1328.57 348.357,1328.57 348.366,1328.57 348.375,1328.56 348.385,1328.56 348.394,1328.56 348.403,1328.56 348.412,1328.56 348.421,1328.55 348.431,1328.55 348.44,1328.55 348.449,1328.55 348.458,1328.55 348.467,1328.54 348.477,1328.54 348.486,1328.54 348.495,1328.54 348.504,1328.54 348.513,1328.53 348.522,1328.53 348.532,1328.53 348.541,1328.53 348.55,1328.53 348.559,1328.52 348.568,1328.52 348.578,1328.52 348.587,1328.52 348.596,1328.52 348.605,1328.51 348.614,1328.51 348.624,1328.51 348.633,1328.51 348.642,1328.51 348.651,1328.51 348.66,1328.5 348.669,1328.5 348.679,1328.5 348.688,1328.5 348.697,1328.5 348.706,1328.49 348.715,1328.49 348.725,1328.49 348.734,1328.49 348.743,1328.49 348.752,1328.48 348.761,1328.48 348.771,1328.48 348.78,1328.48 348.789,1328.48 348.798,1328.47 348.807,1328.47 348.817,1328.47 348.826,1328.47 348.835,1328.47 348.844,1328.46 348.853,1328.46 348.862,1328.46 348.872,1328.46 348.881,1328.46 348.89,1328.45 348.899,1328.45 348.908,1328.45 348.918,1328.45 348.927,1328.45 348.936,1328.44 348.945,1328.44 348.954,1328.44 348.964,1328.44 348.973,1328.44 348.982,1328.43 348.991,1328.43 349,1328.43 349.01,1328.43 349.019,1328.43 349.028,1328.42 349.037,1328.42 349.046,1328.42 349.055,1328.42 349.065,1328.42 349.074,1328.41 349.083,1328.41 349.092,1328.41 349.101,1328.41 349.111,1328.41 349.12,1328.4 349.129,1328.4 349.138,1328.4 349.147,1328.4 349.157,1328.4 349.166,1328.39 349.175,1328.39 349.184,1328.39 349.193,1328.39 349.202,1328.39 349.212,1328.38 349.221,1328.38 349.23,1328.38 349.239,1328.38 349.248,1328.38 349.258,1328.37 349.267,1328.37 349.276,1328.37 349.285,1328.37 349.294,1328.36 349.304,1328.36 349.313,1328.36 349.322,1328.36 349.331,1328.36 349.34,1328.35 349.35,1328.35 349.359,1328.35 349.368,1328.35 349.377,1328.35 349.386,1328.34 349.395,1328.34 349.405,1328.34 349.414,1328.34 349.423,1328.34 349.432,1328.33 349.441,1328.33 349.451,1328.33 349.46,1328.33 349.469,1328.33 349.478,1328.32 349.487,1328.32 349.497,1328.32 349.506,1328.32 349.515,1328.32 349.524,1328.31 349.533,1328.31 349.542,1328.31 349.552,1328.31 349.561,1328.31 349.57,1328.3 349.579,1328.3 349.588,1328.3 349.598,1328.3 349.607,1328.3 349.616,1328.29 349.625,1328.29 349.634,1328.29 349.644,1328.29 349.653,1328.29 349.662,1328.28 349.671,1328.28 349.68,1328.28 349.69,1328.28 349.699,1328.27 349.708,1328.27 349.717,1328.27 349.726,1328.27 349.735,1328.27 349.745,1328.26 349.754,1328.26 349.763,1328.26 349.772,1328.26 349.781,1328.26 349.791,1328.25 349.8,1328.25 349.809,1328.25 349.818,1328.25 349.827,1328.25 349.837,1328.24 349.846,1328.24 349.855,1328.24 349.864,1328.24 349.873,1328.24 349.882,1328.23 349.892,1328.23 349.901,1328.23 349.91,1328.23 349.919,1328.23 349.928,1328.22 349.938,1328.22 349.947,1328.22 349.956,1328.22 349.965,1328.21 349.974,1328.21 349.984,1328.21 349.993,1328.21 350.002,1328.21 350.011,1328.2 350.02,1328.2 350.03,1328.2 350.039,1328.2 350.048,1328.2 350.057,1328.19 350.066,1328.19 350.075,1328.19 350.085,1328.19 350.094,1328.19 350.103,1328.18 350.112,1328.18 350.121,1328.18 350.131,1328.18 350.14,1328.17 350.149,1328.17 350.158,1328.17 350.167,1328.17 350.177,1328.17 350.186,1328.16 350.195,1328.16 350.204,1328.16 350.213,1328.16 350.222,1328.16 350.232,1328.15 350.241,1328.15 350.25,1328.15 350.259,1328.15 350.268,1328.15 350.278,1328.14 350.287,1328.14 350.296,1328.14 350.305,1328.14 350.314,1328.13 350.324,1328.13 350.333,1328.13 350.342,1328.13 350.351,1328.13 350.36,1328.12 350.37,1328.12 350.379,1328.12 350.388,1328.12 350.397,1328.12 350.406,1328.11 350.415,1328.11 350.425,1328.11 350.434,1328.11 350.443,1328.11 350.452,1328.1 350.461,1328.1 350.471,1328.1 350.48,1328.1 350.489,1328.09 350.498,1328.09 350.507,1328.09 350.517,1328.09 350.526,1328.09 350.535,1328.08 350.544,1328.08 350.553,1328.08 350.562,1328.08 350.572,1328.08 350.581,1328.07 350.59,1328.07 350.599,1328.07 350.608,1328.07 350.618,1328.06 350.627,1328.06 350.636,1328.06 350.645,1328.06 350.654,1328.06 350.664,1328.05 350.673,1328.05 350.682,1328.05 350.691,1328.05 350.7,1328.05 350.71,1328.04 350.719,1328.04 350.728,1328.04 350.737,1328.04 350.746,1328.03 350.755,1328.03 350.765,1328.03 350.774,1328.03 350.783,1328.03 350.792,1328.02 350.801,1328.02 350.811,1328.02 350.82,1328.02 350.829,1328.02 350.838,1328.01 350.847,1328.01 350.857,1328.01 350.866,1328.01 350.875,1328 350.884,1328 350.893,1328 350.902,1328 350.912,1328 350.921,1327.99 350.93,1327.99 350.939,1327.99 350.948,1327.99 350.958,1327.98 350.967,1327.98 350.976,1327.98 350.985,1327.98 350.994,1327.98 351.004,1327.97 351.013,1327.97 351.022,1327.97 351.031,1327.97 351.04,1327.97 351.05,1327.96 351.059,1327.96 351.068,1327.96 351.077,1327.96 351.086,1327.95 351.095,1327.95 351.105,1327.95 351.114,1327.95 351.123,1327.95 351.132,1327.94 351.141,1327.94 351.151,1327.94 351.16,1327.94 351.169,1327.93 351.178,1327.93 351.187,1327.93 351.197,1327.93 351.206,1327.93 351.215,1327.92 351.224,1327.92 351.233,1327.92 351.243,1327.92 351.252,1327.92 351.261,1327.91 351.27,1327.91 351.279,1327.91 351.288,1327.91 351.298,1327.9 351.307,1327.9 351.316,1327.9 351.325,1327.9 351.334,1327.9 351.344,1327.89 351.353,1327.89 351.362,1327.89 351.371,1327.89 351.38,1327.88 351.39,1327.88 351.399,1327.88 351.408,1327.88 351.417,1327.88 351.426,1327.87 351.435,1327.87 351.445,1327.87 351.454,1327.87 351.463,1327.86 351.472,1327.86 351.481,1327.86 351.491,1327.86 351.5,1327.86 351.509,1327.85 351.518,1327.85 351.527,1327.85 351.537,1327.85 351.546,1327.84 351.555,1327.84 351.564,1327.84 351.573,1327.84 351.583,1327.84 351.592,1327.83 351.601,1327.83 351.61,1327.83 351.619,1327.83 351.628,1327.82 351.638,1327.82 351.647,1327.82 351.656,1327.82 351.665,1327.82 351.674,1327.81 351.684,1327.81 351.693,1327.81 351.702,1327.81 351.711,1327.81 351.72,1327.8 351.73,1327.8 351.739,1327.8 351.748,1327.8 351.757,1327.79 351.766,1327.79 351.775,1327.79 351.785,1327.79 351.794,1327.78 351.803,1327.78 351.812,1327.78 351.821,1327.78 351.831,1327.78 351.84,1327.77 351.849,1327.77 351.858,1327.77 351.867,1327.77 351.877,1327.76 351.886,1327.76 351.895,1327.76 351.904,1327.76 351.913,1327.76 351.923,1327.75 351.932,1327.75 351.941,1327.75 351.95,1327.75 351.959,1327.74 351.968,1327.74 351.978,1327.74 351.987,1327.74 351.996,1327.74 352.005,1327.73 352.014,1327.73 352.024,1327.73 352.033,1327.73 352.042,1327.72 352.051,1327.72 352.06,1327.72 352.07,1327.72 352.079,1327.72 352.088,1327.71 352.097,1327.71 352.106,1327.71 352.115,1327.71 352.125,1327.7 352.134,1327.7 352.143,1327.7 352.152,1327.7 352.161,1327.7 352.171,1327.69 352.18,1327.69 352.189,1327.69 352.198,1327.69 352.207,1327.68 352.217,1327.68 352.226,1327.68 352.235,1327.68 352.244,1327.67 352.253,1327.67 352.263,1327.67 352.272,1327.67 352.281,1327.67 352.29,1327.66 352.299,1327.66 352.308,1327.66 352.318,1327.66 352.327,1327.65 352.336,1327.65 352.345,1327.65 352.354,1327.65 352.364,1327.65 352.373,1327.64 352.382,1327.64 352.391,1327.64 352.4,1327.64 352.41,1327.63 352.419,1327.63 352.428,1327.63 352.437,1327.63 352.446,1327.62 352.455,1327.62 352.465,1327.62 352.474,1327.62 352.483,1327.62 352.492,1327.61 352.501,1327.61 352.511,1327.61 352.52,1327.61 352.529,1327.6 352.538,1327.6 352.547,1327.6 352.557,1327.6 352.566,1327.6 352.575,1327.59 352.584,1327.59 352.593,1327.59 352.603,1327.59 352.612,1327.58 352.621,1327.58 352.63,1327.58 352.639,1327.58 352.648,1327.57 352.658,1327.57 352.667,1327.57 352.676,1327.57 352.685,1327.57 352.694,1327.56 352.704,1327.56 352.713,1327.56 352.722,1327.56 352.731,1327.55 352.74,1327.55 352.75,1327.55 352.759,1327.55 352.768,1327.54 352.777,1327.54 352.786,1327.54 352.795,1327.54 352.805,1327.54 352.814,1327.53 352.823,1327.53 352.832,1327.53 352.841,1327.53 352.851,1327.52 352.86,1327.52 352.869,1327.52 352.878,1327.52 352.887,1327.51 352.897,1327.51 352.906,1327.51 352.915,1327.51 352.924,1327.51 352.933,1327.5 352.943,1327.5 352.952,1327.5 352.961,1327.5 352.97,1327.49 352.979,1327.49 352.988,1327.49 352.998,1327.49 353.007,1327.48 353.016,1327.48 353.025,1327.48 353.034,1327.48 353.044,1327.48 353.053,1327.47 353.062,1327.47 353.071,1327.47 353.08,1327.47 353.09,1327.46 353.099,1327.46 353.108,1327.46 353.117,1327.46 353.126,1327.45 353.135,1327.45 353.145,1327.45 353.154,1327.45 353.163,1327.45 353.172,1327.44 353.181,1327.44 353.191,1327.44 353.2,1327.44 353.209,1327.43 353.218,1327.43 353.227,1327.43 353.237,1327.43 353.246,1327.42 353.255,1327.42 353.264,1327.42 353.273,1327.42 353.283,1327.42 353.292,1327.41 353.301,1327.41 353.31,1327.41 353.319,1327.41 353.328,1327.4 353.338,1327.4 353.347,1327.4 353.356,1327.4 353.365,1327.39 353.374,1327.39 353.384,1327.39 353.393,1327.39 353.402,1327.38 353.411,1327.38 353.42,1327.38 353.43,1327.38 353.439,1327.38 353.448,1327.37 353.457,1327.37 353.466,1327.37 353.475,1327.37 353.485,1327.36 353.494,1327.36 353.503,1327.36 353.512,1327.36 353.521,1327.35 353.531,1327.35 353.54,1327.35 353.549,1327.35 353.558,1327.34 353.567,1327.34 353.577,1327.34 353.586,1327.34 353.595,1327.34 353.604,1327.33 353.613,1327.33 353.623,1327.33 353.632,1327.33 353.641,1327.32 353.65,1327.32 353.659,1327.32 353.668,1327.32 353.678,1327.31 353.687,1327.31 353.696,1327.31 353.705,1327.31 353.714,1327.3 353.724,1327.3 353.733,1327.3 353.742,1327.3 353.751,1327.3 353.76,1327.29 353.77,1327.29 353.779,1327.29 353.788,1327.29 353.797,1327.28 353.806,1327.28 353.816,1327.28 353.825,1327.28 353.834,1327.27 353.843,1327.27 353.852,1327.27 353.861,1327.27 353.871,1327.26 353.88,1327.26 353.889,1327.26 353.898,1327.26 353.907,1327.25 353.917,1327.25 353.926,1327.25 353.935,1327.25 353.944,1327.25 353.953,1327.24 353.963,1327.24 353.972,1327.24 353.981,1327.24 353.99,1327.23 353.999,1327.23 354.008,1327.23 354.018,1327.23 354.027,1327.22 354.036,1327.22 354.045,1327.22 354.054,1327.22 354.064,1327.21 354.073,1327.21 354.082,1327.21 354.091,1327.21 354.1,1327.2 354.11,1327.2 354.119,1327.2 354.128,1327.2 354.137,1327.2 354.146,1327.19 354.156,1327.19 354.165,1327.19 354.174,1327.19 354.183,1327.18 354.192,1327.18 354.201,1327.18 354.211,1327.18 354.22,1327.17 354.229,1327.17 354.238,1327.17 354.247,1327.17 354.257,1327.16 354.266,1327.16 354.275,1327.16 354.284,1327.16 354.293,1327.15 354.303,1327.15 354.312,1327.15 354.321,1327.15 354.33,1327.14 354.339,1327.14 354.348,1327.14 354.358,1327.14 354.367,1327.14 354.376,1327.13 354.385,1327.13 354.394,1327.13 354.404,1327.13 354.413,1327.12 354.422,1327.12 354.431,1327.12 354.44,1327.12 354.45,1327.11 354.459,1327.11 354.468,1327.11 354.477,1327.11 354.486,1327.1 354.496,1327.1 354.505,1327.1 354.514,1327.1 354.523,1327.09 354.532,1327.09 354.541,1327.09 354.551,1327.09 354.56,1327.08 354.569,1327.08 354.578,1327.08 354.587,1327.08 354.597,1327.07 354.606,1327.07 354.615,1327.07 354.624,1327.07 354.633,1327.07 354.643,1327.06 354.652,1327.06 354.661,1327.06 354.67,1327.06 354.679,1327.05 354.688,1327.05 354.698,1327.05 354.707,1327.05 354.716,1327.04 354.725,1327.04 354.734,1327.04 354.744,1327.04 354.753,1327.03 354.762,1327.03 354.771,1327.03 354.78,1327.03 354.79,1327.02 354.799,1327.02 354.808,1327.02 354.817,1327.02 354.826,1327.01 354.836,1327.01 354.845,1327.01 354.854,1327.01 354.863,1327 354.872,1327 354.881,1327 354.891,1327 354.9,1326.99 354.909,1326.99 354.918,1326.99 354.927,1326.99 354.937,1326.99 354.946,1326.98 354.955,1326.98 354.964,1326.98 354.973,1326.98 354.983,1326.97 354.992,1326.97 355.001,1326.97 355.01,1326.97 355.019,1326.96 355.028,1326.96 355.038,1326.96 355.047,1326.96 355.056,1326.95 355.065,1326.95 355.074,1326.95 355.084,1326.95 355.093,1326.94 355.102,1326.94 355.111,1326.94 355.12,1326.94 355.13,1326.93 355.139,1326.93 355.148,1326.93 355.157,1326.93 355.166,1326.92 355.176,1326.92 355.185,1326.92 355.194,1326.92 355.203,1326.91 355.212,1326.91 355.221,1326.91 355.231,1326.91 355.24,1326.9 355.249,1326.9 355.258,1326.9 355.267,1326.9 355.277,1326.89 355.286,1326.89 355.295,1326.89 355.304,1326.89 355.313,1326.88 355.323,1326.88 355.332,1326.88 355.341,1326.88 355.35,1326.87 355.359,1326.87 355.368,1326.87 355.378,1326.87 355.387,1326.86 355.396,1326.86 355.405,1326.86 355.414,1326.86 355.424,1326.85 355.433,1326.85 355.442,1326.85 355.451,1326.85 355.46,1326.85 355.47,1326.84 355.479,1326.84 355.488,1326.84 355.497,1326.84 355.506,1326.83 355.516,1326.83 355.525,1326.83 355.534,1326.83 355.543,1326.82 355.552,1326.82 355.561,1326.82 355.571,1326.82 355.58,1326.81 355.589,1326.81 355.598,1326.81 355.607,1326.81 355.617,1326.8 355.626,1326.8 355.635,1326.8 355.644,1326.8 355.653,1326.79 355.663,1326.79 355.672,1326.79 355.681,1326.79 355.69,1326.78 355.699,1326.78 355.708,1326.78 355.718,1326.78 355.727,1326.77 355.736,1326.77 355.745,1326.77 355.754,1326.77 355.764,1326.76 355.773,1326.76 355.782,1326.76 355.791,1326.76 355.8,1326.75 355.81,1326.75 355.819,1326.75 355.828,1326.75 355.837,1326.74 355.846,1326.74 355.856,1326.74 355.865,1326.74 355.874,1326.73 355.883,1326.73 355.892,1326.73 355.901,1326.73 355.911,1326.72 355.92,1326.72 355.929,1326.72 355.938,1326.72 355.947,1326.71 355.957,1326.71 355.966,1326.71 355.975,1326.71 355.984,1326.7 355.993,1326.7 356.003,1326.7 356.012,1326.7 356.021,1326.69 356.03,1326.69 356.039,1326.69 356.048,1326.69 356.058,1326.68 356.067,1326.68 356.076,1326.68 356.085,1326.68 356.094,1326.67 356.104,1326.67 356.113,1326.67 356.122,1326.67 356.131,1326.66 356.14,1326.66 356.15,1326.66 356.159,1326.66 356.168,1326.65 356.177,1326.65 356.186,1326.65 356.196,1326.65 356.205,1326.64 356.214,1326.64 356.223,1326.64 356.232,1326.64 356.241,1326.63 356.251,1326.63 356.26,1326.63 356.269,1326.63 356.278,1326.62 356.287,1326.62 356.297,1326.62 356.306,1326.62 356.315,1326.61 356.324,1326.61 356.333,1326.61 356.343,1326.61 356.352,1326.6 356.361,1326.6 356.37,1326.6 356.379,1326.6 356.389,1326.59 356.398,1326.59 356.407,1326.59 356.416,1326.59 356.425,1326.58 356.434,1326.58 356.444,1326.58 356.453,1326.57 356.462,1326.57 356.471,1326.57 356.48,1326.57 356.49,1326.56 356.499,1326.56 356.508,1326.56 356.517,1326.56 356.526,1326.55 356.536,1326.55 356.545,1326.55 356.554,1326.55 356.563,1326.54 356.572,1326.54 356.581,1326.54 356.591,1326.54 356.6,1326.53 356.609,1326.53 356.618,1326.53 356.627,1326.53 356.637,1326.52 356.646,1326.52 356.655,1326.52 356.664,1326.52 356.673,1326.51 356.683,1326.51 356.692,1326.51 356.701,1326.51 356.71,1326.5 356.719,1326.5 356.729,1326.5 356.738,1326.5 356.747,1326.49 356.756,1326.49 356.765,1326.49 356.774,1326.49 356.784,1326.48 356.793,1326.48 356.802,1326.48 356.811,1326.48 356.82,1326.47 356.83,1326.47 356.839,1326.47 356.848,1326.47 356.857,1326.46 356.866,1326.46 356.876,1326.46 356.885,1326.46 356.894,1326.45 356.903,1326.45 356.912,1326.45 356.921,1326.45 356.931,1326.44 356.94,1326.44 356.949,1326.44 356.958,1326.44 356.967,1326.43 356.977,1326.43 356.986,1326.43 356.995,1326.42 357.004,1326.42 357.013,1326.42 357.023,1326.42 357.032,1326.41 357.041,1326.41 357.05,1326.41 357.059,1326.41 357.069,1326.4 357.078,1326.4 357.087,1326.4 357.096,1326.4 357.105,1326.39 357.114,1326.39 357.124,1326.39 357.133,1326.39 357.142,1326.38 357.151,1326.38 357.16,1326.38 357.17,1326.38 357.179,1326.37 357.188,1326.37 357.197,1326.37 357.206,1326.37 357.216,1326.36 357.225,1326.36 357.234,1326.36 357.243,1326.36 357.252,1326.35 357.261,1326.35 357.271,1326.35 357.28,1326.35 357.289,1326.34 357.298,1326.34 357.307,1326.34 357.317,1326.34 357.326,1326.33 357.335,1326.33 357.344,1326.33 357.353,1326.32 357.363,1326.32 357.372,1326.32 357.381,1326.32 357.39,1326.31 357.399,1326.31 357.409,1326.31 357.418,1326.31 357.427,1326.3 357.436,1326.3 357.445,1326.3 357.454,1326.3 357.464,1326.29 357.473,1326.29 357.482,1326.29 357.491,1326.29 357.5,1326.28 357.51,1326.28 357.519,1326.28 357.528,1326.28 357.537,1326.27 357.546,1326.27 357.556,1326.27 357.565,1326.27 357.574,1326.26 357.583,1326.26 357.592,1326.26 357.601,1326.26 357.611,1326.25 357.62,1326.25 357.629,1326.25 357.638,1326.24 357.647,1326.24 357.657,1326.24 357.666,1326.24 357.675,1326.23 357.684,1326.23 357.693,1326.23 357.703,1326.23 357.712,1326.22 357.721,1326.22 357.73,1326.22 357.739,1326.22 357.749,1326.21 357.758,1326.21 357.767,1326.21 357.776,1326.21 357.785,1326.2 357.794,1326.2 357.804,1326.2 357.813,1326.2 357.822,1326.19 357.831,1326.19 357.84,1326.19 357.85,1326.18 357.859,1326.18 357.868,1326.18 357.877,1326.18 357.886,1326.17 357.896,1326.17 357.905,1326.17 357.914,1326.17 357.923,1326.16 357.932,1326.16 357.941,1326.16 357.951,1326.16 357.96,1326.15 357.969,1326.15 357.978,1326.15 357.987,1326.15 357.997,1326.14 358.006,1326.14 358.015,1326.14 358.024,1326.14 358.033,1326.13 358.043,1326.13 358.052,1326.13 358.061,1326.12 358.07,1326.12 358.079,1326.12 358.089,1326.12 358.098,1326.11 358.107,1326.11 358.116,1326.11 358.125,1326.11 358.134,1326.1 358.144,1326.1 358.153,1326.1 358.162,1326.1 358.171,1326.09 358.18,1326.09 358.19,1326.09 358.199,1326.09 358.208,1326.08 358.217,1326.08 358.226,1326.08 358.236,1326.08 358.245,1326.07 358.254,1326.07 358.263,1326.07 358.272,1326.06 358.281,1326.06 358.291,1326.06 358.3,1326.06 358.309,1326.05 358.318,1326.05 358.327,1326.05 358.337,1326.05 358.346,1326.04 358.355,1326.04 358.364,1326.04 358.373,1326.04 358.383,1326.03 358.392,1326.03 358.401,1326.03 358.41,1326.03 358.419,1326.02 358.429,1326.02 358.438,1326.02 358.447,1326.01 358.456,1326.01 358.465,1326.01 358.474,1326.01 358.484,1326 358.493,1326 358.502,1326 358.511,1326 358.52,1325.99 358.53,1325.99 358.539,1325.99 358.548,1325.99 358.557,1325.98 358.566,1325.98 358.576,1325.98 358.585,1325.98 358.594,1325.97 358.603,1325.97 358.612,1325.97 358.621,1325.96 358.631,1325.96 358.64,1325.96 358.649,1325.96 358.658,1325.95 358.667,1325.95 358.677,1325.95 358.686,1325.95 358.695,1325.94 358.704,1325.94 358.713,1325.94 358.723,1325.94 358.732,1325.93 358.741,1325.93 358.75,1325.93 358.759,1325.93 358.769,1325.92 358.778,1325.92 358.787,1325.92 358.796,1325.91 358.805,1325.91 358.814,1325.91 358.824,1325.91 358.833,1325.9 358.842,1325.9 358.851,1325.9 358.86,1325.9 358.87,1325.89 358.879,1325.89 358.888,1325.89 358.897,1325.89 358.906,1325.88 358.916,1325.88 358.925,1325.88 358.934,1325.87 358.943,1325.87 358.952,1325.87 358.962,1325.87 358.971,1325.86 358.98,1325.86 358.989,1325.86 358.998,1325.86 359.007,1325.85 359.017,1325.85 359.026,1325.85 359.035,1325.85 359.044,1325.84 359.053,1325.84 359.063,1325.84 359.072,1325.84 359.081,1325.83 359.09,1325.83 359.099,1325.83 359.109,1325.82 359.118,1325.82 359.127,1325.82 359.136,1325.82 359.145,1325.81 359.154,1325.81 359.164,1325.81 359.173,1325.81 359.182,1325.8 359.191,1325.8 359.2,1325.8 359.21,1325.8 359.219,1325.79 359.228,1325.79 359.237,1325.79 359.246,1325.78 359.256,1325.78 359.265,1325.78 359.274,1325.78 359.283,1325.77 359.292,1325.77 359.302,1325.77 359.311,1325.77 359.32,1325.76 359.329,1325.76 359.338,1325.76 359.347,1325.76 359.357,1325.75 359.366,1325.75 359.375,1325.75 359.384,1325.74 359.393,1325.74 359.403,1325.74 359.412,1325.74 359.421,1325.73 359.43,1325.73 359.439,1325.73 359.449,1325.73 359.458,1325.72 359.467,1325.72 359.476,1325.72 359.485,1325.71 359.494,1325.71 359.504,1325.71 359.513,1325.71 359.522,1325.7 359.531,1325.7 359.54,1325.7 359.55,1325.7 359.559,1325.69 359.568,1325.69 359.577,1325.69 359.586,1325.69 359.596,1325.68 359.605,1325.68 359.614,1325.68 359.623,1325.67 359.632,1325.67 359.642,1325.67 359.651,1325.67 359.66,1325.66 359.669,1325.66 359.678,1325.66 359.687,1325.66 359.697,1325.65 359.706,1325.65 359.715,1325.65 359.724,1325.65 359.733,1325.64 359.743,1325.64 359.752,1325.64 359.761,1325.63 359.77,1325.63 359.779,1325.63 359.789,1325.63 359.798,1325.62 359.807,1325.62 359.816,1325.62 359.825,1325.62 359.834,1325.61 359.844,1325.61 359.853,1325.61 359.862,1325.6 359.871,1325.6 359.88,1325.6 359.89,1325.6 359.899,1325.59 359.908,1325.59 359.917,1325.59 359.926,1325.59 359.936,1325.58 359.945,1325.58 359.954,1325.58 359.963,1325.58 359.972,1325.57 359.982,1325.57 359.991,1325.57 360,1325.56 360.009,1325.56 360.018,1325.56 360.027,1325.56 360.037,1325.55 360.046,1325.55 360.055,1325.55 360.064,1325.55 360.073,1325.54 360.083,1325.54 360.092,1325.54 360.101,1325.53 360.11,1325.53 360.119,1325.53 360.129,1325.53 360.138,1325.52 360.147,1325.52 360.156,1325.52 360.165,1325.52 360.174,1325.51 360.184,1325.51 360.193,1325.51 360.202,1325.5 360.211,1325.5 360.22,1325.5 360.23,1325.5 360.239,1325.49 360.248,1325.49 360.257,1325.49 360.266,1325.49 360.276,1325.48 360.285,1325.48 360.294,1325.48 360.303,1325.48 360.312,1325.47 360.322,1325.47 360.331,1325.47 360.34,1325.46 360.349,1325.46 360.358,1325.46 360.367,1325.46 360.377,1325.45 360.386,1325.45 360.395,1325.45 360.404,1325.45 360.413,1325.44 360.423,1325.44 360.432,1325.44 360.441,1325.43 360.45,1325.43 360.459,1325.43 360.469,1325.43 360.478,1325.42 360.487,1325.42 360.496,1325.42 360.505,1325.42 360.514,1325.41 360.524,1325.41 360.533,1325.41 360.542,1325.4 360.551,1325.4 360.56,1325.4 360.57,1325.4 360.579,1325.39 360.588,1325.39 360.597,1325.39 360.606,1325.39 360.616,1325.38 360.625,1325.38 360.634,1325.38 360.643,1325.37 360.652,1325.37 360.662,1325.37 360.671,1325.37 360.68,1325.36 360.689,1325.36 360.698,1325.36 360.707,1325.36 360.717,1325.35 360.726,1325.35 360.735,1325.35 360.744,1325.34 360.753,1325.34 360.763,1325.34 360.772,1325.34 360.781,1325.33 360.79,1325.33 360.799,1325.33 360.809,1325.33 360.818,1325.32 360.827,1325.32 360.836,1325.32 360.845,1325.31 360.854,1325.31 360.864,1325.31 360.873,1325.31 360.882,1325.3 360.891,1325.3 360.9,1325.3 360.91,1325.3 360.919,1325.29 360.928,1325.29 360.937,1325.29 360.946,1325.28 360.956,1325.28 360.965,1325.28 360.974,1325.28 360.983,1325.27 360.992,1325.27 361.002,1325.27 361.011,1325.27 361.02,1325.26 361.029,1325.26 361.038,1325.26 361.047,1325.25 361.057,1325.25 361.066,1325.25 361.075,1325.25 361.084,1325.24 361.093,1325.24 361.103,1325.24 361.112,1325.23 361.121,1325.23 361.13,1325.23 361.139,1325.23 361.149,1325.22 361.158,1325.22 361.167,1325.22 361.176,1325.22 361.185,1325.21 361.195,1325.21 361.204,1325.21 361.213,1325.2 361.222,1325.2 361.231,1325.2 361.24,1325.2 361.25,1325.19 361.259,1325.19 361.268,1325.19 361.277,1325.19 361.286,1325.18 361.296,1325.18 361.305,1325.18 361.314,1325.17 361.323,1325.17 361.332,1325.17 361.342,1325.17 361.351,1325.16 361.36,1325.16 361.369,1325.16 361.378,1325.16 361.387,1325.15 361.397,1325.15 361.406,1325.15 361.415,1325.14 361.424,1325.14 361.433,1325.14 361.443,1325.14 361.452,1325.13 361.461,1325.13 361.47,1325.13 361.479,1325.12 361.489,1325.12 361.498,1325.12 361.507,1325.12 361.516,1325.11 361.525,1325.11 361.535,1325.11 361.544,1325.11 361.553,1325.1 361.562,1325.1 361.571,1325.1 361.58,1325.09 361.59,1325.09 361.599,1325.09 361.608,1325.09 361.617,1325.08 361.626,1325.08 361.636,1325.08 361.645,1325.08 361.654,1325.07 361.663,1325.07 361.672,1325.07 361.682,1325.06 361.691,1325.06 361.7,1325.06 361.709,1325.06 361.718,1325.05 361.727,1325.05 361.737,1325.05 361.746,1325.04 361.755,1325.04 361.764,1325.04 361.773,1325.04 361.783,1325.03 361.792,1325.03 361.801,1325.03 361.81,1325.03 361.819,1325.02 361.829,1325.02 361.838,1325.02 361.847,1325.01 361.856,1325.01 361.865,1325.01 361.875,1325.01 361.884,1325 361.893,1325 361.902,1325 361.911,1324.99 361.92,1324.99 361.93,1324.99 361.939,1324.99 361.948,1324.98 361.957,1324.98 361.966,1324.98 361.976,1324.98 361.985,1324.97 361.994,1324.97 362.003,1324.97 362.012,1324.96 362.022,1324.96 362.031,1324.96 362.04,1324.96 362.049,1324.95 362.058,1324.95 362.067,1324.95 362.077,1324.94 362.086,1324.94 362.095,1324.94 362.104,1324.94 362.113,1324.93 362.123,1324.93 362.132,1324.93 362.141,1324.93 362.15,1324.92 362.159,1324.92 362.169,1324.92 362.178,1324.91 362.187,1324.91 362.196,1324.91 362.205,1324.91 362.215,1324.9 362.224,1324.9 362.233,1324.9 362.242,1324.89 362.251,1324.89 362.26,1324.89 362.27,1324.89 362.279,1324.88 362.288,1324.88 362.297,1324.88 362.306,1324.88 362.316,1324.87 362.325,1324.87 362.334,1324.87 362.343,1324.86 362.352,1324.86 362.362,1324.86 362.371,1324.86 362.38,1324.85 362.389,1324.85 362.398,1324.85 362.407,1324.84 362.417,1324.84 362.426,1324.84 362.435,1324.84 362.444,1324.83 362.453,1324.83 362.463,1324.83 362.472,1324.83 362.481,1324.82 362.49,1324.82 362.499,1324.82 362.509,1324.81 362.518,1324.81 362.527,1324.81 362.536,1324.81 362.545,1324.8 362.555,1324.8 362.564,1324.8 362.573,1324.79 362.582,1324.79 362.591,1324.79 362.6,1324.79 362.61,1324.78 362.619,1324.78 362.628,1324.78 362.637,1324.77 362.646,1324.77 362.656,1324.77 362.665,1324.77 362.674,1324.76 362.683,1324.76 362.692,1324.76 362.702,1324.76 362.711,1324.75 362.72,1324.75 362.729,1324.75 362.738,1324.74 362.747,1324.74 362.757,1324.74 362.766,1324.74 362.775,1324.73 362.784,1324.73 362.793,1324.73 362.803,1324.72 362.812,1324.72 362.821,1324.72 362.83,1324.72 362.839,1324.71 362.849,1324.71 362.858,1324.71 362.867,1324.7 362.876,1324.7 362.885,1324.7 362.895,1324.7 362.904,1324.69 362.913,1324.69 362.922,1324.69 362.931,1324.68 362.94,1324.68 362.95,1324.68 362.959,1324.68 362.968,1324.67 362.977,1324.67 362.986,1324.67 362.996,1324.67 363.005,1324.66 363.014,1324.66 363.023,1324.66 363.032,1324.65 363.042,1324.65 363.051,1324.65 363.06,1324.65 363.069,1324.64 363.078,1324.64 363.087,1324.64 363.097,1324.63 363.106,1324.63 363.115,1324.63 363.124,1324.63 363.133,1324.62 363.143,1324.62 363.152,1324.62 363.161,1324.61 363.17,1324.61 363.179,1324.61 363.189,1324.61 363.198,1324.6 363.207,1324.6 363.216,1324.6 363.225,1324.59 363.235,1324.59 363.244,1324.59 363.253,1324.59 363.262,1324.58 363.271,1324.58 363.28,1324.58 363.29,1324.58 363.299,1324.57 363.308,1324.57 363.317,1324.57 363.326,1324.56 363.336,1324.56 363.345,1324.56 363.354,1324.56 363.363,1324.55 363.372,1324.55 363.382,1324.55 363.391,1324.54 363.4,1324.54 363.409,1324.54 363.418,1324.54 363.427,1324.53 363.437,1324.53 363.446,1324.53 363.455,1324.52 363.464,1324.52 363.473,1324.52 363.483,1324.52 363.492,1324.51 363.501,1324.51 363.51,1324.51 363.519,1324.5 363.529,1324.5 363.538,1324.5 363.547,1324.5 363.556,1324.49 363.565,1324.49 363.575,1324.49 363.584,1324.48 363.593,1324.48 363.602,1324.48 363.611,1324.48 363.62,1324.47 363.63,1324.47 363.639,1324.47 363.648,1324.46 363.657,1324.46 363.666,1324.46 363.676,1324.46 363.685,1324.45 363.694,1324.45 363.703,1324.45 363.712,1324.45 363.722,1324.44 363.731,1324.44 363.74,1324.44 363.749,1324.43 363.758,1324.43 363.768,1324.43 363.777,1324.43 363.786,1324.42 363.795,1324.42 363.804,1324.42 363.813,1324.41 363.823,1324.41 363.832,1324.41 363.841,1324.41 363.85,1324.4 363.859,1324.4 363.869,1324.4 363.878,1324.39 363.887,1324.39 363.896,1324.39 363.905,1324.39 363.915,1324.38 363.924,1324.38 363.933,1324.38 363.942,1324.37 363.951,1324.37 363.96,1324.37 363.97,1324.37 363.979,1324.36 363.988,1324.36 363.997,1324.36 364.006,1324.35 364.016,1324.35 364.025,1324.35 364.034,1324.35 364.043,1324.34 364.052,1324.34 364.062,1324.34 364.071,1324.33 364.08,1324.33 364.089,1324.33 364.098,1324.33 364.108,1324.32 364.117,1324.32 364.126,1324.32 364.135,1324.31 364.144,1324.31 364.153,1324.31 364.163,1324.31 364.172,1324.3 364.181,1324.3 364.19,1324.3 364.199,1324.29 364.209,1324.29 364.218,1324.29 364.227,1324.29 364.236,1324.28 364.245,1324.28 364.255,1324.28 364.264,1324.27 364.273,1324.27 364.282,1324.27 364.291,1324.27 364.3,1324.26 364.31,1324.26 364.319,1324.26 364.328,1324.25 364.337,1324.25 364.346,1324.25 364.356,1324.25 364.365,1324.24 364.374,1324.24 364.383,1324.24 364.392,1324.23 364.402,1324.23 364.411,1324.23 364.42,1324.23 364.429,1324.22 364.438,1324.22 364.448,1324.22 364.457,1324.21 364.466,1324.21 364.475,1324.21 364.484,1324.21 364.493,1324.2 364.503,1324.2 364.512,1324.2 364.521,1324.19 364.53,1324.19 364.539,1324.19 364.549,1324.19 364.558,1324.18 364.567,1324.18 364.576,1324.18 364.585,1324.17 364.595,1324.17 364.604,1324.17 364.613,1324.17 364.622,1324.16 364.631,1324.16 364.64,1324.16 364.65,1324.15 364.659,1324.15 364.668,1324.15 364.677,1324.15 364.686,1324.14 364.696,1324.14 364.705,1324.14 364.714,1324.13 364.723,1324.13 364.732,1324.13 364.742,1324.13 364.751,1324.12 364.76,1324.12 364.769,1324.12 364.778,1324.11 364.788,1324.11 364.797,1324.11 364.806,1324.11 364.815,1324.1 364.824,1324.1 364.833,1324.1 364.843,1324.09 364.852,1324.09 364.861,1324.09 364.87,1324.09 364.879,1324.08 364.889,1324.08 364.898,1324.08 364.907,1324.07 364.916,1324.07 364.925,1324.07 364.935,1324.07 364.944,1324.06 364.953,1324.06 364.962,1324.06 364.971,1324.05 364.98,1324.05 364.99,1324.05 364.999,1324.05 365.008,1324.04 365.017,1324.04 365.026,1324.04 365.036,1324.03 365.045,1324.03 365.054,1324.03 365.063,1324.03 365.072,1324.02 365.082,1324.02 365.091,1324.02 365.1,1324.01 365.109,1324.01 365.118,1324.01 365.128,1324.01 365.137,1324 365.146,1324 365.155,1324 365.164,1323.99 365.173,1323.99 365.183,1323.99 365.192,1323.99 365.201,1323.98 365.21,1323.98 365.219,1323.98 365.229,1323.97 365.238,1323.97 365.247,1323.97 365.256,1323.97 365.265,1323.96 365.275,1323.96 365.284,1323.96 365.293,1323.95 365.302,1323.95 365.311,1323.95 365.32,1323.94 365.33,1323.94 365.339,1323.94 365.348,1323.94 365.357,1323.93 365.366,1323.93 365.376,1323.93 365.385,1323.92 365.394,1323.92 365.403,1323.92 365.412,1323.92 365.422,1323.91 365.431,1323.91 365.44,1323.91 365.449,1323.9 365.458,1323.9 365.468,1323.9 365.477,1323.9 365.486,1323.89 365.495,1323.89 365.504,1323.89 365.513,1323.88 365.523,1323.88 365.532,1323.88 365.541,1323.88 365.55,1323.87 365.559,1323.87 365.569,1323.87 365.578,1323.86 365.587,1323.86 365.596,1323.86 365.605,1323.86 365.615,1323.85 365.624,1323.85 365.633,1323.85 365.642,1323.84 365.651,1323.84 365.66,1323.84 365.67,1323.84 365.679,1323.83 365.688,1323.83 365.697,1323.83 365.706,1323.82 365.716,1323.82 365.725,1323.82 365.734,1323.82 365.743,1323.81 365.752,1323.81 365.762,1323.81 365.771,1323.8 365.78,1323.8 365.789,1323.8 365.798,1323.79 365.808,1323.79 365.817,1323.79 365.826,1323.79 365.835,1323.78 365.844,1323.78 365.853,1323.78 365.863,1323.77 365.872,1323.77 365.881,1323.77 365.89,1323.77 365.899,1323.76 365.909,1323.76 365.918,1323.76 365.927,1323.75 365.936,1323.75 365.945,1323.75 365.955,1323.75 365.964,1323.74 365.973,1323.74 365.982,1323.74 365.991,1323.73 366,1323.73 366.01,1323.73 366.019,1323.73 366.028,1323.72 366.037,1323.72 366.046,1323.72 366.056,1323.71 366.065,1323.71 366.074,1323.71 366.083,1323.71 366.092,1323.7 366.102,1323.7 366.111,1323.7 366.12,1323.69 366.129,1323.69 366.138,1323.69 366.148,1323.68 366.157,1323.68 366.166,1323.68 366.175,1323.68 366.184,1323.67 366.193,1323.67 366.203,1323.67 366.212,1323.66 366.221,1323.66 366.23,1323.66 366.239,1323.66 366.249,1323.65 366.258,1323.65 366.267,1323.65 366.276,1323.64 366.285,1323.64 366.295,1323.64 366.304,1323.64 366.313,1323.63 366.322,1323.63 366.331,1323.63 366.341,1323.62 366.35,1323.62 366.359,1323.62 366.368,1323.62 366.377,1323.61 366.386,1323.61 366.396,1323.61 366.405,1323.6 366.414,1323.6 366.423,1323.6 366.432,1323.59 366.442,1323.59 366.451,1323.59 366.46,1323.59 366.469,1323.58 366.478,1323.58 366.488,1323.58 366.497,1323.57 366.506,1323.57 366.515,1323.57 366.524,1323.57 366.533,1323.56 366.543,1323.56 366.552,1323.56 366.561,1323.55 366.57,1323.55 366.579,1323.55 366.589,1323.55 366.598,1323.54 366.607,1323.54 366.616,1323.54 366.625,1323.53 366.635,1323.53 366.644,1323.53 366.653,1323.52 366.662,1323.52 366.671,1323.52 366.681,1323.52 366.69,1323.51 366.699,1323.51 366.708,1323.51 366.717,1323.5 366.726,1323.5 366.736,1323.5 366.745,1323.5 366.754,1323.49 366.763,1323.49 366.772,1323.49 366.782,1323.48 366.791,1323.48 366.8,1323.48 366.809,1323.48 366.818,1323.47 366.828,1323.47 366.837,1323.47 366.846,1323.46 366.855,1323.46 366.864,1323.46 366.873,1323.45 366.883,1323.45 366.892,1323.45 366.901,1323.45 366.91,1323.44 366.919,1323.44 366.929,1323.44 366.938,1323.43 366.947,1323.43 366.956,1323.43 366.965,1323.43 366.975,1323.42 366.984,1323.42 366.993,1323.42 367.002,1323.41 367.011,1323.41 367.021,1323.41 367.03,1323.41 367.039,1323.4 367.048,1323.4 367.057,1323.4 367.066,1323.39 367.076,1323.39 367.085,1323.39 367.094,1323.38 367.103,1323.38 367.112,1323.38 367.122,1323.38 367.131,1323.37 367.14,1323.37 367.149,1323.37 367.158,1323.36 367.168,1323.36 367.177,1323.36 367.186,1323.36 367.195,1323.35 367.204,1323.35 367.213,1323.35 367.223,1323.34 367.232,1323.34 367.241,1323.34 367.25,1323.34 367.259,1323.33 367.269,1323.33 367.278,1323.33 367.287,1323.32 367.296,1323.32 367.305,1323.32 367.315,1323.31 367.324,1323.31 367.333,1323.31 367.342,1323.31 367.351,1323.3 367.361,1323.3 367.37,1323.3 367.379,1323.29 367.388,1323.29 367.397,1323.29 367.406,1323.29 367.416,1323.28 367.425,1323.28 367.434,1323.28 367.443,1323.27 367.452,1323.27 367.462,1323.27 367.471,1323.26 367.48,1323.26 367.489,1323.26 367.498,1323.26 367.508,1323.25 367.517,1323.25 367.526,1323.25 367.535,1323.24 367.544,1323.24 367.553,1323.24 367.563,1323.24 367.572,1323.23 367.581,1323.23 367.59,1323.23 367.599,1323.22 367.609,1323.22 367.618,1323.22 367.627,1323.22 367.636,1323.21 367.645,1323.21 367.655,1323.21 367.664,1323.2 367.673,1323.2 367.682,1323.2 367.691,1323.19 367.701,1323.19 367.71,1323.19 367.719,1323.19 367.728,1323.18 367.737,1323.18 367.746,1323.18 367.756,1323.17 367.765,1323.17 367.774,1323.17 367.783,1323.17 367.792,1323.16 367.802,1323.16 367.811,1323.16 367.82,1323.15 367.829,1323.15 367.838,1323.15 367.848,1323.14 367.857,1323.14 367.866,1323.14 367.875,1323.14 367.884,1323.13 367.893,1323.13 367.903,1323.13 367.912,1323.12 367.921,1323.12 367.93,1323.12 367.939,1323.12 367.949,1323.11 367.958,1323.11 367.967,1323.11 367.976,1323.1 367.985,1323.1 367.995,1323.1 368.004,1323.09 368.013,1323.09 368.022,1323.09 368.031,1323.09 368.041,1323.08 368.05,1323.08 368.059,1323.08 368.068,1323.07 368.077,1323.07 368.086,1323.07 368.096,1323.07 368.105,1323.06 368.114,1323.06 368.123,1323.06 368.132,1323.05 368.142,1323.05 368.151,1323.05 368.16,1323.04 368.169,1323.04 368.178,1323.04 368.188,1323.04 368.197,1323.03 368.206,1323.03 368.215,1323.03 368.224,1323.02 368.233,1323.02 368.243,1323.02 368.252,1323.02 368.261,1323.01 368.27,1323.01 368.279,1323.01 368.289,1323 368.298,1323 368.307,1323 368.316,1322.99 368.325,1322.99 368.335,1322.99 368.344,1322.99 368.353,1322.98 368.362,1322.98 368.371,1322.98 368.381,1322.97 368.39,1322.97 368.399,1322.97 368.408,1322.97 368.417,1322.96 368.426,1322.96 368.436,1322.96 368.445,1322.95 368.454,1322.95 368.463,1322.95 368.472,1322.94 368.482,1322.94 368.491,1322.94 368.5,1322.94 368.509,1322.93 368.518,1322.93 368.528,1322.93 368.537,1322.92 368.546,1322.92 368.555,1322.92 368.564,1322.91 368.574,1322.91 368.583,1322.91 368.592,1322.91 368.601,1322.9 368.61,1322.9 368.619,1322.9 368.629,1322.89 368.638,1322.89 368.647,1322.89 368.656,1322.89 368.665,1322.88 368.675,1322.88 368.684,1322.88 368.693,1322.87 368.702,1322.87 368.711,1322.87 368.721,1322.86 368.73,1322.86 368.739,1322.86 368.748,1322.86 368.757,1322.85 368.766,1322.85 368.776,1322.85 368.785,1322.84 368.794,1322.84 368.803,1322.84 368.812,1322.84 368.822,1322.83 368.831,1322.83 368.84,1322.83 368.849,1322.82 368.858,1322.82 368.868,1322.82 368.877,1322.81 368.886,1322.81 368.895,1322.81 368.904,1322.81 368.914,1322.8 368.923,1322.8 368.932,1322.8 368.941,1322.79 368.95,1322.79 368.959,1322.79 368.969,1322.78 368.978,1322.78 368.987,1322.78 368.996,1322.78 369.005,1322.77 369.015,1322.77 369.024,1322.77 369.033,1322.76 369.042,1322.76 369.051,1322.76 369.061,1322.76 369.07,1322.75 369.079,1322.75 369.088,1322.75 369.097,1322.74 369.106,1322.74 369.116,1322.74 369.125,1322.73 369.134,1322.73 369.143,1322.73 369.152,1322.73 369.162,1322.72 369.171,1322.72 369.18,1322.72 369.189,1322.71 369.198,1322.71 369.208,1322.71 369.217,1322.71 369.226,1322.7 369.235,1322.7 369.244,1322.7 369.254,1322.69 369.263,1322.69 369.272,1322.69 369.281,1322.68 369.29,1322.68 369.299,1322.68 369.309,1322.68 369.318,1322.67 369.327,1322.67 369.336,1322.67 369.345,1322.66 369.355,1322.66 369.364,1322.66 369.373,1322.65 369.382,1322.65 369.391,1322.65 369.401,1322.65 369.41,1322.64 369.419,1322.64 369.428,1322.64 369.437,1322.63 369.446,1322.63 369.456,1322.63 369.465,1322.63 369.474,1322.62 369.483,1322.62 369.492,1322.62 369.502,1322.61 369.511,1322.61 369.52,1322.61 369.529,1322.6 369.538,1322.6 369.548,1322.6 369.557,1322.6 369.566,1322.59 369.575,1322.59 369.584,1322.59 369.594,1322.58 369.603,1322.58 369.612,1322.58 369.621,1322.57 369.63,1322.57 369.639,1322.57 369.649,1322.57 369.658,1322.56 369.667,1322.56 369.676,1322.56 369.685,1322.55 369.695,1322.55 369.704,1322.55 369.713,1322.54 369.722,1322.54 369.731,1322.54 369.741,1322.54 369.75,1322.53 369.759,1322.53 369.768,1322.53 369.777,1322.52 369.786,1322.52 369.796,1322.52 369.805,1322.52 369.814,1322.51 369.823,1322.51 369.832,1322.51 369.842,1322.5 369.851,1322.5 369.86,1322.5 369.869,1322.49 369.878,1322.49 369.888,1322.49 369.897,1322.49 369.906,1322.48 369.915,1322.48 369.924,1322.48 369.934,1322.47 369.943,1322.47 369.952,1322.47 369.961,1322.46 369.97,1322.46 369.979,1322.46 369.989,1322.46 369.998,1322.45 370.007,1322.45 370.016,1322.45 370.025,1322.44 370.035,1322.44 370.044,1322.44 370.053,1322.43 370.062,1322.43 370.071,1322.43 370.081,1322.43 370.09,1322.42 370.099,1322.42 370.108,1322.42 370.117,1322.41 370.126,1322.41 370.136,1322.41 370.145,1322.41 370.154,1322.4 370.163,1322.4 370.172,1322.4 370.182,1322.39 370.191,1322.39 370.2,1322.39 370.209,1322.38 370.218,1322.38 370.228,1322.38 370.237,1322.38 370.246,1322.37 370.255,1322.37 370.264,1322.37 370.274,1322.36 370.283,1322.36 370.292,1322.36 370.301,1322.35 370.31,1322.35 370.319,1322.35 370.329,1322.35 370.338,1322.34 370.347,1322.34 370.356,1322.34 370.365,1322.33 370.375,1322.33 370.384,1322.33 370.393,1322.32 370.402,1322.32 370.411,1322.32 370.421,1322.32 370.43,1322.31 370.439,1322.31 370.448,1322.31 370.457,1322.3 370.466,1322.3 370.476,1322.3 370.485,1322.29 370.494,1322.29 370.503,1322.29 370.512,1322.29 370.522,1322.28 370.531,1322.28 370.54,1322.28 370.549,1322.27 370.558,1322.27 370.568,1322.27 370.577,1322.27 370.586,1322.26 370.595,1322.26 370.604,1322.26 370.614,1322.25 370.623,1322.25 370.632,1322.25 370.641,1322.24 370.65,1322.24 370.659,1322.24 370.669,1322.24 370.678,1322.23 370.687,1322.23 370.696,1322.23 370.705,1322.22 370.715,1322.22 370.724,1322.22 370.733,1322.21 370.742,1322.21 370.751,1322.21 370.761,1322.21 370.77,1322.2 370.779,1322.2 370.788,1322.2 370.797,1322.19 370.806,1322.19 370.816,1322.19 370.825,1322.18 370.834,1322.18 370.843,1322.18 370.852,1322.18 370.862,1322.17 370.871,1322.17 370.88,1322.17 370.889,1322.16 370.898,1322.16 370.908,1322.16 370.917,1322.15 370.926,1322.15 370.935,1322.15 370.944,1322.15 370.954,1322.14 370.963,1322.14 370.972,1322.14 370.981,1322.13 370.99,1322.13 370.999,1322.13 371.009,1322.12 371.018,1322.12 371.027,1322.12 371.036,1322.12 371.045,1322.11 371.055,1322.11 371.064,1322.11 371.073,1322.1 371.082,1322.1 371.091,1322.1 371.101,1322.09 371.11,1322.09 371.119,1322.09 371.128,1322.09 371.137,1322.08 371.147,1322.08 371.156,1322.08 371.165,1322.07 371.174,1322.07 371.183,1322.07 371.192,1322.06 371.202,1322.06 371.211,1322.06 371.22,1322.06 371.229,1322.05 371.238,1322.05 371.248,1322.05 371.257,1322.04 371.266,1322.04 371.275,1322.04 371.284,1322.04 371.294,1322.03 371.303,1322.03 371.312,1322.03 371.321,1322.02 371.33,1322.02 371.339,1322.02 371.349,1322.01 371.358,1322.01 371.367,1322.01 371.376,1322.01 371.385,1322 371.395,1322 371.404,1322 371.413,1321.99 371.422,1321.99 371.431,1321.99 371.441,1321.98 371.45,1321.98 371.459,1321.98 371.468,1321.98 371.477,1321.97 371.487,1321.97 371.496,1321.97 371.505,1321.96 371.514,1321.96 371.523,1321.96 371.532,1321.95 371.542,1321.95 371.551,1321.95 371.56,1321.95 371.569,1321.94 371.578,1321.94 371.588,1321.94 371.597,1321.93 371.606,1321.93 371.615,1321.93 371.624,1321.92 371.634,1321.92 371.643,1321.92 371.652,1321.92 371.661,1321.91 371.67,1321.91 371.679,1321.91 371.689,1321.9 371.698,1321.9 371.707,1321.9 371.716,1321.89 371.725,1321.89 371.735,1321.89 371.744,1321.89 371.753,1321.88 371.762,1321.88 371.771,1321.88 371.781,1321.87 371.79,1321.87 371.799,1321.87 371.808,1321.86 371.817,1321.86 371.827,1321.86 371.836,1321.86 371.845,1321.85 371.854,1321.85 371.863,1321.85 371.872,1321.84 371.882,1321.84 371.891,1321.84 371.9,1321.83 371.909,1321.83 371.918,1321.83 371.928,1321.83 371.937,1321.82 371.946,1321.82 371.955,1321.82 371.964,1321.81 371.974,1321.81 371.983,1321.81 371.992,1321.8 372.001,1321.8 372.01,1321.8 372.019,1321.8 372.029,1321.79 372.038,1321.79 372.047,1321.79 372.056,1321.78 372.065,1321.78 372.075,1321.78 372.084,1321.77 372.093,1321.77 372.102,1321.77 372.111,1321.77 372.121,1321.76 372.13,1321.76 372.139,1321.76 372.148,1321.75 372.157,1321.75 372.167,1321.75 372.176,1321.74 372.185,1321.74 372.194,1321.74 372.203,1321.74 372.212,1321.73 372.222,1321.73 372.231,1321.73 372.24,1321.72 372.249,1321.72 372.258,1321.72 372.268,1321.71 372.277,1321.71 372.286,1321.71 372.295,1321.71 372.304,1321.7 372.314,1321.7 372.323,1321.7 372.332,1321.69 372.341,1321.69 372.35,1321.69 372.359,1321.68 372.369,1321.68 372.378,1321.68 372.387,1321.68 372.396,1321.67 372.405,1321.67 372.415,1321.67 372.424,1321.66 372.433,1321.66 372.442,1321.66 372.451,1321.65 372.461,1321.65 372.47,1321.65 372.479,1321.65 372.488,1321.64 372.497,1321.64 372.507,1321.64 372.516,1321.63 372.525,1321.63 372.534,1321.63 372.543,1321.62 372.552,1321.62 372.562,1321.62 372.571,1321.62 372.58,1321.61 372.589,1321.61 372.598,1321.61 372.608,1321.6 372.617,1321.6 372.626,1321.6 372.635,1321.59 372.644,1321.59 372.654,1321.59 372.663,1321.59 372.672,1321.58 372.681,1321.58 372.69,1321.58 372.699,1321.57 372.709,1321.57 372.718,1321.57 372.727,1321.56 372.736,1321.56 372.745,1321.56 372.755,1321.56 372.764,1321.55 372.773,1321.55 372.782,1321.55 372.791,1321.54 372.801,1321.54 372.81,1321.54 372.819,1321.53 372.828,1321.53 372.837,1321.53 372.847,1321.53 372.856,1321.52 372.865,1321.52 372.874,1321.52 372.883,1321.51 372.892,1321.51 372.902,1321.51 372.911,1321.5 372.92,1321.5 372.929,1321.5 372.938,1321.49 372.948,1321.49 372.957,1321.49 372.966,1321.49 372.975,1321.48 372.984,1321.48 372.994,1321.48 373.003,1321.47 373.012,1321.47 373.021,1321.47 373.03,1321.46 373.039,1321.46 373.049,1321.46 373.058,1321.46 373.067,1321.45 373.076,1321.45 373.085,1321.45 373.095,1321.44 373.104,1321.44 373.113,1321.44 373.122,1321.43 373.131,1321.43 373.141,1321.43 373.15,1321.43 373.159,1321.42 373.168,1321.42 373.177,1321.42 373.187,1321.41 373.196,1321.41 373.205,1321.41 373.214,1321.4 373.223,1321.4 373.232,1321.4 373.242,1321.4 373.251,1321.39 373.26,1321.39 373.269,1321.39 373.278,1321.38 373.288,1321.38 373.297,1321.38 373.306,1321.37 373.315,1321.37 373.324,1321.37 373.334,1321.37 373.343,1321.36 373.352,1321.36 373.361,1321.36 373.37,1321.35 373.379,1321.35 373.389,1321.35 373.398,1321.34 373.407,1321.34 373.416,1321.34 373.425,1321.34 373.435,1321.33 373.444,1321.33 373.453,1321.33 373.462,1321.32 373.471,1321.32 373.481,1321.32 373.49,1321.31 373.499,1321.31 373.508,1321.31 373.517,1321.31 373.527,1321.3 373.536,1321.3 373.545,1321.3 373.554,1321.29 373.563,1321.29 373.572,1321.29 373.582,1321.28 373.591,1321.28 373.6,1321.28 373.609,1321.28 373.618,1321.27 373.628,1321.27 373.637,1321.27 373.646,1321.26 373.655,1321.26 373.664,1321.26 373.674,1321.25 373.683,1321.25 373.692,1321.25 373.701,1321.24 373.71,1321.24 373.72,1321.24 373.729,1321.24 373.738,1321.23 373.747,1321.23 373.756,1321.23 373.765,1321.22 373.775,1321.22 373.784,1321.22 373.793,1321.21 373.802,1321.21 373.811,1321.21 373.821,1321.21 373.83,1321.2 373.839,1321.2 373.848,1321.2 373.857,1321.19 373.867,1321.19 373.876,1321.19 373.885,1321.18 373.894,1321.18 373.903,1321.18 373.912,1321.18 373.922,1321.17 373.931,1321.17 373.94,1321.17 373.949,1321.16 373.958,1321.16 373.968,1321.16 373.977,1321.15 373.986,1321.15 373.995,1321.15 374.004,1321.15 374.014,1321.14 374.023,1321.14 374.032,1321.14 374.041,1321.13 374.05,1321.13 374.06,1321.13 374.069,1321.12 374.078,1321.12 374.087,1321.12 374.096,1321.12 374.105,1321.11 374.115,1321.11 374.124,1321.11 374.133,1321.1 374.142,1321.1 374.151,1321.1 374.161,1321.09 374.17,1321.09 374.179,1321.09 374.188,1321.09 374.197,1321.08 374.207,1321.08 374.216,1321.08 374.225,1321.07 374.234,1321.07 374.243,1321.07 374.252,1321.06 374.262,1321.06 374.271,1321.06 374.28,1321.05 374.289,1321.05 374.298,1321.05 374.308,1321.05 374.317,1321.04 374.326,1321.04 374.335,1321.04 374.344,1321.03 374.354,1321.03 374.363,1321.03 374.372,1321.02 374.381,1321.02 374.39,1321.02 374.4,1321.02 374.409,1321.01 374.418,1321.01 374.427,1321.01 374.436,1321 374.445,1321 374.455,1321 374.464,1320.99 374.473,1320.99 374.482,1320.99 374.491,1320.99 374.501,1320.98 374.51,1320.98 374.519,1320.98 374.528,1320.97 374.537,1320.97 374.547,1320.97 374.556,1320.96 374.565,1320.96 374.574,1320.96 374.583,1320.96 374.592,1320.95 374.602,1320.95 374.611,1320.95 374.62,1320.94 374.629,1320.94 374.638,1320.94 374.648,1320.93 374.657,1320.93 374.666,1320.93 374.675,1320.93 374.684,1320.92 374.694,1320.92 374.703,1320.92 374.712,1320.91 374.721,1320.91 374.73,1320.91 374.74,1320.9 374.749,1320.9 374.758,1320.9 374.767,1320.89 374.776,1320.89 374.785,1320.89 374.795,1320.89 374.804,1320.88 374.813,1320.88 374.822,1320.88 374.831,1320.87 374.841,1320.87 374.85,1320.87 374.859,1320.86 374.868,1320.86 374.877,1320.86 374.887,1320.86 374.896,1320.85 374.905,1320.85 374.914,1320.85 374.923,1320.84 374.932,1320.84 374.942,1320.84 374.951,1320.83 374.96,1320.83 374.969,1320.83 374.978,1320.83 374.988,1320.82 374.997,1320.82 375.006,1320.82 375.015,1320.81 375.024,1320.81 375.034,1320.81 375.043,1320.8 375.052,1320.8 375.061,1320.8 375.07,1320.8 375.08,1320.79 375.089,1320.79 375.098,1320.79 375.107,1320.78 375.116,1320.78 375.125,1320.78 375.135,1320.77 375.144,1320.77 375.153,1320.77 375.162,1320.76 375.171,1320.76 375.181,1320.76 375.19,1320.76 375.199,1320.75 375.208,1320.75 375.217,1320.75 375.227,1320.74 375.236,1320.74 375.245,1320.74 375.254,1320.73 375.263,1320.73 375.272,1320.73 375.282,1320.73 375.291,1320.72 375.3,1320.72 375.309,1320.72 375.318,1320.71 375.328,1320.71 375.337,1320.71 375.346,1320.7 375.355,1320.7 375.364,1320.7 375.374,1320.7 375.383,1320.69 375.392,1320.69 375.401,1320.69 375.41,1320.68 375.42,1320.68 375.429,1320.68 375.438,1320.67 375.447,1320.67 375.456,1320.67 375.465,1320.67 375.475,1320.66 375.484,1320.66 375.493,1320.66 375.502,1320.65 375.511,1320.65 375.521,1320.65 375.53,1320.64 375.539,1320.64 375.548,1320.64 375.557,1320.63 375.567,1320.63 375.576,1320.63 375.585,1320.63 375.594,1320.62 375.603,1320.62 375.612,1320.62 375.622,1320.61 375.631,1320.61 375.64,1320.61 375.649,1320.6 375.658,1320.6 375.668,1320.6 375.677,1320.6 375.686,1320.59 375.695,1320.59 375.704,1320.59 375.714,1320.58 375.723,1320.58 375.732,1320.58 375.741,1320.57 375.75,1320.57 375.76,1320.57 375.769,1320.57 375.778,1320.56 375.787,1320.56 375.796,1320.56 375.805,1320.55 375.815,1320.55 375.824,1320.55 375.833,1320.54 375.842,1320.54 375.851,1320.54 375.861,1320.53 375.87,1320.53 375.879,1320.53 375.888,1320.53 375.897,1320.52 375.907,1320.52 375.916,1320.52 375.925,1320.51 375.934,1320.51 375.943,1320.51 375.953,1320.5 375.962,1320.5 375.971,1320.5 375.98,1320.5 375.989,1320.49 375.998,1320.49 376.008,1320.49 376.017,1320.48 376.026,1320.48 376.035,1320.48 376.044,1320.47 376.054,1320.47 376.063,1320.47 376.072,1320.47 376.081,1320.46 376.09,1320.46 376.1,1320.46 376.109,1320.45 376.118,1320.45 376.127,1320.45 376.136,1320.44 376.145,1320.44 376.155,1320.44 376.164,1320.44 376.173,1320.43 376.182,1320.43 376.191,1320.43 376.201,1320.42 376.21,1320.42 376.219,1320.42 376.228,1320.41 376.237,1320.41 376.247,1320.41 376.256,1320.4 376.265,1320.4 376.274,1320.4 376.283,1320.4 376.293,1320.39 376.302,1320.39 376.311,1320.39 376.32,1320.38 376.329,1320.38 376.338,1320.38 376.348,1320.37 376.357,1320.37 376.366,1320.37 376.375,1320.37 376.384,1320.36 376.394,1320.36 376.403,1320.36 376.412,1320.35 376.421,1320.35 376.43,1320.35 376.44,1320.34 376.449,1320.34 376.458,1320.34 376.467,1320.34 376.476,1320.33 376.485,1320.33 376.495,1320.33 376.504,1320.32 376.513,1320.32 376.522,1320.32 376.531,1320.31 376.541,1320.31 376.55,1320.31 376.559,1320.3 376.568,1320.3 376.577,1320.3 376.587,1320.3 376.596,1320.29 376.605,1320.29 376.614,1320.29 376.623,1320.28 376.633,1320.28 376.642,1320.28 376.651,1320.27 376.66,1320.27 376.669,1320.27 376.678,1320.27 376.688,1320.26 376.697,1320.26 376.706,1320.26 376.715,1320.25 376.724,1320.25 376.734,1320.25 376.743,1320.24 376.752,1320.24 376.761,1320.24 376.77,1320.24 376.78,1320.23 376.789,1320.23 376.798,1320.23 376.807,1320.22 376.816,1320.22 376.825,1320.22 376.835,1320.21 376.844,1320.21 376.853,1320.21 376.862,1320.2 376.871,1320.2 376.881,1320.2 376.89,1320.2 376.899,1320.19 376.908,1320.19 376.917,1320.19 376.927,1320.18 376.936,1320.18 376.945,1320.18 376.954,1320.17 376.963,1320.17 376.973,1320.17 376.982,1320.17 376.991,1320.16 377,1320.16 377.009,1320.16 377.018,1320.15 377.028,1320.15 377.037,1320.15 377.046,1320.14 377.055,1320.14 377.064,1320.14 377.074,1320.14 377.083,1320.13 377.092,1320.13 377.101,1320.13 377.11,1320.12 377.12,1320.12 377.129,1320.12 377.138,1320.11 377.147,1320.11 377.156,1320.11 377.165,1320.11 377.175,1320.1 377.184,1320.1 377.193,1320.1 377.202,1320.09 377.211,1320.09 377.221,1320.09 377.23,1320.08 377.239,1320.08 377.248,1320.08 377.257,1320.07 377.267,1320.07 377.276,1320.07 377.285,1320.07 377.294,1320.06 377.303,1320.06 377.313,1320.06 377.322,1320.05 377.331,1320.05 377.34,1320.05 377.349,1320.04 377.358,1320.04 377.368,1320.04 377.377,1320.04 377.386,1320.03 377.395,1320.03 377.404,1320.03 377.414,1320.02 377.423,1320.02 377.432,1320.02 377.441,1320.01 377.45,1320.01 377.46,1320.01 377.469,1320.01 377.478,1320 377.487,1320 377.496,1320 377.505,1319.99 377.515,1319.99 377.524,1319.99 377.533,1319.98 377.542,1319.98 377.551,1319.98 377.561,1319.97 377.57,1319.97 377.579,1319.97 377.588,1319.97 377.597,1319.96 377.607,1319.96 377.616,1319.96 377.625,1319.95 377.634,1319.95 377.643,1319.95 377.653,1319.94 377.662,1319.94 377.671,1319.94 377.68,1319.94 377.689,1319.93 377.698,1319.93 377.708,1319.93 377.717,1319.92 377.726,1319.92 377.735,1319.92 377.744,1319.91 377.754,1319.91 377.763,1319.91 377.772,1319.91 377.781,1319.9 377.79,1319.9 377.8,1319.9 377.809,1319.89 377.818,1319.89 377.827,1319.89 377.836,1319.88 377.845,1319.88 377.855,1319.88 377.864,1319.87 377.873,1319.87 377.882,1319.87 377.891,1319.87 377.901,1319.86 377.91,1319.86 377.919,1319.86 377.928,1319.85 377.937,1319.85 377.947,1319.85 377.956,1319.84 377.965,1319.84 377.974,1319.84 377.983,1319.84 377.993,1319.83 378.002,1319.83 378.011,1319.83 378.02,1319.82 378.029,1319.82 378.038,1319.82 378.048,1319.81 378.057,1319.81 378.066,1319.81 378.075,1319.81 378.084,1319.8 378.094,1319.8 378.103,1319.8 378.112,1319.79 378.121,1319.79 378.13,1319.79 378.14,1319.78 378.149,1319.78 378.158,1319.78 378.167,1319.77 378.176,1319.77 378.185,1319.77 378.195,1319.77 378.204,1319.76 378.213,1319.76 378.222,1319.76 378.231,1319.75 378.241,1319.75 378.25,1319.75 378.259,1319.74 378.268,1319.74 378.277,1319.74 378.287,1319.74 378.296,1319.73 378.305,1319.73 378.314,1319.73 378.323,1319.72 378.333,1319.72 378.342,1319.72 378.351,1319.71 378.36,1319.71 378.369,1319.71 378.378,1319.71 378.388,1319.7 378.397,1319.7 378.406,1319.7 378.415,1319.69 378.424,1319.69 378.434,1319.69 378.443,1319.68 378.452,1319.68 378.461,1319.68 378.47,1319.67 378.48,1319.67 378.489,1319.67 378.498,1319.67 378.507,1319.66 378.516,1319.66 378.526,1319.66 378.535,1319.65 378.544,1319.65 378.553,1319.65 378.562,1319.64 378.571,1319.64 378.581,1319.64 378.59,1319.64 378.599,1319.63 378.608,1319.63 378.617,1319.63 378.627,1319.62 378.636,1319.62 378.645,1319.62 378.654,1319.61 378.663,1319.61 378.673,1319.61 378.682,1319.61 378.691,1319.6 378.7,1319.6 378.709,1319.6 378.718,1319.59 378.728,1319.59 378.737,1319.59 378.746,1319.58 378.755,1319.58 378.764,1319.58 378.774,1319.57 378.783,1319.57 378.792,1319.57 378.801,1319.57 378.81,1319.56 378.82,1319.56 378.829,1319.56 378.838,1319.55 378.847,1319.55 378.856,1319.55 378.866,1319.54 378.875,1319.54 378.884,1319.54 378.893,1319.54 378.902,1319.53 378.911,1319.53 378.921,1319.53 378.93,1319.52 378.939,1319.52 378.948,1319.52 378.957,1319.51 378.967,1319.51 378.976,1319.51 378.985,1319.51 378.994,1319.5 379.003,1319.5 379.013,1319.5 379.022,1319.49 379.031,1319.49 379.04,1319.49 379.049,1319.48 379.058,1319.48 379.068,1319.48 379.077,1319.47 379.086,1319.47 379.095,1319.47 379.104,1319.47 379.114,1319.46 379.123,1319.46 379.132,1319.46 379.141,1319.45 379.15,1319.45 379.16,1319.45 379.169,1319.44 379.178,1319.44 379.187,1319.44 379.196,1319.44 379.206,1319.43 379.215,1319.43 379.224,1319.43 379.233,1319.42 379.242,1319.42 379.251,1319.42 379.261,1319.41 379.27,1319.41 379.279,1319.41 379.288,1319.41 379.297,1319.4 379.307,1319.4 379.316,1319.4 379.325,1319.39 379.334,1319.39 379.343,1319.39 379.353,1319.38 379.362,1319.38 379.371,1319.38 379.38,1319.37 379.389,1319.37 379.398,1319.37 379.408,1319.37 379.417,1319.36 379.426,1319.36 379.435,1319.36 379.444,1319.35 379.454,1319.35 379.463,1319.35 379.472,1319.34 379.481,1319.34 379.49,1319.34 379.5,1319.34 379.509,1319.33 379.518,1319.33 379.527,1319.33 379.536,1319.32 379.546,1319.32 379.555,1319.32 379.564,1319.31 379.573,1319.31 379.582,1319.31 379.591,1319.31 379.601,1319.3 379.61,1319.3 379.619,1319.3 379.628,1319.29 379.637,1319.29 379.647,1319.29 379.656,1319.28 379.665,1319.28 379.674,1319.28 379.683,1319.28 379.693,1319.27 379.702,1319.27 379.711,1319.27 379.72,1319.26 379.729,1319.26 379.738,1319.26 379.748,1319.25 379.757,1319.25 379.766,1319.25 379.775,1319.24 379.784,1319.24 379.794,1319.24 379.803,1319.24 379.812,1319.23 379.821,1319.23 379.83,1319.23 379.84,1319.22 379.849,1319.22 379.858,1319.22 379.867,1319.21 379.876,1319.21 379.886,1319.21 379.895,1319.21 379.904,1319.2 379.913,1319.2 379.922,1319.2 379.931,1319.19 379.941,1319.19 379.95,1319.19 379.959,1319.18 379.968,1319.18 379.977,1319.18 379.987,1319.18 379.996,1319.17 380.005,1319.17 380.014,1319.17 380.023,1319.16 380.033,1319.16 380.042,1319.16 380.051,1319.15 380.06,1319.15 380.069,1319.15 380.078,1319.14 380.088,1319.14 380.097,1319.14 380.106,1319.14 380.115,1319.13 380.124,1319.13 380.134,1319.13 380.143,1319.12 380.152,1319.12 380.161,1319.12 380.17,1319.11 380.18,1319.11 380.189,1319.11 380.198,1319.11 380.207,1319.1 380.216,1319.1 380.226,1319.1 380.235,1319.09 380.244,1319.09 380.253,1319.09 380.262,1319.08 380.271,1319.08 380.281,1319.08 380.29,1319.08 380.299,1319.07 380.308,1319.07 380.317,1319.07 380.327,1319.06 380.336,1319.06 380.345,1319.06 380.354,1319.05 380.363,1319.05 380.373,1319.05 380.382,1319.05 380.391,1319.04 380.4,1319.04 380.409,1319.04 380.418,1319.03 380.428,1319.03 380.437,1319.03 380.446,1319.02 380.455,1319.02 380.464,1319.02 380.474,1319.01 380.483,1319.01 380.492,1319.01 380.501,1319.01 380.51,1319 380.52,1319 380.529,1319 380.538,1318.99 380.547,1318.99 380.556,1318.99 380.566,1318.98 380.575,1318.98 380.584,1318.98 380.593,1318.98 380.602,1318.97 380.611,1318.97 380.621,1318.97 380.63,1318.96 380.639,1318.96 380.648,1318.96 380.657,1318.95 380.667,1318.95 380.676,1318.95 380.685,1318.95 380.694,1318.94 380.703,1318.94 380.713,1318.94 380.722,1318.93 380.731,1318.93 380.74,1318.93 380.749,1318.92 380.758,1318.92 380.768,1318.92 380.777,1318.92 380.786,1318.91 380.795,1318.91 380.804,1318.91 380.814,1318.9 380.823,1318.9 380.832,1318.9 380.841,1318.89 380.85,1318.89 380.86,1318.89 380.869,1318.88 380.878,1318.88 380.887,1318.88 380.896,1318.88 380.906,1318.87 380.915,1318.87 380.924,1318.87 380.933,1318.86 380.942,1318.86 380.951,1318.86 380.961,1318.85 380.97,1318.85 380.979,1318.85 380.988,1318.85 380.997,1318.84 381.007,1318.84 381.016,1318.84 381.025,1318.83 381.034,1318.83 381.043,1318.83 381.053,1318.82 381.062,1318.82 381.071,1318.82 381.08,1318.82 381.089,1318.81 381.099,1318.81 381.108,1318.81 381.117,1318.8 381.126,1318.8 381.135,1318.8 381.144,1318.79 381.154,1318.79 381.163,1318.79 381.172,1318.79 381.181,1318.78 381.19,1318.78 381.2,1318.78 381.209,1318.77 381.218,1318.77 381.227,1318.77 381.236,1318.76 381.246,1318.76 381.255,1318.76 381.264,1318.75 381.273,1318.75 381.282,1318.75 381.291,1318.75 381.301,1318.74 381.31,1318.74 381.319,1318.74 381.328,1318.73 381.337,1318.73 381.347,1318.73 381.356,1318.72 381.365,1318.72 381.374,1318.72 381.383,1318.72 381.393,1318.71 381.402,1318.71 381.411,1318.71 381.42,1318.7 381.429,1318.7 381.439,1318.7 381.448,1318.69 381.457,1318.69 381.466,1318.69 381.475,1318.69 381.484,1318.68 381.494,1318.68 381.503,1318.68 381.512,1318.67 381.521,1318.67 381.53,1318.67 381.54,1318.66 381.549,1318.66 381.558,1318.66 381.567,1318.66 381.576,1318.65 381.586,1318.65 381.595,1318.65 381.604,1318.64 381.613,1318.64 381.622,1318.64 381.631,1318.63 381.641,1318.63 381.65,1318.63 381.659,1318.62 381.668,1318.62 381.677,1318.62 381.687,1318.62 381.696,1318.61 381.705,1318.61 381.714,1318.61 381.723,1318.6 381.733,1318.6 381.742,1318.6 381.751,1318.59 381.76,1318.59 381.769,1318.59 381.779,1318.59 381.788,1318.58 381.797,1318.58 381.806,1318.58 381.815,1318.57 381.824,1318.57 381.834,1318.57 381.843,1318.56 381.852,1318.56 381.861,1318.56 381.87,1318.56 381.88,1318.55 381.889,1318.55 381.898,1318.55 381.907,1318.54 381.916,1318.54 381.926,1318.54 381.935,1318.53 381.944,1318.53 381.953,1318.53 381.962,1318.53 381.971,1318.52 381.981,1318.52 381.99,1318.52 381.999,1318.51 382.008,1318.51 382.017,1318.51 382.027,1318.5 382.036,1318.5 382.045,1318.5 382.054,1318.5 382.063,1318.49 382.073,1318.49 382.082,1318.49 382.091,1318.48 382.1,1318.48 382.109,1318.48 382.119,1318.47 382.128,1318.47 382.137,1318.47 382.146,1318.46 382.155,1318.46 382.164,1318.46 382.174,1318.46 382.183,1318.45 382.192,1318.45 382.201,1318.45 382.21,1318.44 382.22,1318.44 382.229,1318.44 382.238,1318.43 382.247,1318.43 382.256,1318.43 382.266,1318.43 382.275,1318.42 382.284,1318.42 382.293,1318.42 382.302,1318.41 382.311,1318.41 382.321,1318.41 382.33,1318.4 382.339,1318.4 382.348,1318.4 382.357,1318.4 382.367,1318.39 382.376,1318.39 382.385,1318.39 382.394,1318.38 382.403,1318.38 382.413,1318.38 382.422,1318.37 382.431,1318.37 382.44,1318.37 382.449,1318.37 382.459,1318.36 382.468,1318.36 382.477,1318.36 382.486,1318.35 382.495,1318.35 382.504,1318.35 382.514,1318.34 382.523,1318.34 382.532,1318.34 382.541,1318.34 382.55,1318.33 382.56,1318.33 382.569,1318.33 382.578,1318.32 382.587,1318.32 382.596,1318.32 382.606,1318.31 382.615,1318.31 382.624,1318.31 382.633,1318.31 382.642,1318.3 382.651,1318.3 382.661,1318.3 382.67,1318.29 382.679,1318.29 382.688,1318.29 382.697,1318.28 382.707,1318.28 382.716,1318.28 382.725,1318.27 382.734,1318.27 382.743,1318.27 382.753,1318.27 382.762,1318.26 382.771,1318.26 382.78,1318.26 382.789,1318.25 382.799,1318.25 382.808,1318.25 382.817,1318.24 382.826,1318.24 382.835,1318.24 382.844,1318.24 382.854,1318.23 382.863,1318.23 382.872,1318.23 382.881,1318.22 382.89,1318.22 382.9,1318.22 382.909,1318.21 382.918,1318.21 382.927,1318.21 382.936,1318.21 382.946,1318.2 382.955,1318.2 382.964,1318.2 382.973,1318.19 382.982,1318.19 382.991,1318.19 383.001,1318.18 383.01,1318.18 383.019,1318.18 383.028,1318.18 383.037,1318.17 383.047,1318.17 383.056,1318.17 383.065,1318.16 383.074,1318.16 383.083,1318.16 383.093,1318.15 383.102,1318.15 383.111,1318.15 383.12,1318.15 383.129,1318.14 383.139,1318.14 383.148,1318.14 383.157,1318.13 383.166,1318.13 383.175,1318.13 383.184,1318.12 383.194,1318.12 383.203,1318.12 383.212,1318.12 383.221,1318.11 383.23,1318.11 383.24,1318.11 383.249,1318.1 383.258,1318.1 383.267,1318.1 383.276,1318.09 383.286,1318.09 383.295,1318.09 383.304,1318.09 383.313,1318.08 383.322,1318.08 383.332,1318.08 383.341,1318.07 383.35,1318.07 383.359,1318.07 383.368,1318.06 383.377,1318.06 383.387,1318.06 383.396,1318.06 383.405,1318.05 383.414,1318.05 383.423,1318.05 383.433,1318.04 383.442,1318.04 383.451,1318.04 383.46,1318.03 383.469,1318.03 383.479,1318.03 383.488,1318.03 383.497,1318.02 383.506,1318.02 383.515,1318.02 383.524,1318.01 383.534,1318.01 383.543,1318.01 383.552,1318 383.561,1318 383.57,1318 383.58,1317.99 383.589,1317.99 383.598,1317.99 383.607,1317.99 383.616,1317.98 383.626,1317.98 383.635,1317.98 383.644,1317.97 383.653,1317.97 383.662,1317.97 383.672,1317.96 383.681,1317.96 383.69,1317.96 383.699,1317.96 383.708,1317.95 383.717,1317.95 383.727,1317.95 383.736,1317.94 383.745,1317.94 383.754,1317.94 383.763,1317.93 383.773,1317.93 383.782,1317.93 383.791,1317.93 383.8,1317.92 383.809,1317.92 383.819,1317.92 383.828,1317.91 383.837,1317.91 383.846,1317.91 383.855,1317.9 383.864,1317.9 383.874,1317.9 383.883,1317.9 383.892,1317.89 383.901,1317.89 383.91,1317.89 383.92,1317.88 383.929,1317.88 383.938,1317.88 383.947,1317.87 383.956,1317.87 383.966,1317.87 383.975,1317.87 383.984,1317.86 383.993,1317.86 384.002,1317.86 384.012,1317.85 384.021,1317.85 384.03,1317.85 384.039,1317.84 384.048,1317.84 384.057,1317.84 384.067,1317.84 384.076,1317.83 384.085,1317.83 384.094,1317.83 384.103,1317.82 384.113,1317.82 384.122,1317.82 384.131,1317.81 384.14,1317.81 384.149,1317.81 384.159,1317.81 384.168,1317.8 384.177,1317.8 384.186,1317.8 384.195,1317.79 384.204,1317.79 384.214,1317.79 384.223,1317.78 384.232,1317.78 384.241,1317.78 384.25,1317.78 384.26,1317.77 384.269,1317.77 384.278,1317.77 384.287,1317.76 384.296,1317.76 384.306,1317.76 384.315,1317.75 384.324,1317.75 384.333,1317.75 384.342,1317.75 384.352,1317.74 384.361,1317.74 384.37,1317.74 384.379,1317.73 384.388,1317.73 384.397,1317.73 384.407,1317.72 384.416,1317.72 384.425,1317.72 384.434,1317.72 384.443,1317.71 384.453,1317.71 384.462,1317.71 384.471,1317.7 384.48,1317.7 384.489,1317.7 384.499,1317.69 384.508,1317.69 384.517,1317.69 384.526,1317.69 384.535,1317.68 384.544,1317.68 384.554,1317.68 384.563,1317.67 384.572,1317.67 384.581,1317.67 384.59,1317.66 384.6,1317.66 384.609,1317.66 384.618,1317.66 384.627,1317.65 384.636,1317.65 384.646,1317.65 384.655,1317.64 384.664,1317.64 384.673,1317.64 384.682,1317.63 384.692,1317.63 384.701,1317.63 384.71,1317.63 384.719,1317.62 384.728,1317.62 384.737,1317.62 384.747,1317.61 384.756,1317.61 384.765,1317.61 384.774,1317.6 384.783,1317.6 384.793,1317.6 384.802,1317.6 384.811,1317.59 384.82,1317.59 384.829,1317.59 384.839,1317.58 384.848,1317.58 384.857,1317.58 384.866,1317.57 384.875,1317.57 384.884,1317.57 384.894,1317.57 384.903,1317.56 384.912,1317.56 384.921,1317.56 384.93,1317.55 384.94,1317.55 384.949,1317.55 384.958,1317.54 384.967,1317.54 384.976,1317.54 384.986,1317.54 384.995,1317.53 385.004,1317.53 385.013,1317.53 385.022,1317.52 385.032,1317.52 385.041,1317.52 385.05,1317.51 385.059,1317.51 385.068,1317.51 385.077,1317.51 385.087,1317.5 385.096,1317.5 385.105,1317.5 385.114,1317.49 385.123,1317.49 385.133,1317.49 385.142,1317.48 385.151,1317.48 385.16,1317.48 385.169,1317.48 385.179,1317.47 385.188,1317.47 385.197,1317.47 385.206,1317.46 385.215,1317.46 385.224,1317.46 385.234,1317.45 385.243,1317.45 385.252,1317.45 385.261,1317.45 385.27,1317.44 385.28,1317.44 385.289,1317.44 385.298,1317.43 385.307,1317.43 385.316,1317.43 385.326,1317.42 385.335,1317.42 385.344,1317.42 385.353,1317.42 385.362,1317.41 385.372,1317.41 385.381,1317.41 385.39,1317.4 385.399,1317.4 385.408,1317.4 385.417,1317.39 385.427,1317.39 385.436,1317.39 385.445,1317.39 385.454,1317.38 385.463,1317.38 385.473,1317.38 385.482,1317.37 385.491,1317.37 385.5,1317.37 385.509,1317.37 385.519,1317.36 385.528,1317.36 385.537,1317.36 385.546,1317.35 385.555,1317.35 385.564,1317.35 385.574,1317.34 385.583,1317.34 385.592,1317.34 385.601,1317.34 385.61,1317.33 385.62,1317.33 385.629,1317.33 385.638,1317.32 385.647,1317.32 385.656,1317.32 385.666,1317.31 385.675,1317.31 385.684,1317.31 385.693,1317.31 385.702,1317.3 385.712,1317.3 385.721,1317.3 385.73,1317.29 385.739,1317.29 385.748,1317.29 385.757,1317.28 385.767,1317.28 385.776,1317.28 385.785,1317.28 385.794,1317.27 385.803,1317.27 385.813,1317.27 385.822,1317.26 385.831,1317.26 385.84,1317.26 385.849,1317.25 385.859,1317.25 385.868,1317.25 385.877,1317.25 385.886,1317.24 385.895,1317.24 385.905,1317.24 385.914,1317.23 385.923,1317.23 385.932,1317.23 385.941,1317.22 385.95,1317.22 385.96,1317.22 385.969,1317.22 385.978,1317.21 385.987,1317.21 385.996,1317.21 386.006,1317.2 386.015,1317.2 386.024,1317.2 386.033,1317.19 386.042,1317.19 386.052,1317.19 386.061,1317.19 386.07,1317.18 386.079,1317.18 386.088,1317.18 386.097,1317.17 386.107,1317.17 386.116,1317.17 386.125,1317.16 386.134,1317.16 386.143,1317.16 386.153,1317.16 386.162,1317.15 386.171,1317.15 386.18,1317.15 386.189,1317.14 386.199,1317.14 386.208,1317.14 386.217,1317.13 386.226,1317.13 386.235,1317.13 386.245,1317.13 386.254,1317.12 386.263,1317.12 386.272,1317.12 386.281,1317.11 386.29,1317.11 386.3,1317.11 386.309,1317.11 386.318,1317.1 386.327,1317.1 386.336,1317.1 386.346,1317.09 386.355,1317.09 386.364,1317.09 386.373,1317.08 386.382,1317.08 386.392,1317.08 386.401,1317.08 386.41,1317.07 386.419,1317.07 386.428,1317.07 386.437,1317.06 386.447,1317.06 386.456,1317.06 386.465,1317.05 386.474,1317.05 386.483,1317.05 386.493,1317.05 386.502,1317.04 386.511,1317.04 386.52,1317.04 386.529,1317.03 386.539,1317.03 386.548,1317.03 386.557,1317.02 386.566,1317.02 386.575,1317.02 386.585,1317.02 386.594,1317.01 386.603,1317.01 386.612,1317.01 386.621,1317 386.63,1317 386.64,1317 386.649,1316.99 386.658,1316.99 386.667,1316.99 386.676,1316.99 386.686,1316.98 386.695,1316.98 386.704,1316.98 386.713,1316.97 386.722,1316.97 386.732,1316.97 386.741,1316.97 386.75,1316.96 386.759,1316.96 386.768,1316.96 386.777,1316.95 386.787,1316.95 386.796,1316.95 386.805,1316.94 386.814,1316.94 386.823,1316.94 386.833,1316.94 386.842,1316.93 386.851,1316.93 386.86,1316.93 386.869,1316.92 386.879,1316.92 386.888,1316.92 386.897,1316.91 386.906,1316.91 386.915,1316.91 386.925,1316.91 386.934,1316.9 386.943,1316.9 386.952,1316.9 386.961,1316.89 386.97,1316.89 386.98,1316.89 386.989,1316.88 386.998,1316.88 387.007,1316.88 387.016,1316.88 387.026,1316.87 387.035,1316.87 387.044,1316.87 387.053,1316.86 387.062,1316.86 387.072,1316.86 387.081,1316.85 387.09,1316.85 387.099,1316.85 387.108,1316.85 387.117,1316.84 387.127,1316.84 387.136,1316.84 387.145,1316.83 387.154,1316.83 387.163,1316.83 387.173,1316.83 387.182,1316.82 387.191,1316.82 387.2,1316.82 387.209,1316.81 387.219,1316.81 387.228,1316.81 387.237,1316.8 387.246,1316.8 387.255,1316.8 387.265,1316.8 387.274,1316.79 387.283,1316.79 387.292,1316.79 387.301,1316.78 387.31,1316.78 387.32,1316.78 387.329,1316.77 387.338,1316.77 387.347,1316.77 387.356,1316.77 387.366,1316.76 387.375,1316.76 387.384,1316.76 387.393,1316.75 387.402,1316.75 387.412,1316.75 387.421,1316.74 387.43,1316.74 387.439,1316.74 387.448,1316.74 387.457,1316.73 387.467,1316.73 387.476,1316.73 387.485,1316.72 387.494,1316.72 387.503,1316.72 387.513,1316.72 387.522,1316.71 387.531,1316.71 387.54,1316.71 387.549,1316.7 387.559,1316.7 387.568,1316.7 387.577,1316.69 387.586,1316.69 387.595,1316.69 387.605,1316.69 387.614,1316.68 387.623,1316.68 387.632,1316.68 387.641,1316.67 387.65,1316.67 387.66,1316.67 387.669,1316.66 387.678,1316.66 387.687,1316.66 387.696,1316.66 387.706,1316.65 387.715,1316.65 387.724,1316.65 387.733,1316.64 387.742,1316.64 387.752,1316.64 387.761,1316.64 387.77,1316.63 387.779,1316.63 387.788,1316.63 387.797,1316.62 387.807,1316.62 387.816,1316.62 387.825,1316.61 387.834,1316.61 387.843,1316.61 387.853,1316.61 387.862,1316.6 387.871,1316.6 387.88,1316.6 387.889,1316.59 387.899,1316.59 387.908,1316.59 387.917,1316.58 387.926,1316.58 387.935,1316.58 387.945,1316.58 387.954,1316.57 387.963,1316.57 387.972,1316.57 387.981,1316.56 387.99,1316.56 388,1316.56 388.009,1316.55 388.018,1316.55 388.027,1316.55 388.036,1316.55 388.046,1316.54 388.055,1316.54 388.064,1316.54 388.073,1316.53 388.082,1316.53 388.092,1316.53 388.101,1316.53 388.11,1316.52 388.119,1316.52 388.128,1316.52 388.137,1316.51 388.147,1316.51 388.156,1316.51 388.165,1316.5 388.174,1316.5 388.183,1316.5 388.193,1316.5 388.202,1316.49 388.211,1316.49 388.22,1316.49 388.229,1316.48 388.239,1316.48 388.248,1316.48 388.257,1316.47 388.266,1316.47 388.275,1316.47 388.285,1316.47 388.294,1316.46 388.303,1316.46 388.312,1316.46 388.321,1316.45 388.33,1316.45 388.34,1316.45 388.349,1316.45 388.358,1316.44 388.367,1316.44 388.376,1316.44 388.386,1316.43 388.395,1316.43 388.404,1316.43 388.413,1316.42 388.422,1316.42 388.432,1316.42 388.441,1316.42 388.45,1316.41 388.459,1316.41 388.468,1316.41 388.478,1316.4 388.487,1316.4 388.496,1316.4 388.505,1316.4 388.514,1316.39 388.523,1316.39 388.533,1316.39 388.542,1316.38 388.551,1316.38 388.56,1316.38 388.569,1316.37 388.579,1316.37 388.588,1316.37 388.597,1316.37 388.606,1316.36 388.615,1316.36 388.625,1316.36 388.634,1316.35 388.643,1316.35 388.652,1316.35 388.661,1316.34 388.67,1316.34 388.68,1316.34 388.689,1316.34 388.698,1316.33 388.707,1316.33 388.716,1316.33 388.726,1316.32 388.735,1316.32 388.744,1316.32 388.753,1316.32 388.762,1316.31 388.772,1316.31 388.781,1316.31 388.79,1316.3 388.799,1316.3 388.808,1316.3 388.818,1316.29 388.827,1316.29 388.836,1316.29 388.845,1316.29 388.854,1316.28 388.863,1316.28 388.873,1316.28 388.882,1316.27 388.891,1316.27 388.9,1316.27 388.909,1316.27 388.919,1316.26 388.928,1316.26 388.937,1316.26 388.946,1316.25 388.955,1316.25 388.965,1316.25 388.974,1316.24 388.983,1316.24 388.992,1316.24 389.001,1316.24 389.01,1316.23 389.02,1316.23 389.029,1316.23 389.038,1316.22 389.047,1316.22 389.056,1316.22 389.066,1316.21 389.075,1316.21 389.084,1316.21 389.093,1316.21 389.102,1316.2 389.112,1316.2 389.121,1316.2 389.13,1316.19 389.139,1316.19 389.148,1316.19 389.158,1316.19 389.167,1316.18 389.176,1316.18 389.185,1316.18 389.194,1316.17 389.203,1316.17 389.213,1316.17 389.222,1316.16 389.231,1316.16 389.24,1316.16 389.249,1316.16 389.259,1316.15 389.268,1316.15 389.277,1316.15 389.286,1316.14 389.295,1316.14 389.305,1316.14 389.314,1316.14 389.323,1316.13 389.332,1316.13 389.341,1316.13 389.35,1316.12 389.36,1316.12 389.369,1316.12 389.378,1316.11 389.387,1316.11 389.396,1316.11 389.406,1316.11 389.415,1316.1 389.424,1316.1 389.433,1316.1 389.442,1316.09 389.452,1316.09 389.461,1316.09 389.47,1316.09 389.479,1316.08 389.488,1316.08 389.498,1316.08 389.507,1316.07 389.516,1316.07 389.525,1316.07 389.534,1316.06 389.543,1316.06 389.553,1316.06 389.562,1316.06 389.571,1316.05 389.58,1316.05 389.589,1316.05 389.599,1316.04 389.608,1316.04 389.617,1316.04 389.626,1316.04 389.635,1316.03 389.645,1316.03 389.654,1316.03 389.663,1316.02 389.672,1316.02 389.681,1316.02 389.69,1316.01 389.7,1316.01 389.709,1316.01 389.718,1316.01 389.727,1316 389.736,1316 389.746,1316 389.755,1315.99 389.764,1315.99 389.773,1315.99 389.782,1315.99 389.792,1315.98 389.801,1315.98 389.81,1315.98 389.819,1315.97 389.828,1315.97 389.838,1315.97 389.847,1315.96 389.856,1315.96 389.865,1315.96 389.874,1315.96 389.883,1315.95 389.893,1315.95 389.902,1315.95 389.911,1315.94 389.92,1315.94 389.929,1315.94 389.939,1315.94 389.948,1315.93 389.957,1315.93 389.966,1315.93 389.975,1315.92 389.985,1315.92 389.994,1315.92 390.003,1315.91 390.012,1315.91 390.021,1315.91 390.03,1315.91 390.04,1315.9 390.049,1315.9 390.058,1315.9 390.067,1315.89 390.076,1315.89 390.086,1315.89 390.095,1315.89 390.104,1315.88 390.113,1315.88 390.122,1315.88 390.132,1315.87 390.141,1315.87 390.15,1315.87 390.159,1315.86 390.168,1315.86 390.178,1315.86 390.187,1315.86 390.196,1315.85 390.205,1315.85 390.214,1315.85 390.223,1315.84 390.233,1315.84 390.242,1315.84 390.251,1315.84 390.26,1315.83 390.269,1315.83 390.279,1315.83 390.288,1315.82 390.297,1315.82 390.306,1315.82 390.315,1315.81 390.325,1315.81 390.334,1315.81 390.343,1315.81 390.352,1315.8 390.361,1315.8 390.37,1315.8 390.38,1315.79 390.389,1315.79 390.398,1315.79 390.407,1315.79 390.416,1315.78 390.426,1315.78 390.435,1315.78 390.444,1315.77 390.453,1315.77 390.462,1315.77 390.472,1315.76 390.481,1315.76 390.49,1315.76 390.499,1315.76 390.508,1315.75 390.518,1315.75 390.527,1315.75 390.536,1315.74 390.545,1315.74 390.554,1315.74 390.563,1315.74 390.573,1315.73 390.582,1315.73 390.591,1315.73 390.6,1315.72 390.609,1315.72 390.619,1315.72 390.628,1315.71 390.637,1315.71 390.646,1315.71 390.655,1315.71 390.665,1315.7 390.674,1315.7 390.683,1315.7 390.692,1315.69 390.701,1315.69 390.711,1315.69 390.72,1315.69 390.729,1315.68 390.738,1315.68 390.747,1315.68 390.756,1315.67 390.766,1315.67 390.775,1315.67 390.784,1315.67 390.793,1315.66 390.802,1315.66 390.812,1315.66 390.821,1315.65 390.83,1315.65 390.839,1315.65 390.848,1315.64 390.858,1315.64 390.867,1315.64 390.876,1315.64 390.885,1315.63 390.894,1315.63 390.903,1315.63 390.913,1315.62 390.922,1315.62 390.931,1315.62 390.94,1315.62 390.949,1315.61 390.959,1315.61 390.968,1315.61 390.977,1315.6 390.986,1315.6 390.995,1315.6 391.005,1315.59 391.014,1315.59 391.023,1315.59 391.032,1315.59 391.041,1315.58 391.051,1315.58 391.06,1315.58 391.069,1315.57 391.078,1315.57 391.087,1315.57 391.096,1315.57 391.106,1315.56 391.115,1315.56 391.124,1315.56 391.133,1315.55 391.142,1315.55 391.152,1315.55 391.161,1315.55 391.17,1315.54 391.179,1315.54 391.188,1315.54 391.198,1315.53 391.207,1315.53 391.216,1315.53 391.225,1315.52 391.234,1315.52 391.243,1315.52 391.253,1315.52 391.262,1315.51 391.271,1315.51 391.28,1315.51 391.289,1315.5 391.299,1315.5 391.308,1315.5 391.317,1315.5 391.326,1315.49 391.335,1315.49 391.345,1315.49 391.354,1315.48 391.363,1315.48 391.372,1315.48 391.381,1315.48 391.391,1315.47 391.4,1315.47 391.409,1315.47 391.418,1315.46 391.427,1315.46 391.436,1315.46 391.446,1315.45 391.455,1315.45 391.464,1315.45 391.473,1315.45 391.482,1315.44 391.492,1315.44 391.501,1315.44 391.51,1315.43 391.519,1315.43 391.528,1315.43 391.538,1315.43 391.547,1315.42 391.556,1315.42 391.565,1315.42 391.574,1315.41 391.583,1315.41 391.593,1315.41 391.602,1315.41 391.611,1315.4 391.62,1315.4 391.629,1315.4 391.639,1315.39 391.648,1315.39 391.657,1315.39 391.666,1315.38 391.675,1315.38 391.685,1315.38 391.694,1315.38 391.703,1315.37 391.712,1315.37 391.721,1315.37 391.731,1315.36 391.74,1315.36 391.749,1315.36 391.758,1315.36 391.767,1315.35 391.776,1315.35 391.786,1315.35 391.795,1315.34 391.804,1315.34 391.813,1315.34 391.822,1315.34 391.832,1315.33 391.841,1315.33 391.85,1315.33 391.859,1315.32 391.868,1315.32 391.878,1315.32 391.887,1315.31 391.896,1315.31 391.905,1315.31 391.914,1315.31 391.923,1315.3 391.933,1315.3 391.942,1315.3 391.951,1315.29 391.96,1315.29 391.969,1315.29 391.979,1315.29 391.988,1315.28 391.997,1315.28 392.006,1315.28 392.015,1315.27 392.025,1315.27 392.034,1315.27 392.043,1315.27 392.052,1315.26 392.061,1315.26 392.071,1315.26 392.08,1315.25 392.089,1315.25 392.098,1315.25 392.107,1315.24 392.116,1315.24 392.126,1315.24 392.135,1315.24 392.144,1315.23 392.153,1315.23 392.162,1315.23 392.172,1315.22 392.181,1315.22 392.19,1315.22 392.199,1315.22 392.208,1315.21 392.218,1315.21 392.227,1315.21 392.236,1315.2 392.245,1315.2 392.254,1315.2 392.263,1315.2 392.273,1315.19 392.282,1315.19 392.291,1315.19 392.3,1315.18 392.309,1315.18 392.319,1315.18 392.328,1315.18 392.337,1315.17 392.346,1315.17 392.355,1315.17 392.365,1315.16 392.374,1315.16 392.383,1315.16 392.392,1315.15 392.401,1315.15 392.411,1315.15 392.42,1315.15 392.429,1315.14 392.438,1315.14 392.447,1315.14 392.456,1315.13 392.466,1315.13 392.475,1315.13 392.484,1315.13 392.493,1315.12 392.502,1315.12 392.512,1315.12 392.521,1315.11 392.53,1315.11 392.539,1315.11 392.548,1315.11 392.558,1315.1 392.567,1315.1 392.576,1315.1 392.585,1315.09 392.594,1315.09 392.603,1315.09 392.613,1315.09 392.622,1315.08 392.631,1315.08 392.64,1315.08 392.649,1315.07 392.659,1315.07 392.668,1315.07 392.677,1315.06 392.686,1315.06 392.695,1315.06 392.705,1315.06 392.714,1315.05 392.723,1315.05 392.732,1315.05 392.741,1315.04 392.751,1315.04 392.76,1315.04 392.769,1315.04 392.778,1315.03 392.787,1315.03 392.796,1315.03 392.806,1315.02 392.815,1315.02 392.824,1315.02 392.833,1315.02 392.842,1315.01 392.852,1315.01 392.861,1315.01 392.87,1315 392.879,1315 392.888,1315 392.898,1315 392.907,1314.99 392.916,1314.99 392.925,1314.99 392.934,1314.98 392.943,1314.98 392.953,1314.98 392.962,1314.98 392.971,1314.97 392.98,1314.97 392.989,1314.97 392.999,1314.96 393.008,1314.96 393.017,1314.96 393.026,1314.95 393.035,1314.95 393.045,1314.95 393.054,1314.95 393.063,1314.94 393.072,1314.94 393.081,1314.94 393.091,1314.93 393.1,1314.93 393.109,1314.93 393.118,1314.93 393.127,1314.92 393.136,1314.92 393.146,1314.92 393.155,1314.91 393.164,1314.91 393.173,1314.91 393.182,1314.91 393.192,1314.9 393.201,1314.9 393.21,1314.9 393.219,1314.89 393.228,1314.89 393.238,1314.89 393.247,1314.89 393.256,1314.88 393.265,1314.88 393.274,1314.88 393.284,1314.87 393.293,1314.87 393.302,1314.87 393.311,1314.87 393.32,1314.86 393.329,1314.86 393.339,1314.86 393.348,1314.85 393.357,1314.85 393.366,1314.85 393.375,1314.85 393.385,1314.84 393.394,1314.84 393.403,1314.84 393.412,1314.83 393.421,1314.83 393.431,1314.83 393.44,1314.82 393.449,1314.82 393.458,1314.82 393.467,1314.82 393.476,1314.81 393.486,1314.81 393.495,1314.81 393.504,1314.8 393.513,1314.8 393.522,1314.8 393.532,1314.8 393.541,1314.79 393.55,1314.79 393.559,1314.79 393.568,1314.78 393.578,1314.78 393.587,1314.78 393.596,1314.78 393.605,1314.77 393.614,1314.77 393.624,1314.77 393.633,1314.76 393.642,1314.76 393.651,1314.76 393.66,1314.76 393.669,1314.75 393.679,1314.75 393.688,1314.75 393.697,1314.74 393.706,1314.74 393.715,1314.74 393.725,1314.74 393.734,1314.73 393.743,1314.73 393.752,1314.73 393.761,1314.72 393.771,1314.72 393.78,1314.72 393.789,1314.72 393.798,1314.71 393.807,1314.71 393.816,1314.71 393.826,1314.7 393.835,1314.7 393.844,1314.7 393.853,1314.7 393.862,1314.69 393.872,1314.69 393.881,1314.69 393.89,1314.68 393.899,1314.68 393.908,1314.68 393.918,1314.67 393.927,1314.67 393.936,1314.67 393.945,1314.67 393.954,1314.66 393.964,1314.66 393.973,1314.66 393.982,1314.65 393.991,1314.65 394,1314.65 394.009,1314.65 394.019,1314.64 394.028,1314.64 394.037,1314.64 394.046,1314.63 394.055,1314.63 394.065,1314.63 394.074,1314.63 394.083,1314.62 394.092,1314.62 394.101,1314.62 394.111,1314.61 394.12,1314.61 394.129,1314.61 394.138,1314.61 394.147,1314.6 394.156,1314.6 394.166,1314.6 394.175,1314.59 394.184,1314.59 394.193,1314.59 394.202,1314.59 394.212,1314.58 394.221,1314.58 394.23,1314.58 394.239,1314.57 394.248,1314.57 394.258,1314.57 394.267,1314.57 394.276,1314.56 394.285,1314.56 394.294,1314.56 394.304,1314.55 394.313,1314.55 394.322,1314.55 394.331,1314.55 394.34,1314.54 394.349,1314.54 394.359,1314.54 394.368,1314.53 394.377,1314.53 394.386,1314.53 394.395,1314.53 394.405,1314.52 394.414,1314.52 394.423,1314.52 394.432,1314.51 394.441,1314.51 394.451,1314.51 394.46,1314.51 394.469,1314.5 394.478,1314.5 394.487,1314.5 394.496,1314.49 394.506,1314.49 394.515,1314.49 394.524,1314.49 394.533,1314.48 394.542,1314.48 394.552,1314.48 394.561,1314.47 394.57,1314.47 394.579,1314.47 394.588,1314.47 394.598,1314.46 394.607,1314.46 394.616,1314.46 394.625,1314.45 394.634,1314.45 394.644,1314.45 394.653,1314.45 394.662,1314.44 394.671,1314.44 394.68,1314.44 394.689,1314.43 394.699,1314.43 394.708,1314.43 394.717,1314.42 394.726,1314.42 394.735,1314.42 394.745,1314.42 394.754,1314.41 394.763,1314.41 394.772,1314.41 394.781,1314.4 394.791,1314.4 394.8,1314.4 394.809,1314.4 394.818,1314.39 394.827,1314.39 394.836,1314.39 394.846,1314.38 394.855,1314.38 394.864,1314.38 394.873,1314.38 394.882,1314.37 394.892,1314.37 394.901,1314.37 394.91,1314.36 394.919,1314.36 394.928,1314.36 394.938,1314.36 394.947,1314.35 394.956,1314.35 394.965,1314.35 394.974,1314.34 394.984,1314.34 394.993,1314.34 395.002,1314.34 395.011,1314.33 395.02,1314.33 395.029,1314.33 395.039,1314.32 395.048,1314.32 395.057,1314.32 395.066,1314.32 395.075,1314.31 395.085,1314.31 395.094,1314.31 395.103,1314.3 395.112,1314.3 395.121,1314.3 395.131,1314.3 395.14,1314.29 395.149,1314.29 395.158,1314.29 395.167,1314.28 395.176,1314.28 395.186,1314.28 395.195,1314.28 395.204,1314.27 395.213,1314.27 395.222,1314.27 395.232,1314.26 395.241,1314.26 395.25,1314.26 395.259,1314.26 395.268,1314.25 395.278,1314.25 395.287,1314.25 395.296,1314.24 395.305,1314.24 395.314,1314.24 395.324,1314.24 395.333,1314.23 395.342,1314.23 395.351,1314.23 395.36,1314.22 395.369,1314.22 395.379,1314.22 395.388,1314.22 395.397,1314.21 395.406,1314.21 395.415,1314.21 395.425,1314.2 395.434,1314.2 395.443,1314.2 395.452,1314.2 395.461,1314.19 395.471,1314.19 395.48,1314.19 395.489,1314.18 395.498,1314.18 395.507,1314.18 395.516,1314.18 395.526,1314.17 395.535,1314.17 395.544,1314.17 395.553,1314.16 395.562,1314.16 395.572,1314.16 395.581,1314.16 395.59,1314.15 395.599,1314.15 395.608,1314.15 395.618,1314.14 395.627,1314.14 395.636,1314.14 395.645,1314.14 395.654,1314.13 395.664,1314.13 395.673,1314.13 395.682,1314.12 395.691,1314.12 395.7,1314.12 395.709,1314.12 395.719,1314.11 395.728,1314.11 395.737,1314.11 395.746,1314.1 395.755,1314.1 395.765,1314.1 395.774,1314.1 395.783,1314.09 395.792,1314.09 395.801,1314.09 395.811,1314.09 395.82,1314.08 395.829,1314.08 395.838,1314.08 395.847,1314.07 395.857,1314.07 395.866,1314.07 395.875,1314.07 395.884,1314.06 395.893,1314.06 395.902,1314.06 395.912,1314.05 395.921,1314.05 395.93,1314.05 395.939,1314.05 395.948,1314.04 395.958,1314.04 395.967,1314.04 395.976,1314.03 395.985,1314.03 395.994,1314.03 396.004,1314.03 396.013,1314.02 396.022,1314.02 396.031,1314.02 396.04,1314.01 396.049,1314.01 396.059,1314.01 396.068,1314.01 396.077,1314 396.086,1314 396.095,1314 396.105,1313.99 396.114,1313.99 396.123,1313.99 396.132,1313.99 396.141,1313.98 396.151,1313.98 396.16,1313.98 396.169,1313.97 396.178,1313.97 396.187,1313.97 396.197,1313.97 396.206,1313.96 396.215,1313.96 396.224,1313.96 396.233,1313.95 396.242,1313.95 396.252,1313.95 396.261,1313.95 396.27,1313.94 396.279,1313.94 396.288,1313.94 396.298,1313.93 396.307,1313.93 396.316,1313.93 396.325,1313.93 396.334,1313.92 396.344,1313.92 396.353,1313.92 396.362,1313.91 396.371,1313.91 396.38,1313.91 396.389,1313.91 396.399,1313.9 396.408,1313.9 396.417,1313.9 396.426,1313.89 396.435,1313.89 396.445,1313.89 396.454,1313.89 396.463,1313.88 396.472,1313.88 396.481,1313.88 396.491,1313.87 396.5,1313.87 396.509,1313.87 396.518,1313.87 396.527,1313.86 396.537,1313.86 396.546,1313.86 396.555,1313.85 396.564,1313.85 396.573,1313.85 396.582,1313.85 396.592,1313.84 396.601,1313.84 396.61,1313.84 396.619,1313.84 396.628,1313.83 396.638,1313.83 396.647,1313.83 396.656,1313.82 396.665,1313.82 396.674,1313.82 396.684,1313.82 396.693,1313.81 396.702,1313.81 396.711,1313.81 396.72,1313.8 396.729,1313.8 396.739,1313.8 396.748,1313.8 396.757,1313.79 396.766,1313.79 396.775,1313.79 396.785,1313.78 396.794,1313.78 396.803,1313.78 396.812,1313.78 396.821,1313.77 396.831,1313.77 396.84,1313.77 396.849,1313.76 396.858,1313.76 396.867,1313.76 396.877,1313.76 396.886,1313.75 396.895,1313.75 396.904,1313.75 396.913,1313.74 396.922,1313.74 396.932,1313.74 396.941,1313.74 396.95,1313.73 396.959,1313.73 396.968,1313.73 396.978,1313.72 396.987,1313.72 396.996,1313.72 397.005,1313.72 397.014,1313.71 397.024,1313.71 397.033,1313.71 397.042,1313.7 397.051,1313.7 397.06,1313.7 397.069,1313.7 397.079,1313.69 397.088,1313.69 397.097,1313.69 397.106,1313.69 397.115,1313.68 397.125,1313.68 397.134,1313.68 397.143,1313.67 397.152,1313.67 397.161,1313.67 397.171,1313.67 397.18,1313.66 397.189,1313.66 397.198,1313.66 397.207,1313.65 397.217,1313.65 397.226,1313.65 397.235,1313.65 397.244,1313.64 397.253,1313.64 397.262,1313.64 397.272,1313.63 397.281,1313.63 397.29,1313.63 397.299,1313.63 397.308,1313.62 397.318,1313.62 397.327,1313.62 397.336,1313.61 397.345,1313.61 397.354,1313.61 397.364,1313.61 397.373,1313.6 397.382,1313.6 397.391,1313.6 397.4,1313.59 397.409,1313.59 397.419,1313.59 397.428,1313.59 397.437,1313.58 397.446,1313.58 397.455,1313.58 397.465,1313.58 397.474,1313.57 397.483,1313.57 397.492,1313.57 397.501,1313.56 397.511,1313.56 397.52,1313.56 397.529,1313.56 397.538,1313.55 397.547,1313.55 397.557,1313.55 397.566,1313.54 397.575,1313.54 397.584,1313.54 397.593,1313.54 397.602,1313.53 397.612,1313.53 397.621,1313.53 397.63,1313.52 397.639,1313.52 397.648,1313.52 397.658,1313.52 397.667,1313.51 397.676,1313.51 397.685,1313.51 397.694,1313.5 397.704,1313.5 397.713,1313.5 397.722,1313.5 397.731,1313.49 397.74,1313.49 397.749,1313.49 397.759,1313.49 397.768,1313.48 397.777,1313.48 397.786,1313.48 397.795,1313.47 397.805,1313.47 397.814,1313.47 397.823,1313.47 397.832,1313.46 397.841,1313.46 397.851,1313.46 397.86,1313.45 397.869,1313.45 397.878,1313.45 397.887,1313.45 397.897,1313.44 397.906,1313.44 397.915,1313.44 397.924,1313.43 397.933,1313.43 397.942,1313.43 397.952,1313.43 397.961,1313.42 397.97,1313.42 397.979,1313.42 397.988,1313.41 397.998,1313.41 398.007,1313.41 398.016,1313.41 398.025,1313.4 398.034,1313.4 398.044,1313.4 398.053,1313.4 398.062,1313.39 398.071,1313.39 398.08,1313.39 398.09,1313.38 398.099,1313.38 398.108,1313.38 398.117,1313.38 398.126,1313.37 398.135,1313.37 398.145,1313.37 398.154,1313.36 398.163,1313.36 398.172,1313.36 398.181,1313.36 398.191,1313.35 398.2,1313.35 398.209,1313.35 398.218,1313.34 398.227,1313.34 398.237,1313.34 398.246,1313.34 398.255,1313.33 398.264,1313.33 398.273,1313.33 398.282,1313.33 398.292,1313.32 398.301,1313.32 398.31,1313.32 398.319,1313.31 398.328,1313.31 398.338,1313.31 398.347,1313.31 398.356,1313.3 398.365,1313.3 398.374,1313.3 398.384,1313.29 398.393,1313.29 398.402,1313.29 398.411,1313.29 398.42,1313.28 398.43,1313.28 398.439,1313.28 398.448,1313.27 398.457,1313.27 398.466,1313.27 398.475,1313.27 398.485,1313.26 398.494,1313.26 398.503,1313.26 398.512,1313.26 398.521,1313.25 398.531,1313.25 398.54,1313.25 398.549,1313.24 398.558,1313.24 398.567,1313.24 398.577,1313.24 398.586,1313.23 398.595,1313.23 398.604,1313.23 398.613,1313.22 398.622,1313.22 398.632,1313.22 398.641,1313.22 398.65,1313.21 398.659,1313.21 398.668,1313.21 398.678,1313.2 398.687,1313.2 398.696,1313.2 398.705,1313.2 398.714,1313.19 398.724,1313.19 398.733,1313.19 398.742,1313.19 398.751,1313.18 398.76,1313.18 398.77,1313.18 398.779,1313.17 398.788,1313.17 398.797,1313.17 398.806,1313.17 398.815,1313.16 398.825,1313.16 398.834,1313.16 398.843,1313.15 398.852,1313.15 398.861,1313.15 398.871,1313.15 398.88,1313.14 398.889,1313.14 398.898,1313.14 398.907,1313.13 398.917,1313.13 398.926,1313.13 398.935,1313.13 398.944,1313.12 398.953,1313.12 398.962,1313.12 398.972,1313.12 398.981,1313.11 398.99,1313.11 398.999,1313.11 399.008,1313.1 399.018,1313.1 399.027,1313.1 399.036,1313.1 399.045,1313.09 399.054,1313.09 399.064,1313.09 399.073,1313.08 399.082,1313.08 399.091,1313.08 399.1,1313.08 399.11,1313.07 399.119,1313.07 399.128,1313.07 399.137,1313.07 399.146,1313.06 399.155,1313.06 399.165,1313.06 399.174,1313.05 399.183,1313.05 399.192,1313.05 399.201,1313.05 399.211,1313.04 399.22,1313.04 399.229,1313.04 399.238,1313.03 399.247,1313.03 399.257,1313.03 399.266,1313.03 399.275,1313.02 399.284,1313.02 399.293,1313.02 399.302,1313.02 399.312,1313.01 399.321,1313.01 399.33,1313.01 399.339,1313 399.348,1313 399.358,1313 399.367,1313 399.376,1312.99 399.385,1312.99 399.394,1312.99 399.404,1312.98 399.413,1312.98 399.422,1312.98 399.431,1312.98 399.44,1312.97 399.45,1312.97 399.459,1312.97 399.468,1312.97 399.477,1312.96 399.486,1312.96 399.495,1312.96 399.505,1312.95 399.514,1312.95 399.523,1312.95 399.532,1312.95 399.541,1312.94 399.551,1312.94 399.56,1312.94 399.569,1312.93 399.578,1312.93 399.587,1312.93 399.597,1312.93 399.606,1312.92 399.615,1312.92 399.624,1312.92 399.633,1312.92 399.642,1312.91 399.652,1312.91 399.661,1312.91 399.67,1312.9 399.679,1312.9 399.688,1312.9 399.698,1312.9 399.707,1312.89 399.716,1312.89 399.725,1312.89 399.734,1312.88 399.744,1312.88 399.753,1312.88 399.762,1312.88 399.771,1312.87 399.78,1312.87 399.79,1312.87 399.799,1312.87 399.808,1312.86 399.817,1312.86 399.826,1312.86 399.835,1312.85 399.845,1312.85 399.854,1312.85 399.863,1312.85 399.872,1312.84 399.881,1312.84 399.891,1312.84 399.9,1312.83 399.909,1312.83 399.918,1312.83 399.927,1312.83 399.937,1312.82 399.946,1312.82 399.955,1312.82 399.964,1312.82 399.973,1312.81 399.982,1312.81 399.992,1312.81 400.001,1312.8 400.01,1312.8 400.019,1312.8 400.028,1312.8 400.038,1312.79 400.047,1312.79 400.056,1312.79 400.065,1312.78 400.074,1312.78 400.084,1312.78 400.093,1312.78 400.102,1312.77 400.111,1312.77 400.12,1312.77 400.13,1312.77 400.139,1312.76 400.148,1312.76 400.157,1312.76 400.166,1312.75 400.175,1312.75 400.185,1312.75 400.194,1312.75 400.203,1312.74 400.212,1312.74 400.221,1312.74 400.231,1312.74 400.24,1312.73 400.249,1312.73 400.258,1312.73 400.267,1312.72 400.277,1312.72 400.286,1312.72 400.295,1312.72 400.304,1312.71 400.313,1312.71 400.322,1312.71 400.332,1312.7 400.341,1312.7 400.35,1312.7 400.359,1312.7 400.368,1312.69 400.378,1312.69 400.387,1312.69 400.396,1312.69 400.405,1312.68 400.414,1312.68 400.424,1312.68 400.433,1312.67 400.442,1312.67 400.451,1312.67 400.46,1312.67 400.47,1312.66 400.479,1312.66 400.488,1312.66 400.497,1312.65 400.506,1312.65 400.515,1312.65 400.525,1312.65 400.534,1312.64 400.543,1312.64 400.552,1312.64 400.561,1312.64 400.571,1312.63 400.58,1312.63 400.589,1312.63 400.598,1312.62 400.607,1312.62 400.617,1312.62 400.626,1312.62 400.635,1312.61 400.644,1312.61 400.653,1312.61 400.663,1312.61 400.672,1312.6 400.681,1312.6 400.69,1312.6 400.699,1312.59 400.708,1312.59 400.718,1312.59 400.727,1312.59 400.736,1312.58 400.745,1312.58 400.754,1312.58 400.764,1312.57 400.773,1312.57 400.782,1312.57 400.791,1312.57 400.8,1312.56 400.81,1312.56 400.819,1312.56 400.828,1312.56 400.837,1312.55 400.846,1312.55 400.855,1312.55 400.865,1312.54 400.874,1312.54 400.883,1312.54 400.892,1312.54 400.901,1312.53 400.911,1312.53 400.92,1312.53 400.929,1312.53 400.938,1312.52 400.947,1312.52 400.957,1312.52 400.966,1312.51 400.975,1312.51 400.984,1312.51 400.993,1312.51 401.003,1312.5 401.012,1312.5 401.021,1312.5 401.03,1312.5 401.039,1312.49 401.048,1312.49 401.058,1312.49 401.067,1312.48 401.076,1312.48 401.085,1312.48 401.094,1312.48 401.104,1312.47 401.113,1312.47 401.122,1312.47 401.131,1312.46 401.14,1312.46 401.15,1312.46 401.159,1312.46 401.168,1312.45 401.177,1312.45 401.186,1312.45 401.195,1312.45 401.205,1312.44 401.214,1312.44 401.223,1312.44 401.232,1312.43 401.241,1312.43 401.251,1312.43 401.26,1312.43 401.269,1312.42 401.278,1312.42 401.287,1312.42 401.297,1312.42 401.306,1312.41 401.315,1312.41 401.324,1312.41 401.333,1312.4 401.343,1312.4 401.352,1312.4 401.361,1312.4 401.37,1312.39 401.379,1312.39 401.388,1312.39 401.398,1312.39 401.407,1312.38 401.416,1312.38 401.425,1312.38 401.434,1312.37 401.444,1312.37 401.453,1312.37 401.462,1312.37 401.471,1312.36 401.48,1312.36 401.49,1312.36 401.499,1312.36 401.508,1312.35 401.517,1312.35 401.526,1312.35 401.535,1312.34 401.545,1312.34 401.554,1312.34 401.563,1312.34 401.572,1312.33 401.581,1312.33 401.591,1312.33 401.6,1312.33 401.609,1312.32 401.618,1312.32 401.627,1312.32 401.637,1312.31 401.646,1312.31 401.655,1312.31 401.664,1312.31 401.673,1312.3 401.683,1312.3 401.692,1312.3 401.701,1312.29 401.71,1312.29 401.719,1312.29 401.728,1312.29 401.738,1312.28 401.747,1312.28 401.756,1312.28 401.765,1312.28 401.774,1312.27 401.784,1312.27 401.793,1312.27 401.802,1312.26 401.811,1312.26 401.82,1312.26 401.83,1312.26 401.839,1312.25 401.848,1312.25 401.857,1312.25 401.866,1312.25 401.875,1312.24 401.885,1312.24 401.894,1312.24 401.903,1312.23 401.912,1312.23 401.921,1312.23 401.931,1312.23 401.94,1312.22 401.949,1312.22 401.958,1312.22 401.967,1312.22 401.977,1312.21 401.986,1312.21 401.995,1312.21 402.004,1312.2 402.013,1312.2 402.023,1312.2 402.032,1312.2 402.041,1312.19 402.05,1312.19 402.059,1312.19 402.068,1312.19 402.078,1312.18 402.087,1312.18 402.096,1312.18 402.105,1312.17 402.114,1312.17 402.124,1312.17 402.133,1312.17 402.142,1312.16 402.151,1312.16 402.16,1312.16 402.17,1312.16 402.179,1312.15 402.188,1312.15 402.197,1312.15 402.206,1312.14 402.215,1312.14 402.225,1312.14 402.234,1312.14 402.243,1312.13 402.252,1312.13 402.261,1312.13 402.271,1312.13 402.28,1312.12 402.289,1312.12 402.298,1312.12 402.307,1312.11 402.317,1312.11 402.326,1312.11 402.335,1312.11 402.344,1312.1 402.353,1312.1 402.363,1312.1 402.372,1312.1 402.381,1312.09 402.39,1312.09 402.399,1312.09 402.408,1312.08 402.418,1312.08 402.427,1312.08 402.436,1312.08 402.445,1312.07 402.454,1312.07 402.464,1312.07 402.473,1312.07 402.482,1312.06 402.491,1312.06 402.5,1312.06 402.51,1312.06 402.519,1312.05 402.528,1312.05 402.537,1312.05 402.546,1312.04 402.555,1312.04 402.565,1312.04 402.574,1312.04 402.583,1312.03 402.592,1312.03 402.601,1312.03 402.611,1312.03 402.62,1312.02 402.629,1312.02 402.638,1312.02 402.647,1312.01 402.657,1312.01 402.666,1312.01 402.675,1312.01 402.684,1312 402.693,1312 402.703,1312 402.712,1312 402.721,1311.99 402.73,1311.99 402.739,1311.99 402.748,1311.98 402.758,1311.98 402.767,1311.98 402.776,1311.98 402.785,1311.97 402.794,1311.97 402.804,1311.97 402.813,1311.97 402.822,1311.96 402.831,1311.96 402.84,1311.96 402.85,1311.95 402.859,1311.95 402.868,1311.95 402.877,1311.95 402.886,1311.94 402.895,1311.94 402.905,1311.94 402.914,1311.94 402.923,1311.93 402.932,1311.93 402.941,1311.93 402.951,1311.92 402.96,1311.92 402.969,1311.92 402.978,1311.92 402.987,1311.91 402.997,1311.91 403.006,1311.91 403.015,1311.91 403.024,1311.9 403.033,1311.9 403.043,1311.9 403.052,1311.89 403.061,1311.89 403.07,1311.89 403.079,1311.89 403.088,1311.88 403.098,1311.88 403.107,1311.88 403.116,1311.88 403.125,1311.87 403.134,1311.87 403.144,1311.87 403.153,1311.87 403.162,1311.86 403.171,1311.86 403.18,1311.86 403.19,1311.85 403.199,1311.85 403.208,1311.85 403.217,1311.85 403.226,1311.84 403.236,1311.84 403.245,1311.84 403.254,1311.84 403.263,1311.83 403.272,1311.83 403.281,1311.83 403.291,1311.82 403.3,1311.82 403.309,1311.82 403.318,1311.82 403.327,1311.81 403.337,1311.81 403.346,1311.81 403.355,1311.81 403.364,1311.8 403.373,1311.8 403.383,1311.8 403.392,1311.79 403.401,1311.79 403.41,1311.79 403.419,1311.79 403.428,1311.78 403.438,1311.78 403.447,1311.78 403.456,1311.78 403.465,1311.77 403.474,1311.77 403.484,1311.77 403.493,1311.77 403.502,1311.76 403.511,1311.76 403.52,1311.76 403.53,1311.75 403.539,1311.75 403.548,1311.75 403.557,1311.75 403.566,1311.74 403.576,1311.74 403.585,1311.74 403.594,1311.74 403.603,1311.73 403.612,1311.73 403.621,1311.73 403.631,1311.72 403.64,1311.72 403.649,1311.72 403.658,1311.72 403.667,1311.71 403.677,1311.71 403.686,1311.71 403.695,1311.71 403.704,1311.7 403.713,1311.7 403.723,1311.7 403.732,1311.7 403.741,1311.69 403.75,1311.69 403.759,1311.69 403.768,1311.68 403.778,1311.68 403.787,1311.68 403.796,1311.68 403.805,1311.67 403.814,1311.67 403.824,1311.67 403.833,1311.67 403.842,1311.66 403.851,1311.66 403.86,1311.66 403.87,1311.65 403.879,1311.65 403.888,1311.65 403.897,1311.65 403.906,1311.64 403.916,1311.64 403.925,1311.64 403.934,1311.64 403.943,1311.63 403.952,1311.63 403.961,1311.63 403.971,1311.63 403.98,1311.62 403.989,1311.62 403.998,1311.62 404.007,1311.61 404.017,1311.61 404.026,1311.61 404.035,1311.61 404.044,1311.6 404.053,1311.6 404.063,1311.6 404.072,1311.6 404.081,1311.59 404.09,1311.59 404.099,1311.59 404.108,1311.58 404.118,1311.58 404.127,1311.58 404.136,1311.58 404.145,1311.57 404.154,1311.57 404.164,1311.57 404.173,1311.57 404.182,1311.56 404.191,1311.56 404.2,1311.56 404.21,1311.56 404.219,1311.55 404.228,1311.55 404.237,1311.55 404.246,1311.54 404.256,1311.54 404.265,1311.54 404.274,1311.54 404.283,1311.53 404.292,1311.53 404.301,1311.53 404.311,1311.53 404.32,1311.52 404.329,1311.52 404.338,1311.52 404.347,1311.52 404.357,1311.51 404.366,1311.51 404.375,1311.51 404.384,1311.5 404.393,1311.5 404.403,1311.5 404.412,1311.5 404.421,1311.49 404.43,1311.49 404.439,1311.49 404.448,1311.49 404.458,1311.48 404.467,1311.48 404.476,1311.48 404.485,1311.47 404.494,1311.47 404.504,1311.47 404.513,1311.47 404.522,1311.46 404.531,1311.46 404.54,1311.46 404.55,1311.46 404.559,1311.45 404.568,1311.45 404.577,1311.45 404.586,1311.45 404.596,1311.44 404.605,1311.44 404.614,1311.44 404.623,1311.43 404.632,1311.43 404.641,1311.43 404.651,1311.43 404.66,1311.42 404.669,1311.42 404.678,1311.42 404.687,1311.42 404.697,1311.41 404.706,1311.41 404.715,1311.41 404.724,1311.41 404.733,1311.4 404.743,1311.4 404.752,1311.4 404.761,1311.39 404.77,1311.39 404.779,1311.39 404.788,1311.39 404.798,1311.38 404.807,1311.38 404.816,1311.38 404.825,1311.38 404.834,1311.37 404.844,1311.37 404.853,1311.37 404.862,1311.37 404.871,1311.36 404.88,1311.36 404.89,1311.36 404.899,1311.35 404.908,1311.35 404.917,1311.35 404.926,1311.35 404.936,1311.34 404.945,1311.34 404.954,1311.34 404.963,1311.34 404.972,1311.33 404.981,1311.33 404.991,1311.33 405,1311.33 405.009,1311.32 405.018,1311.32 405.027,1311.32 405.037,1311.31 405.046,1311.31 405.055,1311.31 405.064,1311.31 405.073,1311.3 405.083,1311.3 405.092,1311.3 405.101,1311.3 405.11,1311.29 405.119,1311.29 405.128,1311.29 405.138,1311.29 405.147,1311.28 405.156,1311.28 405.165,1311.28 405.174,1311.27 405.184,1311.27 405.193,1311.27 405.202,1311.27 405.211,1311.26 405.22,1311.26 405.23,1311.26 405.239,1311.26 405.248,1311.25 405.257,1311.25 405.266,1311.25 405.276,1311.25 405.285,1311.24 405.294,1311.24 405.303,1311.24 405.312,1311.23 405.321,1311.23 405.331,1311.23 405.34,1311.23 405.349,1311.22 405.358,1311.22 405.367,1311.22 405.377,1311.22 405.386,1311.21 405.395,1311.21 405.404,1311.21 405.413,1311.21 405.423,1311.2 405.432,1311.2 405.441,1311.2 405.45,1311.19 405.459,1311.19 405.469,1311.19 405.478,1311.19 405.487,1311.18 405.496,1311.18 405.505,1311.18 405.514,1311.18 405.524,1311.17 405.533,1311.17 405.542,1311.17 405.551,1311.17 405.56,1311.16 405.57,1311.16 405.579,1311.16 405.588,1311.15 405.597,1311.15 405.606,1311.15 405.616,1311.15 405.625,1311.14 405.634,1311.14 405.643,1311.14 405.652,1311.14 405.661,1311.13 405.671,1311.13 405.68,1311.13 405.689,1311.13 405.698,1311.12 405.707,1311.12 405.717,1311.12 405.726,1311.12 405.735,1311.11 405.744,1311.11 405.753,1311.11 405.763,1311.1 405.772,1311.1 405.781,1311.1 405.79,1311.1 405.799,1311.09 405.809,1311.09 405.818,1311.09 405.827,1311.09 405.836,1311.08 405.845,1311.08 405.854,1311.08 405.864,1311.08 405.873,1311.07 405.882,1311.07 405.891,1311.07 405.9,1311.06 405.91,1311.06 405.919,1311.06 405.928,1311.06 405.937,1311.05 405.946,1311.05 405.956,1311.05 405.965,1311.05 405.974,1311.04 405.983,1311.04 405.992,1311.04 406.001,1311.04 406.011,1311.03 406.02,1311.03 406.029,1311.03 406.038,1311.03 406.047,1311.02 406.057,1311.02 406.066,1311.02 406.075,1311.01 406.084,1311.01 406.093,1311.01 406.103,1311.01 406.112,1311 406.121,1311 406.13,1311 406.139,1311 406.149,1310.99 406.158,1310.99 406.167,1310.99 406.176,1310.99 406.185,1310.98 406.194,1310.98 406.204,1310.98 406.213,1310.97 406.222,1310.97 406.231,1310.97 406.24,1310.97 406.25,1310.96 406.259,1310.96 406.268,1310.96 406.277,1310.96 406.286,1310.95 406.296,1310.95 406.305,1310.95 406.314,1310.95 406.323,1310.94 406.332,1310.94 406.341,1310.94 406.351,1310.94 406.36,1310.93 406.369,1310.93 406.378,1310.93 406.387,1310.92 406.397,1310.92 406.406,1310.92 406.415,1310.92 406.424,1310.91 406.433,1310.91 406.443,1310.91 406.452,1310.91 406.461,1310.9 406.47,1310.9 406.479,1310.9 406.489,1310.9 406.498,1310.89 406.507,1310.89 406.516,1310.89 406.525,1310.89 406.534,1310.88 406.544,1310.88 406.553,1310.88 406.562,1310.87 406.571,1310.87 406.58,1310.87 406.59,1310.87 406.599,1310.86 406.608,1310.86 406.617,1310.86 406.626,1310.86 406.636,1310.85 406.645,1310.85 406.654,1310.85 406.663,1310.85 406.672,1310.84 406.681,1310.84 406.691,1310.84 406.7,1310.84 406.709,1310.83 406.718,1310.83 406.727,1310.83 406.737,1310.82 406.746,1310.82 406.755,1310.82 406.764,1310.82 406.773,1310.81 406.783,1310.81 406.792,1310.81 406.801,1310.81 406.81,1310.8 406.819,1310.8 406.829,1310.8 406.838,1310.8 406.847,1310.79 406.856,1310.79 406.865,1310.79 406.874,1310.79 406.884,1310.78 406.893,1310.78 406.902,1310.78 406.911,1310.77 406.92,1310.77 406.93,1310.77 406.939,1310.77 406.948,1310.76 406.957,1310.76 406.966,1310.76 406.976,1310.76 406.985,1310.75 406.994,1310.75 407.003,1310.75 407.012,1310.75 407.021,1310.74 407.031,1310.74 407.04,1310.74 407.049,1310.74 407.058,1310.73 407.067,1310.73 407.077,1310.73 407.086,1310.72 407.095,1310.72 407.104,1310.72 407.113,1310.72 407.123,1310.71 407.132,1310.71 407.141,1310.71 407.15,1310.71 407.159,1310.7 407.169,1310.7 407.178,1310.7 407.187,1310.7 407.196,1310.69 407.205,1310.69 407.214,1310.69 407.224,1310.69 407.233,1310.68 407.242,1310.68 407.251,1310.68 407.26,1310.68 407.27,1310.67 407.279,1310.67 407.288,1310.67 407.297,1310.66 407.306,1310.66 407.316,1310.66 407.325,1310.66 407.334,1310.65 407.343,1310.65 407.352,1310.65 407.361,1310.65 407.371,1310.64 407.38,1310.64 407.389,1310.64 407.398,1310.64 407.407,1310.63 407.417,1310.63 407.426,1310.63 407.435,1310.63 407.444,1310.62 407.453,1310.62 407.463,1310.62 407.472,1310.61 407.481,1310.61 407.49,1310.61 407.499,1310.61 407.509,1310.6 407.518,1310.6 407.527,1310.6 407.536,1310.6 407.545,1310.59 407.554,1310.59 407.564,1310.59 407.573,1310.59 407.582,1310.58 407.591,1310.58 407.6,1310.58 407.61,1310.58 407.619,1310.57 407.628,1310.57 407.637,1310.57 407.646,1310.57 407.656,1310.56 407.665,1310.56 407.674,1310.56 407.683,1310.55 407.692,1310.55 407.701,1310.55 407.711,1310.55 407.72,1310.54 407.729,1310.54 407.738,1310.54 407.747,1310.54 407.757,1310.53 407.766,1310.53 407.775,1310.53 407.784,1310.53 407.793,1310.52 407.803,1310.52 407.812,1310.52 407.821,1310.52 407.83,1310.51 407.839,1310.51 407.849,1310.51 407.858,1310.51 407.867,1310.5 407.876,1310.5 407.885,1310.5 407.894,1310.49 407.904,1310.49 407.913,1310.49 407.922,1310.49 407.931,1310.48 407.94,1310.48 407.95,1310.48 407.959,1310.48 407.968,1310.47 407.977,1310.47 407.986,1310.47 407.996,1310.47 408.005,1310.46 408.014,1310.46 408.023,1310.46 408.032,1310.46 408.042,1310.45 408.051,1310.45 408.06,1310.45 408.069,1310.45 408.078,1310.44 408.087,1310.44 408.097,1310.44 408.106,1310.44 408.115,1310.43 408.124,1310.43 408.133,1310.43 408.143,1310.42 408.152,1310.42 408.161,1310.42 408.17,1310.42 408.179,1310.41 408.189,1310.41 408.198,1310.41 408.207,1310.41 408.216,1310.4 408.225,1310.4 408.234,1310.4 408.244,1310.4 408.253,1310.39 408.262,1310.39 408.271,1310.39 408.28,1310.39 408.29,1310.38 408.299,1310.38 408.308,1310.38 408.317,1310.38 408.326,1310.37 408.336,1310.37 408.345,1310.37 408.354,1310.36 408.363,1310.36 408.372,1310.36 408.382,1310.36 408.391,1310.35 408.4,1310.35 408.409,1310.35 408.418,1310.35 408.427,1310.34 408.437,1310.34 408.446,1310.34 408.455,1310.34 408.464,1310.33 408.473,1310.33 408.483,1310.33 408.492,1310.33 408.501,1310.32 408.51,1310.32 408.519,1310.32 408.529,1310.32 408.538,1310.31 408.547,1310.31 408.556,1310.31 408.565,1310.31 408.574,1310.3 408.584,1310.3 408.593,1310.3 408.602,1310.29 408.611,1310.29 408.62,1310.29 408.63,1310.29 408.639,1310.28 408.648,1310.28 408.657,1310.28 408.666,1310.28 408.676,1310.27 408.685,1310.27 408.694,1310.27 408.703,1310.27 408.712,1310.26 408.722,1310.26 408.731,1310.26 408.74,1310.26 408.749,1310.25 408.758,1310.25 408.767,1310.25 408.777,1310.25 408.786,1310.24 408.795,1310.24 408.804,1310.24 408.813,1310.24 408.823,1310.23 408.832,1310.23 408.841,1310.23 408.85,1310.23 408.859,1310.22 408.869,1310.22 408.878,1310.22 408.887,1310.21 408.896,1310.21 408.905,1310.21 408.914,1310.21 408.924,1310.2 408.933,1310.2 408.942,1310.2 408.951,1310.2 408.96,1310.19 408.97,1310.19 408.979,1310.19 408.988,1310.19 408.997,1310.18 409.006,1310.18 409.016,1310.18 409.025,1310.18 409.034,1310.17 409.043,1310.17 409.052,1310.17 409.062,1310.17 409.071,1310.16 409.08,1310.16 409.089,1310.16 409.098,1310.16 409.107,1310.15 409.117,1310.15 409.126,1310.15 409.135,1310.15 409.144,1310.14 409.153,1310.14 409.163,1310.14 409.172,1310.13 409.181,1310.13 409.19,1310.13 409.199,1310.13 409.209,1310.12 409.218,1310.12 409.227,1310.12 409.236,1310.12 409.245,1310.11 409.254,1310.11 409.264,1310.11 409.273,1310.11 409.282,1310.1 409.291,1310.1 409.3,1310.1 409.31,1310.1 409.319,1310.09 409.328,1310.09 409.337,1310.09 409.346,1310.09 409.356,1310.08 409.365,1310.08 409.374,1310.08 409.383,1310.08 409.392,1310.07 409.402,1310.07 409.411,1310.07 409.42,1310.07 409.429,1310.06 409.438,1310.06 409.447,1310.06 409.457,1310.06 409.466,1310.05 409.475,1310.05 409.484,1310.05 409.493,1310.04 409.503,1310.04 409.512,1310.04 409.521,1310.04 409.53,1310.03 409.539,1310.03 409.549,1310.03 409.558,1310.03 409.567,1310.02 409.576,1310.02 409.585,1310.02 409.594,1310.02 409.604,1310.01 409.613,1310.01 409.622,1310.01 409.631,1310.01 409.64,1310 409.65,1310 409.659,1310 409.668,1310 409.677,1309.99 409.686,1309.99 409.696,1309.99 409.705,1309.99 409.714,1309.98 409.723,1309.98 409.732,1309.98 409.742,1309.98 409.751,1309.97 409.76,1309.97 409.769,1309.97 409.778,1309.97 409.787,1309.96 409.797,1309.96 409.806,1309.96 409.815,1309.95 409.824,1309.95 409.833,1309.95 409.843,1309.95 409.852,1309.94 409.861,1309.94 409.87,1309.94 409.879,1309.94 409.889,1309.93 409.898,1309.93 409.907,1309.93 409.916,1309.93 409.925,1309.92 409.934,1309.92 409.944,1309.92 409.953,1309.92 409.962,1309.91 409.971,1309.91 409.98,1309.91 409.99,1309.91 409.999,1309.9 410.008,1309.9 410.017,1309.9 410.026,1309.9 410.036,1309.89 410.045,1309.89 410.054,1309.89 410.063,1309.89 410.072,1309.88 410.082,1309.88 410.091,1309.88 410.1,1309.88 410.109,1309.87 410.118,1309.87 410.127,1309.87 410.137,1309.87 410.146,1309.86 410.155,1309.86 410.164,1309.86 410.173,1309.86 410.183,1309.85 410.192,1309.85 410.201,1309.85 410.21,1309.84 410.219,1309.84 410.229,1309.84 410.238,1309.84 410.247,1309.83 410.256,1309.83 410.265,1309.83 410.274,1309.83 410.284,1309.82 410.293,1309.82 410.302,1309.82 410.311,1309.82 410.32,1309.81 410.33,1309.81 410.339,1309.81 410.348,1309.81 410.357,1309.8 410.366,1309.8 410.376,1309.8 410.385,1309.8 410.394,1309.79 410.403,1309.79 410.412,1309.79 410.422,1309.79 410.431,1309.78 410.44,1309.78 410.449,1309.78 410.458,1309.78 410.467,1309.77 410.477,1309.77 410.486,1309.77 410.495,1309.77 410.504,1309.76 410.513,1309.76 410.523,1309.76 410.532,1309.76 410.541,1309.75 410.55,1309.75 410.559,1309.75 410.569,1309.75 410.578,1309.74 410.587,1309.74 410.596,1309.74 410.605,1309.74 410.615,1309.73 410.624,1309.73 410.633,1309.73 410.642,1309.73 410.651,1309.72 410.66,1309.72 410.67,1309.72 410.679,1309.71 410.688,1309.71 410.697,1309.71 410.706,1309.71 410.716,1309.7 410.725,1309.7 410.734,1309.7 410.743,1309.7 410.752,1309.69 410.762,1309.69 410.771,1309.69 410.78,1309.69 410.789,1309.68 410.798,1309.68 410.807,1309.68 410.817,1309.68 410.826,1309.67 410.835,1309.67 410.844,1309.67 410.853,1309.67 410.863,1309.66 410.872,1309.66 410.881,1309.66 410.89,1309.66 410.899,1309.65 410.909,1309.65 410.918,1309.65 410.927,1309.65 410.936,1309.64 410.945,1309.64 410.955,1309.64 410.964,1309.64 410.973,1309.63 410.982,1309.63 410.991,1309.63 411,1309.63 411.01,1309.62 411.019,1309.62 411.028,1309.62 411.037,1309.62 411.046,1309.61 411.056,1309.61 411.065,1309.61 411.074,1309.61 411.083,1309.6 411.092,1309.6 411.102,1309.6 411.111,1309.6 411.12,1309.59 411.129,1309.59 411.138,1309.59 411.147,1309.59 411.157,1309.58 411.166,1309.58 411.175,1309.58 411.184,1309.58 411.193,1309.57 411.203,1309.57 411.212,1309.57 411.221,1309.57 411.23,1309.56 411.239,1309.56 411.249,1309.56 411.258,1309.56 411.267,1309.55 411.276,1309.55 411.285,1309.55 411.295,1309.55 411.304,1309.54 411.313,1309.54 411.322,1309.54 411.331,1309.53 411.34,1309.53 411.35,1309.53 411.359,1309.53 411.368,1309.52 411.377,1309.52 411.386,1309.52 411.396,1309.52 411.405,1309.51 411.414,1309.51 411.423,1309.51 411.432,1309.51 411.442,1309.5 411.451,1309.5 411.46,1309.5 411.469,1309.5 411.478,1309.49 411.487,1309.49 411.497,1309.49 411.506,1309.49 411.515,1309.48 411.524,1309.48 411.533,1309.48 411.543,1309.48 411.552,1309.47 411.561,1309.47 411.57,1309.47 411.579,1309.47 411.589,1309.46 411.598,1309.46 411.607,1309.46 411.616,1309.46 411.625,1309.45 411.635,1309.45 411.644,1309.45 411.653,1309.45 411.662,1309.44 411.671,1309.44 411.68,1309.44 411.69,1309.44 411.699,1309.43 411.708,1309.43 411.717,1309.43 411.726,1309.43 411.736,1309.42 411.745,1309.42 411.754,1309.42 411.763,1309.42 411.772,1309.41 411.782,1309.41 411.791,1309.41 411.8,1309.41 411.809,1309.4 411.818,1309.4 411.827,1309.4 411.837,1309.4 411.846,1309.39 411.855,1309.39 411.864,1309.39 411.873,1309.39 411.883,1309.38 411.892,1309.38 411.901,1309.38 411.91,1309.38 411.919,1309.37 411.929,1309.37 411.938,1309.37 411.947,1309.37 411.956,1309.36 411.965,1309.36 411.975,1309.36 411.984,1309.36 411.993,1309.35 412.002,1309.35 412.011,1309.35 412.02,1309.35 412.03,1309.34 412.039,1309.34 412.048,1309.34 412.057,1309.34 412.066,1309.33 412.076,1309.33 412.085,1309.33 412.094,1309.33 412.103,1309.32 412.112,1309.32 412.122,1309.32 412.131,1309.32 412.14,1309.31 412.149,1309.31 412.158,1309.31 412.167,1309.31 412.177,1309.3 412.186,1309.3 412.195,1309.3 412.204,1309.3 412.213,1309.29 412.223,1309.29 412.232,1309.29 412.241,1309.29 412.25,1309.28 412.259,1309.28 412.269,1309.28 412.278,1309.28 412.287,1309.27 412.296,1309.27 412.305,1309.27 412.315,1309.27 412.324,1309.26 412.333,1309.26 412.342,1309.26 412.351,1309.26 412.36,1309.25 412.37,1309.25 412.379,1309.25 412.388,1309.25 412.397,1309.24 412.406,1309.24 412.416,1309.24 412.425,1309.24 412.434,1309.23 412.443,1309.23 412.452,1309.23 412.462,1309.23 412.471,1309.22 412.48,1309.22 412.489,1309.22 412.498,1309.22 412.507,1309.21 412.517,1309.21 412.526,1309.21 412.535,1309.21 412.544,1309.2 412.553,1309.2 412.563,1309.2 412.572,1309.2 412.581,1309.19 412.59,1309.19 412.599,1309.19 412.609,1309.19 412.618,1309.18 412.627,1309.18 412.636,1309.18 412.645,1309.18 412.655,1309.17 412.664,1309.17 412.673,1309.17 412.682,1309.17 412.691,1309.16 412.7,1309.16 412.71,1309.16 412.719,1309.16 412.728,1309.15 412.737,1309.15 412.746,1309.15 412.756,1309.15 412.765,1309.14 412.774,1309.14 412.783,1309.14 412.792,1309.14 412.802,1309.13 412.811,1309.13 412.82,1309.13 412.829,1309.13 412.838,1309.12 412.847,1309.12 412.857,1309.12 412.866,1309.12 412.875,1309.11 412.884,1309.11 412.893,1309.11 412.903,1309.11 412.912,1309.1 412.921,1309.1 412.93,1309.1 412.939,1309.1 412.949,1309.09 412.958,1309.09 412.967,1309.09 412.976,1309.09 412.985,1309.08 412.995,1309.08 413.004,1309.08 413.013,1309.08 413.022,1309.07 413.031,1309.07 413.04,1309.07 413.05,1309.07 413.059,1309.06 413.068,1309.06 413.077,1309.06 413.086,1309.06 413.096,1309.05 413.105,1309.05 413.114,1309.05 413.123,1309.05 413.132,1309.04 413.142,1309.04 413.151,1309.04 413.16,1309.04 413.169,1309.03 413.178,1309.03 413.188,1309.03 413.197,1309.03 413.206,1309.02 413.215,1309.02 413.224,1309.02 413.233,1309.02 413.243,1309.01 413.252,1309.01 413.261,1309.01 413.27,1309.01 413.279,1309 413.289,1309 413.298,1309 413.307,1309 413.316,1308.99 413.325,1308.99 413.335,1308.99 413.344,1308.99 413.353,1308.98 413.362,1308.98 413.371,1308.98 413.38,1308.98 413.39,1308.97 413.399,1308.97 413.408,1308.97 413.417,1308.97 413.426,1308.96 413.436,1308.96 413.445,1308.96 413.454,1308.96 413.463,1308.95 413.472,1308.95 413.482,1308.95 413.491,1308.95 413.5,1308.94 413.509,1308.94 413.518,1308.94 413.528,1308.94 413.537,1308.93 413.546,1308.93 413.555,1308.93 413.564,1308.93 413.573,1308.92 413.583,1308.92 413.592,1308.92 413.601,1308.92 413.61,1308.91 413.619,1308.91 413.629,1308.91 413.638,1308.91 413.647,1308.9 413.656,1308.9 413.665,1308.9 413.675,1308.9 413.684,1308.89 413.693,1308.89 413.702,1308.89 413.711,1308.89 413.72,1308.88 413.73,1308.88 413.739,1308.88 413.748,1308.88 413.757,1308.87 413.766,1308.87 413.776,1308.87 413.785,1308.87 413.794,1308.86 413.803,1308.86 413.812,1308.86 413.822,1308.86 413.831,1308.85 413.84,1308.85 413.849,1308.85 413.858,1308.85 413.868,1308.84 413.877,1308.84 413.886,1308.84 413.895,1308.84 413.904,1308.84 413.913,1308.83 413.923,1308.83 413.932,1308.83 413.941,1308.83 413.95,1308.82 413.959,1308.82 413.969,1308.82 413.978,1308.82 413.987,1308.81 413.996,1308.81 414.005,1308.81 414.015,1308.81 414.024,1308.8 414.033,1308.8 414.042,1308.8 414.051,1308.8 414.06,1308.79 414.07,1308.79 414.079,1308.79 414.088,1308.79 414.097,1308.78 414.106,1308.78 414.116,1308.78 414.125,1308.78 414.134,1308.77 414.143,1308.77 414.152,1308.77 414.162,1308.77 414.171,1308.76 414.18,1308.76 414.189,1308.76 414.198,1308.76 414.208,1308.75 414.217,1308.75 414.226,1308.75 414.235,1308.75 414.244,1308.74 414.253,1308.74 414.263,1308.74 414.272,1308.74 414.281,1308.73 414.29,1308.73 414.299,1308.73 414.309,1308.73 414.318,1308.72 414.327,1308.72 414.336,1308.72 414.345,1308.72 414.355,1308.71 414.364,1308.71 414.373,1308.71 414.382,1308.71 414.391,1308.7 414.4,1308.7 414.41,1308.7 414.419,1308.7 414.428,1308.69 414.437,1308.69 414.446,1308.69 414.456,1308.69 414.465,1308.68 414.474,1308.68 414.483,1308.68 414.492,1308.68 414.502,1308.67 414.511,1308.67 414.52,1308.67 414.529,1308.67 414.538,1308.67 414.548,1308.66 414.557,1308.66 414.566,1308.66 414.575,1308.66 414.584,1308.65 414.593,1308.65 414.603,1308.65 414.612,1308.65 414.621,1308.64 414.63,1308.64 414.639,1308.64 414.649,1308.64 414.658,1308.63 414.667,1308.63 414.676,1308.63 414.685,1308.63 414.695,1308.62 414.704,1308.62 414.713,1308.62 414.722,1308.62 414.731,1308.61 414.74,1308.61 414.75,1308.61 414.759,1308.61 414.768,1308.6 414.777,1308.6 414.786,1308.6 414.796,1308.6 414.805,1308.59 414.814,1308.59 414.823,1308.59 414.832,1308.59 414.842,1308.58 414.851,1308.58 414.86,1308.58 414.869,1308.58 414.878,1308.57 414.888,1308.57 414.897,1308.57 414.906,1308.57 414.915,1308.56 414.924,1308.56 414.933,1308.56 414.943,1308.56 414.952,1308.55 414.961,1308.55 414.97,1308.55 414.979,1308.55 414.989,1308.55 414.998,1308.54 415.007,1308.54 415.016,1308.54 415.025,1308.54 415.035,1308.53 415.044,1308.53 415.053,1308.53 415.062,1308.53 415.071,1308.52 415.08,1308.52 415.09,1308.52 415.099,1308.52 415.108,1308.51 415.117,1308.51 415.126,1308.51 415.136,1308.51 415.145,1308.5 415.154,1308.5 415.163,1308.5 415.172,1308.5 415.182,1308.49 415.191,1308.49 415.2,1308.49 415.209,1308.49 415.218,1308.48 415.228,1308.48 415.237,1308.48 415.246,1308.48 415.255,1308.47 415.264,1308.47 415.273,1308.47 415.283,1308.47 415.292,1308.46 415.301,1308.46 415.31,1308.46 415.319,1308.46 415.329,1308.45 415.338,1308.45 415.347,1308.45 415.356,1308.45 415.365,1308.44 415.375,1308.44 415.384,1308.44 415.393,1308.44 415.402,1308.44 415.411,1308.43 415.421,1308.43 415.43,1308.43 415.439,1308.43 415.448,1308.42 415.457,1308.42 415.466,1308.42 415.476,1308.42 415.485,1308.41 415.494,1308.41 415.503,1308.41 415.512,1308.41 415.522,1308.4 415.531,1308.4 415.54,1308.4 415.549,1308.4 415.558,1308.39 415.568,1308.39 415.577,1308.39 415.586,1308.39 415.595,1308.38 415.604,1308.38 415.613,1308.38 415.623,1308.38 415.632,1308.37 415.641,1308.37 415.65,1308.37 415.659,1308.37 415.669,1308.36 415.678,1308.36 415.687,1308.36 415.696,1308.36 415.705,1308.35 415.715,1308.35 415.724,1308.35 415.733,1308.35 415.742,1308.35 415.751,1308.34 415.761,1308.34 415.77,1308.34 415.779,1308.34 415.788,1308.33 415.797,1308.33 415.806,1308.33 415.816,1308.33 415.825,1308.32 415.834,1308.32 415.843,1308.32 415.852,1308.32 415.862,1308.31 415.871,1308.31 415.88,1308.31 415.889,1308.31 415.898,1308.3 415.908,1308.3 415.917,1308.3 415.926,1308.3 415.935,1308.29 415.944,1308.29 415.953,1308.29 415.963,1308.29 415.972,1308.28 415.981,1308.28 415.99,1308.28 415.999,1308.28 416.009,1308.27 416.018,1308.27 416.027,1308.27 416.036,1308.27 416.045,1308.27 416.055,1308.26 416.064,1308.26 416.073,1308.26 416.082,1308.26 416.091,1308.25 416.101,1308.25 416.11,1308.25 416.119,1308.25 416.128,1308.24 416.137,1308.24 416.146,1308.24 416.156,1308.24 416.165,1308.23 416.174,1308.23 416.183,1308.23 416.192,1308.23 416.202,1308.22 416.211,1308.22 416.22,1308.22 416.229,1308.22 416.238,1308.21 416.248,1308.21 416.257,1308.21 416.266,1308.21 416.275,1308.2 416.284,1308.2 416.293,1308.2 416.303,1308.2 416.312,1308.2 416.321,1308.19 416.33,1308.19 416.339,1308.19 416.349,1308.19 416.358,1308.18 416.367,1308.18 416.376,1308.18 416.385,1308.18 416.395,1308.17 416.404,1308.17 416.413,1308.17 416.422,1308.17 416.431,1308.16 416.441,1308.16 416.45,1308.16 416.459,1308.16 416.468,1308.15 416.477,1308.15 416.486,1308.15 416.496,1308.15 416.505,1308.14 416.514,1308.14 416.523,1308.14 416.532,1308.14 416.542,1308.13 416.551,1308.13 416.56,1308.13 416.569,1308.13 416.578,1308.13 416.588,1308.12 416.597,1308.12 416.606,1308.12 416.615,1308.12 416.624,1308.11 416.633,1308.11 416.643,1308.11 416.652,1308.11 416.661,1308.1 416.67,1308.1 416.679,1308.1 416.689,1308.1 416.698,1308.09 416.707,1308.09 416.716,1308.09 416.725,1308.09 416.735,1308.08 416.744,1308.08 416.753,1308.08 416.762,1308.08 416.771,1308.07 416.781,1308.07 416.79,1308.07 416.799,1308.07 416.808,1308.06 416.817,1308.06 416.826,1308.06 416.836,1308.06 416.845,1308.06 416.854,1308.05 416.863,1308.05 416.872,1308.05 416.882,1308.05 416.891,1308.04 416.9,1308.04 416.909,1308.04 416.918,1308.04 416.928,1308.03 416.937,1308.03 416.946,1308.03 416.955,1308.03 416.964,1308.02 416.973,1308.02 416.983,1308.02 416.992,1308.02 417.001,1308.01 417.01,1308.01 417.019,1308.01 417.029,1308.01 417.038,1308 417.047,1308 417.056,1308 417.065,1308 417.075,1308 417.084,1307.99 417.093,1307.99 417.102,1307.99 417.111,1307.99 417.121,1307.98 417.13,1307.98 417.139,1307.98 417.148,1307.98 417.157,1307.97 417.166,1307.97 417.176,1307.97 417.185,1307.97 417.194,1307.96 417.203,1307.96 417.212,1307.96 417.222,1307.96 417.231,1307.95 417.24,1307.95 417.249,1307.95 417.258,1307.95 417.268,1307.94 417.277,1307.94 417.286,1307.94 417.295,1307.94 417.304,1307.94 417.313,1307.93 417.323,1307.93 417.332,1307.93 417.341,1307.93 417.35,1307.92 417.359,1307.92 417.369,1307.92 417.378,1307.92 417.387,1307.91 417.396,1307.91 417.405,1307.91 417.415,1307.91 417.424,1307.9 417.433,1307.9 417.442,1307.9 417.451,1307.9 417.461,1307.89 417.47,1307.89 417.479,1307.89 417.488,1307.89 417.497,1307.89 417.506,1307.88 417.516,1307.88 417.525,1307.88 417.534,1307.88 417.543,1307.87 417.552,1307.87 417.562,1307.87 417.571,1307.87 417.58,1307.86 417.589,1307.86 417.598,1307.86 417.608,1307.86 417.617,1307.85 417.626,1307.85 417.635,1307.85 417.644,1307.85 417.653,1307.84 417.663,1307.84 417.672,1307.84 417.681,1307.84 417.69,1307.84 417.699,1307.83 417.709,1307.83 417.718,1307.83 417.727,1307.83 417.736,1307.82 417.745,1307.82 417.755,1307.82 417.764,1307.82 417.773,1307.81 417.782,1307.81 417.791,1307.81 417.801,1307.81 417.81,1307.8 417.819,1307.8 417.828,1307.8 417.837,1307.8 417.846,1307.79 417.856,1307.79 417.865,1307.79 417.874,1307.79 417.883,1307.79 417.892,1307.78 417.902,1307.78 417.911,1307.78 417.92,1307.78 417.929,1307.77 417.938,1307.77 417.948,1307.77 417.957,1307.77 417.966,1307.76 417.975,1307.76 417.984,1307.76 417.994,1307.76 418.003,1307.75 418.012,1307.75 418.021,1307.75 418.03,1307.75 418.039,1307.74 418.049,1307.74 418.058,1307.74 418.067,1307.74 418.076,1307.74 418.085,1307.73 418.095,1307.73 418.104,1307.73 418.113,1307.73 418.122,1307.72 418.131,1307.72 418.141,1307.72 418.15,1307.72 418.159,1307.71 418.168,1307.71 418.177,1307.71 418.186,1307.71 418.196,1307.7 418.205,1307.7 418.214,1307.7 418.223,1307.7 418.232,1307.69 418.242,1307.69 418.251,1307.69 418.26,1307.69 418.269,1307.69 418.278,1307.68 418.288,1307.68 418.297,1307.68 418.306,1307.68 418.315,1307.67 418.324,1307.67 418.334,1307.67 418.343,1307.67 418.352,1307.66 418.361,1307.66 418.37,1307.66 418.379,1307.66 418.389,1307.65 418.398,1307.65 418.407,1307.65 418.416,1307.65 418.425,1307.65 418.435,1307.64 418.444,1307.64 418.453,1307.64 418.462,1307.64 418.471,1307.63 418.481,1307.63 418.49,1307.63 418.499,1307.63 418.508,1307.62 418.517,1307.62 418.526,1307.62 418.536,1307.62 418.545,1307.61 418.554,1307.61 418.563,1307.61 418.572,1307.61 418.582,1307.6 418.591,1307.6 418.6,1307.6 418.609,1307.6 418.618,1307.6 418.628,1307.59 418.637,1307.59 418.646,1307.59 418.655,1307.59 418.664,1307.58 418.674,1307.58 418.683,1307.58 418.692,1307.58 418.701,1307.57 418.71,1307.57 418.719,1307.57 418.729,1307.57 418.738,1307.56 418.747,1307.56 418.756,1307.56 418.765,1307.56 418.775,1307.56 418.784,1307.55 418.793,1307.55 418.802,1307.55 418.811,1307.55 418.821,1307.54 418.83,1307.54 418.839,1307.54 418.848,1307.54 418.857,1307.53 418.866,1307.53 418.876,1307.53 418.885,1307.53 418.894,1307.52 418.903,1307.52 418.912,1307.52 418.922,1307.52 418.931,1307.52 418.94,1307.51 418.949,1307.51 418.958,1307.51 418.968,1307.51 418.977,1307.5 418.986,1307.5 418.995,1307.5 419.004,1307.5 419.014,1307.49 419.023,1307.49 419.032,1307.49 419.041,1307.49 419.05,1307.48 419.059,1307.48 419.069,1307.48 419.078,1307.48 419.087,1307.48 419.096,1307.47 419.105,1307.47 419.115,1307.47 419.124,1307.47 419.133,1307.46 419.142,1307.46 419.151,1307.46 419.161,1307.46 419.17,1307.45 419.179,1307.45 419.188,1307.45 419.197,1307.45 419.206,1307.44 419.216,1307.44 419.225,1307.44 419.234,1307.44 419.243,1307.44 419.252,1307.43 419.262,1307.43 419.271,1307.43 419.28,1307.43 419.289,1307.42 419.298,1307.42 419.308,1307.42 419.317,1307.42 419.326,1307.41 419.335,1307.41 419.344,1307.41 419.354,1307.41 419.363,1307.4 419.372,1307.4 419.381,1307.4 419.39,1307.4 419.399,1307.4 419.409,1307.39 419.418,1307.39 419.427,1307.39 419.436,1307.39 419.445,1307.38 419.455,1307.38 419.464,1307.38 419.473,1307.38 419.482,1307.37 419.491,1307.37 419.501,1307.37 419.51,1307.37 419.519,1307.36 419.528,1307.36 419.537,1307.36 419.546,1307.36 419.556,1307.36 419.565,1307.35 419.574,1307.35 419.583,1307.35 419.592,1307.35 419.602,1307.34 419.611,1307.34 419.62,1307.34 419.629,1307.34 419.638,1307.33 419.648,1307.33 419.657,1307.33 419.666,1307.33 419.675,1307.33 419.684,1307.32 419.694,1307.32 419.703,1307.32 419.712,1307.32 419.721,1307.31 419.73,1307.31 419.739,1307.31 419.749,1307.31 419.758,1307.3 419.767,1307.3 419.776,1307.3 419.785,1307.3 419.795,1307.29 419.804,1307.29 419.813,1307.29 419.822,1307.29 419.831,1307.29 419.841,1307.28 419.85,1307.28 419.859,1307.28 419.868,1307.28 419.877,1307.27 419.886,1307.27 419.896,1307.27 419.905,1307.27 419.914,1307.26 419.923,1307.26 419.932,1307.26 419.942,1307.26 419.951,1307.25 419.96,1307.25 419.969,1307.25 419.978,1307.25 419.988,1307.25 419.997,1307.24 420.006,1307.24 420.015,1307.24 420.024,1307.24 420.034,1307.23 420.043,1307.23 420.052,1307.23 420.061,1307.23 420.07,1307.22 420.079,1307.22 420.089,1307.22 420.098,1307.22 420.107,1307.22 420.116,1307.21 420.125,1307.21 420.135,1307.21 420.144,1307.21 420.153,1307.2 420.162,1307.2 420.171,1307.2 420.181,1307.2 420.19,1307.19 420.199,1307.19 420.208,1307.19 420.217,1307.19 420.226,1307.19 420.236,1307.18 420.245,1307.18 420.254,1307.18 420.263,1307.18 420.272,1307.17 420.282,1307.17 420.291,1307.17 420.3,1307.17 420.309,1307.16 420.318,1307.16 420.328,1307.16 420.337,1307.16 420.346,1307.15 420.355,1307.15 420.364,1307.15 420.374,1307.15 420.383,1307.15 420.392,1307.14 420.401,1307.14 420.41,1307.14 420.419,1307.14 420.429,1307.13 420.438,1307.13 420.447,1307.13 420.456,1307.13 420.465,1307.12 420.475,1307.12 420.484,1307.12 420.493,1307.12 420.502,1307.12 420.511,1307.11 420.521,1307.11 420.53,1307.11 420.539,1307.11 420.548,1307.1 420.557,1307.1 420.567,1307.1 420.576,1307.1 420.585,1307.09 420.594,1307.09 420.603,1307.09 420.612,1307.09 420.622,1307.09 420.631,1307.08 420.64,1307.08 420.649,1307.08 420.658,1307.08 420.668,1307.07 420.677,1307.07 420.686,1307.07 420.695,1307.07 420.704,1307.06 420.714,1307.06 420.723,1307.06 420.732,1307.06 420.741,1307.06 420.75,1307.05 420.759,1307.05 420.769,1307.05 420.778,1307.05 420.787,1307.04 420.796,1307.04 420.805,1307.04 420.815,1307.04 420.824,1307.03 420.833,1307.03 420.842,1307.03 420.851,1307.03 420.861,1307.03 420.87,1307.02 420.879,1307.02 420.888,1307.02 420.897,1307.02 420.907,1307.01 420.916,1307.01 420.925,1307.01 420.934,1307.01 420.943,1307 420.952,1307 420.962,1307 420.971,1307 420.98,1307 420.989,1306.99 420.998,1306.99 421.008,1306.99 421.017,1306.99 421.026,1306.98 421.035,1306.98 421.044,1306.98 421.054,1306.98 421.063,1306.97 421.072,1306.97 421.081,1306.97 421.09,1306.97 421.099,1306.97 421.109,1306.96 421.118,1306.96 421.127,1306.96 421.136,1306.96 421.145,1306.95 421.155,1306.95 421.164,1306.95 421.173,1306.95 421.182,1306.94 421.191,1306.94 421.201,1306.94 421.21,1306.94 421.219,1306.94 421.228,1306.93 421.237,1306.93 421.247,1306.93 421.256,1306.93 421.265,1306.92 421.274,1306.92 421.283,1306.92 421.292,1306.92 421.302,1306.91 421.311,1306.91 421.32,1306.91 421.329,1306.91 421.338,1306.91 421.348,1306.9 421.357,1306.9 421.366,1306.9 421.375,1306.9 421.384,1306.89 421.394,1306.89 421.403,1306.89 421.412,1306.89 421.421,1306.88 421.43,1306.88 421.439,1306.88 421.449,1306.88 421.458,1306.88 421.467,1306.87 421.476,1306.87 421.485,1306.87 421.495,1306.87 421.504,1306.86 421.513,1306.86 421.522,1306.86 421.531,1306.86 421.541,1306.85 421.55,1306.85 421.559,1306.85 421.568,1306.85 421.577,1306.85 421.587,1306.84 421.596,1306.84 421.605,1306.84 421.614,1306.84 421.623,1306.83 421.632,1306.83 421.642,1306.83 421.651,1306.83 421.66,1306.82 421.669,1306.82 421.678,1306.82 421.688,1306.82 421.697,1306.82 421.706,1306.81 421.715,1306.81 421.724,1306.81 421.734,1306.81 421.743,1306.8 421.752,1306.8 421.761,1306.8 421.77,1306.8 421.779,1306.8 421.789,1306.79 421.798,1306.79 421.807,1306.79 421.816,1306.79 421.825,1306.78 421.835,1306.78 421.844,1306.78 421.853,1306.78 421.862,1306.77 421.871,1306.77 421.881,1306.77 421.89,1306.77 421.899,1306.77 421.908,1306.76 421.917,1306.76 421.927,1306.76 421.936,1306.76 421.945,1306.75 421.954,1306.75 421.963,1306.75 421.972,1306.75 421.982,1306.74 421.991,1306.74 422,1306.74 422.009,1306.74 422.018,1306.74 422.028,1306.73 422.037,1306.73 422.046,1306.73 422.055,1306.73 422.064,1306.72 422.074,1306.72 422.083,1306.72 422.092,1306.72 422.101,1306.71 422.11,1306.71 422.119,1306.71 422.129,1306.71 422.138,1306.71 422.147,1306.7 422.156,1306.7 422.165,1306.7 422.175,1306.7 422.184,1306.69 422.193,1306.69 422.202,1306.69 422.211,1306.69 422.221,1306.69 422.23,1306.68 422.239,1306.68 422.248,1306.68 422.257,1306.68 422.267,1306.67 422.276,1306.67 422.285,1306.67 422.294,1306.67 422.303,1306.66 422.312,1306.66 422.322,1306.66 422.331,1306.66 422.34,1306.66 422.349,1306.65 422.358,1306.65 422.368,1306.65 422.377,1306.65 422.386,1306.64 422.395,1306.64 422.404,1306.64 422.414,1306.64 422.423,1306.64 422.432,1306.63 422.441,1306.63 422.45,1306.63 422.459,1306.63 422.469,1306.62 422.478,1306.62 422.487,1306.62 422.496,1306.62 422.505,1306.61 422.515,1306.61 422.524,1306.61 422.533,1306.61 422.542,1306.61 422.551,1306.6 422.561,1306.6 422.57,1306.6 422.579,1306.6 422.588,1306.59 422.597,1306.59 422.607,1306.59 422.616,1306.59 422.625,1306.59 422.634,1306.58 422.643,1306.58 422.652,1306.58 422.662,1306.58 422.671,1306.57 422.68,1306.57 422.689,1306.57 422.698,1306.57 422.708,1306.56 422.717,1306.56 422.726,1306.56 422.735,1306.56 422.744,1306.56 422.754,1306.55 422.763,1306.55 422.772,1306.55 422.781,1306.55 422.79,1306.54 422.8,1306.54 422.809,1306.54 422.818,1306.54 422.827,1306.54 422.836,1306.53 422.845,1306.53 422.855,1306.53 422.864,1306.53 422.873,1306.52 422.882,1306.52 422.891,1306.52 422.901,1306.52 422.91,1306.51 422.919,1306.51 422.928,1306.51 422.937,1306.51 422.947,1306.51 422.956,1306.5 422.965,1306.5 422.974,1306.5 422.983,1306.5 422.992,1306.49 423.002,1306.49 423.011,1306.49 423.02,1306.49 423.029,1306.49 423.038,1306.48 423.048,1306.48 423.057,1306.48 423.066,1306.48 423.075,1306.47 423.084,1306.47 423.094,1306.47 423.103,1306.47 423.112,1306.47 423.121,1306.46 423.13,1306.46 423.14,1306.46 423.149,1306.46 423.158,1306.45 423.167,1306.45 423.176,1306.45 423.185,1306.45 423.195,1306.44 423.204,1306.44 423.213,1306.44 423.222,1306.44 423.231,1306.44 423.241,1306.43 423.25,1306.43 423.259,1306.43 423.268,1306.43 423.277,1306.42 423.287,1306.42 423.296,1306.42 423.305,1306.42 423.314,1306.42 423.323,1306.41 423.332,1306.41 423.342,1306.41 423.351,1306.41 423.36,1306.4 423.369,1306.4 423.378,1306.4 423.388,1306.4 423.397,1306.4 423.406,1306.39 423.415,1306.39 423.424,1306.39 423.434,1306.39 423.443,1306.38 423.452,1306.38 423.461,1306.38 423.47,1306.38 423.48,1306.37 423.489,1306.37 423.498,1306.37 423.507,1306.37 423.516,1306.37 423.525,1306.36 423.535,1306.36 423.544,1306.36 423.553,1306.36 423.562,1306.35 423.571,1306.35 423.581,1306.35 423.59,1306.35 423.599,1306.35 423.608,1306.34 423.617,1306.34 423.627,1306.34 423.636,1306.34 423.645,1306.33 423.654,1306.33 423.663,1306.33 423.672,1306.33 423.682,1306.33 423.691,1306.32 423.7,1306.32 423.709,1306.32 423.718,1306.32 423.728,1306.31 423.737,1306.31 423.746,1306.31 423.755,1306.31 423.764,1306.31 423.774,1306.3 423.783,1306.3 423.792,1306.3 423.801,1306.3 423.81,1306.29 423.82,1306.29 423.829,1306.29 423.838,1306.29 423.847,1306.28 423.856,1306.28 423.865,1306.28 423.875,1306.28 423.884,1306.28 423.893,1306.27 423.902,1306.27 423.911,1306.27 423.921,1306.27 423.93,1306.26 423.939,1306.26 423.948,1306.26 423.957,1306.26 423.967,1306.26 423.976,1306.25 423.985,1306.25 423.994,1306.25 424.003,1306.25 424.012,1306.24 424.022,1306.24 424.031,1306.24 424.04,1306.24 424.049,1306.24 424.058,1306.23 424.068,1306.23 424.077,1306.23 424.086,1306.23 424.095,1306.22 424.104,1306.22 424.114,1306.22 424.123,1306.22 424.132,1306.22 424.141,1306.21 424.15,1306.21 424.16,1306.21 424.169,1306.21 424.178,1306.2 424.187,1306.2 424.196,1306.2 424.205,1306.2 424.215,1306.2 424.224,1306.19 424.233,1306.19 424.242,1306.19 424.251,1306.19 424.261,1306.18 424.27,1306.18 424.279,1306.18 424.288,1306.18 424.297,1306.18 424.307,1306.17 424.316,1306.17 424.325,1306.17 424.334,1306.17 424.343,1306.16 424.352,1306.16 424.362,1306.16 424.371,1306.16 424.38,1306.16 424.389,1306.15 424.398,1306.15 424.408,1306.15 424.417,1306.15 424.426,1306.14 424.435,1306.14 424.444,1306.14 424.454,1306.14 424.463,1306.14 424.472,1306.13 424.481,1306.13 424.49,1306.13 424.5,1306.13 424.509,1306.12 424.518,1306.12 424.527,1306.12 424.536,1306.12 424.545,1306.12 424.555,1306.11 424.564,1306.11 424.573,1306.11 424.582,1306.11 424.591,1306.1 424.601,1306.1 424.61,1306.1 424.619,1306.1 424.628,1306.1 424.637,1306.09 424.647,1306.09 424.656,1306.09 424.665,1306.09 424.674,1306.08 424.683,1306.08 424.692,1306.08 424.702,1306.08 424.711,1306.08 424.72,1306.07 424.729,1306.07 424.738,1306.07 424.748,1306.07 424.757,1306.06 424.766,1306.06 424.775,1306.06 424.784,1306.06 424.794,1306.06 424.803,1306.05 424.812,1306.05 424.821,1306.05 424.83,1306.05 424.84,1306.04 424.849,1306.04 424.858,1306.04 424.867,1306.04 424.876,1306.04 424.885,1306.03 424.895,1306.03 424.904,1306.03 424.913,1306.03 424.922,1306.02 424.931,1306.02 424.941,1306.02 424.95,1306.02 424.959,1306.02 424.968,1306.01 424.977,1306.01 424.987,1306.01 424.996,1306.01 425.005,1306 425.014,1306 425.023,1306 425.032,1306 425.042,1306 425.051,1305.99 425.06,1305.99 425.069,1305.99 425.078,1305.99 425.088,1305.98 425.097,1305.98 425.106,1305.98 425.115,1305.98 425.124,1305.98 425.134,1305.97 425.143,1305.97 425.152,1305.97 425.161,1305.97 425.17,1305.96 425.18,1305.96 425.189,1305.96 425.198,1305.96 425.207,1305.96 425.216,1305.95 425.225,1305.95 425.235,1305.95 425.244,1305.95 425.253,1305.94 425.262,1305.94 425.271,1305.94 425.281,1305.94 425.29,1305.94 425.299,1305.93 425.308,1305.93 425.317,1305.93 425.327,1305.93 425.336,1305.92 425.345,1305.92 425.354,1305.92 425.363,1305.92 425.373,1305.92 425.382,1305.91 425.391,1305.91 425.4,1305.91 425.409,1305.91 425.418,1305.9 425.428,1305.9 425.437,1305.9 425.446,1305.9 425.455,1305.9 425.464,1305.89 425.474,1305.89 425.483,1305.89 425.492,1305.89 425.501,1305.88 425.51,1305.88 425.52,1305.88 425.529,1305.88 425.538,1305.88 425.547,1305.87 425.556,1305.87 425.565,1305.87 425.575,1305.87 425.584,1305.86 425.593,1305.86 425.602,1305.86 425.611,1305.86 425.621,1305.86 425.63,1305.85 425.639,1305.85 425.648,1305.85 425.657,1305.85 425.667,1305.84 425.676,1305.84 425.685,1305.84 425.694,1305.84 425.703,1305.84 425.713,1305.83 425.722,1305.83 425.731,1305.83 425.74,1305.83 425.749,1305.83 425.758,1305.82 425.768,1305.82 425.777,1305.82 425.786,1305.82 425.795,1305.81 425.804,1305.81 425.814,1305.81 425.823,1305.81 425.832,1305.81 425.841,1305.8 425.85,1305.8 425.86,1305.8 425.869,1305.8 425.878,1305.79 425.887,1305.79 425.896,1305.79 425.905,1305.79 425.915,1305.79 425.924,1305.78 425.933,1305.78 425.942,1305.78 425.951,1305.78 425.961,1305.77 425.97,1305.77 425.979,1305.77 425.988,1305.77 425.997,1305.77 426.007,1305.76 426.016,1305.76 426.025,1305.76 426.034,1305.76 426.043,1305.75 426.053,1305.75 426.062,1305.75 426.071,1305.75 426.08,1305.75 426.089,1305.74 426.098,1305.74 426.108,1305.74 426.117,1305.74 426.126,1305.74 426.135,1305.73 426.144,1305.73 426.154,1305.73 426.163,1305.73 426.172,1305.72 426.181,1305.72 426.19,1305.72 426.2,1305.72 426.209,1305.72 426.218,1305.71 426.227,1305.71 426.236,1305.71 426.245,1305.71 426.255,1305.7 426.264,1305.7 426.273,1305.7 426.282,1305.7 426.291,1305.7 426.301,1305.69 426.31,1305.69 426.319,1305.69 426.328,1305.69 426.337,1305.68 426.347,1305.68 426.356,1305.68 426.365,1305.68 426.374,1305.68 426.383,1305.67 426.393,1305.67 426.402,1305.67 426.411,1305.67 426.42,1305.67 426.429,1305.66 426.438,1305.66 426.448,1305.66 426.457,1305.66 426.466,1305.65 426.475,1305.65 426.484,1305.65 426.494,1305.65 426.503,1305.65 426.512,1305.64 426.521,1305.64 426.53,1305.64 426.54,1305.64 426.549,1305.63 426.558,1305.63 426.567,1305.63 426.576,1305.63 426.585,1305.63 426.595,1305.62 426.604,1305.62 426.613,1305.62 426.622,1305.62 426.631,1305.61 426.641,1305.61 426.65,1305.61 426.659,1305.61 426.668,1305.61 426.677,1305.6 426.687,1305.6 426.696,1305.6 426.705,1305.6 426.714,1305.6 426.723,1305.59 426.733,1305.59 426.742,1305.59 426.751,1305.59 426.76,1305.58 426.769,1305.58 426.778,1305.58 426.788,1305.58 426.797,1305.58 426.806,1305.57 426.815,1305.57 426.824,1305.57 426.834,1305.57 426.843,1305.56 426.852,1305.56 426.861,1305.56 426.87,1305.56 426.88,1305.56 426.889,1305.55 426.898,1305.55 426.907,1305.55 426.916,1305.55 426.925,1305.55 426.935,1305.54 426.944,1305.54 426.953,1305.54 426.962,1305.54 426.971,1305.53 426.981,1305.53 426.99,1305.53 426.999,1305.53 427.008,1305.53 427.017,1305.52 427.027,1305.52 427.036,1305.52 427.045,1305.52 427.054,1305.51 427.063,1305.51 427.073,1305.51 427.082,1305.51 427.091,1305.51 427.1,1305.5 427.109,1305.5 427.118,1305.5 427.128,1305.5 427.137,1305.5 427.146,1305.49 427.155,1305.49 427.164,1305.49 427.174,1305.49 427.183,1305.48 427.192,1305.48 427.201,1305.48 427.21,1305.48 427.22,1305.48 427.229,1305.47 427.238,1305.47 427.247,1305.47 427.256,1305.47 427.265,1305.46 427.275,1305.46 427.284,1305.46 427.293,1305.46 427.302,1305.46 427.311,1305.45 427.321,1305.45 427.33,1305.45 427.339,1305.45 427.348,1305.45 427.357,1305.44 427.367,1305.44 427.376,1305.44 427.385,1305.44 427.394,1305.43 427.403,1305.43 427.413,1305.43 427.422,1305.43 427.431,1305.43 427.44,1305.42 427.449,1305.42 427.458,1305.42 427.468,1305.42 427.477,1305.42 427.486,1305.41 427.495,1305.41 427.504,1305.41 427.514,1305.41 427.523,1305.4 427.532,1305.4 427.541,1305.4 427.55,1305.4 427.56,1305.4 427.569,1305.39 427.578,1305.39 427.587,1305.39 427.596,1305.39 427.605,1305.38 427.615,1305.38 427.624,1305.38 427.633,1305.38 427.642,1305.38 427.651,1305.37 427.661,1305.37 427.67,1305.37 427.679,1305.37 427.688,1305.37 427.697,1305.36 427.707,1305.36 427.716,1305.36 427.725,1305.36 427.734,1305.35 427.743,1305.35 427.753,1305.35 427.762,1305.35 427.771,1305.35 427.78,1305.34 427.789,1305.34 427.798,1305.34 427.808,1305.34 427.817,1305.34 427.826,1305.33 427.835,1305.33 427.844,1305.33 427.854,1305.33 427.863,1305.32 427.872,1305.32 427.881,1305.32 427.89,1305.32 427.9,1305.32 427.909,1305.31 427.918,1305.31 427.927,1305.31 427.936,1305.31 427.946,1305.31 427.955,1305.3 427.964,1305.3 427.973,1305.3 427.982,1305.3 427.991,1305.29 428.001,1305.29 428.01,1305.29 428.019,1305.29 428.028,1305.29 428.037,1305.28 428.047,1305.28 428.056,1305.28 428.065,1305.28 428.074,1305.28 428.083,1305.27 428.093,1305.27 428.102,1305.27 428.111,1305.27 428.12,1305.26 428.129,1305.26 428.138,1305.26 428.148,1305.26 428.157,1305.26 428.166,1305.25 428.175,1305.25 428.184,1305.25 428.194,1305.25 428.203,1305.25 428.212,1305.24 428.221,1305.24 428.23,1305.24 428.24,1305.24 428.249,1305.23 428.258,1305.23 428.267,1305.23 428.276,1305.23 428.286,1305.23 428.295,1305.22 428.304,1305.22 428.313,1305.22 428.322,1305.22 428.331,1305.22 428.341,1305.21 428.35,1305.21 428.359,1305.21 428.368,1305.21 428.377,1305.2 428.387,1305.2 428.396,1305.2 428.405,1305.2 428.414,1305.2 428.423,1305.19 428.433,1305.19 428.442,1305.19 428.451,1305.19 428.46,1305.19 428.469,1305.18 428.478,1305.18 428.488,1305.18 428.497,1305.18 428.506,1305.17 428.515,1305.17 428.524,1305.17 428.534,1305.17 428.543,1305.17 428.552,1305.16 428.561,1305.16 428.57,1305.16 428.58,1305.16 428.589,1305.16 428.598,1305.15 428.607,1305.15 428.616,1305.15 428.626,1305.15 428.635,1305.14 428.644,1305.14 428.653,1305.14 428.662,1305.14 428.671,1305.14 428.681,1305.13 428.69,1305.13 428.699,1305.13 428.708,1305.13 428.717,1305.13 428.727,1305.12 428.736,1305.12 428.745,1305.12 428.754,1305.12 428.763,1305.11 428.773,1305.11 428.782,1305.11 428.791,1305.11 428.8,1305.11 428.809,1305.1 428.818,1305.1 428.828,1305.1 428.837,1305.1 428.846,1305.1 428.855,1305.09 428.864,1305.09 428.874,1305.09 428.883,1305.09 428.892,1305.08 428.901,1305.08 428.91,1305.08 428.92,1305.08 428.929,1305.08 428.938,1305.07 428.947,1305.07 428.956,1305.07 428.966,1305.07 428.975,1305.07 428.984,1305.06 428.993,1305.06 429.002,1305.06 429.011,1305.06 429.021,1305.06 429.03,1305.05 429.039,1305.05 429.048,1305.05 429.057,1305.05 429.067,1305.04 429.076,1305.04 429.085,1305.04 429.094,1305.04 429.103,1305.04 429.113,1305.03 429.122,1305.03 429.131,1305.03 429.14,1305.03 429.149,1305.03 429.158,1305.02 429.168,1305.02 429.177,1305.02 429.186,1305.02 429.195,1305.01 429.204,1305.01 429.214,1305.01 429.223,1305.01 429.232,1305.01 429.241,1305 429.25,1305 429.26,1305 429.269,1305 429.278,1305 429.287,1304.99 429.296,1304.99 429.306,1304.99 429.315,1304.99 429.324,1304.98 429.333,1304.98 429.342,1304.98 429.351,1304.98 429.361,1304.98 429.37,1304.97 429.379,1304.97 429.388,1304.97 429.397,1304.97 429.407,1304.97 429.416,1304.96 429.425,1304.96 429.434,1304.96 429.443,1304.96 429.453,1304.96 429.462,1304.95 429.471,1304.95 429.48,1304.95 429.489,1304.95 429.498,1304.94 429.508,1304.94 429.517,1304.94 429.526,1304.94 429.535,1304.94 429.544,1304.93 429.554,1304.93 429.563,1304.93 429.572,1304.93 429.581,1304.93 429.59,1304.92 429.6,1304.92 429.609,1304.92 429.618,1304.92 429.627,1304.92 429.636,1304.91 429.646,1304.91 429.655,1304.91 429.664,1304.91 429.673,1304.9 429.682,1304.9 429.691,1304.9 429.701,1304.9 429.71,1304.9 429.719,1304.89 429.728,1304.89 429.737,1304.89 429.747,1304.89 429.756,1304.89 429.765,1304.88 429.774,1304.88 429.783,1304.88 429.793,1304.88 429.802,1304.88 429.811,1304.87 429.82,1304.87 429.829,1304.87 429.838,1304.87 429.848,1304.86 429.857,1304.86 429.866,1304.86 429.875,1304.86 429.884,1304.86 429.894,1304.85 429.903,1304.85 429.912,1304.85 429.921,1304.85 429.93,1304.85 429.94,1304.84 429.949,1304.84 429.958,1304.84 429.967,1304.84 429.976,1304.84 429.986,1304.83 429.995,1304.83 430.004,1304.83 430.013,1304.83 430.022,1304.82 430.031,1304.82 430.041,1304.82 430.05,1304.82 430.059,1304.82 430.068,1304.81 430.077,1304.81 430.087,1304.81 430.096,1304.81 430.105,1304.81 430.114,1304.8 430.123,1304.8 430.133,1304.8 430.142,1304.8 430.151,1304.8 430.16,1304.79 430.169,1304.79 430.179,1304.79 430.188,1304.79 430.197,1304.78 430.206,1304.78 430.215,1304.78 430.224,1304.78 430.234,1304.78 430.243,1304.77 430.252,1304.77 430.261,1304.77 430.27,1304.77 430.28,1304.77 430.289,1304.76 430.298,1304.76 430.307,1304.76 430.316,1304.76 430.326,1304.76 430.335,1304.75 430.344,1304.75 430.353,1304.75 430.362,1304.75 430.371,1304.74 430.381,1304.74 430.39,1304.74 430.399,1304.74 430.408,1304.74 430.417,1304.73 430.427,1304.73 430.436,1304.73 430.445,1304.73 430.454,1304.73 430.463,1304.72 430.473,1304.72 430.482,1304.72 430.491,1304.72 430.5,1304.72 430.509,1304.71 430.519,1304.71 430.528,1304.71 430.537,1304.71 430.546,1304.7 430.555,1304.7 430.564,1304.7 430.574,1304.7 430.583,1304.7 430.592,1304.69 430.601,1304.69 430.61,1304.69 430.62,1304.69 430.629,1304.69 430.638,1304.68 430.647,1304.68 430.656,1304.68 430.666,1304.68 430.675,1304.68 430.684,1304.67 430.693,1304.67 430.702,1304.67 430.711,1304.67 430.721,1304.67 430.73,1304.66 430.739,1304.66 430.748,1304.66 430.757,1304.66 430.767,1304.65 430.776,1304.65 430.785,1304.65 430.794,1304.65 430.803,1304.65 430.813,1304.64 430.822,1304.64 430.831,1304.64 430.84,1304.64 430.849,1304.64 430.859,1304.63 430.868,1304.63 430.877,1304.63 430.886,1304.63 430.895,1304.63 430.904,1304.62 430.914,1304.62 430.923,1304.62 430.932,1304.62 430.941,1304.62 430.95,1304.61 430.96,1304.61 430.969,1304.61 430.978,1304.61 430.987,1304.6 430.996,1304.6 431.006,1304.6 431.015,1304.6 431.024,1304.6 431.033,1304.59 431.042,1304.59 431.051,1304.59 431.061,1304.59 431.07,1304.59 431.079,1304.58 431.088,1304.58 431.097,1304.58 431.107,1304.58 431.116,1304.58 431.125,1304.57 431.134,1304.57 431.143,1304.57 431.153,1304.57 431.162,1304.57 431.171,1304.56 431.18,1304.56 431.189,1304.56 431.199,1304.56 431.208,1304.55 431.217,1304.55 431.226,1304.55 431.235,1304.55 431.244,1304.55 431.254,1304.54 431.263,1304.54 431.272,1304.54 431.281,1304.54 431.29,1304.54 431.3,1304.53 431.309,1304.53 431.318,1304.53 431.327,1304.53 431.336,1304.53 431.346,1304.52 431.355,1304.52 431.364,1304.52 431.373,1304.52 431.382,1304.52 431.391,1304.51 431.401,1304.51 431.41,1304.51 431.419,1304.51 431.428,1304.5 431.437,1304.5 431.447,1304.5 431.456,1304.5 431.465,1304.5 431.474,1304.49 431.483,1304.49 431.493,1304.49 431.502,1304.49 431.511,1304.49 431.52,1304.48 431.529,1304.48 431.539,1304.48 431.548,1304.48 431.557,1304.48 431.566,1304.47 431.575,1304.47 431.584,1304.47 431.594,1304.47 431.603,1304.47 431.612,1304.46 431.621,1304.46 431.63,1304.46 431.64,1304.46 431.649,1304.46 431.658,1304.45 431.667,1304.45 431.676,1304.45 431.686,1304.45 431.695,1304.44 431.704,1304.44 431.713,1304.44 431.722,1304.44 431.731,1304.44 431.741,1304.43 431.75,1304.43 431.759,1304.43 431.768,1304.43 431.777,1304.43 431.787,1304.42 431.796,1304.42 431.805,1304.42 431.814,1304.42 431.823,1304.42 431.833,1304.41 431.842,1304.41 431.851,1304.41 431.86,1304.41 431.869,1304.41 431.879,1304.4 431.888,1304.4 431.897,1304.4 431.906,1304.4 431.915,1304.4 431.924,1304.39 431.934,1304.39 431.943,1304.39 431.952,1304.39 431.961,1304.39 431.97,1304.38 431.98,1304.38 431.989,1304.38 431.998,1304.38 432.007,1304.37 432.016,1304.37 432.026,1304.37 432.035,1304.37 432.044,1304.37 432.053,1304.36 432.062,1304.36 432.071,1304.36 432.081,1304.36 432.09,1304.36 432.099,1304.35 432.108,1304.35 432.117,1304.35 432.127,1304.35 432.136,1304.35 432.145,1304.34 432.154,1304.34 432.163,1304.34 432.173,1304.34 432.182,1304.34 432.191,1304.33 432.2,1304.33 432.209,1304.33 432.219,1304.33 432.228,1304.33 432.237,1304.32 432.246,1304.32 432.255,1304.32 432.264,1304.32 432.274,1304.32 432.283,1304.31 432.292,1304.31 432.301,1304.31 432.31,1304.31 432.32,1304.3 432.329,1304.3 432.338,1304.3 432.347,1304.3 432.356,1304.3 432.366,1304.29 432.375,1304.29 432.384,1304.29 432.393,1304.29 432.402,1304.29 432.411,1304.28 432.421,1304.28 432.43,1304.28 432.439,1304.28 432.448,1304.28 432.457,1304.27 432.467,1304.27 432.476,1304.27 432.485,1304.27 432.494,1304.27 432.503,1304.26 432.513,1304.26 432.522,1304.26 432.531,1304.26 432.54,1304.26 432.549,1304.25 432.559,1304.25 432.568,1304.25 432.577,1304.25 432.586,1304.25 432.595,1304.24 432.604,1304.24 432.614,1304.24 432.623,1304.24 432.632,1304.24 432.641,1304.23 432.65,1304.23 432.66,1304.23 432.669,1304.23 432.678,1304.22 432.687,1304.22 432.696,1304.22 432.706,1304.22 432.715,1304.22 432.724,1304.21 432.733,1304.21 432.742,1304.21 432.752,1304.21 432.761,1304.21 432.77,1304.2 432.779,1304.2 432.788,1304.2 432.797,1304.2 432.807,1304.2 432.816,1304.19 432.825,1304.19 432.834,1304.19 432.843,1304.19 432.853,1304.19 432.862,1304.18 432.871,1304.18 432.88,1304.18 432.889,1304.18 432.899,1304.18 432.908,1304.17 432.917,1304.17 432.926,1304.17 432.935,1304.17 432.944,1304.17 432.954,1304.16 432.963,1304.16 432.972,1304.16 432.981,1304.16 432.99,1304.16 433,1304.15 433.009,1304.15 433.018,1304.15 433.027,1304.15 433.036,1304.15 433.046,1304.14 433.055,1304.14 433.064,1304.14 433.073,1304.14 433.082,1304.14 433.092,1304.13 433.101,1304.13 433.11,1304.13 433.119,1304.13 433.128,1304.13 433.137,1304.12 433.147,1304.12 433.156,1304.12 433.165,1304.12 433.174,1304.11 433.183,1304.11 433.193,1304.11 433.202,1304.11 433.211,1304.11 433.22,1304.1 433.229,1304.1 433.239,1304.1 433.248,1304.1 433.257,1304.1 433.266,1304.09 433.275,1304.09 433.284,1304.09 433.294,1304.09 433.303,1304.09 433.312,1304.08 433.321,1304.08 433.33,1304.08 433.34,1304.08 433.349,1304.08 433.358,1304.07 433.367,1304.07 433.376,1304.07 433.386,1304.07 433.395,1304.07 433.404,1304.06 433.413,1304.06 433.422,1304.06 433.432,1304.06 433.441,1304.06 433.45,1304.05 433.459,1304.05 433.468,1304.05 433.477,1304.05 433.487,1304.05 433.496,1304.04 433.505,1304.04 433.514,1304.04 433.523,1304.04 433.533,1304.04 433.542,1304.03 433.551,1304.03 433.56,1304.03 433.569,1304.03 433.579,1304.03 433.588,1304.02 433.597,1304.02 433.606,1304.02 433.615,1304.02 433.624,1304.02 433.634,1304.01 433.643,1304.01 433.652,1304.01 433.661,1304.01 433.67,1304.01 433.68,1304 433.689,1304 433.698,1304 433.707,1304 433.716,1304 433.726,1303.99 433.735,1303.99 433.744,1303.99 433.753,1303.99 433.762,1303.99 433.772,1303.98 433.781,1303.98 433.79,1303.98 433.799,1303.98 433.808,1303.97 433.817,1303.97 433.827,1303.97 433.836,1303.97 433.845,1303.97 433.854,1303.96 433.863,1303.96 433.873,1303.96 433.882,1303.96 433.891,1303.96 433.9,1303.95 433.909,1303.95 433.919,1303.95 433.928,1303.95 433.937,1303.95 433.946,1303.94 433.955,1303.94 433.964,1303.94 433.974,1303.94 433.983,1303.94 433.992,1303.93 434.001,1303.93 434.01,1303.93 434.02,1303.93 434.029,1303.93 434.038,1303.92 434.047,1303.92 434.056,1303.92 434.066,1303.92 434.075,1303.92 434.084,1303.91 434.093,1303.91 434.102,1303.91 434.112,1303.91 434.121,1303.91 434.13,1303.9 434.139,1303.9 434.148,1303.9 434.157,1303.9 434.167,1303.9 434.176,1303.89 434.185,1303.89 434.194,1303.89 434.203,1303.89 434.213,1303.89 434.222,1303.88 434.231,1303.88 434.24,1303.88 434.249,1303.88 434.259,1303.88 434.268,1303.87 434.277,1303.87 434.286,1303.87 434.295,1303.87 434.304,1303.87 434.314,1303.86 434.323,1303.86 434.332,1303.86 434.341,1303.86 434.35,1303.86 434.36,1303.85 434.369,1303.85 434.378,1303.85 434.387,1303.85 434.396,1303.85 434.406,1303.84 434.415,1303.84 434.424,1303.84 434.433,1303.84 434.442,1303.84 434.452,1303.83 434.461,1303.83 434.47,1303.83 434.479,1303.83 434.488,1303.83 434.497,1303.82 434.507,1303.82 434.516,1303.82 434.525,1303.82 434.534,1303.82 434.543,1303.81 434.553,1303.81 434.562,1303.81 434.571,1303.81 434.58,1303.81 434.589,1303.8 434.599,1303.8 434.608,1303.8 434.617,1303.8 434.626,1303.8 434.635,1303.79 434.644,1303.79 434.654,1303.79 434.663,1303.79 434.672,1303.79 434.681,1303.78 434.69,1303.78 434.7,1303.78 434.709,1303.78 434.718,1303.78 434.727,1303.77 434.736,1303.77 434.746,1303.77 434.755,1303.77 434.764,1303.77 434.773,1303.76 434.782,1303.76 434.792,1303.76 434.801,1303.76 434.81,1303.76 434.819,1303.75 434.828,1303.75 434.837,1303.75 434.847,1303.75 434.856,1303.75 434.865,1303.74 434.874,1303.74 434.883,1303.74 434.893,1303.74 434.902,1303.74 434.911,1303.73 434.92,1303.73 434.929,1303.73 434.939,1303.73 434.948,1303.73 434.957,1303.72 434.966,1303.72 434.975,1303.72 434.984,1303.72 434.994,1303.72 435.003,1303.71 435.012,1303.71 435.021,1303.71 435.03,1303.71 435.04,1303.71 435.049,1303.7 435.058,1303.7 435.067,1303.7 435.076,1303.7 435.086,1303.7 435.095,1303.69 435.104,1303.69 435.113,1303.69 435.122,1303.69 435.132,1303.69 435.141,1303.68 435.15,1303.68 435.159,1303.68 435.168,1303.68 435.177,1303.68 435.187,1303.67 435.196,1303.67 435.205,1303.67 435.214,1303.67 435.223,1303.67 435.233,1303.66 435.242,1303.66 435.251,1303.66 435.26,1303.66 435.269,1303.66 435.279,1303.65 435.288,1303.65 435.297,1303.65 435.306,1303.65 435.315,1303.65 435.325,1303.64 435.334,1303.64 435.343,1303.64 435.352,1303.64 435.361,1303.64 435.37,1303.63 435.38,1303.63 435.389,1303.63 435.398,1303.63 435.407,1303.63 435.416,1303.62 435.426,1303.62 435.435,1303.62 435.444,1303.62 435.453,1303.62 435.462,1303.61 435.472,1303.61 435.481,1303.61 435.49,1303.61 435.499,1303.61 435.508,1303.6 435.517,1303.6 435.527,1303.6 435.536,1303.6 435.545,1303.6 435.554,1303.59 435.563,1303.59 435.573,1303.59 435.582,1303.59 435.591,1303.59 435.6,1303.58 435.609,1303.58 435.619,1303.58 435.628,1303.58 435.637,1303.58 435.646,1303.57 435.655,1303.57 435.665,1303.57 435.674,1303.57 435.683,1303.57 435.692,1303.57 435.701,1303.56 435.71,1303.56 435.72,1303.56 435.729,1303.56 435.738,1303.56 435.747,1303.55 435.756,1303.55 435.766,1303.55 435.775,1303.55 435.784,1303.55 435.793,1303.54 435.802,1303.54 435.812,1303.54 435.821,1303.54 435.83,1303.54 435.839,1303.53 435.848,1303.53 435.857,1303.53 435.867,1303.53 435.876,1303.53 435.885,1303.52 435.894,1303.52 435.903,1303.52 435.913,1303.52 435.922,1303.52 435.931,1303.51 435.94,1303.51 435.949,1303.51 435.959,1303.51 435.968,1303.51 435.977,1303.5 435.986,1303.5 435.995,1303.5 436.005,1303.5 436.014,1303.5 436.023,1303.49 436.032,1303.49 436.041,1303.49 436.05,1303.49 436.06,1303.49 436.069,1303.48 436.078,1303.48 436.087,1303.48 436.096,1303.48 436.106,1303.48 436.115,1303.47 436.124,1303.47 436.133,1303.47 436.142,1303.47 436.152,1303.47 436.161,1303.46 436.17,1303.46 436.179,1303.46 436.188,1303.46 436.197,1303.46 436.207,1303.45 436.216,1303.45 436.225,1303.45 436.234,1303.45 436.243,1303.45 436.253,1303.44 436.262,1303.44 436.271,1303.44 436.28,1303.44 436.289,1303.44 436.299,1303.43 436.308,1303.43 436.317,1303.43 436.326,1303.43 436.335,1303.43 436.345,1303.43 436.354,1303.42 436.363,1303.42 436.372,1303.42 436.381,1303.42 436.39,1303.42 436.4,1303.41 436.409,1303.41 436.418,1303.41 436.427,1303.41 436.436,1303.41 436.446,1303.4 436.455,1303.4 436.464,1303.4 436.473,1303.4 436.482,1303.4 436.492,1303.39 436.501,1303.39 436.51,1303.39 436.519,1303.39 436.528,1303.39 436.537,1303.38 436.547,1303.38 436.556,1303.38 436.565,1303.38 436.574,1303.38 436.583,1303.37 436.593,1303.37 436.602,1303.37 436.611,1303.37 436.62,1303.37 436.629,1303.36 436.639,1303.36 436.648,1303.36 436.657,1303.36 436.666,1303.36 436.675,1303.35 436.685,1303.35 436.694,1303.35 436.703,1303.35 436.712,1303.35 436.721,1303.34 436.73,1303.34 436.74,1303.34 436.749,1303.34 436.758,1303.34 436.767,1303.33 436.776,1303.33 436.786,1303.33 436.795,1303.33 436.804,1303.33 436.813,1303.33 436.822,1303.32 436.832,1303.32 436.841,1303.32 436.85,1303.32 436.859,1303.32 436.868,1303.31 436.877,1303.31 436.887,1303.31 436.896,1303.31 436.905,1303.31 436.914,1303.3 436.923,1303.3 436.933,1303.3 436.942,1303.3 436.951,1303.3 436.96,1303.29 436.969,1303.29 436.979,1303.29 436.988,1303.29 436.997,1303.29 437.006,1303.28 437.015,1303.28 437.025,1303.28 437.034,1303.28 437.043,1303.28 437.052,1303.27 437.061,1303.27 437.07,1303.27 437.08,1303.27 437.089,1303.27 437.098,1303.26 437.107,1303.26 437.116,1303.26 437.126,1303.26 437.135,1303.26 437.144,1303.25 437.153,1303.25 437.162,1303.25 437.172,1303.25 437.181,1303.25 437.19,1303.25 437.199,1303.24 437.208,1303.24 437.217,1303.24 437.227,1303.24 437.236,1303.24 437.245,1303.23 437.254,1303.23 437.263,1303.23 437.273,1303.23 437.282,1303.23 437.291,1303.22 437.3,1303.22 437.309,1303.22 437.319,1303.22 437.328,1303.22 437.337,1303.21 437.346,1303.21 437.355,1303.21 437.365,1303.21 437.374,1303.21 437.383,1303.2 437.392,1303.2 437.401,1303.2 437.41,1303.2 437.42,1303.2 437.429,1303.19 437.438,1303.19 437.447,1303.19 437.456,1303.19 437.466,1303.19 437.475,1303.18 437.484,1303.18 437.493,1303.18 437.502,1303.18 437.512,1303.18 437.521,1303.18 437.53,1303.17 437.539,1303.17 437.548,1303.17 437.558,1303.17 437.567,1303.17 437.576,1303.16 437.585,1303.16 437.594,1303.16 437.603,1303.16 437.613,1303.16 437.622,1303.15 437.631,1303.15 437.64,1303.15 437.649,1303.15 437.659,1303.15 437.668,1303.14 437.677,1303.14 437.686,1303.14 437.695,1303.14 437.705,1303.14 437.714,1303.13 437.723,1303.13 437.732,1303.13 437.741,1303.13 437.75,1303.13 437.76,1303.12 437.769,1303.12 437.778,1303.12 437.787,1303.12 437.796,1303.12 437.806,1303.12 437.815,1303.11 437.824,1303.11 437.833,1303.11 437.842,1303.11 437.852,1303.11 437.861,1303.1 437.87,1303.1 437.879,1303.1 437.888,1303.1 437.898,1303.1 437.907,1303.09 437.916,1303.09 437.925,1303.09 437.934,1303.09 437.943,1303.09 437.953,1303.08 437.962,1303.08 437.971,1303.08 437.98,1303.08 437.989,1303.08 437.999,1303.07 438.008,1303.07 438.017,1303.07 438.026,1303.07 438.035,1303.07 438.045,1303.06 438.054,1303.06 438.063,1303.06 438.072,1303.06 438.081,1303.06 438.09,1303.06 438.1,1303.05 438.109,1303.05 438.118,1303.05 438.127,1303.05 438.136,1303.05 438.146,1303.04 438.155,1303.04 438.164,1303.04 438.173,1303.04 438.182,1303.04 438.192,1303.03 438.201,1303.03 438.21,1303.03 438.219,1303.03 438.228,1303.03 438.238,1303.02 438.247,1303.02 438.256,1303.02 438.265,1303.02 438.274,1303.02 438.283,1303.01 438.293,1303.01 438.302,1303.01 438.311,1303.01 438.32,1303.01 438.329,1303.01 438.339,1303 438.348,1303 438.357,1303 438.366,1303 438.375,1303 438.385,1302.99 438.394,1302.99 438.403,1302.99 438.412,1302.99 438.421,1302.99 438.43,1302.98 438.44,1302.98 438.449,1302.98 438.458,1302.98 438.467,1302.98 438.476,1302.97 438.486,1302.97 438.495,1302.97 438.504,1302.97 438.513,1302.97 438.522,1302.96 438.532,1302.96 438.541,1302.96 438.55,1302.96 438.559,1302.96 438.568,1302.96 438.578,1302.95 438.587,1302.95 438.596,1302.95 438.605,1302.95 438.614,1302.95 438.623,1302.94 438.633,1302.94 438.642,1302.94 438.651,1302.94 438.66,1302.94 438.669,1302.93 438.679,1302.93 438.688,1302.93 438.697,1302.93 438.706,1302.93 438.715,1302.92 438.725,1302.92 438.734,1302.92 438.743,1302.92 438.752,1302.92 438.761,1302.92 438.77,1302.91 438.78,1302.91 438.789,1302.91 438.798,1302.91 438.807,1302.91 438.816,1302.9 438.826,1302.9 438.835,1302.9 438.844,1302.9 438.853,1302.9 438.862,1302.89 438.872,1302.89 438.881,1302.89 438.89,1302.89 438.899,1302.89 438.908,1302.88 438.918,1302.88 438.927,1302.88 438.936,1302.88 438.945,1302.88 438.954,1302.87 438.963,1302.87 438.973,1302.87 438.982,1302.87 438.991,1302.87 439,1302.87 439.009,1302.86 439.019,1302.86 439.028,1302.86 439.037,1302.86 439.046,1302.86 439.055,1302.85 439.065,1302.85 439.074,1302.85 439.083,1302.85 439.092,1302.85 439.101,1302.84 439.11,1302.84 439.12,1302.84 439.129,1302.84 439.138,1302.84 439.147,1302.83 439.156,1302.83 439.166,1302.83 439.175,1302.83 439.184,1302.83 439.193,1302.83 439.202,1302.82 439.212,1302.82 439.221,1302.82 439.23,1302.82 439.239,1302.82 439.248,1302.81 439.258,1302.81 439.267,1302.81 439.276,1302.81 439.285,1302.81 439.294,1302.8 439.303,1302.8 439.313,1302.8 439.322,1302.8 439.331,1302.8 439.34,1302.79 439.349,1302.79 439.359,1302.79 439.368,1302.79 439.377,1302.79 439.386,1302.79 439.395,1302.78 439.405,1302.78 439.414,1302.78 439.423,1302.78 439.432,1302.78 439.441,1302.77 439.45,1302.77 439.46,1302.77 439.469,1302.77 439.478,1302.77 439.487,1302.76 439.496,1302.76 439.506,1302.76 439.515,1302.76 439.524,1302.76 439.533,1302.75 439.542,1302.75 439.552,1302.75 439.561,1302.75 439.57,1302.75 439.579,1302.75 439.588,1302.74 439.598,1302.74 439.607,1302.74 439.616,1302.74 439.625,1302.74 439.634,1302.73 439.643,1302.73 439.653,1302.73 439.662,1302.73 439.671,1302.73 439.68,1302.72 439.689,1302.72 439.699,1302.72 439.708,1302.72 439.717,1302.72 439.726,1302.72 439.735,1302.71 439.745,1302.71 439.754,1302.71 439.763,1302.71 439.772,1302.71 439.781,1302.7 439.79,1302.7 439.8,1302.7 439.809,1302.7 439.818,1302.7 439.827,1302.69 439.836,1302.69 439.846,1302.69 439.855,1302.69 439.864,1302.69 439.873,1302.68 439.882,1302.68 439.892,1302.68 439.901,1302.68 439.91,1302.68 439.919,1302.68 439.928,1302.67 439.938,1302.67 439.947,1302.67 439.956,1302.67 439.965,1302.67 439.974,1302.66 439.983,1302.66 439.993,1302.66 440.002,1302.66 440.011,1302.66 440.02,1302.65 440.029,1302.65 440.039,1302.65 440.048,1302.65 440.057,1302.65 440.066,1302.65 440.075,1302.64 440.085,1302.64 440.094,1302.64 440.103,1302.64 440.112,1302.64 440.121,1302.63 440.131,1302.63 440.14,1302.63 440.149,1302.63 440.158,1302.63 440.167,1302.62 440.176,1302.62 440.186,1302.62 440.195,1302.62 440.204,1302.62 440.213,1302.62 440.222,1302.61 440.232,1302.61 440.241,1302.61 440.25,1302.61 440.259,1302.61 440.268,1302.6 440.278,1302.6 440.287,1302.6 440.296,1302.6 440.305,1302.6 440.314,1302.59 440.323,1302.59 440.333,1302.59 440.342,1302.59 440.351,1302.59 440.36,1302.59 440.369,1302.58 440.379,1302.58 440.388,1302.58 440.397,1302.58 440.406,1302.58 440.415,1302.57 440.425,1302.57 440.434,1302.57 440.443,1302.57 440.452,1302.57 440.461,1302.56 440.471,1302.56 440.48,1302.56 440.489,1302.56 440.498,1302.56 440.507,1302.55 440.516,1302.55 440.526,1302.55 440.535,1302.55 440.544,1302.55 440.553,1302.55 440.562,1302.54 440.572,1302.54 440.581,1302.54 440.59,1302.54 440.599,1302.54 440.608,1302.53 440.618,1302.53 440.627,1302.53 440.636,1302.53 440.645,1302.53 440.654,1302.52 440.663,1302.52 440.673,1302.52 440.682,1302.52 440.691,1302.52 440.7,1302.52 440.709,1302.51 440.719,1302.51 440.728,1302.51 440.737,1302.51 440.746,1302.51 440.755,1302.5 440.765,1302.5 440.774,1302.5 440.783,1302.5 440.792,1302.5 440.801,1302.5 440.811,1302.49 440.82,1302.49 440.829,1302.49 440.838,1302.49 440.847,1302.49 440.856,1302.48 440.866,1302.48 440.875,1302.48 440.884,1302.48 440.893,1302.48 440.902,1302.47 440.912,1302.47 440.921,1302.47 440.93,1302.47 440.939,1302.47 440.948,1302.47 440.958,1302.46 440.967,1302.46 440.976,1302.46 440.985,1302.46 440.994,1302.46 441.003,1302.45 441.013,1302.45 441.022,1302.45 441.031,1302.45 441.04,1302.45 441.049,1302.44 441.059,1302.44 441.068,1302.44 441.077,1302.44 441.086,1302.44 441.095,1302.44 441.105,1302.43 441.114,1302.43 441.123,1302.43 441.132,1302.43 441.141,1302.43 441.151,1302.42 441.16,1302.42 441.169,1302.42 441.178,1302.42 441.187,1302.42 441.196,1302.41 441.206,1302.41 441.215,1302.41 441.224,1302.41 441.233,1302.41 441.242,1302.41 441.252,1302.4 441.261,1302.4 441.27,1302.4 441.279,1302.4 441.288,1302.4 441.298,1302.39 441.307,1302.39 441.316,1302.39 441.325,1302.39 441.334,1302.39 441.343,1302.39 441.353,1302.38 441.362,1302.38 441.371,1302.38 441.38,1302.38 441.389,1302.38 441.399,1302.37 441.408,1302.37 441.417,1302.37 441.426,1302.37 441.435,1302.37 441.445,1302.36 441.454,1302.36 441.463,1302.36 441.472,1302.36 441.481,1302.36 441.491,1302.36 441.5,1302.35 441.509,1302.35 441.518,1302.35 441.527,1302.35 441.536,1302.35 441.546,1302.34 441.555,1302.34 441.564,1302.34 441.573,1302.34 441.582,1302.34 441.592,1302.33 441.601,1302.33 441.61,1302.33 441.619,1302.33 441.628,1302.33 441.638,1302.33 441.647,1302.32 441.656,1302.32 441.665,1302.32 441.674,1302.32 441.683,1302.32 441.693,1302.31 441.702,1302.31 441.711,1302.31 441.72,1302.31 441.729,1302.31 441.739,1302.31 441.748,1302.3 441.757,1302.3 441.766,1302.3 441.775,1302.3 441.785,1302.3 441.794,1302.29 441.803,1302.29 441.812,1302.29 441.821,1302.29 441.831,1302.29 441.84,1302.28 441.849,1302.28 441.858,1302.28 441.867,1302.28 441.876,1302.28 441.886,1302.28 441.895,1302.27 441.904,1302.27 441.913,1302.27 441.922,1302.27 441.932,1302.27 441.941,1302.26 441.95,1302.26 441.959,1302.26 441.968,1302.26 441.978,1302.26 441.987,1302.26 441.996,1302.25 442.005,1302.25 442.014,1302.25 442.023,1302.25 442.033,1302.25 442.042,1302.24 442.051,1302.24 442.06,1302.24 442.069,1302.24 442.079,1302.24 442.088,1302.24 442.097,1302.23 442.106,1302.23 442.115,1302.23 442.125,1302.23 442.134,1302.23 442.143,1302.22 442.152,1302.22 442.161,1302.22 442.171,1302.22 442.18,1302.22 442.189,1302.21 442.198,1302.21 442.207,1302.21 442.216,1302.21 442.226,1302.21 442.235,1302.21 442.244,1302.2 442.253,1302.2 442.262,1302.2 442.272,1302.2 442.281,1302.2 442.29,1302.19 442.299,1302.19 442.308,1302.19 442.318,1302.19 442.327,1302.19 442.336,1302.19 442.345,1302.18 442.354,1302.18 442.363,1302.18 442.373,1302.18 442.382,1302.18 442.391,1302.17 442.4,1302.17 442.409,1302.17 442.419,1302.17 442.428,1302.17 442.437,1302.17 442.446,1302.16 442.455,1302.16 442.465,1302.16 442.474,1302.16 442.483,1302.16 442.492,1302.15 442.501,1302.15 442.511,1302.15 442.52,1302.15 442.529,1302.15 442.538,1302.14 442.547,1302.14 442.556,1302.14 442.566,1302.14 442.575,1302.14 442.584,1302.14 442.593,1302.13 442.602,1302.13 442.612,1302.13 442.621,1302.13 442.63,1302.13 442.639,1302.12 442.648,1302.12 442.658,1302.12 442.667,1302.12 442.676,1302.12 442.685,1302.12 442.694,1302.11 442.704,1302.11 442.713,1302.11 442.722,1302.11 442.731,1302.11 442.74,1302.1 442.749,1302.1 442.759,1302.1 442.768,1302.1 442.777,1302.1 442.786,1302.1 442.795,1302.09 442.805,1302.09 442.814,1302.09 442.823,1302.09 442.832,1302.09 442.841,1302.08 442.851,1302.08 442.86,1302.08 442.869,1302.08 442.878,1302.08 442.887,1302.08 442.896,1302.07 442.906,1302.07 442.915,1302.07 442.924,1302.07 442.933,1302.07 442.942,1302.06 442.952,1302.06 442.961,1302.06 442.97,1302.06 442.979,1302.06 442.988,1302.06 442.998,1302.05 443.007,1302.05 443.016,1302.05 443.025,1302.05 443.034,1302.05 443.044,1302.04 443.053,1302.04 443.062,1302.04 443.071,1302.04 443.08,1302.04 443.089,1302.04 443.099,1302.03 443.108,1302.03 443.117,1302.03 443.126,1302.03 443.135,1302.03 443.145,1302.02 443.154,1302.02 443.163,1302.02 443.172,1302.02 443.181,1302.02 443.191,1302.02 443.2,1302.01 443.209,1302.01 443.218,1302.01 443.227,1302.01 443.236,1302.01 443.246,1302 443.255,1302 443.264,1302 443.273,1302 443.282,1302 443.292,1302 443.301,1301.99 443.31,1301.99 443.319,1301.99 443.328,1301.99 443.338,1301.99 443.347,1301.98 443.356,1301.98 443.365,1301.98 443.374,1301.98 443.384,1301.98 443.393,1301.98 443.402,1301.97 443.411,1301.97 443.42,1301.97 443.429,1301.97 443.439,1301.97 443.448,1301.96 443.457,1301.96 443.466,1301.96 443.475,1301.96 443.485,1301.96 443.494,1301.96 443.503,1301.95 443.512,1301.95 443.521,1301.95 443.531,1301.95 443.54,1301.95 443.549,1301.94 443.558,1301.94 443.567,1301.94 443.576,1301.94 443.586,1301.94 443.595,1301.94 443.604,1301.93 443.613,1301.93 443.622,1301.93 443.632,1301.93 443.641,1301.93 443.65,1301.92 443.659,1301.92 443.668,1301.92 443.678,1301.92 443.687,1301.92 443.696,1301.92 443.705,1301.91 443.714,1301.91 443.724,1301.91 443.733,1301.91 443.742,1301.91 443.751,1301.9 443.76,1301.9 443.769,1301.9 443.779,1301.9 443.788,1301.9 443.797,1301.9 443.806,1301.89 443.815,1301.89 443.825,1301.89 443.834,1301.89 443.843,1301.89 443.852,1301.88 443.861,1301.88 443.871,1301.88 443.88,1301.88 443.889,1301.88 443.898,1301.88 443.907,1301.87 443.916,1301.87 443.926,1301.87 443.935,1301.87 443.944,1301.87 443.953,1301.86 443.962,1301.86 443.972,1301.86 443.981,1301.86 443.99,1301.86 443.999,1301.86 444.008,1301.85 444.018,1301.85 444.027,1301.85 444.036,1301.85 444.045,1301.85 444.054,1301.84 444.064,1301.84 444.073,1301.84 444.082,1301.84 444.091,1301.84 444.1,1301.84 444.109,1301.83 444.119,1301.83 444.128,1301.83 444.137,1301.83 444.146,1301.83 444.155,1301.83 444.165,1301.82 444.174,1301.82 444.183,1301.82 444.192,1301.82 444.201,1301.82 444.211,1301.81 444.22,1301.81 444.229,1301.81 444.238,1301.81 444.247,1301.81 444.256,1301.81 444.266,1301.8 444.275,1301.8 444.284,1301.8 444.293,1301.8 444.302,1301.8 444.312,1301.79 444.321,1301.79 444.33,1301.79 444.339,1301.79 444.348,1301.79 444.358,1301.79 444.367,1301.78 444.376,1301.78 444.385,1301.78 444.394,1301.78 444.404,1301.78 444.413,1301.77 444.422,1301.77 444.431,1301.77 444.44,1301.77 444.449,1301.77 444.459,1301.77 444.468,1301.76 444.477,1301.76 444.486,1301.76 444.495,1301.76 444.505,1301.76 444.514,1301.75 444.523,1301.75 444.532,1301.75 444.541,1301.75 444.551,1301.75 444.56,1301.75 444.569,1301.74 444.578,1301.74 444.587,1301.74 444.596,1301.74 444.606,1301.74 444.615,1301.74 444.624,1301.73 444.633,1301.73 444.642,1301.73 444.652,1301.73 444.661,1301.73 444.67,1301.72 444.679,1301.72 444.688,1301.72 444.698,1301.72 444.707,1301.72 444.716,1301.72 444.725,1301.71 444.734,1301.71 444.744,1301.71 444.753,1301.71 444.762,1301.71 444.771,1301.7 444.78,1301.7 444.789,1301.7 444.799,1301.7 444.808,1301.7 444.817,1301.7 444.826,1301.69 444.835,1301.69 444.845,1301.69 444.854,1301.69 444.863,1301.69 444.872,1301.69 444.881,1301.68 444.891,1301.68 444.9,1301.68 444.909,1301.68 444.918,1301.68 444.927,1301.67 444.937,1301.67 444.946,1301.67 444.955,1301.67 444.964,1301.67 444.973,1301.67 444.982,1301.66 444.992,1301.66 445.001,1301.66 445.01,1301.66 445.019,1301.66 445.028,1301.65 445.038,1301.65 445.047,1301.65 445.056,1301.65 445.065,1301.65 445.074,1301.65 445.084,1301.64 445.093,1301.64 445.102,1301.64 445.111,1301.64 445.12,1301.64 445.129,1301.64 445.139,1301.63 445.148,1301.63 445.157,1301.63 445.166,1301.63 445.175,1301.63 445.185,1301.62 445.194,1301.62 445.203,1301.62 445.212,1301.62 445.221,1301.62 445.231,1301.62 445.24,1301.61 445.249,1301.61 445.258,1301.61 445.267,1301.61 445.277,1301.61 445.286,1301.6 445.295,1301.6 445.304,1301.6 445.313,1301.6 445.322,1301.6 445.332,1301.6 445.341,1301.59 445.35,1301.59 445.359,1301.59 445.368,1301.59 445.378,1301.59 445.387,1301.59 445.396,1301.58 445.405,1301.58 445.414,1301.58 445.424,1301.58 445.433,1301.58 445.442,1301.57 445.451,1301.57 445.46,1301.57 445.469,1301.57 445.479,1301.57 445.488,1301.57 445.497,1301.56 445.506,1301.56 445.515,1301.56 445.525,1301.56 445.534,1301.56 445.543,1301.56 445.552,1301.55 445.561,1301.55 445.571,1301.55 445.58,1301.55 445.589,1301.55 445.598,1301.54 445.607,1301.54 445.617,1301.54 445.626,1301.54 445.635,1301.54 445.644,1301.54 445.653,1301.53 445.662,1301.53 445.672,1301.53 445.681,1301.53 445.69,1301.53 445.699,1301.53 445.708,1301.52 445.718,1301.52 445.727,1301.52 445.736,1301.52 445.745,1301.52 445.754,1301.51 445.764,1301.51 445.773,1301.51 445.782,1301.51 445.791,1301.51 445.8,1301.51 445.809,1301.5 445.819,1301.5 445.828,1301.5 445.837,1301.5 445.846,1301.5 445.855,1301.5 445.865,1301.49 445.874,1301.49 445.883,1301.49 445.892,1301.49 445.901,1301.49 445.911,1301.48 445.92,1301.48 445.929,1301.48 445.938,1301.48 445.947,1301.48 445.957,1301.48 445.966,1301.47 445.975,1301.47 445.984,1301.47 445.993,1301.47 446.002,1301.47 446.012,1301.47 446.021,1301.46 446.03,1301.46 446.039,1301.46 446.048,1301.46 446.058,1301.46 446.067,1301.45 446.076,1301.45 446.085,1301.45 446.094,1301.45 446.104,1301.45 446.113,1301.45 446.122,1301.44 446.131,1301.44 446.14,1301.44 446.149,1301.44 446.159,1301.44 446.168,1301.44 446.177,1301.43 446.186,1301.43 446.195,1301.43 446.205,1301.43 446.214,1301.43 446.223,1301.42 446.232,1301.42 446.241,1301.42 446.251,1301.42 446.26,1301.42 446.269,1301.42 446.278,1301.41 446.287,1301.41 446.297,1301.41 446.306,1301.41 446.315,1301.41 446.324,1301.41 446.333,1301.4 446.342,1301.4 446.352,1301.4 446.361,1301.4 446.37,1301.4 446.379,1301.39 446.388,1301.39 446.398,1301.39 446.407,1301.39 446.416,1301.39 446.425,1301.39 446.434,1301.38 446.444,1301.38 446.453,1301.38 446.462,1301.38 446.471,1301.38 446.48,1301.38 446.489,1301.37 446.499,1301.37 446.508,1301.37 446.517,1301.37 446.526,1301.37 446.535,1301.36 446.545,1301.36 446.554,1301.36 446.563,1301.36 446.572,1301.36 446.581,1301.36 446.591,1301.35 446.6,1301.35 446.609,1301.35 446.618,1301.35 446.627,1301.35 446.637,1301.35 446.646,1301.34 446.655,1301.34 446.664,1301.34 446.673,1301.34 446.682,1301.34 446.692,1301.34 446.701,1301.33 446.71,1301.33 446.719,1301.33 446.728,1301.33 446.738,1301.33 446.747,1301.32 446.756,1301.32 446.765,1301.32 446.774,1301.32 446.784,1301.32 446.793,1301.32 446.802,1301.31 446.811,1301.31 446.82,1301.31 446.829,1301.31 446.839,1301.31 446.848,1301.31 446.857,1301.3 446.866,1301.3 446.875,1301.3 446.885,1301.3 446.894,1301.3 446.903,1301.29 446.912,1301.29 446.921,1301.29 446.931,1301.29 446.94,1301.29 446.949,1301.29 446.958,1301.28 446.967,1301.28 446.977,1301.28 446.986,1301.28 446.995,1301.28 447.004,1301.28 447.013,1301.27 447.022,1301.27 447.032,1301.27 447.041,1301.27 447.05,1301.27 447.059,1301.27 447.068,1301.26 447.078,1301.26 447.087,1301.26 447.096,1301.26 447.105,1301.26 447.114,1301.25 447.124,1301.25 447.133,1301.25 447.142,1301.25 447.151,1301.25 447.16,1301.25 447.169,1301.24 447.179,1301.24 447.188,1301.24 447.197,1301.24 447.206,1301.24 447.215,1301.24 447.225,1301.23 447.234,1301.23 447.243,1301.23 447.252,1301.23 447.261,1301.23 447.271,1301.23 447.28,1301.22 447.289,1301.22 447.298,1301.22 447.307,1301.22 447.317,1301.22 447.326,1301.21 447.335,1301.21 447.344,1301.21 447.353,1301.21 447.362,1301.21 447.372,1301.21 447.381,1301.2 447.39,1301.2 447.399,1301.2 447.408,1301.2 447.418,1301.2 447.427,1301.2 447.436,1301.19 447.445,1301.19 447.454,1301.19 447.464,1301.19 447.473,1301.19 447.482,1301.19 447.491,1301.18 447.5,1301.18 447.51,1301.18 447.519,1301.18 447.528,1301.18 447.537,1301.17 447.546,1301.17 447.555,1301.17 447.565,1301.17 447.574,1301.17 447.583,1301.17 447.592,1301.16 447.601,1301.16 447.611,1301.16 447.62,1301.16 447.629,1301.16 447.638,1301.16 447.647,1301.15 447.657,1301.15 447.666,1301.15 447.675,1301.15 447.684,1301.15 447.693,1301.15 447.702,1301.14 447.712,1301.14 447.721,1301.14 447.73,1301.14 447.739,1301.14 447.748,1301.14 447.758,1301.13 447.767,1301.13 447.776,1301.13 447.785,1301.13 447.794,1301.13 447.804,1301.12 447.813,1301.12 447.822,1301.12 447.831,1301.12 447.84,1301.12 447.85,1301.12 447.859,1301.11 447.868,1301.11 447.877,1301.11 447.886,1301.11 447.895,1301.11 447.905,1301.11 447.914,1301.1 447.923,1301.1 447.932,1301.1 447.941,1301.1 447.951,1301.1 447.96,1301.1 447.969,1301.09 447.978,1301.09 447.987,1301.09 447.997,1301.09 448.006,1301.09 448.015,1301.09 448.024,1301.08 448.033,1301.08 448.042,1301.08 448.052,1301.08 448.061,1301.08 448.07,1301.07 448.079,1301.07 448.088,1301.07 448.098,1301.07 448.107,1301.07 448.116,1301.07 448.125,1301.06 448.134,1301.06 448.144,1301.06 448.153,1301.06 448.162,1301.06 448.171,1301.06 448.18,1301.05 448.19,1301.05 448.199,1301.05 448.208,1301.05 448.217,1301.05 448.226,1301.05 448.235,1301.04 448.245,1301.04 448.254,1301.04 448.263,1301.04 448.272,1301.04 448.281,1301.04 448.291,1301.03 448.3,1301.03 448.309,1301.03 448.318,1301.03 448.327,1301.03 448.337,1301.02 448.346,1301.02 448.355,1301.02 448.364,1301.02 448.373,1301.02 448.382,1301.02 448.392,1301.01 448.401,1301.01 448.41,1301.01 448.419,1301.01 448.428,1301.01 448.438,1301.01 448.447,1301 448.456,1301 448.465,1301 448.474,1301 448.484,1301 448.493,1301 448.502,1300.99 448.511,1300.99 448.52,1300.99 448.53,1300.99 448.539,1300.99 448.548,1300.99 448.557,1300.98 448.566,1300.98 448.575,1300.98 448.585,1300.98 448.594,1300.98 448.603,1300.98 448.612,1300.97 448.621,1300.97 448.631,1300.97 448.64,1300.97 448.649,1300.97 448.658,1300.96 448.667,1300.96 448.677,1300.96 448.686,1300.96 448.695,1300.96 448.704,1300.96 448.713,1300.95 448.722,1300.95 448.732,1300.95 448.741,1300.95 448.75,1300.95 448.759,1300.95 448.768,1300.94 448.778,1300.94 448.787,1300.94 448.796,1300.94 448.805,1300.94 448.814,1300.94 448.824,1300.93 448.833,1300.93 448.842,1300.93 448.851,1300.93 448.86,1300.93 448.87,1300.93 448.879,1300.92 448.888,1300.92 448.897,1300.92 448.906,1300.92 448.915,1300.92 448.925,1300.92 448.934,1300.91 448.943,1300.91 448.952,1300.91 448.961,1300.91 448.971,1300.91 448.98,1300.91 448.989,1300.9 448.998,1300.9 449.007,1300.9 449.017,1300.9 449.026,1300.9 449.035,1300.89 449.044,1300.89 449.053,1300.89 449.062,1300.89 449.072,1300.89 449.081,1300.89 449.09,1300.88 449.099,1300.88 449.108,1300.88 449.118,1300.88 449.127,1300.88 449.136,1300.88 449.145,1300.87 449.154,1300.87 449.164,1300.87 449.173,1300.87 449.182,1300.87 449.191,1300.87 449.2,1300.86 449.21,1300.86 449.219,1300.86 449.228,1300.86 449.237,1300.86 449.246,1300.86 449.255,1300.85 449.265,1300.85 449.274,1300.85 449.283,1300.85 449.292,1300.85 449.301,1300.85 449.311,1300.84 449.32,1300.84 449.329,1300.84 449.338,1300.84 449.347,1300.84 449.357,1300.84 449.366,1300.83 449.375,1300.83 449.384,1300.83 449.393,1300.83 449.402,1300.83 449.412,1300.83 449.421,1300.82 449.43,1300.82 449.439,1300.82 449.448,1300.82 449.458,1300.82 449.467,1300.82 449.476,1300.81 449.485,1300.81 449.494,1300.81 449.504,1300.81 449.513,1300.81 449.522,1300.8 449.531,1300.8 449.54,1300.8 449.55,1300.8 449.559,1300.8 449.568,1300.8 449.577,1300.79 449.586,1300.79 449.595,1300.79 449.605,1300.79 449.614,1300.79 449.623,1300.79 449.632,1300.78 449.641,1300.78 449.651,1300.78 449.66,1300.78 449.669,1300.78 449.678,1300.78 449.687,1300.77 449.697,1300.77 449.706,1300.77 449.715,1300.77 449.724,1300.77 449.733,1300.77 449.742,1300.76 449.752,1300.76 449.761,1300.76 449.77,1300.76 449.779,1300.76 449.788,1300.76 449.798,1300.75 449.807,1300.75 449.816,1300.75 449.825,1300.75 449.834,1300.75 449.844,1300.75 449.853,1300.74 449.862,1300.74 449.871,1300.74 449.88,1300.74 449.89,1300.74 449.899,1300.74 449.908,1300.73 449.917,1300.73 449.926,1300.73 449.935,1300.73 449.945,1300.73 449.954,1300.73 449.963,1300.72 449.972,1300.72 449.981,1300.72 449.991,1300.72 450,1300.72 450.009,1300.72 450.018,1300.71 450.027,1300.71 450.037,1300.71 450.046,1300.71 450.055,1300.71 450.064,1300.71 450.073,1300.7 450.083,1300.7 450.092,1300.7 450.101,1300.7 450.11,1300.7 450.119,1300.7 450.128,1300.69 450.138,1300.69 450.147,1300.69 450.156,1300.69 450.165,1300.69 450.174,1300.69 450.184,1300.68 450.193,1300.68 450.202,1300.68 450.211,1300.68 450.22,1300.68 450.23,1300.68 450.239,1300.67 450.248,1300.67 450.257,1300.67 450.266,1300.67 450.275,1300.67 450.285,1300.66 450.294,1300.66 450.303,1300.66 450.312,1300.66 450.321,1300.66 450.331,1300.66 450.34,1300.65 450.349,1300.65 450.358,1300.65 450.367,1300.65 450.377,1300.65 450.386,1300.65 450.395,1300.64 450.404,1300.64 450.413,1300.64 450.423,1300.64 450.432,1300.64 450.441,1300.64 450.45,1300.63 450.459,1300.63 450.468,1300.63 450.478,1300.63 450.487,1300.63 450.496,1300.63 450.505,1300.62 450.514,1300.62 450.524,1300.62 450.533,1300.62 450.542,1300.62 450.551,1300.62 450.56,1300.61 450.57,1300.61 450.579,1300.61 450.588,1300.61 450.597,1300.61 450.606,1300.61 450.615,1300.6 450.625,1300.6 450.634,1300.6 450.643,1300.6 450.652,1300.6 450.661,1300.6 450.671,1300.59 450.68,1300.59 450.689,1300.59 450.698,1300.59 450.707,1300.59 450.717,1300.59 450.726,1300.58 450.735,1300.58 450.744,1300.58 450.753,1300.58 450.763,1300.58 450.772,1300.58 450.781,1300.57 450.79,1300.57 450.799,1300.57 450.808,1300.57 450.818,1300.57 450.827,1300.57 450.836,1300.56 450.845,1300.56 450.854,1300.56 450.864,1300.56 450.873,1300.56 450.882,1300.56 450.891,1300.55 450.9,1300.55 450.91,1300.55 450.919,1300.55 450.928,1300.55 450.937,1300.55 450.946,1300.54 450.955,1300.54 450.965,1300.54 450.974,1300.54 450.983,1300.54 450.992,1300.54 451.001,1300.53 451.011,1300.53 451.02,1300.53 451.029,1300.53 451.038,1300.53 451.047,1300.53 451.057,1300.52 451.066,1300.52 451.075,1300.52 451.084,1300.52 451.093,1300.52 451.103,1300.52 451.112,1300.51 451.121,1300.51 451.13,1300.51 451.139,1300.51 451.148,1300.51 451.158,1300.51 451.167,1300.5 451.176,1300.5 451.185,1300.5 451.194,1300.5 451.204,1300.5 451.213,1300.5 451.222,1300.49 451.231,1300.49 451.24,1300.49 451.25,1300.49 451.259,1300.49 451.268,1300.49 451.277,1300.48 451.286,1300.48 451.295,1300.48 451.305,1300.48 451.314,1300.48 451.323,1300.48 451.332,1300.47 451.341,1300.47 451.351,1300.47 451.36,1300.47 451.369,1300.47 451.378,1300.47 451.387,1300.46 451.397,1300.46 451.406,1300.46 451.415,1300.46 451.424,1300.46 451.433,1300.46 451.443,1300.45 451.452,1300.45 451.461,1300.45 451.47,1300.45 451.479,1300.45 451.488,1300.45 451.498,1300.44 451.507,1300.44 451.516,1300.44 451.525,1300.44 451.534,1300.44 451.544,1300.44 451.553,1300.44 451.562,1300.43 451.571,1300.43 451.58,1300.43 451.59,1300.43 451.599,1300.43 451.608,1300.43 451.617,1300.42 451.626,1300.42 451.635,1300.42 451.645,1300.42 451.654,1300.42 451.663,1300.42 451.672,1300.41 451.681,1300.41 451.691,1300.41 451.7,1300.41 451.709,1300.41 451.718,1300.41 451.727,1300.4 451.737,1300.4 451.746,1300.4 451.755,1300.4 451.764,1300.4 451.773,1300.4 451.783,1300.39 451.792,1300.39 451.801,1300.39 451.81,1300.39 451.819,1300.39 451.828,1300.39 451.838,1300.38 451.847,1300.38 451.856,1300.38 451.865,1300.38 451.874,1300.38 451.884,1300.38 451.893,1300.37 451.902,1300.37 451.911,1300.37 451.92,1300.37 451.93,1300.37 451.939,1300.37 451.948,1300.36 451.957,1300.36 451.966,1300.36 451.975,1300.36 451.985,1300.36 451.994,1300.36 452.003,1300.35 452.012,1300.35 452.021,1300.35 452.031,1300.35 452.04,1300.35 452.049,1300.35 452.058,1300.34 452.067,1300.34 452.077,1300.34 452.086,1300.34 452.095,1300.34 452.104,1300.34 452.113,1300.33 452.123,1300.33 452.132,1300.33 452.141,1300.33 452.15,1300.33 452.159,1300.33 452.168,1300.32 452.178,1300.32 452.187,1300.32 452.196,1300.32 452.205,1300.32 452.214,1300.32 452.224,1300.31 452.233,1300.31 452.242,1300.31 452.251,1300.31 452.26,1300.31 452.27,1300.31 452.279,1300.3 452.288,1300.3 452.297,1300.3 452.306,1300.3 452.316,1300.3 452.325,1300.3 452.334,1300.3 452.343,1300.29 452.352,1300.29 452.361,1300.29 452.371,1300.29 452.38,1300.29 452.389,1300.29 452.398,1300.28 452.407,1300.28 452.417,1300.28 452.426,1300.28 452.435,1300.28 452.444,1300.28 452.453,1300.27 452.463,1300.27 452.472,1300.27 452.481,1300.27 452.49,1300.27 452.499,1300.27 452.508,1300.26 452.518,1300.26 452.527,1300.26 452.536,1300.26 452.545,1300.26 452.554,1300.26 452.564,1300.25 452.573,1300.25 452.582,1300.25 452.591,1300.25 452.6,1300.25 452.61,1300.25 452.619,1300.24 452.628,1300.24 452.637,1300.24 452.646,1300.24 452.656,1300.24 452.665,1300.24 452.674,1300.23 452.683,1300.23 452.692,1300.23 452.701,1300.23 452.711,1300.23 452.72,1300.23 452.729,1300.22 452.738,1300.22 452.747,1300.22 452.757,1300.22 452.766,1300.22 452.775,1300.22 452.784,1300.21 452.793,1300.21 452.803,1300.21 452.812,1300.21 452.821,1300.21 452.83,1300.21 452.839,1300.21 452.848,1300.2 452.858,1300.2 452.867,1300.2 452.876,1300.2 452.885,1300.2 452.894,1300.2 452.904,1300.19 452.913,1300.19 452.922,1300.19 452.931,1300.19 452.94,1300.19 452.95,1300.19 452.959,1300.18 452.968,1300.18 452.977,1300.18 452.986,1300.18 452.996,1300.18 453.005,1300.18 453.014,1300.17 453.023,1300.17 453.032,1300.17 453.041,1300.17 453.051,1300.17 453.06,1300.17 453.069,1300.16 453.078,1300.16 453.087,1300.16 453.097,1300.16 453.106,1300.16 453.115,1300.16 453.124,1300.15 453.133,1300.15 453.143,1300.15 453.152,1300.15 453.161,1300.15 453.17,1300.15 453.179,1300.14 453.188,1300.14 453.198,1300.14 453.207,1300.14 453.216,1300.14 453.225,1300.14 453.234,1300.14 453.244,1300.13 453.253,1300.13 453.262,1300.13 453.271,1300.13 453.28,1300.13 453.29,1300.13 453.299,1300.12 453.308,1300.12 453.317,1300.12 453.326,1300.12 453.336,1300.12 453.345,1300.12 453.354,1300.11 453.363,1300.11 453.372,1300.11 453.381,1300.11 453.391,1300.11 453.4,1300.11 453.409,1300.1 453.418,1300.1 453.427,1300.1 453.437,1300.1 453.446,1300.1 453.455,1300.1 453.464,1300.09 453.473,1300.09 453.483,1300.09 453.492,1300.09 453.501,1300.09 453.51,1300.09 453.519,1300.09 453.528,1300.08 453.538,1300.08 453.547,1300.08 453.556,1300.08 453.565,1300.08 453.574,1300.08 453.584,1300.07 453.593,1300.07 453.602,1300.07 453.611,1300.07 453.62,1300.07 453.63,1300.07 453.639,1300.06 453.648,1300.06 453.657,1300.06 453.666,1300.06 453.676,1300.06 453.685,1300.06 453.694,1300.05 453.703,1300.05 453.712,1300.05 453.721,1300.05 453.731,1300.05 453.74,1300.05 453.749,1300.04 453.758,1300.04 453.767,1300.04 453.777,1300.04 453.786,1300.04 453.795,1300.04 453.804,1300.04 453.813,1300.03 453.823,1300.03 453.832,1300.03 453.841,1300.03 453.85,1300.03 453.859,1300.03 453.868,1300.02 453.878,1300.02 453.887,1300.02 453.896,1300.02 453.905,1300.02 453.914,1300.02 453.924,1300.01 453.933,1300.01 453.942,1300.01 453.951,1300.01 453.96,1300.01 453.97,1300.01 453.979,1300 453.988,1300 453.997,1300 454.006,1300 454.016,1300 454.025,1300 454.034,1299.99 454.043,1299.99 454.052,1299.99 454.061,1299.99 454.071,1299.99 454.08,1299.99 454.089,1299.99 454.098,1299.98 454.107,1299.98 454.117,1299.98 454.126,1299.98 454.135,1299.98 454.144,1299.98 454.153,1299.97 454.163,1299.97 454.172,1299.97 454.181,1299.97 454.19,1299.97 454.199,1299.97 454.208,1299.96 454.218,1299.96 454.227,1299.96 454.236,1299.96 454.245,1299.96 454.254,1299.96 454.264,1299.95 454.273,1299.95 454.282,1299.95 454.291,1299.95 454.3,1299.95 454.31,1299.95 454.319,1299.95 454.328,1299.94 454.337,1299.94 454.346,1299.94 454.356,1299.94 454.365,1299.94 454.374,1299.94 454.383,1299.93 454.392,1299.93 454.401,1299.93 454.411,1299.93 454.42,1299.93 454.429,1299.93 454.438,1299.92 454.447,1299.92 454.457,1299.92 454.466,1299.92 454.475,1299.92 454.484,1299.92 454.493,1299.91 454.503,1299.91 454.512,1299.91 454.521,1299.91 454.53,1299.91 454.539,1299.91 454.548,1299.91 454.558,1299.9 454.567,1299.9 454.576,1299.9 454.585,1299.9 454.594,1299.9 454.604,1299.9 454.613,1299.89 454.622,1299.89 454.631,1299.89 454.64,1299.89 454.65,1299.89 454.659,1299.89 454.668,1299.88 454.677,1299.88 454.686,1299.88 454.696,1299.88 454.705,1299.88 454.714,1299.88 454.723,1299.87 454.732,1299.87 454.741,1299.87 454.751,1299.87 454.76,1299.87 454.769,1299.87 454.778,1299.87 454.787,1299.86 454.797,1299.86 454.806,1299.86 454.815,1299.86 454.824,1299.86 454.833,1299.86 454.843,1299.85 454.852,1299.85 454.861,1299.85 454.87,1299.85 454.879,1299.85 454.889,1299.85 454.898,1299.84 454.907,1299.84 454.916,1299.84 454.925,1299.84 454.934,1299.84 454.944,1299.84 454.953,1299.83 454.962,1299.83 454.971,1299.83 454.98,1299.83 454.99,1299.83 454.999,1299.83 455.008,1299.83 455.017,1299.82 455.026,1299.82 455.036,1299.82 455.045,1299.82 455.054,1299.82 455.063,1299.82 455.072,1299.81 455.081,1299.81 455.091,1299.81 455.1,1299.81 455.109,1299.81 455.118,1299.81 455.127,1299.8 455.137,1299.8 455.146,1299.8 455.155,1299.8 455.164,1299.8 455.173,1299.8 455.183,1299.8 455.192,1299.79 455.201,1299.79 455.21,1299.79 455.219,1299.79 455.229,1299.79 455.238,1299.79 455.247,1299.78 455.256,1299.78 455.265,1299.78 455.274,1299.78 455.284,1299.78 455.293,1299.78 455.302,1299.77 455.311,1299.77 455.32,1299.77 455.33,1299.77 455.339,1299.77 455.348,1299.77 455.357,1299.77 455.366,1299.76 455.376,1299.76 455.385,1299.76 455.394,1299.76 455.403,1299.76 455.412,1299.76 455.421,1299.75 455.431,1299.75 455.44,1299.75 455.449,1299.75 455.458,1299.75 455.467,1299.75 455.477,1299.74 455.486,1299.74 455.495,1299.74 455.504,1299.74 455.513,1299.74 455.523,1299.74 455.532,1299.74 455.541,1299.73 455.55,1299.73 455.559,1299.73 455.569,1299.73 455.578,1299.73 455.587,1299.73 455.596,1299.72 455.605,1299.72 455.614,1299.72 455.624,1299.72 455.633,1299.72 455.642,1299.72 455.651,1299.71 455.66,1299.71 455.67,1299.71 455.679,1299.71 455.688,1299.71 455.697,1299.71 455.706,1299.71 455.716,1299.7 455.725,1299.7 455.734,1299.7 455.743,1299.7 455.752,1299.7 455.761,1299.7 455.771,1299.69 455.78,1299.69 455.789,1299.69 455.798,1299.69 455.807,1299.69 455.817,1299.69 455.826,1299.68 455.835,1299.68 455.844,1299.68 455.853,1299.68 455.863,1299.68 455.872,1299.68 455.881,1299.68 455.89,1299.67 455.899,1299.67 455.909,1299.67 455.918,1299.67 455.927,1299.67 455.936,1299.67 455.945,1299.66 455.954,1299.66 455.964,1299.66 455.973,1299.66 455.982,1299.66 455.991,1299.66 456,1299.65 456.01,1299.65 456.019,1299.65 456.028,1299.65 456.037,1299.65 456.046,1299.65 456.056,1299.65 456.065,1299.64 456.074,1299.64 456.083,1299.64 456.092,1299.64 456.101,1299.64 456.111,1299.64 456.12,1299.63 456.129,1299.63 456.138,1299.63 456.147,1299.63 456.157,1299.63 456.166,1299.63 456.175,1299.63 456.184,1299.62 456.193,1299.62 456.203,1299.62 456.212,1299.62 456.221,1299.62 456.23,1299.62 456.239,1299.61 456.249,1299.61 456.258,1299.61 456.267,1299.61 456.276,1299.61 456.285,1299.61 456.294,1299.6 456.304,1299.6 456.313,1299.6 456.322,1299.6 456.331,1299.6 456.34,1299.6 456.35,1299.6 456.359,1299.59 456.368,1299.59 456.377,1299.59 456.386,1299.59 456.396,1299.59 456.405,1299.59 456.414,1299.58 456.423,1299.58 456.432,1299.58 456.441,1299.58 456.451,1299.58 456.46,1299.58 456.469,1299.57 456.478,1299.57 456.487,1299.57 456.497,1299.57 456.506,1299.57 456.515,1299.57 456.524,1299.57 456.533,1299.56 456.543,1299.56 456.552,1299.56 456.561,1299.56 456.57,1299.56 456.579,1299.56 456.589,1299.55 456.598,1299.55 456.607,1299.55 456.616,1299.55 456.625,1299.55 456.634,1299.55 456.644,1299.55 456.653,1299.54 456.662,1299.54 456.671,1299.54 456.68,1299.54 456.69,1299.54 456.699,1299.54 456.708,1299.53 456.717,1299.53 456.726,1299.53 456.736,1299.53 456.745,1299.53 456.754,1299.53 456.763,1299.53 456.772,1299.52 456.781,1299.52 456.791,1299.52 456.8,1299.52 456.809,1299.52 456.818,1299.52 456.827,1299.51 456.837,1299.51 456.846,1299.51 456.855,1299.51 456.864,1299.51 456.873,1299.51 456.883,1299.5 456.892,1299.5 456.901,1299.5 456.91,1299.5 456.919,1299.5 456.929,1299.5 456.938,1299.5 456.947,1299.49 456.956,1299.49 456.965,1299.49 456.974,1299.49 456.984,1299.49 456.993,1299.49 457.002,1299.48 457.011,1299.48 457.02,1299.48 457.03,1299.48 457.039,1299.48 457.048,1299.48 457.057,1299.48 457.066,1299.47 457.076,1299.47 457.085,1299.47 457.094,1299.47 457.103,1299.47 457.112,1299.47 457.121,1299.46 457.131,1299.46 457.14,1299.46 457.149,1299.46 457.158,1299.46 457.167,1299.46 457.177,1299.46 457.186,1299.45 457.195,1299.45 457.204,1299.45 457.213,1299.45 457.223,1299.45 457.232,1299.45 457.241,1299.44 457.25,1299.44 457.259,1299.44 457.269,1299.44 457.278,1299.44 457.287,1299.44 457.296,1299.44 457.305,1299.43 457.314,1299.43 457.324,1299.43 457.333,1299.43 457.342,1299.43 457.351,1299.43 457.36,1299.42 457.37,1299.42 457.379,1299.42 457.388,1299.42 457.397,1299.42 457.406,1299.42 457.416,1299.42 457.425,1299.41 457.434,1299.41 457.443,1299.41 457.452,1299.41 457.462,1299.41 457.471,1299.41 457.48,1299.4 457.489,1299.4 457.498,1299.4 457.507,1299.4 457.517,1299.4 457.526,1299.4 457.535,1299.39 457.544,1299.39 457.553,1299.39 457.563,1299.39 457.572,1299.39 457.581,1299.39 457.59,1299.39 457.599,1299.38 457.609,1299.38 457.618,1299.38 457.627,1299.38 457.636,1299.38 457.645,1299.38 457.654,1299.37 457.664,1299.37 457.673,1299.37 457.682,1299.37 457.691,1299.37 457.7,1299.37 457.71,1299.37 457.719,1299.36 457.728,1299.36 457.737,1299.36 457.746,1299.36 457.756,1299.36 457.765,1299.36 457.774,1299.35 457.783,1299.35 457.792,1299.35 457.802,1299.35 457.811,1299.35 457.82,1299.35 457.829,1299.35 457.838,1299.34 457.847,1299.34 457.857,1299.34 457.866,1299.34 457.875,1299.34 457.884,1299.34 457.893,1299.33 457.903,1299.33 457.912,1299.33 457.921,1299.33 457.93,1299.33 457.939,1299.33 457.949,1299.33 457.958,1299.32 457.967,1299.32 457.976,1299.32 457.985,1299.32 457.994,1299.32 458.004,1299.32 458.013,1299.31 458.022,1299.31 458.031,1299.31 458.04,1299.31 458.05,1299.31 458.059,1299.31 458.068,1299.31 458.077,1299.3 458.086,1299.3 458.096,1299.3 458.105,1299.3 458.114,1299.3 458.123,1299.3 458.132,1299.3 458.142,1299.29 458.151,1299.29 458.16,1299.29 458.169,1299.29 458.178,1299.29 458.187,1299.29 458.197,1299.28 458.206,1299.28 458.215,1299.28 458.224,1299.28 458.233,1299.28 458.243,1299.28 458.252,1299.28 458.261,1299.27 458.27,1299.27 458.279,1299.27 458.289,1299.27 458.298,1299.27 458.307,1299.27 458.316,1299.26 458.325,1299.26 458.334,1299.26 458.344,1299.26 458.353,1299.26 458.362,1299.26 458.371,1299.26 458.38,1299.25 458.39,1299.25 458.399,1299.25 458.408,1299.25 458.417,1299.25 458.426,1299.25 458.436,1299.24 458.445,1299.24 458.454,1299.24 458.463,1299.24 458.472,1299.24 458.482,1299.24 458.491,1299.24 458.5,1299.23 458.509,1299.23 458.518,1299.23 458.527,1299.23 458.537,1299.23 458.546,1299.23 458.555,1299.22 458.564,1299.22 458.573,1299.22 458.583,1299.22 458.592,1299.22 458.601,1299.22 458.61,1299.22 458.619,1299.21 458.629,1299.21 458.638,1299.21 458.647,1299.21 458.656,1299.21 458.665,1299.21 458.674,1299.21 458.684,1299.2 458.693,1299.2 458.702,1299.2 458.711,1299.2 458.72,1299.2 458.73,1299.2 458.739,1299.19 458.748,1299.19 458.757,1299.19 458.766,1299.19 458.776,1299.19 458.785,1299.19 458.794,1299.19 458.803,1299.18 458.812,1299.18 458.822,1299.18 458.831,1299.18 458.84,1299.18 458.849,1299.18 458.858,1299.17 458.867,1299.17 458.877,1299.17 458.886,1299.17 458.895,1299.17 458.904,1299.17 458.913,1299.17 458.923,1299.16 458.932,1299.16 458.941,1299.16 458.95,1299.16 458.959,1299.16 458.969,1299.16 458.978,1299.15 458.987,1299.15 458.996,1299.15 459.005,1299.15 459.014,1299.15 459.024,1299.15 459.033,1299.15 459.042,1299.14 459.051,1299.14 459.06,1299.14 459.07,1299.14 459.079,1299.14 459.088,1299.14 459.097,1299.14 459.106,1299.13 459.116,1299.13 459.125,1299.13 459.134,1299.13 459.143,1299.13 459.152,1299.13 459.162,1299.12 459.171,1299.12 459.18,1299.12 459.189,1299.12 459.198,1299.12 459.207,1299.12 459.217,1299.12 459.226,1299.11 459.235,1299.11 459.244,1299.11 459.253,1299.11 459.263,1299.11 459.272,1299.11 459.281,1299.1 459.29,1299.1 459.299,1299.1 459.309,1299.1 459.318,1299.1 459.327,1299.1 459.336,1299.1 459.345,1299.09 459.354,1299.09 459.364,1299.09 459.373,1299.09 459.382,1299.09 459.391,1299.09 459.4,1299.09 459.41,1299.08 459.419,1299.08 459.428,1299.08 459.437,1299.08 459.446,1299.08 459.456,1299.08 459.465,1299.07 459.474,1299.07 459.483,1299.07 459.492,1299.07 459.502,1299.07 459.511,1299.07 459.52,1299.07 459.529,1299.06 459.538,1299.06 459.547,1299.06 459.557,1299.06 459.566,1299.06 459.575,1299.06 459.584,1299.06 459.593,1299.05 459.603,1299.05 459.612,1299.05 459.621,1299.05 459.63,1299.05 459.639,1299.05 459.649,1299.04 459.658,1299.04 459.667,1299.04 459.676,1299.04 459.685,1299.04 459.695,1299.04 459.704,1299.04 459.713,1299.03 459.722,1299.03 459.731,1299.03 459.74,1299.03 459.75,1299.03 459.759,1299.03 459.768,1299.03 459.777,1299.02 459.786,1299.02 459.796,1299.02 459.805,1299.02 459.814,1299.02 459.823,1299.02 459.832,1299.01 459.842,1299.01 459.851,1299.01 459.86,1299.01 459.869,1299.01 459.878,1299.01 459.887,1299.01 459.897,1299 459.906,1299 459.915,1299 459.924,1299 459.933,1299 459.943,1299 459.952,1299 459.961,1298.99 459.97,1298.99 459.979,1298.99 459.989,1298.99 459.998,1298.99 460.007,1298.99 460.016,1298.98 460.025,1298.98 460.035,1298.98 460.044,1298.98 460.053,1298.98 460.062,1298.98 460.071,1298.98 460.08,1298.97 460.09,1298.97 460.099,1298.97 460.108,1298.97 460.117,1298.97 460.126,1298.97 460.136,1298.97 460.145,1298.96 460.154,1298.96 460.163,1298.96 460.172,1298.96 460.182,1298.96 460.191,1298.96 460.2,1298.95 460.209,1298.95 460.218,1298.95 460.227,1298.95 460.237,1298.95 460.246,1298.95 460.255,1298.95 460.264,1298.94 460.273,1298.94 460.283,1298.94 460.292,1298.94 460.301,1298.94 460.31,1298.94 460.319,1298.94 460.329,1298.93 460.338,1298.93 460.347,1298.93 460.356,1298.93 460.365,1298.93 460.375,1298.93 460.384,1298.92 460.393,1298.92 460.402,1298.92 460.411,1298.92 460.42,1298.92 460.43,1298.92 460.439,1298.92 460.448,1298.91 460.457,1298.91 460.466,1298.91 460.476,1298.91 460.485,1298.91 460.494,1298.91 460.503,1298.91 460.512,1298.9 460.522,1298.9 460.531,1298.9 460.54,1298.9 460.549,1298.9 460.558,1298.9 460.567,1298.9 460.577,1298.89 460.586,1298.89 460.595,1298.89 460.604,1298.89 460.613,1298.89 460.623,1298.89 460.632,1298.88 460.641,1298.88 460.65,1298.88 460.659,1298.88 460.669,1298.88 460.678,1298.88 460.687,1298.88 460.696,1298.87 460.705,1298.87 460.715,1298.87 460.724,1298.87 460.733,1298.87 460.742,1298.87 460.751,1298.87 460.76,1298.86 460.77,1298.86 460.779,1298.86 460.788,1298.86 460.797,1298.86 460.806,1298.86 460.816,1298.86 460.825,1298.85 460.834,1298.85 460.843,1298.85 460.852,1298.85 460.862,1298.85 460.871,1298.85 460.88,1298.84 460.889,1298.84 460.898,1298.84 460.907,1298.84 460.917,1298.84 460.926,1298.84 460.935,1298.84 460.944,1298.83 460.953,1298.83 460.963,1298.83 460.972,1298.83 460.981,1298.83 460.99,1298.83 460.999,1298.83 461.009,1298.82 461.018,1298.82 461.027,1298.82 461.036,1298.82 461.045,1298.82 461.055,1298.82 461.064,1298.82 461.073,1298.81 461.082,1298.81 461.091,1298.81 461.1,1298.81 461.11,1298.81 461.119,1298.81 461.128,1298.8 461.137,1298.8 461.146,1298.8 461.156,1298.8 461.165,1298.8 461.174,1298.8 461.183,1298.8 461.192,1298.79 461.202,1298.79 461.211,1298.79 461.22,1298.79 461.229,1298.79 461.238,1298.79 461.247,1298.79 461.257,1298.78 461.266,1298.78 461.275,1298.78 461.284,1298.78 461.293,1298.78 461.303,1298.78 461.312,1298.78 461.321,1298.77 461.33,1298.77 461.339,1298.77 461.349,1298.77 461.358,1298.77 461.367,1298.77 461.376,1298.76 461.385,1298.76 461.395,1298.76 461.404,1298.76 461.413,1298.76 461.422,1298.76 461.431,1298.76 461.44,1298.75 461.45,1298.75 461.459,1298.75 461.468,1298.75 461.477,1298.75 461.486,1298.75 461.496,1298.75 461.505,1298.74 461.514,1298.74 461.523,1298.74 461.532,1298.74 461.542,1298.74 461.551,1298.74 461.56,1298.74 461.569,1298.73 461.578,1298.73 461.587,1298.73 461.597,1298.73 461.606,1298.73 461.615,1298.73 461.624,1298.73 461.633,1298.72 461.643,1298.72 461.652,1298.72 461.661,1298.72 461.67,1298.72 461.679,1298.72 461.689,1298.71 461.698,1298.71 461.707,1298.71 461.716,1298.71 461.725,1298.71 461.735,1298.71 461.744,1298.71 461.753,1298.7 461.762,1298.7 461.771,1298.7 461.78,1298.7 461.79,1298.7 461.799,1298.7 461.808,1298.7 461.817,1298.69 461.826,1298.69 461.836,1298.69 461.845,1298.69 461.854,1298.69 461.863,1298.69 461.872,1298.69 461.882,1298.68 461.891,1298.68 461.9,1298.68 461.909,1298.68 461.918,1298.68 461.927,1298.68 461.937,1298.68 461.946,1298.67 461.955,1298.67 461.964,1298.67 461.973,1298.67 461.983,1298.67 461.992,1298.67 462.001,1298.67 462.01,1298.66 462.019,1298.66 462.029,1298.66 462.038,1298.66 462.047,1298.66 462.056,1298.66 462.065,1298.65 462.075,1298.65 462.084,1298.65 462.093,1298.65 462.102,1298.65 462.111,1298.65 462.12,1298.65 462.13,1298.64 462.139,1298.64 462.148,1298.64 462.157,1298.64 462.166,1298.64 462.176,1298.64 462.185,1298.64 462.194,1298.63 462.203,1298.63 462.212,1298.63 462.222,1298.63 462.231,1298.63 462.24,1298.63 462.249,1298.63 462.258,1298.62 462.268,1298.62 462.277,1298.62 462.286,1298.62 462.295,1298.62 462.304,1298.62 462.313,1298.62 462.323,1298.61 462.332,1298.61 462.341,1298.61 462.35,1298.61 462.359,1298.61 462.369,1298.61 462.378,1298.61 462.387,1298.6 462.396,1298.6 462.405,1298.6 462.415,1298.6 462.424,1298.6 462.433,1298.6 462.442,1298.6 462.451,1298.59 462.46,1298.59 462.47,1298.59 462.479,1298.59 462.488,1298.59 462.497,1298.59 462.506,1298.58 462.516,1298.58 462.525,1298.58 462.534,1298.58 462.543,1298.58 462.552,1298.58 462.562,1298.58 462.571,1298.57 462.58,1298.57 462.589,1298.57 462.598,1298.57 462.608,1298.57 462.617,1298.57 462.626,1298.57 462.635,1298.56 462.644,1298.56 462.653,1298.56 462.663,1298.56 462.672,1298.56 462.681,1298.56 462.69,1298.56 462.699,1298.55 462.709,1298.55 462.718,1298.55 462.727,1298.55 462.736,1298.55 462.745,1298.55 462.755,1298.55 462.764,1298.54 462.773,1298.54 462.782,1298.54 462.791,1298.54 462.8,1298.54 462.81,1298.54 462.819,1298.54 462.828,1298.53 462.837,1298.53 462.846,1298.53 462.856,1298.53 462.865,1298.53 462.874,1298.53 462.883,1298.53 462.892,1298.52 462.902,1298.52 462.911,1298.52 462.92,1298.52 462.929,1298.52 462.938,1298.52 462.948,1298.52 462.957,1298.51 462.966,1298.51 462.975,1298.51 462.984,1298.51 462.993,1298.51 463.003,1298.51 463.012,1298.51 463.021,1298.5 463.03,1298.5 463.039,1298.5 463.049,1298.5 463.058,1298.5 463.067,1298.5 463.076,1298.5 463.085,1298.49 463.095,1298.49 463.104,1298.49 463.113,1298.49 463.122,1298.49 463.131,1298.49 463.14,1298.48 463.15,1298.48 463.159,1298.48 463.168,1298.48 463.177,1298.48 463.186,1298.48 463.196,1298.48 463.205,1298.47 463.214,1298.47 463.223,1298.47 463.232,1298.47 463.242,1298.47 463.251,1298.47 463.26,1298.47 463.269,1298.46 463.278,1298.46 463.288,1298.46 463.297,1298.46 463.306,1298.46 463.315,1298.46 463.324,1298.46 463.333,1298.45 463.343,1298.45 463.352,1298.45 463.361,1298.45 463.37,1298.45 463.379,1298.45 463.389,1298.45 463.398,1298.44 463.407,1298.44 463.416,1298.44 463.425,1298.44 463.435,1298.44 463.444,1298.44 463.453,1298.44 463.462,1298.43 463.471,1298.43 463.48,1298.43 463.49,1298.43 463.499,1298.43 463.508,1298.43 463.517,1298.43 463.526,1298.42 463.536,1298.42 463.545,1298.42 463.554,1298.42 463.563,1298.42 463.572,1298.42 463.582,1298.42 463.591,1298.41 463.6,1298.41 463.609,1298.41 463.618,1298.41 463.628,1298.41 463.637,1298.41 463.646,1298.41 463.655,1298.4 463.664,1298.4 463.673,1298.4 463.683,1298.4 463.692,1298.4 463.701,1298.4 463.71,1298.4 463.719,1298.39 463.729,1298.39 463.738,1298.39 463.747,1298.39 463.756,1298.39 463.765,1298.39 463.775,1298.39 463.784,1298.38 463.793,1298.38 463.802,1298.38 463.811,1298.38 463.82,1298.38 463.83,1298.38 463.839,1298.38 463.848,1298.37 463.857,1298.37 463.866,1298.37 463.876,1298.37 463.885,1298.37 463.894,1298.37 463.903,1298.37 463.912,1298.36 463.922,1298.36 463.931,1298.36 463.94,1298.36 463.949,1298.36 463.958,1298.36 463.968,1298.36 463.977,1298.35 463.986,1298.35 463.995,1298.35 464.004,1298.35 464.013,1298.35 464.023,1298.35 464.032,1298.35 464.041,1298.34 464.05,1298.34 464.059,1298.34 464.069,1298.34 464.078,1298.34 464.087,1298.34 464.096,1298.34 464.105,1298.33 464.115,1298.33 464.124,1298.33 464.133,1298.33 464.142,1298.33 464.151,1298.33 464.16,1298.33 464.17,1298.32 464.179,1298.32 464.188,1298.32 464.197,1298.32 464.206,1298.32 464.216,1298.32 464.225,1298.32 464.234,1298.31 464.243,1298.31 464.252,1298.31 464.262,1298.31 464.271,1298.31 464.28,1298.31 464.289,1298.31 464.298,1298.3 464.308,1298.3 464.317,1298.3 464.326,1298.3 464.335,1298.3 464.344,1298.3 464.353,1298.3 464.363,1298.29 464.372,1298.29 464.381,1298.29 464.39,1298.29 464.399,1298.29 464.409,1298.29 464.418,1298.29 464.427,1298.28 464.436,1298.28 464.445,1298.28 464.455,1298.28 464.464,1298.28 464.473,1298.28 464.482,1298.28 464.491,1298.27 464.5,1298.27 464.51,1298.27 464.519,1298.27 464.528,1298.27 464.537,1298.27 464.546,1298.27 464.556,1298.26 464.565,1298.26 464.574,1298.26 464.583,1298.26 464.592,1298.26 464.602,1298.26 464.611,1298.26 464.62,1298.25 464.629,1298.25 464.638,1298.25 464.648,1298.25 464.657,1298.25 464.666,1298.25 464.675,1298.25 464.684,1298.24 464.693,1298.24 464.703,1298.24 464.712,1298.24 464.721,1298.24 464.73,1298.24 464.739,1298.24 464.749,1298.23 464.758,1298.23 464.767,1298.23 464.776,1298.23 464.785,1298.23 464.795,1298.23 464.804,1298.23 464.813,1298.23 464.822,1298.22 464.831,1298.22 464.841,1298.22 464.85,1298.22 464.859,1298.22 464.868,1298.22 464.877,1298.22 464.886,1298.21 464.896,1298.21 464.905,1298.21 464.914,1298.21 464.923,1298.21 464.932,1298.21 464.942,1298.21 464.951,1298.2 464.96,1298.2 464.969,1298.2 464.978,1298.2 464.988,1298.2 464.997,1298.2 465.006,1298.2 465.015,1298.19 465.024,1298.19 465.033,1298.19 465.043,1298.19 465.052,1298.19 465.061,1298.19 465.07,1298.19 465.079,1298.18 465.089,1298.18 465.098,1298.18 465.107,1298.18 465.116,1298.18 465.125,1298.18 465.135,1298.18 465.144,1298.17 465.153,1298.17 465.162,1298.17 465.171,1298.17 465.181,1298.17 465.19,1298.17 465.199,1298.17 465.208,1298.16 465.217,1298.16 465.226,1298.16 465.236,1298.16 465.245,1298.16 465.254,1298.16 465.263,1298.16 465.272,1298.15 465.282,1298.15 465.291,1298.15 465.3,1298.15 465.309,1298.15 465.318,1298.15 465.328,1298.15 465.337,1298.14 465.346,1298.14 465.355,1298.14 465.364,1298.14 465.373,1298.14 465.383,1298.14 465.392,1298.14 465.401,1298.13 465.41,1298.13 465.419,1298.13 465.429,1298.13 465.438,1298.13 465.447,1298.13 465.456,1298.13 465.465,1298.13 465.475,1298.12 465.484,1298.12 465.493,1298.12 465.502,1298.12 465.511,1298.12 465.521,1298.12 465.53,1298.12 465.539,1298.11 465.548,1298.11 465.557,1298.11 465.566,1298.11 465.576,1298.11 465.585,1298.11 465.594,1298.11 465.603,1298.1 465.612,1298.1 465.622,1298.1 465.631,1298.1 465.64,1298.1 465.649,1298.1 465.658,1298.1 465.668,1298.09 465.677,1298.09 465.686,1298.09 465.695,1298.09 465.704,1298.09 465.713,1298.09 465.723,1298.09 465.732,1298.08 465.741,1298.08 465.75,1298.08 465.759,1298.08 465.769,1298.08 465.778,1298.08 465.787,1298.08 465.796,1298.07 465.805,1298.07 465.815,1298.07 465.824,1298.07 465.833,1298.07 465.842,1298.07 465.851,1298.07 465.861,1298.06 465.87,1298.06 465.879,1298.06 465.888,1298.06 465.897,1298.06 465.906,1298.06 465.916,1298.06 465.925,1298.06 465.934,1298.05 465.943,1298.05 465.952,1298.05 465.962,1298.05 465.971,1298.05 465.98,1298.05 465.989,1298.05 465.998,1298.04 466.008,1298.04 466.017,1298.04 466.026,1298.04 466.035,1298.04 466.044,1298.04 466.053,1298.04 466.063,1298.03 466.072,1298.03 466.081,1298.03 466.09,1298.03 466.099,1298.03 466.109,1298.03 466.118,1298.03 466.127,1298.02 466.136,1298.02 466.145,1298.02 466.155,1298.02 466.164,1298.02 466.173,1298.02 466.182,1298.02 466.191,1298.01 466.201,1298.01 466.21,1298.01 466.219,1298.01 466.228,1298.01 466.237,1298.01 466.246,1298.01 466.256,1298.01 466.265,1298 466.274,1298 466.283,1298 466.292,1298 466.302,1298 466.311,1298 466.32,1298 466.329,1297.99 466.338,1297.99 466.348,1297.99 466.357,1297.99 466.366,1297.99 466.375,1297.99 466.384,1297.99 466.393,1297.98 466.403,1297.98 466.412,1297.98 466.421,1297.98 466.43,1297.98 466.439,1297.98 466.449,1297.98 466.458,1297.97 466.467,1297.97 466.476,1297.97 466.485,1297.97 466.495,1297.97 466.504,1297.97 466.513,1297.97 466.522,1297.96 466.531,1297.96 466.541,1297.96 466.55,1297.96 466.559,1297.96 466.568,1297.96 466.577,1297.96 466.586,1297.96 466.596,1297.95 466.605,1297.95 466.614,1297.95 466.623,1297.95 466.632,1297.95 466.642,1297.95 466.651,1297.95 466.66,1297.94 466.669,1297.94 466.678,1297.94 466.688,1297.94 466.697,1297.94 466.706,1297.94 466.715,1297.94 466.724,1297.93 466.733,1297.93 466.743,1297.93 466.752,1297.93 466.761,1297.93 466.77,1297.93 466.779,1297.93 466.789,1297.92 466.798,1297.92 466.807,1297.92 466.816,1297.92 466.825,1297.92 466.835,1297.92 466.844,1297.92 466.853,1297.92 466.862,1297.91 466.871,1297.91 466.881,1297.91 466.89,1297.91 466.899,1297.91 466.908,1297.91 466.917,1297.91 466.926,1297.9 466.936,1297.9 466.945,1297.9 466.954,1297.9 466.963,1297.9 466.972,1297.9 466.982,1297.9 466.991,1297.89 467,1297.89 467.009,1297.89 467.018,1297.89 467.028,1297.89 467.037,1297.89 467.046,1297.89 467.055,1297.88 467.064,1297.88 467.074,1297.88 467.083,1297.88 467.092,1297.88 467.101,1297.88 467.11,1297.88 467.119,1297.88 467.129,1297.87 467.138,1297.87 467.147,1297.87 467.156,1297.87 467.165,1297.87 467.175,1297.87 467.184,1297.87 467.193,1297.86 467.202,1297.86 467.211,1297.86 467.221,1297.86 467.23,1297.86 467.239,1297.86 467.248,1297.86 467.257,1297.85 467.266,1297.85 467.276,1297.85 467.285,1297.85 467.294,1297.85 467.303,1297.85 467.312,1297.85 467.322,1297.84 467.331,1297.84 467.34,1297.84 467.349,1297.84 467.358,1297.84 467.368,1297.84 467.377,1297.84 467.386,1297.84 467.395,1297.83 467.404,1297.83 467.414,1297.83 467.423,1297.83 467.432,1297.83 467.441,1297.83 467.45,1297.83 467.459,1297.82 467.469,1297.82 467.478,1297.82 467.487,1297.82 467.496,1297.82 467.505,1297.82 467.515,1297.82 467.524,1297.81 467.533,1297.81 467.542,1297.81 467.551,1297.81 467.561,1297.81 467.57,1297.81 467.579,1297.81 467.588,1297.81 467.597,1297.8 467.606,1297.8 467.616,1297.8 467.625,1297.8 467.634,1297.8 467.643,1297.8 467.652,1297.8 467.662,1297.79 467.671,1297.79 467.68,1297.79 467.689,1297.79 467.698,1297.79 467.708,1297.79 467.717,1297.79 467.726,1297.78 467.735,1297.78 467.744,1297.78 467.754,1297.78 467.763,1297.78 467.772,1297.78 467.781,1297.78 467.79,1297.78 467.799,1297.77 467.809,1297.77 467.818,1297.77 467.827,1297.77 467.836,1297.77 467.845,1297.77 467.855,1297.77 467.864,1297.76 467.873,1297.76 467.882,1297.76 467.891,1297.76 467.901,1297.76 467.91,1297.76 467.919,1297.76 467.928,1297.75 467.937,1297.75 467.946,1297.75 467.956,1297.75 467.965,1297.75 467.974,1297.75 467.983,1297.75 467.992,1297.75 468.002,1297.74 468.011,1297.74 468.02,1297.74 468.029,1297.74 468.038,1297.74 468.048,1297.74 468.057,1297.74 468.066,1297.73 468.075,1297.73 468.084,1297.73 468.094,1297.73 468.103,1297.73 468.112,1297.73 468.121,1297.73 468.13,1297.72 468.139,1297.72 468.149,1297.72 468.158,1297.72 468.167,1297.72 468.176,1297.72 468.185,1297.72 468.195,1297.72 468.204,1297.71 468.213,1297.71 468.222,1297.71 468.231,1297.71 468.241,1297.71 468.25,1297.71 468.259,1297.71 468.268,1297.7 468.277,1297.7 468.286,1297.7 468.296,1297.7 468.305,1297.7 468.314,1297.7 468.323,1297.7 468.332,1297.69 468.342,1297.69 468.351,1297.69 468.36,1297.69 468.369,1297.69 468.378,1297.69 468.388,1297.69 468.397,1297.69 468.406,1297.68 468.415,1297.68 468.424,1297.68 468.434,1297.68 468.443,1297.68 468.452,1297.68 468.461,1297.68 468.47,1297.67 468.479,1297.67 468.489,1297.67 468.498,1297.67 468.507,1297.67 468.516,1297.67 468.525,1297.67 468.535,1297.67 468.544,1297.66 468.553,1297.66 468.562,1297.66 468.571,1297.66 468.581,1297.66 468.59,1297.66 468.599,1297.66 468.608,1297.65 468.617,1297.65 468.626,1297.65 468.636,1297.65 468.645,1297.65 468.654,1297.65 468.663,1297.65 468.672,1297.64 468.682,1297.64 468.691,1297.64 468.7,1297.64 468.709,1297.64 468.718,1297.64 468.728,1297.64 468.737,1297.64 468.746,1297.63 468.755,1297.63 468.764,1297.63 468.774,1297.63 468.783,1297.63 468.792,1297.63 468.801,1297.63 468.81,1297.62 468.819,1297.62 468.829,1297.62 468.838,1297.62 468.847,1297.62 468.856,1297.62 468.865,1297.62 468.875,1297.62 468.884,1297.61 468.893,1297.61 468.902,1297.61 468.911,1297.61 468.921,1297.61 468.93,1297.61 468.939,1297.61 468.948,1297.6 468.957,1297.6 468.966,1297.6 468.976,1297.6 468.985,1297.6 468.994,1297.6 469.003,1297.6 469.012,1297.6 469.022,1297.59 469.031,1297.59 469.04,1297.59 469.049,1297.59 469.058,1297.59 469.068,1297.59 469.077,1297.59 469.086,1297.58 469.095,1297.58 469.104,1297.58 469.114,1297.58 469.123,1297.58 469.132,1297.58 469.141,1297.58 469.15,1297.57 469.159,1297.57 469.169,1297.57 469.178,1297.57 469.187,1297.57 469.196,1297.57 469.205,1297.57 469.215,1297.57 469.224,1297.56 469.233,1297.56 469.242,1297.56 469.251,1297.56 469.261,1297.56 469.27,1297.56 469.279,1297.56 469.288,1297.55 469.297,1297.55 469.306,1297.55 469.316,1297.55 469.325,1297.55 469.334,1297.55 469.343,1297.55 469.352,1297.55 469.362,1297.54 469.371,1297.54 469.38,1297.54 469.389,1297.54 469.398,1297.54 469.408,1297.54 469.417,1297.54 469.426,1297.53 469.435,1297.53 469.444,1297.53 469.454,1297.53 469.463,1297.53 469.472,1297.53 469.481,1297.53 469.49,1297.53 469.499,1297.52 469.509,1297.52 469.518,1297.52 469.527,1297.52 469.536,1297.52 469.545,1297.52 469.555,1297.52 469.564,1297.51 469.573,1297.51 469.582,1297.51 469.591,1297.51 469.601,1297.51 469.61,1297.51 469.619,1297.51 469.628,1297.51 469.637,1297.5 469.647,1297.5 469.656,1297.5 469.665,1297.5 469.674,1297.5 469.683,1297.5 469.692,1297.5 469.702,1297.49 469.711,1297.49 469.72,1297.49 469.729,1297.49 469.738,1297.49 469.748,1297.49 469.757,1297.49 469.766,1297.49 469.775,1297.48 469.784,1297.48 469.794,1297.48 469.803,1297.48 469.812,1297.48 469.821,1297.48 469.83,1297.48 469.839,1297.47 469.849,1297.47 469.858,1297.47 469.867,1297.47 469.876,1297.47 469.885,1297.47 469.895,1297.47 469.904,1297.47 469.913,1297.46 469.922,1297.46 469.931,1297.46 469.941,1297.46 469.95,1297.46 469.959,1297.46 469.968,1297.46 469.977,1297.45 469.987,1297.45 469.996,1297.45 470.005,1297.45 470.014,1297.45 470.023,1297.45 470.032,1297.45 470.042,1297.45 470.051,1297.44 470.06,1297.44 470.069,1297.44 470.078,1297.44 470.088,1297.44 470.097,1297.44 470.106,1297.44 470.115,1297.43 470.124,1297.43 470.134,1297.43 470.143,1297.43 470.152,1297.43 470.161,1297.43 470.17,1297.43 470.179,1297.43 470.189,1297.42 470.198,1297.42 470.207,1297.42 470.216,1297.42 470.225,1297.42 470.235,1297.42 470.244,1297.42 470.253,1297.42 470.262,1297.41 470.271,1297.41 470.281,1297.41 470.29,1297.41 470.299,1297.41 470.308,1297.41 470.317,1297.41 470.327,1297.4 470.336,1297.4 470.345,1297.4 470.354,1297.4 470.363,1297.4 470.372,1297.4 470.382,1297.4 470.391,1297.4 470.4,1297.39 470.409,1297.39 470.418,1297.39 470.428,1297.39 470.437,1297.39 470.446,1297.39 470.455,1297.39 470.464,1297.38 470.474,1297.38 470.483,1297.38 470.492,1297.38 470.501,1297.38 470.51,1297.38 470.519,1297.38 470.529,1297.38 470.538,1297.37 470.547,1297.37 470.556,1297.37 470.565,1297.37 470.575,1297.37 470.584,1297.37 470.593,1297.37 470.602,1297.36 470.611,1297.36 470.621,1297.36 470.63,1297.36 470.639,1297.36 470.648,1297.36 470.657,1297.36 470.667,1297.36 470.676,1297.35 470.685,1297.35 470.694,1297.35 470.703,1297.35 470.712,1297.35 470.722,1297.35 470.731,1297.35 470.74,1297.35 470.749,1297.34 470.758,1297.34 470.768,1297.34 470.777,1297.34 470.786,1297.34 470.795,1297.34 470.804,1297.34 470.814,1297.33 470.823,1297.33 470.832,1297.33 470.841,1297.33 470.85,1297.33 470.859,1297.33 470.869,1297.33 470.878,1297.33 470.887,1297.32 470.896,1297.32 470.905,1297.32 470.915,1297.32 470.924,1297.32 470.933,1297.32 470.942,1297.32 470.951,1297.31 470.961,1297.31 470.97,1297.31 470.979,1297.31 470.988,1297.31 470.997,1297.31 471.007,1297.31 471.016,1297.31 471.025,1297.3 471.034,1297.3 471.043,1297.3 471.052,1297.3 471.062,1297.3 471.071,1297.3 471.08,1297.3 471.089,1297.3 471.098,1297.29 471.108,1297.29 471.117,1297.29 471.126,1297.29 471.135,1297.29 471.144,1297.29 471.154,1297.29 471.163,1297.28 471.172,1297.28 471.181,1297.28 471.19,1297.28 471.199,1297.28 471.209,1297.28 471.218,1297.28 471.227,1297.28 471.236,1297.27 471.245,1297.27 471.255,1297.27 471.264,1297.27 471.273,1297.27 471.282,1297.27 471.291,1297.27 471.301,1297.27 471.31,1297.26 471.319,1297.26 471.328,1297.26 471.337,1297.26 471.347,1297.26 471.356,1297.26 471.365,1297.26 471.374,1297.25 471.383,1297.25 471.392,1297.25 471.402,1297.25 471.411,1297.25 471.42,1297.25 471.429,1297.25 471.438,1297.25 471.448,1297.24 471.457,1297.24 471.466,1297.24 471.475,1297.24 471.484,1297.24 471.494,1297.24 471.503,1297.24 471.512,1297.24 471.521,1297.23 471.53,1297.23 471.539,1297.23 471.549,1297.23 471.558,1297.23 471.567,1297.23 471.576,1297.23 471.585,1297.22 471.595,1297.22 471.604,1297.22 471.613,1297.22 471.622,1297.22 471.631,1297.22 471.641,1297.22 471.65,1297.22 471.659,1297.21 471.668,1297.21 471.677,1297.21 471.687,1297.21 471.696,1297.21 471.705,1297.21 471.714,1297.21 471.723,1297.21 471.732,1297.2 471.742,1297.2 471.751,1297.2 471.76,1297.2 471.769,1297.2 471.778,1297.2 471.788,1297.2 471.797,1297.19 471.806,1297.19 471.815,1297.19 471.824,1297.19 471.834,1297.19 471.843,1297.19 471.852,1297.19 471.861,1297.19 471.87,1297.18 471.879,1297.18 471.889,1297.18 471.898,1297.18 471.907,1297.18 471.916,1297.18 471.925,1297.18 471.935,1297.18 471.944,1297.17 471.953,1297.17 471.962,1297.17 471.971,1297.17 471.981,1297.17 471.99,1297.17 471.999,1297.17 472.008,1297.16 472.017,1297.16 472.027,1297.16 472.036,1297.16 472.045,1297.16 472.054,1297.16 472.063,1297.16 472.072,1297.16 472.082,1297.15 472.091,1297.15 472.1,1297.15 472.109,1297.15 472.118,1297.15 472.128,1297.15 472.137,1297.15 472.146,1297.15 472.155,1297.14 472.164,1297.14 472.174,1297.14 472.183,1297.14 472.192,1297.14 472.201,1297.14 472.21,1297.14 472.22,1297.14 472.229,1297.13 472.238,1297.13 472.247,1297.13 472.256,1297.13 472.265,1297.13 472.275,1297.13 472.284,1297.13 472.293,1297.12 472.302,1297.12 472.311,1297.12 472.321,1297.12 472.33,1297.12 472.339,1297.12 472.348,1297.12 472.357,1297.12 472.367,1297.11 472.376,1297.11 472.385,1297.11 472.394,1297.11 472.403,1297.11 472.412,1297.11 472.422,1297.11 472.431,1297.11 472.44,1297.1 472.449,1297.1 472.458,1297.1 472.468,1297.1 472.477,1297.1 472.486,1297.1 472.495,1297.1 472.504,1297.1 472.514,1297.09 472.523,1297.09 472.532,1297.09 472.541,1297.09 472.55,1297.09 472.56,1297.09 472.569,1297.09 472.578,1297.08 472.587,1297.08 472.596,1297.08 472.605,1297.08 472.615,1297.08 472.624,1297.08 472.633,1297.08 472.642,1297.08 472.651,1297.07 472.661,1297.07 472.67,1297.07 472.679,1297.07 472.688,1297.07 472.697,1297.07 472.707,1297.07 472.716,1297.07 472.725,1297.06 472.734,1297.06 472.743,1297.06 472.752,1297.06 472.762,1297.06 472.771,1297.06 472.78,1297.06 472.789,1297.06 472.798,1297.05 472.808,1297.05 472.817,1297.05 472.826,1297.05 472.835,1297.05 472.844,1297.05 472.854,1297.05 472.863,1297.05 472.872,1297.04 472.881,1297.04 472.89,1297.04 472.9,1297.04 472.909,1297.04 472.918,1297.04 472.927,1297.04 472.936,1297.03 472.945,1297.03 472.955,1297.03 472.964,1297.03 472.973,1297.03 472.982,1297.03 472.991,1297.03 473.001,1297.03 473.01,1297.02 473.019,1297.02 473.028,1297.02 473.037,1297.02 473.047,1297.02 473.056,1297.02 473.065,1297.02 473.074,1297.02 473.083,1297.01 473.092,1297.01 473.102,1297.01 473.111,1297.01 473.12,1297.01 473.129,1297.01 473.138,1297.01 473.148,1297.01 473.157,1297 473.166,1297 473.175,1297 473.184,1297 473.194,1297 473.203,1297 473.212,1297 473.221,1297 473.23,1296.99 473.24,1296.99 473.249,1296.99 473.258,1296.99 473.267,1296.99 473.276,1296.99 473.285,1296.99 473.295,1296.98 473.304,1296.98 473.313,1296.98 473.322,1296.98 473.331,1296.98 473.341,1296.98 473.35,1296.98 473.359,1296.98 473.368,1296.97 473.377,1296.97 473.387,1296.97 473.396,1296.97 473.405,1296.97 473.414,1296.97 473.423,1296.97 473.432,1296.97 473.442,1296.96 473.451,1296.96 473.46,1296.96 473.469,1296.96 473.478,1296.96 473.488,1296.96 473.497,1296.96 473.506,1296.96 473.515,1296.95 473.524,1296.95 473.534,1296.95 473.543,1296.95 473.552,1296.95 473.561,1296.95 473.57,1296.95 473.58,1296.95 473.589,1296.94 473.598,1296.94 473.607,1296.94 473.616,1296.94 473.625,1296.94 473.635,1296.94 473.644,1296.94 473.653,1296.94 473.662,1296.93 473.671,1296.93 473.681,1296.93 473.69,1296.93 473.699,1296.93 473.708,1296.93 473.717,1296.93 473.727,1296.93 473.736,1296.92 473.745,1296.92 473.754,1296.92 473.763,1296.92 473.772,1296.92 473.782,1296.92 473.791,1296.92 473.8,1296.92 473.809,1296.91 473.818,1296.91 473.828,1296.91 473.837,1296.91 473.846,1296.91 473.855,1296.91 473.864,1296.91 473.874,1296.9 473.883,1296.9 473.892,1296.9 473.901,1296.9 473.91,1296.9 473.92,1296.9 473.929,1296.9 473.938,1296.9 473.947,1296.89 473.956,1296.89 473.965,1296.89 473.975,1296.89 473.984,1296.89 473.993,1296.89 474.002,1296.89 474.011,1296.89 474.021,1296.88 474.03,1296.88 474.039,1296.88 474.048,1296.88 474.057,1296.88 474.067,1296.88 474.076,1296.88 474.085,1296.88 474.094,1296.87 474.103,1296.87 474.112,1296.87 474.122,1296.87 474.131,1296.87 474.14,1296.87 474.149,1296.87 474.158,1296.87 474.168,1296.86 474.177,1296.86 474.186,1296.86 474.195,1296.86 474.204,1296.86 474.214,1296.86 474.223,1296.86 474.232,1296.86 474.241,1296.85 474.25,1296.85 474.26,1296.85 474.269,1296.85 474.278,1296.85 474.287,1296.85 474.296,1296.85 474.305,1296.85 474.315,1296.84 474.324,1296.84 474.333,1296.84 474.342,1296.84 474.351,1296.84 474.361,1296.84 474.37,1296.84 474.379,1296.84 474.388,1296.83 474.397,1296.83 474.407,1296.83 474.416,1296.83 474.425,1296.83 474.434,1296.83 474.443,1296.83 474.452,1296.83 474.462,1296.82 474.471,1296.82 474.48,1296.82 474.489,1296.82 474.498,1296.82 474.508,1296.82 474.517,1296.82 474.526,1296.82 474.535,1296.81 474.544,1296.81 474.554,1296.81 474.563,1296.81 474.572,1296.81 474.581,1296.81 474.59,1296.81 474.6,1296.81 474.609,1296.8 474.618,1296.8 474.627,1296.8 474.636,1296.8 474.645,1296.8 474.655,1296.8 474.664,1296.8 474.673,1296.8 474.682,1296.79 474.691,1296.79 474.701,1296.79 474.71,1296.79 474.719,1296.79 474.728,1296.79 474.737,1296.79 474.747,1296.79 474.756,1296.78 474.765,1296.78 474.774,1296.78 474.783,1296.78 474.793,1296.78 474.802,1296.78 474.811,1296.78 474.82,1296.78 474.829,1296.77 474.838,1296.77 474.848,1296.77 474.857,1296.77 474.866,1296.77 474.875,1296.77 474.884,1296.77 474.894,1296.77 474.903,1296.76 474.912,1296.76 474.921,1296.76 474.93,1296.76 474.94,1296.76 474.949,1296.76 474.958,1296.76 474.967,1296.76 474.976,1296.75 474.985,1296.75 474.995,1296.75 475.004,1296.75 475.013,1296.75 475.022,1296.75 475.031,1296.75 475.041,1296.75 475.05,1296.74 475.059,1296.74 475.068,1296.74 475.077,1296.74 475.087,1296.74 475.096,1296.74 475.105,1296.74 475.114,1296.74 475.123,1296.73 475.133,1296.73 475.142,1296.73 475.151,1296.73 475.16,1296.73 475.169,1296.73 475.178,1296.73 475.188,1296.73 475.197,1296.72 475.206,1296.72 475.215,1296.72 475.224,1296.72 475.234,1296.72 475.243,1296.72 475.252,1296.72 475.261,1296.72 475.27,1296.71 475.28,1296.71 475.289,1296.71 475.298,1296.71 475.307,1296.71 475.316,1296.71 475.325,1296.71 475.335,1296.71 475.344,1296.7 475.353,1296.7 475.362,1296.7 475.371,1296.7 475.381,1296.7 475.39,1296.7 475.399,1296.7 475.408,1296.7 475.417,1296.69 475.427,1296.69 475.436,1296.69 475.445,1296.69 475.454,1296.69 475.463,1296.69 475.473,1296.69 475.482,1296.69 475.491,1296.68 475.5,1296.68 475.509,1296.68 475.518,1296.68 475.528,1296.68 475.537,1296.68 475.546,1296.68 475.555,1296.68 475.564,1296.67 475.574,1296.67 475.583,1296.67 475.592,1296.67 475.601,1296.67 475.61,1296.67 475.62,1296.67 475.629,1296.67 475.638,1296.66 475.647,1296.66 475.656,1296.66 475.665,1296.66 475.675,1296.66 475.684,1296.66 475.693,1296.66 475.702,1296.66 475.711,1296.65 475.721,1296.65 475.73,1296.65 475.739,1296.65 475.748,1296.65 475.757,1296.65 475.767,1296.65 475.776,1296.65 475.785,1296.64 475.794,1296.64 475.803,1296.64 475.813,1296.64 475.822,1296.64 475.831,1296.64 475.84,1296.64 475.849,1296.64 475.858,1296.63 475.868,1296.63 475.877,1296.63 475.886,1296.63 475.895,1296.63 475.904,1296.63 475.914,1296.63 475.923,1296.63 475.932,1296.62 475.941,1296.62 475.95,1296.62 475.96,1296.62 475.969,1296.62 475.978,1296.62 475.987,1296.62 475.996,1296.62 476.005,1296.62 476.015,1296.61 476.024,1296.61 476.033,1296.61 476.042,1296.61 476.051,1296.61 476.061,1296.61 476.07,1296.61 476.079,1296.61 476.088,1296.6 476.097,1296.6 476.107,1296.6 476.116,1296.6 476.125,1296.6 476.134,1296.6 476.143,1296.6 476.153,1296.6 476.162,1296.59 476.171,1296.59 476.18,1296.59 476.189,1296.59 476.198,1296.59 476.208,1296.59 476.217,1296.59 476.226,1296.59 476.235,1296.58 476.244,1296.58 476.254,1296.58 476.263,1296.58 476.272,1296.58 476.281,1296.58 476.29,1296.58 476.3,1296.58 476.309,1296.57 476.318,1296.57 476.327,1296.57 476.336,1296.57 476.345,1296.57 476.355,1296.57 476.364,1296.57 476.373,1296.57 476.382,1296.56 476.391,1296.56 476.401,1296.56 476.41,1296.56 476.419,1296.56 476.428,1296.56 476.437,1296.56 476.447,1296.56 476.456,1296.55 476.465,1296.55 476.474,1296.55 476.483,1296.55 476.493,1296.55 476.502,1296.55 476.511,1296.55 476.52,1296.55 476.529,1296.54 476.538,1296.54 476.548,1296.54 476.557,1296.54 476.566,1296.54 476.575,1296.54 476.584,1296.54 476.594,1296.54 476.603,1296.54 476.612,1296.53 476.621,1296.53 476.63,1296.53 476.64,1296.53 476.649,1296.53 476.658,1296.53 476.667,1296.53 476.676,1296.53 476.685,1296.52 476.695,1296.52 476.704,1296.52 476.713,1296.52 476.722,1296.52 476.731,1296.52 476.741,1296.52 476.75,1296.52 476.759,1296.51 476.768,1296.51 476.777,1296.51 476.787,1296.51 476.796,1296.51 476.805,1296.51 476.814,1296.51 476.823,1296.51 476.833,1296.5 476.842,1296.5 476.851,1296.5 476.86,1296.5 476.869,1296.5 476.878,1296.5 476.888,1296.5 476.897,1296.5 476.906,1296.49 476.915,1296.49 476.924,1296.49 476.934,1296.49 476.943,1296.49 476.952,1296.49 476.961,1296.49 476.97,1296.49 476.98,1296.49 476.989,1296.48 476.998,1296.48 477.007,1296.48 477.016,1296.48 477.026,1296.48 477.035,1296.48 477.044,1296.48 477.053,1296.48 477.062,1296.47 477.071,1296.47 477.081,1296.47 477.09,1296.47 477.099,1296.47 477.108,1296.47 477.117,1296.47 477.127,1296.47 477.136,1296.46 477.145,1296.46 477.154,1296.46 477.163,1296.46 477.173,1296.46 477.182,1296.46 477.191,1296.46 477.2,1296.46 477.209,1296.45 477.218,1296.45 477.228,1296.45 477.237,1296.45 477.246,1296.45 477.255,1296.45 477.264,1296.45 477.274,1296.45 477.283,1296.44 477.292,1296.44 477.301,1296.44 477.31,1296.44 477.32,1296.44 477.329,1296.44 477.338,1296.44 477.347,1296.44 477.356,1296.44 477.366,1296.43 477.375,1296.43 477.384,1296.43 477.393,1296.43 477.402,1296.43 477.411,1296.43 477.421,1296.43 477.43,1296.43 477.439,1296.42 477.448,1296.42 477.457,1296.42 477.467,1296.42 477.476,1296.42 477.485,1296.42 477.494,1296.42 477.503,1296.42 477.513,1296.41 477.522,1296.41 477.531,1296.41 477.54,1296.41 477.549,1296.41 477.558,1296.41 477.568,1296.41 477.577,1296.41 477.586,1296.4 477.595,1296.4 477.604,1296.4 477.614,1296.4 477.623,1296.4 477.632,1296.4 477.641,1296.4 477.65,1296.4 477.66,1296.4 477.669,1296.39 477.678,1296.39 477.687,1296.39 477.696,1296.39 477.706,1296.39 477.715,1296.39 477.724,1296.39 477.733,1296.39 477.742,1296.38 477.751,1296.38 477.761,1296.38 477.77,1296.38 477.779,1296.38 477.788,1296.38 477.797,1296.38 477.807,1296.38 477.816,1296.37 477.825,1296.37 477.834,1296.37 477.843,1296.37 477.853,1296.37 477.862,1296.37 477.871,1296.37 477.88,1296.37 477.889,1296.37 477.898,1296.36 477.908,1296.36 477.917,1296.36 477.926,1296.36 477.935,1296.36 477.944,1296.36 477.954,1296.36 477.963,1296.36 477.972,1296.35 477.981,1296.35 477.99,1296.35 478,1296.35 478.009,1296.35 478.018,1296.35 478.027,1296.35 478.036,1296.35 478.046,1296.34 478.055,1296.34 478.064,1296.34 478.073,1296.34 478.082,1296.34 478.091,1296.34 478.101,1296.34 478.11,1296.34 478.119,1296.34 478.128,1296.33 478.137,1296.33 478.147,1296.33 478.156,1296.33 478.165,1296.33 478.174,1296.33 478.183,1296.33 478.193,1296.33 478.202,1296.32 478.211,1296.32 478.22,1296.32 478.229,1296.32 478.238,1296.32 478.248,1296.32 478.257,1296.32 478.266,1296.32 478.275,1296.31 478.284,1296.31 478.294,1296.31 478.303,1296.31 478.312,1296.31 478.321,1296.31 478.33,1296.31 478.34,1296.31 478.349,1296.31 478.358,1296.3 478.367,1296.3 478.376,1296.3 478.386,1296.3 478.395,1296.3 478.404,1296.3 478.413,1296.3 478.422,1296.3 478.431,1296.29 478.441,1296.29 478.45,1296.29 478.459,1296.29 478.468,1296.29 478.477,1296.29 478.487,1296.29 478.496,1296.29 478.505,1296.28 478.514,1296.28 478.523,1296.28 478.533,1296.28 478.542,1296.28 478.551,1296.28 478.56,1296.28 478.569,1296.28 478.578,1296.28 478.588,1296.27 478.597,1296.27 478.606,1296.27 478.615,1296.27 478.624,1296.27 478.634,1296.27 478.643,1296.27 478.652,1296.27 478.661,1296.26 478.67,1296.26 478.68,1296.26 478.689,1296.26 478.698,1296.26 478.707,1296.26 478.716,1296.26 478.726,1296.26 478.735,1296.25 478.744,1296.25 478.753,1296.25 478.762,1296.25 478.771,1296.25 478.781,1296.25 478.79,1296.25 478.799,1296.25 478.808,1296.25 478.817,1296.24 478.827,1296.24 478.836,1296.24 478.845,1296.24 478.854,1296.24 478.863,1296.24 478.873,1296.24 478.882,1296.24 478.891,1296.23 478.9,1296.23 478.909,1296.23 478.918,1296.23 478.928,1296.23 478.937,1296.23 478.946,1296.23 478.955,1296.23 478.964,1296.23 478.974,1296.22 478.983,1296.22 478.992,1296.22 479.001,1296.22 479.01,1296.22 479.02,1296.22 479.029,1296.22 479.038,1296.22 479.047,1296.21 479.056,1296.21 479.066,1296.21 479.075,1296.21 479.084,1296.21 479.093,1296.21 479.102,1296.21 479.111,1296.21 479.121,1296.2 479.13,1296.2 479.139,1296.2 479.148,1296.2 479.157,1296.2 479.167,1296.2 479.176,1296.2 479.185,1296.2 479.194,1296.2 479.203,1296.19 479.213,1296.19 479.222,1296.19 479.231,1296.19 479.24,1296.19 479.249,1296.19 479.258,1296.19 479.268,1296.19 479.277,1296.18 479.286,1296.18 479.295,1296.18 479.304,1296.18 479.314,1296.18 479.323,1296.18 479.332,1296.18 479.341,1296.18 479.35,1296.18 479.36,1296.17 479.369,1296.17 479.378,1296.17 479.387,1296.17 479.396,1296.17 479.406,1296.17 479.415,1296.17 479.424,1296.17 479.433,1296.16 479.442,1296.16 479.451,1296.16 479.461,1296.16 479.47,1296.16 479.479,1296.16 479.488,1296.16 479.497,1296.16 479.507,1296.16 479.516,1296.15 479.525,1296.15 479.534,1296.15 479.543,1296.15 479.553,1296.15 479.562,1296.15 479.571,1296.15 479.58,1296.15 479.589,1296.14 479.599,1296.14 479.608,1296.14 479.617,1296.14 479.626,1296.14 479.635,1296.14 479.644,1296.14 479.654,1296.14 479.663,1296.14 479.672,1296.13 479.681,1296.13 479.69,1296.13 479.7,1296.13 479.709,1296.13 479.718,1296.13 479.727,1296.13 479.736,1296.13 479.746,1296.12 479.755,1296.12 479.764,1296.12 479.773,1296.12 479.782,1296.12 479.791,1296.12 479.801,1296.12 479.81,1296.12 479.819,1296.12 479.828,1296.11 479.837,1296.11 479.847,1296.11 479.856,1296.11 479.865,1296.11 479.874,1296.11 479.883,1296.11 479.893,1296.11 479.902,1296.1 479.911,1296.1 479.92,1296.1 479.929,1296.1 479.939,1296.1 479.948,1296.1 479.957,1296.1 479.966,1296.1 479.975,1296.1 479.984,1296.09 479.994,1296.09 480.003,1296.09 480.012,1296.09 480.021,1296.09 480.03,1296.09 480.04,1296.09 480.049,1296.09 480.058,1296.08 480.067,1296.08 480.076,1296.08 480.086,1296.08 480.095,1296.08 480.104,1296.08 480.113,1296.08 480.122,1296.08 480.131,1296.08 480.141,1296.07 480.15,1296.07 480.159,1296.07 480.168,1296.07 480.177,1296.07 480.187,1296.07 480.196,1296.07 480.205,1296.07 480.214,1296.06 480.223,1296.06 480.233,1296.06 480.242,1296.06 480.251,1296.06 480.26,1296.06 480.269,1296.06 480.279,1296.06 480.288,1296.06 480.297,1296.05 480.306,1296.05 480.315,1296.05 480.324,1296.05 480.334,1296.05 480.343,1296.05 480.352,1296.05 480.361,1296.05 480.37,1296.04 480.38,1296.04 480.389,1296.04 480.398,1296.04 480.407,1296.04 480.416,1296.04 480.426,1296.04 480.435,1296.04 480.444,1296.04 480.453,1296.03 480.462,1296.03 480.471,1296.03 480.481,1296.03 480.49,1296.03 480.499,1296.03 480.508,1296.03 480.517,1296.03 480.527,1296.02 480.536,1296.02 480.545,1296.02 480.554,1296.02 480.563,1296.02 480.573,1296.02 480.582,1296.02 480.591,1296.02 480.6,1296.02 480.609,1296.01 480.619,1296.01 480.628,1296.01 480.637,1296.01 480.646,1296.01 480.655,1296.01 480.664,1296.01 480.674,1296.01 480.683,1296.01 480.692,1296 480.701,1296 480.71,1296 480.72,1296 480.729,1296 480.738,1296 480.747,1296 480.756,1296 480.766,1295.99 480.775,1295.99 480.784,1295.99 480.793,1295.99 480.802,1295.99 480.811,1295.99 480.821,1295.99 480.83,1295.99 480.839,1295.99 480.848,1295.98 480.857,1295.98 480.867,1295.98 480.876,1295.98 480.885,1295.98 480.894,1295.98 480.903,1295.98 480.913,1295.98 480.922,1295.97 480.931,1295.97 480.94,1295.97 480.949,1295.97 480.959,1295.97 480.968,1295.97 480.977,1295.97 480.986,1295.97 480.995,1295.97 481.004,1295.96 481.014,1295.96 481.023,1295.96 481.032,1295.96 481.041,1295.96 481.05,1295.96 481.06,1295.96 481.069,1295.96 481.078,1295.96 481.087,1295.95 481.096,1295.95 481.106,1295.95 481.115,1295.95 481.124,1295.95 481.133,1295.95 481.142,1295.95 481.151,1295.95 481.161,1295.94 481.17,1295.94 481.179,1295.94 481.188,1295.94 481.197,1295.94 481.207,1295.94 481.216,1295.94 481.225,1295.94 481.234,1295.94 481.243,1295.93 481.253,1295.93 481.262,1295.93 481.271,1295.93 481.28,1295.93 481.289,1295.93 481.299,1295.93 481.308,1295.93 481.317,1295.93 481.326,1295.92 481.335,1295.92 481.344,1295.92 481.354,1295.92 481.363,1295.92 481.372,1295.92 481.381,1295.92 481.39,1295.92 481.4,1295.91 481.409,1295.91 481.418,1295.91 481.427,1295.91 481.436,1295.91 481.446,1295.91 481.455,1295.91 481.464,1295.91 481.473,1295.91 481.482,1295.9 481.491,1295.9 481.501,1295.9 481.51,1295.9 481.519,1295.9 481.528,1295.9 481.537,1295.9 481.547,1295.9 481.556,1295.9 481.565,1295.89 481.574,1295.89 481.583,1295.89 481.593,1295.89 481.602,1295.89 481.611,1295.89 481.62,1295.89 481.629,1295.89 481.639,1295.88 481.648,1295.88 481.657,1295.88 481.666,1295.88 481.675,1295.88 481.684,1295.88 481.694,1295.88 481.703,1295.88 481.712,1295.88 481.721,1295.87 481.73,1295.87 481.74,1295.87 481.749,1295.87 481.758,1295.87 481.767,1295.87 481.776,1295.87 481.786,1295.87 481.795,1295.87 481.804,1295.86 481.813,1295.86 481.822,1295.86 481.831,1295.86 481.841,1295.86 481.85,1295.86 481.859,1295.86 481.868,1295.86 481.877,1295.86 481.887,1295.85 481.896,1295.85 481.905,1295.85 481.914,1295.85 481.923,1295.85 481.933,1295.85 481.942,1295.85 481.951,1295.85 481.96,1295.84 481.969,1295.84 481.979,1295.84 481.988,1295.84 481.997,1295.84 482.006,1295.84 482.015,1295.84 482.024,1295.84 482.034,1295.84 482.043,1295.83 482.052,1295.83 482.061,1295.83 482.07,1295.83 482.08,1295.83 482.089,1295.83 482.098,1295.83 482.107,1295.83 482.116,1295.83 482.126,1295.82 482.135,1295.82 482.144,1295.82 482.153,1295.82 482.162,1295.82 482.172,1295.82 482.181,1295.82 482.19,1295.82 482.199,1295.81 482.208,1295.81 482.217,1295.81 482.227,1295.81 482.236,1295.81 482.245,1295.81 482.254,1295.81 482.263,1295.81 482.273,1295.81 482.282,1295.8 482.291,1295.8 482.3,1295.8 482.309,1295.8 482.319,1295.8 482.328,1295.8 482.337,1295.8 482.346,1295.8 482.355,1295.8 482.364,1295.79 482.374,1295.79 482.383,1295.79 482.392,1295.79 482.401,1295.79 482.41,1295.79 482.42,1295.79 482.429,1295.79 482.438,1295.79 482.447,1295.78 482.456,1295.78 482.466,1295.78 482.475,1295.78 482.484,1295.78 482.493,1295.78 482.502,1295.78 482.512,1295.78 482.521,1295.78 482.53,1295.77 482.539,1295.77 482.548,1295.77 482.557,1295.77 482.567,1295.77 482.576,1295.77 482.585,1295.77 482.594,1295.77 482.603,1295.76 482.613,1295.76 482.622,1295.76 482.631,1295.76 482.64,1295.76 482.649,1295.76 482.659,1295.76 482.668,1295.76 482.677,1295.76 482.686,1295.75 482.695,1295.75 482.704,1295.75 482.714,1295.75 482.723,1295.75 482.732,1295.75 482.741,1295.75 482.75,1295.75 482.76,1295.75 482.769,1295.74 482.778,1295.74 482.787,1295.74 482.796,1295.74 482.806,1295.74 482.815,1295.74 482.824,1295.74 482.833,1295.74 482.842,1295.74 482.852,1295.73 482.861,1295.73 482.87,1295.73 482.879,1295.73 482.888,1295.73 482.897,1295.73 482.907,1295.73 482.916,1295.73 482.925,1295.73 482.934,1295.72 482.943,1295.72 482.953,1295.72 482.962,1295.72 482.971,1295.72 482.98,1295.72 482.989,1295.72 482.999,1295.72 483.008,1295.71 483.017,1295.71 483.026,1295.71 483.035,1295.71 483.044,1295.71 483.054,1295.71 483.063,1295.71 483.072,1295.71 483.081,1295.71 483.09,1295.7 483.1,1295.7 483.109,1295.7 483.118,1295.7 483.127,1295.7 483.136,1295.7 483.146,1295.7 483.155,1295.7 483.164,1295.7 483.173,1295.69 483.182,1295.69 483.192,1295.69 483.201,1295.69 483.21,1295.69 483.219,1295.69 483.228,1295.69 483.237,1295.69 483.247,1295.69 483.256,1295.68 483.265,1295.68 483.274,1295.68 483.283,1295.68 483.293,1295.68 483.302,1295.68 483.311,1295.68 483.32,1295.68 483.329,1295.68 483.339,1295.67 483.348,1295.67 483.357,1295.67 483.366,1295.67 483.375,1295.67 483.384,1295.67 483.394,1295.67 483.403,1295.67 483.412,1295.67 483.421,1295.66 483.43,1295.66 483.44,1295.66 483.449,1295.66 483.458,1295.66 483.467,1295.66 483.476,1295.66 483.486,1295.66 483.495,1295.66 483.504,1295.65 483.513,1295.65 483.522,1295.65 483.532,1295.65 483.541,1295.65 483.55,1295.65 483.559,1295.65 483.568,1295.65 483.577,1295.65 483.587,1295.64 483.596,1295.64 483.605,1295.64 483.614,1295.64 483.623,1295.64 483.633,1295.64 483.642,1295.64 483.651,1295.64 483.66,1295.64 483.669,1295.63 483.679,1295.63 483.688,1295.63 483.697,1295.63 483.706,1295.63 483.715,1295.63 483.724,1295.63 483.734,1295.63 483.743,1295.62 483.752,1295.62 483.761,1295.62 483.77,1295.62 483.78,1295.62 483.789,1295.62 483.798,1295.62 483.807,1295.62 483.816,1295.62 483.826,1295.61 483.835,1295.61 483.844,1295.61 483.853,1295.61 483.862,1295.61 483.872,1295.61 483.881,1295.61 483.89,1295.61 483.899,1295.61 483.908,1295.6 483.917,1295.6 483.927,1295.6 483.936,1295.6 483.945,1295.6 483.954,1295.6 483.963,1295.6 483.973,1295.6 483.982,1295.6 483.991,1295.59 484,1295.59 484.009,1295.59 484.019,1295.59 484.028,1295.59 484.037,1295.59 484.046,1295.59 484.055,1295.59 484.064,1295.59 484.074,1295.58 484.083,1295.58 484.092,1295.58 484.101,1295.58 484.11,1295.58 484.12,1295.58 484.129,1295.58 484.138,1295.58 484.147,1295.58 484.156,1295.57 484.166,1295.57 484.175,1295.57 484.184,1295.57 484.193,1295.57 484.202,1295.57 484.212,1295.57 484.221,1295.57 484.23,1295.57 484.239,1295.56 484.248,1295.56 484.257,1295.56 484.267,1295.56 484.276,1295.56 484.285,1295.56 484.294,1295.56 484.303,1295.56 484.313,1295.56 484.322,1295.55 484.331,1295.55 484.34,1295.55 484.349,1295.55 484.359,1295.55 484.368,1295.55 484.377,1295.55 484.386,1295.55 484.395,1295.55 484.405,1295.54 484.414,1295.54 484.423,1295.54 484.432,1295.54 484.441,1295.54 484.45,1295.54 484.46,1295.54 484.469,1295.54 484.478,1295.54 484.487,1295.53 484.496,1295.53 484.506,1295.53 484.515,1295.53 484.524,1295.53 484.533,1295.53 484.542,1295.53 484.552,1295.53 484.561,1295.53 484.57,1295.52 484.579,1295.52 484.588,1295.52 484.597,1295.52 484.607,1295.52 484.616,1295.52 484.625,1295.52 484.634,1295.52 484.643,1295.52 484.653,1295.51 484.662,1295.51 484.671,1295.51 484.68,1295.51 484.689,1295.51 484.699,1295.51 484.708,1295.51 484.717,1295.51 484.726,1295.51 484.735,1295.5 484.745,1295.5 484.754,1295.5 484.763,1295.5 484.772,1295.5 484.781,1295.5 484.79,1295.5 484.8,1295.5 484.809,1295.5 484.818,1295.49 484.827,1295.49 484.836,1295.49 484.846,1295.49 484.855,1295.49 484.864,1295.49 484.873,1295.49 484.882,1295.49 484.892,1295.49 484.901,1295.48 484.91,1295.48 484.919,1295.48 484.928,1295.48 484.937,1295.48 484.947,1295.48 484.956,1295.48 484.965,1295.48 484.974,1295.48 484.983,1295.47 484.993,1295.47 485.002,1295.47 485.011,1295.47 485.02,1295.47 485.029,1295.47 485.039,1295.47 485.048,1295.47 485.057,1295.47 485.066,1295.47 485.075,1295.46 485.085,1295.46 485.094,1295.46 485.103,1295.46 485.112,1295.46 485.121,1295.46 485.13,1295.46 485.14,1295.46 485.149,1295.46 485.158,1295.45 485.167,1295.45 485.176,1295.45 485.186,1295.45 485.195,1295.45 485.204,1295.45 485.213,1295.45 485.222,1295.45 485.232,1295.45 485.241,1295.44 485.25,1295.44 485.259,1295.44 485.268,1295.44 485.277,1295.44 485.287,1295.44 485.296,1295.44 485.305,1295.44 485.314,1295.44 485.323,1295.43 485.333,1295.43 485.342,1295.43 485.351,1295.43 485.36,1295.43 485.369,1295.43 485.379,1295.43 485.388,1295.43 485.397,1295.43 485.406,1295.42 485.415,1295.42 485.425,1295.42 485.434,1295.42 485.443,1295.42 485.452,1295.42 485.461,1295.42 485.47,1295.42 485.48,1295.42 485.489,1295.41 485.498,1295.41 485.507,1295.41 485.516,1295.41 485.526,1295.41 485.535,1295.41 485.544,1295.41 485.553,1295.41 485.562,1295.41 485.572,1295.4 485.581,1295.4 485.59,1295.4 485.599,1295.4 485.608,1295.4 485.617,1295.4 485.627,1295.4 485.636,1295.4 485.645,1295.4 485.654,1295.39 485.663,1295.39 485.673,1295.39 485.682,1295.39 485.691,1295.39 485.7,1295.39 485.709,1295.39 485.719,1295.39 485.728,1295.39 485.737,1295.39 485.746,1295.38 485.755,1295.38 485.765,1295.38 485.774,1295.38 485.783,1295.38 485.792,1295.38 485.801,1295.38 485.81,1295.38 485.82,1295.38 485.829,1295.37 485.838,1295.37 485.847,1295.37 485.856,1295.37 485.866,1295.37 485.875,1295.37 485.884,1295.37 485.893,1295.37 485.902,1295.37 485.912,1295.36 485.921,1295.36 485.93,1295.36 485.939,1295.36 485.948,1295.36 485.957,1295.36 485.967,1295.36 485.976,1295.36 485.985,1295.36 485.994,1295.35 486.003,1295.35 486.013,1295.35 486.022,1295.35 486.031,1295.35 486.04,1295.35 486.049,1295.35 486.059,1295.35 486.068,1295.35 486.077,1295.34 486.086,1295.34 486.095,1295.34 486.105,1295.34 486.114,1295.34 486.123,1295.34 486.132,1295.34 486.141,1295.34 486.15,1295.34 486.16,1295.33 486.169,1295.33 486.178,1295.33 486.187,1295.33 486.196,1295.33 486.206,1295.33 486.215,1295.33 486.224,1295.33 486.233,1295.33 486.242,1295.33 486.252,1295.32 486.261,1295.32 486.27,1295.32 486.279,1295.32 486.288,1295.32 486.297,1295.32 486.307,1295.32 486.316,1295.32 486.325,1295.32 486.334,1295.31 486.343,1295.31 486.353,1295.31 486.362,1295.31 486.371,1295.31 486.38,1295.31 486.389,1295.31 486.399,1295.31 486.408,1295.31 486.417,1295.3 486.426,1295.3 486.435,1295.3 486.445,1295.3 486.454,1295.3 486.463,1295.3 486.472,1295.3 486.481,1295.3 486.49,1295.3 486.5,1295.29 486.509,1295.29 486.518,1295.29 486.527,1295.29 486.536,1295.29 486.546,1295.29 486.555,1295.29 486.564,1295.29 486.573,1295.29 486.582,1295.29 486.592,1295.28 486.601,1295.28 486.61,1295.28 486.619,1295.28 486.628,1295.28 486.637,1295.28 486.647,1295.28 486.656,1295.28 486.665,1295.28 486.674,1295.27 486.683,1295.27 486.693,1295.27 486.702,1295.27 486.711,1295.27 486.72,1295.27 486.729,1295.27 486.739,1295.27 486.748,1295.27 486.757,1295.26 486.766,1295.26 486.775,1295.26 486.785,1295.26 486.794,1295.26 486.803,1295.26 486.812,1295.26 486.821,1295.26 486.83,1295.26 486.84,1295.25 486.849,1295.25 486.858,1295.25 486.867,1295.25 486.876,1295.25 486.886,1295.25 486.895,1295.25 486.904,1295.25 486.913,1295.25 486.922,1295.25 486.932,1295.24 486.941,1295.24 486.95,1295.24 486.959,1295.24 486.968,1295.24 486.978,1295.24 486.987,1295.24 486.996,1295.24 487.005,1295.24 487.014,1295.23 487.023,1295.23 487.033,1295.23 487.042,1295.23 487.051,1295.23 487.06,1295.23 487.069,1295.23 487.079,1295.23 487.088,1295.23 487.097,1295.22 487.106,1295.22 487.115,1295.22 487.125,1295.22 487.134,1295.22 487.143,1295.22 487.152,1295.22 487.161,1295.22 487.17,1295.22 487.18,1295.22 487.189,1295.21 487.198,1295.21 487.207,1295.21 487.216,1295.21 487.226,1295.21 487.235,1295.21 487.244,1295.21 487.253,1295.21 487.262,1295.21 487.272,1295.2 487.281,1295.2 487.29,1295.2 487.299,1295.2 487.308,1295.2 487.318,1295.2 487.327,1295.2 487.336,1295.2 487.345,1295.2 487.354,1295.19 487.363,1295.19 487.373,1295.19 487.382,1295.19 487.391,1295.19 487.4,1295.19 487.409,1295.19 487.419,1295.19 487.428,1295.19 487.437,1295.19 487.446,1295.18 487.455,1295.18 487.465,1295.18 487.474,1295.18 487.483,1295.18 487.492,1295.18 487.501,1295.18 487.51,1295.18 487.52,1295.18 487.529,1295.17 487.538,1295.17 487.547,1295.17 487.556,1295.17 487.566,1295.17 487.575,1295.17 487.584,1295.17 487.593,1295.17 487.602,1295.17 487.612,1295.16 487.621,1295.16 487.63,1295.16 487.639,1295.16 487.648,1295.16 487.658,1295.16 487.667,1295.16 487.676,1295.16 487.685,1295.16 487.694,1295.16 487.703,1295.15 487.713,1295.15 487.722,1295.15 487.731,1295.15 487.74,1295.15 487.749,1295.15 487.759,1295.15 487.768,1295.15 487.777,1295.15 487.786,1295.14 487.795,1295.14 487.805,1295.14 487.814,1295.14 487.823,1295.14 487.832,1295.14 487.841,1295.14 487.85,1295.14 487.86,1295.14 487.869,1295.14 487.878,1295.13 487.887,1295.13 487.896,1295.13 487.906,1295.13 487.915,1295.13 487.924,1295.13 487.933,1295.13 487.942,1295.13 487.952,1295.13 487.961,1295.12 487.97,1295.12 487.979,1295.12 487.988,1295.12 487.998,1295.12 488.007,1295.12 488.016,1295.12 488.025,1295.12 488.034,1295.12 488.043,1295.11 488.053,1295.11 488.062,1295.11 488.071,1295.11 488.08,1295.11 488.089,1295.11 488.099,1295.11 488.108,1295.11 488.117,1295.11 488.126,1295.11 488.135,1295.1 488.145,1295.1 488.154,1295.1 488.163,1295.1 488.172,1295.1 488.181,1295.1 488.19,1295.1 488.2,1295.1 488.209,1295.1 488.218,1295.09 488.227,1295.09 488.236,1295.09 488.246,1295.09 488.255,1295.09 488.264,1295.09 488.273,1295.09 488.282,1295.09 488.292,1295.09 488.301,1295.09 488.31,1295.08 488.319,1295.08 488.328,1295.08 488.338,1295.08 488.347,1295.08 488.356,1295.08 488.365,1295.08 488.374,1295.08 488.383,1295.08 488.393,1295.07 488.402,1295.07 488.411,1295.07 488.42,1295.07 488.429,1295.07 488.439,1295.07 488.448,1295.07 488.457,1295.07 488.466,1295.07 488.475,1295.07 488.485,1295.06 488.494,1295.06 488.503,1295.06 488.512,1295.06 488.521,1295.06 488.53,1295.06 488.54,1295.06 488.549,1295.06 488.558,1295.06 488.567,1295.05 488.576,1295.05 488.586,1295.05 488.595,1295.05 488.604,1295.05 488.613,1295.05 488.622,1295.05 488.632,1295.05 488.641,1295.05 488.65,1295.05 488.659,1295.04 488.668,1295.04 488.678,1295.04 488.687,1295.04 488.696,1295.04 488.705,1295.04 488.714,1295.04 488.723,1295.04 488.733,1295.04 488.742,1295.03 488.751,1295.03 488.76,1295.03 488.769,1295.03 488.779,1295.03 488.788,1295.03 488.797,1295.03 488.806,1295.03 488.815,1295.03 488.825,1295.03 488.834,1295.02 488.843,1295.02 488.852,1295.02 488.861,1295.02 488.87,1295.02 488.88,1295.02 488.889,1295.02 488.898,1295.02 488.907,1295.02 488.916,1295.01 488.926,1295.01 488.935,1295.01 488.944,1295.01 488.953,1295.01 488.962,1295.01 488.972,1295.01 488.981,1295.01 488.99,1295.01 488.999,1295.01 489.008,1295 489.018,1295 489.027,1295 489.036,1295 489.045,1295 489.054,1295 489.063,1295 489.073,1295 489.082,1295 489.091,1294.99 489.1,1294.99 489.109,1294.99 489.119,1294.99 489.128,1294.99 489.137,1294.99 489.146,1294.99 489.155,1294.99 489.165,1294.99 489.174,1294.99 489.183,1294.98 489.192,1294.98 489.201,1294.98 489.21,1294.98 489.22,1294.98 489.229,1294.98 489.238,1294.98 489.247,1294.98 489.256,1294.98 489.266,1294.97 489.275,1294.97 489.284,1294.97 489.293,1294.97 489.302,1294.97 489.312,1294.97 489.321,1294.97 489.33,1294.97 489.339,1294.97 489.348,1294.97 489.358,1294.96 489.367,1294.96 489.376,1294.96 489.385,1294.96 489.394,1294.96 489.403,1294.96 489.413,1294.96 489.422,1294.96 489.431,1294.96 489.44,1294.96 489.449,1294.95 489.459,1294.95 489.468,1294.95 489.477,1294.95 489.486,1294.95 489.495,1294.95 489.505,1294.95 489.514,1294.95 489.523,1294.95 489.532,1294.94 489.541,1294.94 489.551,1294.94 489.56,1294.94 489.569,1294.94 489.578,1294.94 489.587,1294.94 489.596,1294.94 489.606,1294.94 489.615,1294.94 489.624,1294.93 489.633,1294.93 489.642,1294.93 489.652,1294.93 489.661,1294.93 489.67,1294.93 489.679,1294.93 489.688,1294.93 489.698,1294.93 489.707,1294.92 489.716,1294.92 489.725,1294.92 489.734,1294.92 489.743,1294.92 489.753,1294.92 489.762,1294.92 489.771,1294.92 489.78,1294.92 489.789,1294.92 489.799,1294.91 489.808,1294.91 489.817,1294.91 489.826,1294.91 489.835,1294.91 489.845,1294.91 489.854,1294.91 489.863,1294.91 489.872,1294.91 489.881,1294.91 489.891,1294.9 489.9,1294.9 489.909,1294.9 489.918,1294.9 489.927,1294.9 489.936,1294.9 489.946,1294.9 489.955,1294.9 489.964,1294.9 489.973,1294.89 489.982,1294.89 489.992,1294.89 490.001,1294.89 490.01,1294.89 490.019,1294.89 490.028,1294.89 490.038,1294.89 490.047,1294.89 490.056,1294.89 490.065,1294.88 490.074,1294.88 490.083,1294.88 490.093,1294.88 490.102,1294.88 490.111,1294.88 490.12,1294.88 490.129,1294.88 490.139,1294.88 490.148,1294.88 490.157,1294.87 490.166,1294.87 490.175,1294.87 490.185,1294.87 490.194,1294.87 490.203,1294.87 490.212,1294.87 490.221,1294.87 490.231,1294.87 490.24,1294.86 490.249,1294.86 490.258,1294.86 490.267,1294.86 490.276,1294.86 490.286,1294.86 490.295,1294.86 490.304,1294.86 490.313,1294.86 490.322,1294.86 490.332,1294.85 490.341,1294.85 490.35,1294.85 490.359,1294.85 490.368,1294.85 490.378,1294.85 490.387,1294.85 490.396,1294.85 490.405,1294.85 490.414,1294.85 490.423,1294.84 490.433,1294.84 490.442,1294.84 490.451,1294.84 490.46,1294.84 490.469,1294.84 490.479,1294.84 490.488,1294.84 490.497,1294.84 490.506,1294.84 490.515,1294.83 490.525,1294.83 490.534,1294.83 490.543,1294.83 490.552,1294.83 490.561,1294.83 490.571,1294.83 490.58,1294.83 490.589,1294.83 490.598,1294.82 490.607,1294.82 490.616,1294.82 490.626,1294.82 490.635,1294.82 490.644,1294.82 490.653,1294.82 490.662,1294.82 490.672,1294.82 490.681,1294.82 490.69,1294.81 490.699,1294.81 490.708,1294.81 490.718,1294.81 490.727,1294.81 490.736,1294.81 490.745,1294.81 490.754,1294.81 490.763,1294.81 490.773,1294.81 490.782,1294.8 490.791,1294.8 490.8,1294.8 490.809,1294.8 490.819,1294.8 490.828,1294.8 490.837,1294.8 490.846,1294.8 490.855,1294.8 490.865,1294.8 490.874,1294.79 490.883,1294.79 490.892,1294.79 490.901,1294.79 490.911,1294.79 490.92,1294.79 490.929,1294.79 490.938,1294.79 490.947,1294.79 490.956,1294.78 490.966,1294.78 490.975,1294.78 490.984,1294.78 490.993,1294.78 491.002,1294.78 491.012,1294.78 491.021,1294.78 491.03,1294.78 491.039,1294.78 491.048,1294.77 491.058,1294.77 491.067,1294.77 491.076,1294.77 491.085,1294.77 491.094,1294.77 491.103,1294.77 491.113,1294.77 491.122,1294.77 491.131,1294.77 491.14,1294.76 491.149,1294.76 491.159,1294.76 491.168,1294.76 491.177,1294.76 491.186,1294.76 491.195,1294.76 491.205,1294.76 491.214,1294.76 491.223,1294.76 491.232,1294.75 491.241,1294.75 491.251,1294.75 491.26,1294.75 491.269,1294.75 491.278,1294.75 491.287,1294.75 491.296,1294.75 491.306,1294.75 491.315,1294.75 491.324,1294.74 491.333,1294.74 491.342,1294.74 491.352,1294.74 491.361,1294.74 491.37,1294.74 491.379,1294.74 491.388,1294.74 491.398,1294.74 491.407,1294.73 491.416,1294.73 491.425,1294.73 491.434,1294.73 491.443,1294.73 491.453,1294.73 491.462,1294.73 491.471,1294.73 491.48,1294.73 491.489,1294.73 491.499,1294.72 491.508,1294.72 491.517,1294.72 491.526,1294.72 491.535,1294.72 491.545,1294.72 491.554,1294.72 491.563,1294.72 491.572,1294.72 491.581,1294.72 491.591,1294.71 491.6,1294.71 491.609,1294.71 491.618,1294.71 491.627,1294.71 491.636,1294.71 491.646,1294.71 491.655,1294.71 491.664,1294.71 491.673,1294.71 491.682,1294.7 491.692,1294.7 491.701,1294.7 491.71,1294.7 491.719,1294.7 491.728,1294.7 491.738,1294.7 491.747,1294.7 491.756,1294.7 491.765,1294.7 491.774,1294.69 491.784,1294.69 491.793,1294.69 491.802,1294.69 491.811,1294.69 491.82,1294.69 491.829,1294.69 491.839,1294.69 491.848,1294.69 491.857,1294.69 491.866,1294.68 491.875,1294.68 491.885,1294.68 491.894,1294.68 491.903,1294.68 491.912,1294.68 491.921,1294.68 491.931,1294.68 491.94,1294.68 491.949,1294.68 491.958,1294.67 491.967,1294.67 491.976,1294.67 491.986,1294.67 491.995,1294.67 492.004,1294.67 492.013,1294.67 492.022,1294.67 492.032,1294.67 492.041,1294.67 492.05,1294.66 492.059,1294.66 492.068,1294.66 492.078,1294.66 492.087,1294.66 492.096,1294.66 492.105,1294.66 492.114,1294.66 492.124,1294.66 492.133,1294.66 492.142,1294.65 492.151,1294.65 492.16,1294.65 492.169,1294.65 492.179,1294.65 492.188,1294.65 492.197,1294.65 492.206,1294.65 492.215,1294.65 492.225,1294.64 492.234,1294.64 492.243,1294.64 492.252,1294.64 492.261,1294.64 492.271,1294.64 492.28,1294.64 492.289,1294.64 492.298,1294.64 492.307,1294.64 492.316,1294.63 492.326,1294.63 492.335,1294.63 492.344,1294.63 492.353,1294.63 492.362,1294.63 492.372,1294.63 492.381,1294.63 492.39,1294.63 492.399,1294.63 492.408,1294.62 492.418,1294.62 492.427,1294.62 492.436,1294.62 492.445,1294.62 492.454,1294.62 492.464,1294.62 492.473,1294.62 492.482,1294.62 492.491,1294.62 492.5,1294.61 492.509,1294.61 492.519,1294.61 492.528,1294.61 492.537,1294.61 492.546,1294.61 492.555,1294.61 492.565,1294.61 492.574,1294.61 492.583,1294.61 492.592,1294.6 492.601,1294.6 492.611,1294.6 492.62,1294.6 492.629,1294.6 492.638,1294.6 492.647,1294.6 492.656,1294.6 492.666,1294.6 492.675,1294.6 492.684,1294.59 492.693,1294.59 492.702,1294.59 492.712,1294.59 492.721,1294.59 492.73,1294.59 492.739,1294.59 492.748,1294.59 492.758,1294.59 492.767,1294.59 492.776,1294.58 492.785,1294.58 492.794,1294.58 492.804,1294.58 492.813,1294.58 492.822,1294.58 492.831,1294.58 492.84,1294.58 492.849,1294.58 492.859,1294.58 492.868,1294.57 492.877,1294.57 492.886,1294.57 492.895,1294.57 492.905,1294.57 492.914,1294.57 492.923,1294.57 492.932,1294.57 492.941,1294.57 492.951,1294.57 492.96,1294.56 492.969,1294.56 492.978,1294.56 492.987,1294.56 492.996,1294.56 493.006,1294.56 493.015,1294.56 493.024,1294.56 493.033,1294.56 493.042,1294.56 493.052,1294.55 493.061,1294.55 493.07,1294.55 493.079,1294.55 493.088,1294.55 493.098,1294.55 493.107,1294.55 493.116,1294.55 493.125,1294.55 493.134,1294.55 493.144,1294.55 493.153,1294.54 493.162,1294.54 493.171,1294.54 493.18,1294.54 493.189,1294.54 493.199,1294.54 493.208,1294.54 493.217,1294.54 493.226,1294.54 493.235,1294.54 493.245,1294.53 493.254,1294.53 493.263,1294.53 493.272,1294.53 493.281,1294.53 493.291,1294.53 493.3,1294.53 493.309,1294.53 493.318,1294.53 493.327,1294.53 493.336,1294.52 493.346,1294.52 493.355,1294.52 493.364,1294.52 493.373,1294.52 493.382,1294.52 493.392,1294.52 493.401,1294.52 493.41,1294.52 493.419,1294.52 493.428,1294.51 493.438,1294.51 493.447,1294.51 493.456,1294.51 493.465,1294.51 493.474,1294.51 493.484,1294.51 493.493,1294.51 493.502,1294.51 493.511,1294.51 493.52,1294.5 493.529,1294.5 493.539,1294.5 493.548,1294.5 493.557,1294.5 493.566,1294.5 493.575,1294.5 493.585,1294.5 493.594,1294.5 493.603,1294.5 493.612,1294.49 493.621,1294.49 493.631,1294.49 493.64,1294.49 493.649,1294.49 493.658,1294.49 493.667,1294.49 493.676,1294.49 493.686,1294.49 493.695,1294.49 493.704,1294.48 493.713,1294.48 493.722,1294.48 493.732,1294.48 493.741,1294.48 493.75,1294.48 493.759,1294.48 493.768,1294.48 493.778,1294.48 493.787,1294.48 493.796,1294.47 493.805,1294.47 493.814,1294.47 493.824,1294.47 493.833,1294.47 493.842,1294.47 493.851,1294.47 493.86,1294.47 493.869,1294.47 493.879,1294.47 493.888,1294.46 493.897,1294.46 493.906,1294.46 493.915,1294.46 493.925,1294.46 493.934,1294.46 493.943,1294.46 493.952,1294.46 493.961,1294.46 493.971,1294.46 493.98,1294.46 493.989,1294.45 493.998,1294.45 494.007,1294.45 494.016,1294.45 494.026,1294.45 494.035,1294.45 494.044,1294.45 494.053,1294.45 494.062,1294.45 494.072,1294.45 494.081,1294.44 494.09,1294.44 494.099,1294.44 494.108,1294.44 494.118,1294.44 494.127,1294.44 494.136,1294.44 494.145,1294.44 494.154,1294.44 494.164,1294.44 494.173,1294.43 494.182,1294.43 494.191,1294.43 494.2,1294.43 494.209,1294.43 494.219,1294.43 494.228,1294.43 494.237,1294.43 494.246,1294.43 494.255,1294.43 494.265,1294.42 494.274,1294.42 494.283,1294.42 494.292,1294.42 494.301,1294.42 494.311,1294.42 494.32,1294.42 494.329,1294.42 494.338,1294.42 494.347,1294.42 494.357,1294.41 494.366,1294.41 494.375,1294.41 494.384,1294.41 494.393,1294.41 494.402,1294.41 494.412,1294.41 494.421,1294.41 494.43,1294.41 494.439,1294.41 494.448,1294.41 494.458,1294.4 494.467,1294.4 494.476,1294.4 494.485,1294.4 494.494,1294.4 494.504,1294.4 494.513,1294.4 494.522,1294.4 494.531,1294.4 494.54,1294.4 494.549,1294.39 494.559,1294.39 494.568,1294.39 494.577,1294.39 494.586,1294.39 494.595,1294.39 494.605,1294.39 494.614,1294.39 494.623,1294.39 494.632,1294.39 494.641,1294.38 494.651,1294.38 494.66,1294.38 494.669,1294.38 494.678,1294.38 494.687,1294.38 494.697,1294.38 494.706,1294.38 494.715,1294.38 494.724,1294.38 494.733,1294.37 494.742,1294.37 494.752,1294.37 494.761,1294.37 494.77,1294.37 494.779,1294.37 494.788,1294.37 494.798,1294.37 494.807,1294.37 494.816,1294.37 494.825,1294.37 494.834,1294.36 494.844,1294.36 494.853,1294.36 494.862,1294.36 494.871,1294.36 494.88,1294.36 494.889,1294.36 494.899,1294.36 494.908,1294.36 494.917,1294.36 494.926,1294.35 494.935,1294.35 494.945,1294.35 494.954,1294.35 494.963,1294.35 494.972,1294.35 494.981,1294.35 494.991,1294.35 495,1294.35 495.009,1294.35 495.018,1294.34 495.027,1294.34 495.037,1294.34 495.046,1294.34 495.055,1294.34 495.064,1294.34 495.073,1294.34 495.082,1294.34 495.092,1294.34 495.101,1294.34 495.11,1294.34 495.119,1294.33 495.128,1294.33 495.138,1294.33 495.147,1294.33 495.156,1294.33 495.165,1294.33 495.174,1294.33 495.184,1294.33 495.193,1294.33 495.202,1294.33 495.211,1294.32 495.22,1294.32 495.229,1294.32 495.239,1294.32 495.248,1294.32 495.257,1294.32 495.266,1294.32 495.275,1294.32 495.285,1294.32 495.294,1294.32 495.303,1294.31 495.312,1294.31 495.321,1294.31 495.331,1294.31 495.34,1294.31 495.349,1294.31 495.358,1294.31 495.367,1294.31 495.377,1294.31 495.386,1294.31 495.395,1294.31 495.404,1294.3 495.413,1294.3 495.422,1294.3 495.432,1294.3 495.441,1294.3 495.45,1294.3 495.459,1294.3 495.468,1294.3 495.478,1294.3 495.487,1294.3 495.496,1294.29 495.505,1294.29 495.514,1294.29 495.524,1294.29 495.533,1294.29 495.542,1294.29 495.551,1294.29 495.56,1294.29 495.569,1294.29 495.579,1294.29 495.588,1294.28 495.597,1294.28 495.606,1294.28 495.615,1294.28 495.625,1294.28 495.634,1294.28 495.643,1294.28 495.652,1294.28 495.661,1294.28 495.671,1294.28 495.68,1294.28 495.689,1294.27 495.698,1294.27 495.707,1294.27 495.717,1294.27 495.726,1294.27 495.735,1294.27 495.744,1294.27 495.753,1294.27 495.762,1294.27 495.772,1294.27 495.781,1294.26 495.79,1294.26 495.799,1294.26 495.808,1294.26 495.818,1294.26 495.827,1294.26 495.836,1294.26 495.845,1294.26 495.854,1294.26 495.864,1294.26 495.873,1294.26 495.882,1294.25 495.891,1294.25 495.9,1294.25 495.909,1294.25 495.919,1294.25 495.928,1294.25 495.937,1294.25 495.946,1294.25 495.955,1294.25 495.965,1294.25 495.974,1294.24 495.983,1294.24 495.992,1294.24 496.001,1294.24 496.011,1294.24 496.02,1294.24 496.029,1294.24 496.038,1294.24 496.047,1294.24 496.057,1294.24 496.066,1294.24 496.075,1294.23 496.084,1294.23 496.093,1294.23 496.102,1294.23 496.112,1294.23 496.121,1294.23 496.13,1294.23 496.139,1294.23 496.148,1294.23 496.158,1294.23 496.167,1294.22 496.176,1294.22 496.185,1294.22 496.194,1294.22 496.204,1294.22 496.213,1294.22 496.222,1294.22 496.231,1294.22 496.24,1294.22 496.249,1294.22 496.259,1294.21 496.268,1294.21 496.277,1294.21 496.286,1294.21 496.295,1294.21 496.305,1294.21 496.314,1294.21 496.323,1294.21 496.332,1294.21 496.341,1294.21 496.351,1294.21 496.36,1294.2 496.369,1294.2 496.378,1294.2 496.387,1294.2 496.397,1294.2 496.406,1294.2 496.415,1294.2 496.424,1294.2 496.433,1294.2 496.442,1294.2 496.452,1294.19 496.461,1294.19 496.47,1294.19 496.479,1294.19 496.488,1294.19 496.498,1294.19 496.507,1294.19 496.516,1294.19 496.525,1294.19 496.534,1294.19 496.544,1294.19 496.553,1294.18 496.562,1294.18 496.571,1294.18 496.58,1294.18 496.589,1294.18 496.599,1294.18 496.608,1294.18 496.617,1294.18 496.626,1294.18 496.635,1294.18 496.645,1294.17 496.654,1294.17 496.663,1294.17 496.672,1294.17 496.681,1294.17 496.691,1294.17 496.7,1294.17 496.709,1294.17 496.718,1294.17 496.727,1294.17 496.737,1294.17 496.746,1294.16 496.755,1294.16 496.764,1294.16 496.773,1294.16 496.782,1294.16 496.792,1294.16 496.801,1294.16 496.81,1294.16 496.819,1294.16 496.828,1294.16 496.838,1294.16 496.847,1294.15 496.856,1294.15 496.865,1294.15 496.874,1294.15 496.884,1294.15 496.893,1294.15 496.902,1294.15 496.911,1294.15 496.92,1294.15 496.93,1294.15 496.939,1294.14 496.948,1294.14 496.957,1294.14 496.966,1294.14 496.975,1294.14 496.985,1294.14 496.994,1294.14 497.003,1294.14 497.012,1294.14 497.021,1294.14 497.031,1294.14 497.04,1294.13 497.049,1294.13 497.058,1294.13 497.067,1294.13 497.077,1294.13 497.086,1294.13 497.095,1294.13 497.104,1294.13 497.113,1294.13 497.122,1294.13 497.132,1294.12 497.141,1294.12 497.15,1294.12 497.159,1294.12 497.168,1294.12 497.178,1294.12 497.187,1294.12 497.196,1294.12 497.205,1294.12 497.214,1294.12 497.224,1294.12 497.233,1294.11 497.242,1294.11 497.251,1294.11 497.26,1294.11 497.27,1294.11 497.279,1294.11 497.288,1294.11 497.297,1294.11 497.306,1294.11 497.315,1294.11 497.325,1294.11 497.334,1294.1 497.343,1294.1 497.352,1294.1 497.361,1294.1 497.371,1294.1 497.38,1294.1 497.389,1294.1 497.398,1294.1 497.407,1294.1 497.417,1294.1 497.426,1294.09 497.435,1294.09 497.444,1294.09 497.453,1294.09 497.462,1294.09 497.472,1294.09 497.481,1294.09 497.49,1294.09 497.499,1294.09 497.508,1294.09 497.518,1294.09 497.527,1294.08 497.536,1294.08 497.545,1294.08 497.554,1294.08 497.564,1294.08 497.573,1294.08 497.582,1294.08 497.591,1294.08 497.6,1294.08 497.61,1294.08 497.619,1294.07 497.628,1294.07 497.637,1294.07 497.646,1294.07 497.655,1294.07 497.665,1294.07 497.674,1294.07 497.683,1294.07 497.692,1294.07 497.701,1294.07 497.711,1294.07 497.72,1294.06 497.729,1294.06 497.738,1294.06 497.747,1294.06 497.757,1294.06 497.766,1294.06 497.775,1294.06 497.784,1294.06 497.793,1294.06 497.802,1294.06 497.812,1294.06 497.821,1294.05 497.83,1294.05 497.839,1294.05 497.848,1294.05 497.858,1294.05 497.867,1294.05 497.876,1294.05 497.885,1294.05 497.894,1294.05 497.904,1294.05 497.913,1294.05 497.922,1294.04 497.931,1294.04 497.94,1294.04 497.95,1294.04 497.959,1294.04 497.968,1294.04 497.977,1294.04 497.986,1294.04 497.995,1294.04 498.005,1294.04 498.014,1294.03 498.023,1294.03 498.032,1294.03 498.041,1294.03 498.051,1294.03 498.06,1294.03 498.069,1294.03 498.078,1294.03 498.087,1294.03 498.097,1294.03 498.106,1294.03 498.115,1294.02 498.124,1294.02 498.133,1294.02 498.142,1294.02 498.152,1294.02 498.161,1294.02 498.17,1294.02 498.179,1294.02 498.188,1294.02 498.198,1294.02 498.207,1294.02 498.216,1294.01 498.225,1294.01 498.234,1294.01 498.244,1294.01 498.253,1294.01 498.262,1294.01 498.271,1294.01 498.28,1294.01 498.29,1294.01 498.299,1294.01 498.308,1294 498.317,1294 498.326,1294 498.335,1294 498.345,1294 498.354,1294 498.363,1294 498.372,1294 498.381,1294 498.391,1294 498.4,1294 498.409,1293.99 498.418,1293.99 498.427,1293.99 498.437,1293.99 498.446,1293.99 498.455,1293.99 498.464,1293.99 498.473,1293.99 498.482,1293.99 498.492,1293.99 498.501,1293.99 498.51,1293.98 498.519,1293.98 498.528,1293.98 498.538,1293.98 498.547,1293.98 498.556,1293.98 498.565,1293.98 498.574,1293.98 498.584,1293.98 498.593,1293.98 498.602,1293.98 498.611,1293.97 498.62,1293.97 498.63,1293.97 498.639,1293.97 498.648,1293.97 498.657,1293.97 498.666,1293.97 498.675,1293.97 498.685,1293.97 498.694,1293.97 498.703,1293.97 498.712,1293.96 498.721,1293.96 498.731,1293.96 498.74,1293.96 498.749,1293.96 498.758,1293.96 498.767,1293.96 498.777,1293.96 498.786,1293.96 498.795,1293.96 498.804,1293.95 498.813,1293.95 498.822,1293.95 498.832,1293.95 498.841,1293.95 498.85,1293.95 498.859,1293.95 498.868,1293.95 498.878,1293.95 498.887,1293.95 498.896,1293.95 498.905,1293.94 498.914,1293.94 498.924,1293.94 498.933,1293.94 498.942,1293.94 498.951,1293.94 498.96,1293.94 498.97,1293.94 498.979,1293.94 498.988,1293.94 498.997,1293.94 499.006,1293.93 499.015,1293.93 499.025,1293.93 499.034,1293.93 499.043,1293.93 499.052,1293.93 499.061,1293.93 499.071,1293.93 499.08,1293.93 499.089,1293.93 499.098,1293.93 499.107,1293.92 499.117,1293.92 499.126,1293.92 499.135,1293.92 499.144,1293.92 499.153,1293.92 499.163,1293.92 499.172,1293.92 499.181,1293.92 499.19,1293.92 499.199,1293.92 499.208,1293.91 499.218,1293.91 499.227,1293.91 499.236,1293.91 499.245,1293.91 499.254,1293.91 499.264,1293.91 499.273,1293.91 499.282,1293.91 499.291,1293.91 499.3,1293.91 499.31,1293.9 499.319,1293.9 499.328,1293.9 499.337,1293.9 499.346,1293.9 499.355,1293.9 499.365,1293.9 499.374,1293.9 499.383,1293.9 499.392,1293.9 499.401,1293.9 499.411,1293.89 499.42,1293.89 499.429,1293.89 499.438,1293.89 499.447,1293.89 499.457,1293.89 499.466,1293.89 499.475,1293.89 499.484,1293.89 499.493,1293.89 499.503,1293.89 499.512,1293.88 499.521,1293.88 499.53,1293.88 499.539,1293.88 499.548,1293.88 499.558,1293.88 499.567,1293.88 499.576,1293.88 499.585,1293.88 499.594,1293.88 499.604,1293.88 499.613,1293.87 499.622,1293.87 499.631,1293.87 499.64,1293.87 499.65,1293.87 499.659,1293.87 499.668,1293.87 499.677,1293.87 499.686,1293.87 499.695,1293.87 499.705,1293.87 499.714,1293.86 499.723,1293.86 499.732,1293.86 499.741,1293.86 499.751,1293.86 499.76,1293.86 499.769,1293.86 499.778,1293.86 499.787,1293.86 499.797,1293.86 499.806,1293.85 499.815,1293.85 499.824,1293.85 499.833,1293.85 499.843,1293.85 499.852,1293.85 499.861,1293.85 499.87,1293.85 499.879,1293.85 499.888,1293.85 499.898,1293.85 499.907,1293.84 499.916,1293.84 499.925,1293.84 499.934,1293.84 499.944,1293.84 499.953,1293.84 499.962,1293.84 499.971,1293.84 499.98,1293.84 499.99,1293.84 499.999,1293.84 500.008,1293.83 500.017,1293.83 500.026,1293.83 500.035,1293.83 500.045,1293.83 500.054,1293.83 500.063,1293.83 500.072,1293.83 500.081,1293.83 500.091,1293.83 500.1,1293.83 500.109,1293.82 500.118,1293.82 500.127,1293.82 500.137,1293.82 500.146,1293.82 500.155,1293.82 500.164,1293.82 500.173,1293.82 500.183,1293.82 500.192,1293.82 500.201,1293.82 500.21,1293.82 500.219,1293.81 500.228,1293.81 500.238,1293.81 500.247,1293.81 500.256,1293.81 500.265,1293.81 500.274,1293.81 500.284,1293.81 500.293,1293.81 500.302,1293.81 500.311,1293.81 500.32,1293.8 500.33,1293.8 500.339,1293.8 500.348,1293.8 500.357,1293.8 500.366,1293.8 500.375,1293.8 500.385,1293.8 500.394,1293.8 500.403,1293.8 500.412,1293.8 500.421,1293.79 500.431,1293.79 500.44,1293.79 500.449,1293.79 500.458,1293.79 500.467,1293.79 500.477,1293.79 500.486,1293.79 500.495,1293.79 500.504,1293.79 500.513,1293.79 500.523,1293.78 500.532,1293.78 500.541,1293.78 500.55,1293.78 500.559,1293.78 500.568,1293.78 500.578,1293.78 500.587,1293.78 500.596,1293.78 500.605,1293.78 500.614,1293.78 500.624,1293.77 500.633,1293.77 500.642,1293.77 500.651,1293.77 500.66,1293.77 500.67,1293.77 500.679,1293.77 500.688,1293.77 500.697,1293.77 500.706,1293.77 500.715,1293.77 500.725,1293.76 500.734,1293.76 500.743,1293.76 500.752,1293.76 500.761,1293.76 500.771,1293.76 500.78,1293.76 500.789,1293.76 500.798,1293.76 500.807,1293.76 500.817,1293.76 500.826,1293.75 500.835,1293.75 500.844,1293.75 500.853,1293.75 500.863,1293.75 500.872,1293.75 500.881,1293.75 500.89,1293.75 500.899,1293.75 500.908,1293.75 500.918,1293.75 500.927,1293.74 500.936,1293.74 500.945,1293.74 500.954,1293.74 500.964,1293.74 500.973,1293.74 500.982,1293.74 500.991,1293.74 501,1293.74 501.01,1293.74 501.019,1293.74 501.028,1293.73 501.037,1293.73 501.046,1293.73 501.055,1293.73 501.065,1293.73 501.074,1293.73 501.083,1293.73 501.092,1293.73 501.101,1293.73 501.111,1293.73 501.12,1293.73 501.129,1293.72 501.138,1293.72 501.147,1293.72 501.157,1293.72 501.166,1293.72 501.175,1293.72 501.184,1293.72 501.193,1293.72 501.203,1293.72 501.212,1293.72 501.221,1293.72 501.23,1293.72 501.239,1293.71 501.248,1293.71 501.258,1293.71 501.267,1293.71 501.276,1293.71 501.285,1293.71 501.294,1293.71 501.304,1293.71 501.313,1293.71 501.322,1293.71 501.331,1293.71 501.34,1293.7 501.35,1293.7 501.359,1293.7 501.368,1293.7 501.377,1293.7 501.386,1293.7 501.395,1293.7 501.405,1293.7 501.414,1293.7 501.423,1293.7 501.432,1293.7 501.441,1293.69 501.451,1293.69 501.46,1293.69 501.469,1293.69 501.478,1293.69 501.487,1293.69 501.497,1293.69 501.506,1293.69 501.515,1293.69 501.524,1293.69 501.533,1293.69 501.543,1293.68 501.552,1293.68 501.561,1293.68 501.57,1293.68 501.579,1293.68 501.588,1293.68 501.598,1293.68 501.607,1293.68 501.616,1293.68 501.625,1293.68 501.634,1293.68 501.644,1293.67 501.653,1293.67 501.662,1293.67 501.671,1293.67 501.68,1293.67 501.69,1293.67 501.699,1293.67 501.708,1293.67 501.717,1293.67 501.726,1293.67 501.736,1293.67 501.745,1293.67 501.754,1293.66 501.763,1293.66 501.772,1293.66 501.781,1293.66 501.791,1293.66 501.8,1293.66 501.809,1293.66 501.818,1293.66 501.827,1293.66 501.837,1293.66 501.846,1293.66 501.855,1293.65 501.864,1293.65 501.873,1293.65 501.883,1293.65 501.892,1293.65 501.901,1293.65 501.91,1293.65 501.919,1293.65 501.928,1293.65 501.938,1293.65 501.947,1293.65 501.956,1293.64 501.965,1293.64 501.974,1293.64 501.984,1293.64 501.993,1293.64 502.002,1293.64 502.011,1293.64 502.02,1293.64 502.03,1293.64 502.039,1293.64 502.048,1293.64 502.057,1293.64 502.066,1293.63 502.076,1293.63 502.085,1293.63 502.094,1293.63 502.103,1293.63 502.112,1293.63 502.121,1293.63 502.131,1293.63 502.14,1293.63 502.149,1293.63 502.158,1293.63 502.167,1293.62 502.177,1293.62 502.186,1293.62 502.195,1293.62 502.204,1293.62 502.213,1293.62 502.223,1293.62 502.232,1293.62 502.241,1293.62 502.25,1293.62 502.259,1293.62 502.268,1293.61 502.278,1293.61 502.287,1293.61 502.296,1293.61 502.305,1293.61 502.314,1293.61 502.324,1293.61 502.333,1293.61 502.342,1293.61 502.351,1293.61 502.36,1293.61 502.37,1293.61 502.379,1293.6 502.388,1293.6 502.397,1293.6 502.406,1293.6 502.416,1293.6 502.425,1293.6 502.434,1293.6 502.443,1293.6 502.452,1293.6 502.461,1293.6 502.471,1293.6 502.48,1293.59 502.489,1293.59 502.498,1293.59 502.507,1293.59 502.517,1293.59 502.526,1293.59 502.535,1293.59 502.544,1293.59 502.553,1293.59 502.563,1293.59 502.572,1293.59 502.581,1293.58 502.59,1293.58 502.599,1293.58 502.608,1293.58 502.618,1293.58 502.627,1293.58 502.636,1293.58 502.645,1293.58 502.654,1293.58 502.664,1293.58 502.673,1293.58 502.682,1293.58 502.691,1293.57 502.7,1293.57 502.71,1293.57 502.719,1293.57 502.728,1293.57 502.737,1293.57 502.746,1293.57 502.756,1293.57 502.765,1293.57 502.774,1293.57 502.783,1293.57 502.792,1293.56 502.801,1293.56 502.811,1293.56 502.82,1293.56 502.829,1293.56 502.838,1293.56 502.847,1293.56 502.857,1293.56 502.866,1293.56 502.875,1293.56 502.884,1293.56 502.893,1293.56 502.903,1293.55 502.912,1293.55 502.921,1293.55 502.93,1293.55 502.939,1293.55 502.948,1293.55 502.958,1293.55 502.967,1293.55 502.976,1293.55 502.985,1293.55 502.994,1293.55 503.004,1293.54 503.013,1293.54 503.022,1293.54 503.031,1293.54 503.04,1293.54 503.05,1293.54 503.059,1293.54 503.068,1293.54 503.077,1293.54 503.086,1293.54 503.096,1293.54 503.105,1293.53 503.114,1293.53 503.123,1293.53 503.132,1293.53 503.141,1293.53 503.151,1293.53 503.16,1293.53 503.169,1293.53 503.178,1293.53 503.187,1293.53 503.197,1293.53 503.206,1293.53 503.215,1293.52 503.224,1293.52 503.233,1293.52 503.243,1293.52 503.252,1293.52 503.261,1293.52 503.27,1293.52 503.279,1293.52 503.288,1293.52 503.298,1293.52 503.307,1293.52 503.316,1293.51 503.325,1293.51 503.334,1293.51 503.344,1293.51 503.353,1293.51 503.362,1293.51 503.371,1293.51 503.38,1293.51 503.39,1293.51 503.399,1293.51 503.408,1293.51 503.417,1293.51 503.426,1293.5 503.436,1293.5 503.445,1293.5 503.454,1293.5 503.463,1293.5 503.472,1293.5 503.481,1293.5 503.491,1293.5 503.5,1293.5 503.509,1293.5 503.518,1293.5 503.527,1293.49 503.537,1293.49 503.546,1293.49 503.555,1293.49 503.564,1293.49 503.573,1293.49 503.583,1293.49 503.592,1293.49 503.601,1293.49 503.61,1293.49 503.619,1293.49 503.628,1293.49 503.638,1293.48 503.647,1293.48 503.656,1293.48 503.665,1293.48 503.674,1293.48 503.684,1293.48 503.693,1293.48 503.702,1293.48 503.711,1293.48 503.72,1293.48 503.73,1293.48 503.739,1293.48 503.748,1293.47 503.757,1293.47 503.766,1293.47 503.776,1293.47 503.785,1293.47 503.794,1293.47 503.803,1293.47 503.812,1293.47 503.821,1293.47 503.831,1293.47 503.84,1293.47 503.849,1293.46 503.858,1293.46 503.867,1293.46 503.877,1293.46 503.886,1293.46 503.895,1293.46 503.904,1293.46 503.913,1293.46 503.923,1293.46 503.932,1293.46 503.941,1293.46 503.95,1293.46 503.959,1293.45 503.968,1293.45 503.978,1293.45 503.987,1293.45 503.996,1293.45 504.005,1293.45 504.014,1293.45 504.024,1293.45 504.033,1293.45 504.042,1293.45 504.051,1293.45 504.06,1293.44 504.07,1293.44 504.079,1293.44 504.088,1293.44 504.097,1293.44 504.106,1293.44 504.116,1293.44 504.125,1293.44 504.134,1293.44 504.143,1293.44 504.152,1293.44 504.161,1293.44 504.171,1293.43 504.18,1293.43 504.189,1293.43 504.198,1293.43 504.207,1293.43 504.217,1293.43 504.226,1293.43 504.235,1293.43 504.244,1293.43 504.253,1293.43 504.263,1293.43 504.272,1293.43 504.281,1293.42 504.29,1293.42 504.299,1293.42 504.309,1293.42 504.318,1293.42 504.327,1293.42 504.336,1293.42 504.345,1293.42 504.354,1293.42 504.364,1293.42 504.373,1293.42 504.382,1293.41 504.391,1293.41 504.4,1293.41 504.41,1293.41 504.419,1293.41 504.428,1293.41 504.437,1293.41 504.446,1293.41 504.456,1293.41 504.465,1293.41 504.474,1293.41 504.483,1293.41 504.492,1293.4 504.501,1293.4 504.511,1293.4 504.52,1293.4 504.529,1293.4 504.538,1293.4 504.547,1293.4 504.557,1293.4 504.566,1293.4 504.575,1293.4 504.584,1293.4 504.593,1293.4 504.603,1293.39 504.612,1293.39 504.621,1293.39 504.63,1293.39 504.639,1293.39 504.649,1293.39 504.658,1293.39 504.667,1293.39 504.676,1293.39 504.685,1293.39 504.694,1293.39 504.704,1293.38 504.713,1293.38 504.722,1293.38 504.731,1293.38 504.74,1293.38 504.75,1293.38 504.759,1293.38 504.768,1293.38 504.777,1293.38 504.786,1293.38 504.796,1293.38 504.805,1293.38 504.814,1293.37 504.823,1293.37 504.832,1293.37 504.841,1293.37 504.851,1293.37 504.86,1293.37 504.869,1293.37 504.878,1293.37 504.887,1293.37 504.897,1293.37 504.906,1293.37 504.915,1293.37 504.924,1293.36 504.933,1293.36 504.943,1293.36 504.952,1293.36 504.961,1293.36 504.97,1293.36 504.979,1293.36 504.989,1293.36 504.998,1293.36 505.007,1293.36 505.016,1293.36 505.025,1293.35 505.034,1293.35 505.044,1293.35 505.053,1293.35 505.062,1293.35 505.071,1293.35 505.08,1293.35 505.09,1293.35 505.099,1293.35 505.108,1293.35 505.117,1293.35 505.126,1293.35 505.136,1293.34 505.145,1293.34 505.154,1293.34 505.163,1293.34 505.172,1293.34 505.181,1293.34 505.191,1293.34 505.2,1293.34 505.209,1293.34 505.218,1293.34 505.227,1293.34 505.237,1293.34 505.246,1293.33 505.255,1293.33 505.264,1293.33 505.273,1293.33 505.283,1293.33 505.292,1293.33 505.301,1293.33 505.31,1293.33 505.319,1293.33 505.329,1293.33 505.338,1293.33 505.347,1293.33 505.356,1293.32 505.365,1293.32 505.374,1293.32 505.384,1293.32 505.393,1293.32 505.402,1293.32 505.411,1293.32 505.42,1293.32 505.43,1293.32 505.439,1293.32 505.448,1293.32 505.457,1293.32 505.466,1293.31 505.476,1293.31 505.485,1293.31 505.494,1293.31 505.503,1293.31 505.512,1293.31 505.521,1293.31 505.531,1293.31 505.54,1293.31 505.549,1293.31 505.558,1293.31 505.567,1293.3 505.577,1293.3 505.586,1293.3 505.595,1293.3 505.604,1293.3 505.613,1293.3 505.623,1293.3 505.632,1293.3 505.641,1293.3 505.65,1293.3 505.659,1293.3 505.669,1293.3 505.678,1293.29 505.687,1293.29 505.696,1293.29 505.705,1293.29 505.714,1293.29 505.724,1293.29 505.733,1293.29 505.742,1293.29 505.751,1293.29 505.76,1293.29 505.77,1293.29 505.779,1293.29 505.788,1293.28 505.797,1293.28 505.806,1293.28 505.816,1293.28 505.825,1293.28 505.834,1293.28 505.843,1293.28 505.852,1293.28 505.861,1293.28 505.871,1293.28 505.88,1293.28 505.889,1293.28 505.898,1293.27 505.907,1293.27 505.917,1293.27 505.926,1293.27 505.935,1293.27 505.944,1293.27 505.953,1293.27 505.963,1293.27 505.972,1293.27 505.981,1293.27 505.99,1293.27 505.999,1293.27 506.009,1293.26 506.018,1293.26 506.027,1293.26 506.036,1293.26 506.045,1293.26 506.054,1293.26 506.064,1293.26 506.073,1293.26 506.082,1293.26 506.091,1293.26 506.1,1293.26 506.11,1293.26 506.119,1293.25 506.128,1293.25 506.137,1293.25 506.146,1293.25 506.156,1293.25 506.165,1293.25 506.174,1293.25 506.183,1293.25 506.192,1293.25 506.201,1293.25 506.211,1293.25 506.22,1293.25 506.229,1293.24 506.238,1293.24 506.247,1293.24 506.257,1293.24 506.266,1293.24 506.275,1293.24 506.284,1293.24 506.293,1293.24 506.303,1293.24 506.312,1293.24 506.321,1293.24 506.33,1293.24 506.339,1293.23 506.349,1293.23 506.358,1293.23 506.367,1293.23 506.376,1293.23 506.385,1293.23 506.394,1293.23 506.404,1293.23 506.413,1293.23 506.422,1293.23 506.431,1293.23 506.44,1293.23 506.45,1293.22 506.459,1293.22 506.468,1293.22 506.477,1293.22 506.486,1293.22 506.496,1293.22 506.505,1293.22 506.514,1293.22 506.523,1293.22 506.532,1293.22 506.542,1293.22 506.551,1293.22 506.56,1293.21 506.569,1293.21 506.578,1293.21 506.587,1293.21 506.597,1293.21 506.606,1293.21 506.615,1293.21 506.624,1293.21 506.633,1293.21 506.643,1293.21 506.652,1293.21 506.661,1293.21 506.67,1293.2 506.679,1293.2 506.689,1293.2 506.698,1293.2 506.707,1293.2 506.716,1293.2 506.725,1293.2 506.734,1293.2 506.744,1293.2 506.753,1293.2 506.762,1293.2 506.771,1293.2 506.78,1293.19 506.79,1293.19 506.799,1293.19 506.808,1293.19 506.817,1293.19 506.826,1293.19 506.836,1293.19 506.845,1293.19 506.854,1293.19 506.863,1293.19 506.872,1293.19 506.882,1293.19 506.891,1293.18 506.9,1293.18 506.909,1293.18 506.918,1293.18 506.927,1293.18 506.937,1293.18 506.946,1293.18 506.955,1293.18 506.964,1293.18 506.973,1293.18 506.983,1293.18 506.992,1293.18 507.001,1293.17 507.01,1293.17 507.019,1293.17 507.029,1293.17 507.038,1293.17 507.047,1293.17 507.056,1293.17 507.065,1293.17 507.074,1293.17 507.084,1293.17 507.093,1293.17 507.102,1293.17 507.111,1293.16 507.12,1293.16 507.13,1293.16 507.139,1293.16 507.148,1293.16 507.157,1293.16 507.166,1293.16 507.176,1293.16 507.185,1293.16 507.194,1293.16 507.203,1293.16 507.212,1293.16 507.222,1293.15 507.231,1293.15 507.24,1293.15 507.249,1293.15 507.258,1293.15 507.267,1293.15 507.277,1293.15 507.286,1293.15 507.295,1293.15 507.304,1293.15 507.313,1293.15 507.323,1293.15 507.332,1293.14 507.341,1293.14 507.35,1293.14 507.359,1293.14 507.369,1293.14 507.378,1293.14 507.387,1293.14 507.396,1293.14 507.405,1293.14 507.414,1293.14 507.424,1293.14 507.433,1293.14 507.442,1293.13 507.451,1293.13 507.46,1293.13 507.47,1293.13 507.479,1293.13 507.488,1293.13 507.497,1293.13 507.506,1293.13 507.516,1293.13 507.525,1293.13 507.534,1293.13 507.543,1293.13 507.552,1293.13 507.562,1293.12 507.571,1293.12 507.58,1293.12 507.589,1293.12 507.598,1293.12 507.607,1293.12 507.617,1293.12 507.626,1293.12 507.635,1293.12 507.644,1293.12 507.653,1293.12 507.663,1293.12 507.672,1293.11 507.681,1293.11 507.69,1293.11 507.699,1293.11 507.709,1293.11 507.718,1293.11 507.727,1293.11 507.736,1293.11 507.745,1293.11 507.754,1293.11 507.764,1293.11 507.773,1293.11 507.782,1293.1 507.791,1293.1 507.8,1293.1 507.81,1293.1 507.819,1293.1 507.828,1293.1 507.837,1293.1 507.846,1293.1 507.856,1293.1 507.865,1293.1 507.874,1293.1 507.883,1293.1 507.892,1293.09 507.902,1293.09 507.911,1293.09 507.92,1293.09 507.929,1293.09 507.938,1293.09 507.947,1293.09 507.957,1293.09 507.966,1293.09 507.975,1293.09 507.984,1293.09 507.993,1293.09 508.003,1293.08 508.012,1293.08 508.021,1293.08 508.03,1293.08 508.039,1293.08 508.049,1293.08 508.058,1293.08 508.067,1293.08 508.076,1293.08 508.085,1293.08 508.094,1293.08 508.104,1293.08 508.113,1293.08 508.122,1293.07 508.131,1293.07 508.14,1293.07 508.15,1293.07 508.159,1293.07 508.168,1293.07 508.177,1293.07 508.186,1293.07 508.196,1293.07 508.205,1293.07 508.214,1293.07 508.223,1293.07 508.232,1293.06 508.242,1293.06 508.251,1293.06 508.26,1293.06 508.269,1293.06 508.278,1293.06 508.287,1293.06 508.297,1293.06 508.306,1293.06 508.315,1293.06 508.324,1293.06 508.333,1293.06 508.343,1293.05 508.352,1293.05 508.361,1293.05 508.37,1293.05 508.379,1293.05 508.389,1293.05 508.398,1293.05 508.407,1293.05 508.416,1293.05 508.425,1293.05 508.434,1293.05 508.444,1293.05 508.453,1293.05 508.462,1293.04 508.471,1293.04 508.48,1293.04 508.49,1293.04 508.499,1293.04 508.508,1293.04 508.517,1293.04 508.526,1293.04 508.536,1293.04 508.545,1293.04 508.554,1293.04 508.563,1293.04 508.572,1293.03 508.582,1293.03 508.591,1293.03 508.6,1293.03 508.609,1293.03 508.618,1293.03 508.627,1293.03 508.637,1293.03 508.646,1293.03 508.655,1293.03 508.664,1293.03 508.673,1293.03 508.683,1293.02 508.692,1293.02 508.701,1293.02 508.71,1293.02 508.719,1293.02 508.729,1293.02 508.738,1293.02 508.747,1293.02 508.756,1293.02 508.765,1293.02 508.774,1293.02 508.784,1293.02 508.793,1293.02 508.802,1293.01 508.811,1293.01 508.82,1293.01 508.83,1293.01 508.839,1293.01 508.848,1293.01 508.857,1293.01 508.866,1293.01 508.876,1293.01 508.885,1293.01 508.894,1293.01 508.903,1293.01 508.912,1293 508.922,1293 508.931,1293 508.94,1293 508.949,1293 508.958,1293 508.967,1293 508.977,1293 508.986,1293 508.995,1293 509.004,1293 509.013,1293 509.023,1292.99 509.032,1292.99 509.041,1292.99 509.05,1292.99 509.059,1292.99 509.069,1292.99 509.078,1292.99 509.087,1292.99 509.096,1292.99 509.105,1292.99 509.115,1292.99 509.124,1292.99 509.133,1292.99 509.142,1292.98 509.151,1292.98 509.16,1292.98 509.17,1292.98 509.179,1292.98 509.188,1292.98 509.197,1292.98 509.206,1292.98 509.216,1292.98 509.225,1292.98 509.234,1292.98 509.243,1292.98 509.252,1292.97 509.262,1292.97 509.271,1292.97 509.28,1292.97 509.289,1292.97 509.298,1292.97 509.307,1292.97 509.317,1292.97 509.326,1292.97 509.335,1292.97 509.344,1292.97 509.353,1292.97 509.363,1292.97 509.372,1292.96 509.381,1292.96 509.39,1292.96 509.399,1292.96 509.409,1292.96 509.418,1292.96 509.427,1292.96 509.436,1292.96 509.445,1292.96 509.455,1292.96 509.464,1292.96 509.473,1292.96 509.482,1292.95 509.491,1292.95 509.5,1292.95 509.51,1292.95 509.519,1292.95 509.528,1292.95 509.537,1292.95 509.546,1292.95 509.556,1292.95 509.565,1292.95 509.574,1292.95 509.583,1292.95 509.592,1292.95 509.602,1292.94 509.611,1292.94 509.62,1292.94 509.629,1292.94 509.638,1292.94 509.647,1292.94 509.657,1292.94 509.666,1292.94 509.675,1292.94 509.684,1292.94 509.693,1292.94 509.703,1292.94 509.712,1292.93 509.721,1292.93 509.73,1292.93 509.739,1292.93 509.749,1292.93 509.758,1292.93 509.767,1292.93 509.776,1292.93 509.785,1292.93 509.795,1292.93 509.804,1292.93 509.813,1292.93 509.822,1292.93 509.831,1292.92 509.84,1292.92 509.85,1292.92 509.859,1292.92 509.868,1292.92 509.877,1292.92 509.886,1292.92 509.896,1292.92 509.905,1292.92 509.914,1292.92 509.923,1292.92 509.932,1292.92 509.942,1292.91 509.951,1292.91 509.96,1292.91 509.969,1292.91 509.978,1292.91 509.987,1292.91 509.997,1292.91 510.006,1292.91 510.015,1292.91 510.024,1292.91 510.033,1292.91 510.043,1292.91 510.052,1292.91 510.061,1292.9 510.07,1292.9 510.079,1292.9 510.089,1292.9 510.098,1292.9 510.107,1292.9 510.116,1292.9 510.125,1292.9 510.135,1292.9 510.144,1292.9 510.153,1292.9 510.162,1292.9 510.171,1292.89 510.18,1292.89 510.19,1292.89 510.199,1292.89 510.208,1292.89 510.217,1292.89 510.226,1292.89 510.236,1292.89 510.245,1292.89 510.254,1292.89 510.263,1292.89 510.272,1292.89 510.282,1292.89 510.291,1292.88 510.3,1292.88 510.309,1292.88 510.318,1292.88 510.327,1292.88 510.337,1292.88 510.346,1292.88 510.355,1292.88 510.364,1292.88 510.373,1292.88 510.383,1292.88 510.392,1292.88 510.401,1292.88 510.41,1292.87 510.419,1292.87 510.429,1292.87 510.438,1292.87 510.447,1292.87 510.456,1292.87 510.465,1292.87 510.475,1292.87 510.484,1292.87 510.493,1292.87 510.502,1292.87 510.511,1292.87 510.52,1292.86 510.53,1292.86 510.539,1292.86 510.548,1292.86 510.557,1292.86 510.566,1292.86 510.576,1292.86 510.585,1292.86 510.594,1292.86 510.603,1292.86 510.612,1292.86 510.622,1292.86 510.631,1292.86 510.64,1292.85 510.649,1292.85 510.658,1292.85 510.667,1292.85 510.677,1292.85 510.686,1292.85 510.695,1292.85 510.704,1292.85 510.713,1292.85 510.723,1292.85 510.732,1292.85 510.741,1292.85 510.75,1292.85 510.759,1292.84 510.769,1292.84 510.778,1292.84 510.787,1292.84 510.796,1292.84 510.805,1292.84 510.815,1292.84 510.824,1292.84 510.833,1292.84 510.842,1292.84 510.851,1292.84 510.86,1292.84 510.87,1292.83 510.879,1292.83 510.888,1292.83 510.897,1292.83 510.906,1292.83 510.916,1292.83 510.925,1292.83 510.934,1292.83 510.943,1292.83 510.952,1292.83 510.962,1292.83 510.971,1292.83 510.98,1292.83 510.989,1292.82 510.998,1292.82 511.007,1292.82 511.017,1292.82 511.026,1292.82 511.035,1292.82 511.044,1292.82 511.053,1292.82 511.063,1292.82 511.072,1292.82 511.081,1292.82 511.09,1292.82 511.099,1292.82 511.109,1292.81 511.118,1292.81 511.127,1292.81 511.136,1292.81 511.145,1292.81 511.155,1292.81 511.164,1292.81 511.173,1292.81 511.182,1292.81 511.191,1292.81 511.2,1292.81 511.21,1292.81 511.219,1292.81 511.228,1292.8 511.237,1292.8 511.246,1292.8 511.256,1292.8 511.265,1292.8 511.274,1292.8 511.283,1292.8 511.292,1292.8 511.302,1292.8 511.311,1292.8 511.32,1292.8 511.329,1292.8 511.338,1292.8 511.347,1292.79 511.357,1292.79 511.366,1292.79 511.375,1292.79 511.384,1292.79 511.393,1292.79 511.403,1292.79 511.412,1292.79 511.421,1292.79 511.43,1292.79 511.439,1292.79 511.449,1292.79 511.458,1292.78 511.467,1292.78 511.476,1292.78 511.485,1292.78 511.495,1292.78 511.504,1292.78 511.513,1292.78 511.522,1292.78 511.531,1292.78 511.54,1292.78 511.55,1292.78 511.559,1292.78 511.568,1292.78 511.577,1292.77 511.586,1292.77 511.596,1292.77 511.605,1292.77 511.614,1292.77 511.623,1292.77 511.632,1292.77 511.642,1292.77 511.651,1292.77 511.66,1292.77 511.669,1292.77 511.678,1292.77 511.688,1292.77 511.697,1292.76 511.706,1292.76 511.715,1292.76 511.724,1292.76 511.733,1292.76 511.743,1292.76 511.752,1292.76 511.761,1292.76 511.77,1292.76 511.779,1292.76 511.789,1292.76 511.798,1292.76 511.807,1292.76 511.816,1292.75 511.825,1292.75 511.835,1292.75 511.844,1292.75 511.853,1292.75 511.862,1292.75 511.871,1292.75 511.88,1292.75 511.89,1292.75 511.899,1292.75 511.908,1292.75 511.917,1292.75 511.926,1292.75 511.936,1292.74 511.945,1292.74 511.954,1292.74 511.963,1292.74 511.972,1292.74 511.982,1292.74 511.991,1292.74 512,1292.74 512.009,1292.74 512.018,1292.74 512.028,1292.74 512.037,1292.74 512.046,1292.74 512.055,1292.73 512.064,1292.73 512.073,1292.73 512.083,1292.73 512.092,1292.73 512.101,1292.73 512.11,1292.73 512.119,1292.73 512.129,1292.73 512.138,1292.73 512.147,1292.73 512.156,1292.73 512.165,1292.73 512.175,1292.72 512.184,1292.72 512.193,1292.72 512.202,1292.72 512.211,1292.72 512.22,1292.72 512.23,1292.72 512.239,1292.72 512.248,1292.72 512.257,1292.72 512.266,1292.72 512.276,1292.72 512.285,1292.72 512.294,1292.71 512.303,1292.71 512.312,1292.71 512.322,1292.71 512.331,1292.71 512.34,1292.71 512.349,1292.71 512.358,1292.71 512.368,1292.71 512.377,1292.71 512.386,1292.71 512.395,1292.71 512.404,1292.71 512.413,1292.7 512.423,1292.7 512.432,1292.7 512.441,1292.7 512.45,1292.7 512.459,1292.7 512.469,1292.7 512.478,1292.7 512.487,1292.7 512.496,1292.7 512.505,1292.7 512.515,1292.7 512.524,1292.7 512.533,1292.69 512.542,1292.69 512.551,1292.69 512.56,1292.69 512.57,1292.69 512.579,1292.69 512.588,1292.69 512.597,1292.69 512.606,1292.69 512.616,1292.69 512.625,1292.69 512.634,1292.69 512.643,1292.69 512.652,1292.68 512.662,1292.68 512.671,1292.68 512.68,1292.68 512.689,1292.68 512.698,1292.68 512.708,1292.68 512.717,1292.68 512.726,1292.68 512.735,1292.68 512.744,1292.68 512.753,1292.68 512.763,1292.68 512.772,1292.67 512.781,1292.67 512.79,1292.67 512.799,1292.67 512.809,1292.67 512.818,1292.67 512.827,1292.67 512.836,1292.67 512.845,1292.67 512.855,1292.67 512.864,1292.67 512.873,1292.67 512.882,1292.67 512.891,1292.66 512.9,1292.66 512.91,1292.66 512.919,1292.66 512.928,1292.66 512.937,1292.66 512.946,1292.66 512.956,1292.66 512.965,1292.66 512.974,1292.66 512.983,1292.66 512.992,1292.66 513.002,1292.66 513.011,1292.65 513.02,1292.65 513.029,1292.65 513.038,1292.65 513.048,1292.65 513.057,1292.65 513.066,1292.65 513.075,1292.65 513.084,1292.65 513.093,1292.65 513.103,1292.65 513.112,1292.65 513.121,1292.65 513.13,1292.64 513.139,1292.64 513.149,1292.64 513.158,1292.64 513.167,1292.64 513.176,1292.64 513.185,1292.64 513.195,1292.64 513.204,1292.64 513.213,1292.64 513.222,1292.64 513.231,1292.64 513.24,1292.64 513.25,1292.63 513.259,1292.63 513.268,1292.63 513.277,1292.63 513.286,1292.63 513.296,1292.63 513.305,1292.63 513.314,1292.63 513.323,1292.63 513.332,1292.63 513.342,1292.63 513.351,1292.63 513.36,1292.63 513.369,1292.62 513.378,1292.62 513.388,1292.62 513.397,1292.62 513.406,1292.62 513.415,1292.62 513.424,1292.62 513.433,1292.62 513.443,1292.62 513.452,1292.62 513.461,1292.62 513.47,1292.62 513.479,1292.62 513.489,1292.61 513.498,1292.61 513.507,1292.61 513.516,1292.61 513.525,1292.61 513.535,1292.61 513.544,1292.61 513.553,1292.61 513.562,1292.61 513.571,1292.61 513.58,1292.61 513.59,1292.61 513.599,1292.61 513.608,1292.61 513.617,1292.6 513.626,1292.6 513.636,1292.6 513.645,1292.6 513.654,1292.6 513.663,1292.6 513.672,1292.6 513.682,1292.6 513.691,1292.6 513.7,1292.6 513.709,1292.6 513.718,1292.6 513.728,1292.6 513.737,1292.59 513.746,1292.59 513.755,1292.59 513.764,1292.59 513.773,1292.59 513.783,1292.59 513.792,1292.59 513.801,1292.59 513.81,1292.59 513.819,1292.59 513.829,1292.59 513.838,1292.59 513.847,1292.59 513.856,1292.58 513.865,1292.58 513.875,1292.58 513.884,1292.58 513.893,1292.58 513.902,1292.58 513.911,1292.58 513.921,1292.58 513.93,1292.58 513.939,1292.58 513.948,1292.58 513.957,1292.58 513.966,1292.58 513.976,1292.57 513.985,1292.57 513.994,1292.57 514.003,1292.57 514.012,1292.57 514.022,1292.57 514.031,1292.57 514.04,1292.57 514.049,1292.57 514.058,1292.57 514.068,1292.57 514.077,1292.57 514.086,1292.57 514.095,1292.57 514.104,1292.56 514.113,1292.56 514.123,1292.56 514.132,1292.56 514.141,1292.56 514.15,1292.56 514.159,1292.56 514.169,1292.56 514.178,1292.56 514.187,1292.56 514.196,1292.56 514.205,1292.56 514.215,1292.56 514.224,1292.55 514.233,1292.55 514.242,1292.55 514.251,1292.55 514.261,1292.55 514.27,1292.55 514.279,1292.55 514.288,1292.55 514.297,1292.55 514.306,1292.55 514.316,1292.55 514.325,1292.55 514.334,1292.55 514.343,1292.54 514.352,1292.54 514.362,1292.54 514.371,1292.54 514.38,1292.54 514.389,1292.54 514.398,1292.54 514.408,1292.54 514.417,1292.54 514.426,1292.54 514.435,1292.54 514.444,1292.54 514.453,1292.54 514.463,1292.54 514.472,1292.53 514.481,1292.53 514.49,1292.53 514.499,1292.53 514.509,1292.53 514.518,1292.53 514.527,1292.53 514.536,1292.53 514.545,1292.53 514.555,1292.53 514.564,1292.53 514.573,1292.53 514.582,1292.53 514.591,1292.52 514.601,1292.52 514.61,1292.52 514.619,1292.52 514.628,1292.52 514.637,1292.52 514.646,1292.52 514.656,1292.52 514.665,1292.52 514.674,1292.52 514.683,1292.52 514.692,1292.52 514.702,1292.52 514.711,1292.52 514.72,1292.51 514.729,1292.51 514.738,1292.51 514.748,1292.51 514.757,1292.51 514.766,1292.51 514.775,1292.51 514.784,1292.51 514.793,1292.51 514.803,1292.51 514.812,1292.51 514.821,1292.51 514.83,1292.51 514.839,1292.5 514.849,1292.5 514.858,1292.5 514.867,1292.5 514.876,1292.5 514.885,1292.5 514.895,1292.5 514.904,1292.5 514.913,1292.5 514.922,1292.5 514.931,1292.5 514.941,1292.5 514.95,1292.5 514.959,1292.49 514.968,1292.49 514.977,1292.49 514.986,1292.49 514.996,1292.49 515.005,1292.49 515.014,1292.49 515.023,1292.49 515.032,1292.49 515.042,1292.49 515.051,1292.49 515.06,1292.49 515.069,1292.49 515.078,1292.49 515.088,1292.48 515.097,1292.48 515.106,1292.48 515.115,1292.48 515.124,1292.48 515.133,1292.48 515.143,1292.48 515.152,1292.48 515.161,1292.48 515.17,1292.48 515.179,1292.48 515.189,1292.48 515.198,1292.48 515.207,1292.47 515.216,1292.47 515.225,1292.47 515.235,1292.47 515.244,1292.47 515.253,1292.47 515.262,1292.47 515.271,1292.47 515.281,1292.47 515.29,1292.47 515.299,1292.47 515.308,1292.47 515.317,1292.47 515.326,1292.47 515.336,1292.46 515.345,1292.46 515.354,1292.46 515.363,1292.46 515.372,1292.46 515.382,1292.46 515.391,1292.46 515.4,1292.46 515.409,1292.46 515.418,1292.46 515.428,1292.46 515.437,1292.46 515.446,1292.46 515.455,1292.45 515.464,1292.45 515.473,1292.45 515.483,1292.45 515.492,1292.45 515.501,1292.45 515.51,1292.45 515.519,1292.45 515.529,1292.45 515.538,1292.45 515.547,1292.45 515.556,1292.45 515.565,1292.45 515.575,1292.45 515.584,1292.44 515.593,1292.44 515.602,1292.44 515.611,1292.44 515.621,1292.44 515.63,1292.44 515.639,1292.44 515.648,1292.44 515.657,1292.44 515.666,1292.44 515.676,1292.44 515.685,1292.44 515.694,1292.44 515.703,1292.44 515.712,1292.43 515.722,1292.43 515.731,1292.43 515.74,1292.43 515.749,1292.43 515.758,1292.43 515.768,1292.43 515.777,1292.43 515.786,1292.43 515.795,1292.43 515.804,1292.43 515.813,1292.43 515.823,1292.43 515.832,1292.42 515.841,1292.42 515.85,1292.42 515.859,1292.42 515.869,1292.42 515.878,1292.42 515.887,1292.42 515.896,1292.42 515.905,1292.42 515.915,1292.42 515.924,1292.42 515.933,1292.42 515.942,1292.42 515.951,1292.42 515.961,1292.41 515.97,1292.41 515.979,1292.41 515.988,1292.41 515.997,1292.41 516.006,1292.41 516.016,1292.41 516.025,1292.41 516.034,1292.41 516.043,1292.41 516.052,1292.41 516.062,1292.41 516.071,1292.41 516.08,1292.4 516.089,1292.4 516.098,1292.4 516.108,1292.4 516.117,1292.4 516.126,1292.4 516.135,1292.4 516.144,1292.4 516.153,1292.4 516.163,1292.4 516.172,1292.4 516.181,1292.4 516.19,1292.4 516.199,1292.4 516.209,1292.39 516.218,1292.39 516.227,1292.39 516.236,1292.39 516.245,1292.39 516.255,1292.39 516.264,1292.39 516.273,1292.39 516.282,1292.39 516.291,1292.39 516.301,1292.39 516.31,1292.39 516.319,1292.39 516.328,1292.39 516.337,1292.38 516.346,1292.38 516.356,1292.38 516.365,1292.38 516.374,1292.38 516.383,1292.38 516.392,1292.38 516.402,1292.38 516.411,1292.38 516.42,1292.38 516.429,1292.38 516.438,1292.38 516.448,1292.38 516.457,1292.38 516.466,1292.37 516.475,1292.37 516.484,1292.37 516.494,1292.37 516.503,1292.37 516.512,1292.37 516.521,1292.37 516.53,1292.37 516.539,1292.37 516.549,1292.37 516.558,1292.37 516.567,1292.37 516.576,1292.37 516.585,1292.36 516.595,1292.36 516.604,1292.36 516.613,1292.36 516.622,1292.36 516.631,1292.36 516.641,1292.36 516.65,1292.36 516.659,1292.36 516.668,1292.36 516.677,1292.36 516.686,1292.36 516.696,1292.36 516.705,1292.36 516.714,1292.35 516.723,1292.35 516.732,1292.35 516.742,1292.35 516.751,1292.35 516.76,1292.35 516.769,1292.35 516.778,1292.35 516.788,1292.35 516.797,1292.35 516.806,1292.35 516.815,1292.35 516.824,1292.35 516.834,1292.35 516.843,1292.34 516.852,1292.34 516.861,1292.34 516.87,1292.34 516.879,1292.34 516.889,1292.34 516.898,1292.34 516.907,1292.34 516.916,1292.34 516.925,1292.34 516.935,1292.34 516.944,1292.34 516.953,1292.34 516.962,1292.34 516.971,1292.33 516.981,1292.33 516.99,1292.33 516.999,1292.33 517.008,1292.33 517.017,1292.33 517.026,1292.33 517.036,1292.33 517.045,1292.33 517.054,1292.33 517.063,1292.33 517.072,1292.33 517.082,1292.33 517.091,1292.33 517.1,1292.32 517.109,1292.32 517.118,1292.32 517.128,1292.32 517.137,1292.32 517.146,1292.32 517.155,1292.32 517.164,1292.32 517.174,1292.32 517.183,1292.32 517.192,1292.32 517.201,1292.32 517.21,1292.32 517.219,1292.32 517.229,1292.31 517.238,1292.31 517.247,1292.31 517.256,1292.31 517.265,1292.31 517.275,1292.31 517.284,1292.31 517.293,1292.31 517.302,1292.31 517.311,1292.31 517.321,1292.31 517.33,1292.31 517.339,1292.31 517.348,1292.3 517.357,1292.3 517.366,1292.3 517.376,1292.3 517.385,1292.3 517.394,1292.3 517.403,1292.3 517.412,1292.3 517.422,1292.3 517.431,1292.3 517.44,1292.3 517.449,1292.3 517.458,1292.3 517.468,1292.3 517.477,1292.29 517.486,1292.29 517.495,1292.29 517.504,1292.29 517.514,1292.29 517.523,1292.29 517.532,1292.29 517.541,1292.29 517.55,1292.29 517.559,1292.29 517.569,1292.29 517.578,1292.29 517.587,1292.29 517.596,1292.29 517.605,1292.28 517.615,1292.28 517.624,1292.28 517.633,1292.28 517.642,1292.28 517.651,1292.28 517.661,1292.28 517.67,1292.28 517.679,1292.28 517.688,1292.28 517.697,1292.28 517.706,1292.28 517.716,1292.28 517.725,1292.28 517.734,1292.27 517.743,1292.27 517.752,1292.27 517.762,1292.27 517.771,1292.27 517.78,1292.27 517.789,1292.27 517.798,1292.27 517.808,1292.27 517.817,1292.27 517.826,1292.27 517.835,1292.27 517.844,1292.27 517.854,1292.27 517.863,1292.26 517.872,1292.26 517.881,1292.26 517.89,1292.26 517.899,1292.26 517.909,1292.26 517.918,1292.26 517.927,1292.26 517.936,1292.26 517.945,1292.26 517.955,1292.26 517.964,1292.26 517.973,1292.26 517.982,1292.26 517.991,1292.25 518.001,1292.25 518.01,1292.25 518.019,1292.25 518.028,1292.25 518.037,1292.25 518.046,1292.25 518.056,1292.25 518.065,1292.25 518.074,1292.25 518.083,1292.25 518.092,1292.25 518.102,1292.25 518.111,1292.25 518.12,1292.24 518.129,1292.24 518.138,1292.24 518.148,1292.24 518.157,1292.24 518.166,1292.24 518.175,1292.24 518.184,1292.24 518.194,1292.24 518.203,1292.24 518.212,1292.24 518.221,1292.24 518.23,1292.24 518.239,1292.24 518.249,1292.23 518.258,1292.23 518.267,1292.23 518.276,1292.23 518.285,1292.23 518.295,1292.23 518.304,1292.23 518.313,1292.23 518.322,1292.23 518.331,1292.23 518.341,1292.23 518.35,1292.23 518.359,1292.23 518.368,1292.23 518.377,1292.23 518.386,1292.22 518.396,1292.22 518.405,1292.22 518.414,1292.22 518.423,1292.22 518.432,1292.22 518.442,1292.22 518.451,1292.22 518.46,1292.22 518.469,1292.22 518.478,1292.22 518.488,1292.22 518.497,1292.22 518.506,1292.22 518.515,1292.21 518.524,1292.21 518.534,1292.21 518.543,1292.21 518.552,1292.21 518.561,1292.21 518.57,1292.21 518.579,1292.21 518.589,1292.21 518.598,1292.21 518.607,1292.21 518.616,1292.21 518.625,1292.21 518.635,1292.21 518.644,1292.2 518.653,1292.2 518.662,1292.2 518.671,1292.2 518.681,1292.2 518.69,1292.2 518.699,1292.2 518.708,1292.2 518.717,1292.2 518.726,1292.2 518.736,1292.2 518.745,1292.2 518.754,1292.2 518.763,1292.2 518.772,1292.19 518.782,1292.19 518.791,1292.19 518.8,1292.19 518.809,1292.19 518.818,1292.19 518.828,1292.19 518.837,1292.19 518.846,1292.19 518.855,1292.19 518.864,1292.19 518.874,1292.19 518.883,1292.19 518.892,1292.19 518.901,1292.18 518.91,1292.18 518.919,1292.18 518.929,1292.18 518.938,1292.18 518.947,1292.18 518.956,1292.18 518.965,1292.18 518.975,1292.18 518.984,1292.18 518.993,1292.18 519.002,1292.18 519.011,1292.18 519.021,1292.18 519.03,1292.18 519.039,1292.17 519.048,1292.17 519.057,1292.17 519.067,1292.17 519.076,1292.17 519.085,1292.17 519.094,1292.17 519.103,1292.17 519.112,1292.17 519.122,1292.17 519.131,1292.17 519.14,1292.17 519.149,1292.17 519.158,1292.17 519.168,1292.16 519.177,1292.16 519.186,1292.16 519.195,1292.16 519.204,1292.16 519.214,1292.16 519.223,1292.16 519.232,1292.16 519.241,1292.16 519.25,1292.16 519.259,1292.16 519.269,1292.16 519.278,1292.16 519.287,1292.16 519.296,1292.15 519.305,1292.15 519.315,1292.15 519.324,1292.15 519.333,1292.15 519.342,1292.15 519.351,1292.15 519.361,1292.15 519.37,1292.15 519.379,1292.15 519.388,1292.15 519.397,1292.15 519.407,1292.15 519.416,1292.15 519.425,1292.14 519.434,1292.14 519.443,1292.14 519.452,1292.14 519.462,1292.14 519.471,1292.14 519.48,1292.14 519.489,1292.14 519.498,1292.14 519.508,1292.14 519.517,1292.14 519.526,1292.14 519.535,1292.14 519.544,1292.14 519.554,1292.14 519.563,1292.13 519.572,1292.13 519.581,1292.13 519.59,1292.13 519.599,1292.13 519.609,1292.13 519.618,1292.13 519.627,1292.13 519.636,1292.13 519.645,1292.13 519.655,1292.13 519.664,1292.13 519.673,1292.13 519.682,1292.13 519.691,1292.12 519.701,1292.12 519.71,1292.12 519.719,1292.12 519.728,1292.12 519.737,1292.12 519.747,1292.12 519.756,1292.12 519.765,1292.12 519.774,1292.12 519.783,1292.12 519.792,1292.12 519.802,1292.12 519.811,1292.12 519.82,1292.11 519.829,1292.11 519.838,1292.11 519.848,1292.11 519.857,1292.11 519.866,1292.11 519.875,1292.11 519.884,1292.11 519.894,1292.11 519.903,1292.11 519.912,1292.11 519.921,1292.11 519.93,1292.11 519.939,1292.11 519.949,1292.11 519.958,1292.1 519.967,1292.1 519.976,1292.1 519.985,1292.1 519.995,1292.1 520.004,1292.1 520.013,1292.1 520.022,1292.1 520.031,1292.1 520.041,1292.1 520.05,1292.1 520.059,1292.1 520.068,1292.1 520.077,1292.1 520.087,1292.09 520.096,1292.09 520.105,1292.09 520.114,1292.09 520.123,1292.09 520.132,1292.09 520.142,1292.09 520.151,1292.09 520.16,1292.09 520.169,1292.09 520.178,1292.09 520.188,1292.09 520.197,1292.09 520.206,1292.09 520.215,1292.09 520.224,1292.08 520.234,1292.08 520.243,1292.08 520.252,1292.08 520.261,1292.08 520.27,1292.08 520.279,1292.08 520.289,1292.08 520.298,1292.08 520.307,1292.08 520.316,1292.08 520.325,1292.08 520.335,1292.08 520.344,1292.08 520.353,1292.07 520.362,1292.07 520.371,1292.07 520.381,1292.07 520.39,1292.07 520.399,1292.07 520.408,1292.07 520.417,1292.07 520.427,1292.07 520.436,1292.07 520.445,1292.07 520.454,1292.07 520.463,1292.07 520.472,1292.07 520.482,1292.07 520.491,1292.06 520.5,1292.06 520.509,1292.06 520.518,1292.06 520.528,1292.06 520.537,1292.06 520.546,1292.06 520.555,1292.06 520.564,1292.06 520.574,1292.06 520.583,1292.06 520.592,1292.06 520.601,1292.06 520.61,1292.06 520.619,1292.05 520.629,1292.05 520.638,1292.05 520.647,1292.05 520.656,1292.05 520.665,1292.05 520.675,1292.05 520.684,1292.05 520.693,1292.05 520.702,1292.05 520.711,1292.05 520.721,1292.05 520.73,1292.05 520.739,1292.05 520.748,1292.05 520.757,1292.04 520.767,1292.04 520.776,1292.04 520.785,1292.04 520.794,1292.04 520.803,1292.04 520.812,1292.04 520.822,1292.04 520.831,1292.04 520.84,1292.04 520.849,1292.04 520.858,1292.04 520.868,1292.04 520.877,1292.04 520.886,1292.04 520.895,1292.03 520.904,1292.03 520.914,1292.03 520.923,1292.03 520.932,1292.03 520.941,1292.03 520.95,1292.03 520.959,1292.03 520.969,1292.03 520.978,1292.03 520.987,1292.03 520.996,1292.03 521.005,1292.03 521.015,1292.03 521.024,1292.02 521.033,1292.02 521.042,1292.02 521.051,1292.02 521.061,1292.02 521.07,1292.02 521.079,1292.02 521.088,1292.02 521.097,1292.02 521.107,1292.02 521.116,1292.02 521.125,1292.02 521.134,1292.02 521.143,1292.02 521.152,1292.02 521.162,1292.01 521.171,1292.01 521.18,1292.01 521.189,1292.01 521.198,1292.01 521.208,1292.01 521.217,1292.01 521.226,1292.01 521.235,1292.01 521.244,1292.01 521.254,1292.01 521.263,1292.01 521.272,1292.01 521.281,1292.01 521.29,1292.01 521.3,1292 521.309,1292 521.318,1292 521.327,1292 521.336,1292 521.345,1292 521.355,1292 521.364,1292 521.373,1292 521.382,1292 521.391,1292 521.401,1292 521.41,1292 521.419,1292 521.428,1291.99 521.437,1291.99 521.447,1291.99 521.456,1291.99 521.465,1291.99 521.474,1291.99 521.483,1291.99 521.492,1291.99 521.502,1291.99 521.511,1291.99 521.52,1291.99 521.529,1291.99 521.538,1291.99 521.548,1291.99 521.557,1291.99 521.566,1291.98 521.575,1291.98 521.584,1291.98 521.594,1291.98 521.603,1291.98 521.612,1291.98 521.621,1291.98 521.63,1291.98 521.64,1291.98 521.649,1291.98 521.658,1291.98 521.667,1291.98 521.676,1291.98 521.685,1291.98 521.695,1291.98 521.704,1291.97 521.713,1291.97 521.722,1291.97 521.731,1291.97 521.741,1291.97 521.75,1291.97 521.759,1291.97 521.768,1291.97 521.777,1291.97 521.787,1291.97 521.796,1291.97 521.805,1291.97 521.814,1291.97 521.823,1291.97 521.832,1291.97 521.842,1291.96 521.851,1291.96 521.86,1291.96 521.869,1291.96 521.878,1291.96 521.888,1291.96 521.897,1291.96 521.906,1291.96 521.915,1291.96 521.924,1291.96 521.934,1291.96 521.943,1291.96 521.952,1291.96 521.961,1291.96 521.97,1291.96 521.98,1291.95 521.989,1291.95 521.998,1291.95 522.007,1291.95 522.016,1291.95 522.025,1291.95 522.035,1291.95 522.044,1291.95 522.053,1291.95 522.062,1291.95 522.071,1291.95 522.081,1291.95 522.09,1291.95 522.099,1291.95 522.108,1291.94 522.117,1291.94 522.127,1291.94 522.136,1291.94 522.145,1291.94 522.154,1291.94 522.163,1291.94 522.172,1291.94 522.182,1291.94 522.191,1291.94 522.2,1291.94 522.209,1291.94 522.218,1291.94 522.228,1291.94 522.237,1291.94 522.246,1291.93 522.255,1291.93 522.264,1291.93 522.274,1291.93 522.283,1291.93 522.292,1291.93 522.301,1291.93 522.31,1291.93 522.32,1291.93 522.329,1291.93 522.338,1291.93 522.347,1291.93 522.356,1291.93 522.365,1291.93 522.375,1291.93 522.384,1291.92 522.393,1291.92 522.402,1291.92 522.411,1291.92 522.421,1291.92 522.43,1291.92 522.439,1291.92 522.448,1291.92 522.457,1291.92 522.467,1291.92 522.476,1291.92 522.485,1291.92 522.494,1291.92 522.503,1291.92 522.512,1291.92 522.522,1291.91 522.531,1291.91 522.54,1291.91 522.549,1291.91 522.558,1291.91 522.568,1291.91 522.577,1291.91 522.586,1291.91 522.595,1291.91 522.604,1291.91 522.614,1291.91 522.623,1291.91 522.632,1291.91 522.641,1291.91 522.65,1291.91 522.66,1291.9 522.669,1291.9 522.678,1291.9 522.687,1291.9 522.696,1291.9 522.705,1291.9 522.715,1291.9 522.724,1291.9 522.733,1291.9 522.742,1291.9 522.751,1291.9 522.761,1291.9 522.77,1291.9 522.779,1291.9 522.788,1291.9 522.797,1291.89 522.807,1291.89 522.816,1291.89 522.825,1291.89 522.834,1291.89 522.843,1291.89 522.852,1291.89 522.862,1291.89 522.871,1291.89 522.88,1291.89 522.889,1291.89 522.898,1291.89 522.908,1291.89 522.917,1291.89 522.926,1291.89 522.935,1291.88 522.944,1291.88 522.954,1291.88 522.963,1291.88 522.972,1291.88 522.981,1291.88 522.99,1291.88 523,1291.88 523.009,1291.88 523.018,1291.88 523.027,1291.88 523.036,1291.88 523.045,1291.88 523.055,1291.88 523.064,1291.88 523.073,1291.87 523.082,1291.87 523.091,1291.87 523.101,1291.87 523.11,1291.87 523.119,1291.87 523.128,1291.87 523.137,1291.87 523.147,1291.87 523.156,1291.87 523.165,1291.87 523.174,1291.87 523.183,1291.87 523.192,1291.87 523.202,1291.87 523.211,1291.86 523.22,1291.86 523.229,1291.86 523.238,1291.86 523.248,1291.86 523.257,1291.86 523.266,1291.86 523.275,1291.86 523.284,1291.86 523.294,1291.86 523.303,1291.86 523.312,1291.86 523.321,1291.86 523.33,1291.86 523.34,1291.86 523.349,1291.86 523.358,1291.85 523.367,1291.85 523.376,1291.85 523.385,1291.85 523.395,1291.85 523.404,1291.85 523.413,1291.85 523.422,1291.85 523.431,1291.85 523.441,1291.85 523.45,1291.85 523.459,1291.85 523.468,1291.85 523.477,1291.85 523.487,1291.85 523.496,1291.84 523.505,1291.84 523.514,1291.84 523.523,1291.84 523.532,1291.84 523.542,1291.84 523.551,1291.84 523.56,1291.84 523.569,1291.84 523.578,1291.84 523.588,1291.84 523.597,1291.84 523.606,1291.84 523.615,1291.84 523.624,1291.84 523.634,1291.83 523.643,1291.83 523.652,1291.83 523.661,1291.83 523.67,1291.83 523.68,1291.83 523.689,1291.83 523.698,1291.83 523.707,1291.83 523.716,1291.83 523.725,1291.83 523.735,1291.83 523.744,1291.83 523.753,1291.83 523.762,1291.83 523.771,1291.82 523.781,1291.82 523.79,1291.82 523.799,1291.82 523.808,1291.82 523.817,1291.82 523.827,1291.82 523.836,1291.82 523.845,1291.82 523.854,1291.82 523.863,1291.82 523.873,1291.82 523.882,1291.82 523.891,1291.82 523.9,1291.82 523.909,1291.81 523.918,1291.81 523.928,1291.81 523.937,1291.81 523.946,1291.81 523.955,1291.81 523.964,1291.81 523.974,1291.81 523.983,1291.81 523.992,1291.81 524.001,1291.81 524.01,1291.81 524.02,1291.81 524.029,1291.81 524.038,1291.81 524.047,1291.81 524.056,1291.8 524.065,1291.8 524.075,1291.8 524.084,1291.8 524.093,1291.8 524.102,1291.8 524.111,1291.8 524.121,1291.8 524.13,1291.8 524.139,1291.8 524.148,1291.8 524.157,1291.8 524.167,1291.8 524.176,1291.8 524.185,1291.8 524.194,1291.79 524.203,1291.79 524.213,1291.79 524.222,1291.79 524.231,1291.79 524.24,1291.79 524.249,1291.79 524.258,1291.79 524.268,1291.79 524.277,1291.79 524.286,1291.79 524.295,1291.79 524.304,1291.79 524.314,1291.79 524.323,1291.79 524.332,1291.78 524.341,1291.78 524.35,1291.78 524.36,1291.78 524.369,1291.78 524.378,1291.78 524.387,1291.78 524.396,1291.78 524.405,1291.78 524.415,1291.78 524.424,1291.78 524.433,1291.78 524.442,1291.78 524.451,1291.78 524.461,1291.78 524.47,1291.78 524.479,1291.77 524.488,1291.77 524.497,1291.77 524.507,1291.77 524.516,1291.77 524.525,1291.77 524.534,1291.77 524.543,1291.77 524.553,1291.77 524.562,1291.77 524.571,1291.77 524.58,1291.77 524.589,1291.77 524.598,1291.77 524.608,1291.77 524.617,1291.76 524.626,1291.76 524.635,1291.76 524.644,1291.76 524.654,1291.76 524.663,1291.76 524.672,1291.76 524.681,1291.76 524.69,1291.76 524.7,1291.76 524.709,1291.76 524.718,1291.76 524.727,1291.76 524.736,1291.76 524.745,1291.76 524.755,1291.76 524.764,1291.75 524.773,1291.75 524.782,1291.75 524.791,1291.75 524.801,1291.75 524.81,1291.75 524.819,1291.75 524.828,1291.75 524.837,1291.75 524.847,1291.75 524.856,1291.75 524.865,1291.75 524.874,1291.75 524.883,1291.75 524.893,1291.75 524.902,1291.74 524.911,1291.74 524.92,1291.74 524.929,1291.74 524.938,1291.74 524.948,1291.74 524.957,1291.74 524.966,1291.74 524.975,1291.74 524.984,1291.74 524.994,1291.74 525.003,1291.74 525.012,1291.74 525.021,1291.74 525.03,1291.74 525.04,1291.74 525.049,1291.73 525.058,1291.73 525.067,1291.73 525.076,1291.73 525.085,1291.73 525.095,1291.73 525.104,1291.73 525.113,1291.73 525.122,1291.73 525.131,1291.73 525.141,1291.73 525.15,1291.73 525.159,1291.73 525.168,1291.73 525.177,1291.73 525.187,1291.72 525.196,1291.72 525.205,1291.72 525.214,1291.72 525.223,1291.72 525.233,1291.72 525.242,1291.72 525.251,1291.72 525.26,1291.72 525.269,1291.72 525.278,1291.72 525.288,1291.72 525.297,1291.72 525.306,1291.72 525.315,1291.72 525.324,1291.72 525.334,1291.71 525.343,1291.71 525.352,1291.71 525.361,1291.71 525.37,1291.71 525.38,1291.71 525.389,1291.71 525.398,1291.71 525.407,1291.71 525.416,1291.71 525.425,1291.71 525.435,1291.71 525.444,1291.71 525.453,1291.71 525.462,1291.71 525.471,1291.7 525.481,1291.7 525.49,1291.7 525.499,1291.7 525.508,1291.7 525.517,1291.7 525.527,1291.7 525.536,1291.7 525.545,1291.7 525.554,1291.7 525.563,1291.7 525.573,1291.7 525.582,1291.7 525.591,1291.7 525.6,1291.7 525.609,1291.7 525.618,1291.69 525.628,1291.69 525.637,1291.69 525.646,1291.69 525.655,1291.69 525.664,1291.69 525.674,1291.69 525.683,1291.69 525.692,1291.69 525.701,1291.69 525.71,1291.69 525.72,1291.69 525.729,1291.69 525.738,1291.69 525.747,1291.69 525.756,1291.69 525.765,1291.68 525.775,1291.68 525.784,1291.68 525.793,1291.68 525.802,1291.68 525.811,1291.68 525.821,1291.68 525.83,1291.68 525.839,1291.68 525.848,1291.68 525.857,1291.68 525.867,1291.68 525.876,1291.68 525.885,1291.68 525.894,1291.68 525.903,1291.67 525.913,1291.67 525.922,1291.67 525.931,1291.67 525.94,1291.67 525.949,1291.67 525.958,1291.67 525.968,1291.67 525.977,1291.67 525.986,1291.67 525.995,1291.67 526.004,1291.67 526.014,1291.67 526.023,1291.67 526.032,1291.67 526.041,1291.67 526.05,1291.66 526.06,1291.66 526.069,1291.66 526.078,1291.66 526.087,1291.66 526.096,1291.66 526.105,1291.66 526.115,1291.66 526.124,1291.66 526.133,1291.66 526.142,1291.66 526.151,1291.66 526.161,1291.66 526.17,1291.66 526.179,1291.66 526.188,1291.66 526.197,1291.65 526.207,1291.65 526.216,1291.65 526.225,1291.65 526.234,1291.65 526.243,1291.65 526.253,1291.65 526.262,1291.65 526.271,1291.65 526.28,1291.65 526.289,1291.65 526.298,1291.65 526.308,1291.65 526.317,1291.65 526.326,1291.65 526.335,1291.65 526.344,1291.64 526.354,1291.64 526.363,1291.64 526.372,1291.64 526.381,1291.64 526.39,1291.64 526.4,1291.64 526.409,1291.64 526.418,1291.64 526.427,1291.64 526.436,1291.64 526.446,1291.64 526.455,1291.64 526.464,1291.64 526.473,1291.64 526.482,1291.64 526.491,1291.63 526.501,1291.63 526.51,1291.63 526.519,1291.63 526.528,1291.63 526.537,1291.63 526.547,1291.63 526.556,1291.63 526.565,1291.63 526.574,1291.63 526.583,1291.63 526.593,1291.63 526.602,1291.63 526.611,1291.63 526.62,1291.63 526.629,1291.62 526.638,1291.62 526.648,1291.62 526.657,1291.62 526.666,1291.62 526.675,1291.62 526.684,1291.62 526.694,1291.62 526.703,1291.62 526.712,1291.62 526.721,1291.62 526.73,1291.62 526.74,1291.62 526.749,1291.62 526.758,1291.62 526.767,1291.62 526.776,1291.61 526.786,1291.61 526.795,1291.61 526.804,1291.61 526.813,1291.61 526.822,1291.61 526.831,1291.61 526.841,1291.61 526.85,1291.61 526.859,1291.61 526.868,1291.61 526.877,1291.61 526.887,1291.61 526.896,1291.61 526.905,1291.61 526.914,1291.61 526.923,1291.6 526.933,1291.6 526.942,1291.6 526.951,1291.6 526.96,1291.6 526.969,1291.6 526.978,1291.6 526.988,1291.6 526.997,1291.6 527.006,1291.6 527.015,1291.6 527.024,1291.6 527.034,1291.6 527.043,1291.6 527.052,1291.6 527.061,1291.6 527.07,1291.59 527.08,1291.59 527.089,1291.59 527.098,1291.59 527.107,1291.59 527.116,1291.59 527.126,1291.59 527.135,1291.59 527.144,1291.59 527.153,1291.59 527.162,1291.59 527.171,1291.59 527.181,1291.59 527.19,1291.59 527.199,1291.59 527.208,1291.59 527.217,1291.58 527.227,1291.58 527.236,1291.58 527.245,1291.58 527.254,1291.58 527.263,1291.58 527.273,1291.58 527.282,1291.58 527.291,1291.58 527.3,1291.58 527.309,1291.58 527.318,1291.58 527.328,1291.58 527.337,1291.58 527.346,1291.58 527.355,1291.58 527.364,1291.57 527.374,1291.57 527.383,1291.57 527.392,1291.57 527.401,1291.57 527.41,1291.57 527.42,1291.57 527.429,1291.57 527.438,1291.57 527.447,1291.57 527.456,1291.57 527.466,1291.57 527.475,1291.57 527.484,1291.57 527.493,1291.57 527.502,1291.57 527.511,1291.56 527.521,1291.56 527.53,1291.56 527.539,1291.56 527.548,1291.56 527.557,1291.56 527.567,1291.56 527.576,1291.56 527.585,1291.56 527.594,1291.56 527.603,1291.56 527.613,1291.56 527.622,1291.56 527.631,1291.56 527.64,1291.56 527.649,1291.56 527.658,1291.55 527.668,1291.55 527.677,1291.55 527.686,1291.55 527.695,1291.55 527.704,1291.55 527.714,1291.55 527.723,1291.55 527.732,1291.55 527.741,1291.55 527.75,1291.55 527.76,1291.55 527.769,1291.55 527.778,1291.55 527.787,1291.55 527.796,1291.55 527.806,1291.55 527.815,1291.54 527.824,1291.54 527.833,1291.54 527.842,1291.54 527.851,1291.54 527.861,1291.54 527.87,1291.54 527.879,1291.54 527.888,1291.54 527.897,1291.54 527.907,1291.54 527.916,1291.54 527.925,1291.54 527.934,1291.54 527.943,1291.54 527.953,1291.54 527.962,1291.53 527.971,1291.53 527.98,1291.53 527.989,1291.53 527.998,1291.53 528.008,1291.53 528.017,1291.53 528.026,1291.53 528.035,1291.53 528.044,1291.53 528.054,1291.53 528.063,1291.53 528.072,1291.53 528.081,1291.53 528.09,1291.53 528.1,1291.53 528.109,1291.52 528.118,1291.52 528.127,1291.52 528.136,1291.52 528.146,1291.52 528.155,1291.52 528.164,1291.52 528.173,1291.52 528.182,1291.52 528.191,1291.52 528.201,1291.52 528.21,1291.52 528.219,1291.52 528.228,1291.52 528.237,1291.52 528.247,1291.52 528.256,1291.51 528.265,1291.51 528.274,1291.51 528.283,1291.51 528.293,1291.51 528.302,1291.51 528.311,1291.51 528.32,1291.51 528.329,1291.51 528.338,1291.51 528.348,1291.51 528.357,1291.51 528.366,1291.51 528.375,1291.51 528.384,1291.51 528.394,1291.51 528.403,1291.51 528.412,1291.5 528.421,1291.5 528.43,1291.5 528.44,1291.5 528.449,1291.5 528.458,1291.5 528.467,1291.5 528.476,1291.5 528.486,1291.5 528.495,1291.5 528.504,1291.5 528.513,1291.5 528.522,1291.5 528.531,1291.5 528.541,1291.5 528.55,1291.5 528.559,1291.49 528.568,1291.49 528.577,1291.49 528.587,1291.49 528.596,1291.49 528.605,1291.49 528.614,1291.49 528.623,1291.49 528.633,1291.49 528.642,1291.49 528.651,1291.49 528.66,1291.49 528.669,1291.49 528.678,1291.49 528.688,1291.49 528.697,1291.49 528.706,1291.48 528.715,1291.48 528.724,1291.48 528.734,1291.48 528.743,1291.48 528.752,1291.48 528.761,1291.48 528.77,1291.48 528.78,1291.48 528.789,1291.48 528.798,1291.48 528.807,1291.48 528.816,1291.48 528.826,1291.48 528.835,1291.48 528.844,1291.48 528.853,1291.48 528.862,1291.47 528.871,1291.47 528.881,1291.47 528.89,1291.47 528.899,1291.47 528.908,1291.47 528.917,1291.47 528.927,1291.47 528.936,1291.47 528.945,1291.47 528.954,1291.47 528.963,1291.47 528.973,1291.47 528.982,1291.47 528.991,1291.47 529,1291.47 529.009,1291.46 529.019,1291.46 529.028,1291.46 529.037,1291.46 529.046,1291.46 529.055,1291.46 529.064,1291.46 529.074,1291.46 529.083,1291.46 529.092,1291.46 529.101,1291.46 529.11,1291.46 529.12,1291.46 529.129,1291.46 529.138,1291.46 529.147,1291.46 529.156,1291.46 529.166,1291.45 529.175,1291.45 529.184,1291.45 529.193,1291.45 529.202,1291.45 529.211,1291.45 529.221,1291.45 529.23,1291.45 529.239,1291.45 529.248,1291.45 529.257,1291.45 529.267,1291.45 529.276,1291.45 529.285,1291.45 529.294,1291.45 529.303,1291.45 529.313,1291.44 529.322,1291.44 529.331,1291.44 529.34,1291.44 529.349,1291.44 529.359,1291.44 529.368,1291.44 529.377,1291.44 529.386,1291.44 529.395,1291.44 529.404,1291.44 529.414,1291.44 529.423,1291.44 529.432,1291.44 529.441,1291.44 529.45,1291.44 529.46,1291.44 529.469,1291.43 529.478,1291.43 529.487,1291.43 529.496,1291.43 529.506,1291.43 529.515,1291.43 529.524,1291.43 529.533,1291.43 529.542,1291.43 529.551,1291.43 529.561,1291.43 529.57,1291.43 529.579,1291.43 529.588,1291.43 529.597,1291.43 529.607,1291.43 529.616,1291.42 529.625,1291.42 529.634,1291.42 529.643,1291.42 529.653,1291.42 529.662,1291.42 529.671,1291.42 529.68,1291.42 529.689,1291.42 529.699,1291.42 529.708,1291.42 529.717,1291.42 529.726,1291.42 529.735,1291.42 529.744,1291.42 529.754,1291.42 529.763,1291.42 529.772,1291.41 529.781,1291.41 529.79,1291.41 529.8,1291.41 529.809,1291.41 529.818,1291.41 529.827,1291.41 529.836,1291.41 529.846,1291.41 529.855,1291.41 529.864,1291.41 529.873,1291.41 529.882,1291.41 529.891,1291.41 529.901,1291.41 529.91,1291.41 529.919,1291.41 529.928,1291.4 529.937,1291.4 529.947,1291.4 529.956,1291.4 529.965,1291.4 529.974,1291.4 529.983,1291.4 529.993,1291.4 530.002,1291.4 530.011,1291.4 530.02,1291.4 530.029,1291.4 530.039,1291.4 530.048,1291.4 530.057,1291.4 530.066,1291.4 530.075,1291.39 530.084,1291.39 530.094,1291.39 530.103,1291.39 530.112,1291.39 530.121,1291.39 530.13,1291.39 530.14,1291.39 530.149,1291.39 530.158,1291.39 530.167,1291.39 530.176,1291.39 530.186,1291.39 530.195,1291.39 530.204,1291.39 530.213,1291.39 530.222,1291.39 530.231,1291.38 530.241,1291.38 530.25,1291.38 530.259,1291.38 530.268,1291.38 530.277,1291.38 530.287,1291.38 530.296,1291.38 530.305,1291.38 530.314,1291.38 530.323,1291.38 530.333,1291.38 530.342,1291.38 530.351,1291.38 530.36,1291.38 530.369,1291.38 530.379,1291.38 530.388,1291.37 530.397,1291.37 530.406,1291.37 530.415,1291.37 530.424,1291.37 530.434,1291.37 530.443,1291.37 530.452,1291.37 530.461,1291.37 530.47,1291.37 530.48,1291.37 530.489,1291.37 530.498,1291.37 530.507,1291.37 530.516,1291.37 530.526,1291.37 530.535,1291.37 530.544,1291.36 530.553,1291.36 530.562,1291.36 530.571,1291.36 530.581,1291.36 530.59,1291.36 530.599,1291.36 530.608,1291.36 530.617,1291.36 530.627,1291.36 530.636,1291.36 530.645,1291.36 530.654,1291.36 530.663,1291.36 530.673,1291.36 530.682,1291.36 530.691,1291.35 530.7,1291.35 530.709,1291.35 530.719,1291.35 530.728,1291.35 530.737,1291.35 530.746,1291.35 530.755,1291.35 530.764,1291.35 530.774,1291.35 530.783,1291.35 530.792,1291.35 530.801,1291.35 530.81,1291.35 530.82,1291.35 530.829,1291.35 530.838,1291.35 530.847,1291.34 530.856,1291.34 530.866,1291.34 530.875,1291.34 530.884,1291.34 530.893,1291.34 530.902,1291.34 530.911,1291.34 530.921,1291.34 530.93,1291.34 530.939,1291.34 530.948,1291.34 530.957,1291.34 530.967,1291.34 530.976,1291.34 530.985,1291.34 530.994,1291.34 531.003,1291.33 531.013,1291.33 531.022,1291.33 531.031,1291.33 531.04,1291.33 531.049,1291.33 531.059,1291.33 531.068,1291.33 531.077,1291.33 531.086,1291.33 531.095,1291.33 531.104,1291.33 531.114,1291.33 531.123,1291.33 531.132,1291.33 531.141,1291.33 531.15,1291.33 531.16,1291.32 531.169,1291.32 531.178,1291.32 531.187,1291.32 531.196,1291.32 531.206,1291.32 531.215,1291.32 531.224,1291.32 531.233,1291.32 531.242,1291.32 531.252,1291.32 531.261,1291.32 531.27,1291.32 531.279,1291.32 531.288,1291.32 531.297,1291.32 531.307,1291.32 531.316,1291.31 531.325,1291.31 531.334,1291.31 531.343,1291.31 531.353,1291.31 531.362,1291.31 531.371,1291.31 531.38,1291.31 531.389,1291.31 531.399,1291.31 531.408,1291.31 531.417,1291.31 531.426,1291.31 531.435,1291.31 531.444,1291.31 531.454,1291.31 531.463,1291.31 531.472,1291.3 531.481,1291.3 531.49,1291.3 531.5,1291.3 531.509,1291.3 531.518,1291.3 531.527,1291.3 531.536,1291.3 531.546,1291.3 531.555,1291.3 531.564,1291.3 531.573,1291.3 531.582,1291.3 531.592,1291.3 531.601,1291.3 531.61,1291.3 531.619,1291.3 531.628,1291.29 531.637,1291.29 531.647,1291.29 531.656,1291.29 531.665,1291.29 531.674,1291.29 531.683,1291.29 531.693,1291.29 531.702,1291.29 531.711,1291.29 531.72,1291.29 531.729,1291.29 531.739,1291.29 531.748,1291.29 531.757,1291.29 531.766,1291.29 531.775,1291.29 531.784,1291.28 531.794,1291.28 531.803,1291.28 531.812,1291.28 531.821,1291.28 531.83,1291.28 531.84,1291.28 531.849,1291.28 531.858,1291.28 531.867,1291.28 531.876,1291.28 531.886,1291.28 531.895,1291.28 531.904,1291.28 531.913,1291.28 531.922,1291.28 531.932,1291.28 531.941,1291.28 531.95,1291.27 531.959,1291.27 531.968,1291.27 531.977,1291.27 531.987,1291.27 531.996,1291.27 532.005,1291.27 532.014,1291.27 532.023,1291.27 532.033,1291.27 532.042,1291.27 532.051,1291.27 532.06,1291.27 532.069,1291.27 532.079,1291.27 532.088,1291.27 532.097,1291.27 532.106,1291.26 532.115,1291.26 532.124,1291.26 532.134,1291.26 532.143,1291.26 532.152,1291.26 532.161,1291.26 532.17,1291.26 532.18,1291.26 532.189,1291.26 532.198,1291.26 532.207,1291.26 532.216,1291.26 532.226,1291.26 532.235,1291.26 532.244,1291.26 532.253,1291.26 532.262,1291.25 532.272,1291.25 532.281,1291.25 532.29,1291.25 532.299,1291.25 532.308,1291.25 532.317,1291.25 532.327,1291.25 532.336,1291.25 532.345,1291.25 532.354,1291.25 532.363,1291.25 532.373,1291.25 532.382,1291.25 532.391,1291.25 532.4,1291.25 532.409,1291.25 532.419,1291.24 532.428,1291.24 532.437,1291.24 532.446,1291.24 532.455,1291.24 532.464,1291.24 532.474,1291.24 532.483,1291.24 532.492,1291.24 532.501,1291.24 532.51,1291.24 532.52,1291.24 532.529,1291.24 532.538,1291.24 532.547,1291.24 532.556,1291.24 532.566,1291.24 532.575,1291.24 532.584,1291.23 532.593,1291.23 532.602,1291.23 532.612,1291.23 532.621,1291.23 532.63,1291.23 532.639,1291.23 532.648,1291.23 532.657,1291.23 532.667,1291.23 532.676,1291.23 532.685,1291.23 532.694,1291.23 532.703,1291.23 532.713,1291.23 532.722,1291.23 532.731,1291.23 532.74,1291.22 532.749,1291.22 532.759,1291.22 532.768,1291.22 532.777,1291.22 532.786,1291.22 532.795,1291.22 532.804,1291.22 532.814,1291.22 532.823,1291.22 532.832,1291.22 532.841,1291.22 532.85,1291.22 532.86,1291.22 532.869,1291.22 532.878,1291.22 532.887,1291.22 532.896,1291.22 532.906,1291.21 532.915,1291.21 532.924,1291.21 532.933,1291.21 532.942,1291.21 532.952,1291.21 532.961,1291.21 532.97,1291.21 532.979,1291.21 532.988,1291.21 532.997,1291.21 533.007,1291.21 533.016,1291.21 533.025,1291.21 533.034,1291.21 533.043,1291.21 533.053,1291.21 533.062,1291.2 533.071,1291.2 533.08,1291.2 533.089,1291.2 533.099,1291.2 533.108,1291.2 533.117,1291.2 533.126,1291.2 533.135,1291.2 533.144,1291.2 533.154,1291.2 533.163,1291.2 533.172,1291.2 533.181,1291.2 533.19,1291.2 533.2,1291.2 533.209,1291.2 533.218,1291.19 533.227,1291.19 533.236,1291.19 533.246,1291.19 533.255,1291.19 533.264,1291.19 533.273,1291.19 533.282,1291.19 533.292,1291.19 533.301,1291.19 533.31,1291.19 533.319,1291.19 533.328,1291.19 533.337,1291.19 533.347,1291.19 533.356,1291.19 533.365,1291.19 533.374,1291.19 533.383,1291.18 533.393,1291.18 533.402,1291.18 533.411,1291.18 533.42,1291.18 533.429,1291.18 533.439,1291.18 533.448,1291.18 533.457,1291.18 533.466,1291.18 533.475,1291.18 533.484,1291.18 533.494,1291.18 533.503,1291.18 533.512,1291.18 533.521,1291.18 533.53,1291.18 533.54,1291.18 533.549,1291.17 533.558,1291.17 533.567,1291.17 533.576,1291.17 533.586,1291.17 533.595,1291.17 533.604,1291.17 533.613,1291.17 533.622,1291.17 533.632,1291.17 533.641,1291.17 533.65,1291.17 533.659,1291.17 533.668,1291.17 533.677,1291.17 533.687,1291.17 533.696,1291.17 533.705,1291.16 533.714,1291.16 533.723,1291.16 533.733,1291.16 533.742,1291.16 533.751,1291.16 533.76,1291.16 533.769,1291.16 533.779,1291.16 533.788,1291.16 533.797,1291.16 533.806,1291.16 533.815,1291.16 533.825,1291.16 533.834,1291.16 533.843,1291.16 533.852,1291.16 533.861,1291.16 533.87,1291.15 533.88,1291.15 533.889,1291.15 533.898,1291.15 533.907,1291.15 533.916,1291.15 533.926,1291.15 533.935,1291.15 533.944,1291.15 533.953,1291.15 533.962,1291.15 533.972,1291.15 533.981,1291.15 533.99,1291.15 533.999,1291.15 534.008,1291.15 534.017,1291.15 534.027,1291.15 534.036,1291.14 534.045,1291.14 534.054,1291.14 534.063,1291.14 534.073,1291.14 534.082,1291.14 534.091,1291.14 534.1,1291.14 534.109,1291.14 534.119,1291.14 534.128,1291.14 534.137,1291.14 534.146,1291.14 534.155,1291.14 534.165,1291.14 534.174,1291.14 534.183,1291.14 534.192,1291.13 534.201,1291.13 534.21,1291.13 534.22,1291.13 534.229,1291.13 534.238,1291.13 534.247,1291.13 534.256,1291.13 534.266,1291.13 534.275,1291.13 534.284,1291.13 534.293,1291.13 534.302,1291.13 534.312,1291.13 534.321,1291.13 534.33,1291.13 534.339,1291.13 534.348,1291.13 534.357,1291.12 534.367,1291.12 534.376,1291.12 534.385,1291.12 534.394,1291.12 534.403,1291.12 534.413,1291.12 534.422,1291.12 534.431,1291.12 534.44,1291.12 534.449,1291.12 534.459,1291.12 534.468,1291.12 534.477,1291.12 534.486,1291.12 534.495,1291.12 534.505,1291.12 534.514,1291.12 534.523,1291.11 534.532,1291.11 534.541,1291.11 534.55,1291.11 534.56,1291.11 534.569,1291.11 534.578,1291.11 534.587,1291.11 534.596,1291.11 534.606,1291.11 534.615,1291.11 534.624,1291.11 534.633,1291.11 534.642,1291.11 534.652,1291.11 534.661,1291.11 534.67,1291.11 534.679,1291.11 534.688,1291.1 534.697,1291.1 534.707,1291.1 534.716,1291.1 534.725,1291.1 534.734,1291.1 534.743,1291.1 534.753,1291.1 534.762,1291.1 534.771,1291.1 534.78,1291.1 534.789,1291.1 534.799,1291.1 534.808,1291.1 534.817,1291.1 534.826,1291.1 534.835,1291.1 534.845,1291.1 534.854,1291.09 534.863,1291.09 534.872,1291.09 534.881,1291.09 534.89,1291.09 534.9,1291.09 534.909,1291.09 534.918,1291.09 534.927,1291.09 534.936,1291.09 534.946,1291.09 534.955,1291.09 534.964,1291.09 534.973,1291.09 534.982,1291.09 534.992,1291.09 535.001,1291.09 535.01,1291.09 535.019,1291.08 535.028,1291.08 535.037,1291.08 535.047,1291.08 535.056,1291.08 535.065,1291.08 535.074,1291.08 535.083,1291.08 535.093,1291.08 535.102,1291.08 535.111,1291.08 535.12,1291.08 535.129,1291.08 535.139,1291.08 535.148,1291.08 535.157,1291.08 535.166,1291.08 535.175,1291.08 535.185,1291.07 535.194,1291.07 535.203,1291.07 535.212,1291.07 535.221,1291.07 535.23,1291.07 535.24,1291.07 535.249,1291.07 535.258,1291.07 535.267,1291.07 535.276,1291.07 535.286,1291.07 535.295,1291.07 535.304,1291.07 535.313,1291.07 535.322,1291.07 535.332,1291.07 535.341,1291.07 535.35,1291.06 535.359,1291.06 535.368,1291.06 535.377,1291.06 535.387,1291.06 535.396,1291.06 535.405,1291.06 535.414,1291.06 535.423,1291.06 535.433,1291.06 535.442,1291.06 535.451,1291.06 535.46,1291.06 535.469,1291.06 535.479,1291.06 535.488,1291.06 535.497,1291.06 535.506,1291.06 535.515,1291.05 535.525,1291.05 535.534,1291.05 535.543,1291.05 535.552,1291.05 535.561,1291.05 535.57,1291.05 535.58,1291.05 535.589,1291.05 535.598,1291.05 535.607,1291.05 535.616,1291.05 535.626,1291.05 535.635,1291.05 535.644,1291.05 535.653,1291.05 535.662,1291.05 535.672,1291.05 535.681,1291.04 535.69,1291.04 535.699,1291.04 535.708,1291.04 535.717,1291.04 535.727,1291.04 535.736,1291.04 535.745,1291.04 535.754,1291.04 535.763,1291.04 535.773,1291.04 535.782,1291.04 535.791,1291.04 535.8,1291.04 535.809,1291.04 535.819,1291.04 535.828,1291.04 535.837,1291.04 535.846,1291.04 535.855,1291.03 535.865,1291.03 535.874,1291.03 535.883,1291.03 535.892,1291.03 535.901,1291.03 535.91,1291.03 535.92,1291.03 535.929,1291.03 535.938,1291.03 535.947,1291.03 535.956,1291.03 535.966,1291.03 535.975,1291.03 535.984,1291.03 535.993,1291.03 536.002,1291.03 536.012,1291.03 536.021,1291.02 536.03,1291.02 536.039,1291.02 536.048,1291.02 536.057,1291.02 536.067,1291.02 536.076,1291.02 536.085,1291.02 536.094,1291.02 536.103,1291.02 536.113,1291.02 536.122,1291.02 536.131,1291.02 536.14,1291.02 536.149,1291.02 536.159,1291.02 536.168,1291.02 536.177,1291.02 536.186,1291.01 536.195,1291.01 536.205,1291.01 536.214,1291.01 536.223,1291.01 536.232,1291.01 536.241,1291.01 536.25,1291.01 536.26,1291.01 536.269,1291.01 536.278,1291.01 536.287,1291.01 536.296,1291.01 536.306,1291.01 536.315,1291.01 536.324,1291.01 536.333,1291.01 536.342,1291.01 536.352,1291 536.361,1291 536.37,1291 536.379,1291 536.388,1291 536.398,1291 536.407,1291 536.416,1291 536.425,1291 536.434,1291 536.443,1291 536.453,1291 536.462,1291 536.471,1291 536.48,1291 536.489,1291 536.499,1291 536.508,1291 536.517,1291 536.526,1290.99 536.535,1290.99 536.545,1290.99 536.554,1290.99 536.563,1290.99 536.572,1290.99 536.581,1290.99 536.59,1290.99 536.6,1290.99 536.609,1290.99 536.618,1290.99 536.627,1290.99 536.636,1290.99 536.646,1290.99 536.655,1290.99 536.664,1290.99 536.673,1290.99 536.682,1290.99 536.692,1290.98 536.701,1290.98 536.71,1290.98 536.719,1290.98 536.728,1290.98 536.738,1290.98 536.747,1290.98 536.756,1290.98 536.765,1290.98 536.774,1290.98 536.783,1290.98 536.793,1290.98 536.802,1290.98 536.811,1290.98 536.82,1290.98 536.829,1290.98 536.839,1290.98 536.848,1290.98 536.857,1290.98 536.866,1290.97 536.875,1290.97 536.885,1290.97 536.894,1290.97 536.903,1290.97 536.912,1290.97 536.921,1290.97 536.93,1290.97 536.94,1290.97 536.949,1290.97 536.958,1290.97 536.967,1290.97 536.976,1290.97 536.986,1290.97 536.995,1290.97 537.004,1290.97 537.013,1290.97 537.022,1290.97 537.032,1290.96 537.041,1290.96 537.05,1290.96 537.059,1290.96 537.068,1290.96 537.078,1290.96 537.087,1290.96 537.096,1290.96 537.105,1290.96 537.114,1290.96 537.123,1290.96 537.133,1290.96 537.142,1290.96 537.151,1290.96 537.16,1290.96 537.169,1290.96 537.179,1290.96 537.188,1290.96 537.197,1290.96 537.206,1290.95 537.215,1290.95 537.225,1290.95 537.234,1290.95 537.243,1290.95 537.252,1290.95 537.261,1290.95 537.27,1290.95 537.28,1290.95 537.289,1290.95 537.298,1290.95 537.307,1290.95 537.316,1290.95 537.326,1290.95 537.335,1290.95 537.344,1290.95 537.353,1290.95 537.362,1290.95 537.372,1290.95 537.381,1290.94 537.39,1290.94 537.399,1290.94 537.408,1290.94 537.418,1290.94 537.427,1290.94 537.436,1290.94 537.445,1290.94 537.454,1290.94 537.463,1290.94 537.473,1290.94 537.482,1290.94 537.491,1290.94 537.5,1290.94 537.509,1290.94 537.519,1290.94 537.528,1290.94 537.537,1290.94 537.546,1290.93 537.555,1290.93 537.565,1290.93 537.574,1290.93 537.583,1290.93 537.592,1290.93 537.601,1290.93 537.61,1290.93 537.62,1290.93 537.629,1290.93 537.638,1290.93 537.647,1290.93 537.656,1290.93 537.666,1290.93 537.675,1290.93 537.684,1290.93 537.693,1290.93 537.702,1290.93 537.712,1290.93 537.721,1290.92 537.73,1290.92 537.739,1290.92 537.748,1290.92 537.758,1290.92 537.767,1290.92 537.776,1290.92 537.785,1290.92 537.794,1290.92 537.803,1290.92 537.813,1290.92 537.822,1290.92 537.831,1290.92 537.84,1290.92 537.849,1290.92 537.859,1290.92 537.868,1290.92 537.877,1290.92 537.886,1290.92 537.895,1290.91 537.905,1290.91 537.914,1290.91 537.923,1290.91 537.932,1290.91 537.941,1290.91 537.95,1290.91 537.96,1290.91 537.969,1290.91 537.978,1290.91 537.987,1290.91 537.996,1290.91 538.006,1290.91 538.015,1290.91 538.024,1290.91 538.033,1290.91 538.042,1290.91 538.052,1290.91 538.061,1290.91 538.07,1290.9 538.079,1290.9 538.088,1290.9 538.098,1290.9 538.107,1290.9 538.116,1290.9 538.125,1290.9 538.134,1290.9 538.143,1290.9 538.153,1290.9 538.162,1290.9 538.171,1290.9 538.18,1290.9 538.189,1290.9 538.199,1290.9 538.208,1290.9 538.217,1290.9 538.226,1290.9 538.235,1290.9 538.245,1290.89 538.254,1290.89 538.263,1290.89 538.272,1290.89 538.281,1290.89 538.29,1290.89 538.3,1290.89 538.309,1290.89 538.318,1290.89 538.327,1290.89 538.336,1290.89 538.346,1290.89 538.355,1290.89 538.364,1290.89 538.373,1290.89 538.382,1290.89 538.392,1290.89 538.401,1290.89 538.41,1290.89 538.419,1290.88 538.428,1290.88 538.438,1290.88 538.447,1290.88 538.456,1290.88 538.465,1290.88 538.474,1290.88 538.483,1290.88 538.493,1290.88 538.502,1290.88 538.511,1290.88 538.52,1290.88 538.529,1290.88 538.539,1290.88 538.548,1290.88 538.557,1290.88 538.566,1290.88 538.575,1290.88 538.585,1290.88 538.594,1290.87 538.603,1290.87 538.612,1290.87 538.621,1290.87 538.631,1290.87 538.64,1290.87 538.649,1290.87 538.658,1290.87 538.667,1290.87 538.676,1290.87 538.686,1290.87 538.695,1290.87 538.704,1290.87 538.713,1290.87 538.722,1290.87 538.732,1290.87 538.741,1290.87 538.75,1290.87 538.759,1290.87 538.768,1290.86 538.778,1290.86 538.787,1290.86 538.796,1290.86 538.805,1290.86 538.814,1290.86 538.823,1290.86 538.833,1290.86 538.842,1290.86 538.851,1290.86 538.86,1290.86 538.869,1290.86 538.879,1290.86 538.888,1290.86 538.897,1290.86 538.906,1290.86 538.915,1290.86 538.925,1290.86 538.934,1290.86 538.943,1290.85 538.952,1290.85 538.961,1290.85 538.971,1290.85 538.98,1290.85 538.989,1290.85 538.998,1290.85 539.007,1290.85 539.016,1290.85 539.026,1290.85 539.035,1290.85 539.044,1290.85 539.053,1290.85 539.062,1290.85 539.072,1290.85 539.081,1290.85 539.09,1290.85 539.099,1290.85 539.108,1290.85 539.118,1290.84 539.127,1290.84 539.136,1290.84 539.145,1290.84 539.154,1290.84 539.163,1290.84 539.173,1290.84 539.182,1290.84 539.191,1290.84 539.2,1290.84 539.209,1290.84 539.219,1290.84 539.228,1290.84 539.237,1290.84 539.246,1290.84 539.255,1290.84 539.265,1290.84 539.274,1290.84 539.283,1290.84 539.292,1290.83 539.301,1290.83 539.311,1290.83 539.32,1290.83 539.329,1290.83 539.338,1290.83 539.347,1290.83 539.356,1290.83 539.366,1290.83 539.375,1290.83 539.384,1290.83 539.393,1290.83 539.402,1290.83 539.412,1290.83 539.421,1290.83 539.43,1290.83 539.439,1290.83 539.448,1290.83 539.458,1290.83 539.467,1290.82 539.476,1290.82 539.485,1290.82 539.494,1290.82 539.503,1290.82 539.513,1290.82 539.522,1290.82 539.531,1290.82 539.54,1290.82 539.549,1290.82 539.559,1290.82 539.568,1290.82 539.577,1290.82 539.586,1290.82 539.595,1290.82 539.605,1290.82 539.614,1290.82 539.623,1290.82 539.632,1290.82 539.641,1290.82 539.651,1290.81 539.66,1290.81 539.669,1290.81 539.678,1290.81 539.687,1290.81 539.696,1290.81 539.706,1290.81 539.715,1290.81 539.724,1290.81 539.733,1290.81 539.742,1290.81 539.752,1290.81 539.761,1290.81 539.77,1290.81 539.779,1290.81 539.788,1290.81 539.798,1290.81 539.807,1290.81 539.816,1290.81 539.825,1290.8 539.834,1290.8 539.843,1290.8 539.853,1290.8 539.862,1290.8 539.871,1290.8 539.88,1290.8 539.889,1290.8 539.899,1290.8 539.908,1290.8 539.917,1290.8 539.926,1290.8 539.935,1290.8 539.945,1290.8 539.954,1290.8 539.963,1290.8 539.972,1290.8 539.981,1290.8 539.991,1290.8 540,1290.8 540.009,1290.79 540.018,1290.79 540.027,1290.79 540.036,1290.79 540.046,1290.79 540.055,1290.79 540.064,1290.79 540.073,1290.79 540.082,1290.79 540.092,1290.79 540.101,1290.79 540.11,1290.79 540.119,1290.79 540.128,1290.79 540.138,1290.79 540.147,1290.79 540.156,1290.79 540.165,1290.79 540.174,1290.79 540.183,1290.78 540.193,1290.78 540.202,1290.78 540.211,1290.78 540.22,1290.78 540.229,1290.78 540.239,1290.78 540.248,1290.78 540.257,1290.78 540.266,1290.78 540.275,1290.78 540.285,1290.78 540.294,1290.78 540.303,1290.78 540.312,1290.78 540.321,1290.78 540.331,1290.78 540.34,1290.78 540.349,1290.78 540.358,1290.78 540.367,1290.77 540.376,1290.77 540.386,1290.77 540.395,1290.77 540.404,1290.77 540.413,1290.77 540.422,1290.77 540.432,1290.77 540.441,1290.77 540.45,1290.77 540.459,1290.77 540.468,1290.77 540.478,1290.77 540.487,1290.77 540.496,1290.77 540.505,1290.77 540.514,1290.77 540.523,1290.77 540.533,1290.77 540.542,1290.76 540.551,1290.76 540.56,1290.76 540.569,1290.76 540.579,1290.76 540.588,1290.76 540.597,1290.76 540.606,1290.76 540.615,1290.76 540.625,1290.76 540.634,1290.76 540.643,1290.76 540.652,1290.76 540.661,1290.76 540.671,1290.76 540.68,1290.76 540.689,1290.76 540.698,1290.76 540.707,1290.76 540.716,1290.76 540.726,1290.75 540.735,1290.75 540.744,1290.75 540.753,1290.75 540.762,1290.75 540.772,1290.75 540.781,1290.75 540.79,1290.75 540.799,1290.75 540.808,1290.75 540.818,1290.75 540.827,1290.75 540.836,1290.75 540.845,1290.75 540.854,1290.75 540.863,1290.75 540.873,1290.75 540.882,1290.75 540.891,1290.75 540.9,1290.75 540.909,1290.74 540.919,1290.74 540.928,1290.74 540.937,1290.74 540.946,1290.74 540.955,1290.74 540.965,1290.74 540.974,1290.74 540.983,1290.74 540.992,1290.74 541.001,1290.74 541.011,1290.74 541.02,1290.74 541.029,1290.74 541.038,1290.74 541.047,1290.74 541.056,1290.74 541.066,1290.74 541.075,1290.74 541.084,1290.73 541.093,1290.73 541.102,1290.73 541.112,1290.73 541.121,1290.73 541.13,1290.73 541.139,1290.73 541.148,1290.73 541.158,1290.73 541.167,1290.73 541.176,1290.73 541.185,1290.73 541.194,1290.73 541.204,1290.73 541.213,1290.73 541.222,1290.73 541.231,1290.73 541.24,1290.73 541.249,1290.73 541.259,1290.73 541.268,1290.72 541.277,1290.72 541.286,1290.72 541.295,1290.72 541.305,1290.72 541.314,1290.72 541.323,1290.72 541.332,1290.72 541.341,1290.72 541.351,1290.72 541.36,1290.72 541.369,1290.72 541.378,1290.72 541.387,1290.72 541.396,1290.72 541.406,1290.72 541.415,1290.72 541.424,1290.72 541.433,1290.72 541.442,1290.72 541.452,1290.71 541.461,1290.71 541.47,1290.71 541.479,1290.71 541.488,1290.71 541.498,1290.71 541.507,1290.71 541.516,1290.71 541.525,1290.71 541.534,1290.71 541.544,1290.71 541.553,1290.71 541.562,1290.71 541.571,1290.71 541.58,1290.71 541.589,1290.71 541.599,1290.71 541.608,1290.71 541.617,1290.71 541.626,1290.71 541.635,1290.7 541.645,1290.7 541.654,1290.7 541.663,1290.7 541.672,1290.7 541.681,1290.7 541.691,1290.7 541.7,1290.7 541.709,1290.7 541.718,1290.7 541.727,1290.7 541.736,1290.7 541.746,1290.7 541.755,1290.7 541.764,1290.7 541.773,1290.7 541.782,1290.7 541.792,1290.7 541.801,1290.7 541.81,1290.7 541.819,1290.69 541.828,1290.69 541.838,1290.69 541.847,1290.69 541.856,1290.69 541.865,1290.69 541.874,1290.69 541.884,1290.69 541.893,1290.69 541.902,1290.69 541.911,1290.69 541.92,1290.69 541.929,1290.69 541.939,1290.69 541.948,1290.69 541.957,1290.69 541.966,1290.69 541.975,1290.69 541.985,1290.69 541.994,1290.69 542.003,1290.68 542.012,1290.68 542.021,1290.68 542.031,1290.68 542.04,1290.68 542.049,1290.68 542.058,1290.68 542.067,1290.68 542.076,1290.68 542.086,1290.68 542.095,1290.68 542.104,1290.68 542.113,1290.68 542.122,1290.68 542.132,1290.68 542.141,1290.68 542.15,1290.68 542.159,1290.68 542.168,1290.68 542.178,1290.68 542.187,1290.67 542.196,1290.67 542.205,1290.67 542.214,1290.67 542.224,1290.67 542.233,1290.67 542.242,1290.67 542.251,1290.67 542.26,1290.67 542.269,1290.67 542.279,1290.67 542.288,1290.67 542.297,1290.67 542.306,1290.67 542.315,1290.67 542.325,1290.67 542.334,1290.67 542.343,1290.67 542.352,1290.67 542.361,1290.67 542.371,1290.67 542.38,1290.66 542.389,1290.66 542.398,1290.66 542.407,1290.66 542.416,1290.66 542.426,1290.66 542.435,1290.66 542.444,1290.66 542.453,1290.66 542.462,1290.66 542.472,1290.66 542.481,1290.66 542.49,1290.66 542.499,1290.66 542.508,1290.66 542.518,1290.66 542.527,1290.66 542.536,1290.66 542.545,1290.66 542.554,1290.66 542.564,1290.65 542.573,1290.65 542.582,1290.65 542.591,1290.65 542.6,1290.65 542.609,1290.65 542.619,1290.65 542.628,1290.65 542.637,1290.65 542.646,1290.65 542.655,1290.65 542.665,1290.65 542.674,1290.65 542.683,1290.65 542.692,1290.65 542.701,1290.65 542.711,1290.65 542.72,1290.65 542.729,1290.65 542.738,1290.65 542.747,1290.64 542.756,1290.64 542.766,1290.64 542.775,1290.64 542.784,1290.64 542.793,1290.64 542.802,1290.64 542.812,1290.64 542.821,1290.64 542.83,1290.64 542.839,1290.64 542.848,1290.64 542.858,1290.64 542.867,1290.64 542.876,1290.64 542.885,1290.64 542.894,1290.64 542.904,1290.64 542.913,1290.64 542.922,1290.64 542.931,1290.63 542.94,1290.63 542.949,1290.63 542.959,1290.63 542.968,1290.63 542.977,1290.63 542.986,1290.63 542.995,1290.63 543.005,1290.63 543.014,1290.63 543.023,1290.63 543.032,1290.63 543.041,1290.63 543.051,1290.63 543.06,1290.63 543.069,1290.63 543.078,1290.63 543.087,1290.63 543.096,1290.63 543.106,1290.63 543.115,1290.63 543.124,1290.62 543.133,1290.62 543.142,1290.62 543.152,1290.62 543.161,1290.62 543.17,1290.62 543.179,1290.62 543.188,1290.62 543.198,1290.62 543.207,1290.62 543.216,1290.62 543.225,1290.62 543.234,1290.62 543.244,1290.62 543.253,1290.62 543.262,1290.62 543.271,1290.62 543.28,1290.62 543.289,1290.62 543.299,1290.62 543.308,1290.61 543.317,1290.61 543.326,1290.61 543.335,1290.61 543.345,1290.61 543.354,1290.61 543.363,1290.61 543.372,1290.61 543.381,1290.61 543.391,1290.61 543.4,1290.61 543.409,1290.61 543.418,1290.61 543.427,1290.61 543.436,1290.61 543.446,1290.61 543.455,1290.61 543.464,1290.61 543.473,1290.61 543.482,1290.61 543.492,1290.61 543.501,1290.6 543.51,1290.6 543.519,1290.6 543.528,1290.6 543.538,1290.6 543.547,1290.6 543.556,1290.6 543.565,1290.6 543.574,1290.6 543.584,1290.6 543.593,1290.6 543.602,1290.6 543.611,1290.6 543.62,1290.6 543.629,1290.6 543.639,1290.6 543.648,1290.6 543.657,1290.6 543.666,1290.6 543.675,1290.6 543.685,1290.6 543.694,1290.59 543.703,1290.59 543.712,1290.59 543.721,1290.59 543.731,1290.59 543.74,1290.59 543.749,1290.59 543.758,1290.59 543.767,1290.59 543.777,1290.59 543.786,1290.59 543.795,1290.59 543.804,1290.59 543.813,1290.59 543.822,1290.59 543.832,1290.59 543.841,1290.59 543.85,1290.59 543.859,1290.59 543.868,1290.59 543.878,1290.58 543.887,1290.58 543.896,1290.58 543.905,1290.58 543.914,1290.58 543.924,1290.58 543.933,1290.58 543.942,1290.58 543.951,1290.58 543.96,1290.58 543.969,1290.58 543.979,1290.58 543.988,1290.58 543.997,1290.58 544.006,1290.58 544.015,1290.58 544.025,1290.58 544.034,1290.58 544.043,1290.58 544.052,1290.58 544.061,1290.58 544.071,1290.57 544.08,1290.57 544.089,1290.57 544.098,1290.57 544.107,1290.57 544.117,1290.57 544.126,1290.57 544.135,1290.57 544.144,1290.57 544.153,1290.57 544.162,1290.57 544.172,1290.57 544.181,1290.57 544.19,1290.57 544.199,1290.57 544.208,1290.57 544.218,1290.57 544.227,1290.57 544.236,1290.57 544.245,1290.57 544.254,1290.57 544.264,1290.56 544.273,1290.56 544.282,1290.56 544.291,1290.56 544.3,1290.56 544.309,1290.56 544.319,1290.56 544.328,1290.56 544.337,1290.56 544.346,1290.56 544.355,1290.56 544.365,1290.56 544.374,1290.56 544.383,1290.56 544.392,1290.56 544.401,1290.56 544.411,1290.56 544.42,1290.56 544.429,1290.56 544.438,1290.56 544.447,1290.56 544.457,1290.55 544.466,1290.55 544.475,1290.55 544.484,1290.55 544.493,1290.55 544.502,1290.55 544.512,1290.55 544.521,1290.55 544.53,1290.55 544.539,1290.55 544.548,1290.55 544.558,1290.55 544.567,1290.55 544.576,1290.55 544.585,1290.55 544.594,1290.55 544.604,1290.55 544.613,1290.55 544.622,1290.55 544.631,1290.55 544.64,1290.55 544.649,1290.54 544.659,1290.54 544.668,1290.54 544.677,1290.54 544.686,1290.54 544.695,1290.54 544.705,1290.54 544.714,1290.54 544.723,1290.54 544.732,1290.54 544.741,1290.54 544.751,1290.54 544.76,1290.54 544.769,1290.54 544.778,1290.54 544.787,1290.54 544.797,1290.54 544.806,1290.54 544.815,1290.54 544.824,1290.54 544.833,1290.54 544.842,1290.53 544.852,1290.53 544.861,1290.53 544.87,1290.53 544.879,1290.53 544.888,1290.53 544.898,1290.53 544.907,1290.53 544.916,1290.53 544.925,1290.53 544.934,1290.53 544.944,1290.53 544.953,1290.53 544.962,1290.53 544.971,1290.53 544.98,1290.53 544.989,1290.53 544.999,1290.53 545.008,1290.53 545.017,1290.53 545.026,1290.53 545.035,1290.52 545.045,1290.52 545.054,1290.52 545.063,1290.52 545.072,1290.52 545.081,1290.52 545.091,1290.52 545.1,1290.52 545.109,1290.52 545.118,1290.52 545.127,1290.52 545.137,1290.52 545.146,1290.52 545.155,1290.52 545.164,1290.52 545.173,1290.52 545.182,1290.52 545.192,1290.52 545.201,1290.52 545.21,1290.52 545.219,1290.52 545.228,1290.51 545.238,1290.51 545.247,1290.51 545.256,1290.51 545.265,1290.51 545.274,1290.51 545.284,1290.51 545.293,1290.51 545.302,1290.51 545.311,1290.51 545.32,1290.51 545.329,1290.51 545.339,1290.51 545.348,1290.51 545.357,1290.51 545.366,1290.51 545.375,1290.51 545.385,1290.51 545.394,1290.51 545.403,1290.51 545.412,1290.51 545.421,1290.5 545.431,1290.5 545.44,1290.5 545.449,1290.5 545.458,1290.5 545.467,1290.5 545.477,1290.5 545.486,1290.5 545.495,1290.5 545.504,1290.5 545.513,1290.5 545.522,1290.5 545.532,1290.5 545.541,1290.5 545.55,1290.5 545.559,1290.5 545.568,1290.5 545.578,1290.5 545.587,1290.5 545.596,1290.5 545.605,1290.5 545.614,1290.49 545.624,1290.49 545.633,1290.49 545.642,1290.49 545.651,1290.49 545.66,1290.49 545.669,1290.49 545.679,1290.49 545.688,1290.49 545.697,1290.49 545.706,1290.49 545.715,1290.49 545.725,1290.49 545.734,1290.49 545.743,1290.49 545.752,1290.49 545.761,1290.49 545.771,1290.49 545.78,1290.49 545.789,1290.49 545.798,1290.49 545.807,1290.49 545.817,1290.48 545.826,1290.48 545.835,1290.48 545.844,1290.48 545.853,1290.48 545.862,1290.48 545.872,1290.48 545.881,1290.48 545.89,1290.48 545.899,1290.48 545.908,1290.48 545.918,1290.48 545.927,1290.48 545.936,1290.48 545.945,1290.48 545.954,1290.48 545.964,1290.48 545.973,1290.48 545.982,1290.48 545.991,1290.48 546,1290.48 546.01,1290.47 546.019,1290.47 546.028,1290.47 546.037,1290.47 546.046,1290.47 546.055,1290.47 546.065,1290.47 546.074,1290.47 546.083,1290.47 546.092,1290.47 546.101,1290.47 546.111,1290.47 546.12,1290.47 546.129,1290.47 546.138,1290.47 546.147,1290.47 546.157,1290.47 546.166,1290.47 546.175,1290.47 546.184,1290.47 546.193,1290.47 546.202,1290.47 546.212,1290.46 546.221,1290.46 546.23,1290.46 546.239,1290.46 546.248,1290.46 546.258,1290.46 546.267,1290.46 546.276,1290.46 546.285,1290.46 546.294,1290.46 546.304,1290.46 546.313,1290.46 546.322,1290.46 546.331,1290.46 546.34,1290.46 546.35,1290.46 546.359,1290.46 546.368,1290.46 546.377,1290.46 546.386,1290.46 546.395,1290.46 546.405,1290.45 546.414,1290.45 546.423,1290.45 546.432,1290.45 546.441,1290.45 546.451,1290.45 546.46,1290.45 546.469,1290.45 546.478,1290.45 546.487,1290.45 546.497,1290.45 546.506,1290.45 546.515,1290.45 546.524,1290.45 546.533,1290.45 546.542,1290.45 546.552,1290.45 546.561,1290.45 546.57,1290.45 546.579,1290.45 546.588,1290.45 546.598,1290.45 546.607,1290.44 546.616,1290.44 546.625,1290.44 546.634,1290.44 546.644,1290.44 546.653,1290.44 546.662,1290.44 546.671,1290.44 546.68,1290.44 546.69,1290.44 546.699,1290.44 546.708,1290.44 546.717,1290.44 546.726,1290.44 546.735,1290.44 546.745,1290.44 546.754,1290.44 546.763,1290.44 546.772,1290.44 546.781,1290.44 546.791,1290.44 546.8,1290.44 546.809,1290.43 546.818,1290.43 546.827,1290.43 546.837,1290.43 546.846,1290.43 546.855,1290.43 546.864,1290.43 546.873,1290.43 546.882,1290.43 546.892,1290.43 546.901,1290.43 546.91,1290.43 546.919,1290.43 546.928,1290.43 546.938,1290.43 546.947,1290.43 546.956,1290.43 546.965,1290.43 546.974,1290.43 546.984,1290.43 546.993,1290.43 547.002,1290.42 547.011,1290.42 547.02,1290.42 547.03,1290.42 547.039,1290.42 547.048,1290.42 547.057,1290.42 547.066,1290.42 547.075,1290.42 547.085,1290.42 547.094,1290.42 547.103,1290.42 547.112,1290.42 547.121,1290.42 547.131,1290.42 547.14,1290.42 547.149,1290.42 547.158,1290.42 547.167,1290.42 547.177,1290.42 547.186,1290.42 547.195,1290.42 547.204,1290.41 547.213,1290.41 547.222,1290.41 547.232,1290.41 547.241,1290.41 547.25,1290.41 547.259,1290.41 547.268,1290.41 547.278,1290.41 547.287,1290.41 547.296,1290.41 547.305,1290.41 547.314,1290.41 547.324,1290.41 547.333,1290.41 547.342,1290.41 547.351,1290.41 547.36,1290.41 547.37,1290.41 547.379,1290.41 547.388,1290.41 547.397,1290.41 547.406,1290.4 547.415,1290.4 547.425,1290.4 547.434,1290.4 547.443,1290.4 547.452,1290.4 547.461,1290.4 547.471,1290.4 547.48,1290.4 547.489,1290.4 547.498,1290.4 547.507,1290.4 547.517,1290.4 547.526,1290.4 547.535,1290.4 547.544,1290.4 547.553,1290.4 547.562,1290.4 547.572,1290.4 547.581,1290.4 547.59,1290.4 547.599,1290.4 547.608,1290.39 547.618,1290.39 547.627,1290.39 547.636,1290.39 547.645,1290.39 547.654,1290.39 547.664,1290.39 547.673,1290.39 547.682,1290.39 547.691,1290.39 547.7,1290.39 547.71,1290.39 547.719,1290.39 547.728,1290.39 547.737,1290.39 547.746,1290.39 547.755,1290.39 547.765,1290.39 547.774,1290.39 547.783,1290.39 547.792,1290.39 547.801,1290.39 547.811,1290.38 547.82,1290.38 547.829,1290.38 547.838,1290.38 547.847,1290.38 547.857,1290.38 547.866,1290.38 547.875,1290.38 547.884,1290.38 547.893,1290.38 547.902,1290.38 547.912,1290.38 547.921,1290.38 547.93,1290.38 547.939,1290.38 547.948,1290.38 547.958,1290.38 547.967,1290.38 547.976,1290.38 547.985,1290.38 547.994,1290.38 548.004,1290.38 548.013,1290.37 548.022,1290.37 548.031,1290.37 548.04,1290.37 548.05,1290.37 548.059,1290.37 548.068,1290.37 548.077,1290.37 548.086,1290.37 548.095,1290.37 548.105,1290.37 548.114,1290.37 548.123,1290.37 548.132,1290.37 548.141,1290.37 548.151,1290.37 548.16,1290.37 548.169,1290.37 548.178,1290.37 548.187,1290.37 548.197,1290.37 548.206,1290.37 548.215,1290.37 548.224,1290.36 548.233,1290.36 548.242,1290.36 548.252,1290.36 548.261,1290.36 548.27,1290.36 548.279,1290.36 548.288,1290.36 548.298,1290.36 548.307,1290.36 548.316,1290.36 548.325,1290.36 548.334,1290.36 548.344,1290.36 548.353,1290.36 548.362,1290.36 548.371,1290.36 548.38,1290.36 548.39,1290.36 548.399,1290.36 548.408,1290.36 548.417,1290.36 548.426,1290.35 548.435,1290.35 548.445,1290.35 548.454,1290.35 548.463,1290.35 548.472,1290.35 548.481,1290.35 548.491,1290.35 548.5,1290.35 548.509,1290.35 548.518,1290.35 548.527,1290.35 548.537,1290.35 548.546,1290.35 548.555,1290.35 548.564,1290.35 548.573,1290.35 548.583,1290.35 548.592,1290.35 548.601,1290.35 548.61,1290.35 548.619,1290.35 548.628,1290.34 548.638,1290.34 548.647,1290.34 548.656,1290.34 548.665,1290.34 548.674,1290.34 548.684,1290.34 548.693,1290.34 548.702,1290.34 548.711,1290.34 548.72,1290.34 548.73,1290.34 548.739,1290.34 548.748,1290.34 548.757,1290.34 548.766,1290.34 548.775,1290.34 548.785,1290.34 548.794,1290.34 548.803,1290.34 548.812,1290.34 548.821,1290.34 548.831,1290.34 548.84,1290.33 548.849,1290.33 548.858,1290.33 548.867,1290.33 548.877,1290.33 548.886,1290.33 548.895,1290.33 548.904,1290.33 548.913,1290.33 548.923,1290.33 548.932,1290.33 548.941,1290.33 548.95,1290.33 548.959,1290.33 548.968,1290.33 548.978,1290.33 548.987,1290.33 548.996,1290.33 549.005,1290.33 549.014,1290.33 549.024,1290.33 549.033,1290.33 549.042,1290.32 549.051,1290.32 549.06,1290.32 549.07,1290.32 549.079,1290.32 549.088,1290.32 549.097,1290.32 549.106,1290.32 549.115,1290.32 549.125,1290.32 549.134,1290.32 549.143,1290.32 549.152,1290.32 549.161,1290.32 549.171,1290.32 549.18,1290.32 549.189,1290.32 549.198,1290.32 549.207,1290.32 549.217,1290.32 549.226,1290.32 549.235,1290.32 549.244,1290.32 549.253,1290.31 549.263,1290.31 549.272,1290.31 549.281,1290.31 549.29,1290.31 549.299,1290.31 549.308,1290.31 549.318,1290.31 549.327,1290.31 549.336,1290.31 549.345,1290.31 549.354,1290.31 549.364,1290.31 549.373,1290.31 549.382,1290.31 549.391,1290.31 549.4,1290.31 549.41,1290.31 549.419,1290.31 549.428,1290.31 549.437,1290.31 549.446,1290.31 549.455,1290.31 549.465,1290.3 549.474,1290.3 549.483,1290.3 549.492,1290.3 549.501,1290.3 549.511,1290.3 549.52,1290.3 549.529,1290.3 549.538,1290.3 549.547,1290.3 549.557,1290.3 549.566,1290.3 549.575,1290.3 549.584,1290.3 549.593,1290.3 549.603,1290.3 549.612,1290.3 549.621,1290.3 549.63,1290.3 549.639,1290.3 549.648,1290.3 549.658,1290.3 549.667,1290.29 549.676,1290.29 549.685,1290.29 549.694,1290.29 549.704,1290.29 549.713,1290.29 549.722,1290.29 549.731,1290.29 549.74,1290.29 549.75,1290.29 549.759,1290.29 549.768,1290.29 549.777,1290.29 549.786,1290.29 549.795,1290.29 549.805,1290.29 549.814,1290.29 549.823,1290.29 549.832,1290.29 549.841,1290.29 549.851,1290.29 549.86,1290.29 549.869,1290.29 549.878,1290.28 549.887,1290.28 549.897,1290.28 549.906,1290.28 549.915,1290.28 549.924,1290.28 549.933,1290.28 549.943,1290.28 549.952,1290.28 549.961,1290.28 549.97,1290.28 549.979,1290.28 549.988,1290.28 549.998,1290.28 550.007,1290.28 550.016,1290.28 550.025,1290.28 550.034,1290.28 550.044,1290.28 550.053,1290.28 550.062,1290.28 550.071,1290.28 550.08,1290.28 550.09,1290.27 550.099,1290.27 550.108,1290.27 550.117,1290.27 550.126,1290.27 550.135,1290.27 550.145,1290.27 550.154,1290.27 550.163,1290.27 550.172,1290.27 550.181,1290.27 550.191,1290.27 550.2,1290.27 550.209,1290.27 550.218,1290.27 550.227,1290.27 550.237,1290.27 550.246,1290.27 550.255,1290.27 550.264,1290.27 550.273,1290.27 550.283,1290.27 550.292,1290.27 550.301,1290.26 550.31,1290.26 550.319,1290.26 550.328,1290.26 550.338,1290.26 550.347,1290.26 550.356,1290.26 550.365,1290.26 550.374,1290.26 550.384,1290.26 550.393,1290.26 550.402,1290.26 550.411,1290.26 550.42,1290.26 550.43,1290.26 550.439,1290.26 550.448,1290.26 550.457,1290.26 550.466,1290.26 550.475,1290.26 550.485,1290.26 550.494,1290.26 550.503,1290.26 550.512,1290.25 550.521,1290.25 550.531,1290.25 550.54,1290.25 550.549,1290.25 550.558,1290.25 550.567,1290.25 550.577,1290.25 550.586,1290.25 550.595,1290.25 550.604,1290.25 550.613,1290.25 550.623,1290.25 550.632,1290.25 550.641,1290.25 550.65,1290.25 550.659,1290.25 550.668,1290.25 550.678,1290.25 550.687,1290.25 550.696,1290.25 550.705,1290.25 550.714,1290.25 550.724,1290.25 550.733,1290.24 550.742,1290.24 550.751,1290.24 550.76,1290.24 550.77,1290.24 550.779,1290.24 550.788,1290.24 550.797,1290.24 550.806,1290.24 550.815,1290.24 550.825,1290.24 550.834,1290.24 550.843,1290.24 550.852,1290.24 550.861,1290.24 550.871,1290.24 550.88,1290.24 550.889,1290.24 550.898,1290.24 550.907,1290.24 550.917,1290.24 550.926,1290.24 550.935,1290.24 550.944,1290.23 550.953,1290.23 550.963,1290.23 550.972,1290.23 550.981,1290.23 550.99,1290.23 550.999,1290.23 551.008,1290.23 551.018,1290.23 551.027,1290.23 551.036,1290.23 551.045,1290.23 551.054,1290.23 551.064,1290.23 551.073,1290.23 551.082,1290.23 551.091,1290.23 551.1,1290.23 551.11,1290.23 551.119,1290.23 551.128,1290.23 551.137,1290.23 551.146,1290.23 551.156,1290.22 551.165,1290.22 551.174,1290.22 551.183,1290.22 551.192,1290.22 551.201,1290.22 551.211,1290.22 551.22,1290.22 551.229,1290.22 551.238,1290.22 551.247,1290.22 551.257,1290.22 551.266,1290.22 551.275,1290.22 551.284,1290.22 551.293,1290.22 551.303,1290.22 551.312,1290.22 551.321,1290.22 551.33,1290.22 551.339,1290.22 551.348,1290.22 551.358,1290.22 551.367,1290.22 551.376,1290.21 551.385,1290.21 551.394,1290.21 551.404,1290.21 551.413,1290.21 551.422,1290.21 551.431,1290.21 551.44,1290.21 551.45,1290.21 551.459,1290.21 551.468,1290.21 551.477,1290.21 551.486,1290.21 551.496,1290.21 551.505,1290.21 551.514,1290.21 551.523,1290.21 551.532,1290.21 551.541,1290.21 551.551,1290.21 551.56,1290.21 551.569,1290.21 551.578,1290.21 551.587,1290.2 551.597,1290.2 551.606,1290.2 551.615,1290.2 551.624,1290.2 551.633,1290.2 551.643,1290.2 551.652,1290.2 551.661,1290.2 551.67,1290.2 551.679,1290.2 551.688,1290.2 551.698,1290.2 551.707,1290.2 551.716,1290.2 551.725,1290.2 551.734,1290.2 551.744,1290.2 551.753,1290.2 551.762,1290.2 551.771,1290.2 551.78,1290.2 551.79,1290.2 551.799,1290.2 551.808,1290.19 551.817,1290.19 551.826,1290.19 551.836,1290.19 551.845,1290.19 551.854,1290.19 551.863,1290.19 551.872,1290.19 551.881,1290.19 551.891,1290.19 551.9,1290.19 551.909,1290.19 551.918,1290.19 551.927,1290.19 551.937,1290.19 551.946,1290.19 551.955,1290.19 551.964,1290.19 551.973,1290.19 551.983,1290.19 551.992,1290.19 552.001,1290.19 552.01,1290.19 552.019,1290.19 552.028,1290.18 552.038,1290.18 552.047,1290.18 552.056,1290.18 552.065,1290.18 552.074,1290.18 552.084,1290.18 552.093,1290.18 552.102,1290.18 552.111,1290.18 552.12,1290.18 552.13,1290.18 552.139,1290.18 552.148,1290.18 552.157,1290.18 552.166,1290.18 552.176,1290.18 552.185,1290.18 552.194,1290.18 552.203,1290.18 552.212,1290.18 552.221,1290.18 552.231,1290.18 552.24,1290.17 552.249,1290.17 552.258,1290.17 552.267,1290.17 552.277,1290.17 552.286,1290.17 552.295,1290.17 552.304,1290.17 552.313,1290.17 552.323,1290.17 552.332,1290.17 552.341,1290.17 552.35,1290.17 552.359,1290.17 552.368,1290.17 552.378,1290.17 552.387,1290.17 552.396,1290.17 552.405,1290.17 552.414,1290.17 552.424,1290.17 552.433,1290.17 552.442,1290.17 552.451,1290.17 552.46,1290.16 552.47,1290.16 552.479,1290.16 552.488,1290.16 552.497,1290.16 552.506,1290.16 552.516,1290.16 552.525,1290.16 552.534,1290.16 552.543,1290.16 552.552,1290.16 552.561,1290.16 552.571,1290.16 552.58,1290.16 552.589,1290.16 552.598,1290.16 552.607,1290.16 552.617,1290.16 552.626,1290.16 552.635,1290.16 552.644,1290.16 552.653,1290.16 552.663,1290.16 552.672,1290.16 552.681,1290.15 552.69,1290.15 552.699,1290.15 552.708,1290.15 552.718,1290.15 552.727,1290.15 552.736,1290.15 552.745,1290.15 552.754,1290.15 552.764,1290.15 552.773,1290.15 552.782,1290.15 552.791,1290.15 552.8,1290.15 552.81,1290.15 552.819,1290.15 552.828,1290.15 552.837,1290.15 552.846,1290.15 552.856,1290.15 552.865,1290.15 552.874,1290.15 552.883,1290.15 552.892,1290.15 552.901,1290.14 552.911,1290.14 552.92,1290.14 552.929,1290.14 552.938,1290.14 552.947,1290.14 552.957,1290.14 552.966,1290.14 552.975,1290.14 552.984,1290.14 552.993,1290.14 553.003,1290.14 553.012,1290.14 553.021,1290.14 553.03,1290.14 553.039,1290.14 553.048,1290.14 553.058,1290.14 553.067,1290.14 553.076,1290.14 553.085,1290.14 553.094,1290.14 553.104,1290.14 553.113,1290.14 553.122,1290.14 553.131,1290.13 553.14,1290.13 553.15,1290.13 553.159,1290.13 553.168,1290.13 553.177,1290.13 553.186,1290.13 553.196,1290.13 553.205,1290.13 553.214,1290.13 553.223,1290.13 553.232,1290.13 553.241,1290.13 553.251,1290.13 553.26,1290.13 553.269,1290.13 553.278,1290.13 553.287,1290.13 553.297,1290.13 553.306,1290.13 553.315,1290.13 553.324,1290.13 553.333,1290.13 553.343,1290.13 553.352,1290.12 553.361,1290.12 553.37,1290.12 553.379,1290.12 553.389,1290.12 553.398,1290.12 553.407,1290.12 553.416,1290.12 553.425,1290.12 553.434,1290.12 553.444,1290.12 553.453,1290.12 553.462,1290.12 553.471,1290.12 553.48,1290.12 553.49,1290.12 553.499,1290.12 553.508,1290.12 553.517,1290.12 553.526,1290.12 553.536,1290.12 553.545,1290.12 553.554,1290.12 553.563,1290.12 553.572,1290.11 553.581,1290.11 553.591,1290.11 553.6,1290.11 553.609,1290.11 553.618,1290.11 553.627,1290.11 553.637,1290.11 553.646,1290.11 553.655,1290.11 553.664,1290.11 553.673,1290.11 553.683,1290.11 553.692,1290.11 553.701,1290.11 553.71,1290.11 553.719,1290.11 553.729,1290.11 553.738,1290.11 553.747,1290.11 553.756,1290.11 553.765,1290.11 553.774,1290.11 553.784,1290.11 553.793,1290.11 553.802,1290.1 553.811,1290.1 553.82,1290.1 553.83,1290.1 553.839,1290.1 553.848,1290.1 553.857,1290.1 553.866,1290.1 553.876,1290.1 553.885,1290.1 553.894,1290.1 553.903,1290.1 553.912,1290.1 553.921,1290.1 553.931,1290.1 553.94,1290.1 553.949,1290.1 553.958,1290.1 553.967,1290.1 553.977,1290.1 553.986,1290.1 553.995,1290.1 554.004,1290.1 554.013,1290.1 554.023,1290.09 554.032,1290.09 554.041,1290.09 554.05,1290.09 554.059,1290.09 554.069,1290.09 554.078,1290.09 554.087,1290.09 554.096,1290.09 554.105,1290.09 554.114,1290.09 554.124,1290.09 554.133,1290.09 554.142,1290.09 554.151,1290.09 554.16,1290.09 554.17,1290.09 554.179,1290.09 554.188,1290.09 554.197,1290.09 554.206,1290.09 554.216,1290.09 554.225,1290.09 554.234,1290.09 554.243,1290.09 554.252,1290.08 554.261,1290.08 554.271,1290.08 554.28,1290.08 554.289,1290.08 554.298,1290.08 554.307,1290.08 554.317,1290.08 554.326,1290.08 554.335,1290.08 554.344,1290.08 554.353,1290.08 554.363,1290.08 554.372,1290.08 554.381,1290.08 554.39,1290.08 554.399,1290.08 554.409,1290.08 554.418,1290.08 554.427,1290.08 554.436,1290.08 554.445,1290.08 554.454,1290.08 554.464,1290.08 554.473,1290.08 554.482,1290.07 554.491,1290.07 554.5,1290.07 554.51,1290.07 554.519,1290.07 554.528,1290.07 554.537,1290.07 554.546,1290.07 554.556,1290.07 554.565,1290.07 554.574,1290.07 554.583,1290.07 554.592,1290.07 554.601,1290.07 554.611,1290.07 554.62,1290.07 554.629,1290.07 554.638,1290.07 554.647,1290.07 554.657,1290.07 554.666,1290.07 554.675,1290.07 554.684,1290.07 554.693,1290.07 554.703,1290.07 554.712,1290.06 554.721,1290.06 554.73,1290.06 554.739,1290.06 554.749,1290.06 554.758,1290.06 554.767,1290.06 554.776,1290.06 554.785,1290.06 554.794,1290.06 554.804,1290.06 554.813,1290.06 554.822,1290.06 554.831,1290.06 554.84,1290.06 554.85,1290.06 554.859,1290.06 554.868,1290.06 554.877,1290.06 554.886,1290.06 554.896,1290.06 554.905,1290.06 554.914,1290.06 554.923,1290.06 554.932,1290.06 554.941,1290.05 554.951,1290.05 554.96,1290.05 554.969,1290.05 554.978,1290.05 554.987,1290.05 554.997,1290.05 555.006,1290.05 555.015,1290.05 555.024,1290.05 555.033,1290.05 555.043,1290.05 555.052,1290.05 555.061,1290.05 555.07,1290.05 555.079,1290.05 555.089,1290.05 555.098,1290.05 555.107,1290.05 555.116,1290.05 555.125,1290.05 555.134,1290.05 555.144,1290.05 555.153,1290.05 555.162,1290.05 555.171,1290.04 555.18,1290.04 555.19,1290.04 555.199,1290.04 555.208,1290.04 555.217,1290.04 555.226,1290.04 555.236,1290.04 555.245,1290.04 555.254,1290.04 555.263,1290.04 555.272,1290.04 555.281,1290.04 555.291,1290.04 555.3,1290.04 555.309,1290.04 555.318,1290.04 555.327,1290.04 555.337,1290.04 555.346,1290.04 555.355,1290.04 555.364,1290.04 555.373,1290.04 555.383,1290.04 555.392,1290.04 555.401,1290.03 555.41,1290.03 555.419,1290.03 555.429,1290.03 555.438,1290.03 555.447,1290.03 555.456,1290.03 555.465,1290.03 555.474,1290.03 555.484,1290.03 555.493,1290.03 555.502,1290.03 555.511,1290.03 555.52,1290.03 555.53,1290.03 555.539,1290.03 555.548,1290.03 555.557,1290.03 555.566,1290.03 555.576,1290.03 555.585,1290.03 555.594,1290.03 555.603,1290.03 555.612,1290.03 555.621,1290.03 555.631,1290.02 555.64,1290.02 555.649,1290.02 555.658,1290.02 555.667,1290.02 555.677,1290.02 555.686,1290.02 555.695,1290.02 555.704,1290.02 555.713,1290.02 555.723,1290.02 555.732,1290.02 555.741,1290.02 555.75,1290.02 555.759,1290.02 555.769,1290.02 555.778,1290.02 555.787,1290.02 555.796,1290.02 555.805,1290.02 555.814,1290.02 555.824,1290.02 555.833,1290.02 555.842,1290.02 555.851,1290.02 555.86,1290.02 555.87,1290.01 555.879,1290.01 555.888,1290.01 555.897,1290.01 555.906,1290.01 555.916,1290.01 555.925,1290.01 555.934,1290.01 555.943,1290.01 555.952,1290.01 555.962,1290.01 555.971,1290.01 555.98,1290.01 555.989,1290.01 555.998,1290.01 556.007,1290.01 556.017,1290.01 556.026,1290.01 556.035,1290.01 556.044,1290.01 556.053,1290.01 556.063,1290.01 556.072,1290.01 556.081,1290.01 556.09,1290.01 556.099,1290 556.109,1290 556.118,1290 556.127,1290 556.136,1290 556.145,1290 556.154,1290 556.164,1290 556.173,1290 556.182,1290 556.191,1290 556.2,1290 556.21,1290 556.219,1290 556.228,1290 556.237,1290 556.246,1290 556.256,1290 556.265,1290 556.274,1290 556.283,1290 556.292,1290 556.302,1290 556.311,1290 556.32,1290 556.329,1290 556.338,1289.99 556.347,1289.99 556.357,1289.99 556.366,1289.99 556.375,1289.99 556.384,1289.99 556.393,1289.99 556.403,1289.99 556.412,1289.99 556.421,1289.99 556.43,1289.99 556.439,1289.99 556.449,1289.99 556.458,1289.99 556.467,1289.99 556.476,1289.99 556.485,1289.99 556.494,1289.99 556.504,1289.99 556.513,1289.99 556.522,1289.99 556.531,1289.99 556.54,1289.99 556.55,1289.99 556.559,1289.99 556.568,1289.99 556.577,1289.98 556.586,1289.98 556.596,1289.98 556.605,1289.98 556.614,1289.98 556.623,1289.98 556.632,1289.98 556.642,1289.98 556.651,1289.98 556.66,1289.98 556.669,1289.98 556.678,1289.98 556.687,1289.98 556.697,1289.98 556.706,1289.98 556.715,1289.98 556.724,1289.98 556.733,1289.98 556.743,1289.98 556.752,1289.98 556.761,1289.98 556.77,1289.98 556.779,1289.98 556.789,1289.98 556.798,1289.98 556.807,1289.98 556.816,1289.97 556.825,1289.97 556.834,1289.97 556.844,1289.97 556.853,1289.97 556.862,1289.97 556.871,1289.97 556.88,1289.97 556.89,1289.97 556.899,1289.97 556.908,1289.97 556.917,1289.97 556.926,1289.97 556.936,1289.97 556.945,1289.97 556.954,1289.97 556.963,1289.97 556.972,1289.97 556.982,1289.97 556.991,1289.97 557,1289.97 557.009,1289.97 557.018,1289.97 557.027,1289.97 557.037,1289.97 557.046,1289.97 557.055,1289.96 557.064,1289.96 557.073,1289.96 557.083,1289.96 557.092,1289.96 557.101,1289.96 557.11,1289.96 557.119,1289.96 557.129,1289.96 557.138,1289.96 557.147,1289.96 557.156,1289.96 557.165,1289.96 557.174,1289.96 557.184,1289.96 557.193,1289.96 557.202,1289.96 557.211,1289.96 557.22,1289.96 557.23,1289.96 557.239,1289.96 557.248,1289.96 557.257,1289.96 557.266,1289.96 557.276,1289.96 557.285,1289.96 557.294,1289.95 557.303,1289.95 557.312,1289.95 557.322,1289.95 557.331,1289.95 557.34,1289.95 557.349,1289.95 557.358,1289.95 557.367,1289.95 557.377,1289.95 557.386,1289.95 557.395,1289.95 557.404,1289.95 557.413,1289.95 557.423,1289.95 557.432,1289.95 557.441,1289.95 557.45,1289.95 557.459,1289.95 557.469,1289.95 557.478,1289.95 557.487,1289.95 557.496,1289.95 557.505,1289.95 557.514,1289.95 557.524,1289.95 557.533,1289.94 557.542,1289.94 557.551,1289.94 557.56,1289.94 557.57,1289.94 557.579,1289.94 557.588,1289.94 557.597,1289.94 557.606,1289.94 557.616,1289.94 557.625,1289.94 557.634,1289.94 557.643,1289.94 557.652,1289.94 557.662,1289.94 557.671,1289.94 557.68,1289.94 557.689,1289.94 557.698,1289.94 557.707,1289.94 557.717,1289.94 557.726,1289.94 557.735,1289.94 557.744,1289.94 557.753,1289.94 557.763,1289.94 557.772,1289.93 557.781,1289.93 557.79,1289.93 557.799,1289.93 557.809,1289.93 557.818,1289.93 557.827,1289.93 557.836,1289.93 557.845,1289.93 557.854,1289.93 557.864,1289.93 557.873,1289.93 557.882,1289.93 557.891,1289.93 557.9,1289.93 557.91,1289.93 557.919,1289.93 557.928,1289.93 557.937,1289.93 557.946,1289.93 557.956,1289.93 557.965,1289.93 557.974,1289.93 557.983,1289.93 557.992,1289.93 558.002,1289.93 558.011,1289.93 558.02,1289.92 558.029,1289.92 558.038,1289.92 558.047,1289.92 558.057,1289.92 558.066,1289.92 558.075,1289.92 558.084,1289.92 558.093,1289.92 558.103,1289.92 558.112,1289.92 558.121,1289.92 558.13,1289.92 558.139,1289.92 558.149,1289.92 558.158,1289.92 558.167,1289.92 558.176,1289.92 558.185,1289.92 558.194,1289.92 558.204,1289.92 558.213,1289.92 558.222,1289.92 558.231,1289.92 558.24,1289.92 558.25,1289.92 558.259,1289.91 558.268,1289.91 558.277,1289.91 558.286,1289.91 558.296,1289.91 558.305,1289.91 558.314,1289.91 558.323,1289.91 558.332,1289.91 558.342,1289.91 558.351,1289.91 558.36,1289.91 558.369,1289.91 558.378,1289.91 558.387,1289.91 558.397,1289.91 558.406,1289.91 558.415,1289.91 558.424,1289.91 558.433,1289.91 558.443,1289.91 558.452,1289.91 558.461,1289.91 558.47,1289.91 558.479,1289.91 558.489,1289.91 558.498,1289.91 558.507,1289.9 558.516,1289.9 558.525,1289.9 558.535,1289.9 558.544,1289.9 558.553,1289.9 558.562,1289.9 558.571,1289.9 558.58,1289.9 558.59,1289.9 558.599,1289.9 558.608,1289.9 558.617,1289.9 558.626,1289.9 558.636,1289.9 558.645,1289.9 558.654,1289.9 558.663,1289.9 558.672,1289.9 558.682,1289.9 558.691,1289.9 558.7,1289.9 558.709,1289.9 558.718,1289.9 558.727,1289.9 558.737,1289.9 558.746,1289.9 558.755,1289.89 558.764,1289.89 558.773,1289.89 558.783,1289.89 558.792,1289.89 558.801,1289.89 558.81,1289.89 558.819,1289.89 558.829,1289.89 558.838,1289.89 558.847,1289.89 558.856,1289.89 558.865,1289.89 558.875,1289.89 558.884,1289.89 558.893,1289.89 558.902,1289.89 558.911,1289.89 558.92,1289.89 558.93,1289.89 558.939,1289.89 558.948,1289.89 558.957,1289.89 558.966,1289.89 558.976,1289.89 558.985,1289.89 558.994,1289.89 559.003,1289.88 559.012,1289.88 559.022,1289.88 559.031,1289.88 559.04,1289.88 559.049,1289.88 559.058,1289.88 559.067,1289.88 559.077,1289.88 559.086,1289.88 559.095,1289.88 559.104,1289.88 559.113,1289.88 559.123,1289.88 559.132,1289.88 559.141,1289.88 559.15,1289.88 559.159,1289.88 559.169,1289.88 559.178,1289.88 559.187,1289.88 559.196,1289.88 559.205,1289.88 559.215,1289.88 559.224,1289.88 559.233,1289.88 559.242,1289.88 559.251,1289.87 559.26,1289.87 559.27,1289.87 559.279,1289.87 559.288,1289.87 559.297,1289.87 559.306,1289.87 559.316,1289.87 559.325,1289.87 559.334,1289.87 559.343,1289.87 559.352,1289.87 559.362,1289.87 559.371,1289.87 559.38,1289.87 559.389,1289.87 559.398,1289.87 559.407,1289.87 559.417,1289.87 559.426,1289.87 559.435,1289.87 559.444,1289.87 559.453,1289.87 559.463,1289.87 559.472,1289.87 559.481,1289.87 559.49,1289.87 559.499,1289.86 559.509,1289.86 559.518,1289.86 559.527,1289.86 559.536,1289.86 559.545,1289.86 559.555,1289.86 559.564,1289.86 559.573,1289.86 559.582,1289.86 559.591,1289.86 559.6,1289.86 559.61,1289.86 559.619,1289.86 559.628,1289.86 559.637,1289.86 559.646,1289.86 559.656,1289.86 559.665,1289.86 559.674,1289.86 559.683,1289.86 559.692,1289.86 559.702,1289.86 559.711,1289.86 559.72,1289.86 559.729,1289.86 559.738,1289.86 559.747,1289.86 559.757,1289.85 559.766,1289.85 559.775,1289.85 559.784,1289.85 559.793,1289.85 559.803,1289.85 559.812,1289.85 559.821,1289.85 559.83,1289.85 559.839,1289.85 559.849,1289.85 559.858,1289.85 559.867,1289.85 559.876,1289.85 559.885,1289.85 559.895,1289.85 559.904,1289.85 559.913,1289.85 559.922,1289.85 559.931,1289.85 559.94,1289.85 559.95,1289.85 559.959,1289.85 559.968,1289.85 559.977,1289.85 559.986,1289.85 559.996,1289.85 560.005,1289.84 560.014,1289.84 560.023,1289.84 560.032,1289.84 560.042,1289.84 560.051,1289.84 560.06,1289.84 560.069,1289.84 560.078,1289.84 560.087,1289.84 560.097,1289.84 560.106,1289.84 560.115,1289.84 560.124,1289.84 560.133,1289.84 560.143,1289.84 560.152,1289.84 560.161,1289.84 560.17,1289.84 560.179,1289.84 560.189,1289.84 560.198,1289.84 560.207,1289.84 560.216,1289.84 560.225,1289.84 560.235,1289.84 560.244,1289.84 560.253,1289.84 560.262,1289.83 560.271,1289.83 560.28,1289.83 560.29,1289.83 560.299,1289.83 560.308,1289.83 560.317,1289.83 560.326,1289.83 560.336,1289.83 560.345,1289.83 560.354,1289.83 560.363,1289.83 560.372,1289.83 560.382,1289.83 560.391,1289.83 560.4,1289.83 560.409,1289.83 560.418,1289.83 560.427,1289.83 560.437,1289.83 560.446,1289.83 560.455,1289.83 560.464,1289.83 560.473,1289.83 560.483,1289.83 560.492,1289.83 560.501,1289.83 560.51,1289.82 560.519,1289.82 560.529,1289.82 560.538,1289.82 560.547,1289.82 560.556,1289.82 560.565,1289.82 560.575,1289.82 560.584,1289.82 560.593,1289.82 560.602,1289.82 560.611,1289.82 560.62,1289.82 560.63,1289.82 560.639,1289.82 560.648,1289.82 560.657,1289.82 560.666,1289.82 560.676,1289.82 560.685,1289.82 560.694,1289.82 560.703,1289.82 560.712,1289.82 560.722,1289.82 560.731,1289.82 560.74,1289.82 560.749,1289.82 560.758,1289.82 560.768,1289.81 560.777,1289.81 560.786,1289.81 560.795,1289.81 560.804,1289.81 560.813,1289.81 560.823,1289.81 560.832,1289.81 560.841,1289.81 560.85,1289.81 560.859,1289.81 560.869,1289.81 560.878,1289.81 560.887,1289.81 560.896,1289.81 560.905,1289.81 560.915,1289.81 560.924,1289.81 560.933,1289.81 560.942,1289.81 560.951,1289.81 560.96,1289.81 560.97,1289.81 560.979,1289.81 560.988,1289.81 560.997,1289.81 561.006,1289.81 561.016,1289.81 561.025,1289.8 561.034,1289.8 561.043,1289.8 561.052,1289.8 561.062,1289.8 561.071,1289.8 561.08,1289.8 561.089,1289.8 561.098,1289.8 561.108,1289.8 561.117,1289.8 561.126,1289.8 561.135,1289.8 561.144,1289.8 561.153,1289.8 561.163,1289.8 561.172,1289.8 561.181,1289.8 561.19,1289.8 561.199,1289.8 561.209,1289.8 561.218,1289.8 561.227,1289.8 561.236,1289.8 561.245,1289.8 561.255,1289.8 561.264,1289.8 561.273,1289.8 561.282,1289.79 561.291,1289.79 561.3,1289.79 561.31,1289.79 561.319,1289.79 561.328,1289.79 561.337,1289.79 561.346,1289.79 561.356,1289.79 561.365,1289.79 561.374,1289.79 561.383,1289.79 561.392,1289.79 561.402,1289.79 561.411,1289.79 561.42,1289.79 561.429,1289.79 561.438,1289.79 561.448,1289.79 561.457,1289.79 561.466,1289.79 561.475,1289.79 561.484,1289.79 561.493,1289.79 561.503,1289.79 561.512,1289.79 561.521,1289.79 561.53,1289.79 561.539,1289.79 561.549,1289.78 561.558,1289.78 561.567,1289.78 561.576,1289.78 561.585,1289.78 561.595,1289.78 561.604,1289.78 561.613,1289.78 561.622,1289.78 561.631,1289.78 561.64,1289.78 561.65,1289.78 561.659,1289.78 561.668,1289.78 561.677,1289.78 561.686,1289.78 561.696,1289.78 561.705,1289.78 561.714,1289.78 561.723,1289.78 561.732,1289.78 561.742,1289.78 561.751,1289.78 561.76,1289.78 561.769,1289.78 561.778,1289.78 561.788,1289.78 561.797,1289.78 561.806,1289.77 561.815,1289.77 561.824,1289.77 561.833,1289.77 561.843,1289.77 561.852,1289.77 561.861,1289.77 561.87,1289.77 561.879,1289.77 561.889,1289.77 561.898,1289.77 561.907,1289.77 561.916,1289.77 561.925,1289.77 561.935,1289.77 561.944,1289.77 561.953,1289.77 561.962,1289.77 561.971,1289.77 561.98,1289.77 561.99,1289.77 561.999,1289.77 562.008,1289.77 562.017,1289.77 562.026,1289.77 562.036,1289.77 562.045,1289.77 562.054,1289.77 562.063,1289.77 562.072,1289.76 562.082,1289.76 562.091,1289.76 562.1,1289.76 562.109,1289.76 562.118,1289.76 562.128,1289.76 562.137,1289.76 562.146,1289.76 562.155,1289.76 562.164,1289.76 562.173,1289.76 562.183,1289.76 562.192,1289.76 562.201,1289.76 562.21,1289.76 562.219,1289.76 562.229,1289.76 562.238,1289.76 562.247,1289.76 562.256,1289.76 562.265,1289.76 562.275,1289.76 562.284,1289.76 562.293,1289.76 562.302,1289.76 562.311,1289.76 562.32,1289.76 562.33,1289.76 562.339,1289.75 562.348,1289.75 562.357,1289.75 562.366,1289.75 562.376,1289.75 562.385,1289.75 562.394,1289.75 562.403,1289.75 562.412,1289.75 562.422,1289.75 562.431,1289.75 562.44,1289.75 562.449,1289.75 562.458,1289.75 562.468,1289.75 562.477,1289.75 562.486,1289.75 562.495,1289.75 562.504,1289.75 562.513,1289.75 562.523,1289.75 562.532,1289.75 562.541,1289.75 562.55,1289.75 562.559,1289.75 562.569,1289.75 562.578,1289.75 562.587,1289.75 562.596,1289.74 562.605,1289.74 562.615,1289.74 562.624,1289.74 562.633,1289.74 562.642,1289.74 562.651,1289.74 562.66,1289.74 562.67,1289.74 562.679,1289.74 562.688,1289.74 562.697,1289.74 562.706,1289.74 562.716,1289.74 562.725,1289.74 562.734,1289.74 562.743,1289.74 562.752,1289.74 562.762,1289.74 562.771,1289.74 562.78,1289.74 562.789,1289.74 562.798,1289.74 562.808,1289.74 562.817,1289.74 562.826,1289.74 562.835,1289.74 562.844,1289.74 562.853,1289.74 562.863,1289.74 562.872,1289.73 562.881,1289.73 562.89,1289.73 562.899,1289.73 562.909,1289.73 562.918,1289.73 562.927,1289.73 562.936,1289.73 562.945,1289.73 562.955,1289.73 562.964,1289.73 562.973,1289.73 562.982,1289.73 562.991,1289.73 563,1289.73 563.01,1289.73 563.019,1289.73 563.028,1289.73 563.037,1289.73 563.046,1289.73 563.056,1289.73 563.065,1289.73 563.074,1289.73 563.083,1289.73 563.092,1289.73 563.102,1289.73 563.111,1289.73 563.12,1289.73 563.129,1289.73 563.138,1289.72 563.148,1289.72 563.157,1289.72 563.166,1289.72 563.175,1289.72 563.184,1289.72 563.193,1289.72 563.203,1289.72 563.212,1289.72 563.221,1289.72 563.23,1289.72 563.239,1289.72 563.249,1289.72 563.258,1289.72 563.267,1289.72 563.276,1289.72 563.285,1289.72 563.295,1289.72 563.304,1289.72 563.313,1289.72 563.322,1289.72 563.331,1289.72 563.341,1289.72 563.35,1289.72 563.359,1289.72 563.368,1289.72 563.377,1289.72 563.386,1289.72 563.396,1289.72 563.405,1289.71 563.414,1289.71 563.423,1289.71 563.432,1289.71 563.442,1289.71 563.451,1289.71 563.46,1289.71 563.469,1289.71 563.478,1289.71 563.488,1289.71 563.497,1289.71 563.506,1289.71 563.515,1289.71 563.524,1289.71 563.533,1289.71 563.543,1289.71 563.552,1289.71 563.561,1289.71 563.57,1289.71 563.579,1289.71 563.589,1289.71 563.598,1289.71 563.607,1289.71 563.616,1289.71 563.625,1289.71 563.635,1289.71 563.644,1289.71 563.653,1289.71 563.662,1289.71 563.671,1289.71 563.681,1289.7 563.69,1289.7 563.699,1289.7 563.708,1289.7 563.717,1289.7 563.726,1289.7 563.736,1289.7 563.745,1289.7 563.754,1289.7 563.763,1289.7 563.772,1289.7 563.782,1289.7 563.791,1289.7 563.8,1289.7 563.809,1289.7 563.818,1289.7 563.828,1289.7 563.837,1289.7 563.846,1289.7 563.855,1289.7 563.864,1289.7 563.873,1289.7 563.883,1289.7 563.892,1289.7 563.901,1289.7 563.91,1289.7 563.919,1289.7 563.929,1289.7 563.938,1289.7 563.947,1289.69 563.956,1289.69 563.965,1289.69 563.975,1289.69 563.984,1289.69 563.993,1289.69 564.002,1289.69 564.011,1289.69 564.021,1289.69 564.03,1289.69 564.039,1289.69 564.048,1289.69 564.057,1289.69 564.066,1289.69 564.076,1289.69 564.085,1289.69 564.094,1289.69 564.103,1289.69 564.112,1289.69 564.122,1289.69 564.131,1289.69 564.14,1289.69 564.149,1289.69 564.158,1289.69 564.168,1289.69 564.177,1289.69 564.186,1289.69 564.195,1289.69 564.204,1289.69 564.213,1289.69 564.223,1289.68 564.232,1289.68 564.241,1289.68 564.25,1289.68 564.259,1289.68 564.269,1289.68 564.278,1289.68 564.287,1289.68 564.296,1289.68 564.305,1289.68 564.315,1289.68 564.324,1289.68 564.333,1289.68 564.342,1289.68 564.351,1289.68 564.361,1289.68 564.37,1289.68 564.379,1289.68 564.388,1289.68 564.397,1289.68 564.406,1289.68 564.416,1289.68 564.425,1289.68 564.434,1289.68 564.443,1289.68 564.452,1289.68 564.462,1289.68 564.471,1289.68 564.48,1289.68 564.489,1289.68 564.498,1289.67 564.508,1289.67 564.517,1289.67 564.526,1289.67 564.535,1289.67 564.544,1289.67 564.553,1289.67 564.563,1289.67 564.572,1289.67 564.581,1289.67 564.59,1289.67 564.599,1289.67 564.609,1289.67 564.618,1289.67 564.627,1289.67 564.636,1289.67 564.645,1289.67 564.655,1289.67 564.664,1289.67 564.673,1289.67 564.682,1289.67 564.691,1289.67 564.701,1289.67 564.71,1289.67 564.719,1289.67 564.728,1289.67 564.737,1289.67 564.746,1289.67 564.756,1289.67 564.765,1289.67 564.774,1289.67 564.783,1289.66 564.792,1289.66 564.802,1289.66 564.811,1289.66 564.82,1289.66 564.829,1289.66 564.838,1289.66 564.848,1289.66 564.857,1289.66 564.866,1289.66 564.875,1289.66 564.884,1289.66 564.893,1289.66 564.903,1289.66 564.912,1289.66 564.921,1289.66 564.93,1289.66 564.939,1289.66 564.949,1289.66 564.958,1289.66 564.967,1289.66 564.976,1289.66 564.985,1289.66 564.995,1289.66 565.004,1289.66 565.013,1289.66 565.022,1289.66 565.031,1289.66 565.041,1289.66 565.05,1289.66 565.059,1289.65 565.068,1289.65 565.077,1289.65 565.086,1289.65 565.096,1289.65 565.105,1289.65 565.114,1289.65 565.123,1289.65 565.132,1289.65 565.142,1289.65 565.151,1289.65 565.16,1289.65 565.169,1289.65 565.178,1289.65 565.188,1289.65 565.197,1289.65 565.206,1289.65 565.215,1289.65 565.224,1289.65 565.233,1289.65 565.243,1289.65 565.252,1289.65 565.261,1289.65 565.27,1289.65 565.279,1289.65 565.289,1289.65 565.298,1289.65 565.307,1289.65 565.316,1289.65 565.325,1289.65 565.335,1289.65 565.344,1289.64 565.353,1289.64 565.362,1289.64 565.371,1289.64 565.381,1289.64 565.39,1289.64 565.399,1289.64 565.408,1289.64 565.417,1289.64 565.426,1289.64 565.436,1289.64 565.445,1289.64 565.454,1289.64 565.463,1289.64 565.472,1289.64 565.482,1289.64 565.491,1289.64 565.5,1289.64 565.509,1289.64 565.518,1289.64 565.528,1289.64 565.537,1289.64 565.546,1289.64 565.555,1289.64 565.564,1289.64 565.573,1289.64 565.583,1289.64 565.592,1289.64 565.601,1289.64 565.61,1289.64 565.619,1289.63 565.629,1289.63 565.638,1289.63 565.647,1289.63 565.656,1289.63 565.665,1289.63 565.675,1289.63 565.684,1289.63 565.693,1289.63 565.702,1289.63 565.711,1289.63 565.721,1289.63 565.73,1289.63 565.739,1289.63 565.748,1289.63 565.757,1289.63 565.766,1289.63 565.776,1289.63 565.785,1289.63 565.794,1289.63 565.803,1289.63 565.812,1289.63 565.822,1289.63 565.831,1289.63 565.84,1289.63 565.849,1289.63 565.858,1289.63 565.868,1289.63 565.877,1289.63 565.886,1289.63 565.895,1289.63 565.904,1289.62 565.914,1289.62 565.923,1289.62 565.932,1289.62 565.941,1289.62 565.95,1289.62 565.959,1289.62 565.969,1289.62 565.978,1289.62 565.987,1289.62 565.996,1289.62 566.005,1289.62 566.015,1289.62 566.024,1289.62 566.033,1289.62 566.042,1289.62 566.051,1289.62 566.061,1289.62 566.07,1289.62 566.079,1289.62 566.088,1289.62 566.097,1289.62 566.106,1289.62 566.116,1289.62 566.125,1289.62 566.134,1289.62 566.143,1289.62 566.152,1289.62 566.162,1289.62 566.171,1289.62 566.18,1289.62 566.189,1289.61 566.198,1289.61 566.208,1289.61 566.217,1289.61 566.226,1289.61 566.235,1289.61 566.244,1289.61 566.254,1289.61 566.263,1289.61 566.272,1289.61 566.281,1289.61 566.29,1289.61 566.299,1289.61 566.309,1289.61 566.318,1289.61 566.327,1289.61 566.336,1289.61 566.345,1289.61 566.355,1289.61 566.364,1289.61 566.373,1289.61 566.382,1289.61 566.391,1289.61 566.401,1289.61 566.41,1289.61 566.419,1289.61 566.428,1289.61 566.437,1289.61 566.446,1289.61 566.456,1289.61 566.465,1289.61 566.474,1289.61 566.483,1289.6 566.492,1289.6 566.502,1289.6 566.511,1289.6 566.52,1289.6 566.529,1289.6 566.538,1289.6 566.548,1289.6 566.557,1289.6 566.566,1289.6 566.575,1289.6 566.584,1289.6 566.594,1289.6 566.603,1289.6 566.612,1289.6 566.621,1289.6 566.63,1289.6 566.639,1289.6 566.649,1289.6 566.658,1289.6 566.667,1289.6 566.676,1289.6 566.685,1289.6 566.695,1289.6 566.704,1289.6 566.713,1289.6 566.722,1289.6 566.731,1289.6 566.741,1289.6 566.75,1289.6 566.759,1289.6 566.768,1289.59 566.777,1289.59 566.786,1289.59 566.796,1289.59 566.805,1289.59 566.814,1289.59 566.823,1289.59 566.832,1289.59 566.842,1289.59 566.851,1289.59 566.86,1289.59 566.869,1289.59 566.878,1289.59 566.888,1289.59 566.897,1289.59 566.906,1289.59 566.915,1289.59 566.924,1289.59 566.934,1289.59 566.943,1289.59 566.952,1289.59 566.961,1289.59 566.97,1289.59 566.979,1289.59 566.989,1289.59 566.998,1289.59 567.007,1289.59 567.016,1289.59 567.025,1289.59 567.035,1289.59 567.044,1289.59 567.053,1289.59 567.062,1289.58 567.071,1289.58 567.081,1289.58 567.09,1289.58 567.099,1289.58 567.108,1289.58 567.117,1289.58 567.126,1289.58 567.136,1289.58 567.145,1289.58 567.154,1289.58 567.163,1289.58 567.172,1289.58 567.182,1289.58 567.191,1289.58 567.2,1289.58 567.209,1289.58 567.218,1289.58 567.228,1289.58 567.237,1289.58 567.246,1289.58 567.255,1289.58 567.264,1289.58 567.274,1289.58 567.283,1289.58 567.292,1289.58 567.301,1289.58 567.31,1289.58 567.319,1289.58 567.329,1289.58 567.338,1289.58 567.347,1289.58 567.356,1289.57 567.365,1289.57 567.375,1289.57 567.384,1289.57 567.393,1289.57 567.402,1289.57 567.411,1289.57 567.421,1289.57 567.43,1289.57 567.439,1289.57 567.448,1289.57 567.457,1289.57 567.466,1289.57 567.476,1289.57 567.485,1289.57 567.494,1289.57 567.503,1289.57 567.512,1289.57 567.522,1289.57 567.531,1289.57 567.54,1289.57 567.549,1289.57 567.558,1289.57 567.568,1289.57 567.577,1289.57 567.586,1289.57 567.595,1289.57 567.604,1289.57 567.614,1289.57 567.623,1289.57 567.632,1289.57 567.641,1289.57 567.65,1289.56 567.659,1289.56 567.669,1289.56 567.678,1289.56 567.687,1289.56 567.696,1289.56 567.705,1289.56 567.715,1289.56 567.724,1289.56 567.733,1289.56 567.742,1289.56 567.751,1289.56 567.761,1289.56 567.77,1289.56 567.779,1289.56 567.788,1289.56 567.797,1289.56 567.806,1289.56 567.816,1289.56 567.825,1289.56 567.834,1289.56 567.843,1289.56 567.852,1289.56 567.862,1289.56 567.871,1289.56 567.88,1289.56 567.889,1289.56 567.898,1289.56 567.908,1289.56 567.917,1289.56 567.926,1289.56 567.935,1289.56 567.944,1289.55 567.954,1289.55 567.963,1289.55 567.972,1289.55 567.981,1289.55 567.99,1289.55 567.999,1289.55 568.009,1289.55 568.018,1289.55 568.027,1289.55 568.036,1289.55 568.045,1289.55 568.055,1289.55 568.064,1289.55 568.073,1289.55 568.082,1289.55 568.091,1289.55 568.101,1289.55 568.11,1289.55 568.119,1289.55 568.128,1289.55 568.137,1289.55 568.147,1289.55 568.156,1289.55 568.165,1289.55 568.174,1289.55 568.183,1289.55 568.192,1289.55 568.202,1289.55 568.211,1289.55 568.22,1289.55 568.229,1289.55 568.238,1289.55 568.248,1289.54 568.257,1289.54 568.266,1289.54 568.275,1289.54 568.284,1289.54 568.294,1289.54 568.303,1289.54 568.312,1289.54 568.321,1289.54 568.33,1289.54 568.339,1289.54 568.349,1289.54 568.358,1289.54 568.367,1289.54 568.376,1289.54 568.385,1289.54 568.395,1289.54 568.404,1289.54 568.413,1289.54 568.422,1289.54 568.431,1289.54 568.441,1289.54 568.45,1289.54 568.459,1289.54 568.468,1289.54 568.477,1289.54 568.487,1289.54 568.496,1289.54 568.505,1289.54 568.514,1289.54 568.523,1289.54 568.532,1289.54 568.542,1289.54 568.551,1289.53 568.56,1289.53 568.569,1289.53 568.578,1289.53 568.588,1289.53 568.597,1289.53 568.606,1289.53 568.615,1289.53 568.624,1289.53 568.634,1289.53 568.643,1289.53 568.652,1289.53 568.661,1289.53 568.67,1289.53 568.679,1289.53 568.689,1289.53 568.698,1289.53 568.707,1289.53 568.716,1289.53 568.725,1289.53 568.735,1289.53 568.744,1289.53 568.753,1289.53 568.762,1289.53 568.771,1289.53 568.781,1289.53 568.79,1289.53 568.799,1289.53 568.808,1289.53 568.817,1289.53 568.827,1289.53 568.836,1289.53 568.845,1289.53 568.854,1289.52 568.863,1289.52 568.872,1289.52 568.882,1289.52 568.891,1289.52 568.9,1289.52 568.909,1289.52 568.918,1289.52 568.928,1289.52 568.937,1289.52 568.946,1289.52 568.955,1289.52 568.964,1289.52 568.974,1289.52 568.983,1289.52 568.992,1289.52 569.001,1289.52 569.01,1289.52 569.019,1289.52 569.029,1289.52 569.038,1289.52 569.047,1289.52 569.056,1289.52 569.065,1289.52 569.075,1289.52 569.084,1289.52 569.093,1289.52 569.102,1289.52 569.111,1289.52 569.121,1289.52 569.13,1289.52 569.139,1289.52 569.148,1289.52 569.157,1289.51 569.167,1289.51 569.176,1289.51 569.185,1289.51 569.194,1289.51 569.203,1289.51 569.212,1289.51 569.222,1289.51 569.231,1289.51 569.24,1289.51 569.249,1289.51 569.258,1289.51 569.268,1289.51 569.277,1289.51 569.286,1289.51 569.295,1289.51 569.304,1289.51 569.314,1289.51 569.323,1289.51 569.332,1289.51 569.341,1289.51 569.35,1289.51 569.359,1289.51 569.369,1289.51 569.378,1289.51 569.387,1289.51 569.396,1289.51 569.405,1289.51 569.415,1289.51 569.424,1289.51 569.433,1289.51 569.442,1289.51 569.451,1289.51 569.461,1289.5 569.47,1289.5 569.479,1289.5 569.488,1289.5 569.497,1289.5 569.507,1289.5 569.516,1289.5 569.525,1289.5 569.534,1289.5 569.543,1289.5 569.552,1289.5 569.562,1289.5 569.571,1289.5 569.58,1289.5 569.589,1289.5 569.598,1289.5 569.608,1289.5 569.617,1289.5 569.626,1289.5 569.635,1289.5 569.644,1289.5 569.654,1289.5 569.663,1289.5 569.672,1289.5 569.681,1289.5 569.69,1289.5 569.699,1289.5 569.709,1289.5 569.718,1289.5 569.727,1289.5 569.736,1289.5 569.745,1289.5 569.755,1289.5 569.764,1289.5 569.773,1289.49 569.782,1289.49 569.791,1289.49 569.801,1289.49 569.81,1289.49 569.819,1289.49 569.828,1289.49 569.837,1289.49 569.847,1289.49 569.856,1289.49 569.865,1289.49 569.874,1289.49 569.883,1289.49 569.892,1289.49 569.902,1289.49 569.911,1289.49 569.92,1289.49 569.929,1289.49 569.938,1289.49 569.948,1289.49 569.957,1289.49 569.966,1289.49 569.975,1289.49 569.984,1289.49 569.994,1289.49 570.003,1289.49 570.012,1289.49 570.021,1289.49 570.03,1289.49 570.039,1289.49 570.049,1289.49 570.058,1289.49 570.067,1289.49 570.076,1289.49 570.085,1289.48 570.095,1289.48 570.104,1289.48 570.113,1289.48 570.122,1289.48 570.131,1289.48 570.141,1289.48 570.15,1289.48 570.159,1289.48 570.168,1289.48 570.177,1289.48 570.187,1289.48 570.196,1289.48 570.205,1289.48 570.214,1289.48 570.223,1289.48 570.232,1289.48 570.242,1289.48 570.251,1289.48 570.26,1289.48 570.269,1289.48 570.278,1289.48 570.288,1289.48 570.297,1289.48 570.306,1289.48 570.315,1289.48 570.324,1289.48 570.334,1289.48 570.343,1289.48 570.352,1289.48 570.361,1289.48 570.37,1289.48 570.379,1289.48 570.389,1289.48 570.398,1289.47 570.407,1289.47 570.416,1289.47 570.425,1289.47 570.435,1289.47 570.444,1289.47 570.453,1289.47 570.462,1289.47 570.471,1289.47 570.481,1289.47 570.49,1289.47 570.499,1289.47 570.508,1289.47 570.517,1289.47 570.527,1289.47 570.536,1289.47 570.545,1289.47 570.554,1289.47 570.563,1289.47 570.572,1289.47 570.582,1289.47 570.591,1289.47 570.6,1289.47 570.609,1289.47 570.618,1289.47 570.628,1289.47 570.637,1289.47 570.646,1289.47 570.655,1289.47 570.664,1289.47 570.674,1289.47 570.683,1289.47 570.692,1289.47 570.701,1289.47 570.71,1289.46 570.72,1289.46 570.729,1289.46 570.738,1289.46 570.747,1289.46 570.756,1289.46 570.765,1289.46 570.775,1289.46 570.784,1289.46 570.793,1289.46 570.802,1289.46 570.811,1289.46 570.821,1289.46 570.83,1289.46 570.839,1289.46 570.848,1289.46 570.857,1289.46 570.867,1289.46 570.876,1289.46 570.885,1289.46 570.894,1289.46 570.903,1289.46 570.912,1289.46 570.922,1289.46 570.931,1289.46 570.94,1289.46 570.949,1289.46 570.958,1289.46 570.968,1289.46 570.977,1289.46 570.986,1289.46 570.995,1289.46 571.004,1289.46 571.014,1289.46 571.023,1289.46 571.032,1289.45 571.041,1289.45 571.05,1289.45 571.06,1289.45 571.069,1289.45 571.078,1289.45 571.087,1289.45 571.096,1289.45 571.105,1289.45 571.115,1289.45 571.124,1289.45 571.133,1289.45 571.142,1289.45 571.151,1289.45 571.161,1289.45 571.17,1289.45 571.179,1289.45 571.188,1289.45 571.197,1289.45 571.207,1289.45 571.216,1289.45 571.225,1289.45 571.234,1289.45 571.243,1289.45 571.252,1289.45 571.262,1289.45 571.271,1289.45 571.28,1289.45 571.289,1289.45 571.298,1289.45 571.308,1289.45 571.317,1289.45 571.326,1289.45 571.335,1289.45 571.344,1289.45 571.354,1289.44 571.363,1289.44 571.372,1289.44 571.381,1289.44 571.39,1289.44 571.4,1289.44 571.409,1289.44 571.418,1289.44 571.427,1289.44 571.436,1289.44 571.445,1289.44 571.455,1289.44 571.464,1289.44 571.473,1289.44 571.482,1289.44 571.491,1289.44 571.501,1289.44 571.51,1289.44 571.519,1289.44 571.528,1289.44 571.537,1289.44 571.547,1289.44 571.556,1289.44 571.565,1289.44 571.574,1289.44 571.583,1289.44 571.592,1289.44 571.602,1289.44 571.611,1289.44 571.62,1289.44 571.629,1289.44 571.638,1289.44 571.648,1289.44 571.657,1289.44 571.666,1289.44 571.675,1289.43 571.684,1289.43 571.694,1289.43 571.703,1289.43 571.712,1289.43 571.721,1289.43 571.73,1289.43 571.74,1289.43 571.749,1289.43 571.758,1289.43 571.767,1289.43 571.776,1289.43 571.785,1289.43 571.795,1289.43 571.804,1289.43 571.813,1289.43 571.822,1289.43 571.831,1289.43 571.841,1289.43 571.85,1289.43 571.859,1289.43 571.868,1289.43 571.877,1289.43 571.887,1289.43 571.896,1289.43 571.905,1289.43 571.914,1289.43 571.923,1289.43 571.932,1289.43 571.942,1289.43 571.951,1289.43 571.96,1289.43 571.969,1289.43 571.978,1289.43 571.988,1289.43 571.997,1289.43 572.006,1289.42 572.015,1289.42 572.024,1289.42 572.034,1289.42 572.043,1289.42 572.052,1289.42 572.061,1289.42 572.07,1289.42 572.08,1289.42 572.089,1289.42 572.098,1289.42 572.107,1289.42 572.116,1289.42 572.125,1289.42 572.135,1289.42 572.144,1289.42 572.153,1289.42 572.162,1289.42 572.171,1289.42 572.181,1289.42 572.19,1289.42 572.199,1289.42 572.208,1289.42 572.217,1289.42 572.227,1289.42 572.236,1289.42 572.245,1289.42 572.254,1289.42 572.263,1289.42 572.272,1289.42 572.282,1289.42 572.291,1289.42 572.3,1289.42 572.309,1289.42 572.318,1289.42 572.328,1289.41 572.337,1289.41 572.346,1289.41 572.355,1289.41 572.364,1289.41 572.374,1289.41 572.383,1289.41 572.392,1289.41 572.401,1289.41 572.41,1289.41 572.42,1289.41 572.429,1289.41 572.438,1289.41 572.447,1289.41 572.456,1289.41 572.465,1289.41 572.475,1289.41 572.484,1289.41 572.493,1289.41 572.502,1289.41 572.511,1289.41 572.521,1289.41 572.53,1289.41 572.539,1289.41 572.548,1289.41 572.557,1289.41 572.567,1289.41 572.576,1289.41 572.585,1289.41 572.594,1289.41 572.603,1289.41 572.612,1289.41 572.622,1289.41 572.631,1289.41 572.64,1289.41 572.649,1289.41 572.658,1289.4 572.668,1289.4 572.677,1289.4 572.686,1289.4 572.695,1289.4 572.704,1289.4 572.714,1289.4 572.723,1289.4 572.732,1289.4 572.741,1289.4 572.75,1289.4 572.76,1289.4 572.769,1289.4 572.778,1289.4 572.787,1289.4 572.796,1289.4 572.805,1289.4 572.815,1289.4 572.824,1289.4 572.833,1289.4 572.842,1289.4 572.851,1289.4 572.861,1289.4 572.87,1289.4 572.879,1289.4 572.888,1289.4 572.897,1289.4 572.907,1289.4 572.916,1289.4 572.925,1289.4 572.934,1289.4 572.943,1289.4 572.952,1289.4 572.962,1289.4 572.971,1289.4 572.98,1289.4 572.989,1289.4 572.998,1289.39 573.008,1289.39 573.017,1289.39 573.026,1289.39 573.035,1289.39 573.044,1289.39 573.054,1289.39 573.063,1289.39 573.072,1289.39 573.081,1289.39 573.09,1289.39 573.1,1289.39 573.109,1289.39 573.118,1289.39 573.127,1289.39 573.136,1289.39 573.145,1289.39 573.155,1289.39 573.164,1289.39 573.173,1289.39 573.182,1289.39 573.191,1289.39 573.201,1289.39 573.21,1289.39 573.219,1289.39 573.228,1289.39 573.237,1289.39 573.247,1289.39 573.256,1289.39 573.265,1289.39 573.274,1289.39 573.283,1289.39 573.293,1289.39 573.302,1289.39 573.311,1289.39 573.32,1289.39 573.329,1289.38 573.338,1289.38 573.348,1289.38 573.357,1289.38 573.366,1289.38 573.375,1289.38 573.384,1289.38 573.394,1289.38 573.403,1289.38 573.412,1289.38 573.421,1289.38 573.43,1289.38 573.44,1289.38 573.449,1289.38 573.458,1289.38 573.467,1289.38 573.476,1289.38 573.485,1289.38 573.495,1289.38 573.504,1289.38 573.513,1289.38 573.522,1289.38 573.531,1289.38 573.541,1289.38 573.55,1289.38 573.559,1289.38 573.568,1289.38 573.577,1289.38 573.587,1289.38 573.596,1289.38 573.605,1289.38 573.614,1289.38 573.623,1289.38 573.633,1289.38 573.642,1289.38 573.651,1289.38 573.66,1289.38 573.669,1289.37 573.678,1289.37 573.688,1289.37 573.697,1289.37 573.706,1289.37 573.715,1289.37 573.724,1289.37 573.734,1289.37 573.743,1289.37 573.752,1289.37 573.761,1289.37 573.77,1289.37 573.78,1289.37 573.789,1289.37 573.798,1289.37 573.807,1289.37 573.816,1289.37 573.825,1289.37 573.835,1289.37 573.844,1289.37 573.853,1289.37 573.862,1289.37 573.871,1289.37 573.881,1289.37 573.89,1289.37 573.899,1289.37 573.908,1289.37 573.917,1289.37 573.927,1289.37 573.936,1289.37 573.945,1289.37 573.954,1289.37 573.963,1289.37 573.973,1289.37 573.982,1289.37 573.991,1289.37 574,1289.37 574.009,1289.36 574.018,1289.36 574.028,1289.36 574.037,1289.36 574.046,1289.36 574.055,1289.36 574.064,1289.36 574.074,1289.36 574.083,1289.36 574.092,1289.36 574.101,1289.36 574.11,1289.36 574.12,1289.36 574.129,1289.36 574.138,1289.36 574.147,1289.36 574.156,1289.36 574.165,1289.36 574.175,1289.36 574.184,1289.36 574.193,1289.36 574.202,1289.36 574.211,1289.36 574.221,1289.36 574.23,1289.36 574.239,1289.36 574.248,1289.36 574.257,1289.36 574.267,1289.36 574.276,1289.36 574.285,1289.36 574.294,1289.36 574.303,1289.36 574.313,1289.36 574.322,1289.36 574.331,1289.36 574.34,1289.36 574.349,1289.36 574.358,1289.35 574.368,1289.35 574.377,1289.35 574.386,1289.35 574.395,1289.35 574.404,1289.35 574.414,1289.35 574.423,1289.35 574.432,1289.35 574.441,1289.35 574.45,1289.35 574.46,1289.35 574.469,1289.35 574.478,1289.35 574.487,1289.35 574.496,1289.35 574.505,1289.35 574.515,1289.35 574.524,1289.35 574.533,1289.35 574.542,1289.35 574.551,1289.35 574.561,1289.35 574.57,1289.35 574.579,1289.35 574.588,1289.35 574.597,1289.35 574.607,1289.35 574.616,1289.35 574.625,1289.35 574.634,1289.35 574.643,1289.35 574.653,1289.35 574.662,1289.35 574.671,1289.35 574.68,1289.35 574.689,1289.35 574.698,1289.35 574.708,1289.34 574.717,1289.34 574.726,1289.34 574.735,1289.34 574.744,1289.34 574.754,1289.34 574.763,1289.34 574.772,1289.34 574.781,1289.34 574.79,1289.34 574.8,1289.34 574.809,1289.34 574.818,1289.34 574.827,1289.34 574.836,1289.34 574.845,1289.34 574.855,1289.34 574.864,1289.34 574.873,1289.34 574.882,1289.34 574.891,1289.34 574.901,1289.34 574.91,1289.34 574.919,1289.34 574.928,1289.34 574.937,1289.34 574.947,1289.34 574.956,1289.34 574.965,1289.34 574.974,1289.34 574.983,1289.34 574.993,1289.34 575.002,1289.34 575.011,1289.34 575.02,1289.34 575.029,1289.34 575.038,1289.34 575.048,1289.34 575.057,1289.33 575.066,1289.33 575.075,1289.33 575.084,1289.33 575.094,1289.33 575.103,1289.33 575.112,1289.33 575.121,1289.33 575.13,1289.33 575.14,1289.33 575.149,1289.33 575.158,1289.33 575.167,1289.33 575.176,1289.33 575.185,1289.33 575.195,1289.33 575.204,1289.33 575.213,1289.33 575.222,1289.33 575.231,1289.33 575.241,1289.33 575.25,1289.33 575.259,1289.33 575.268,1289.33 575.277,1289.33 575.287,1289.33 575.296,1289.33 575.305,1289.33 575.314,1289.33 575.323,1289.33 575.333,1289.33 575.342,1289.33 575.351,1289.33 575.36,1289.33 575.369,1289.33 575.378,1289.33 575.388,1289.33 575.397,1289.33 575.406,1289.33 575.415,1289.32 575.424,1289.32 575.434,1289.32 575.443,1289.32 575.452,1289.32 575.461,1289.32 575.47,1289.32 575.48,1289.32 575.489,1289.32 575.498,1289.32 575.507,1289.32 575.516,1289.32 575.526,1289.32 575.535,1289.32 575.544,1289.32 575.553,1289.32 575.562,1289.32 575.571,1289.32 575.581,1289.32 575.59,1289.32 575.599,1289.32 575.608,1289.32 575.617,1289.32 575.627,1289.32 575.636,1289.32 575.645,1289.32 575.654,1289.32 575.663,1289.32 575.673,1289.32 575.682,1289.32 575.691,1289.32 575.7,1289.32 575.709,1289.32 575.718,1289.32 575.728,1289.32 575.737,1289.32 575.746,1289.32 575.755,1289.32 575.764,1289.32 575.774,1289.31 575.783,1289.31 575.792,1289.31 575.801,1289.31 575.81,1289.31 575.82,1289.31 575.829,1289.31 575.838,1289.31 575.847,1289.31 575.856,1289.31 575.866,1289.31 575.875,1289.31 575.884,1289.31 575.893,1289.31 575.902,1289.31 575.911,1289.31 575.921,1289.31 575.93,1289.31 575.939,1289.31 575.948,1289.31 575.957,1289.31 575.967,1289.31 575.976,1289.31 575.985,1289.31 575.994,1289.31 576.003,1289.31 576.013,1289.31 576.022,1289.31 576.031,1289.31 576.04,1289.31 576.049,1289.31 576.058,1289.31 576.068,1289.31 576.077,1289.31 576.086,1289.31 576.095,1289.31 576.104,1289.31 576.114,1289.31 576.123,1289.31 576.132,1289.3 576.141,1289.3 576.15,1289.3 576.16,1289.3 576.169,1289.3 576.178,1289.3 576.187,1289.3 576.196,1289.3 576.206,1289.3 576.215,1289.3 576.224,1289.3 576.233,1289.3 576.242,1289.3 576.251,1289.3 576.261,1289.3 576.27,1289.3 576.279,1289.3 576.288,1289.3 576.297,1289.3 576.307,1289.3 576.316,1289.3 576.325,1289.3 576.334,1289.3 576.343,1289.3 576.353,1289.3 576.362,1289.3 576.371,1289.3 576.38,1289.3 576.389,1289.3 576.398,1289.3 576.408,1289.3 576.417,1289.3 576.426,1289.3 576.435,1289.3 576.444,1289.3 576.454,1289.3 576.463,1289.3 576.472,1289.3 576.481,1289.3 576.49,1289.3 576.5,1289.29 576.509,1289.29 576.518,1289.29 576.527,1289.29 576.536,1289.29 576.546,1289.29 576.555,1289.29 576.564,1289.29 576.573,1289.29 576.582,1289.29 576.591,1289.29 576.601,1289.29 576.61,1289.29 576.619,1289.29 576.628,1289.29 576.637,1289.29 576.647,1289.29 576.656,1289.29 576.665,1289.29 576.674,1289.29 576.683,1289.29 576.693,1289.29 576.702,1289.29 576.711,1289.29 576.72,1289.29 576.729,1289.29 576.738,1289.29 576.748,1289.29 576.757,1289.29 576.766,1289.29 576.775,1289.29 576.784,1289.29 576.794,1289.29 576.803,1289.29 576.812,1289.29 576.821,1289.29 576.83,1289.29 576.84,1289.29 576.849,1289.29 576.858,1289.29 576.867,1289.28 576.876,1289.28 576.886,1289.28 576.895,1289.28 576.904,1289.28 576.913,1289.28 576.922,1289.28 576.931,1289.28 576.941,1289.28 576.95,1289.28 576.959,1289.28 576.968,1289.28 576.977,1289.28 576.987,1289.28 576.996,1289.28 577.005,1289.28 577.014,1289.28 577.023,1289.28 577.033,1289.28 577.042,1289.28 577.051,1289.28 577.06,1289.28 577.069,1289.28 577.078,1289.28 577.088,1289.28 577.097,1289.28 577.106,1289.28 577.115,1289.28 577.124,1289.28 577.134,1289.28 577.143,1289.28 577.152,1289.28 577.161,1289.28 577.17,1289.28 577.18,1289.28 577.189,1289.28 577.198,1289.28 577.207,1289.28 577.216,1289.28 577.226,1289.28 577.235,1289.27 577.244,1289.27 577.253,1289.27 577.262,1289.27 577.271,1289.27 577.281,1289.27 577.29,1289.27 577.299,1289.27 577.308,1289.27 577.317,1289.27 577.327,1289.27 577.336,1289.27 577.345,1289.27 577.354,1289.27 577.363,1289.27 577.373,1289.27 577.382,1289.27 577.391,1289.27 577.4,1289.27 577.409,1289.27 577.418,1289.27 577.428,1289.27 577.437,1289.27 577.446,1289.27 577.455,1289.27 577.464,1289.27 577.474,1289.27 577.483,1289.27 577.492,1289.27 577.501,1289.27 577.51,1289.27 577.52,1289.27 577.529,1289.27 577.538,1289.27 577.547,1289.27 577.556,1289.27 577.566,1289.27 577.575,1289.27 577.584,1289.27 577.593,1289.27 577.602,1289.27 577.611,1289.26 577.621,1289.26 577.63,1289.26 577.639,1289.26 577.648,1289.26 577.657,1289.26 577.667,1289.26 577.676,1289.26 577.685,1289.26 577.694,1289.26 577.703,1289.26 577.713,1289.26 577.722,1289.26 577.731,1289.26 577.74,1289.26 577.749,1289.26 577.758,1289.26 577.768,1289.26 577.777,1289.26 577.786,1289.26 577.795,1289.26 577.804,1289.26 577.814,1289.26 577.823,1289.26 577.832,1289.26 577.841,1289.26 577.85,1289.26 577.86,1289.26 577.869,1289.26 577.878,1289.26 577.887,1289.26 577.896,1289.26 577.906,1289.26 577.915,1289.26 577.924,1289.26 577.933,1289.26 577.942,1289.26 577.951,1289.26 577.961,1289.26 577.97,1289.26 577.979,1289.26 577.988,1289.25 577.997,1289.25 578.007,1289.25 578.016,1289.25 578.025,1289.25 578.034,1289.25 578.043,1289.25 578.053,1289.25 578.062,1289.25 578.071,1289.25 578.08,1289.25 578.089,1289.25 578.099,1289.25 578.108,1289.25 578.117,1289.25 578.126,1289.25 578.135,1289.25 578.144,1289.25 578.154,1289.25 578.163,1289.25 578.172,1289.25 578.181,1289.25 578.19,1289.25 578.2,1289.25 578.209,1289.25 578.218,1289.25 578.227,1289.25 578.236,1289.25 578.246,1289.25 578.255,1289.25 578.264,1289.25 578.273,1289.25 578.282,1289.25 578.291,1289.25 578.301,1289.25 578.31,1289.25 578.319,1289.25 578.328,1289.25 578.337,1289.25 578.347,1289.25 578.356,1289.25 578.365,1289.25 578.374,1289.24 578.383,1289.24 578.393,1289.24 578.402,1289.24 578.411,1289.24 578.42,1289.24 578.429,1289.24 578.439,1289.24 578.448,1289.24 578.457,1289.24 578.466,1289.24 578.475,1289.24 578.484,1289.24 578.494,1289.24 578.503,1289.24 578.512,1289.24 578.521,1289.24 578.53,1289.24 578.54,1289.24 578.549,1289.24 578.558,1289.24 578.567,1289.24 578.576,1289.24 578.586,1289.24 578.595,1289.24 578.604,1289.24 578.613,1289.24 578.622,1289.24 578.631,1289.24 578.641,1289.24 578.65,1289.24 578.659,1289.24 578.668,1289.24 578.677,1289.24 578.687,1289.24 578.696,1289.24 578.705,1289.24 578.714,1289.24 578.723,1289.24 578.733,1289.24 578.742,1289.24 578.751,1289.24 578.76,1289.23 578.769,1289.23 578.779,1289.23 578.788,1289.23 578.797,1289.23 578.806,1289.23 578.815,1289.23 578.824,1289.23 578.834,1289.23 578.843,1289.23 578.852,1289.23 578.861,1289.23 578.87,1289.23 578.88,1289.23 578.889,1289.23 578.898,1289.23 578.907,1289.23 578.916,1289.23 578.926,1289.23 578.935,1289.23 578.944,1289.23 578.953,1289.23 578.962,1289.23 578.971,1289.23 578.981,1289.23 578.99,1289.23 578.999,1289.23 579.008,1289.23 579.017,1289.23 579.027,1289.23 579.036,1289.23 579.045,1289.23 579.054,1289.23 579.063,1289.23 579.073,1289.23 579.082,1289.23 579.091,1289.23 579.1,1289.23 579.109,1289.23 579.119,1289.23 579.128,1289.23 579.137,1289.23 579.146,1289.23 579.155,1289.22 579.164,1289.22 579.174,1289.22 579.183,1289.22 579.192,1289.22 579.201,1289.22 579.21,1289.22 579.22,1289.22 579.229,1289.22 579.238,1289.22 579.247,1289.22 579.256,1289.22 579.266,1289.22 579.275,1289.22 579.284,1289.22 579.293,1289.22 579.302,1289.22 579.311,1289.22 579.321,1289.22 579.33,1289.22 579.339,1289.22 579.348,1289.22 579.357,1289.22 579.367,1289.22 579.376,1289.22 579.385,1289.22 579.394,1289.22 579.403,1289.22 579.413,1289.22 579.422,1289.22 579.431,1289.22 579.44,1289.22 579.449,1289.22 579.459,1289.22 579.468,1289.22 579.477,1289.22 579.486,1289.22 579.495,1289.22 579.504,1289.22 579.514,1289.22 579.523,1289.22 579.532,1289.22 579.541,1289.22 579.55,1289.21 579.56,1289.21 579.569,1289.21 579.578,1289.21 579.587,1289.21 579.596,1289.21 579.606,1289.21 579.615,1289.21 579.624,1289.21 579.633,1289.21 579.642,1289.21 579.651,1289.21 579.661,1289.21 579.67,1289.21 579.679,1289.21 579.688,1289.21 579.697,1289.21 579.707,1289.21 579.716,1289.21 579.725,1289.21 579.734,1289.21 579.743,1289.21 579.753,1289.21 579.762,1289.21 579.771,1289.21 579.78,1289.21 579.789,1289.21 579.799,1289.21 579.808,1289.21 579.817,1289.21 579.826,1289.21 579.835,1289.21 579.844,1289.21 579.854,1289.21 579.863,1289.21 579.872,1289.21 579.881,1289.21 579.89,1289.21 579.9,1289.21 579.909,1289.21 579.918,1289.21 579.927,1289.21 579.936,1289.21 579.946,1289.21 579.955,1289.2 579.964,1289.2 579.973,1289.2 579.982,1289.2 579.991,1289.2 580.001,1289.2 580.01,1289.2 580.019,1289.2 580.028,1289.2 580.037,1289.2 580.047,1289.2 580.056,1289.2 580.065,1289.2 580.074,1289.2 580.083,1289.2 580.093,1289.2 580.102,1289.2 580.111,1289.2 580.12,1289.2 580.129,1289.2 580.139,1289.2 580.148,1289.2 580.157,1289.2 580.166,1289.2 580.175,1289.2 580.184,1289.2 580.194,1289.2 580.203,1289.2 580.212,1289.2 580.221,1289.2 580.23,1289.2 580.24,1289.2 580.249,1289.2 580.258,1289.2 580.267,1289.2 580.276,1289.2 580.286,1289.2 580.295,1289.2 580.304,1289.2 580.313,1289.2 580.322,1289.2 580.331,1289.2 580.341,1289.2 580.35,1289.2 580.359,1289.19 580.368,1289.19 580.377,1289.19 580.387,1289.19 580.396,1289.19 580.405,1289.19 580.414,1289.19 580.423,1289.19 580.433,1289.19 580.442,1289.19 580.451,1289.19 580.46,1289.19 580.469,1289.19 580.479,1289.19 580.488,1289.19 580.497,1289.19 580.506,1289.19 580.515,1289.19 580.524,1289.19 580.534,1289.19 580.543,1289.19 580.552,1289.19 580.561,1289.19 580.57,1289.19 580.58,1289.19 580.589,1289.19 580.598,1289.19 580.607,1289.19 580.616,1289.19 580.626,1289.19 580.635,1289.19 580.644,1289.19 580.653,1289.19 580.662,1289.19 580.672,1289.19 580.681,1289.19 580.69,1289.19 580.699,1289.19 580.708,1289.19 580.717,1289.19 580.727,1289.19 580.736,1289.19 580.745,1289.19 580.754,1289.19 580.763,1289.19 580.773,1289.18 580.782,1289.18 580.791,1289.18 580.8,1289.18 580.809,1289.18 580.819,1289.18 580.828,1289.18 580.837,1289.18 580.846,1289.18 580.855,1289.18 580.864,1289.18 580.874,1289.18 580.883,1289.18 580.892,1289.18 580.901,1289.18 580.91,1289.18 580.92,1289.18 580.929,1289.18 580.938,1289.18 580.947,1289.18 580.956,1289.18 580.966,1289.18 580.975,1289.18 580.984,1289.18 580.993,1289.18 581.002,1289.18 581.012,1289.18 581.021,1289.18 581.03,1289.18 581.039,1289.18 581.048,1289.18 581.057,1289.18 581.067,1289.18 581.076,1289.18 581.085,1289.18 581.094,1289.18 581.103,1289.18 581.113,1289.18 581.122,1289.18 581.131,1289.18 581.14,1289.18 581.149,1289.18 581.159,1289.18 581.168,1289.18 581.177,1289.18 581.186,1289.17 581.195,1289.17 581.204,1289.17 581.214,1289.17 581.223,1289.17 581.232,1289.17 581.241,1289.17 581.25,1289.17 581.26,1289.17 581.269,1289.17 581.278,1289.17 581.287,1289.17 581.296,1289.17 581.306,1289.17 581.315,1289.17 581.324,1289.17 581.333,1289.17 581.342,1289.17 581.352,1289.17 581.361,1289.17 581.37,1289.17 581.379,1289.17 581.388,1289.17 581.397,1289.17 581.407,1289.17 581.416,1289.17 581.425,1289.17 581.434,1289.17 581.443,1289.17 581.453,1289.17 581.462,1289.17 581.471,1289.17 581.48,1289.17 581.489,1289.17 581.499,1289.17 581.508,1289.17 581.517,1289.17 581.526,1289.17 581.535,1289.17 581.544,1289.17 581.554,1289.17 581.563,1289.17 581.572,1289.17 581.581,1289.17 581.59,1289.17 581.6,1289.17 581.609,1289.16 581.618,1289.16 581.627,1289.16 581.636,1289.16 581.646,1289.16 581.655,1289.16 581.664,1289.16 581.673,1289.16 581.682,1289.16 581.692,1289.16 581.701,1289.16 581.71,1289.16 581.719,1289.16 581.728,1289.16 581.737,1289.16 581.747,1289.16 581.756,1289.16 581.765,1289.16 581.774,1289.16 581.783,1289.16 581.793,1289.16 581.802,1289.16 581.811,1289.16 581.82,1289.16 581.829,1289.16 581.839,1289.16 581.848,1289.16 581.857,1289.16 581.866,1289.16 581.875,1289.16 581.884,1289.16 581.894,1289.16 581.903,1289.16 581.912,1289.16 581.921,1289.16 581.93,1289.16 581.94,1289.16 581.949,1289.16 581.958,1289.16 581.967,1289.16 581.976,1289.16 581.986,1289.16 581.995,1289.16 582.004,1289.16 582.013,1289.16 582.022,1289.16 582.032,1289.16 582.041,1289.15 582.05,1289.15 582.059,1289.15 582.068,1289.15 582.077,1289.15 582.087,1289.15 582.096,1289.15 582.105,1289.15 582.114,1289.15 582.123,1289.15 582.133,1289.15 582.142,1289.15 582.151,1289.15 582.16,1289.15 582.169,1289.15 582.179,1289.15 582.188,1289.15 582.197,1289.15 582.206,1289.15 582.215,1289.15 582.224,1289.15 582.234,1289.15 582.243,1289.15 582.252,1289.15 582.261,1289.15 582.27,1289.15 582.28,1289.15 582.289,1289.15 582.298,1289.15 582.307,1289.15 582.316,1289.15 582.326,1289.15 582.335,1289.15 582.344,1289.15 582.353,1289.15 582.362,1289.15 582.372,1289.15 582.381,1289.15 582.39,1289.15 582.399,1289.15 582.408,1289.15 582.417,1289.15 582.427,1289.15 582.436,1289.15 582.445,1289.15 582.454,1289.15 582.463,1289.15 582.473,1289.14 582.482,1289.14 582.491,1289.14 582.5,1289.14 582.509,1289.14 582.519,1289.14 582.528,1289.14 582.537,1289.14 582.546,1289.14 582.555,1289.14 582.564,1289.14 582.574,1289.14 582.583,1289.14 582.592,1289.14 582.601,1289.14 582.61,1289.14 582.62,1289.14 582.629,1289.14 582.638,1289.14 582.647,1289.14 582.656,1289.14 582.666,1289.14 582.675,1289.14 582.684,1289.14 582.693,1289.14 582.702,1289.14 582.712,1289.14 582.721,1289.14 582.73,1289.14 582.739,1289.14 582.748,1289.14 582.757,1289.14 582.767,1289.14 582.776,1289.14 582.785,1289.14 582.794,1289.14 582.803,1289.14 582.813,1289.14 582.822,1289.14 582.831,1289.14 582.84,1289.14 582.849,1289.14 582.859,1289.14 582.868,1289.14 582.877,1289.14 582.886,1289.14 582.895,1289.14 582.905,1289.14 582.914,1289.13 582.923,1289.13 582.932,1289.13 582.941,1289.13 582.95,1289.13 582.96,1289.13 582.969,1289.13 582.978,1289.13 582.987,1289.13 582.996,1289.13 583.006,1289.13 583.015,1289.13 583.024,1289.13 583.033,1289.13 583.042,1289.13 583.052,1289.13 583.061,1289.13 583.07,1289.13 583.079,1289.13 583.088,1289.13 583.097,1289.13 583.107,1289.13 583.116,1289.13 583.125,1289.13 583.134,1289.13 583.143,1289.13 583.153,1289.13 583.162,1289.13 583.171,1289.13 583.18,1289.13 583.189,1289.13 583.199,1289.13 583.208,1289.13 583.217,1289.13 583.226,1289.13 583.235,1289.13 583.245,1289.13 583.254,1289.13 583.263,1289.13 583.272,1289.13 583.281,1289.13 583.29,1289.13 583.3,1289.13 583.309,1289.13 583.318,1289.13 583.327,1289.13 583.336,1289.13 583.346,1289.13 583.355,1289.12 583.364,1289.12 583.373,1289.12 583.382,1289.12 583.392,1289.12 583.401,1289.12 583.41,1289.12 583.419,1289.12 583.428,1289.12 583.437,1289.12 583.447,1289.12 583.456,1289.12 583.465,1289.12 583.474,1289.12 583.483,1289.12 583.493,1289.12 583.502,1289.12 583.511,1289.12 583.52,1289.12 583.529,1289.12 583.539,1289.12 583.548,1289.12 583.557,1289.12 583.566,1289.12 583.575,1289.12 583.585,1289.12 583.594,1289.12 583.603,1289.12 583.612,1289.12 583.621,1289.12 583.63,1289.12 583.64,1289.12 583.649,1289.12 583.658,1289.12 583.667,1289.12 583.676,1289.12 583.686,1289.12 583.695,1289.12 583.704,1289.12 583.713,1289.12 583.722,1289.12 583.732,1289.12 583.741,1289.12 583.75,1289.12 583.759,1289.12 583.768,1289.12 583.777,1289.12 583.787,1289.12 583.796,1289.12 583.805,1289.11 583.814,1289.11 583.823,1289.11 583.833,1289.11 583.842,1289.11 583.851,1289.11 583.86,1289.11 583.869,1289.11 583.879,1289.11 583.888,1289.11 583.897,1289.11 583.906,1289.11 583.915,1289.11 583.925,1289.11 583.934,1289.11 583.943,1289.11 583.952,1289.11 583.961,1289.11 583.97,1289.11 583.98,1289.11 583.989,1289.11 583.998,1289.11 584.007,1289.11 584.016,1289.11 584.026,1289.11 584.035,1289.11 584.044,1289.11 584.053,1289.11 584.062,1289.11 584.072,1289.11 584.081,1289.11 584.09,1289.11 584.099,1289.11 584.108,1289.11 584.117,1289.11 584.127,1289.11 584.136,1289.11 584.145,1289.11 584.154,1289.11 584.163,1289.11 584.173,1289.11 584.182,1289.11 584.191,1289.11 584.2,1289.11 584.209,1289.11 584.219,1289.11 584.228,1289.11 584.237,1289.11 584.246,1289.11 584.255,1289.11 584.265,1289.1 584.274,1289.1 584.283,1289.1 584.292,1289.1 584.301,1289.1 584.31,1289.1 584.32,1289.1 584.329,1289.1 584.338,1289.1 584.347,1289.1 584.356,1289.1 584.366,1289.1 584.375,1289.1 584.384,1289.1 584.393,1289.1 584.402,1289.1 584.412,1289.1 584.421,1289.1 584.43,1289.1 584.439,1289.1 584.448,1289.1 584.457,1289.1 584.467,1289.1 584.476,1289.1 584.485,1289.1 584.494,1289.1 584.503,1289.1 584.513,1289.1 584.522,1289.1 584.531,1289.1 584.54,1289.1 584.549,1289.1 584.559,1289.1 584.568,1289.1 584.577,1289.1 584.586,1289.1 584.595,1289.1 584.605,1289.1 584.614,1289.1 584.623,1289.1 584.632,1289.1 584.641,1289.1 584.65,1289.1 584.66,1289.1 584.669,1289.1 584.678,1289.1 584.687,1289.1 584.696,1289.1 584.706,1289.1 584.715,1289.1 584.724,1289.1 584.733,1289.09 584.742,1289.09 584.752,1289.09 584.761,1289.09 584.77,1289.09 584.779,1289.09 584.788,1289.09 584.797,1289.09 584.807,1289.09 584.816,1289.09 584.825,1289.09 584.834,1289.09 584.843,1289.09 584.853,1289.09 584.862,1289.09 584.871,1289.09 584.88,1289.09 584.889,1289.09 584.899,1289.09 584.908,1289.09 584.917,1289.09 584.926,1289.09 584.935,1289.09 584.945,1289.09 584.954,1289.09 584.963,1289.09 584.972,1289.09 584.981,1289.09 584.99,1289.09 585,1289.09 585.009,1289.09 585.018,1289.09 585.027,1289.09 585.036,1289.09 585.046,1289.09 585.055,1289.09 585.064,1289.09 585.073,1289.09 585.082,1289.09 585.092,1289.09 585.101,1289.09 585.11,1289.09 585.119,1289.09 585.128,1289.09 585.137,1289.09 585.147,1289.09 585.156,1289.09 585.165,1289.09 585.174,1289.09 585.183,1289.09 585.193,1289.09 585.202,1289.09 585.211,1289.08 585.22,1289.08 585.229,1289.08 585.239,1289.08 585.248,1289.08 585.257,1289.08 585.266,1289.08 585.275,1289.08 585.285,1289.08 585.294,1289.08 585.303,1289.08 585.312,1289.08 585.321,1289.08 585.33,1289.08 585.34,1289.08 585.349,1289.08 585.358,1289.08 585.367,1289.08 585.376,1289.08 585.386,1289.08 585.395,1289.08 585.404,1289.08 585.413,1289.08 585.422,1289.08 585.432,1289.08 585.441,1289.08 585.45,1289.08 585.459,1289.08 585.468,1289.08 585.478,1289.08 585.487,1289.08 585.496,1289.08 585.505,1289.08 585.514,1289.08 585.523,1289.08 585.533,1289.08 585.542,1289.08 585.551,1289.08 585.56,1289.08 585.569,1289.08 585.579,1289.08 585.588,1289.08 585.597,1289.08 585.606,1289.08 585.615,1289.08 585.625,1289.08 585.634,1289.08 585.643,1289.08 585.652,1289.08 585.661,1289.08 585.67,1289.08 585.68,1289.08 585.689,1289.08 585.698,1289.07 585.707,1289.07 585.716,1289.07 585.726,1289.07 585.735,1289.07 585.744,1289.07 585.753,1289.07 585.762,1289.07 585.772,1289.07 585.781,1289.07 585.79,1289.07 585.799,1289.07 585.808,1289.07 585.818,1289.07 585.827,1289.07 585.836,1289.07 585.845,1289.07 585.854,1289.07 585.863,1289.07 585.873,1289.07 585.882,1289.07 585.891,1289.07 585.9,1289.07 585.909,1289.07 585.919,1289.07 585.928,1289.07 585.937,1289.07 585.946,1289.07 585.955,1289.07 585.965,1289.07 585.974,1289.07 585.983,1289.07 585.992,1289.07 586.001,1289.07 586.01,1289.07 586.02,1289.07 586.029,1289.07 586.038,1289.07 586.047,1289.07 586.056,1289.07 586.066,1289.07 586.075,1289.07 586.084,1289.07 586.093,1289.07 586.102,1289.07 586.112,1289.07 586.121,1289.07 586.13,1289.07 586.139,1289.07 586.148,1289.07 586.158,1289.07 586.167,1289.07 586.176,1289.07 586.185,1289.06 586.194,1289.06 586.203,1289.06 586.213,1289.06 586.222,1289.06 586.231,1289.06 586.24,1289.06 586.249,1289.06 586.259,1289.06 586.268,1289.06 586.277,1289.06 586.286,1289.06 586.295,1289.06 586.305,1289.06 586.314,1289.06 586.323,1289.06 586.332,1289.06 586.341,1289.06 586.35,1289.06 586.36,1289.06 586.369,1289.06 586.378,1289.06 586.387,1289.06 586.396,1289.06 586.406,1289.06 586.415,1289.06 586.424,1289.06 586.433,1289.06 586.442,1289.06 586.452,1289.06 586.461,1289.06 586.47,1289.06 586.479,1289.06 586.488,1289.06 586.498,1289.06 586.507,1289.06 586.516,1289.06 586.525,1289.06 586.534,1289.06 586.543,1289.06 586.553,1289.06 586.562,1289.06 586.571,1289.06 586.58,1289.06 586.589,1289.06 586.599,1289.06 586.608,1289.06 586.617,1289.06 586.626,1289.06 586.635,1289.06 586.645,1289.06 586.654,1289.06 586.663,1289.06 586.672,1289.06 586.681,1289.06 586.69,1289.05 586.7,1289.05 586.709,1289.05 586.718,1289.05 586.727,1289.05 586.736,1289.05 586.746,1289.05 586.755,1289.05 586.764,1289.05 586.773,1289.05 586.782,1289.05 586.792,1289.05 586.801,1289.05 586.81,1289.05 586.819,1289.05 586.828,1289.05 586.838,1289.05 586.847,1289.05 586.856,1289.05 586.865,1289.05 586.874,1289.05 586.883,1289.05 586.893,1289.05 586.902,1289.05 586.911,1289.05 586.92,1289.05 586.929,1289.05 586.939,1289.05 586.948,1289.05 586.957,1289.05 586.966,1289.05 586.975,1289.05 586.985,1289.05 586.994,1289.05 587.003,1289.05 587.012,1289.05 587.021,1289.05 587.03,1289.05 587.04,1289.05 587.049,1289.05 587.058,1289.05 587.067,1289.05 587.076,1289.05 587.086,1289.05 587.095,1289.05 587.104,1289.05 587.113,1289.05 587.122,1289.05 587.132,1289.05 587.141,1289.05 587.15,1289.05 587.159,1289.05 587.168,1289.05 587.178,1289.05 587.187,1289.05 587.196,1289.04 587.205,1289.04 587.214,1289.04 587.223,1289.04 587.233,1289.04 587.242,1289.04 587.251,1289.04 587.26,1289.04 587.269,1289.04 587.279,1289.04 587.288,1289.04 587.297,1289.04 587.306,1289.04 587.315,1289.04 587.325,1289.04 587.334,1289.04 587.343,1289.04 587.352,1289.04 587.361,1289.04 587.37,1289.04 587.38,1289.04 587.389,1289.04 587.398,1289.04 587.407,1289.04 587.416,1289.04 587.426,1289.04 587.435,1289.04 587.444,1289.04 587.453,1289.04 587.462,1289.04 587.472,1289.04 587.481,1289.04 587.49,1289.04 587.499,1289.04 587.508,1289.04 587.518,1289.04 587.527,1289.04 587.536,1289.04 587.545,1289.04 587.554,1289.04 587.563,1289.04 587.573,1289.04 587.582,1289.04 587.591,1289.04 587.6,1289.04 587.609,1289.04 587.619,1289.04 587.628,1289.04 587.637,1289.04 587.646,1289.04 587.655,1289.04 587.665,1289.04 587.674,1289.04 587.683,1289.04 587.692,1289.04 587.701,1289.04 587.71,1289.04 587.72,1289.03 587.729,1289.03 587.738,1289.03 587.747,1289.03 587.756,1289.03 587.766,1289.03 587.775,1289.03 587.784,1289.03 587.793,1289.03 587.802,1289.03 587.812,1289.03 587.821,1289.03 587.83,1289.03 587.839,1289.03 587.848,1289.03 587.858,1289.03 587.867,1289.03 587.876,1289.03 587.885,1289.03 587.894,1289.03 587.903,1289.03 587.913,1289.03 587.922,1289.03 587.931,1289.03 587.94,1289.03 587.949,1289.03 587.959,1289.03 587.968,1289.03 587.977,1289.03 587.986,1289.03 587.995,1289.03 588.005,1289.03 588.014,1289.03 588.023,1289.03 588.032,1289.03 588.041,1289.03 588.051,1289.03 588.06,1289.03 588.069,1289.03 588.078,1289.03 588.087,1289.03 588.096,1289.03 588.106,1289.03 588.115,1289.03 588.124,1289.03 588.133,1289.03 588.142,1289.03 588.152,1289.03 588.161,1289.03 588.17,1289.03 588.179,1289.03 588.188,1289.03 588.198,1289.03 588.207,1289.03 588.216,1289.03 588.225,1289.03 588.234,1289.03 588.243,1289.03 588.253,1289.02 588.262,1289.02 588.271,1289.02 588.28,1289.02 588.289,1289.02 588.299,1289.02 588.308,1289.02 588.317,1289.02 588.326,1289.02 588.335,1289.02 588.345,1289.02 588.354,1289.02 588.363,1289.02 588.372,1289.02 588.381,1289.02 588.391,1289.02 588.4,1289.02 588.409,1289.02 588.418,1289.02 588.427,1289.02 588.436,1289.02 588.446,1289.02 588.455,1289.02 588.464,1289.02 588.473,1289.02 588.482,1289.02 588.492,1289.02 588.501,1289.02 588.51,1289.02 588.519,1289.02 588.528,1289.02 588.538,1289.02 588.547,1289.02 588.556,1289.02 588.565,1289.02 588.574,1289.02 588.583,1289.02 588.593,1289.02 588.602,1289.02 588.611,1289.02 588.62,1289.02 588.629,1289.02 588.639,1289.02 588.648,1289.02 588.657,1289.02 588.666,1289.02 588.675,1289.02 588.685,1289.02 588.694,1289.02 588.703,1289.02 588.712,1289.02 588.721,1289.02 588.731,1289.02 588.74,1289.02 588.749,1289.02 588.758,1289.02 588.767,1289.02 588.776,1289.02 588.786,1289.02 588.795,1289.02 588.804,1289.01 588.813,1289.01 588.822,1289.01 588.832,1289.01 588.841,1289.01 588.85,1289.01 588.859,1289.01 588.868,1289.01 588.878,1289.01 588.887,1289.01 588.896,1289.01 588.905,1289.01 588.914,1289.01 588.923,1289.01 588.933,1289.01 588.942,1289.01 588.951,1289.01 588.96,1289.01 588.969,1289.01 588.979,1289.01 588.988,1289.01 588.997,1289.01 589.006,1289.01 589.015,1289.01 589.025,1289.01 589.034,1289.01 589.043,1289.01 589.052,1289.01 589.061,1289.01 589.071,1289.01 589.08,1289.01 589.089,1289.01 589.098,1289.01 589.107,1289.01 589.116,1289.01 589.126,1289.01 589.135,1289.01 589.144,1289.01 589.153,1289.01 589.162,1289.01 589.172,1289.01 589.181,1289.01 589.19,1289.01 589.199,1289.01 589.208,1289.01 589.218,1289.01 589.227,1289.01 589.236,1289.01 589.245,1289.01 589.254,1289.01 589.263,1289.01 589.273,1289.01 589.282,1289.01 589.291,1289.01 589.3,1289.01 589.309,1289.01 589.319,1289.01 589.328,1289.01 589.337,1289.01 589.346,1289.01 589.355,1289 589.365,1289 589.374,1289 589.383,1289 589.392,1289 589.401,1289 589.411,1289 589.42,1289 589.429,1289 589.438,1289 589.447,1289 589.456,1289 589.466,1289 589.475,1289 589.484,1289 589.493,1289 589.502,1289 589.512,1289 589.521,1289 589.53,1289 589.539,1289 589.548,1289 589.558,1289 589.567,1289 589.576,1289 589.585,1289 589.594,1289 589.603,1289 589.613,1289 589.622,1289 589.631,1289 589.64,1289 589.649,1289 589.659,1289 589.668,1289 589.677,1289 589.686,1289 589.695,1289 589.705,1289 589.714,1289 589.723,1289 589.732,1289 589.741,1289 589.751,1289 589.76,1289 589.769,1289 589.778,1289 589.787,1289 589.796,1289 589.806,1289 589.815,1289 589.824,1289 589.833,1289 589.842,1289 589.852,1289 589.861,1289 589.87,1289 589.879,1289 589.888,1289 589.898,1289 589.907,1289 589.916,1289 589.925,1289 589.934,1288.99 589.943,1288.99 589.953,1288.99 589.962,1288.99 589.971,1288.99 589.98,1288.99 589.989,1288.99 589.999,1288.99 590.008,1288.99 590.017,1288.99 590.026,1288.99 590.035,1288.99 590.045,1288.99 590.054,1288.99 590.063,1288.99 590.072,1288.99 590.081,1288.99 590.091,1288.99 590.1,1288.99 590.109,1288.99 590.118,1288.99 590.127,1288.99 590.136,1288.99 590.146,1288.99 590.155,1288.99 590.164,1288.99 590.173,1288.99 590.182,1288.99 590.192,1288.99 590.201,1288.99 590.21,1288.99 590.219,1288.99 590.228,1288.99 590.238,1288.99 590.247,1288.99 590.256,1288.99 590.265,1288.99 590.274,1288.99 590.283,1288.99 590.293,1288.99 590.302,1288.99 590.311,1288.99 590.32,1288.99 590.329,1288.99 590.339,1288.99 590.348,1288.99 590.357,1288.99 590.366,1288.99 590.375,1288.99 590.385,1288.99 590.394,1288.99 590.403,1288.99 590.412,1288.99 590.421,1288.99 590.431,1288.99 590.44,1288.99 590.449,1288.99 590.458,1288.99 590.467,1288.99 590.476,1288.99 590.486,1288.99 590.495,1288.99 590.504,1288.99 590.513,1288.98 590.522,1288.98 590.532,1288.98 590.541,1288.98 590.55,1288.98 590.559,1288.98 590.568,1288.98 590.578,1288.98 590.587,1288.98 590.596,1288.98 590.605,1288.98 590.614,1288.98 590.624,1288.98 590.633,1288.98 590.642,1288.98 590.651,1288.98 590.66,1288.98 590.669,1288.98 590.679,1288.98 590.688,1288.98 590.697,1288.98 590.706,1288.98 590.715,1288.98 590.725,1288.98 590.734,1288.98 590.743,1288.98 590.752,1288.98 590.761,1288.98 590.771,1288.98 590.78,1288.98 590.789,1288.98 590.798,1288.98 590.807,1288.98 590.816,1288.98 590.826,1288.98 590.835,1288.98 590.844,1288.98 590.853,1288.98 590.862,1288.98 590.872,1288.98 590.881,1288.98 590.89,1288.98 590.899,1288.98 590.908,1288.98 590.918,1288.98 590.927,1288.98 590.936,1288.98 590.945,1288.98 590.954,1288.98 590.964,1288.98 590.973,1288.98 590.982,1288.98 590.991,1288.98 591,1288.98 591.009,1288.98 591.019,1288.98 591.028,1288.98 591.037,1288.98 591.046,1288.98 591.055,1288.98 591.065,1288.98 591.074,1288.98 591.083,1288.98 591.092,1288.98 591.101,1288.98 591.111,1288.98 591.12,1288.97 591.129,1288.97 591.138,1288.97 591.147,1288.97 591.156,1288.97 591.166,1288.97 591.175,1288.97 591.184,1288.97 591.193,1288.97 591.202,1288.97 591.212,1288.97 591.221,1288.97 591.23,1288.97 591.239,1288.97 591.248,1288.97 591.258,1288.97 591.267,1288.97 591.276,1288.97 591.285,1288.97 591.294,1288.97 591.304,1288.97 591.313,1288.97 591.322,1288.97 591.331,1288.97 591.34,1288.97 591.349,1288.97 591.359,1288.97 591.368,1288.97 591.377,1288.97 591.386,1288.97 591.395,1288.97 591.405,1288.97 591.414,1288.97 591.423,1288.97 591.432,1288.97 591.441,1288.97 591.451,1288.97 591.46,1288.97 591.469,1288.97 591.478,1288.97 591.487,1288.97 591.496,1288.97 591.506,1288.97 591.515,1288.97 591.524,1288.97 591.533,1288.97 591.542,1288.97 591.552,1288.97 591.561,1288.97 591.57,1288.97 591.579,1288.97 591.588,1288.97 591.598,1288.97 591.607,1288.97 591.616,1288.97 591.625,1288.97 591.634,1288.97 591.644,1288.97 591.653,1288.97 591.662,1288.97 591.671,1288.97 591.68,1288.97 591.689,1288.97 591.699,1288.97 591.708,1288.97 591.717,1288.97 591.726,1288.97 591.735,1288.97 591.745,1288.96 591.754,1288.96 591.763,1288.96 591.772,1288.96 591.781,1288.96 591.791,1288.96 591.8,1288.96 591.809,1288.96 591.818,1288.96 591.827,1288.96 591.836,1288.96 591.846,1288.96 591.855,1288.96 591.864,1288.96 591.873,1288.96 591.882,1288.96 591.892,1288.96 591.901,1288.96 591.91,1288.96 591.919,1288.96 591.928,1288.96 591.938,1288.96 591.947,1288.96 591.956,1288.96 591.965,1288.96 591.974,1288.96 591.984,1288.96 591.993,1288.96 592.002,1288.96 592.011,1288.96 592.02,1288.96 592.029,1288.96 592.039,1288.96 592.048,1288.96 592.057,1288.96 592.066,1288.96 592.075,1288.96 592.085,1288.96 592.094,1288.96 592.103,1288.96 592.112,1288.96 592.121,1288.96 592.131,1288.96 592.14,1288.96 592.149,1288.96 592.158,1288.96 592.167,1288.96 592.176,1288.96 592.186,1288.96 592.195,1288.96 592.204,1288.96 592.213,1288.96 592.222,1288.96 592.232,1288.96 592.241,1288.96 592.25,1288.96 592.259,1288.96 592.268,1288.96 592.278,1288.96 592.287,1288.96 592.296,1288.96 592.305,1288.96 592.314,1288.96 592.324,1288.96 592.333,1288.96 592.342,1288.96 592.351,1288.96 592.36,1288.96 592.369,1288.96 592.379,1288.96 592.388,1288.95 592.397,1288.95 592.406,1288.95 592.415,1288.95 592.425,1288.95 592.434,1288.95 592.443,1288.95 592.452,1288.95 592.461,1288.95 592.471,1288.95 592.48,1288.95 592.489,1288.95 592.498,1288.95 592.507,1288.95 592.516,1288.95 592.526,1288.95 592.535,1288.95 592.544,1288.95 592.553,1288.95 592.562,1288.95 592.572,1288.95 592.581,1288.95 592.59,1288.95 592.599,1288.95 592.608,1288.95 592.618,1288.95 592.627,1288.95 592.636,1288.95 592.645,1288.95 592.654,1288.95 592.664,1288.95 592.673,1288.95 592.682,1288.95 592.691,1288.95 592.7,1288.95 592.709,1288.95 592.719,1288.95 592.728,1288.95 592.737,1288.95 592.746,1288.95 592.755,1288.95 592.765,1288.95 592.774,1288.95 592.783,1288.95 592.792,1288.95 592.801,1288.95 592.811,1288.95 592.82,1288.95 592.829,1288.95 592.838,1288.95 592.847,1288.95 592.857,1288.95 592.866,1288.95 592.875,1288.95 592.884,1288.95 592.893,1288.95 592.902,1288.95 592.912,1288.95 592.921,1288.95 592.93,1288.95 592.939,1288.95 592.948,1288.95 592.958,1288.95 592.967,1288.95 592.976,1288.95 592.985,1288.95 592.994,1288.95 593.004,1288.95 593.013,1288.95 593.022,1288.95 593.031,1288.95 593.04,1288.95 593.049,1288.94 593.059,1288.94 593.068,1288.94 593.077,1288.94 593.086,1288.94 593.095,1288.94 593.105,1288.94 593.114,1288.94 593.123,1288.94 593.132,1288.94 593.141,1288.94 593.151,1288.94 593.16,1288.94 593.169,1288.94 593.178,1288.94 593.187,1288.94 593.197,1288.94 593.206,1288.94 593.215,1288.94 593.224,1288.94 593.233,1288.94 593.242,1288.94 593.252,1288.94 593.261,1288.94 593.27,1288.94 593.279,1288.94 593.288,1288.94 593.298,1288.94 593.307,1288.94 593.316,1288.94 593.325,1288.94 593.334,1288.94 593.344,1288.94 593.353,1288.94 593.362,1288.94 593.371,1288.94 593.38,1288.94 593.389,1288.94 593.399,1288.94 593.408,1288.94 593.417,1288.94 593.426,1288.94 593.435,1288.94 593.445,1288.94 593.454,1288.94 593.463,1288.94 593.472,1288.94 593.481,1288.94 593.491,1288.94 593.5,1288.94 593.509,1288.94 593.518,1288.94 593.527,1288.94 593.537,1288.94 593.546,1288.94 593.555,1288.94 593.564,1288.94 593.573,1288.94 593.582,1288.94 593.592,1288.94 593.601,1288.94 593.61,1288.94 593.619,1288.94 593.628,1288.94 593.638,1288.94 593.647,1288.94 593.656,1288.94 593.665,1288.94 593.674,1288.94 593.684,1288.94 593.693,1288.94 593.702,1288.94 593.711,1288.94 593.72,1288.94 593.729,1288.94 593.739,1288.93 593.748,1288.93 593.757,1288.93 593.766,1288.93 593.775,1288.93 593.785,1288.93 593.794,1288.93 593.803,1288.93 593.812,1288.93 593.821,1288.93 593.831,1288.93 593.84,1288.93 593.849,1288.93 593.858,1288.93 593.867,1288.93 593.877,1288.93 593.886,1288.93 593.895,1288.93 593.904,1288.93 593.913,1288.93 593.922,1288.93 593.932,1288.93 593.941,1288.93 593.95,1288.93 593.959,1288.93 593.968,1288.93 593.978,1288.93 593.987,1288.93 593.996,1288.93 594.005,1288.93 594.014,1288.93 594.024,1288.93 594.033,1288.93 594.042,1288.93 594.051,1288.93 594.06,1288.93 594.069,1288.93 594.079,1288.93 594.088,1288.93 594.097,1288.93 594.106,1288.93 594.115,1288.93 594.125,1288.93 594.134,1288.93 594.143,1288.93 594.152,1288.93 594.161,1288.93 594.171,1288.93 594.18,1288.93 594.189,1288.93 594.198,1288.93 594.207,1288.93 594.217,1288.93 594.226,1288.93 594.235,1288.93 594.244,1288.93 594.253,1288.93 594.262,1288.93 594.272,1288.93 594.281,1288.93 594.29,1288.93 594.299,1288.93 594.308,1288.93 594.318,1288.93 594.327,1288.93 594.336,1288.93 594.345,1288.93 594.354,1288.93 594.364,1288.93 594.373,1288.93 594.382,1288.93 594.391,1288.93 594.4,1288.93 594.409,1288.93 594.419,1288.93 594.428,1288.93 594.437,1288.93 594.446,1288.93 594.455,1288.92 594.465,1288.92 594.474,1288.92 594.483,1288.92 594.492,1288.92 594.501,1288.92 594.511,1288.92 594.52,1288.92 594.529,1288.92 594.538,1288.92 594.547,1288.92 594.557,1288.92 594.566,1288.92 594.575,1288.92 594.584,1288.92 594.593,1288.92 594.602,1288.92 594.612,1288.92 594.621,1288.92 594.63,1288.92 594.639,1288.92 594.648,1288.92 594.658,1288.92 594.667,1288.92 594.676,1288.92 594.685,1288.92 594.694,1288.92 594.704,1288.92 594.713,1288.92 594.722,1288.92 594.731,1288.92 594.74,1288.92 594.749,1288.92 594.759,1288.92 594.768,1288.92 594.777,1288.92 594.786,1288.92 594.795,1288.92 594.805,1288.92 594.814,1288.92 594.823,1288.92 594.832,1288.92 594.841,1288.92 594.851,1288.92 594.86,1288.92 594.869,1288.92 594.878,1288.92 594.887,1288.92 594.897,1288.92 594.906,1288.92 594.915,1288.92 594.924,1288.92 594.933,1288.92 594.942,1288.92 594.952,1288.92 594.961,1288.92 594.97,1288.92 594.979,1288.92 594.988,1288.92 594.998,1288.92 595.007,1288.92 595.016,1288.92 595.025,1288.92 595.034,1288.92 595.044,1288.92 595.053,1288.92 595.062,1288.92 595.071,1288.92 595.08,1288.92 595.089,1288.92 595.099,1288.92 595.108,1288.92 595.117,1288.92 595.126,1288.92 595.135,1288.92 595.145,1288.92 595.154,1288.92 595.163,1288.92 595.172,1288.92 595.181,1288.92 595.191,1288.92 595.2,1288.92 595.209,1288.91 595.218,1288.91 595.227,1288.91 595.237,1288.91 595.246,1288.91 595.255,1288.91 595.264,1288.91 595.273,1288.91 595.282,1288.91 595.292,1288.91 595.301,1288.91 595.31,1288.91 595.319,1288.91 595.328,1288.91 595.338,1288.91 595.347,1288.91 595.356,1288.91 595.365,1288.91 595.374,1288.91 595.384,1288.91 595.393,1288.91 595.402,1288.91 595.411,1288.91 595.42,1288.91 595.43,1288.91 595.439,1288.91 595.448,1288.91 595.457,1288.91 595.466,1288.91 595.475,1288.91 595.485,1288.91 595.494,1288.91 595.503,1288.91 595.512,1288.91 595.521,1288.91 595.531,1288.91 595.54,1288.91 595.549,1288.91 595.558,1288.91 595.567,1288.91 595.577,1288.91 595.586,1288.91 595.595,1288.91 595.604,1288.91 595.613,1288.91 595.622,1288.91 595.632,1288.91 595.641,1288.91 595.65,1288.91 595.659,1288.91 595.668,1288.91 595.678,1288.91 595.687,1288.91 595.696,1288.91 595.705,1288.91 595.714,1288.91 595.724,1288.91 595.733,1288.91 595.742,1288.91 595.751,1288.91 595.76,1288.91 595.77,1288.91 595.779,1288.91 595.788,1288.91 595.797,1288.91 595.806,1288.91 595.815,1288.91 595.825,1288.91 595.834,1288.91 595.843,1288.91 595.852,1288.91 595.861,1288.91 595.871,1288.91 595.88,1288.91 595.889,1288.91 595.898,1288.91 595.907,1288.91 595.917,1288.91 595.926,1288.91 595.935,1288.91 595.944,1288.91 595.953,1288.91 595.962,1288.91 595.972,1288.91 595.981,1288.91 595.99,1288.91 595.999,1288.9 596.008,1288.9 596.018,1288.9 596.027,1288.9 596.036,1288.9 596.045,1288.9 596.054,1288.9 596.064,1288.9 596.073,1288.9 596.082,1288.9 596.091,1288.9 596.1,1288.9 596.11,1288.9 596.119,1288.9 596.128,1288.9 596.137,1288.9 596.146,1288.9 596.155,1288.9 596.165,1288.9 596.174,1288.9 596.183,1288.9 596.192,1288.9 596.201,1288.9 596.211,1288.9 596.22,1288.9 596.229,1288.9 596.238,1288.9 596.247,1288.9 596.257,1288.9 596.266,1288.9 596.275,1288.9 596.284,1288.9 596.293,1288.9 596.302,1288.9 596.312,1288.9 596.321,1288.9 596.33,1288.9 596.339,1288.9 596.348,1288.9 596.358,1288.9 596.367,1288.9 596.376,1288.9 596.385,1288.9 596.394,1288.9 596.404,1288.9 596.413,1288.9 596.422,1288.9 596.431,1288.9 596.44,1288.9 596.45,1288.9 596.459,1288.9 596.468,1288.9 596.477,1288.9 596.486,1288.9 596.495,1288.9 596.505,1288.9 596.514,1288.9 596.523,1288.9 596.532,1288.9 596.541,1288.9 596.551,1288.9 596.56,1288.9 596.569,1288.9 596.578,1288.9 596.587,1288.9 596.597,1288.9 596.606,1288.9 596.615,1288.9 596.624,1288.9 596.633,1288.9 596.642,1288.9 596.652,1288.9 596.661,1288.9 596.67,1288.9 596.679,1288.9 596.688,1288.9 596.698,1288.9 596.707,1288.9 596.716,1288.9 596.725,1288.9 596.734,1288.9 596.744,1288.9 596.753,1288.9 596.762,1288.9 596.771,1288.9 596.78,1288.9 596.79,1288.9 596.799,1288.9 596.808,1288.9 596.817,1288.9 596.826,1288.9 596.835,1288.89 596.845,1288.89 596.854,1288.89 596.863,1288.89 596.872,1288.89 596.881,1288.89 596.891,1288.89 596.9,1288.89 596.909,1288.89 596.918,1288.89 596.927,1288.89 596.937,1288.89 596.946,1288.89 596.955,1288.89 596.964,1288.89 596.973,1288.89 596.982,1288.89 596.992,1288.89 597.001,1288.89 597.01,1288.89 597.019,1288.89 597.028,1288.89 597.038,1288.89 597.047,1288.89 597.056,1288.89 597.065,1288.89 597.074,1288.89 597.084,1288.89 597.093,1288.89 597.102,1288.89 597.111,1288.89 597.12,1288.89 597.13,1288.89 597.139,1288.89 597.148,1288.89 597.157,1288.89 597.166,1288.89 597.175,1288.89 597.185,1288.89 597.194,1288.89 597.203,1288.89 597.212,1288.89 597.221,1288.89 597.231,1288.89 597.24,1288.89 597.249,1288.89 597.258,1288.89 597.267,1288.89 597.277,1288.89 597.286,1288.89 597.295,1288.89 597.304,1288.89 597.313,1288.89 597.322,1288.89 597.332,1288.89 597.341,1288.89 597.35,1288.89 597.359,1288.89 597.368,1288.89 597.378,1288.89 597.387,1288.89 597.396,1288.89 597.405,1288.89 597.414,1288.89 597.424,1288.89 597.433,1288.89 597.442,1288.89 597.451,1288.89 597.46,1288.89 597.47,1288.89 597.479,1288.89 597.488,1288.89 597.497,1288.89 597.506,1288.89 597.515,1288.89 597.525,1288.89 597.534,1288.89 597.543,1288.89 597.552,1288.89 597.561,1288.89 597.571,1288.89 597.58,1288.89 597.589,1288.89 597.598,1288.89 597.607,1288.89 597.617,1288.89 597.626,1288.89 597.635,1288.89 597.644,1288.89 597.653,1288.89 597.662,1288.89 597.672,1288.89 597.681,1288.89 597.69,1288.89 597.699,1288.89 597.708,1288.89 597.718,1288.88 597.727,1288.88 597.736,1288.88 597.745,1288.88 597.754,1288.88 597.764,1288.88 597.773,1288.88 597.782,1288.88 597.791,1288.88 597.8,1288.88 597.81,1288.88 597.819,1288.88 597.828,1288.88 597.837,1288.88 597.846,1288.88 597.855,1288.88 597.865,1288.88 597.874,1288.88 597.883,1288.88 597.892,1288.88 597.901,1288.88 597.911,1288.88 597.92,1288.88 597.929,1288.88 597.938,1288.88 597.947,1288.88 597.957,1288.88 597.966,1288.88 597.975,1288.88 597.984,1288.88 597.993,1288.88 598.003,1288.88 598.012,1288.88 598.021,1288.88 598.03,1288.88 598.039,1288.88 598.048,1288.88 598.058,1288.88 598.067,1288.88 598.076,1288.88 598.085,1288.88 598.094,1288.88 598.104,1288.88 598.113,1288.88 598.122,1288.88 598.131,1288.88 598.14,1288.88 598.15,1288.88 598.159,1288.88 598.168,1288.88 598.177,1288.88 598.186,1288.88 598.195,1288.88 598.205,1288.88 598.214,1288.88 598.223,1288.88 598.232,1288.88 598.241,1288.88 598.251,1288.88 598.26,1288.88 598.269,1288.88 598.278,1288.88 598.287,1288.88 598.297,1288.88 598.306,1288.88 598.315,1288.88 598.324,1288.88 598.333,1288.88 598.343,1288.88 598.352,1288.88 598.361,1288.88 598.37,1288.88 598.379,1288.88 598.388,1288.88 598.398,1288.88 598.407,1288.88 598.416,1288.88 598.425,1288.88 598.434,1288.88 598.444,1288.88 598.453,1288.88 598.462,1288.88 598.471,1288.88 598.48,1288.88 598.49,1288.88 598.499,1288.88 598.508,1288.88 598.517,1288.88 598.526,1288.88 598.535,1288.88 598.545,1288.88 598.554,1288.88 598.563,1288.88 598.572,1288.88 598.581,1288.88 598.591,1288.88 598.6,1288.88 598.609,1288.88 598.618,1288.88 598.627,1288.88 598.637,1288.88 598.646,1288.88 598.655,1288.88 598.664,1288.88 598.673,1288.87 598.683,1288.87 598.692,1288.87 598.701,1288.87 598.71,1288.87 598.719,1288.87 598.728,1288.87 598.738,1288.87 598.747,1288.87 598.756,1288.87 598.765,1288.87 598.774,1288.87 598.784,1288.87 598.793,1288.87 598.802,1288.87 598.811,1288.87 598.82,1288.87 598.83,1288.87 598.839,1288.87 598.848,1288.87 598.857,1288.87 598.866,1288.87 598.875,1288.87 598.885,1288.87 598.894,1288.87 598.903,1288.87 598.912,1288.87 598.921,1288.87 598.931,1288.87 598.94,1288.87 598.949,1288.87 598.958,1288.87 598.967,1288.87 598.977,1288.87 598.986,1288.87 598.995,1288.87 599.004,1288.87 599.013,1288.87 599.023,1288.87 599.032,1288.87 599.041,1288.87 599.05,1288.87 599.059,1288.87 599.068,1288.87 599.078,1288.87 599.087,1288.87 599.096,1288.87 599.105,1288.87 599.114,1288.87 599.124,1288.87 599.133,1288.87 599.142,1288.87 599.151,1288.87 599.16,1288.87 599.17,1288.87 599.179,1288.87 599.188,1288.87 599.197,1288.87 599.206,1288.87 599.215,1288.87 599.225,1288.87 599.234,1288.87 599.243,1288.87 599.252,1288.87 599.261,1288.87 599.271,1288.87 599.28,1288.87 599.289,1288.87 599.298,1288.87 599.307,1288.87 599.317,1288.87 599.326,1288.87 599.335,1288.87 599.344,1288.87 599.353,1288.87 599.363,1288.87 599.372,1288.87 599.381,1288.87 599.39,1288.87 599.399,1288.87 599.408,1288.87 599.418,1288.87 599.427,1288.87 599.436,1288.87 599.445,1288.87 599.454,1288.87 599.464,1288.87 599.473,1288.87 599.482,1288.87 599.491,1288.87 599.5,1288.87 599.51,1288.87 599.519,1288.87 599.528,1288.87 599.537,1288.87 599.546,1288.87 599.555,1288.87 599.565,1288.87 599.574,1288.87 599.583,1288.87 599.592,1288.87 599.601,1288.87 599.611,1288.87 599.62,1288.87 599.629,1288.87 599.638,1288.87 599.647,1288.87 599.657,1288.87 599.666,1288.87 599.675,1288.87 599.684,1288.87 599.693,1288.87 599.703,1288.87 599.712,1288.87 599.721,1288.86 599.73,1288.86 599.739,1288.86 599.748,1288.86 599.758,1288.86 599.767,1288.86 599.776,1288.86 599.785,1288.86 599.794,1288.86 599.804,1288.86 599.813,1288.86 599.822,1288.86 599.831,1288.86 599.84,1288.86 599.85,1288.86 599.859,1288.86 599.868,1288.86 599.877,1288.86 599.886,1288.86 599.895,1288.86 599.905,1288.86 599.914,1288.86 599.923,1288.86 599.932,1288.86 599.941,1288.86 599.951,1288.86 599.96,1288.86 599.969,1288.86 599.978,1288.86 599.987,1288.86 599.997,1288.86 600.006,1288.86 600.015,1288.86 600.024,1288.86 600.033,1288.86 600.043,1288.86 600.052,1288.86 600.061,1288.86 600.07,1288.86 600.079,1288.86 600.088,1288.86 600.098,1288.86 600.107,1288.86 600.116,1288.86 600.125,1288.86 600.134,1288.86 600.144,1288.86 600.153,1288.86 600.162,1288.86 600.171,1288.86 600.18,1288.86 600.19,1288.86 600.199,1288.86 600.208,1288.86 600.217,1288.86 600.226,1288.86 600.236,1288.86 600.245,1288.86 600.254,1288.86 600.263,1288.86 600.272,1288.86 600.281,1288.86 600.291,1288.86 600.3,1288.86 600.309,1288.86 600.318,1288.86 600.327,1288.86 600.337,1288.86 600.346,1288.86 600.355,1288.86 600.364,1288.86 600.373,1288.86 600.383,1288.86 600.392,1288.86 600.401,1288.86 600.41,1288.86 600.419,1288.86 600.428,1288.86 600.438,1288.86 600.447,1288.86 600.456,1288.86 600.465,1288.86 600.474,1288.86 600.484,1288.86 600.493,1288.86 600.502,1288.86 600.511,1288.86 600.52,1288.86 600.53,1288.86 600.539,1288.86 600.548,1288.86 600.557,1288.86 600.566,1288.86 600.576,1288.86 600.585,1288.86 600.594,1288.86 600.603,1288.86 600.612,1288.86 600.621,1288.86 600.631,1288.86 600.64,1288.86 600.649,1288.86 600.658,1288.86 600.667,1288.86 600.677,1288.86 600.686,1288.86 600.695,1288.86 600.704,1288.86 600.713,1288.86 600.723,1288.86 600.732,1288.86 600.741,1288.86 600.75,1288.86 600.759,1288.86 600.768,1288.86 600.778,1288.86 600.787,1288.86 600.796,1288.86 600.805,1288.86 600.814,1288.86 600.824,1288.86 600.833,1288.86 600.842,1288.86 600.851,1288.86 600.86,1288.86 600.87,1288.86 600.879,1288.86 600.888,1288.85 600.897,1288.85 600.906,1288.85 600.916,1288.85 600.925,1288.85 600.934,1288.85 600.943,1288.85 600.952,1288.85 600.961,1288.85 600.971,1288.85 600.98,1288.85 600.989,1288.85 600.998,1288.85 601.007,1288.85 601.017,1288.85 601.026,1288.85 601.035,1288.85 601.044,1288.85 601.053,1288.85 601.063,1288.85 601.072,1288.85 601.081,1288.85 601.09,1288.85 601.099,1288.85 601.108,1288.85 601.118,1288.85 601.127,1288.85 601.136,1288.85 601.145,1288.85 601.154,1288.85 601.164,1288.85 601.173,1288.85 601.182,1288.85 601.191,1288.85 601.2,1288.85 601.21,1288.85 601.219,1288.85 601.228,1288.85 601.237,1288.85 601.246,1288.85 601.256,1288.85 601.265,1288.85 601.274,1288.85 601.283,1288.85 601.292,1288.85 601.301,1288.85 601.311,1288.85 601.32,1288.85 601.329,1288.85 601.338,1288.85 601.347,1288.85 601.357,1288.85 601.366,1288.85 601.375,1288.85 601.384,1288.85 601.393,1288.85 601.403,1288.85 601.412,1288.85 601.421,1288.85 601.43,1288.85 601.439,1288.85 601.448,1288.85 601.458,1288.85 601.467,1288.85 601.476,1288.85 601.485,1288.85 601.494,1288.85 601.504,1288.85 601.513,1288.85 601.522,1288.85 601.531,1288.85 601.54,1288.85 601.55,1288.85 601.559,1288.85 601.568,1288.85 601.577,1288.85 601.586,1288.85 601.596,1288.85 601.605,1288.85 601.614,1288.85 601.623,1288.85 601.632,1288.85 601.641,1288.85 601.651,1288.85 601.66,1288.85 601.669,1288.85 601.678,1288.85 601.687,1288.85 601.697,1288.85 601.706,1288.85 601.715,1288.85 601.724,1288.85 601.733,1288.85 601.743,1288.85 601.752,1288.85 601.761,1288.85 601.77,1288.85 601.779,1288.85 601.788,1288.85 601.798,1288.85 601.807,1288.85 601.816,1288.85 601.825,1288.85 601.834,1288.85 601.844,1288.85 601.853,1288.85 601.862,1288.85 601.871,1288.85 601.88,1288.85 601.89,1288.85 601.899,1288.85 601.908,1288.85 601.917,1288.85 601.926,1288.85 601.936,1288.85 601.945,1288.85 601.954,1288.85 601.963,1288.85 601.972,1288.85 601.981,1288.85 601.991,1288.85 602,1288.85 602.009,1288.85 602.018,1288.85 602.027,1288.85 602.037,1288.85 602.046,1288.85 602.055,1288.85 602.064,1288.85 602.073,1288.85 602.083,1288.85 602.092,1288.85 602.101,1288.85 602.11,1288.85 602.119,1288.85 602.128,1288.85 602.138,1288.85 602.147,1288.85 602.156,1288.85 602.165,1288.85 602.174,1288.85 602.184,1288.85 602.193,1288.85 602.202,1288.85 602.211,1288.85 602.22,1288.85 602.23,1288.84 602.239,1288.84 602.248,1288.84 602.257,1288.84 602.266,1288.84 602.276,1288.84 602.285,1288.84 602.294,1288.84 602.303,1288.84 602.312,1288.84 602.321,1288.84 602.331,1288.84 602.34,1288.84 602.349,1288.84 602.358,1288.84 602.367,1288.84 602.377,1288.84 602.386,1288.84 602.395,1288.84 602.404,1288.84 602.413,1288.84 602.423,1288.84 602.432,1288.84 602.441,1288.84 602.45,1288.84 602.459,1288.84 602.468,1288.84 602.478,1288.84 602.487,1288.84 602.496,1288.84 602.505,1288.84 602.514,1288.84 602.524,1288.84 602.533,1288.84 602.542,1288.84 602.551,1288.84 602.56,1288.84 602.57,1288.84 602.579,1288.84 602.588,1288.84 602.597,1288.84 602.606,1288.84 602.616,1288.84 602.625,1288.84 602.634,1288.84 602.643,1288.84 602.652,1288.84 602.661,1288.84 602.671,1288.84 602.68,1288.84 602.689,1288.84 602.698,1288.84 602.707,1288.84 602.717,1288.84 602.726,1288.84 602.735,1288.84 602.744,1288.84 602.753,1288.84 602.763,1288.84 602.772,1288.84 602.781,1288.84 602.79,1288.84 602.799,1288.84 602.809,1288.84 602.818,1288.84 602.827,1288.84 602.836,1288.84 602.845,1288.84 602.854,1288.84 602.864,1288.84 602.873,1288.84 602.882,1288.84 602.891,1288.84 602.9,1288.84 602.91,1288.84 602.919,1288.84 602.928,1288.84 602.937,1288.84 602.946,1288.84 602.956,1288.84 602.965,1288.84 602.974,1288.84 602.983,1288.84 602.992,1288.84 603.001,1288.84 603.011,1288.84 603.02,1288.84 603.029,1288.84 603.038,1288.84 603.047,1288.84 603.057,1288.84 603.066,1288.84 603.075,1288.84 603.084,1288.84 603.093,1288.84 603.103,1288.84 603.112,1288.84 603.121,1288.84 603.13,1288.84 603.139,1288.84 603.149,1288.84 603.158,1288.84 603.167,1288.84 603.176,1288.84 603.185,1288.84 603.194,1288.84 603.204,1288.84 603.213,1288.84 603.222,1288.84 603.231,1288.84 603.24,1288.84 603.25,1288.84 603.259,1288.84 603.268,1288.84 603.277,1288.84 603.286,1288.84 603.296,1288.84 603.305,1288.84 603.314,1288.84 603.323,1288.84 603.332,1288.84 603.341,1288.84 603.351,1288.84 603.36,1288.84 603.369,1288.84 603.378,1288.84 603.387,1288.84 603.397,1288.84 603.406,1288.84 603.415,1288.84 603.424,1288.84 603.433,1288.84 603.443,1288.84 603.452,1288.84 603.461,1288.84 603.47,1288.84 603.479,1288.84 603.489,1288.84 603.498,1288.84 603.507,1288.84 603.516,1288.84 603.525,1288.84 603.534,1288.84 603.544,1288.84 603.553,1288.84 603.562,1288.84 603.571,1288.84 603.58,1288.84 603.59,1288.84 603.599,1288.84 603.608,1288.84 603.617,1288.84 603.626,1288.84 603.636,1288.84 603.645,1288.84 603.654,1288.84 603.663,1288.84 603.672,1288.84 603.681,1288.84 603.691,1288.84 603.7,1288.84 603.709,1288.84 603.718,1288.84 603.727,1288.84 603.737,1288.84 603.746,1288.84 603.755,1288.84 603.764,1288.84 603.773,1288.84 603.783,1288.84 603.792,1288.84 603.801,1288.84 603.81,1288.84 603.819,1288.84 603.829,1288.84 603.838,1288.84 603.847,1288.84 603.856,1288.84 603.865,1288.84 603.874,1288.84 603.884,1288.84 603.893,1288.83 603.902,1288.83 603.911,1288.83 603.92,1288.83 603.93,1288.83 603.939,1288.83 603.948,1288.83 603.957,1288.83 603.966,1288.83 603.976,1288.83 603.985,1288.83 603.994,1288.83 604.003,1288.83 604.012,1288.83 604.021,1288.83 604.031,1288.83 604.04,1288.83 604.049,1288.83 604.058,1288.83 604.067,1288.83 604.077,1288.83 604.086,1288.83 604.095,1288.83 604.104,1288.83 604.113,1288.83 604.123,1288.83 604.132,1288.83 604.141,1288.83 604.15,1288.83 604.159,1288.83 604.169,1288.83 604.178,1288.83 604.187,1288.83 604.196,1288.83 604.205,1288.83 604.214,1288.83 604.224,1288.83 604.233,1288.83 604.242,1288.83 604.251,1288.83 604.26,1288.83 604.27,1288.83 604.279,1288.83 604.288,1288.83 604.297,1288.83 604.306,1288.83 604.316,1288.83 604.325,1288.83 604.334,1288.83 604.343,1288.83 604.352,1288.83 604.361,1288.83 604.371,1288.83 604.38,1288.83 604.389,1288.83 604.398,1288.83 604.407,1288.83 604.417,1288.83 604.426,1288.83 604.435,1288.83 604.444,1288.83 604.453,1288.83 604.463,1288.83 604.472,1288.83 604.481,1288.83 604.49,1288.83 604.499,1288.83 604.509,1288.83 604.518,1288.83 604.527,1288.83 604.536,1288.83 604.545,1288.83 604.554,1288.83 604.564,1288.83 604.573,1288.83 604.582,1288.83 604.591,1288.83 604.6,1288.83 604.61,1288.83 604.619,1288.83 604.628,1288.83 604.637,1288.83 604.646,1288.83 604.656,1288.83 604.665,1288.83 604.674,1288.83 604.683,1288.83 604.692,1288.83 604.701,1288.83 604.711,1288.83 604.72,1288.83 604.729,1288.83 604.738,1288.83 604.747,1288.83 604.757,1288.83 604.766,1288.83 604.775,1288.83 604.784,1288.83 604.793,1288.83 604.803,1288.83 604.812,1288.83 604.821,1288.83 604.83,1288.83 604.839,1288.83 604.849,1288.83 604.858,1288.83 604.867,1288.83 604.876,1288.83 604.885,1288.83 604.894,1288.83 604.904,1288.83 604.913,1288.83 604.922,1288.83 604.931,1288.83 604.94,1288.83 604.95,1288.83 604.959,1288.83 604.968,1288.83 604.977,1288.83 604.986,1288.83 604.996,1288.83 605.005,1288.83 605.014,1288.83 605.023,1288.83 605.032,1288.83 605.041,1288.83 605.051,1288.83 605.06,1288.83 605.069,1288.83 605.078,1288.83 605.087,1288.83 605.097,1288.83 605.106,1288.83 605.115,1288.83 605.124,1288.83 605.133,1288.83 605.143,1288.83 605.152,1288.83 605.161,1288.83 605.17,1288.83 605.179,1288.83 605.189,1288.83 605.198,1288.83 605.207,1288.83 605.216,1288.83 605.225,1288.83 605.234,1288.83 605.244,1288.83 605.253,1288.83 605.262,1288.83 605.271,1288.83 605.28,1288.83 605.29,1288.83 605.299,1288.83 605.308,1288.83 605.317,1288.83 605.326,1288.83 605.336,1288.83 605.345,1288.83 605.354,1288.83 605.363,1288.83 605.372,1288.83 605.382,1288.83 605.391,1288.83 605.4,1288.83 605.409,1288.83 605.418,1288.83 605.427,1288.83 605.437,1288.83 605.446,1288.83 605.455,1288.83 605.464,1288.83 605.473,1288.83 605.483,1288.83 605.492,1288.83 605.501,1288.83 605.51,1288.83 605.519,1288.83 605.529,1288.83 605.538,1288.83 605.547,1288.83 605.556,1288.83 605.565,1288.83 605.574,1288.83 605.584,1288.83 605.593,1288.83 605.602,1288.83 605.611,1288.83 605.62,1288.83 605.63,1288.83 605.639,1288.83 605.648,1288.83 605.657,1288.83 605.666,1288.83 605.676,1288.83 605.685,1288.83 605.694,1288.83 605.703,1288.83 605.712,1288.83 605.722,1288.83 605.731,1288.83 605.74,1288.83 605.749,1288.83 605.758,1288.83 605.767,1288.83 605.777,1288.83 605.786,1288.83 605.795,1288.83 605.804,1288.83 605.813,1288.83 605.823,1288.83 605.832,1288.83 605.841,1288.83 605.85,1288.83 605.859,1288.83 605.869,1288.83 605.878,1288.83 605.887,1288.83 605.896,1288.83 605.905,1288.83 605.914,1288.83 605.924,1288.83 605.933,1288.83 605.942,1288.83 605.951,1288.83 605.96,1288.83 605.97,1288.83 605.979,1288.83 605.988,1288.83 605.997,1288.83 606.006,1288.83 606.016,1288.83 606.025,1288.83 606.034,1288.83 606.043,1288.83 606.052,1288.83 606.062,1288.83 606.071,1288.83 606.08,1288.83 606.089,1288.83 606.098,1288.83 606.107,1288.83 606.117,1288.83 606.126,1288.83 606.135,1288.83 606.144,1288.83 606.153,1288.83 606.163,1288.83 606.172,1288.83 606.181,1288.83 606.19,1288.83 606.199,1288.83 606.209,1288.83 606.218,1288.83 606.227,1288.83 606.236,1288.83 606.245,1288.83 606.254,1288.83 606.264,1288.83 606.273,1288.83 606.282,1288.83 606.291,1288.83 606.3,1288.83 606.31,1288.83 606.319,1288.83 606.328,1288.83 606.337,1288.83 606.346,1288.83 606.356,1288.83 606.365,1288.83 606.374,1288.83 606.383,1288.83 606.392,1288.83 606.402,1288.83 606.411,1288.83 606.42,1288.83 606.429,1288.82 606.438,1288.82 606.447,1288.82 606.457,1288.82 606.466,1288.82 606.475,1288.82 606.484,1288.82 606.493,1288.82 606.503,1288.82 606.512,1288.82 606.521,1288.82 606.53,1288.82 606.539,1288.82 606.549,1288.82 606.558,1288.82 606.567,1288.82 606.576,1288.82 606.585,1288.82 606.594,1288.82 606.604,1288.82 606.613,1288.82 606.622,1288.82 606.631,1288.82 606.64,1288.82 606.65,1288.82 606.659,1288.82 606.668,1288.82 606.677,1288.82 606.686,1288.82 606.696,1288.82 606.705,1288.82 606.714,1288.82 606.723,1288.82 606.732,1288.82 606.742,1288.82 606.751,1288.82 606.76,1288.82 606.769,1288.82 606.778,1288.82 606.787,1288.82 606.797,1288.82 606.806,1288.82 606.815,1288.82 606.824,1288.82 606.833,1288.82 606.843,1288.82 606.852,1288.82 606.861,1288.82 606.87,1288.82 606.879,1288.82 606.889,1288.82 606.898,1288.82 606.907,1288.82 606.916,1288.82 606.925,1288.82 606.934,1288.82 606.944,1288.82 606.953,1288.82 606.962,1288.82 606.971,1288.82 606.98,1288.82 606.99,1288.82 606.999,1288.82 607.008,1288.82 607.017,1288.82 607.026,1288.82 607.036,1288.82 607.045,1288.82 607.054,1288.82 607.063,1288.82 607.072,1288.82 607.082,1288.82 607.091,1288.82 607.1,1288.82 607.109,1288.82 607.118,1288.82 607.127,1288.82 607.137,1288.82 607.146,1288.82 607.155,1288.82 607.164,1288.82 607.173,1288.82 607.183,1288.82 607.192,1288.82 607.201,1288.82 607.21,1288.82 607.219,1288.82 607.229,1288.82 607.238,1288.82 607.247,1288.82 607.256,1288.82 607.265,1288.82 607.274,1288.82 607.284,1288.82 607.293,1288.82 607.302,1288.82 607.311,1288.82 607.32,1288.82 607.33,1288.82 607.339,1288.82 607.348,1288.82 607.357,1288.82 607.366,1288.82 607.376,1288.82 607.385,1288.82 607.394,1288.82 607.403,1288.82 607.412,1288.82 607.422,1288.82 607.431,1288.82 607.44,1288.82 607.449,1288.82 607.458,1288.82 607.467,1288.82 607.477,1288.82 607.486,1288.82 607.495,1288.82 607.504,1288.82 607.513,1288.82 607.523,1288.82 607.532,1288.82 607.541,1288.82 607.55,1288.82 607.559,1288.82 607.569,1288.82 607.578,1288.82 607.587,1288.82 607.596,1288.82 607.605,1288.82 607.615,1288.82 607.624,1288.82 607.633,1288.82 607.642,1288.82 607.651,1288.82 607.66,1288.82 607.67,1288.82 607.679,1288.82 607.688,1288.82 607.697,1288.82 607.706,1288.82 607.716,1288.82 607.725,1288.82 607.734,1288.82 607.743,1288.82 607.752,1288.82 607.762,1288.82 607.771,1288.82 607.78,1288.82 607.789,1288.82 607.798,1288.82 607.807,1288.82 607.817,1288.82 607.826,1288.82 607.835,1288.82 607.844,1288.82 607.853,1288.82 607.863,1288.82 607.872,1288.82 607.881,1288.82 607.89,1288.82 607.899,1288.82 607.909,1288.82 607.918,1288.82 607.927,1288.82 607.936,1288.82 607.945,1288.82 607.955,1288.82 607.964,1288.82 607.973,1288.82 607.982,1288.82 607.991,1288.82 608,1288.82 608.01,1288.82 608.019,1288.82 608.028,1288.82 608.037,1288.82 608.046,1288.82 608.056,1288.82 608.065,1288.82 608.074,1288.82 608.083,1288.82 608.092,1288.82 608.102,1288.82 608.111,1288.82 608.12,1288.82 608.129,1288.82 608.138,1288.82 608.147,1288.82 608.157,1288.82 608.166,1288.82 608.175,1288.82 608.184,1288.82 608.193,1288.82 608.203,1288.82 608.212,1288.82 608.221,1288.82 608.23,1288.82 608.239,1288.82 608.249,1288.82 608.258,1288.82 608.267,1288.82 608.276,1288.82 608.285,1288.82 608.295,1288.82 608.304,1288.82 608.313,1288.82 608.322,1288.82 608.331,1288.82 608.34,1288.82 608.35,1288.82 608.359,1288.82 608.368,1288.82 608.377,1288.82 608.386,1288.82 608.396,1288.82 608.405,1288.82 608.414,1288.82 608.423,1288.82 608.432,1288.82 608.442,1288.82 608.451,1288.82 608.46,1288.82 608.469,1288.82 608.478,1288.82 608.487,1288.82 608.497,1288.82 608.506,1288.82 608.515,1288.82 608.524,1288.82 608.533,1288.82 608.543,1288.82 608.552,1288.82 608.561,1288.82 608.57,1288.82 608.579,1288.82 608.589,1288.82 608.598,1288.82 608.607,1288.82 608.616,1288.82 608.625,1288.82 608.635,1288.82 608.644,1288.82 608.653,1288.82 608.662,1288.82 608.671,1288.82 608.68,1288.82 608.69,1288.82 608.699,1288.82 608.708,1288.82 608.717,1288.82 608.726,1288.82 608.736,1288.82 608.745,1288.82 608.754,1288.82 608.763,1288.82 608.772,1288.82 608.782,1288.82 608.791,1288.82 608.8,1288.82 608.809,1288.82 608.818,1288.82 608.827,1288.82 608.837,1288.82 608.846,1288.82 608.855,1288.82 608.864,1288.82 608.873,1288.82 608.883,1288.82 608.892,1288.82 608.901,1288.82 608.91,1288.82 608.919,1288.82 608.929,1288.82 608.938,1288.82 608.947,1288.82 608.956,1288.82 608.965,1288.82 608.975,1288.82 608.984,1288.82 608.993,1288.82 609.002,1288.82 609.011,1288.82 609.02,1288.82 609.03,1288.82 609.039,1288.82 609.048,1288.82 609.057,1288.82 609.066,1288.82 609.076,1288.82 609.085,1288.82 609.094,1288.82 609.103,1288.82 609.112,1288.82 609.122,1288.82 609.131,1288.82 609.14,1288.82 609.149,1288.82 609.158,1288.82 609.167,1288.82 609.177,1288.82 609.186,1288.82 609.195,1288.82 609.204,1288.82 609.213,1288.82 609.223,1288.82 609.232,1288.82 609.241,1288.82 609.25,1288.82 609.259,1288.82 609.269,1288.82 609.278,1288.82 609.287,1288.82 609.296,1288.82 609.305,1288.82 609.315,1288.82 609.324,1288.82 609.333,1288.82 609.342,1288.82 609.351,1288.82 609.36,1288.82 609.37,1288.82 609.379,1288.82 609.388,1288.82 609.397,1288.82 609.406,1288.82 609.416,1288.82 609.425,1288.82 609.434,1288.82 609.443,1288.82 609.452,1288.82 609.462,1288.82 609.471,1288.82 609.48,1288.82 609.489,1288.82 609.498,1288.82 609.507,1288.82 609.517,1288.82 609.526,1288.82 609.535,1288.82 609.544,1288.82 609.553,1288.82 609.563,1288.82 609.572,1288.82 609.581,1288.82 609.59,1288.82 609.599,1288.82 609.609,1288.82 609.618,1288.82 609.627,1288.82 609.636,1288.82 609.645,1288.82 609.655,1288.82 609.664,1288.82 609.673,1288.82 609.682,1288.82 609.691,1288.82 609.7,1288.82 609.71,1288.82 609.719,1288.82 609.728,1288.82 609.737,1288.82 609.746,1288.82 609.756,1288.82 609.765,1288.82 609.774,1288.82 609.783,1288.82 609.792,1288.82 609.802,1288.82 609.811,1288.82 609.82,1288.82 609.829,1288.82 609.838,1288.82 609.847,1288.82 609.857,1288.82 609.866,1288.82 609.875,1288.82 609.884,1288.82 609.893,1288.82 609.903,1288.82 609.912,1288.82 609.921,1288.82 609.93,1288.82 609.939,1288.82 609.949,1288.82 609.958,1288.82 609.967,1288.82 609.976,1288.82 609.985,1288.82 609.995,1288.82 610.004,1288.82 610.013,1288.82 610.022,1288.82 610.031,1288.82 610.04,1288.82 610.05,1288.82 610.059,1288.82 610.068,1288.82 610.077,1288.82 610.086,1288.82 610.096,1288.82 610.105,1288.82 610.114,1288.82 610.123,1288.82 610.132,1288.82 610.142,1288.82 610.151,1288.82 610.16,1288.82 610.169,1288.82 610.178,1288.82 610.188,1288.82 610.197,1288.82 610.206,1288.82 610.215,1288.82 610.224,1288.82 610.233,1288.82 610.243,1288.82 610.252,1288.82 610.261,1288.82 610.27,1288.82 610.279,1288.82 610.289,1288.82 610.298,1288.82 610.307,1288.82 610.316,1288.82 610.325,1288.82 610.335,1288.82 610.344,1288.82 610.353,1288.82 610.362,1288.82 610.371,1288.82 610.38,1288.82 610.39,1288.82 610.399,1288.82 610.408,1288.82 610.417,1288.82 610.426,1288.82 610.436,1288.82 610.445,1288.82 610.454,1288.82 610.463,1288.82 610.472,1288.82 610.482,1288.82 610.491,1288.82 610.5,1288.82 610.509,1288.82 610.518,1288.82 610.528,1288.82 610.537,1288.82 610.546,1288.82 610.555,1288.82 610.564,1288.82 610.573,1288.82 610.583,1288.82 610.592,1288.82 610.601,1288.82 610.61,1288.82 610.619,1288.82 610.629,1288.82 610.638,1288.82 610.647,1288.82 610.656,1288.82 610.665,1288.82 610.675,1288.82 610.684,1288.82 610.693,1288.82 610.702,1288.82 610.711,1288.82 610.72,1288.82 610.73,1288.82 610.739,1288.82 610.748,1288.82 610.757,1288.82 610.766,1288.82 610.776,1288.82 610.785,1288.82 610.794,1288.82 610.803,1288.82 610.812,1288.82 610.822,1288.82 610.831,1288.82 610.84,1288.82 610.849,1288.82 610.858,1288.82 610.868,1288.82 610.877,1288.82 610.886,1288.82 610.895,1288.82 610.904,1288.82 610.913,1288.82 610.923,1288.82 610.932,1288.82 610.941,1288.82 610.95,1288.82 610.959,1288.82 610.969,1288.82 610.978,1288.82 610.987,1288.82 610.996,1288.82 611.005,1288.82 611.015,1288.82 611.024,1288.82 611.033,1288.82 611.042,1288.82 611.051,1288.82 611.06,1288.82 611.07,1288.82 611.079,1288.82 611.088,1288.82 611.097,1288.82 611.106,1288.82 611.116,1288.82 611.125,1288.82 611.134,1288.82 611.143,1288.82 611.152,1288.82 611.162,1288.82 611.171,1288.82 611.18,1288.82 611.189,1288.82 611.198,1288.82 611.208,1288.82 611.217,1288.82 611.226,1288.82 611.235,1288.82 611.244,1288.82 611.253,1288.82 611.263,1288.82 611.272,1288.82 611.281,1288.82 611.29,1288.82 611.299,1288.82 611.309,1288.82 611.318,1288.82 611.327,1288.83 611.336,1288.83 611.345,1288.83 611.355,1288.83 611.364,1288.83 611.373,1288.83 611.382,1288.83 611.391,1288.83 611.4,1288.83 611.41,1288.83 611.419,1288.83 611.428,1288.83 611.437,1288.83 611.446,1288.83 611.456,1288.83 611.465,1288.83 611.474,1288.83 611.483,1288.83 611.492,1288.83 611.502,1288.83 611.511,1288.83 611.52,1288.83 611.529,1288.83 611.538,1288.83 611.548,1288.83 611.557,1288.83 611.566,1288.83 611.575,1288.83 611.584,1288.83 611.593,1288.83 611.603,1288.83 611.612,1288.83 611.621,1288.83 611.63,1288.83 611.639,1288.83 611.649,1288.83 611.658,1288.83 611.667,1288.83 611.676,1288.83 611.685,1288.83 611.695,1288.83 611.704,1288.83 611.713,1288.83 611.722,1288.83 611.731,1288.83 611.74,1288.83 611.75,1288.83 611.759,1288.83 611.768,1288.83 611.777,1288.83 611.786,1288.83 611.796,1288.83 611.805,1288.83 611.814,1288.83 611.823,1288.83 611.832,1288.83 611.842,1288.83 611.851,1288.83 611.86,1288.83 611.869,1288.83 611.878,1288.83 611.888,1288.83 611.897,1288.83 611.906,1288.83 611.915,1288.83 611.924,1288.83 611.933,1288.83 611.943,1288.83 611.952,1288.83 611.961,1288.83 611.97,1288.83 611.979,1288.83 611.989,1288.83 611.998,1288.83 612.007,1288.83 612.016,1288.83 612.025,1288.83 612.035,1288.83 612.044,1288.83 612.053,1288.83 612.062,1288.83 612.071,1288.83 612.08,1288.83 612.09,1288.83 612.099,1288.83 612.108,1288.83 612.117,1288.83 612.126,1288.83 612.136,1288.83 612.145,1288.83 612.154,1288.83 612.163,1288.83 612.172,1288.83 612.182,1288.83 612.191,1288.83 612.2,1288.83 612.209,1288.83 612.218,1288.83 612.228,1288.83 612.237,1288.83 612.246,1288.83 612.255,1288.83 612.264,1288.83 612.273,1288.83 612.283,1288.83 612.292,1288.83 612.301,1288.83 612.31,1288.83 612.319,1288.83 612.329,1288.83 612.338,1288.83 612.347,1288.83 612.356,1288.83 612.365,1288.83 612.375,1288.83 612.384,1288.83 612.393,1288.83 612.402,1288.83 612.411,1288.83 612.42,1288.83 612.43,1288.83 612.439,1288.83 612.448,1288.83 612.457,1288.83 612.466,1288.83 612.476,1288.83 612.485,1288.83 612.494,1288.83 612.503,1288.83 612.512,1288.83 612.522,1288.83 612.531,1288.83 612.54,1288.83 612.549,1288.83 612.558,1288.83 612.568,1288.83 612.577,1288.83 612.586,1288.83 612.595,1288.83 612.604,1288.83 612.613,1288.83 612.623,1288.83 612.632,1288.83 612.641,1288.83 612.65,1288.83 612.659,1288.83 612.669,1288.83 612.678,1288.83 612.687,1288.83 612.696,1288.83 612.705,1288.83 612.715,1288.83 612.724,1288.83 612.733,1288.83 612.742,1288.83 612.751,1288.83 612.761,1288.83 612.77,1288.83 612.779,1288.83 612.788,1288.83 612.797,1288.83 612.806,1288.83 612.816,1288.83 612.825,1288.83 612.834,1288.83 612.843,1288.83 612.852,1288.83 612.862,1288.83 612.871,1288.83 612.88,1288.83 612.889,1288.83 612.898,1288.83 612.908,1288.83 612.917,1288.83 612.926,1288.83 612.935,1288.83 612.944,1288.83 612.953,1288.83 612.963,1288.83 612.972,1288.83 612.981,1288.83 612.99,1288.83 612.999,1288.83 613.009,1288.83 613.018,1288.83 613.027,1288.83 613.036,1288.83 613.045,1288.83 613.055,1288.83 613.064,1288.83 613.073,1288.83 613.082,1288.83 613.091,1288.83 613.101,1288.83 613.11,1288.83 613.119,1288.83 613.128,1288.83 613.137,1288.83 613.146,1288.83 613.156,1288.83 613.165,1288.83 613.174,1288.83 613.183,1288.83 613.192,1288.83 613.202,1288.83 613.211,1288.83 613.22,1288.83 613.229,1288.83 613.238,1288.83 613.248,1288.83 613.257,1288.83 613.266,1288.83 613.275,1288.83 613.284,1288.83 613.293,1288.83 613.303,1288.83 613.312,1288.83 613.321,1288.83 613.33,1288.83 613.339,1288.83 613.349,1288.83 613.358,1288.83 613.367,1288.83 613.376,1288.83 613.385,1288.83 613.395,1288.83 613.404,1288.83 613.413,1288.83 613.422,1288.83 613.431,1288.83 613.441,1288.83 613.45,1288.83 613.459,1288.83 613.468,1288.83 613.477,1288.83 613.486,1288.83 613.496,1288.83 613.505,1288.83 613.514,1288.83 613.523,1288.83 613.532,1288.83 613.542,1288.83 613.551,1288.83 613.56,1288.83 613.569,1288.83 613.578,1288.83 613.588,1288.83 613.597,1288.83 613.606,1288.83 613.615,1288.83 613.624,1288.83 613.633,1288.83 613.643,1288.83 613.652,1288.83 613.661,1288.83 613.67,1288.83 613.679,1288.83 613.689,1288.83 613.698,1288.83 613.707,1288.84 613.716,1288.84 613.725,1288.84 613.735,1288.84 613.744,1288.84 613.753,1288.84 613.762,1288.84 613.771,1288.84 613.781,1288.84 613.79,1288.84 613.799,1288.84 613.808,1288.84 613.817,1288.84 613.826,1288.84 613.836,1288.84 613.845,1288.84 613.854,1288.84 613.863,1288.84 613.872,1288.84 613.882,1288.84 613.891,1288.84 613.9,1288.84 613.909,1288.84 613.918,1288.84 613.928,1288.84 613.937,1288.84 613.946,1288.84 613.955,1288.84 613.964,1288.84 613.973,1288.84 613.983,1288.84 613.992,1288.84 614.001,1288.84 614.01,1288.84 614.019,1288.84 614.029,1288.84 614.038,1288.84 614.047,1288.84 614.056,1288.84 614.065,1288.84 614.075,1288.84 614.084,1288.84 614.093,1288.84 614.102,1288.84 614.111,1288.84 614.121,1288.84 614.13,1288.84 614.139,1288.84 614.148,1288.84 614.157,1288.84 614.166,1288.84 614.176,1288.84 614.185,1288.84 614.194,1288.84 614.203,1288.84 614.212,1288.84 614.222,1288.84 614.231,1288.84 614.24,1288.84 614.249,1288.84 614.258,1288.84 614.268,1288.84 614.277,1288.84 614.286,1288.84 614.295,1288.84 614.304,1288.84 614.313,1288.84 614.323,1288.84 614.332,1288.84 614.341,1288.84 614.35,1288.84 614.359,1288.84 614.369,1288.84 614.378,1288.84 614.387,1288.84 614.396,1288.84 614.405,1288.84 614.415,1288.84 614.424,1288.84 614.433,1288.84 614.442,1288.84 614.451,1288.84 614.461,1288.84 614.47,1288.84 614.479,1288.84 614.488,1288.84 614.497,1288.84 614.506,1288.84 614.516,1288.84 614.525,1288.84 614.534,1288.84 614.543,1288.84 614.552,1288.84 614.562,1288.84 614.571,1288.84 614.58,1288.84 614.589,1288.84 614.598,1288.84 614.608,1288.84 614.617,1288.84 614.626,1288.84 614.635,1288.84 614.644,1288.84 614.653,1288.84 614.663,1288.84 614.672,1288.84 614.681,1288.84 614.69,1288.84 614.699,1288.84 614.709,1288.84 614.718,1288.84 614.727,1288.84 614.736,1288.84 614.745,1288.84 614.755,1288.84 614.764,1288.84 614.773,1288.84 614.782,1288.84 614.791,1288.84 614.801,1288.84 614.81,1288.84 614.819,1288.84 614.828,1288.84 614.837,1288.84 614.846,1288.84 614.856,1288.84 614.865,1288.84 614.874,1288.84 614.883,1288.84 614.892,1288.84 614.902,1288.84 614.911,1288.84 614.92,1288.84 614.929,1288.84 614.938,1288.84 614.948,1288.84 614.957,1288.84 614.966,1288.84 614.975,1288.84 614.984,1288.84 614.994,1288.84 615.003,1288.84 615.012,1288.84 615.021,1288.84 615.03,1288.84 615.039,1288.84 615.049,1288.84 615.058,1288.84 615.067,1288.84 615.076,1288.84 615.085,1288.84 615.095,1288.84 615.104,1288.84 615.113,1288.84 615.122,1288.84 615.131,1288.84 615.141,1288.84 615.15,1288.84 615.159,1288.84 615.168,1288.84 615.177,1288.84 615.186,1288.84 615.196,1288.84 615.205,1288.85 615.214,1288.85 615.223,1288.85 615.232,1288.85 615.242,1288.85 615.251,1288.85 615.26,1288.85 615.269,1288.85 615.278,1288.85 615.288,1288.85 615.297,1288.85 615.306,1288.85 615.315,1288.85 615.324,1288.85 615.334,1288.85 615.343,1288.85 615.352,1288.85 615.361,1288.85 615.37,1288.85 615.379,1288.85 615.389,1288.85 615.398,1288.85 615.407,1288.85 615.416,1288.85 615.425,1288.85 615.435,1288.85 615.444,1288.85 615.453,1288.85 615.462,1288.85 615.471,1288.85 615.481,1288.85 615.49,1288.85 615.499,1288.85 615.508,1288.85 615.517,1288.85 615.526,1288.85 615.536,1288.85 615.545,1288.85 615.554,1288.85 615.563,1288.85 615.572,1288.85 615.582,1288.85 615.591,1288.85 615.6,1288.85 615.609,1288.85 615.618,1288.85 615.628,1288.85 615.637,1288.85 615.646,1288.85 615.655,1288.85 615.664,1288.85 615.674,1288.85 615.683,1288.85 615.692,1288.85 615.701,1288.85 615.71,1288.85 615.719,1288.85 615.729,1288.85 615.738,1288.85 615.747,1288.85 615.756,1288.85 615.765,1288.85 615.775,1288.85 615.784,1288.85 615.793,1288.85 615.802,1288.85 615.811,1288.85 615.821,1288.85 615.83,1288.85 615.839,1288.85 615.848,1288.85 615.857,1288.85 615.866,1288.85 615.876,1288.85 615.885,1288.85 615.894,1288.85 615.903,1288.85 615.912,1288.85 615.922,1288.85 615.931,1288.85 615.94,1288.85 615.949,1288.85 615.958,1288.85 615.968,1288.85 615.977,1288.85 615.986,1288.85 615.995,1288.85 616.004,1288.85 616.014,1288.85 616.023,1288.85 616.032,1288.85 616.041,1288.85 616.05,1288.85 616.059,1288.85 616.069,1288.85 616.078,1288.85 616.087,1288.85 616.096,1288.85 616.105,1288.85 616.115,1288.85 616.124,1288.85 616.133,1288.85 616.142,1288.85 616.151,1288.85 616.161,1288.85 616.17,1288.85 616.179,1288.85 616.188,1288.85 616.197,1288.85 616.206,1288.85 616.216,1288.85 616.225,1288.85 616.234,1288.85 616.243,1288.85 616.252,1288.85 616.262,1288.85 616.271,1288.85 616.28,1288.85 616.289,1288.85 616.298,1288.85 616.308,1288.85 616.317,1288.85 616.326,1288.85 616.335,1288.85 616.344,1288.85 616.354,1288.85 616.363,1288.85 616.372,1288.85 616.381,1288.85 616.39,1288.86 616.399,1288.86 616.409,1288.86 616.418,1288.86 616.427,1288.86 616.436,1288.86 616.445,1288.86 616.455,1288.86 616.464,1288.86 616.473,1288.86 616.482,1288.86 616.491,1288.86 616.501,1288.86 616.51,1288.86 616.519,1288.86 616.528,1288.86 616.537,1288.86 616.546,1288.86 616.556,1288.86 616.565,1288.86 616.574,1288.86 616.583,1288.86 616.592,1288.86 616.602,1288.86 616.611,1288.86 616.62,1288.86 616.629,1288.86 616.638,1288.86 616.648,1288.86 616.657,1288.86 616.666,1288.86 616.675,1288.86 616.684,1288.86 616.694,1288.86 616.703,1288.86 616.712,1288.86 616.721,1288.86 616.73,1288.86 616.739,1288.86 616.749,1288.86 616.758,1288.86 616.767,1288.86 616.776,1288.86 616.785,1288.86 616.795,1288.86 616.804,1288.86 616.813,1288.86 616.822,1288.86 616.831,1288.86 616.841,1288.86 616.85,1288.86 616.859,1288.86 616.868,1288.86 616.877,1288.86 616.886,1288.86 616.896,1288.86 616.905,1288.86 616.914,1288.86 616.923,1288.86 616.932,1288.86 616.942,1288.86 616.951,1288.86 616.96,1288.86 616.969,1288.86 616.978,1288.86 616.988,1288.86 616.997,1288.86 617.006,1288.86 617.015,1288.86 617.024,1288.86 617.034,1288.86 617.043,1288.86 617.052,1288.86 617.061,1288.86 617.07,1288.86 617.079,1288.86 617.089,1288.86 617.098,1288.86 617.107,1288.86 617.116,1288.86 617.125,1288.86 617.135,1288.86 617.144,1288.86 617.153,1288.86 617.162,1288.86 617.171,1288.86 617.181,1288.86 617.19,1288.86 617.199,1288.86 617.208,1288.86 617.217,1288.86 617.226,1288.86 617.236,1288.86 617.245,1288.86 617.254,1288.86 617.263,1288.86 617.272,1288.86 617.282,1288.86 617.291,1288.86 617.3,1288.86 617.309,1288.86 617.318,1288.86 617.328,1288.86 617.337,1288.86 617.346,1288.86 617.355,1288.86 617.364,1288.86 617.374,1288.86 617.383,1288.86 617.392,1288.86 617.401,1288.87 617.41,1288.87 617.419,1288.87 617.429,1288.87 617.438,1288.87 617.447,1288.87 617.456,1288.87 617.465,1288.87 617.475,1288.87 617.484,1288.87 617.493,1288.87 617.502,1288.87 617.511,1288.87 617.521,1288.87 617.53,1288.87 617.539,1288.87 617.548,1288.87 617.557,1288.87 617.567,1288.87 617.576,1288.87 617.585,1288.87 617.594,1288.87 617.603,1288.87 617.612,1288.87 617.622,1288.87 617.631,1288.87 617.64,1288.87 617.649,1288.87 617.658,1288.87 617.668,1288.87 617.677,1288.87 617.686,1288.87 617.695,1288.87 617.704,1288.87 617.714,1288.87 617.723,1288.87 617.732,1288.87 617.741,1288.87 617.75,1288.87 617.759,1288.87 617.769,1288.87 617.778,1288.87 617.787,1288.87 617.796,1288.87 617.805,1288.87 617.815,1288.87 617.824,1288.87 617.833,1288.87 617.842,1288.87 617.851,1288.87 617.861,1288.87 617.87,1288.87 617.879,1288.87 617.888,1288.87 617.897,1288.87 617.907,1288.87 617.916,1288.87 617.925,1288.87 617.934,1288.87 617.943,1288.87 617.952,1288.87 617.962,1288.87 617.971,1288.87 617.98,1288.87 617.989,1288.87 617.998,1288.87 618.008,1288.87 618.017,1288.87 618.026,1288.87 618.035,1288.87 618.044,1288.87 618.054,1288.87 618.063,1288.87 618.072,1288.87 618.081,1288.87 618.09,1288.87 618.099,1288.87 618.109,1288.87 618.118,1288.87 618.127,1288.87 618.136,1288.87 618.145,1288.87 618.155,1288.87 618.164,1288.87 618.173,1288.87 618.182,1288.87 618.191,1288.87 618.201,1288.87 618.21,1288.87 618.219,1288.87 618.228,1288.87 618.237,1288.87 618.247,1288.87 618.256,1288.87 618.265,1288.87 618.274,1288.87 618.283,1288.88 618.292,1288.88 618.302,1288.88 618.311,1288.88 618.32,1288.88 618.329,1288.88 618.338,1288.88 618.348,1288.88 618.357,1288.88 618.366,1288.88 618.375,1288.88 618.384,1288.88 618.394,1288.88 618.403,1288.88 618.412,1288.88 618.421,1288.88 618.43,1288.88 618.439,1288.88 618.449,1288.88 618.458,1288.88 618.467,1288.88 618.476,1288.88 618.485,1288.88 618.495,1288.88 618.504,1288.88 618.513,1288.88 618.522,1288.88 618.531,1288.88 618.541,1288.88 618.55,1288.88 618.559,1288.88 618.568,1288.88 618.577,1288.88 618.587,1288.88 618.596,1288.88 618.605,1288.88 618.614,1288.88 618.623,1288.88 618.632,1288.88 618.642,1288.88 618.651,1288.88 618.66,1288.88 618.669,1288.88 618.678,1288.88 618.688,1288.88 618.697,1288.88 618.706,1288.88 618.715,1288.88 618.724,1288.88 618.734,1288.88 618.743,1288.88 618.752,1288.88 618.761,1288.88 618.77,1288.88 618.779,1288.88 618.789,1288.88 618.798,1288.88 618.807,1288.88 618.816,1288.88 618.825,1288.88 618.835,1288.88 618.844,1288.88 618.853,1288.88 618.862,1288.88 618.871,1288.88 618.881,1288.88 618.89,1288.88 618.899,1288.88 618.908,1288.88 618.917,1288.88 618.927,1288.88 618.936,1288.88 618.945,1288.88 618.954,1288.88 618.963,1288.88 618.972,1288.88 618.982,1288.88 618.991,1288.88 619,1288.88 619.009,1288.88 619.018,1288.88 619.028,1288.88 619.037,1288.88 619.046,1288.88 619.055,1288.88 619.064,1288.88 619.074,1288.88 619.083,1288.89 619.092,1288.89 619.101,1288.89 619.11,1288.89 619.119,1288.89 619.129,1288.89 619.138,1288.89 619.147,1288.89 619.156,1288.89 619.165,1288.89 619.175,1288.89 619.184,1288.89 619.193,1288.89 619.202,1288.89 619.211,1288.89 619.221,1288.89 619.23,1288.89 619.239,1288.89 619.248,1288.89 619.257,1288.89 619.267,1288.89 619.276,1288.89 619.285,1288.89 619.294,1288.89 619.303,1288.89 619.312,1288.89 619.322,1288.89 619.331,1288.89 619.34,1288.89 619.349,1288.89 619.358,1288.89 619.368,1288.89 619.377,1288.89 619.386,1288.89 619.395,1288.89 619.404,1288.89 619.414,1288.89 619.423,1288.89 619.432,1288.89 619.441,1288.89 619.45,1288.89 619.459,1288.89 619.469,1288.89 619.478,1288.89 619.487,1288.89 619.496,1288.89 619.505,1288.89 619.515,1288.89 619.524,1288.89 619.533,1288.89 619.542,1288.89 619.551,1288.89 619.561,1288.89 619.57,1288.89 619.579,1288.89 619.588,1288.89 619.597,1288.89 619.607,1288.89 619.616,1288.89 619.625,1288.89 619.634,1288.89 619.643,1288.89 619.652,1288.89 619.662,1288.89 619.671,1288.89 619.68,1288.89 619.689,1288.89 619.698,1288.89 619.708,1288.89 619.717,1288.89 619.726,1288.89 619.735,1288.89 619.744,1288.89 619.754,1288.89 619.763,1288.89 619.772,1288.89 619.781,1288.89 619.79,1288.89 619.799,1288.89 619.809,1288.89 619.818,1288.9 619.827,1288.9 619.836,1288.9 619.845,1288.9 619.855,1288.9 619.864,1288.9 619.873,1288.9 619.882,1288.9 619.891,1288.9 619.901,1288.9 619.91,1288.9 619.919,1288.9 619.928,1288.9 619.937,1288.9 619.947,1288.9 619.956,1288.9 619.965,1288.9 619.974,1288.9 619.983,1288.9 619.992,1288.9 620.002,1288.9 620.011,1288.9 620.02,1288.9 620.029,1288.9 620.038,1288.9 620.048,1288.9 620.057,1288.9 620.066,1288.9 620.075,1288.9 620.084,1288.9 620.094,1288.9 620.103,1288.9 620.112,1288.9 620.121,1288.9 620.13,1288.9 620.14,1288.9 620.149,1288.9 620.158,1288.9 620.167,1288.9 620.176,1288.9 620.185,1288.9 620.195,1288.9 620.204,1288.9 620.213,1288.9 620.222,1288.9 620.231,1288.9 620.241,1288.9 620.25,1288.9 620.259,1288.9 620.268,1288.9 620.277,1288.9 620.287,1288.9 620.296,1288.9 620.305,1288.9 620.314,1288.9 620.323,1288.9 620.332,1288.9 620.342,1288.9 620.351,1288.9 620.36,1288.9 620.369,1288.9 620.378,1288.9 620.388,1288.9 620.397,1288.9 620.406,1288.9 620.415,1288.9 620.424,1288.9 620.434,1288.9 620.443,1288.9 620.452,1288.9 620.461,1288.9 620.47,1288.9 620.48,1288.9 620.489,1288.91 620.498,1288.91 620.507,1288.91 620.516,1288.91 620.525,1288.91 620.535,1288.91 620.544,1288.91 620.553,1288.91 620.562,1288.91 620.571,1288.91 620.581,1288.91 620.59,1288.91 620.599,1288.91 620.608,1288.91 620.617,1288.91 620.627,1288.91 620.636,1288.91 620.645,1288.91 620.654,1288.91 620.663,1288.91 620.672,1288.91 620.682,1288.91 620.691,1288.91 620.7,1288.91 620.709,1288.91 620.718,1288.91 620.728,1288.91 620.737,1288.91 620.746,1288.91 620.755,1288.91 620.764,1288.91 620.774,1288.91 620.783,1288.91 620.792,1288.91 620.801,1288.91 620.81,1288.91 620.82,1288.91 620.829,1288.91 620.838,1288.91 620.847,1288.91 620.856,1288.91 620.865,1288.91 620.875,1288.91 620.884,1288.91 620.893,1288.91 620.902,1288.91 620.911,1288.91 620.921,1288.91 620.93,1288.91 620.939,1288.91 620.948,1288.91 620.957,1288.91 620.967,1288.91 620.976,1288.91 620.985,1288.91 620.994,1288.91 621.003,1288.91 621.012,1288.91 621.022,1288.91 621.031,1288.91 621.04,1288.91 621.049,1288.91 621.058,1288.91 621.068,1288.91 621.077,1288.91 621.086,1288.91 621.095,1288.91 621.104,1288.91 621.114,1288.91 621.123,1288.92 621.132,1288.92 621.141,1288.92 621.15,1288.92 621.16,1288.92 621.169,1288.92 621.178,1288.92 621.187,1288.92 621.196,1288.92 621.205,1288.92 621.215,1288.92 621.224,1288.92 621.233,1288.92 621.242,1288.92 621.251,1288.92 621.261,1288.92 621.27,1288.92 621.279,1288.92 621.288,1288.92 621.297,1288.92 621.307,1288.92 621.316,1288.92 621.325,1288.92 621.334,1288.92 621.343,1288.92 621.352,1288.92 621.362,1288.92 621.371,1288.92 621.38,1288.92 621.389,1288.92 621.398,1288.92 621.408,1288.92 621.417,1288.92 621.426,1288.92 621.435,1288.92 621.444,1288.92 621.454,1288.92 621.463,1288.92 621.472,1288.92 621.481,1288.92 621.49,1288.92 621.5,1288.92 621.509,1288.92 621.518,1288.92 621.527,1288.92 621.536,1288.92 621.545,1288.92 621.555,1288.92 621.564,1288.92 621.573,1288.92 621.582,1288.92 621.591,1288.92 621.601,1288.92 621.61,1288.92 621.619,1288.92 621.628,1288.92 621.637,1288.92 621.647,1288.92 621.656,1288.92 621.665,1288.92 621.674,1288.92 621.683,1288.92 621.692,1288.92 621.702,1288.92 621.711,1288.92 621.72,1288.93 621.729,1288.93 621.738,1288.93 621.748,1288.93 621.757,1288.93 621.766,1288.93 621.775,1288.93 621.784,1288.93 621.794,1288.93 621.803,1288.93 621.812,1288.93 621.821,1288.93 621.83,1288.93 621.84,1288.93 621.849,1288.93 621.858,1288.93 621.867,1288.93 621.876,1288.93 621.885,1288.93 621.895,1288.93 621.904,1288.93 621.913,1288.93 621.922,1288.93 621.931,1288.93 621.941,1288.93 621.95,1288.93 621.959,1288.93 621.968,1288.93 621.977,1288.93 621.987,1288.93 621.996,1288.93 622.005,1288.93 622.014,1288.93 622.023,1288.93 622.032,1288.93 622.042,1288.93 622.051,1288.93 622.06,1288.93 622.069,1288.93 622.078,1288.93 622.088,1288.93 622.097,1288.93 622.106,1288.93 622.115,1288.93 622.124,1288.93 622.134,1288.93 622.143,1288.93 622.152,1288.93 622.161,1288.93 622.17,1288.93 622.18,1288.93 622.189,1288.93 622.198,1288.93 622.207,1288.93 622.216,1288.93 622.225,1288.93 622.235,1288.93 622.244,1288.93 622.253,1288.93 622.262,1288.93 622.271,1288.93 622.281,1288.94 622.29,1288.94 622.299,1288.94 622.308,1288.94 622.317,1288.94 622.327,1288.94 622.336,1288.94 622.345,1288.94 622.354,1288.94 622.363,1288.94 622.373,1288.94 622.382,1288.94 622.391,1288.94 622.4,1288.94 622.409,1288.94 622.418,1288.94 622.428,1288.94 622.437,1288.94 622.446,1288.94 622.455,1288.94 622.464,1288.94 622.474,1288.94 622.483,1288.94 622.492,1288.94 622.501,1288.94 622.51,1288.94 622.52,1288.94 622.529,1288.94 622.538,1288.94 622.547,1288.94 622.556,1288.94 622.565,1288.94 622.575,1288.94 622.584,1288.94 622.593,1288.94 622.602,1288.94 622.611,1288.94 622.621,1288.94 622.63,1288.94 622.639,1288.94 622.648,1288.94 622.657,1288.94 622.667,1288.94 622.676,1288.94 622.685,1288.94 622.694,1288.94 622.703,1288.94 622.713,1288.94 622.722,1288.94 622.731,1288.94 622.74,1288.94 622.749,1288.94 622.758,1288.94 622.768,1288.94 622.777,1288.94 622.786,1288.94 622.795,1288.94 622.804,1288.94 622.814,1288.94 622.823,1288.95 622.832,1288.95 622.841,1288.95 622.85,1288.95 622.86,1288.95 622.869,1288.95 622.878,1288.95 622.887,1288.95 622.896,1288.95 622.905,1288.95 622.915,1288.95 622.924,1288.95 622.933,1288.95 622.942,1288.95 622.951,1288.95 622.961,1288.95 622.97,1288.95 622.979,1288.95 622.988,1288.95 622.997,1288.95 623.007,1288.95 623.016,1288.95 623.025,1288.95 623.034,1288.95 623.043,1288.95 623.053,1288.95 623.062,1288.95 623.071,1288.95 623.08,1288.95 623.089,1288.95 623.098,1288.95 623.108,1288.95 623.117,1288.95 623.126,1288.95 623.135,1288.95 623.144,1288.95 623.154,1288.95 623.163,1288.95 623.172,1288.95 623.181,1288.95 623.19,1288.95 623.2,1288.95 623.209,1288.95 623.218,1288.95 623.227,1288.95 623.236,1288.95 623.245,1288.95 623.255,1288.95 623.264,1288.95 623.273,1288.95 623.282,1288.95 623.291,1288.95 623.301,1288.95 623.31,1288.95 623.319,1288.95 623.328,1288.96 623.337,1288.96 623.347,1288.96 623.356,1288.96 623.365,1288.96 623.374,1288.96 623.383,1288.96 623.393,1288.96 623.402,1288.96 623.411,1288.96 623.42,1288.96 623.429,1288.96 623.438,1288.96 623.448,1288.96 623.457,1288.96 623.466,1288.96 623.475,1288.96 623.484,1288.96 623.494,1288.96 623.503,1288.96 623.512,1288.96 623.521,1288.96 623.53,1288.96 623.54,1288.96 623.549,1288.96 623.558,1288.96 623.567,1288.96 623.576,1288.96 623.585,1288.96 623.595,1288.96 623.604,1288.96 623.613,1288.96 623.622,1288.96 623.631,1288.96 623.641,1288.96 623.65,1288.96 623.659,1288.96 623.668,1288.96 623.677,1288.96 623.687,1288.96 623.696,1288.96 623.705,1288.96 623.714,1288.96 623.723,1288.96 623.733,1288.96 623.742,1288.96 623.751,1288.96 623.76,1288.96 623.769,1288.96 623.778,1288.96 623.788,1288.96 623.797,1288.96 623.806,1288.96 623.815,1288.97 623.824,1288.97 623.834,1288.97 623.843,1288.97 623.852,1288.97 623.861,1288.97 623.87,1288.97 623.88,1288.97 623.889,1288.97 623.898,1288.97 623.907,1288.97 623.916,1288.97 623.925,1288.97 623.935,1288.97 623.944,1288.97 623.953,1288.97 623.962,1288.97 623.971,1288.97 623.981,1288.97 623.99,1288.97 623.999,1288.97 624.008,1288.97 624.017,1288.97 624.027,1288.97 624.036,1288.97 624.045,1288.97 624.054,1288.97 624.063,1288.97 624.073,1288.97 624.082,1288.97 624.091,1288.97 624.1,1288.97 624.109,1288.97 624.118,1288.97 624.128,1288.97 624.137,1288.97 624.146,1288.97 624.155,1288.97 624.164,1288.97 624.174,1288.97 624.183,1288.97 624.192,1288.97 624.201,1288.97 624.21,1288.97 624.22,1288.97 624.229,1288.97 624.238,1288.97 624.247,1288.97 624.256,1288.97 624.265,1288.97 624.275,1288.97 624.284,1288.97 624.293,1288.98 624.302,1288.98 624.311,1288.98 624.321,1288.98 624.33,1288.98 624.339,1288.98 624.348,1288.98 624.357,1288.98 624.367,1288.98 624.376,1288.98 624.385,1288.98 624.394,1288.98 624.403,1288.98 624.413,1288.98 624.422,1288.98 624.431,1288.98 624.44,1288.98 624.449,1288.98 624.458,1288.98 624.468,1288.98 624.477,1288.98 624.486,1288.98 624.495,1288.98 624.504,1288.98 624.514,1288.98 624.523,1288.98 624.532,1288.98 624.541,1288.98 624.55,1288.98 624.56,1288.98 624.569,1288.98 624.578,1288.98 624.587,1288.98 624.596,1288.98 624.605,1288.98 624.615,1288.98 624.624,1288.98 624.633,1288.98 624.642,1288.98 624.651,1288.98 624.661,1288.98 624.67,1288.98 624.679,1288.98 624.688,1288.98 624.697,1288.98 624.707,1288.98 624.716,1288.98 624.725,1288.98 624.734,1288.98 624.743,1288.99 624.753,1288.99 624.762,1288.99 624.771,1288.99 624.78,1288.99 624.789,1288.99 624.798,1288.99 624.808,1288.99 624.817,1288.99 624.826,1288.99 624.835,1288.99 624.844,1288.99 624.854,1288.99 624.863,1288.99 624.872,1288.99 624.881,1288.99 624.89,1288.99 624.9,1288.99 624.909,1288.99 624.918,1288.99 624.927,1288.99 624.936,1288.99 624.946,1288.99 624.955,1288.99 624.964,1288.99 624.973,1288.99 624.982,1288.99 624.991,1288.99 625.001,1288.99 625.01,1288.99 625.019,1288.99 625.028,1288.99 625.037,1288.99 625.047,1288.99 625.056,1288.99 625.065,1288.99 625.074,1288.99 625.083,1288.99 625.093,1288.99 625.102,1288.99 625.111,1288.99 625.12,1288.99 625.129,1288.99 625.138,1288.99 625.148,1288.99 625.157,1288.99 625.166,1288.99 625.175,1289 625.184,1289 625.194,1289 625.203,1289 625.212,1289 625.221,1289 625.23,1289 625.24,1289 625.249,1289 625.258,1289 625.267,1289 625.276,1289 625.286,1289 625.295,1289 625.304,1289 625.313,1289 625.322,1289 625.331,1289 625.341,1289 625.35,1289 625.359,1289 625.368,1289 625.377,1289 625.387,1289 625.396,1289 625.405,1289 625.414,1289 625.423,1289 625.433,1289 625.442,1289 625.451,1289 625.46,1289 625.469,1289 625.478,1289 625.488,1289 625.497,1289 625.506,1289 625.515,1289 625.524,1289 625.534,1289 625.543,1289 625.552,1289 625.561,1289 625.57,1289 625.58,1289 625.589,1289 625.598,1289.01 625.607,1289.01 625.616,1289.01 625.626,1289.01 625.635,1289.01 625.644,1289.01 625.653,1289.01 625.662,1289.01 625.671,1289.01 625.681,1289.01 625.69,1289.01 625.699,1289.01 625.708,1289.01 625.717,1289.01 625.727,1289.01 625.736,1289.01 625.745,1289.01 625.754,1289.01 625.763,1289.01 625.773,1289.01 625.782,1289.01 625.791,1289.01 625.8,1289.01 625.809,1289.01 625.818,1289.01 625.828,1289.01 625.837,1289.01 625.846,1289.01 625.855,1289.01 625.864,1289.01 625.874,1289.01 625.883,1289.01 625.892,1289.01 625.901,1289.01 625.91,1289.01 625.92,1289.01 625.929,1289.01 625.938,1289.01 625.947,1289.01 625.956,1289.01 625.966,1289.01 625.975,1289.01 625.984,1289.01 625.993,1289.01 626.002,1289.02 626.011,1289.02 626.021,1289.02 626.03,1289.02 626.039,1289.02 626.048,1289.02 626.057,1289.02 626.067,1289.02 626.076,1289.02 626.085,1289.02 626.094,1289.02 626.103,1289.02 626.113,1289.02 626.122,1289.02 626.131,1289.02 626.14,1289.02 626.149,1289.02 626.158,1289.02 626.168,1289.02 626.177,1289.02 626.186,1289.02 626.195,1289.02 626.204,1289.02 626.214,1289.02 626.223,1289.02 626.232,1289.02 626.241,1289.02 626.25,1289.02 626.26,1289.02 626.269,1289.02 626.278,1289.02 626.287,1289.02 626.296,1289.02 626.306,1289.02 626.315,1289.02 626.324,1289.02 626.333,1289.02 626.342,1289.02 626.351,1289.02 626.361,1289.02 626.37,1289.02 626.379,1289.02 626.388,1289.02 626.397,1289.03 626.407,1289.03 626.416,1289.03 626.425,1289.03 626.434,1289.03 626.443,1289.03 626.453,1289.03 626.462,1289.03 626.471,1289.03 626.48,1289.03 626.489,1289.03 626.498,1289.03 626.508,1289.03 626.517,1289.03 626.526,1289.03 626.535,1289.03 626.544,1289.03 626.554,1289.03 626.563,1289.03 626.572,1289.03 626.581,1289.03 626.59,1289.03 626.6,1289.03 626.609,1289.03 626.618,1289.03 626.627,1289.03 626.636,1289.03 626.646,1289.03 626.655,1289.03 626.664,1289.03 626.673,1289.03 626.682,1289.03 626.691,1289.03 626.701,1289.03 626.71,1289.03 626.719,1289.03 626.728,1289.03 626.737,1289.03 626.747,1289.03 626.756,1289.03 626.765,1289.03 626.774,1289.03 626.783,1289.04 626.793,1289.04 626.802,1289.04 626.811,1289.04 626.82,1289.04 626.829,1289.04 626.838,1289.04 626.848,1289.04 626.857,1289.04 626.866,1289.04 626.875,1289.04 626.884,1289.04 626.894,1289.04 626.903,1289.04 626.912,1289.04 626.921,1289.04 626.93,1289.04 626.94,1289.04 626.949,1289.04 626.958,1289.04 626.967,1289.04 626.976,1289.04 626.986,1289.04 626.995,1289.04 627.004,1289.04 627.013,1289.04 627.022,1289.04 627.031,1289.04 627.041,1289.04 627.05,1289.04 627.059,1289.04 627.068,1289.04 627.077,1289.04 627.087,1289.04 627.096,1289.04 627.105,1289.04 627.114,1289.04 627.123,1289.04 627.133,1289.04 627.142,1289.04 627.151,1289.05 627.16,1289.05 627.169,1289.05 627.178,1289.05 627.188,1289.05 627.197,1289.05 627.206,1289.05 627.215,1289.05 627.224,1289.05 627.234,1289.05 627.243,1289.05 627.252,1289.05 627.261,1289.05 627.27,1289.05 627.28,1289.05 627.289,1289.05 627.298,1289.05 627.307,1289.05 627.316,1289.05 627.326,1289.05 627.335,1289.05 627.344,1289.05 627.353,1289.05 627.362,1289.05 627.371,1289.05 627.381,1289.05 627.39,1289.05 627.399,1289.05 627.408,1289.05 627.417,1289.05 627.427,1289.05 627.436,1289.05 627.445,1289.05 627.454,1289.05 627.463,1289.05 627.473,1289.05 627.482,1289.05 627.491,1289.05 627.5,1289.05 627.509,1289.05 627.519,1289.06 627.528,1289.06 627.537,1289.06 627.546,1289.06 627.555,1289.06 627.564,1289.06 627.574,1289.06 627.583,1289.06 627.592,1289.06 627.601,1289.06 627.61,1289.06 627.62,1289.06 627.629,1289.06 627.638,1289.06 627.647,1289.06 627.656,1289.06 627.666,1289.06 627.675,1289.06 627.684,1289.06 627.693,1289.06 627.702,1289.06 627.711,1289.06 627.721,1289.06 627.73,1289.06 627.739,1289.06 627.748,1289.06 627.757,1289.06 627.767,1289.06 627.776,1289.06 627.785,1289.06 627.794,1289.06 627.803,1289.06 627.813,1289.06 627.822,1289.06 627.831,1289.06 627.84,1289.06 627.849,1289.06 627.859,1289.06 627.868,1289.07 627.877,1289.07 627.886,1289.07 627.895,1289.07 627.904,1289.07 627.914,1289.07 627.923,1289.07 627.932,1289.07 627.941,1289.07 627.95,1289.07 627.96,1289.07 627.969,1289.07 627.978,1289.07 627.987,1289.07 627.996,1289.07 628.006,1289.07 628.015,1289.07 628.024,1289.07 628.033,1289.07 628.042,1289.07 628.051,1289.07 628.061,1289.07 628.07,1289.07 628.079,1289.07 628.088,1289.07 628.097,1289.07 628.107,1289.07 628.116,1289.07 628.125,1289.07 628.134,1289.07 628.143,1289.07 628.153,1289.07 628.162,1289.07 628.171,1289.07 628.18,1289.07 628.189,1289.07 628.199,1289.07 628.208,1289.07 628.217,1289.08 628.226,1289.08 628.235,1289.08 628.244,1289.08 628.254,1289.08 628.263,1289.08 628.272,1289.08 628.281,1289.08 628.29,1289.08 628.3,1289.08 628.309,1289.08 628.318,1289.08 628.327,1289.08 628.336,1289.08 628.346,1289.08 628.355,1289.08 628.364,1289.08 628.373,1289.08 628.382,1289.08 628.391,1289.08 628.401,1289.08 628.41,1289.08 628.419,1289.08 628.428,1289.08 628.437,1289.08 628.447,1289.08 628.456,1289.08 628.465,1289.08 628.474,1289.08 628.483,1289.08 628.493,1289.08 628.502,1289.08 628.511,1289.08 628.52,1289.08 628.529,1289.08 628.539,1289.08 628.548,1289.09 628.557,1289.09 628.566,1289.09 628.575,1289.09 628.584,1289.09 628.594,1289.09 628.603,1289.09 628.612,1289.09 628.621,1289.09 628.63,1289.09 628.64,1289.09 628.649,1289.09 628.658,1289.09 628.667,1289.09 628.676,1289.09 628.686,1289.09 628.695,1289.09 628.704,1289.09 628.713,1289.09 628.722,1289.09 628.731,1289.09 628.741,1289.09 628.75,1289.09 628.759,1289.09 628.768,1289.09 628.777,1289.09 628.787,1289.09 628.796,1289.09 628.805,1289.09 628.814,1289.09 628.823,1289.09 628.833,1289.09 628.842,1289.09 628.851,1289.09 628.86,1289.09 628.869,1289.09 628.879,1289.1 628.888,1289.1 628.897,1289.1 628.906,1289.1 628.915,1289.1 628.924,1289.1 628.934,1289.1 628.943,1289.1 628.952,1289.1 628.961,1289.1 628.97,1289.1 628.98,1289.1 628.989,1289.1 628.998,1289.1 629.007,1289.1 629.016,1289.1 629.026,1289.1 629.035,1289.1 629.044,1289.1 629.053,1289.1 629.062,1289.1 629.071,1289.1 629.081,1289.1 629.09,1289.1 629.099,1289.1 629.108,1289.1 629.117,1289.1 629.127,1289.1 629.136,1289.1 629.145,1289.1 629.154,1289.1 629.163,1289.1 629.173,1289.1 629.182,1289.1 629.191,1289.1 629.2,1289.11 629.209,1289.11 629.219,1289.11 629.228,1289.11 629.237,1289.11 629.246,1289.11 629.255,1289.11 629.264,1289.11 629.274,1289.11 629.283,1289.11 629.292,1289.11 629.301,1289.11 629.31,1289.11 629.32,1289.11 629.329,1289.11 629.338,1289.11 629.347,1289.11 629.356,1289.11 629.366,1289.11 629.375,1289.11 629.384,1289.11 629.393,1289.11 629.402,1289.11 629.411,1289.11 629.421,1289.11 629.43,1289.11 629.439,1289.11 629.448,1289.11 629.457,1289.11 629.467,1289.11 629.476,1289.11 629.485,1289.11 629.494,1289.11 629.503,1289.11 629.513,1289.12 629.522,1289.12 629.531,1289.12 629.54,1289.12 629.549,1289.12 629.559,1289.12 629.568,1289.12 629.577,1289.12 629.586,1289.12 629.595,1289.12 629.604,1289.12 629.614,1289.12 629.623,1289.12 629.632,1289.12 629.641,1289.12 629.65,1289.12 629.66,1289.12 629.669,1289.12 629.678,1289.12 629.687,1289.12 629.696,1289.12 629.706,1289.12 629.715,1289.12 629.724,1289.12 629.733,1289.12 629.742,1289.12 629.752,1289.12 629.761,1289.12 629.77,1289.12 629.779,1289.12 629.788,1289.12 629.797,1289.12 629.807,1289.12 629.816,1289.12 629.825,1289.13 629.834,1289.13 629.843,1289.13 629.853,1289.13 629.862,1289.13 629.871,1289.13 629.88,1289.13 629.889,1289.13 629.899,1289.13 629.908,1289.13 629.917,1289.13 629.926,1289.13 629.935,1289.13 629.944,1289.13 629.954,1289.13 629.963,1289.13 629.972,1289.13 629.981,1289.13 629.99,1289.13 630,1289.13 630.009,1289.13 630.018,1289.13 630.027,1289.13 630.036,1289.13 630.046,1289.13 630.055,1289.13 630.064,1289.13 630.073,1289.13 630.082,1289.13 630.092,1289.13 630.101,1289.13 630.11,1289.13 630.119,1289.13 630.128,1289.14 630.137,1289.14 630.147,1289.14 630.156,1289.14 630.165,1289.14 630.174,1289.14 630.183,1289.14 630.193,1289.14 630.202,1289.14 630.211,1289.14 630.22,1289.14 630.229,1289.14 630.239,1289.14 630.248,1289.14 630.257,1289.14 630.266,1289.14 630.275,1289.14 630.284,1289.14 630.294,1289.14 630.303,1289.14 630.312,1289.14 630.321,1289.14 630.33,1289.14 630.34,1289.14 630.349,1289.14 630.358,1289.14 630.367,1289.14 630.376,1289.14 630.386,1289.14 630.395,1289.14 630.404,1289.14 630.413,1289.14 630.422,1289.15 630.432,1289.15 630.441,1289.15 630.45,1289.15 630.459,1289.15 630.468,1289.15 630.477,1289.15 630.487,1289.15 630.496,1289.15 630.505,1289.15 630.514,1289.15 630.523,1289.15 630.533,1289.15 630.542,1289.15 630.551,1289.15 630.56,1289.15 630.569,1289.15 630.579,1289.15 630.588,1289.15 630.597,1289.15 630.606,1289.15 630.615,1289.15 630.624,1289.15 630.634,1289.15 630.643,1289.15 630.652,1289.15 630.661,1289.15 630.67,1289.15 630.68,1289.15 630.689,1289.15 630.698,1289.15 630.707,1289.16 630.716,1289.16 630.726,1289.16 630.735,1289.16 630.744,1289.16 630.753,1289.16 630.762,1289.16 630.772,1289.16 630.781,1289.16 630.79,1289.16 630.799,1289.16 630.808,1289.16 630.817,1289.16 630.827,1289.16 630.836,1289.16 630.845,1289.16 630.854,1289.16 630.863,1289.16 630.873,1289.16 630.882,1289.16 630.891,1289.16 630.9,1289.16 630.909,1289.16 630.919,1289.16 630.928,1289.16 630.937,1289.16 630.946,1289.16 630.955,1289.16 630.964,1289.16 630.974,1289.16 630.983,1289.16 630.992,1289.17 631.001,1289.17 631.01,1289.17 631.02,1289.17 631.029,1289.17 631.038,1289.17 631.047,1289.17 631.056,1289.17 631.066,1289.17 631.075,1289.17 631.084,1289.17 631.093,1289.17 631.102,1289.17 631.112,1289.17 631.121,1289.17 631.13,1289.17 631.139,1289.17 631.148,1289.17 631.157,1289.17 631.167,1289.17 631.176,1289.17 631.185,1289.17 631.194,1289.17 631.203,1289.17 631.213,1289.17 631.222,1289.17 631.231,1289.17 631.24,1289.17 631.249,1289.17 631.259,1289.17 631.268,1289.18 631.277,1289.18 631.286,1289.18 631.295,1289.18 631.304,1289.18 631.314,1289.18 631.323,1289.18 631.332,1289.18 631.341,1289.18 631.35,1289.18 631.36,1289.18 631.369,1289.18 631.378,1289.18 631.387,1289.18 631.396,1289.18 631.406,1289.18 631.415,1289.18 631.424,1289.18 631.433,1289.18 631.442,1289.18 631.452,1289.18 631.461,1289.18 631.47,1289.18 631.479,1289.18 631.488,1289.18 631.497,1289.18 631.507,1289.18 631.516,1289.18 631.525,1289.18 631.534,1289.18 631.543,1289.19 631.553,1289.19 631.562,1289.19 631.571,1289.19 631.58,1289.19 631.589,1289.19 631.599,1289.19 631.608,1289.19 631.617,1289.19 631.626,1289.19 631.635,1289.19 631.644,1289.19 631.654,1289.19 631.663,1289.19 631.672,1289.19 631.681,1289.19 631.69,1289.19 631.7,1289.19 631.709,1289.19 631.718,1289.19 631.727,1289.19 631.736,1289.19 631.746,1289.19 631.755,1289.19 631.764,1289.19 631.773,1289.19 631.782,1289.19 631.792,1289.19 631.801,1289.19 631.81,1289.19 631.819,1289.2 631.828,1289.2 631.837,1289.2 631.847,1289.2 631.856,1289.2 631.865,1289.2 631.874,1289.2 631.883,1289.2 631.893,1289.2 631.902,1289.2 631.911,1289.2 631.92,1289.2 631.929,1289.2 631.939,1289.2 631.948,1289.2 631.957,1289.2 631.966,1289.2 631.975,1289.2 631.984,1289.2 631.994,1289.2 632.003,1289.2 632.012,1289.2 632.021,1289.2 632.03,1289.2 632.04,1289.2 632.049,1289.2 632.058,1289.2 632.067,1289.2 632.076,1289.21 632.086,1289.21 632.095,1289.21 632.104,1289.21 632.113,1289.21 632.122,1289.21 632.132,1289.21 632.141,1289.21 632.15,1289.21 632.159,1289.21 632.168,1289.21 632.177,1289.21 632.187,1289.21 632.196,1289.21 632.205,1289.21 632.214,1289.21 632.223,1289.21 632.233,1289.21 632.242,1289.21 632.251,1289.21 632.26,1289.21 632.269,1289.21 632.279,1289.21 632.288,1289.21 632.297,1289.21 632.306,1289.21 632.315,1289.21 632.325,1289.21 632.334,1289.21 632.343,1289.22 632.352,1289.22 632.361,1289.22 632.37,1289.22 632.38,1289.22 632.389,1289.22 632.398,1289.22 632.407,1289.22 632.416,1289.22 632.426,1289.22 632.435,1289.22 632.444,1289.22 632.453,1289.22 632.462,1289.22 632.472,1289.22 632.481,1289.22 632.49,1289.22 632.499,1289.22 632.508,1289.22 632.517,1289.22 632.527,1289.22 632.536,1289.22 632.545,1289.22 632.554,1289.22 632.563,1289.22 632.573,1289.22 632.582,1289.22 632.591,1289.22 632.6,1289.23 632.609,1289.23 632.619,1289.23 632.628,1289.23 632.637,1289.23 632.646,1289.23 632.655,1289.23 632.665,1289.23 632.674,1289.23 632.683,1289.23 632.692,1289.23 632.701,1289.23 632.71,1289.23 632.72,1289.23 632.729,1289.23 632.738,1289.23 632.747,1289.23 632.756,1289.23 632.766,1289.23 632.775,1289.23 632.784,1289.23 632.793,1289.23 632.802,1289.23 632.812,1289.23 632.821,1289.23 632.83,1289.23 632.839,1289.23 632.848,1289.24 632.857,1289.24 632.867,1289.24 632.876,1289.24 632.885,1289.24 632.894,1289.24 632.903,1289.24 632.913,1289.24 632.922,1289.24 632.931,1289.24 632.94,1289.24 632.949,1289.24 632.959,1289.24 632.968,1289.24 632.977,1289.24 632.986,1289.24 632.995,1289.24 633.005,1289.24 633.014,1289.24 633.023,1289.24 633.032,1289.24 633.041,1289.24 633.05,1289.24 633.06,1289.24 633.069,1289.24 633.078,1289.24 633.087,1289.24 633.096,1289.25 633.106,1289.25 633.115,1289.25 633.124,1289.25 633.133,1289.25 633.142,1289.25 633.152,1289.25 633.161,1289.25 633.17,1289.25 633.179,1289.25 633.188,1289.25 633.197,1289.25 633.207,1289.25 633.216,1289.25 633.225,1289.25 633.234,1289.25 633.243,1289.25 633.253,1289.25 633.262,1289.25 633.271,1289.25 633.28,1289.25 633.289,1289.25 633.299,1289.25 633.308,1289.25 633.317,1289.25 633.326,1289.25 633.335,1289.25 633.345,1289.26 633.354,1289.26 633.363,1289.26 633.372,1289.26 633.381,1289.26 633.39,1289.26 633.4,1289.26 633.409,1289.26 633.418,1289.26 633.427,1289.26 633.436,1289.26 633.446,1289.26 633.455,1289.26 633.464,1289.26 633.473,1289.26 633.482,1289.26 633.492,1289.26 633.501,1289.26 633.51,1289.26 633.519,1289.26 633.528,1289.26 633.537,1289.26 633.547,1289.26 633.556,1289.26 633.565,1289.26 633.574,1289.26 633.583,1289.27 633.593,1289.27 633.602,1289.27 633.611,1289.27 633.62,1289.27 633.629,1289.27 633.639,1289.27 633.648,1289.27 633.657,1289.27 633.666,1289.27 633.675,1289.27 633.685,1289.27 633.694,1289.27 633.703,1289.27 633.712,1289.27 633.721,1289.27 633.73,1289.27 633.74,1289.27 633.749,1289.27 633.758,1289.27 633.767,1289.27 633.776,1289.27 633.786,1289.27 633.795,1289.27 633.804,1289.27 633.813,1289.28 633.822,1289.28 633.832,1289.28 633.841,1289.28 633.85,1289.28 633.859,1289.28 633.868,1289.28 633.877,1289.28 633.887,1289.28 633.896,1289.28 633.905,1289.28 633.914,1289.28 633.923,1289.28 633.933,1289.28 633.942,1289.28 633.951,1289.28 633.96,1289.28 633.969,1289.28 633.979,1289.28 633.988,1289.28 633.997,1289.28 634.006,1289.28 634.015,1289.28 634.025,1289.28 634.034,1289.28 634.043,1289.28 634.052,1289.29 634.061,1289.29 634.07,1289.29 634.08,1289.29 634.089,1289.29 634.098,1289.29 634.107,1289.29 634.116,1289.29 634.126,1289.29 634.135,1289.29 634.144,1289.29 634.153,1289.29 634.162,1289.29 634.172,1289.29 634.181,1289.29 634.19,1289.29 634.199,1289.29 634.208,1289.29 634.217,1289.29 634.227,1289.29 634.236,1289.29 634.245,1289.29 634.254,1289.29 634.263,1289.29 634.273,1289.29 634.282,1289.3 634.291,1289.3 634.3,1289.3 634.309,1289.3 634.319,1289.3 634.328,1289.3 634.337,1289.3 634.346,1289.3 634.355,1289.3 634.365,1289.3 634.374,1289.3 634.383,1289.3 634.392,1289.3 634.401,1289.3 634.41,1289.3 634.42,1289.3 634.429,1289.3 634.438,1289.3 634.447,1289.3 634.456,1289.3 634.466,1289.3 634.475,1289.3 634.484,1289.3 634.493,1289.3 634.502,1289.3 634.512,1289.31 634.521,1289.31 634.53,1289.31 634.539,1289.31 634.548,1289.31 634.557,1289.31 634.567,1289.31 634.576,1289.31 634.585,1289.31 634.594,1289.31 634.603,1289.31 634.613,1289.31 634.622,1289.31 634.631,1289.31 634.64,1289.31 634.649,1289.31 634.659,1289.31 634.668,1289.31 634.677,1289.31 634.686,1289.31 634.695,1289.31 634.705,1289.31 634.714,1289.31 634.723,1289.31 634.732,1289.32 634.741,1289.32 634.75,1289.32 634.76,1289.32 634.769,1289.32 634.778,1289.32 634.787,1289.32 634.796,1289.32 634.806,1289.32 634.815,1289.32 634.824,1289.32 634.833,1289.32 634.842,1289.32 634.852,1289.32 634.861,1289.32 634.87,1289.32 634.879,1289.32 634.888,1289.32 634.898,1289.32 634.907,1289.32 634.916,1289.32 634.925,1289.32 634.934,1289.32 634.943,1289.32 634.953,1289.33 634.962,1289.33 634.971,1289.33 634.98,1289.33 634.989,1289.33 634.999,1289.33 635.008,1289.33 635.017,1289.33 635.026,1289.33 635.035,1289.33 635.045,1289.33 635.054,1289.33 635.063,1289.33 635.072,1289.33 635.081,1289.33 635.09,1289.33 635.1,1289.33 635.109,1289.33 635.118,1289.33 635.127,1289.33 635.136,1289.33 635.146,1289.33 635.155,1289.33 635.164,1289.33 635.173,1289.34 635.182,1289.34 635.192,1289.34 635.201,1289.34 635.21,1289.34 635.219,1289.34 635.228,1289.34 635.238,1289.34 635.247,1289.34 635.256,1289.34 635.265,1289.34 635.274,1289.34 635.283,1289.34 635.293,1289.34 635.302,1289.34 635.311,1289.34 635.32,1289.34 635.329,1289.34 635.339,1289.34 635.348,1289.34 635.357,1289.34 635.366,1289.34 635.375,1289.34 635.385,1289.35 635.394,1289.35 635.403,1289.35 635.412,1289.35 635.421,1289.35 635.43,1289.35 635.44,1289.35 635.449,1289.35 635.458,1289.35 635.467,1289.35 635.476,1289.35 635.486,1289.35 635.495,1289.35 635.504,1289.35 635.513,1289.35 635.522,1289.35 635.532,1289.35 635.541,1289.35 635.55,1289.35 635.559,1289.35 635.568,1289.35 635.578,1289.35 635.587,1289.35 635.596,1289.35 635.605,1289.36 635.614,1289.36 635.623,1289.36 635.633,1289.36 635.642,1289.36 635.651,1289.36 635.66,1289.36 635.669,1289.36 635.679,1289.36 635.688,1289.36 635.697,1289.36 635.706,1289.36 635.715,1289.36 635.725,1289.36 635.734,1289.36 635.743,1289.36 635.752,1289.36 635.761,1289.36 635.77,1289.36 635.78,1289.36 635.789,1289.36 635.798,1289.36 635.807,1289.37 635.816,1289.37 635.826,1289.37 635.835,1289.37 635.844,1289.37 635.853,1289.37 635.862,1289.37 635.872,1289.37 635.881,1289.37 635.89,1289.37 635.899,1289.37 635.908,1289.37 635.918,1289.37 635.927,1289.37 635.936,1289.37 635.945,1289.37 635.954,1289.37 635.963,1289.37 635.973,1289.37 635.982,1289.37 635.991,1289.37 636,1289.37 636.009,1289.37 636.019,1289.38 636.028,1289.38 636.037,1289.38 636.046,1289.38 636.055,1289.38 636.065,1289.38 636.074,1289.38 636.083,1289.38 636.092,1289.38 636.101,1289.38 636.11,1289.38 636.12,1289.38 636.129,1289.38 636.138,1289.38 636.147,1289.38 636.156,1289.38 636.166,1289.38 636.175,1289.38 636.184,1289.38 636.193,1289.38 636.202,1289.38 636.212,1289.38 636.221,1289.39 636.23,1289.39 636.239,1289.39 636.248,1289.39 636.258,1289.39 636.267,1289.39 636.276,1289.39 636.285,1289.39 636.294,1289.39 636.303,1289.39 636.313,1289.39 636.322,1289.39 636.331,1289.39 636.34,1289.39 636.349,1289.39 636.359,1289.39 636.368,1289.39 636.377,1289.39 636.386,1289.39 636.395,1289.39 636.405,1289.39 636.414,1289.39 636.423,1289.4 636.432,1289.4 636.441,1289.4 636.45,1289.4 636.46,1289.4 636.469,1289.4 636.478,1289.4 636.487,1289.4 636.496,1289.4 636.506,1289.4 636.515,1289.4 636.524,1289.4 636.533,1289.4 636.542,1289.4 636.552,1289.4 636.561,1289.4 636.57,1289.4 636.579,1289.4 636.588,1289.4 636.598,1289.4 636.607,1289.4 636.616,1289.4 636.625,1289.41 636.634,1289.41 636.643,1289.41 636.653,1289.41 636.662,1289.41 636.671,1289.41 636.68,1289.41 636.689,1289.41 636.699,1289.41 636.708,1289.41 636.717,1289.41 636.726,1289.41 636.735,1289.41 636.745,1289.41 636.754,1289.41 636.763,1289.41 636.772,1289.41 636.781,1289.41 636.79,1289.41 636.8,1289.41 636.809,1289.41 636.818,1289.41 636.827,1289.42 636.836,1289.42 636.846,1289.42 636.855,1289.42 636.864,1289.42 636.873,1289.42 636.882,1289.42 636.892,1289.42 636.901,1289.42 636.91,1289.42 636.919,1289.42 636.928,1289.42 636.938,1289.42 636.947,1289.42 636.956,1289.42 636.965,1289.42 636.974,1289.42 636.983,1289.42 636.993,1289.42 637.002,1289.42 637.011,1289.42 637.02,1289.43 637.029,1289.43 637.039,1289.43 637.048,1289.43 637.057,1289.43 637.066,1289.43 637.075,1289.43 637.085,1289.43 637.094,1289.43 637.103,1289.43 637.112,1289.43 637.121,1289.43 637.131,1289.43 637.14,1289.43 637.149,1289.43 637.158,1289.43 637.167,1289.43 637.176,1289.43 637.186,1289.43 637.195,1289.43 637.204,1289.43 637.213,1289.44 637.222,1289.44 637.232,1289.44 637.241,1289.44 637.25,1289.44 637.259,1289.44 637.268,1289.44 637.278,1289.44 637.287,1289.44 637.296,1289.44 637.305,1289.44 637.314,1289.44 637.323,1289.44 637.333,1289.44 637.342,1289.44 637.351,1289.44 637.36,1289.44 637.369,1289.44 637.379,1289.44 637.388,1289.44 637.397,1289.44 637.406,1289.45 637.415,1289.45 637.425,1289.45 637.434,1289.45 637.443,1289.45 637.452,1289.45 637.461,1289.45 637.471,1289.45 637.48,1289.45 637.489,1289.45 637.498,1289.45 637.507,1289.45 637.516,1289.45 637.526,1289.45 637.535,1289.45 637.544,1289.45 637.553,1289.45 637.562,1289.45 637.572,1289.45 637.581,1289.45 637.59,1289.45 637.599,1289.46 637.608,1289.46 637.618,1289.46 637.627,1289.46 637.636,1289.46 637.645,1289.46 637.654,1289.46 637.663,1289.46 637.673,1289.46 637.682,1289.46 637.691,1289.46 637.7,1289.46 637.709,1289.46 637.719,1289.46 637.728,1289.46 637.737,1289.46 637.746,1289.46 637.755,1289.46 637.765,1289.46 637.774,1289.46 637.783,1289.47 637.792,1289.47 637.801,1289.47 637.811,1289.47 637.82,1289.47 637.829,1289.47 637.838,1289.47 637.847,1289.47 637.856,1289.47 637.866,1289.47 637.875,1289.47 637.884,1289.47 637.893,1289.47 637.902,1289.47 637.912,1289.47 637.921,1289.47 637.93,1289.47 637.939,1289.47 637.948,1289.47 637.958,1289.47 637.967,1289.48 637.976,1289.48 637.985,1289.48 637.994,1289.48 638.003,1289.48 638.013,1289.48 638.022,1289.48 638.031,1289.48 638.04,1289.48 638.049,1289.48 638.059,1289.48 638.068,1289.48 638.077,1289.48 638.086,1289.48 638.095,1289.48 638.105,1289.48 638.114,1289.48 638.123,1289.48 638.132,1289.48 638.141,1289.48 638.151,1289.49 638.16,1289.49 638.169,1289.49 638.178,1289.49 638.187,1289.49 638.196,1289.49 638.206,1289.49 638.215,1289.49 638.224,1289.49 638.233,1289.49 638.242,1289.49 638.252,1289.49 638.261,1289.49 638.27,1289.49 638.279,1289.49 638.288,1289.49 638.298,1289.49 638.307,1289.49 638.316,1289.49 638.325,1289.49 638.334,1289.5 638.343,1289.5 638.353,1289.5 638.362,1289.5 638.371,1289.5 638.38,1289.5 638.389,1289.5 638.399,1289.5 638.408,1289.5 638.417,1289.5 638.426,1289.5 638.435,1289.5 638.445,1289.5 638.454,1289.5 638.463,1289.5 638.472,1289.5 638.481,1289.5 638.491,1289.5 638.5,1289.5 638.509,1289.51 638.518,1289.51 638.527,1289.51 638.536,1289.51 638.546,1289.51 638.555,1289.51 638.564,1289.51 638.573,1289.51 638.582,1289.51 638.592,1289.51 638.601,1289.51 638.61,1289.51 638.619,1289.51 638.628,1289.51 638.638,1289.51 638.647,1289.51 638.656,1289.51 638.665,1289.51 638.674,1289.51 638.683,1289.51 638.693,1289.52 638.702,1289.52 638.711,1289.52 638.72,1289.52 638.729,1289.52 638.739,1289.52 638.748,1289.52 638.757,1289.52 638.766,1289.52 638.775,1289.52 638.785,1289.52 638.794,1289.52 638.803,1289.52 638.812,1289.52 638.821,1289.52 638.831,1289.52 638.84,1289.52 638.849,1289.52 638.858,1289.52 638.867,1289.53 638.876,1289.53 638.886,1289.53 638.895,1289.53 638.904,1289.53 638.913,1289.53 638.922,1289.53 638.932,1289.53 638.941,1289.53 638.95,1289.53 638.959,1289.53 638.968,1289.53 638.978,1289.53 638.987,1289.53 638.996,1289.53 639.005,1289.53 639.014,1289.53 639.023,1289.53 639.033,1289.53 639.042,1289.54 639.051,1289.54 639.06,1289.54 639.069,1289.54 639.079,1289.54 639.088,1289.54 639.097,1289.54 639.106,1289.54 639.115,1289.54 639.125,1289.54 639.134,1289.54 639.143,1289.54 639.152,1289.54 639.161,1289.54 639.171,1289.54 639.18,1289.54 639.189,1289.54 639.198,1289.54 639.207,1289.54 639.216,1289.55 639.226,1289.55 639.235,1289.55 639.244,1289.55 639.253,1289.55 639.262,1289.55 639.272,1289.55 639.281,1289.55 639.29,1289.55 639.299,1289.55 639.308,1289.55 639.318,1289.55 639.327,1289.55 639.336,1289.55 639.345,1289.55 639.354,1289.55 639.363,1289.55 639.373,1289.55 639.382,1289.56 639.391,1289.56 639.4,1289.56 639.409,1289.56 639.419,1289.56 639.428,1289.56 639.437,1289.56 639.446,1289.56 639.455,1289.56 639.465,1289.56 639.474,1289.56 639.483,1289.56 639.492,1289.56 639.501,1289.56 639.511,1289.56 639.52,1289.56 639.529,1289.56 639.538,1289.56 639.547,1289.56 639.556,1289.57 639.566,1289.57 639.575,1289.57 639.584,1289.57 639.593,1289.57 639.602,1289.57 639.612,1289.57 639.621,1289.57 639.63,1289.57 639.639,1289.57 639.648,1289.57 639.658,1289.57 639.667,1289.57 639.676,1289.57 639.685,1289.57 639.694,1289.57 639.704,1289.57 639.713,1289.57 639.722,1289.58 639.731,1289.58 639.74,1289.58 639.749,1289.58 639.759,1289.58 639.768,1289.58 639.777,1289.58 639.786,1289.58 639.795,1289.58 639.805,1289.58 639.814,1289.58 639.823,1289.58 639.832,1289.58 639.841,1289.58 639.851,1289.58 639.86,1289.58 639.869,1289.58 639.878,1289.58 639.887,1289.59 639.896,1289.59 639.906,1289.59 639.915,1289.59 639.924,1289.59 639.933,1289.59 639.942,1289.59 639.952,1289.59 639.961,1289.59 639.97,1289.59 639.979,1289.59 639.988,1289.59 639.998,1289.59 640.007,1289.59 640.016,1289.59 640.025,1289.59 640.034,1289.59 640.044,1289.59 640.053,1289.6 640.062,1289.6 640.071,1289.6 640.08,1289.6 640.089,1289.6 640.099,1289.6 640.108,1289.6 640.117,1289.6 640.126,1289.6 640.135,1289.6 640.145,1289.6 640.154,1289.6 640.163,1289.6 640.172,1289.6 640.181,1289.6 640.191,1289.6 640.2,1289.6 640.209,1289.6 640.218,1289.61 640.227,1289.61 640.236,1289.61 640.246,1289.61 640.255,1289.61 640.264,1289.61 640.273,1289.61 640.282,1289.61 640.292,1289.61 640.301,1289.61 640.31,1289.61 640.319,1289.61 640.328,1289.61 640.338,1289.61 640.347,1289.61 640.356,1289.61 640.365,1289.61 640.374,1289.61 640.384,1289.62 640.393,1289.62 640.402,1289.62 640.411,1289.62 640.42,1289.62 640.429,1289.62 640.439,1289.62 640.448,1289.62 640.457,1289.62 640.466,1289.62 640.475,1289.62 640.485,1289.62 640.494,1289.62 640.503,1289.62 640.512,1289.62 640.521,1289.62 640.531,1289.62 640.54,1289.63 640.549,1289.63 640.558,1289.63 640.567,1289.63 640.576,1289.63 640.586,1289.63 640.595,1289.63 640.604,1289.63 640.613,1289.63 640.622,1289.63 640.632,1289.63 640.641,1289.63 640.65,1289.63 640.659,1289.63 640.668,1289.63 640.678,1289.63 640.687,1289.63 640.696,1289.64 640.705,1289.64 640.714,1289.64 640.724,1289.64 640.733,1289.64 640.742,1289.64 640.751,1289.64 640.76,1289.64 640.769,1289.64 640.779,1289.64 640.788,1289.64 640.797,1289.64 640.806,1289.64 640.815,1289.64 640.825,1289.64 640.834,1289.64 640.843,1289.64 640.852,1289.64 640.861,1289.65 640.871,1289.65 640.88,1289.65 640.889,1289.65 640.898,1289.65 640.907,1289.65 640.916,1289.65 640.926,1289.65 640.935,1289.65 640.944,1289.65 640.953,1289.65 640.962,1289.65 640.972,1289.65 640.981,1289.65 640.99,1289.65 640.999,1289.65 641.008,1289.65 641.018,1289.66 641.027,1289.66 641.036,1289.66 641.045,1289.66 641.054,1289.66 641.064,1289.66 641.073,1289.66 641.082,1289.66 641.091,1289.66 641.1,1289.66 641.109,1289.66 641.119,1289.66 641.128,1289.66 641.137,1289.66 641.146,1289.66 641.155,1289.66 641.165,1289.66 641.174,1289.67 641.183,1289.67 641.192,1289.67 641.201,1289.67 641.211,1289.67 641.22,1289.67 641.229,1289.67 641.238,1289.67 641.247,1289.67 641.256,1289.67 641.266,1289.67 641.275,1289.67 641.284,1289.67 641.293,1289.67 641.302,1289.67 641.312,1289.67 641.321,1289.68 641.33,1289.68 641.339,1289.68 641.348,1289.68 641.358,1289.68 641.367,1289.68 641.376,1289.68 641.385,1289.68 641.394,1289.68 641.404,1289.68 641.413,1289.68 641.422,1289.68 641.431,1289.68 641.44,1289.68 641.449,1289.68 641.459,1289.68 641.468,1289.68 641.477,1289.69 641.486,1289.69 641.495,1289.69 641.505,1289.69 641.514,1289.69 641.523,1289.69 641.532,1289.69 641.541,1289.69 641.551,1289.69 641.56,1289.69 641.569,1289.69 641.578,1289.69 641.587,1289.69 641.596,1289.69 641.606,1289.69 641.615,1289.69 641.624,1289.7 641.633,1289.7 641.642,1289.7 641.652,1289.7 641.661,1289.7 641.67,1289.7 641.679,1289.7 641.688,1289.7 641.698,1289.7 641.707,1289.7 641.716,1289.7 641.725,1289.7 641.734,1289.7 641.744,1289.7 641.753,1289.7 641.762,1289.7 641.771,1289.7 641.78,1289.71 641.789,1289.71 641.799,1289.71 641.808,1289.71 641.817,1289.71 641.826,1289.71 641.835,1289.71 641.845,1289.71 641.854,1289.71 641.863,1289.71 641.872,1289.71 641.881,1289.71 641.891,1289.71 641.9,1289.71 641.909,1289.71 641.918,1289.71 641.927,1289.72 641.936,1289.72 641.946,1289.72 641.955,1289.72 641.964,1289.72 641.973,1289.72 641.982,1289.72 641.992,1289.72 642.001,1289.72 642.01,1289.72 642.019,1289.72 642.028,1289.72 642.038,1289.72 642.047,1289.72 642.056,1289.72 642.065,1289.72 642.074,1289.73 642.084,1289.73 642.093,1289.73 642.102,1289.73 642.111,1289.73 642.12,1289.73 642.129,1289.73 642.139,1289.73 642.148,1289.73 642.157,1289.73 642.166,1289.73 642.175,1289.73 642.185,1289.73 642.194,1289.73 642.203,1289.73 642.212,1289.73 642.221,1289.74 642.231,1289.74 642.24,1289.74 642.249,1289.74 642.258,1289.74 642.267,1289.74 642.277,1289.74 642.286,1289.74 642.295,1289.74 642.304,1289.74 642.313,1289.74 642.322,1289.74 642.332,1289.74 642.341,1289.74 642.35,1289.74 642.359,1289.74 642.368,1289.75 642.378,1289.75 642.387,1289.75 642.396,1289.75 642.405,1289.75 642.414,1289.75 642.424,1289.75 642.433,1289.75 642.442,1289.75 642.451,1289.75 642.46,1289.75 642.469,1289.75 642.479,1289.75 642.488,1289.75 642.497,1289.75 642.506,1289.75 642.515,1289.76 642.525,1289.76 642.534,1289.76 642.543,1289.76 642.552,1289.76 642.561,1289.76 642.571,1289.76 642.58,1289.76 642.589,1289.76 642.598,1289.76 642.607,1289.76 642.617,1289.76 642.626,1289.76 642.635,1289.76 642.644,1289.76 642.653,1289.77 642.662,1289.77 642.672,1289.77 642.681,1289.77 642.69,1289.77 642.699,1289.77 642.708,1289.77 642.718,1289.77 642.727,1289.77 642.736,1289.77 642.745,1289.77 642.754,1289.77 642.764,1289.77 642.773,1289.77 642.782,1289.77 642.791,1289.77 642.8,1289.78 642.809,1289.78 642.819,1289.78 642.828,1289.78 642.837,1289.78 642.846,1289.78 642.855,1289.78 642.865,1289.78 642.874,1289.78 642.883,1289.78 642.892,1289.78 642.901,1289.78 642.911,1289.78 642.92,1289.78 642.929,1289.78 642.938,1289.79 642.947,1289.79 642.957,1289.79 642.966,1289.79 642.975,1289.79 642.984,1289.79 642.993,1289.79 643.002,1289.79 643.012,1289.79 643.021,1289.79 643.03,1289.79 643.039,1289.79 643.048,1289.79 643.058,1289.79 643.067,1289.79 643.076,1289.8 643.085,1289.8 643.094,1289.8 643.104,1289.8 643.113,1289.8 643.122,1289.8 643.131,1289.8 643.14,1289.8 643.149,1289.8 643.159,1289.8 643.168,1289.8 643.177,1289.8 643.186,1289.8 643.195,1289.8 643.205,1289.8 643.214,1289.81 643.223,1289.81 643.232,1289.81 643.241,1289.81 643.251,1289.81 643.26,1289.81 643.269,1289.81 643.278,1289.81 643.287,1289.81 643.297,1289.81 643.306,1289.81 643.315,1289.81 643.324,1289.81 643.333,1289.81 643.342,1289.81 643.352,1289.81 643.361,1289.82 643.37,1289.82 643.379,1289.82 643.388,1289.82 643.398,1289.82 643.407,1289.82 643.416,1289.82 643.425,1289.82 643.434,1289.82 643.444,1289.82 643.453,1289.82 643.462,1289.82 643.471,1289.82 643.48,1289.82 643.489,1289.83 643.499,1289.83 643.508,1289.83 643.517,1289.83 643.526,1289.83 643.535,1289.83 643.545,1289.83 643.554,1289.83 643.563,1289.83 643.572,1289.83 643.581,1289.83 643.591,1289.83 643.6,1289.83 643.609,1289.83 643.618,1289.83 643.627,1289.84 643.637,1289.84 643.646,1289.84 643.655,1289.84 643.664,1289.84 643.673,1289.84 643.682,1289.84 643.692,1289.84 643.701,1289.84 643.71,1289.84 643.719,1289.84 643.728,1289.84 643.738,1289.84 643.747,1289.84 643.756,1289.84 643.765,1289.85 643.774,1289.85 643.784,1289.85 643.793,1289.85 643.802,1289.85 643.811,1289.85 643.82,1289.85 643.829,1289.85 643.839,1289.85 643.848,1289.85 643.857,1289.85 643.866,1289.85 643.875,1289.85 643.885,1289.85 643.894,1289.85 643.903,1289.86 643.912,1289.86 643.921,1289.86 643.931,1289.86 643.94,1289.86 643.949,1289.86 643.958,1289.86 643.967,1289.86 643.977,1289.86 643.986,1289.86 643.995,1289.86 644.004,1289.86 644.013,1289.86 644.022,1289.86 644.032,1289.87 644.041,1289.87 644.05,1289.87 644.059,1289.87 644.068,1289.87 644.078,1289.87 644.087,1289.87 644.096,1289.87 644.105,1289.87 644.114,1289.87 644.124,1289.87 644.133,1289.87 644.142,1289.87 644.151,1289.87 644.16,1289.87 644.169,1289.88 644.179,1289.88 644.188,1289.88 644.197,1289.88 644.206,1289.88 644.215,1289.88 644.225,1289.88 644.234,1289.88 644.243,1289.88 644.252,1289.88 644.261,1289.88 644.271,1289.88 644.28,1289.88 644.289,1289.88 644.298,1289.89 644.307,1289.89 644.317,1289.89 644.326,1289.89 644.335,1289.89 644.344,1289.89 644.353,1289.89 644.362,1289.89 644.372,1289.89 644.381,1289.89 644.39,1289.89 644.399,1289.89 644.408,1289.89 644.418,1289.89 644.427,1289.9 644.436,1289.9 644.445,1289.9 644.454,1289.9 644.464,1289.9 644.473,1289.9 644.482,1289.9 644.491,1289.9 644.5,1289.9 644.509,1289.9 644.519,1289.9 644.528,1289.9 644.537,1289.9 644.546,1289.9 644.555,1289.91 644.565,1289.91 644.574,1289.91 644.583,1289.91 644.592,1289.91 644.601,1289.91 644.611,1289.91 644.62,1289.91 644.629,1289.91 644.638,1289.91 644.647,1289.91 644.657,1289.91 644.666,1289.91 644.675,1289.91 644.684,1289.92 644.693,1289.92 644.702,1289.92 644.712,1289.92 644.721,1289.92 644.73,1289.92 644.739,1289.92 644.748,1289.92 644.758,1289.92 644.767,1289.92 644.776,1289.92 644.785,1289.92 644.794,1289.92 644.804,1289.92 644.813,1289.93 644.822,1289.93 644.831,1289.93 644.84,1289.93 644.85,1289.93 644.859,1289.93 644.868,1289.93 644.877,1289.93 644.886,1289.93 644.895,1289.93 644.905,1289.93 644.914,1289.93 644.923,1289.93 644.932,1289.93 644.941,1289.94 644.951,1289.94 644.96,1289.94 644.969,1289.94 644.978,1289.94 644.987,1289.94 644.997,1289.94 645.006,1289.94 645.015,1289.94 645.024,1289.94 645.033,1289.94 645.042,1289.94 645.052,1289.94 645.061,1289.94 645.07,1289.95 645.079,1289.95 645.088,1289.95 645.098,1289.95 645.107,1289.95 645.116,1289.95 645.125,1289.95 645.134,1289.95 645.144,1289.95 645.153,1289.95 645.162,1289.95 645.171,1289.95 645.18,1289.95 645.19,1289.96 645.199,1289.96 645.208,1289.96 645.217,1289.96 645.226,1289.96 645.235,1289.96 645.245,1289.96 645.254,1289.96 645.263,1289.96 645.272,1289.96 645.281,1289.96 645.291,1289.96 645.3,1289.96 645.309,1289.96 645.318,1289.97 645.327,1289.97 645.337,1289.97 645.346,1289.97 645.355,1289.97 645.364,1289.97 645.373,1289.97 645.382,1289.97 645.392,1289.97 645.401,1289.97 645.41,1289.97 645.419,1289.97 645.428,1289.97 645.438,1289.97 645.447,1289.98 645.456,1289.98 645.465,1289.98 645.474,1289.98 645.484,1289.98 645.493,1289.98 645.502,1289.98 645.511,1289.98 645.52,1289.98 645.53,1289.98 645.539,1289.98 645.548,1289.98 645.557,1289.98 645.566,1289.99 645.575,1289.99 645.585,1289.99 645.594,1289.99 645.603,1289.99 645.612,1289.99 645.621,1289.99 645.631,1289.99 645.64,1289.99 645.649,1289.99 645.658,1289.99 645.667,1289.99 645.677,1289.99 645.686,1290 645.695,1290 645.704,1290 645.713,1290 645.722,1290 645.732,1290 645.741,1290 645.75,1290 645.759,1290 645.768,1290 645.778,1290 645.787,1290 645.796,1290 645.805,1290 645.814,1290.01 645.824,1290.01 645.833,1290.01 645.842,1290.01 645.851,1290.01 645.86,1290.01 645.87,1290.01 645.879,1290.01 645.888,1290.01 645.897,1290.01 645.906,1290.01 645.915,1290.01 645.925,1290.01 645.934,1290.02 645.943,1290.02 645.952,1290.02 645.961,1290.02 645.971,1290.02 645.98,1290.02 645.989,1290.02 645.998,1290.02 646.007,1290.02 646.017,1290.02 646.026,1290.02 646.035,1290.02 646.044,1290.02 646.053,1290.03 646.062,1290.03 646.072,1290.03 646.081,1290.03 646.09,1290.03 646.099,1290.03 646.108,1290.03 646.118,1290.03 646.127,1290.03 646.136,1290.03 646.145,1290.03 646.154,1290.03 646.164,1290.03 646.173,1290.04 646.182,1290.04 646.191,1290.04 646.2,1290.04 646.21,1290.04 646.219,1290.04 646.228,1290.04 646.237,1290.04 646.246,1290.04 646.255,1290.04 646.265,1290.04 646.274,1290.04 646.283,1290.04 646.292,1290.05 646.301,1290.05 646.311,1290.05 646.32,1290.05 646.329,1290.05 646.338,1290.05 646.347,1290.05 646.357,1290.05 646.366,1290.05 646.375,1290.05 646.384,1290.05 646.393,1290.05 646.402,1290.05 646.412,1290.06 646.421,1290.06 646.43,1290.06 646.439,1290.06 646.448,1290.06 646.458,1290.06 646.467,1290.06 646.476,1290.06 646.485,1290.06 646.494,1290.06 646.504,1290.06 646.513,1290.06 646.522,1290.07 646.531,1290.07 646.54,1290.07 646.55,1290.07 646.559,1290.07 646.568,1290.07 646.577,1290.07 646.586,1290.07 646.595,1290.07 646.605,1290.07 646.614,1290.07 646.623,1290.07 646.632,1290.07 646.641,1290.08 646.651,1290.08 646.66,1290.08 646.669,1290.08 646.678,1290.08 646.687,1290.08 646.697,1290.08 646.706,1290.08 646.715,1290.08 646.724,1290.08 646.733,1290.08 646.742,1290.08 646.752,1290.08 646.761,1290.09 646.77,1290.09 646.779,1290.09 646.788,1290.09 646.798,1290.09 646.807,1290.09 646.816,1290.09 646.825,1290.09 646.834,1290.09 646.844,1290.09 646.853,1290.09 646.862,1290.09 646.871,1290.1 646.88,1290.1 646.89,1290.1 646.899,1290.1 646.908,1290.1 646.917,1290.1 646.926,1290.1 646.935,1290.1 646.945,1290.1 646.954,1290.1 646.963,1290.1 646.972,1290.1 646.981,1290.1 646.991,1290.11 647,1290.11 647.009,1290.11 647.018,1290.11 647.027,1290.11 647.037,1290.11 647.046,1290.11 647.055,1290.11 647.064,1290.11 647.073,1290.11 647.083,1290.11 647.092,1290.11 647.101,1290.12 647.11,1290.12 647.119,1290.12 647.128,1290.12 647.138,1290.12 647.147,1290.12 647.156,1290.12 647.165,1290.12 647.174,1290.12 647.184,1290.12 647.193,1290.12 647.202,1290.12 647.211,1290.12 647.22,1290.13 647.23,1290.13 647.239,1290.13 647.248,1290.13 647.257,1290.13 647.266,1290.13 647.275,1290.13 647.285,1290.13 647.294,1290.13 647.303,1290.13 647.312,1290.13 647.321,1290.13 647.331,1290.14 647.34,1290.14 647.349,1290.14 647.358,1290.14 647.367,1290.14 647.377,1290.14 647.386,1290.14 647.395,1290.14 647.404,1290.14 647.413,1290.14 647.423,1290.14 647.432,1290.14 647.441,1290.15 647.45,1290.15 647.459,1290.15 647.468,1290.15 647.478,1290.15 647.487,1290.15 647.496,1290.15 647.505,1290.15 647.514,1290.15 647.524,1290.15 647.533,1290.15 647.542,1290.15 647.551,1290.16 647.56,1290.16 647.57,1290.16 647.579,1290.16 647.588,1290.16 647.597,1290.16 647.606,1290.16 647.615,1290.16 647.625,1290.16 647.634,1290.16 647.643,1290.16 647.652,1290.16 647.661,1290.17 647.671,1290.17 647.68,1290.17 647.689,1290.17 647.698,1290.17 647.707,1290.17 647.717,1290.17 647.726,1290.17 647.735,1290.17 647.744,1290.17 647.753,1290.17 647.763,1290.17 647.772,1290.18 647.781,1290.18 647.79,1290.18 647.799,1290.18 647.808,1290.18 647.818,1290.18 647.827,1290.18 647.836,1290.18 647.845,1290.18 647.854,1290.18 647.864,1290.18 647.873,1290.18 647.882,1290.19 647.891,1290.19 647.9,1290.19 647.91,1290.19 647.919,1290.19 647.928,1290.19 647.937,1290.19 647.946,1290.19 647.955,1290.19 647.965,1290.19 647.974,1290.19 647.983,1290.19 647.992,1290.2 648.001,1290.2 648.011,1290.2 648.02,1290.2 648.029,1290.2 648.038,1290.2 648.047,1290.2 648.057,1290.2 648.066,1290.2 648.075,1290.2 648.084,1290.2 648.093,1290.2 648.103,1290.21 648.112,1290.21 648.121,1290.21 648.13,1290.21 648.139,1290.21 648.148,1290.21 648.158,1290.21 648.167,1290.21 648.176,1290.21 648.185,1290.21 648.194,1290.21 648.204,1290.21 648.213,1290.22 648.222,1290.22 648.231,1290.22 648.24,1290.22 648.25,1290.22 648.259,1290.22 648.268,1290.22 648.277,1290.22 648.286,1290.22 648.295,1290.22 648.305,1290.22 648.314,1290.23 648.323,1290.23 648.332,1290.23 648.341,1290.23 648.351,1290.23 648.36,1290.23 648.369,1290.23 648.378,1290.23 648.387,1290.23 648.397,1290.23 648.406,1290.23 648.415,1290.23 648.424,1290.24 648.433,1290.24 648.443,1290.24 648.452,1290.24 648.461,1290.24 648.47,1290.24 648.479,1290.24 648.488,1290.24 648.498,1290.24 648.507,1290.24 648.516,1290.24 648.525,1290.25 648.534,1290.25 648.544,1290.25 648.553,1290.25 648.562,1290.25 648.571,1290.25 648.58,1290.25 648.59,1290.25 648.599,1290.25 648.608,1290.25 648.617,1290.25 648.626,1290.25 648.635,1290.26 648.645,1290.26 648.654,1290.26 648.663,1290.26 648.672,1290.26 648.681,1290.26 648.691,1290.26 648.7,1290.26 648.709,1290.26 648.718,1290.26 648.727,1290.26 648.737,1290.27 648.746,1290.27 648.755,1290.27 648.764,1290.27 648.773,1290.27 648.783,1290.27 648.792,1290.27 648.801,1290.27 648.81,1290.27 648.819,1290.27 648.828,1290.27 648.838,1290.27 648.847,1290.28 648.856,1290.28 648.865,1290.28 648.874,1290.28 648.884,1290.28 648.893,1290.28 648.902,1290.28 648.911,1290.28 648.92,1290.28 648.93,1290.28 648.939,1290.28 648.948,1290.29 648.957,1290.29 648.966,1290.29 648.975,1290.29 648.985,1290.29 648.994,1290.29 649.003,1290.29 649.012,1290.29 649.021,1290.29 649.031,1290.29 649.04,1290.29 649.049,1290.29 649.058,1290.3 649.067,1290.3 649.077,1290.3 649.086,1290.3 649.095,1290.3 649.104,1290.3 649.113,1290.3 649.123,1290.3 649.132,1290.3 649.141,1290.3 649.15,1290.3 649.159,1290.31 649.168,1290.31 649.178,1290.31 649.187,1290.31 649.196,1290.31 649.205,1290.31 649.214,1290.31 649.224,1290.31 649.233,1290.31 649.242,1290.31 649.251,1290.31 649.26,1290.31 649.27,1290.32 649.279,1290.32 649.288,1290.32 649.297,1290.32 649.306,1290.32 649.315,1290.32 649.325,1290.32 649.334,1290.32 649.343,1290.32 649.352,1290.32 649.361,1290.32 649.371,1290.33 649.38,1290.33 649.389,1290.33 649.398,1290.33 649.407,1290.33 649.417,1290.33 649.426,1290.33 649.435,1290.33 649.444,1290.33 649.453,1290.33 649.463,1290.33 649.472,1290.33 649.481,1290.34 649.49,1290.34 649.499,1290.34 649.508,1290.34 649.518,1290.34 649.527,1290.34 649.536,1290.34 649.545,1290.34 649.554,1290.34 649.564,1290.34 649.573,1290.34 649.582,1290.35 649.591,1290.35 649.6,1290.35 649.61,1290.35 649.619,1290.35 649.628,1290.35 649.637,1290.35 649.646,1290.35 649.656,1290.35 649.665,1290.35 649.674,1290.35 649.683,1290.35 649.692,1290.36 649.701,1290.36 649.711,1290.36 649.72,1290.36 649.729,1290.36 649.738,1290.36 649.747,1290.36 649.757,1290.36 649.766,1290.36 649.775,1290.36 649.784,1290.36 649.793,1290.37 649.803,1290.37 649.812,1290.37 649.821,1290.37 649.83,1290.37 649.839,1290.37 649.848,1290.37 649.858,1290.37 649.867,1290.37 649.876,1290.37 649.885,1290.37 649.894,1290.37 649.904,1290.38 649.913,1290.38 649.922,1290.38 649.931,1290.38 649.94,1290.38 649.95,1290.38 649.959,1290.38 649.968,1290.38 649.977,1290.38 649.986,1290.38 649.996,1290.38 650.005,1290.39 650.014,1290.39 650.023,1290.39 650.032,1290.39 650.041,1290.39 650.051,1290.39 650.06,1290.39 650.069,1290.39 650.078,1290.39 650.087,1290.39 650.097,1290.39 650.106,1290.39 650.115,1290.4 650.124,1290.4 650.133,1290.4 650.143,1290.4 650.152,1290.4 650.161,1290.4 650.17,1290.4 650.179,1290.4 650.188,1290.4 650.198,1290.4 650.207,1290.4 650.216,1290.41 650.225,1290.41 650.234,1290.41 650.244,1290.41 650.253,1290.41 650.262,1290.41 650.271,1290.41 650.28,1290.41 650.29,1290.41 650.299,1290.41 650.308,1290.41 650.317,1290.41 650.326,1290.42 650.336,1290.42 650.345,1290.42 650.354,1290.42 650.363,1290.42 650.372,1290.42 650.381,1290.42 650.391,1290.42 650.4,1290.42 650.409,1290.42 650.418,1290.42 650.427,1290.43 650.437,1290.43 650.446,1290.43 650.455,1290.43 650.464,1290.43 650.473,1290.43 650.483,1290.43 650.492,1290.43 650.501,1290.43 650.51,1290.43 650.519,1290.43 650.528,1290.43 650.538,1290.44 650.547,1290.44 650.556,1290.44 650.565,1290.44 650.574,1290.44 650.584,1290.44 650.593,1290.44 650.602,1290.44 650.611,1290.44 650.62,1290.44 650.63,1290.44 650.639,1290.45 650.648,1290.45 650.657,1290.45 650.666,1290.45 650.676,1290.45 650.685,1290.45 650.694,1290.45 650.703,1290.45 650.712,1290.45 650.721,1290.45 650.731,1290.45 650.74,1290.45 650.749,1290.46 650.758,1290.46 650.767,1290.46 650.777,1290.46 650.786,1290.46 650.795,1290.46 650.804,1290.46 650.813,1290.46 650.823,1290.46 650.832,1290.46 650.841,1290.46 650.85,1290.47 650.859,1290.47 650.868,1290.47 650.878,1290.47 650.887,1290.47 650.896,1290.47 650.905,1290.47 650.914,1290.47 650.924,1290.47 650.933,1290.47 650.942,1290.47 650.951,1290.47 650.96,1290.48 650.97,1290.48 650.979,1290.48 650.988,1290.48 650.997,1290.48 651.006,1290.48 651.016,1290.48 651.025,1290.48 651.034,1290.48 651.043,1290.48 651.052,1290.48 651.061,1290.49 651.071,1290.49 651.08,1290.49 651.089,1290.49 651.098,1290.49 651.107,1290.49 651.117,1290.49 651.126,1290.49 651.135,1290.49 651.144,1290.49 651.153,1290.49 651.163,1290.49 651.172,1290.5 651.181,1290.5 651.19,1290.5 651.199,1290.5 651.208,1290.5 651.218,1290.5 651.227,1290.5 651.236,1290.5 651.245,1290.5 651.254,1290.5 651.264,1290.5 651.273,1290.51 651.282,1290.51 651.291,1290.51 651.3,1290.51 651.31,1290.51 651.319,1290.51 651.328,1290.51 651.337,1290.51 651.346,1290.51 651.356,1290.51 651.365,1290.51 651.374,1290.51 651.383,1290.52 651.392,1290.52 651.401,1290.52 651.411,1290.52 651.42,1290.52 651.429,1290.52 651.438,1290.52 651.447,1290.52 651.457,1290.52 651.466,1290.52 651.475,1290.52 651.484,1290.53 651.493,1290.53 651.503,1290.53 651.512,1290.53 651.521,1290.53 651.53,1290.53 651.539,1290.53 651.548,1290.53 651.558,1290.53 651.567,1290.53 651.576,1290.53 651.585,1290.53 651.594,1290.54 651.604,1290.54 651.613,1290.54 651.622,1290.54 651.631,1290.54 651.64,1290.54 651.65,1290.54 651.659,1290.54 651.668,1290.54 651.677,1290.54 651.686,1290.54 651.696,1290.55 651.705,1290.55 651.714,1290.55 651.723,1290.55 651.732,1290.55 651.741,1290.55 651.751,1290.55 651.76,1290.55 651.769,1290.55 651.778,1290.55 651.787,1290.55 651.797,1290.55 651.806,1290.56 651.815,1290.56 651.824,1290.56 651.833,1290.56 651.843,1290.56 651.852,1290.56 651.861,1290.56 651.87,1290.56 651.879,1290.56 651.888,1290.56 651.898,1290.56 651.907,1290.57 651.916,1290.57 651.925,1290.57 651.934,1290.57 651.944,1290.57 651.953,1290.57 651.962,1290.57 651.971,1290.57 651.98,1290.57 651.99,1290.57 651.999,1290.57 652.008,1290.57 652.017,1290.58 652.026,1290.58 652.036,1290.58 652.045,1290.58 652.054,1290.58 652.063,1290.58 652.072,1290.58 652.081,1290.58 652.091,1290.58 652.1,1290.58 652.109,1290.58 652.118,1290.59 652.127,1290.59 652.137,1290.59 652.146,1290.59 652.155,1290.59 652.164,1290.59 652.173,1290.59 652.183,1290.59 652.192,1290.59 652.201,1290.59 652.21,1290.59 652.219,1290.59 652.229,1290.6 652.238,1290.6 652.247,1290.6 652.256,1290.6 652.265,1290.6 652.274,1290.6 652.284,1290.6 652.293,1290.6 652.302,1290.6 652.311,1290.6 652.32,1290.6 652.33,1290.61 652.339,1290.61 652.348,1290.61 652.357,1290.61 652.366,1290.61 652.376,1290.61 652.385,1290.61 652.394,1290.61 652.403,1290.61 652.412,1290.61 652.421,1290.61 652.431,1290.61 652.44,1290.62 652.449,1290.62 652.458,1290.62 652.467,1290.62 652.477,1290.62 652.486,1290.62 652.495,1290.62 652.504,1290.62 652.513,1290.62 652.523,1290.62 652.532,1290.62 652.541,1290.63 652.55,1290.63 652.559,1290.63 652.569,1290.63 652.578,1290.63 652.587,1290.63 652.596,1290.63 652.605,1290.63 652.614,1290.63 652.624,1290.63 652.633,1290.63 652.642,1290.63 652.651,1290.64 652.66,1290.64 652.67,1290.64 652.679,1290.64 652.688,1290.64 652.697,1290.64 652.706,1290.64 652.716,1290.64 652.725,1290.64 652.734,1290.64 652.743,1290.64 652.752,1290.65 652.761,1290.65 652.771,1290.65 652.78,1290.65 652.789,1290.65 652.798,1290.65 652.807,1290.65 652.817,1290.65 652.826,1290.65 652.835,1290.65 652.844,1290.65 652.853,1290.65 652.863,1290.66 652.872,1290.66 652.881,1290.66 652.89,1290.66 652.899,1290.66 652.909,1290.66 652.918,1290.66 652.927,1290.66 652.936,1290.66 652.945,1290.66 652.954,1290.66 652.964,1290.67 652.973,1290.67 652.982,1290.67 652.991,1290.67 653,1290.67 653.01,1290.67 653.019,1290.67 653.028,1290.67 653.037,1290.67 653.046,1290.67 653.056,1290.67 653.065,1290.67 653.074,1290.68 653.083,1290.68 653.092,1290.68 653.101,1290.68 653.111,1290.68 653.12,1290.68 653.129,1290.68 653.138,1290.68 653.147,1290.68 653.157,1290.68 653.166,1290.68 653.175,1290.69 653.184,1290.69 653.193,1290.69 653.203,1290.69 653.212,1290.69 653.221,1290.69 653.23,1290.69 653.239,1290.69 653.249,1290.69 653.258,1290.69 653.267,1290.69 653.276,1290.69 653.285,1290.7 653.294,1290.7 653.304,1290.7 653.313,1290.7 653.322,1290.7 653.331,1290.7 653.34,1290.7 653.35,1290.7 653.359,1290.7 653.368,1290.7 653.377,1290.7 653.386,1290.71 653.396,1290.71 653.405,1290.71 653.414,1290.71 653.423,1290.71 653.432,1290.71 653.441,1290.71 653.451,1290.71 653.46,1290.71 653.469,1290.71 653.478,1290.71 653.487,1290.71 653.497,1290.72 653.506,1290.72 653.515,1290.72 653.524,1290.72 653.533,1290.72 653.543,1290.72 653.552,1290.72 653.561,1290.72 653.57,1290.72 653.579,1290.72 653.589,1290.72 653.598,1290.73 653.607,1290.73 653.616,1290.73 653.625,1290.73 653.634,1290.73 653.644,1290.73 653.653,1290.73 653.662,1290.73 653.671,1290.73 653.68,1290.73 653.69,1290.73 653.699,1290.73 653.708,1290.74 653.717,1290.74 653.726,1290.74 653.736,1290.74 653.745,1290.74 653.754,1290.74 653.763,1290.74 653.772,1290.74 653.781,1290.74 653.791,1290.74 653.8,1290.74 653.809,1290.75 653.818,1290.75 653.827,1290.75 653.837,1290.75 653.846,1290.75 653.855,1290.75 653.864,1290.75 653.873,1290.75 653.883,1290.75 653.892,1290.75 653.901,1290.75 653.91,1290.75 653.919,1290.76 653.929,1290.76 653.938,1290.76 653.947,1290.76 653.956,1290.76 653.965,1290.76 653.974,1290.76 653.984,1290.76 653.993,1290.76 654.002,1290.76 654.011,1290.76 654.02,1290.77 654.03,1290.77 654.039,1290.77 654.048,1290.77 654.057,1290.77 654.066,1290.77 654.076,1290.77 654.085,1290.77 654.094,1290.77 654.103,1290.77 654.112,1290.77 654.121,1290.77 654.131,1290.78 654.14,1290.78 654.149,1290.78 654.158,1290.78 654.167,1290.78 654.177,1290.78 654.186,1290.78 654.195,1290.78 654.204,1290.78 654.213,1290.78 654.223,1290.78 654.232,1290.79 654.241,1290.79 654.25,1290.79 654.259,1290.79 654.269,1290.79 654.278,1290.79 654.287,1290.79 654.296,1290.79 654.305,1290.79 654.314,1290.79 654.324,1290.79 654.333,1290.79 654.342,1290.8 654.351,1290.8 654.36,1290.8 654.37,1290.8 654.379,1290.8 654.388,1290.8 654.397,1290.8 654.406,1290.8 654.416,1290.8 654.425,1290.8 654.434,1290.8 654.443,1290.8 654.452,1290.81 654.462,1290.81 654.471,1290.81 654.48,1290.81 654.489,1290.81 654.498,1290.81 654.507,1290.81 654.517,1290.81 654.526,1290.81 654.535,1290.81 654.544,1290.81 654.553,1290.82 654.563,1290.82 654.572,1290.82 654.581,1290.82 654.59,1290.82 654.599,1290.82 654.609,1290.82 654.618,1290.82 654.627,1290.82 654.636,1290.82 654.645,1290.82 654.654,1290.82 654.664,1290.83 654.673,1290.83 654.682,1290.83 654.691,1290.83 654.7,1290.83 654.71,1290.83 654.719,1290.83 654.728,1290.83 654.737,1290.83 654.746,1290.83 654.756,1290.83 654.765,1290.84 654.774,1290.84 654.783,1290.84 654.792,1290.84 654.802,1290.84 654.811,1290.84 654.82,1290.84 654.829,1290.84 654.838,1290.84 654.847,1290.84 654.857,1290.84 654.866,1290.84 654.875,1290.85 654.884,1290.85 654.893,1290.85 654.903,1290.85 654.912,1290.85 654.921,1290.85 654.93,1290.85 654.939,1290.85 654.949,1290.85 654.958,1290.85 654.967,1290.85 654.976,1290.86 654.985,1290.86 654.994,1290.86 655.004,1290.86 655.013,1290.86 655.022,1290.86 655.031,1290.86 655.04,1290.86 655.05,1290.86 655.059,1290.86 655.068,1290.86 655.077,1290.86 655.086,1290.87 655.096,1290.87 655.105,1290.87 655.114,1290.87 655.123,1290.87 655.132,1290.87 655.142,1290.87 655.151,1290.87 655.16,1290.87 655.169,1290.87 655.178,1290.87 655.187,1290.88 655.197,1290.88 655.206,1290.88 655.215,1290.88 655.224,1290.88 655.233,1290.88 655.243,1290.88 655.252,1290.88 655.261,1290.88 655.27,1290.88 655.279,1290.88 655.289,1290.88 655.298,1290.89 655.307,1290.89 655.316,1290.89 655.325,1290.89 655.334,1290.89 655.344,1290.89 655.353,1290.89 655.362,1290.89 655.371,1290.89 655.38,1290.89 655.39,1290.89 655.399,1290.9 655.408,1290.9 655.417,1290.9 655.426,1290.9 655.436,1290.9 655.445,1290.9 655.454,1290.9 655.463,1290.9 655.472,1290.9 655.482,1290.9 655.491,1290.9 655.5,1290.9 655.509,1290.91 655.518,1290.91 655.527,1290.91 655.537,1290.91 655.546,1290.91 655.555,1290.91 655.564,1290.91 655.573,1290.91 655.583,1290.91 655.592,1290.91 655.601,1290.91 655.61,1290.92 655.619,1290.92 655.629,1290.92 655.638,1290.92 655.647,1290.92 655.656,1290.92 655.665,1290.92 655.674,1290.92 655.684,1290.92 655.693,1290.92 655.702,1290.92 655.711,1290.92 655.72,1290.93 655.73,1290.93 655.739,1290.93 655.748,1290.93 655.757,1290.93 655.766,1290.93 655.776,1290.93 655.785,1290.93 655.794,1290.93 655.803,1290.93 655.812,1290.93 655.822,1290.93 655.831,1290.94 655.84,1290.94 655.849,1290.94 655.858,1290.94 655.867,1290.94 655.877,1290.94 655.886,1290.94 655.895,1290.94 655.904,1290.94 655.913,1290.94 655.923,1290.94 655.932,1290.95 655.941,1290.95 655.95,1290.95 655.959,1290.95 655.969,1290.95 655.978,1290.95 655.987,1290.95 655.996,1290.95 656.005,1290.95 656.014,1290.95 656.024,1290.95 656.033,1290.95 656.042,1290.96 656.051,1290.96 656.06,1290.96 656.07,1290.96 656.079,1290.96 656.088,1290.96 656.097,1290.96 656.106,1290.96 656.116,1290.96 656.125,1290.96 656.134,1290.96 656.143,1290.97 656.152,1290.97 656.162,1290.97 656.171,1290.97 656.18,1290.97 656.189,1290.97 656.198,1290.97 656.207,1290.97 656.217,1290.97 656.226,1290.97 656.235,1290.97 656.244,1290.97 656.253,1290.98 656.263,1290.98 656.272,1290.98 656.281,1290.98 656.29,1290.98 656.299,1290.98 656.309,1290.98 656.318,1290.98 656.327,1290.98 656.336,1290.98 656.345,1290.98 656.354,1290.99 656.364,1290.99 656.373,1290.99 656.382,1290.99 656.391,1290.99 656.4,1290.99 656.41,1290.99 656.419,1290.99 656.428,1290.99 656.437,1290.99 656.446,1290.99 656.456,1290.99 656.465,1291 656.474,1291 656.483,1291 656.492,1291 656.502,1291 656.511,1291 656.52,1291 656.529,1291 656.538,1291 656.547,1291 656.557,1291 656.566,1291.01 656.575,1291.01 656.584,1291.01 656.593,1291.01 656.603,1291.01 656.612,1291.01 656.621,1291.01 656.63,1291.01 656.639,1291.01 656.649,1291.01 656.658,1291.01 656.667,1291.01 656.676,1291.02 656.685,1291.02 656.694,1291.02 656.704,1291.02 656.713,1291.02 656.722,1291.02 656.731,1291.02 656.74,1291.02 656.75,1291.02 656.759,1291.02 656.768,1291.02 656.777,1291.03 656.786,1291.03 656.796,1291.03 656.805,1291.03 656.814,1291.03 656.823,1291.03 656.832,1291.03 656.842,1291.03 656.851,1291.03 656.86,1291.03 656.869,1291.03 656.878,1291.03 656.887,1291.04 656.897,1291.04 656.906,1291.04 656.915,1291.04 656.924,1291.04 656.933,1291.04 656.943,1291.04 656.952,1291.04 656.961,1291.04 656.97,1291.04 656.979,1291.04 656.989,1291.04 656.998,1291.05 657.007,1291.05 657.016,1291.05 657.025,1291.05 657.035,1291.05 657.044,1291.05 657.053,1291.05 657.062,1291.05 657.071,1291.05 657.08,1291.05 657.09,1291.05 657.099,1291.06 657.108,1291.06 657.117,1291.06 657.126,1291.06 657.136,1291.06 657.145,1291.06 657.154,1291.06 657.163,1291.06 657.172,1291.06 657.182,1291.06 657.191,1291.06 657.2,1291.06 657.209,1291.07 657.218,1291.07 657.227,1291.07 657.237,1291.07 657.246,1291.07 657.255,1291.07 657.264,1291.07 657.273,1291.07 657.283,1291.07 657.292,1291.07 657.301,1291.07 657.31,1291.08 657.319,1291.08 657.329,1291.08 657.338,1291.08 657.347,1291.08 657.356,1291.08 657.365,1291.08 657.375,1291.08 657.384,1291.08 657.393,1291.08 657.402,1291.08 657.411,1291.08 657.42,1291.09 657.43,1291.09 657.439,1291.09 657.448,1291.09 657.457,1291.09 657.466,1291.09 657.476,1291.09 657.485,1291.09 657.494,1291.09 657.503,1291.09 657.512,1291.09 657.522,1291.1 657.531,1291.1 657.54,1291.1 657.549,1291.1 657.558,1291.1 657.567,1291.1 657.577,1291.1 657.586,1291.1 657.595,1291.1 657.604,1291.1 657.613,1291.1 657.623,1291.1 657.632,1291.11 657.641,1291.11 657.65,1291.11 657.659,1291.11 657.669,1291.11 657.678,1291.11 657.687,1291.11 657.696,1291.11 657.705,1291.11 657.715,1291.11 657.724,1291.11 657.733,1291.12 657.742,1291.12 657.751,1291.12 657.76,1291.12 657.77,1291.12 657.779,1291.12 657.788,1291.12 657.797,1291.12 657.806,1291.12 657.816,1291.12 657.825,1291.12 657.834,1291.12 657.843,1291.13 657.852,1291.13 657.862,1291.13 657.871,1291.13 657.88,1291.13 657.889,1291.13 657.898,1291.13 657.907,1291.13 657.917,1291.13 657.926,1291.13 657.935,1291.13 657.944,1291.13 657.953,1291.14 657.963,1291.14 657.972,1291.14 657.981,1291.14 657.99,1291.14 657.999,1291.14 658.009,1291.14 658.018,1291.14 658.027,1291.14 658.036,1291.14 658.045,1291.14 658.055,1291.15 658.064,1291.15 658.073,1291.15 658.082,1291.15 658.091,1291.15 658.1,1291.15 658.11,1291.15 658.119,1291.15 658.128,1291.15 658.137,1291.15 658.146,1291.15 658.156,1291.15 658.165,1291.16 658.174,1291.16 658.183,1291.16 658.192,1291.16 658.202,1291.16 658.211,1291.16 658.22,1291.16 658.229,1291.16 658.238,1291.16 658.247,1291.16 658.257,1291.16 658.266,1291.17 658.275,1291.17 658.284,1291.17 658.293,1291.17 658.303,1291.17 658.312,1291.17 658.321,1291.17 658.33,1291.17 658.339,1291.17 658.349,1291.17 658.358,1291.17 658.367,1291.17 658.376,1291.18 658.385,1291.18 658.395,1291.18 658.404,1291.18 658.413,1291.18 658.422,1291.18 658.431,1291.18 658.44,1291.18 658.45,1291.18 658.459,1291.18 658.468,1291.18 658.477,1291.19 658.486,1291.19 658.496,1291.19 658.505,1291.19 658.514,1291.19 658.523,1291.19 658.532,1291.19 658.542,1291.19 658.551,1291.19 658.56,1291.19 658.569,1291.19 658.578,1291.19 658.587,1291.2 658.597,1291.2 658.606,1291.2 658.615,1291.2 658.624,1291.2 658.633,1291.2 658.643,1291.2 658.652,1291.2 658.661,1291.2 658.67,1291.2 658.679,1291.2 658.689,1291.21 658.698,1291.21 658.707,1291.21 658.716,1291.21 658.725,1291.21 658.735,1291.21 658.744,1291.21 658.753,1291.21 658.762,1291.21 658.771,1291.21 658.78,1291.21 658.79,1291.21 658.799,1291.22 658.808,1291.22 658.817,1291.22 658.826,1291.22 658.836,1291.22 658.845,1291.22 658.854,1291.22 658.863,1291.22 658.872,1291.22 658.882,1291.22 658.891,1291.22 658.9,1291.22 658.909,1291.23 658.918,1291.23 658.927,1291.23 658.937,1291.23 658.946,1291.23 658.955,1291.23 658.964,1291.23 658.973,1291.23 658.983,1291.23 658.992,1291.23 659.001,1291.23 659.01,1291.24 659.019,1291.24 659.029,1291.24 659.038,1291.24 659.047,1291.24 659.056,1291.24 659.065,1291.24 659.075,1291.24 659.084,1291.24 659.093,1291.24 659.102,1291.24 659.111,1291.24 659.12,1291.25 659.13,1291.25 659.139,1291.25 659.148,1291.25 659.157,1291.25 659.166,1291.25 659.176,1291.25 659.185,1291.25 659.194,1291.25 659.203,1291.25 659.212,1291.25 659.222,1291.26 659.231,1291.26 659.24,1291.26 659.249,1291.26 659.258,1291.26 659.267,1291.26 659.277,1291.26 659.286,1291.26 659.295,1291.26 659.304,1291.26 659.313,1291.26 659.323,1291.26 659.332,1291.27 659.341,1291.27 659.35,1291.27 659.359,1291.27 659.369,1291.27 659.378,1291.27 659.387,1291.27 659.396,1291.27 659.405,1291.27 659.415,1291.27 659.424,1291.27 659.433,1291.28 659.442,1291.28 659.451,1291.28 659.46,1291.28 659.47,1291.28 659.479,1291.28 659.488,1291.28 659.497,1291.28 659.506,1291.28 659.516,1291.28 659.525,1291.28 659.534,1291.28 659.543,1291.29 659.552,1291.29 659.562,1291.29 659.571,1291.29 659.58,1291.29 659.589,1291.29 659.598,1291.29 659.608,1291.29 659.617,1291.29 659.626,1291.29 659.635,1291.29 659.644,1291.29 659.653,1291.3 659.663,1291.3 659.672,1291.3 659.681,1291.3 659.69,1291.3 659.699,1291.3 659.709,1291.3 659.718,1291.3 659.727,1291.3 659.736,1291.3 659.745,1291.3 659.755,1291.31 659.764,1291.31 659.773,1291.31 659.782,1291.31 659.791,1291.31 659.8,1291.31 659.81,1291.31 659.819,1291.31 659.828,1291.31 659.837,1291.31 659.846,1291.31 659.856,1291.31 659.865,1291.32 659.874,1291.32 659.883,1291.32 659.892,1291.32 659.902,1291.32 659.911,1291.32 659.92,1291.32 659.929,1291.32 659.938,1291.32 659.948,1291.32 659.957,1291.32 659.966,1291.33 659.975,1291.33 659.984,1291.33 659.993,1291.33 660.003,1291.33 660.012,1291.33 660.021,1291.33 660.03,1291.33 660.039,1291.33 660.049,1291.33 660.058,1291.33 660.067,1291.33 660.076,1291.34 660.085,1291.34 660.095,1291.34 660.104,1291.34 660.113,1291.34 660.122,1291.34 660.131,1291.34 660.14,1291.34 660.15,1291.34 660.159,1291.34 660.168,1291.34 660.177,1291.34 660.186,1291.35 660.196,1291.35 660.205,1291.35 660.214,1291.35 660.223,1291.35 660.232,1291.35 660.242,1291.35 660.251,1291.35 660.26,1291.35 660.269,1291.35 660.278,1291.35 660.288,1291.36 660.297,1291.36 660.306,1291.36 660.315,1291.36 660.324,1291.36 660.333,1291.36 660.343,1291.36 660.352,1291.36 660.361,1291.36 660.37,1291.36 660.379,1291.36 660.389,1291.36 660.398,1291.37 660.407,1291.37 660.416,1291.37 660.425,1291.37 660.435,1291.37 660.444,1291.37 660.453,1291.37 660.462,1291.37 660.471,1291.37 660.48,1291.37 660.49,1291.37 660.499,1291.38 660.508,1291.38 660.517,1291.38 660.526,1291.38 660.536,1291.38 660.545,1291.38 660.554,1291.38 660.563,1291.38 660.572,1291.38 660.582,1291.38 660.591,1291.38 660.6,1291.38 660.609,1291.39 660.618,1291.39 660.628,1291.39 660.637,1291.39 660.646,1291.39 660.655,1291.39 660.664,1291.39 660.673,1291.39 660.683,1291.39 660.692,1291.39 660.701,1291.39 660.71,1291.4 660.719,1291.4 660.729,1291.4 660.738,1291.4 660.747,1291.4 660.756,1291.4 660.765,1291.4 660.775,1291.4 660.784,1291.4 660.793,1291.4 660.802,1291.4 660.811,1291.4 660.82,1291.41 660.83,1291.41 660.839,1291.41 660.848,1291.41 660.857,1291.41 660.866,1291.41 660.876,1291.41 660.885,1291.41 660.894,1291.41 660.903,1291.41 660.912,1291.41 660.922,1291.41 660.931,1291.42 660.94,1291.42 660.949,1291.42 660.958,1291.42 660.968,1291.42 660.977,1291.42 660.986,1291.42 660.995,1291.42 661.004,1291.42 661.013,1291.42 661.023,1291.42 661.032,1291.43 661.041,1291.43 661.05,1291.43 661.059,1291.43 661.069,1291.43 661.078,1291.43 661.087,1291.43 661.096,1291.43 661.105,1291.43 661.115,1291.43 661.124,1291.43 661.133,1291.43 661.142,1291.44 661.151,1291.44 661.16,1291.44 661.17,1291.44 661.179,1291.44 661.188,1291.44 661.197,1291.44 661.206,1291.44 661.216,1291.44 661.225,1291.44 661.234,1291.44 661.243,1291.45 661.252,1291.45 661.262,1291.45 661.271,1291.45 661.28,1291.45 661.289,1291.45 661.298,1291.45 661.308,1291.45 661.317,1291.45 661.326,1291.45 661.335,1291.45 661.344,1291.45 661.353,1291.46 661.363,1291.46 661.372,1291.46 661.381,1291.46 661.39,1291.46 661.399,1291.46 661.409,1291.46 661.418,1291.46 661.427,1291.46 661.436,1291.46 661.445,1291.46 661.455,1291.46 661.464,1291.47 661.473,1291.47 661.482,1291.47 661.491,1291.47 661.5,1291.47 661.51,1291.47 661.519,1291.47 661.528,1291.47 661.537,1291.47 661.546,1291.47 661.556,1291.47 661.565,1291.48 661.574,1291.48 661.583,1291.48 661.592,1291.48 661.602,1291.48 661.611,1291.48 661.62,1291.48 661.629,1291.48 661.638,1291.48 661.648,1291.48 661.657,1291.48 661.666,1291.48 661.675,1291.49 661.684,1291.49 661.693,1291.49 661.703,1291.49 661.712,1291.49 661.721,1291.49 661.73,1291.49 661.739,1291.49 661.749,1291.49 661.758,1291.49 661.767,1291.49 661.776,1291.5 661.785,1291.5 661.795,1291.5 661.804,1291.5 661.813,1291.5 661.822,1291.5 661.831,1291.5 661.841,1291.5 661.85,1291.5 661.859,1291.5 661.868,1291.5 661.877,1291.5 661.886,1291.51 661.896,1291.51 661.905,1291.51 661.914,1291.51 661.923,1291.51 661.932,1291.51 661.942,1291.51 661.951,1291.51 661.96,1291.51 661.969,1291.51 661.978,1291.51 661.988,1291.51 661.997,1291.52 662.006,1291.52 662.015,1291.52 662.024,1291.52 662.033,1291.52 662.043,1291.52 662.052,1291.52 662.061,1291.52 662.07,1291.52 662.079,1291.52 662.089,1291.52 662.098,1291.53 662.107,1291.53 662.116,1291.53 662.125,1291.53 662.135,1291.53 662.144,1291.53 662.153,1291.53 662.162,1291.53 662.171,1291.53 662.181,1291.53 662.19,1291.53 662.199,1291.53 662.208,1291.54 662.217,1291.54 662.226,1291.54 662.236,1291.54 662.245,1291.54 662.254,1291.54 662.263,1291.54 662.272,1291.54 662.282,1291.54 662.291,1291.54 662.3,1291.54 662.309,1291.55 662.318,1291.55 662.328,1291.55 662.337,1291.55 662.346,1291.55 662.355,1291.55 662.364,1291.55 662.373,1291.55 662.383,1291.55 662.392,1291.55 662.401,1291.55 662.41,1291.55 662.419,1291.56 662.429,1291.56 662.438,1291.56 662.447,1291.56 662.456,1291.56 662.465,1291.56 662.475,1291.56 662.484,1291.56 662.493,1291.56 662.502,1291.56 662.511,1291.56 662.521,1291.56 662.53,1291.57 662.539,1291.57 662.548,1291.57 662.557,1291.57 662.566,1291.57 662.576,1291.57 662.585,1291.57 662.594,1291.57 662.603,1291.57 662.612,1291.57 662.622,1291.57 662.631,1291.58 662.64,1291.58 662.649,1291.58 662.658,1291.58 662.668,1291.58 662.677,1291.58 662.686,1291.58 662.695,1291.58 662.704,1291.58 662.713,1291.58 662.723,1291.58 662.732,1291.58 662.741,1291.59 662.75,1291.59 662.759,1291.59 662.769,1291.59 662.778,1291.59 662.787,1291.59 662.796,1291.59 662.805,1291.59 662.815,1291.59 662.824,1291.59 662.833,1291.59 662.842,1291.6 662.851,1291.6 662.861,1291.6 662.87,1291.6 662.879,1291.6 662.888,1291.6 662.897,1291.6 662.906,1291.6 662.916,1291.6 662.925,1291.6 662.934,1291.6 662.943,1291.6 662.952,1291.61 662.962,1291.61 662.971,1291.61 662.98,1291.61 662.989,1291.61 662.998,1291.61 663.008,1291.61 663.017,1291.61 663.026,1291.61 663.035,1291.61 663.044,1291.61 663.053,1291.61 663.063,1291.62 663.072,1291.62 663.081,1291.62 663.09,1291.62 663.099,1291.62 663.109,1291.62 663.118,1291.62 663.127,1291.62 663.136,1291.62 663.145,1291.62 663.155,1291.62 663.164,1291.63 663.173,1291.63 663.182,1291.63 663.191,1291.63 663.201,1291.63 663.21,1291.63 663.219,1291.63 663.228,1291.63 663.237,1291.63 663.246,1291.63 663.256,1291.63 663.265,1291.63 663.274,1291.64 663.283,1291.64 663.292,1291.64 663.302,1291.64 663.311,1291.64 663.32,1291.64 663.329,1291.64 663.338,1291.64 663.348,1291.64 663.357,1291.64 663.366,1291.64 663.375,1291.65 663.384,1291.65 663.393,1291.65 663.403,1291.65 663.412,1291.65 663.421,1291.65 663.43,1291.65 663.439,1291.65 663.449,1291.65 663.458,1291.65 663.467,1291.65 663.476,1291.65 663.485,1291.66 663.495,1291.66 663.504,1291.66 663.513,1291.66 663.522,1291.66 663.531,1291.66 663.541,1291.66 663.55,1291.66 663.559,1291.66 663.568,1291.66 663.577,1291.66 663.586,1291.66 663.596,1291.67 663.605,1291.67 663.614,1291.67 663.623,1291.67 663.632,1291.67 663.642,1291.67 663.651,1291.67 663.66,1291.67 663.669,1291.67 663.678,1291.67 663.688,1291.67 663.697,1291.68 663.706,1291.68 663.715,1291.68 663.724,1291.68 663.733,1291.68 663.743,1291.68 663.752,1291.68 663.761,1291.68 663.77,1291.68 663.779,1291.68 663.789,1291.68 663.798,1291.68 663.807,1291.69 663.816,1291.69 663.825,1291.69 663.835,1291.69 663.844,1291.69 663.853,1291.69 663.862,1291.69 663.871,1291.69 663.881,1291.69 663.89,1291.69 663.899,1291.69 663.908,1291.69 663.917,1291.7 663.926,1291.7 663.936,1291.7 663.945,1291.7 663.954,1291.7 663.963,1291.7 663.972,1291.7 663.982,1291.7 663.991,1291.7 664,1291.7 664.009,1291.7 664.018,1291.71 664.028,1291.71 664.037,1291.71 664.046,1291.71 664.055,1291.71 664.064,1291.71 664.073,1291.71 664.083,1291.71 664.092,1291.71 664.101,1291.71 664.11,1291.71 664.119,1291.71 664.129,1291.72 664.138,1291.72 664.147,1291.72 664.156,1291.72 664.165,1291.72 664.175,1291.72 664.184,1291.72 664.193,1291.72 664.202,1291.72 664.211,1291.72 664.221,1291.72 664.23,1291.73 664.239,1291.73 664.248,1291.73 664.257,1291.73 664.266,1291.73 664.276,1291.73 664.285,1291.73 664.294,1291.73 664.303,1291.73 664.312,1291.73 664.322,1291.73 664.331,1291.73 664.34,1291.74 664.349,1291.74 664.358,1291.74 664.368,1291.74 664.377,1291.74 664.386,1291.74 664.395,1291.74 664.404,1291.74 664.414,1291.74 664.423,1291.74 664.432,1291.74 664.441,1291.74 664.45,1291.75 664.459,1291.75 664.469,1291.75 664.478,1291.75 664.487,1291.75 664.496,1291.75 664.505,1291.75 664.515,1291.75 664.524,1291.75 664.533,1291.75 664.542,1291.75 664.551,1291.76 664.561,1291.76 664.57,1291.76 664.579,1291.76 664.588,1291.76 664.597,1291.76 664.606,1291.76 664.616,1291.76 664.625,1291.76 664.634,1291.76 664.643,1291.76 664.652,1291.76 664.662,1291.77 664.671,1291.77 664.68,1291.77 664.689,1291.77 664.698,1291.77 664.708,1291.77 664.717,1291.77 664.726,1291.77 664.735,1291.77 664.744,1291.77 664.754,1291.77 664.763,1291.77 664.772,1291.78 664.781,1291.78 664.79,1291.78 664.799,1291.78 664.809,1291.78 664.818,1291.78 664.827,1291.78 664.836,1291.78 664.845,1291.78 664.855,1291.78 664.864,1291.78 664.873,1291.79 664.882,1291.79 664.891,1291.79 664.901,1291.79 664.91,1291.79 664.919,1291.79 664.928,1291.79 664.937,1291.79 664.946,1291.79 664.956,1291.79 664.965,1291.79 664.974,1291.79 664.983,1291.8 664.992,1291.8 665.002,1291.8 665.011,1291.8 665.02,1291.8 665.029,1291.8 665.038,1291.8 665.048,1291.8 665.057,1291.8 665.066,1291.8 665.075,1291.8 665.084,1291.81 665.094,1291.81 665.103,1291.81 665.112,1291.81 665.121,1291.81 665.13,1291.81 665.139,1291.81 665.149,1291.81 665.158,1291.81 665.167,1291.81 665.176,1291.81 665.185,1291.81 665.195,1291.82 665.204,1291.82 665.213,1291.82 665.222,1291.82 665.231,1291.82 665.241,1291.82 665.25,1291.82 665.259,1291.82 665.268,1291.82 665.277,1291.82 665.286,1291.82 665.296,1291.82 665.305,1291.83 665.314,1291.83 665.323,1291.83 665.332,1291.83 665.342,1291.83 665.351,1291.83 665.36,1291.83 665.369,1291.83 665.378,1291.83 665.388,1291.83 665.397,1291.83 665.406,1291.84 665.415,1291.84 665.424,1291.84 665.434,1291.84 665.443,1291.84 665.452,1291.84 665.461,1291.84 665.47,1291.84 665.479,1291.84 665.489,1291.84 665.498,1291.84 665.507,1291.84 665.516,1291.85 665.525,1291.85 665.535,1291.85 665.544,1291.85 665.553,1291.85 665.562,1291.85 665.571,1291.85 665.581,1291.85 665.59,1291.85 665.599,1291.85 665.608,1291.85 665.617,1291.85 665.626,1291.86 665.636,1291.86 665.645,1291.86 665.654,1291.86 665.663,1291.86 665.672,1291.86 665.682,1291.86 665.691,1291.86 665.7,1291.86 665.709,1291.86 665.718,1291.86 665.728,1291.87 665.737,1291.87 665.746,1291.87 665.755,1291.87 665.764,1291.87 665.774,1291.87 665.783,1291.87 665.792,1291.87 665.801,1291.87 665.81,1291.87 665.819,1291.87 665.829,1291.87 665.838,1291.88 665.847,1291.88 665.856,1291.88 665.865,1291.88 665.875,1291.88 665.884,1291.88 665.893,1291.88 665.902,1291.88 665.911,1291.88 665.921,1291.88 665.93,1291.88 665.939,1291.89 665.948,1291.89 665.957,1291.89 665.966,1291.89 665.976,1291.89 665.985,1291.89 665.994,1291.89 666.003,1291.89 666.012,1291.89 666.022,1291.89 666.031,1291.89 666.04,1291.89 666.049,1291.9 666.058,1291.9 666.068,1291.9 666.077,1291.9 666.086,1291.9 666.095,1291.9 666.104,1291.9 666.114,1291.9 666.123,1291.9 666.132,1291.9 666.141,1291.9 666.15,1291.9 666.159,1291.91 666.169,1291.91 666.178,1291.91 666.187,1291.91 666.196,1291.91 666.205,1291.91 666.215,1291.91 666.224,1291.91 666.233,1291.91 666.242,1291.91 666.251,1291.91 666.261,1291.92 666.27,1291.92 666.279,1291.92 666.288,1291.92 666.297,1291.92 666.306,1291.92 666.316,1291.92 666.325,1291.92 666.334,1291.92 666.343,1291.92 666.352,1291.92 666.362,1291.92 666.371,1291.93 666.38,1291.93 666.389,1291.93 666.398,1291.93 666.408,1291.93 666.417,1291.93 666.426,1291.93 666.435,1291.93 666.444,1291.93 666.454,1291.93 666.463,1291.93 666.472,1291.93 666.481,1291.94 666.49,1291.94 666.499,1291.94 666.509,1291.94 666.518,1291.94 666.527,1291.94 666.536,1291.94 666.545,1291.94 666.555,1291.94 666.564,1291.94 666.573,1291.94 666.582,1291.95 666.591,1291.95 666.601,1291.95 666.61,1291.95 666.619,1291.95 666.628,1291.95 666.637,1291.95 666.646,1291.95 666.656,1291.95 666.665,1291.95 666.674,1291.95 666.683,1291.95 666.692,1291.96 666.702,1291.96 666.711,1291.96 666.72,1291.96 666.729,1291.96 666.738,1291.96 666.748,1291.96 666.757,1291.96 666.766,1291.96 666.775,1291.96 666.784,1291.96 666.794,1291.96 666.803,1291.97 666.812,1291.97 666.821,1291.97 666.83,1291.97 666.839,1291.97 666.849,1291.97 666.858,1291.97 666.867,1291.97 666.876,1291.97 666.885,1291.97 666.895,1291.97 666.904,1291.98 666.913,1291.98 666.922,1291.98 666.931,1291.98 666.941,1291.98 666.95,1291.98 666.959,1291.98 666.968,1291.98 666.977,1291.98 666.987,1291.98 666.996,1291.98 667.005,1291.98 667.014,1291.99 667.023,1291.99 667.032,1291.99 667.042,1291.99 667.051,1291.99 667.06,1291.99 667.069,1291.99 667.078,1291.99 667.088,1291.99 667.097,1291.99 667.106,1291.99 667.115,1291.99 667.124,1292 667.134,1292 667.143,1292 667.152,1292 667.161,1292 667.17,1292 667.179,1292 667.189,1292 667.198,1292 667.207,1292 667.216,1292 667.225,1292.01 667.235,1292.01 667.244,1292.01 667.253,1292.01 667.262,1292.01 667.271,1292.01 667.281,1292.01 667.29,1292.01 667.299,1292.01 667.308,1292.01 667.317,1292.01 667.327,1292.01 667.336,1292.02 667.345,1292.02 667.354,1292.02 667.363,1292.02 667.372,1292.02 667.382,1292.02 667.391,1292.02 667.4,1292.02 667.409,1292.02 667.418,1292.02 667.428,1292.02 667.437,1292.03 667.446,1292.03 667.455,1292.03 667.464,1292.03 667.474,1292.03 667.483,1292.03 667.492,1292.03 667.501,1292.03 667.51,1292.03 667.519,1292.03 667.529,1292.03 667.538,1292.03 667.547,1292.04 667.556,1292.04 667.565,1292.04 667.575,1292.04 667.584,1292.04 667.593,1292.04 667.602,1292.04 667.611,1292.04 667.621,1292.04 667.63,1292.04 667.639,1292.04 667.648,1292.04 667.657,1292.05 667.667,1292.05 667.676,1292.05 667.685,1292.05 667.694,1292.05 667.703,1292.05 667.712,1292.05 667.722,1292.05 667.731,1292.05 667.74,1292.05 667.749,1292.05 667.758,1292.06 667.768,1292.06 667.777,1292.06 667.786,1292.06 667.795,1292.06 667.804,1292.06 667.814,1292.06 667.823,1292.06 667.832,1292.06 667.841,1292.06 667.85,1292.06 667.859,1292.06 667.869,1292.07 667.878,1292.07 667.887,1292.07 667.896,1292.07 667.905,1292.07 667.915,1292.07 667.924,1292.07 667.933,1292.07 667.942,1292.07 667.951,1292.07 667.961,1292.07 667.97,1292.07 667.979,1292.08 667.988,1292.08 667.997,1292.08 668.007,1292.08 668.016,1292.08 668.025,1292.08 668.034,1292.08 668.043,1292.08 668.052,1292.08 668.062,1292.08 668.071,1292.08 668.08,1292.09 668.089,1292.09 668.098,1292.09 668.108,1292.09 668.117,1292.09 668.126,1292.09 668.135,1292.09 668.144,1292.09 668.154,1292.09 668.163,1292.09 668.172,1292.09 668.181,1292.09 668.19,1292.1 668.199,1292.1 668.209,1292.1 668.218,1292.1 668.227,1292.1 668.236,1292.1 668.245,1292.1 668.255,1292.1 668.264,1292.1 668.273,1292.1 668.282,1292.1 668.291,1292.1 668.301,1292.11 668.31,1292.11 668.319,1292.11 668.328,1292.11 668.337,1292.11 668.347,1292.11 668.356,1292.11 668.365,1292.11 668.374,1292.11 668.383,1292.11 668.392,1292.11 668.402,1292.12 668.411,1292.12 668.42,1292.12 668.429,1292.12 668.438,1292.12 668.448,1292.12 668.457,1292.12 668.466,1292.12 668.475,1292.12 668.484,1292.12 668.494,1292.12 668.503,1292.12 668.512,1292.13 668.521,1292.13 668.53,1292.13 668.539,1292.13 668.549,1292.13 668.558,1292.13 668.567,1292.13 668.576,1292.13 668.585,1292.13 668.595,1292.13 668.604,1292.13 668.613,1292.13 668.622,1292.14 668.631,1292.14 668.641,1292.14 668.65,1292.14 668.659,1292.14 668.668,1292.14 668.677,1292.14 668.687,1292.14 668.696,1292.14 668.705,1292.14 668.714,1292.14 668.723,1292.15 668.732,1292.15 668.742,1292.15 668.751,1292.15 668.76,1292.15 668.769,1292.15 668.778,1292.15 668.788,1292.15 668.797,1292.15 668.806,1292.15 668.815,1292.15 668.824,1292.15 668.834,1292.16 668.843,1292.16 668.852,1292.16 668.861,1292.16 668.87,1292.16 668.879,1292.16 668.889,1292.16 668.898,1292.16 668.907,1292.16 668.916,1292.16 668.925,1292.16 668.935,1292.16 668.944,1292.17 668.953,1292.17 668.962,1292.17 668.971,1292.17 668.981,1292.17 668.99,1292.17 668.999,1292.17 669.008,1292.17 669.017,1292.17 669.027,1292.17 669.036,1292.17 669.045,1292.18 669.054,1292.18 669.063,1292.18 669.072,1292.18 669.082,1292.18 669.091,1292.18 669.1,1292.18 669.109,1292.18 669.118,1292.18 669.128,1292.18 669.137,1292.18 669.146,1292.18 669.155,1292.19 669.164,1292.19 669.174,1292.19 669.183,1292.19 669.192,1292.19 669.201,1292.19 669.21,1292.19 669.22,1292.19 669.229,1292.19 669.238,1292.19 669.247,1292.19 669.256,1292.19 669.265,1292.2 669.275,1292.2 669.284,1292.2 669.293,1292.2 669.302,1292.2 669.311,1292.2 669.321,1292.2 669.33,1292.2 669.339,1292.2 669.348,1292.2 669.357,1292.2 669.367,1292.21 669.376,1292.21 669.385,1292.21 669.394,1292.21 669.403,1292.21 669.412,1292.21 669.422,1292.21 669.431,1292.21 669.44,1292.21 669.449,1292.21 669.458,1292.21 669.468,1292.21 669.477,1292.22 669.486,1292.22 669.495,1292.22 669.504,1292.22 669.514,1292.22 669.523,1292.22 669.532,1292.22 669.541,1292.22 669.55,1292.22 669.56,1292.22 669.569,1292.22 669.578,1292.22 669.587,1292.23 669.596,1292.23 669.605,1292.23 669.615,1292.23 669.624,1292.23 669.633,1292.23 669.642,1292.23 669.651,1292.23 669.661,1292.23 669.67,1292.23 669.679,1292.23 669.688,1292.24 669.697,1292.24 669.707,1292.24 669.716,1292.24 669.725,1292.24 669.734,1292.24 669.743,1292.24 669.752,1292.24 669.762,1292.24 669.771,1292.24 669.78,1292.24 669.789,1292.24 669.798,1292.25 669.808,1292.25 669.817,1292.25 669.826,1292.25 669.835,1292.25 669.844,1292.25 669.854,1292.25 669.863,1292.25 669.872,1292.25 669.881,1292.25 669.89,1292.25 669.9,1292.25 669.909,1292.26 669.918,1292.26 669.927,1292.26 669.936,1292.26 669.945,1292.26 669.955,1292.26 669.964,1292.26 669.973,1292.26 669.982,1292.26 669.991,1292.26 670.001,1292.26 670.01,1292.27 670.019,1292.27 670.028,1292.27 670.037,1292.27 670.047,1292.27 670.056,1292.27 670.065,1292.27 670.074,1292.27 670.083,1292.27 670.092,1292.27 670.102,1292.27 670.111,1292.27 670.12,1292.28 670.129,1292.28 670.138,1292.28 670.148,1292.28 670.157,1292.28 670.166,1292.28 670.175,1292.28 670.184,1292.28 670.194,1292.28 670.203,1292.28 670.212,1292.28 670.221,1292.28 670.23,1292.29 670.24,1292.29 670.249,1292.29 670.258,1292.29 670.267,1292.29 670.276,1292.29 670.285,1292.29 670.295,1292.29 670.304,1292.29 670.313,1292.29 670.322,1292.29 670.331,1292.3 670.341,1292.3 670.35,1292.3 670.359,1292.3 670.368,1292.3 670.377,1292.3 670.387,1292.3 670.396,1292.3 670.405,1292.3 670.414,1292.3 670.423,1292.3 670.432,1292.3 670.442,1292.31 670.451,1292.31 670.46,1292.31 670.469,1292.31 670.478,1292.31 670.488,1292.31 670.497,1292.31 670.506,1292.31 670.515,1292.31 670.524,1292.31 670.534,1292.31 670.543,1292.31 670.552,1292.32 670.561,1292.32 670.57,1292.32 670.58,1292.32 670.589,1292.32 670.598,1292.32 670.607,1292.32 670.616,1292.32 670.625,1292.32 670.635,1292.32 670.644,1292.32 670.653,1292.33 670.662,1292.33 670.671,1292.33 670.681,1292.33 670.69,1292.33 670.699,1292.33 670.708,1292.33 670.717,1292.33 670.727,1292.33 670.736,1292.33 670.745,1292.33 670.754,1292.33 670.763,1292.34 670.772,1292.34 670.782,1292.34 670.791,1292.34 670.8,1292.34 670.809,1292.34 670.818,1292.34 670.828,1292.34 670.837,1292.34 670.846,1292.34 670.855,1292.34 670.864,1292.34 670.874,1292.35 670.883,1292.35 670.892,1292.35 670.901,1292.35 670.91,1292.35 670.92,1292.35 670.929,1292.35 670.938,1292.35 670.947,1292.35 670.956,1292.35 670.965,1292.35 670.975,1292.36 670.984,1292.36 670.993,1292.36 671.002,1292.36 671.011,1292.36 671.021,1292.36 671.03,1292.36 671.039,1292.36 671.048,1292.36 671.057,1292.36 671.067,1292.36 671.076,1292.36 671.085,1292.37 671.094,1292.37 671.103,1292.37 671.112,1292.37 671.122,1292.37 671.131,1292.37 671.14,1292.37 671.149,1292.37 671.158,1292.37 671.168,1292.37 671.177,1292.37 671.186,1292.37 671.195,1292.38 671.204,1292.38 671.214,1292.38 671.223,1292.38 671.232,1292.38 671.241,1292.38 671.25,1292.38 671.26,1292.38 671.269,1292.38 671.278,1292.38 671.287,1292.38 671.296,1292.38 671.305,1292.39 671.315,1292.39 671.324,1292.39 671.333,1292.39 671.342,1292.39 671.351,1292.39 671.361,1292.39 671.37,1292.39 671.379,1292.39 671.388,1292.39 671.397,1292.39 671.407,1292.4 671.416,1292.4 671.425,1292.4 671.434,1292.4 671.443,1292.4 671.452,1292.4 671.462,1292.4 671.471,1292.4 671.48,1292.4 671.489,1292.4 671.498,1292.4 671.508,1292.4 671.517,1292.41 671.526,1292.41 671.535,1292.41 671.544,1292.41 671.554,1292.41 671.563,1292.41 671.572,1292.41 671.581,1292.41 671.59,1292.41 671.6,1292.41 671.609,1292.41 671.618,1292.41 671.627,1292.42 671.636,1292.42 671.645,1292.42 671.655,1292.42 671.664,1292.42 671.673,1292.42 671.682,1292.42 671.691,1292.42 671.701,1292.42 671.71,1292.42 671.719,1292.42 671.728,1292.43 671.737,1292.43 671.747,1292.43 671.756,1292.43 671.765,1292.43 671.774,1292.43 671.783,1292.43 671.793,1292.43 671.802,1292.43 671.811,1292.43 671.82,1292.43 671.829,1292.43 671.838,1292.44 671.848,1292.44 671.857,1292.44 671.866,1292.44 671.875,1292.44 671.884,1292.44 671.894,1292.44 671.903,1292.44 671.912,1292.44 671.921,1292.44 671.93,1292.44 671.94,1292.44 671.949,1292.45 671.958,1292.45 671.967,1292.45 671.976,1292.45 671.985,1292.45 671.995,1292.45 672.004,1292.45 672.013,1292.45 672.022,1292.45 672.031,1292.45 672.041,1292.45 672.05,1292.46 672.059,1292.46 672.068,1292.46 672.077,1292.46 672.087,1292.46 672.096,1292.46 672.105,1292.46 672.114,1292.46 672.123,1292.46 672.133,1292.46 672.142,1292.46 672.151,1292.46 672.16,1292.47 672.169,1292.47 672.178,1292.47 672.188,1292.47 672.197,1292.47 672.206,1292.47 672.215,1292.47 672.224,1292.47 672.234,1292.47 672.243,1292.47 672.252,1292.47 672.261,1292.47 672.27,1292.48 672.28,1292.48 672.289,1292.48 672.298,1292.48 672.307,1292.48 672.316,1292.48 672.325,1292.48 672.335,1292.48 672.344,1292.48 672.353,1292.48 672.362,1292.48 672.371,1292.49 672.381,1292.49 672.39,1292.49 672.399,1292.49 672.408,1292.49 672.417,1292.49 672.427,1292.49 672.436,1292.49 672.445,1292.49 672.454,1292.49 672.463,1292.49 672.473,1292.49 672.482,1292.5 672.491,1292.5 672.5,1292.5 672.509,1292.5 672.518,1292.5 672.528,1292.5 672.537,1292.5 672.546,1292.5 672.555,1292.5 672.564,1292.5 672.574,1292.5 672.583,1292.5 672.592,1292.51 672.601,1292.51 672.61,1292.51 672.62,1292.51 672.629,1292.51 672.638,1292.51 672.647,1292.51 672.656,1292.51 672.665,1292.51 672.675,1292.51 672.684,1292.51 672.693,1292.51 672.702,1292.52 672.711,1292.52 672.721,1292.52 672.73,1292.52 672.739,1292.52 672.748,1292.52 672.757,1292.52 672.767,1292.52 672.776,1292.52 672.785,1292.52 672.794,1292.52 672.803,1292.53 672.813,1292.53 672.822,1292.53 672.831,1292.53 672.84,1292.53 672.849,1292.53 672.858,1292.53 672.868,1292.53 672.877,1292.53 672.886,1292.53 672.895,1292.53 672.904,1292.53 672.914,1292.54 672.923,1292.54 672.932,1292.54 672.941,1292.54 672.95,1292.54 672.96,1292.54 672.969,1292.54 672.978,1292.54 672.987,1292.54 672.996,1292.54 673.005,1292.54 673.015,1292.54 673.024,1292.55 673.033,1292.55 673.042,1292.55 673.051,1292.55 673.061,1292.55 673.07,1292.55 673.079,1292.55 673.088,1292.55 673.097,1292.55 673.107,1292.55 673.116,1292.55 673.125,1292.56 673.134,1292.56 673.143,1292.56 673.153,1292.56 673.162,1292.56 673.171,1292.56 673.18,1292.56 673.189,1292.56 673.198,1292.56 673.208,1292.56 673.217,1292.56 673.226,1292.56 673.235,1292.57 673.244,1292.57 673.254,1292.57 673.263,1292.57 673.272,1292.57 673.281,1292.57 673.29,1292.57 673.3,1292.57 673.309,1292.57 673.318,1292.57 673.327,1292.57 673.336,1292.57 673.345,1292.58 673.355,1292.58 673.364,1292.58 673.373,1292.58 673.382,1292.58 673.391,1292.58 673.401,1292.58 673.41,1292.58 673.419,1292.58 673.428,1292.58 673.437,1292.58 673.447,1292.58 673.456,1292.59 673.465,1292.59 673.474,1292.59 673.483,1292.59 673.493,1292.59 673.502,1292.59 673.511,1292.59 673.52,1292.59 673.529,1292.59 673.538,1292.59 673.548,1292.59 673.557,1292.6 673.566,1292.6 673.575,1292.6 673.584,1292.6 673.594,1292.6 673.603,1292.6 673.612,1292.6 673.621,1292.6 673.63,1292.6 673.64,1292.6 673.649,1292.6 673.658,1292.6 673.667,1292.61 673.676,1292.61 673.685,1292.61 673.695,1292.61 673.704,1292.61 673.713,1292.61 673.722,1292.61 673.731,1292.61 673.741,1292.61 673.75,1292.61 673.759,1292.61 673.768,1292.61 673.777,1292.62 673.787,1292.62 673.796,1292.62 673.805,1292.62 673.814,1292.62 673.823,1292.62 673.833,1292.62 673.842,1292.62 673.851,1292.62 673.86,1292.62 673.869,1292.62 673.878,1292.63 673.888,1292.63 673.897,1292.63 673.906,1292.63 673.915,1292.63 673.924,1292.63 673.934,1292.63 673.943,1292.63 673.952,1292.63 673.961,1292.63 673.97,1292.63 673.98,1292.63 673.989,1292.64 673.998,1292.64 674.007,1292.64 674.016,1292.64 674.025,1292.64 674.035,1292.64 674.044,1292.64 674.053,1292.64 674.062,1292.64 674.071,1292.64 674.081,1292.64 674.09,1292.64 674.099,1292.65 674.108,1292.65 674.117,1292.65 674.127,1292.65 674.136,1292.65 674.145,1292.65 674.154,1292.65 674.163,1292.65 674.173,1292.65 674.182,1292.65 674.191,1292.65 674.2,1292.66 674.209,1292.66 674.218,1292.66 674.228,1292.66 674.237,1292.66 674.246,1292.66 674.255,1292.66 674.264,1292.66 674.274,1292.66 674.283,1292.66 674.292,1292.66 674.301,1292.66 674.31,1292.67 674.32,1292.67 674.329,1292.67 674.338,1292.67 674.347,1292.67 674.356,1292.67 674.366,1292.67 674.375,1292.67 674.384,1292.67 674.393,1292.67 674.402,1292.67 674.411,1292.67 674.421,1292.68 674.43,1292.68 674.439,1292.68 674.448,1292.68 674.457,1292.68 674.467,1292.68 674.476,1292.68 674.485,1292.68 674.494,1292.68 674.503,1292.68 674.513,1292.68 674.522,1292.68 674.531,1292.69 674.54,1292.69 674.549,1292.69 674.558,1292.69 674.568,1292.69 674.577,1292.69 674.586,1292.69 674.595,1292.69 674.604,1292.69 674.614,1292.69 674.623,1292.69 674.632,1292.7 674.641,1292.7 674.65,1292.7 674.66,1292.7 674.669,1292.7 674.678,1292.7 674.687,1292.7 674.696,1292.7 674.706,1292.7 674.715,1292.7 674.724,1292.7 674.733,1292.7 674.742,1292.71 674.751,1292.71 674.761,1292.71 674.77,1292.71 674.779,1292.71 674.788,1292.71 674.797,1292.71 674.807,1292.71 674.816,1292.71 674.825,1292.71 674.834,1292.71 674.843,1292.71 674.853,1292.72 674.862,1292.72 674.871,1292.72 674.88,1292.72 674.889,1292.72 674.898,1292.72 674.908,1292.72 674.917,1292.72 674.926,1292.72 674.935,1292.72 674.944,1292.72 674.954,1292.72 674.963,1292.73 674.972,1292.73 674.981,1292.73 674.99,1292.73 675,1292.73 675.009,1292.73 675.018,1292.73 675.027,1292.73 675.036,1292.73 675.046,1292.73 675.055,1292.73 675.064,1292.74 675.073,1292.74 675.082,1292.74 675.091,1292.74 675.101,1292.74 675.11,1292.74 675.119,1292.74 675.128,1292.74 675.137,1292.74 675.147,1292.74 675.156,1292.74 675.165,1292.74 675.174,1292.75 675.183,1292.75 675.193,1292.75 675.202,1292.75 675.211,1292.75 675.22,1292.75 675.229,1292.75 675.238,1292.75 675.248,1292.75 675.257,1292.75 675.266,1292.75 675.275,1292.75 675.284,1292.76 675.294,1292.76 675.303,1292.76 675.312,1292.76 675.321,1292.76 675.33,1292.76 675.34,1292.76 675.349,1292.76 675.358,1292.76 675.367,1292.76 675.376,1292.76 675.386,1292.77 675.395,1292.77 675.404,1292.77 675.413,1292.77 675.422,1292.77 675.431,1292.77 675.441,1292.77 675.45,1292.77 675.459,1292.77 675.468,1292.77 675.477,1292.77 675.487,1292.77 675.496,1292.78 675.505,1292.78 675.514,1292.78 675.523,1292.78 675.533,1292.78 675.542,1292.78 675.551,1292.78 675.56,1292.78 675.569,1292.78 675.578,1292.78 675.588,1292.78 675.597,1292.78 675.606,1292.79 675.615,1292.79 675.624,1292.79 675.634,1292.79 675.643,1292.79 675.652,1292.79 675.661,1292.79 675.67,1292.79 675.68,1292.79 675.689,1292.79 675.698,1292.79 675.707,1292.79 675.716,1292.8 675.726,1292.8 675.735,1292.8 675.744,1292.8 675.753,1292.8 675.762,1292.8 675.771,1292.8 675.781,1292.8 675.79,1292.8 675.799,1292.8 675.808,1292.8 675.817,1292.81 675.827,1292.81 675.836,1292.81 675.845,1292.81 675.854,1292.81 675.863,1292.81 675.873,1292.81 675.882,1292.81 675.891,1292.81 675.9,1292.81 675.909,1292.81 675.918,1292.81 675.928,1292.82 675.937,1292.82 675.946,1292.82 675.955,1292.82 675.964,1292.82 675.974,1292.82 675.983,1292.82 675.992,1292.82 676.001,1292.82 676.01,1292.82 676.02,1292.82 676.029,1292.82 676.038,1292.83 676.047,1292.83 676.056,1292.83 676.066,1292.83 676.075,1292.83 676.084,1292.83 676.093,1292.83 676.102,1292.83 676.111,1292.83 676.121,1292.83 676.13,1292.83 676.139,1292.83 676.148,1292.84 676.157,1292.84 676.167,1292.84 676.176,1292.84 676.185,1292.84 676.194,1292.84 676.203,1292.84 676.213,1292.84 676.222,1292.84 676.231,1292.84 676.24,1292.84 676.249,1292.85 676.258,1292.85 676.268,1292.85 676.277,1292.85 676.286,1292.85 676.295,1292.85 676.304,1292.85 676.314,1292.85 676.323,1292.85 676.332,1292.85 676.341,1292.85 676.35,1292.85 676.36,1292.86 676.369,1292.86 676.378,1292.86 676.387,1292.86 676.396,1292.86 676.406,1292.86 676.415,1292.86 676.424,1292.86 676.433,1292.86 676.442,1292.86 676.451,1292.86 676.461,1292.86 676.47,1292.87 676.479,1292.87 676.488,1292.87 676.497,1292.87 676.507,1292.87 676.516,1292.87 676.525,1292.87 676.534,1292.87 676.543,1292.87 676.553,1292.87 676.562,1292.87 676.571,1292.88 676.58,1292.88 676.589,1292.88 676.599,1292.88 676.608,1292.88 676.617,1292.88 676.626,1292.88 676.635,1292.88 676.644,1292.88 676.654,1292.88 676.663,1292.88 676.672,1292.88 676.681,1292.89 676.69,1292.89 676.7,1292.89 676.709,1292.89 676.718,1292.89 676.727,1292.89 676.736,1292.89 676.746,1292.89 676.755,1292.89 676.764,1292.89 676.773,1292.89 676.782,1292.89 676.791,1292.9 676.801,1292.9 676.81,1292.9 676.819,1292.9 676.828,1292.9 676.837,1292.9 676.847,1292.9 676.856,1292.9 676.865,1292.9 676.874,1292.9 676.883,1292.9 676.893,1292.9 676.902,1292.91 676.911,1292.91 676.92,1292.91 676.929,1292.91 676.939,1292.91 676.948,1292.91 676.957,1292.91 676.966,1292.91 676.975,1292.91 676.984,1292.91 676.994,1292.91 677.003,1292.92 677.012,1292.92 677.021,1292.92 677.03,1292.92 677.04,1292.92 677.049,1292.92 677.058,1292.92 677.067,1292.92 677.076,1292.92 677.086,1292.92 677.095,1292.92 677.104,1292.92 677.113,1292.93 677.122,1292.93 677.131,1292.93 677.141,1292.93 677.15,1292.93 677.159,1292.93 677.168,1292.93 677.177,1292.93 677.187,1292.93 677.196,1292.93 677.205,1292.93 677.214,1292.93 677.223,1292.94 677.233,1292.94 677.242,1292.94 677.251,1292.94 677.26,1292.94 677.269,1292.94 677.279,1292.94 677.288,1292.94 677.297,1292.94 677.306,1292.94 677.315,1292.94 677.324,1292.94 677.334,1292.95 677.343,1292.95 677.352,1292.95 677.361,1292.95 677.37,1292.95 677.38,1292.95 677.389,1292.95 677.398,1292.95 677.407,1292.95 677.416,1292.95 677.426,1292.95 677.435,1292.96 677.444,1292.96 677.453,1292.96 677.462,1292.96 677.471,1292.96 677.481,1292.96 677.49,1292.96 677.499,1292.96 677.508,1292.96 677.517,1292.96 677.527,1292.96 677.536,1292.96 677.545,1292.97 677.554,1292.97 677.563,1292.97 677.573,1292.97 677.582,1292.97 677.591,1292.97 677.6,1292.97 677.609,1292.97 677.619,1292.97 677.628,1292.97 677.637,1292.97 677.646,1292.97 677.655,1292.98 677.664,1292.98 677.674,1292.98 677.683,1292.98 677.692,1292.98 677.701,1292.98 677.71,1292.98 677.72,1292.98 677.729,1292.98 677.738,1292.98 677.747,1292.98 677.756,1292.98 677.766,1292.99 677.775,1292.99 677.784,1292.99 677.793,1292.99 677.802,1292.99 677.811,1292.99 677.821,1292.99 677.83,1292.99 677.839,1292.99 677.848,1292.99 677.857,1292.99 677.867,1293 677.876,1293 677.885,1293 677.894,1293 677.903,1293 677.913,1293 677.922,1293 677.931,1293 677.94,1293 677.949,1293 677.959,1293 677.968,1293 677.977,1293.01 677.986,1293.01 677.995,1293.01 678.004,1293.01 678.014,1293.01 678.023,1293.01 678.032,1293.01 678.041,1293.01 678.05,1293.01 678.06,1293.01 678.069,1293.01 678.078,1293.01 678.087,1293.02 678.096,1293.02 678.106,1293.02 678.115,1293.02 678.124,1293.02 678.133,1293.02 678.142,1293.02 678.151,1293.02 678.161,1293.02 678.17,1293.02 678.179,1293.02 678.188,1293.02 678.197,1293.03 678.207,1293.03 678.216,1293.03 678.225,1293.03 678.234,1293.03 678.243,1293.03 678.253,1293.03 678.262,1293.03 678.271,1293.03 678.28,1293.03 678.289,1293.03 678.299,1293.04 678.308,1293.04 678.317,1293.04 678.326,1293.04 678.335,1293.04 678.344,1293.04 678.354,1293.04 678.363,1293.04 678.372,1293.04 678.381,1293.04 678.39,1293.04 678.4,1293.04 678.409,1293.05 678.418,1293.05 678.427,1293.05 678.436,1293.05 678.446,1293.05 678.455,1293.05 678.464,1293.05 678.473,1293.05 678.482,1293.05 678.491,1293.05 678.501,1293.05 678.51,1293.05 678.519,1293.06 678.528,1293.06 678.537,1293.06 678.547,1293.06 678.556,1293.06 678.565,1293.06 678.574,1293.06 678.583,1293.06 678.593,1293.06 678.602,1293.06 678.611,1293.06 678.62,1293.06 678.629,1293.07 678.639,1293.07 678.648,1293.07 678.657,1293.07 678.666,1293.07 678.675,1293.07 678.684,1293.07 678.694,1293.07 678.703,1293.07 678.712,1293.07 678.721,1293.07 678.73,1293.08 678.74,1293.08 678.749,1293.08 678.758,1293.08 678.767,1293.08 678.776,1293.08 678.786,1293.08 678.795,1293.08 678.804,1293.08 678.813,1293.08 678.822,1293.08 678.831,1293.08 678.841,1293.09 678.85,1293.09 678.859,1293.09 678.868,1293.09 678.877,1293.09 678.887,1293.09 678.896,1293.09 678.905,1293.09 678.914,1293.09 678.923,1293.09 678.933,1293.09 678.942,1293.09 678.951,1293.1 678.96,1293.1 678.969,1293.1 678.979,1293.1 678.988,1293.1 678.997,1293.1 679.006,1293.1 679.015,1293.1 679.024,1293.1 679.034,1293.1 679.043,1293.1 679.052,1293.1 679.061,1293.11 679.07,1293.11 679.08,1293.11 679.089,1293.11 679.098,1293.11 679.107,1293.11 679.116,1293.11 679.126,1293.11 679.135,1293.11 679.144,1293.11 679.153,1293.11 679.162,1293.12 679.172,1293.12 679.181,1293.12 679.19,1293.12 679.199,1293.12 679.208,1293.12 679.217,1293.12 679.227,1293.12 679.236,1293.12 679.245,1293.12 679.254,1293.12 679.263,1293.12 679.273,1293.13 679.282,1293.13 679.291,1293.13 679.3,1293.13 679.309,1293.13 679.319,1293.13 679.328,1293.13 679.337,1293.13 679.346,1293.13 679.355,1293.13 679.364,1293.13 679.374,1293.13 679.383,1293.14 679.392,1293.14 679.401,1293.14 679.41,1293.14 679.42,1293.14 679.429,1293.14 679.438,1293.14 679.447,1293.14 679.456,1293.14 679.466,1293.14 679.475,1293.14 679.484,1293.14 679.493,1293.15 679.502,1293.15 679.512,1293.15 679.521,1293.15 679.53,1293.15 679.539,1293.15 679.548,1293.15 679.557,1293.15 679.567,1293.15 679.576,1293.15 679.585,1293.15 679.594,1293.15 679.603,1293.16 679.613,1293.16 679.622,1293.16 679.631,1293.16 679.64,1293.16 679.649,1293.16 679.659,1293.16 679.668,1293.16 679.677,1293.16 679.686,1293.16 679.695,1293.16 679.704,1293.17 679.714,1293.17 679.723,1293.17 679.732,1293.17 679.741,1293.17 679.75,1293.17 679.76,1293.17 679.769,1293.17 679.778,1293.17 679.787,1293.17 679.796,1293.17 679.806,1293.17 679.815,1293.18 679.824,1293.18 679.833,1293.18 679.842,1293.18 679.852,1293.18 679.861,1293.18 679.87,1293.18 679.879,1293.18 679.888,1293.18 679.897,1293.18 679.907,1293.18 679.916,1293.18 679.925,1293.19 679.934,1293.19 679.943,1293.19 679.953,1293.19 679.962,1293.19 679.971,1293.19 679.98,1293.19 679.989,1293.19 679.999,1293.19 680.008,1293.19 680.017,1293.19 680.026,1293.19 680.035,1293.2 680.044,1293.2 680.054,1293.2 680.063,1293.2 680.072,1293.2 680.081,1293.2 680.09,1293.2 680.1,1293.2 680.109,1293.2 680.118,1293.2 680.127,1293.2 680.136,1293.21 680.146,1293.21 680.155,1293.21 680.164,1293.21 680.173,1293.21 680.182,1293.21 680.192,1293.21 680.201,1293.21 680.21,1293.21 680.219,1293.21 680.228,1293.21 680.237,1293.21 680.247,1293.22 680.256,1293.22 680.265,1293.22 680.274,1293.22 680.283,1293.22 680.293,1293.22 680.302,1293.22 680.311,1293.22 680.32,1293.22 680.329,1293.22 680.339,1293.22 680.348,1293.22 680.357,1293.23 680.366,1293.23 680.375,1293.23 680.384,1293.23 680.394,1293.23 680.403,1293.23 680.412,1293.23 680.421,1293.23 680.43,1293.23 680.44,1293.23 680.449,1293.23 680.458,1293.23 680.467,1293.24 680.476,1293.24 680.486,1293.24 680.495,1293.24 680.504,1293.24 680.513,1293.24 680.522,1293.24 680.532,1293.24 680.541,1293.24 680.55,1293.24 680.559,1293.24 680.568,1293.25 680.577,1293.25 680.587,1293.25 680.596,1293.25 680.605,1293.25 680.614,1293.25 680.623,1293.25 680.633,1293.25 680.642,1293.25 680.651,1293.25 680.66,1293.25 680.669,1293.25 680.679,1293.26 680.688,1293.26 680.697,1293.26 680.706,1293.26 680.715,1293.26 680.724,1293.26 680.734,1293.26 680.743,1293.26 680.752,1293.26 680.761,1293.26 680.77,1293.26 680.78,1293.26 680.789,1293.27 680.798,1293.27 680.807,1293.27 680.816,1293.27 680.826,1293.27 680.835,1293.27 680.844,1293.27 680.853,1293.27 680.862,1293.27 680.872,1293.27 680.881,1293.27 680.89,1293.27 680.899,1293.28 680.908,1293.28 680.917,1293.28 680.927,1293.28 680.936,1293.28 680.945,1293.28 680.954,1293.28 680.963,1293.28 680.973,1293.28 680.982,1293.28 680.991,1293.28 681,1293.28 681.009,1293.29 681.019,1293.29 681.028,1293.29 681.037,1293.29 681.046,1293.29 681.055,1293.29 681.064,1293.29 681.074,1293.29 681.083,1293.29 681.092,1293.29 681.101,1293.29 681.11,1293.3 681.12,1293.3 681.129,1293.3 681.138,1293.3 681.147,1293.3 681.156,1293.3 681.166,1293.3 681.175,1293.3 681.184,1293.3 681.193,1293.3 681.202,1293.3 681.212,1293.3 681.221,1293.31 681.23,1293.31 681.239,1293.31 681.248,1293.31 681.257,1293.31 681.267,1293.31 681.276,1293.31 681.285,1293.31 681.294,1293.31 681.303,1293.31 681.313,1293.31 681.322,1293.31 681.331,1293.32 681.34,1293.32 681.349,1293.32 681.359,1293.32 681.368,1293.32 681.377,1293.32 681.386,1293.32 681.395,1293.32 681.404,1293.32 681.414,1293.32 681.423,1293.32 681.432,1293.32 681.441,1293.33 681.45,1293.33 681.46,1293.33 681.469,1293.33 681.478,1293.33 681.487,1293.33 681.496,1293.33 681.506,1293.33 681.515,1293.33 681.524,1293.33 681.533,1293.33 681.542,1293.33 681.552,1293.34 681.561,1293.34 681.57,1293.34 681.579,1293.34 681.588,1293.34 681.597,1293.34 681.607,1293.34 681.616,1293.34 681.625,1293.34 681.634,1293.34 681.643,1293.34 681.653,1293.35 681.662,1293.35 681.671,1293.35 681.68,1293.35 681.689,1293.35 681.699,1293.35 681.708,1293.35 681.717,1293.35 681.726,1293.35 681.735,1293.35 681.745,1293.35 681.754,1293.35 681.763,1293.36 681.772,1293.36 681.781,1293.36 681.79,1293.36 681.8,1293.36 681.809,1293.36 681.818,1293.36 681.827,1293.36 681.836,1293.36 681.846,1293.36 681.855,1293.36 681.864,1293.36 681.873,1293.37 681.882,1293.37 681.892,1293.37 681.901,1293.37 681.91,1293.37 681.919,1293.37 681.928,1293.37 681.937,1293.37 681.947,1293.37 681.956,1293.37 681.965,1293.37 681.974,1293.37 681.983,1293.38 681.993,1293.38 682.002,1293.38 682.011,1293.38 682.02,1293.38 682.029,1293.38 682.039,1293.38 682.048,1293.38 682.057,1293.38 682.066,1293.38 682.075,1293.38 682.085,1293.39 682.094,1293.39 682.103,1293.39 682.112,1293.39 682.121,1293.39 682.13,1293.39 682.14,1293.39 682.149,1293.39 682.158,1293.39 682.167,1293.39 682.176,1293.39 682.186,1293.39 682.195,1293.4 682.204,1293.4 682.213,1293.4 682.222,1293.4 682.232,1293.4 682.241,1293.4 682.25,1293.4 682.259,1293.4 682.268,1293.4 682.277,1293.4 682.287,1293.4 682.296,1293.4 682.305,1293.41 682.314,1293.41 682.323,1293.41 682.333,1293.41 682.342,1293.41 682.351,1293.41 682.36,1293.41 682.369,1293.41 682.379,1293.41 682.388,1293.41 682.397,1293.41 682.406,1293.41 682.415,1293.42 682.425,1293.42 682.434,1293.42 682.443,1293.42 682.452,1293.42 682.461,1293.42 682.47,1293.42 682.48,1293.42 682.489,1293.42 682.498,1293.42 682.507,1293.42 682.516,1293.42 682.526,1293.43 682.535,1293.43 682.544,1293.43 682.553,1293.43 682.562,1293.43 682.572,1293.43 682.581,1293.43 682.59,1293.43 682.599,1293.43 682.608,1293.43 682.617,1293.43 682.627,1293.44 682.636,1293.44 682.645,1293.44 682.654,1293.44 682.663,1293.44 682.673,1293.44 682.682,1293.44 682.691,1293.44 682.7,1293.44 682.709,1293.44 682.719,1293.44 682.728,1293.44 682.737,1293.45 682.746,1293.45 682.755,1293.45 682.765,1293.45 682.774,1293.45 682.783,1293.45 682.792,1293.45 682.801,1293.45 682.81,1293.45 682.82,1293.45 682.829,1293.45 682.838,1293.45 682.847,1293.46 682.856,1293.46 682.866,1293.46 682.875,1293.46 682.884,1293.46 682.893,1293.46 682.902,1293.46 682.912,1293.46 682.921,1293.46 682.93,1293.46 682.939,1293.46 682.948,1293.46 682.957,1293.47 682.967,1293.47 682.976,1293.47 682.985,1293.47 682.994,1293.47 683.003,1293.47 683.013,1293.47 683.022,1293.47 683.031,1293.47 683.04,1293.47 683.049,1293.47 683.059,1293.47 683.068,1293.48 683.077,1293.48 683.086,1293.48 683.095,1293.48 683.105,1293.48 683.114,1293.48 683.123,1293.48 683.132,1293.48 683.141,1293.48 683.15,1293.48 683.16,1293.48 683.169,1293.49 683.178,1293.49 683.187,1293.49 683.196,1293.49 683.206,1293.49 683.215,1293.49 683.224,1293.49 683.233,1293.49 683.242,1293.49 683.252,1293.49 683.261,1293.49 683.27,1293.49 683.279,1293.5 683.288,1293.5 683.297,1293.5 683.307,1293.5 683.316,1293.5 683.325,1293.5 683.334,1293.5 683.343,1293.5 683.353,1293.5 683.362,1293.5 683.371,1293.5 683.38,1293.5 683.389,1293.51 683.399,1293.51 683.408,1293.51 683.417,1293.51 683.426,1293.51 683.435,1293.51 683.445,1293.51 683.454,1293.51 683.463,1293.51 683.472,1293.51 683.481,1293.51 683.49,1293.51 683.5,1293.52 683.509,1293.52 683.518,1293.52 683.527,1293.52 683.536,1293.52 683.546,1293.52 683.555,1293.52 683.564,1293.52 683.573,1293.52 683.582,1293.52 683.592,1293.52 683.601,1293.52 683.61,1293.53 683.619,1293.53 683.628,1293.53 683.637,1293.53 683.647,1293.53 683.656,1293.53 683.665,1293.53 683.674,1293.53 683.683,1293.53 683.693,1293.53 683.702,1293.53 683.711,1293.54 683.72,1293.54 683.729,1293.54 683.739,1293.54 683.748,1293.54 683.757,1293.54 683.766,1293.54 683.775,1293.54 683.785,1293.54 683.794,1293.54 683.803,1293.54 683.812,1293.54 683.821,1293.55 683.83,1293.55 683.84,1293.55 683.849,1293.55 683.858,1293.55 683.867,1293.55 683.876,1293.55 683.886,1293.55 683.895,1293.55 683.904,1293.55 683.913,1293.55 683.922,1293.55 683.932,1293.56 683.941,1293.56 683.95,1293.56 683.959,1293.56 683.968,1293.56 683.978,1293.56 683.987,1293.56 683.996,1293.56 684.005,1293.56 684.014,1293.56 684.023,1293.56 684.033,1293.56 684.042,1293.57 684.051,1293.57 684.06,1293.57 684.069,1293.57 684.079,1293.57 684.088,1293.57 684.097,1293.57 684.106,1293.57 684.115,1293.57 684.125,1293.57 684.134,1293.57 684.143,1293.57 684.152,1293.58 684.161,1293.58 684.17,1293.58 684.18,1293.58 684.189,1293.58 684.198,1293.58 684.207,1293.58 684.216,1293.58 684.226,1293.58 684.235,1293.58 684.244,1293.58 684.253,1293.59 684.262,1293.59 684.272,1293.59 684.281,1293.59 684.29,1293.59 684.299,1293.59 684.308,1293.59 684.318,1293.59 684.327,1293.59 684.336,1293.59 684.345,1293.59 684.354,1293.59 684.363,1293.6 684.373,1293.6 684.382,1293.6 684.391,1293.6 684.4,1293.6 684.409,1293.6 684.419,1293.6 684.428,1293.6 684.437,1293.6 684.446,1293.6 684.455,1293.6 684.465,1293.6 684.474,1293.61 684.483,1293.61 684.492,1293.61 684.501,1293.61 684.51,1293.61 684.52,1293.61 684.529,1293.61 684.538,1293.61 684.547,1293.61 684.556,1293.61 684.566,1293.61 684.575,1293.61 684.584,1293.62 684.593,1293.62 684.602,1293.62 684.612,1293.62 684.621,1293.62 684.63,1293.62 684.639,1293.62 684.648,1293.62 684.658,1293.62 684.667,1293.62 684.676,1293.62 684.685,1293.62 684.694,1293.63 684.703,1293.63 684.713,1293.63 684.722,1293.63 684.731,1293.63 684.74,1293.63 684.749,1293.63 684.759,1293.63 684.768,1293.63 684.777,1293.63 684.786,1293.63 684.795,1293.63 684.805,1293.64 684.814,1293.64 684.823,1293.64 684.832,1293.64 684.841,1293.64 684.85,1293.64 684.86,1293.64 684.869,1293.64 684.878,1293.64 684.887,1293.64 684.896,1293.64 684.906,1293.65 684.915,1293.65 684.924,1293.65 684.933,1293.65 684.942,1293.65 684.952,1293.65 684.961,1293.65 684.97,1293.65 684.979,1293.65 684.988,1293.65 684.998,1293.65 685.007,1293.65 685.016,1293.66 685.025,1293.66 685.034,1293.66 685.043,1293.66 685.053,1293.66 685.062,1293.66 685.071,1293.66 685.08,1293.66 685.089,1293.66 685.099,1293.66 685.108,1293.66 685.117,1293.66 685.126,1293.67 685.135,1293.67 685.145,1293.67 685.154,1293.67 685.163,1293.67 685.172,1293.67 685.181,1293.67 685.19,1293.67 685.2,1293.67 685.209,1293.67 685.218,1293.67 685.227,1293.67 685.236,1293.68 685.246,1293.68 685.255,1293.68 685.264,1293.68 685.273,1293.68 685.282,1293.68 685.292,1293.68 685.301,1293.68 685.31,1293.68 685.319,1293.68 685.328,1293.68 685.338,1293.68 685.347,1293.69 685.356,1293.69 685.365,1293.69 685.374,1293.69 685.383,1293.69 685.393,1293.69 685.402,1293.69 685.411,1293.69 685.42,1293.69 685.429,1293.69 685.439,1293.69 685.448,1293.7 685.457,1293.7 685.466,1293.7 685.475,1293.7 685.485,1293.7 685.494,1293.7 685.503,1293.7 685.512,1293.7 685.521,1293.7 685.53,1293.7 685.54,1293.7 685.549,1293.7 685.558,1293.71 685.567,1293.71 685.576,1293.71 685.586,1293.71 685.595,1293.71 685.604,1293.71 685.613,1293.71 685.622,1293.71 685.632,1293.71 685.641,1293.71 685.65,1293.71 685.659,1293.71 685.668,1293.72 685.678,1293.72 685.687,1293.72 685.696,1293.72 685.705,1293.72 685.714,1293.72 685.723,1293.72 685.733,1293.72 685.742,1293.72 685.751,1293.72 685.76,1293.72 685.769,1293.72 685.779,1293.73 685.788,1293.73 685.797,1293.73 685.806,1293.73 685.815,1293.73 685.825,1293.73 685.834,1293.73 685.843,1293.73 685.852,1293.73 685.861,1293.73 685.87,1293.73 685.88,1293.73 685.889,1293.74 685.898,1293.74 685.907,1293.74 685.916,1293.74 685.926,1293.74 685.935,1293.74 685.944,1293.74 685.953,1293.74 685.962,1293.74 685.972,1293.74 685.981,1293.74 685.99,1293.74 685.999,1293.75 686.008,1293.75 686.018,1293.75 686.027,1293.75 686.036,1293.75 686.045,1293.75 686.054,1293.75 686.063,1293.75 686.073,1293.75 686.082,1293.75 686.091,1293.75 686.1,1293.76 686.109,1293.76 686.119,1293.76 686.128,1293.76 686.137,1293.76 686.146,1293.76 686.155,1293.76 686.165,1293.76 686.174,1293.76 686.183,1293.76 686.192,1293.76 686.201,1293.76 686.21,1293.77 686.22,1293.77 686.229,1293.77 686.238,1293.77 686.247,1293.77 686.256,1293.77 686.266,1293.77 686.275,1293.77 686.284,1293.77 686.293,1293.77 686.302,1293.77 686.312,1293.77 686.321,1293.78 686.33,1293.78 686.339,1293.78 686.348,1293.78 686.358,1293.78 686.367,1293.78 686.376,1293.78 686.385,1293.78 686.394,1293.78 686.403,1293.78 686.413,1293.78 686.422,1293.78 686.431,1293.79 686.44,1293.79 686.449,1293.79 686.459,1293.79 686.468,1293.79 686.477,1293.79 686.486,1293.79 686.495,1293.79 686.505,1293.79 686.514,1293.79 686.523,1293.79 686.532,1293.79 686.541,1293.8 686.551,1293.8 686.56,1293.8 686.569,1293.8 686.578,1293.8 686.587,1293.8 686.596,1293.8 686.606,1293.8 686.615,1293.8 686.624,1293.8 686.633,1293.8 686.642,1293.8 686.652,1293.81 686.661,1293.81 686.67,1293.81 686.679,1293.81 686.688,1293.81 686.698,1293.81 686.707,1293.81 686.716,1293.81 686.725,1293.81 686.734,1293.81 686.743,1293.81 686.753,1293.82 686.762,1293.82 686.771,1293.82 686.78,1293.82 686.789,1293.82 686.799,1293.82 686.808,1293.82 686.817,1293.82 686.826,1293.82 686.835,1293.82 686.845,1293.82 686.854,1293.82 686.863,1293.83 686.872,1293.83 686.881,1293.83 686.891,1293.83 686.9,1293.83 686.909,1293.83 686.918,1293.83 686.927,1293.83 686.936,1293.83 686.946,1293.83 686.955,1293.83 686.964,1293.83 686.973,1293.84 686.982,1293.84 686.992,1293.84 687.001,1293.84 687.01,1293.84 687.019,1293.84 687.028,1293.84 687.038,1293.84 687.047,1293.84 687.056,1293.84 687.065,1293.84 687.074,1293.84 687.083,1293.85 687.093,1293.85 687.102,1293.85 687.111,1293.85 687.12,1293.85 687.129,1293.85 687.139,1293.85 687.148,1293.85 687.157,1293.85 687.166,1293.85 687.175,1293.85 687.185,1293.85 687.194,1293.86 687.203,1293.86 687.212,1293.86 687.221,1293.86 687.231,1293.86 687.24,1293.86 687.249,1293.86 687.258,1293.86 687.267,1293.86 687.276,1293.86 687.286,1293.86 687.295,1293.86 687.304,1293.87 687.313,1293.87 687.322,1293.87 687.332,1293.87 687.341,1293.87 687.35,1293.87 687.359,1293.87 687.368,1293.87 687.378,1293.87 687.387,1293.87 687.396,1293.87 687.405,1293.88 687.414,1293.88 687.423,1293.88 687.433,1293.88 687.442,1293.88 687.451,1293.88 687.46,1293.88 687.469,1293.88 687.479,1293.88 687.488,1293.88 687.497,1293.88 687.506,1293.88 687.515,1293.89 687.525,1293.89 687.534,1293.89 687.543,1293.89 687.552,1293.89 687.561,1293.89 687.571,1293.89 687.58,1293.89 687.589,1293.89 687.598,1293.89 687.607,1293.89 687.616,1293.89 687.626,1293.9 687.635,1293.9 687.644,1293.9 687.653,1293.9 687.662,1293.9 687.672,1293.9 687.681,1293.9 687.69,1293.9 687.699,1293.9 687.708,1293.9 687.718,1293.9 687.727,1293.9 687.736,1293.91 687.745,1293.91 687.754,1293.91 687.763,1293.91 687.773,1293.91 687.782,1293.91 687.791,1293.91 687.8,1293.91 687.809,1293.91 687.819,1293.91 687.828,1293.91 687.837,1293.91 687.846,1293.92 687.855,1293.92 687.865,1293.92 687.874,1293.92 687.883,1293.92 687.892,1293.92 687.901,1293.92 687.911,1293.92 687.92,1293.92 687.929,1293.92 687.938,1293.92 687.947,1293.92 687.956,1293.93 687.966,1293.93 687.975,1293.93 687.984,1293.93 687.993,1293.93 688.002,1293.93 688.012,1293.93 688.021,1293.93 688.03,1293.93 688.039,1293.93 688.048,1293.93 688.058,1293.93 688.067,1293.94 688.076,1293.94 688.085,1293.94 688.094,1293.94 688.103,1293.94 688.113,1293.94 688.122,1293.94 688.131,1293.94 688.14,1293.94 688.149,1293.94 688.159,1293.94 688.168,1293.95 688.177,1293.95 688.186,1293.95 688.195,1293.95 688.205,1293.95 688.214,1293.95 688.223,1293.95 688.232,1293.95 688.241,1293.95 688.251,1293.95 688.26,1293.95 688.269,1293.95 688.278,1293.96 688.287,1293.96 688.296,1293.96 688.306,1293.96 688.315,1293.96 688.324,1293.96 688.333,1293.96 688.342,1293.96 688.352,1293.96 688.361,1293.96 688.37,1293.96 688.379,1293.96 688.388,1293.97 688.398,1293.97 688.407,1293.97 688.416,1293.97 688.425,1293.97 688.434,1293.97 688.443,1293.97 688.453,1293.97 688.462,1293.97 688.471,1293.97 688.48,1293.97 688.489,1293.97 688.499,1293.98 688.508,1293.98 688.517,1293.98 688.526,1293.98 688.535,1293.98 688.545,1293.98 688.554,1293.98 688.563,1293.98 688.572,1293.98 688.581,1293.98 688.591,1293.98 688.6,1293.98 688.609,1293.99 688.618,1293.99 688.627,1293.99 688.636,1293.99 688.646,1293.99 688.655,1293.99 688.664,1293.99 688.673,1293.99 688.682,1293.99 688.692,1293.99 688.701,1293.99 688.71,1293.99 688.719,1294 688.728,1294 688.738,1294 688.747,1294 688.756,1294 688.765,1294 688.774,1294 688.783,1294 688.793,1294 688.802,1294 688.811,1294 688.82,1294.01 688.829,1294.01 688.839,1294.01 688.848,1294.01 688.857,1294.01 688.866,1294.01 688.875,1294.01 688.885,1294.01 688.894,1294.01 688.903,1294.01 688.912,1294.01 688.921,1294.01 688.931,1294.02 688.94,1294.02 688.949,1294.02 688.958,1294.02 688.967,1294.02 688.976,1294.02 688.986,1294.02 688.995,1294.02 689.004,1294.02 689.013,1294.02 689.022,1294.02 689.032,1294.02 689.041,1294.03 689.05,1294.03 689.059,1294.03 689.068,1294.03 689.078,1294.03 689.087,1294.03 689.096,1294.03 689.105,1294.03 689.114,1294.03 689.124,1294.03 689.133,1294.03 689.142,1294.03 689.151,1294.04 689.16,1294.04 689.169,1294.04 689.179,1294.04 689.188,1294.04 689.197,1294.04 689.206,1294.04 689.215,1294.04 689.225,1294.04 689.234,1294.04 689.243,1294.04 689.252,1294.04 689.261,1294.05 689.271,1294.05 689.28,1294.05 689.289,1294.05 689.298,1294.05 689.307,1294.05 689.316,1294.05 689.326,1294.05 689.335,1294.05 689.344,1294.05 689.353,1294.05 689.362,1294.05 689.372,1294.06 689.381,1294.06 689.39,1294.06 689.399,1294.06 689.408,1294.06 689.418,1294.06 689.427,1294.06 689.436,1294.06 689.445,1294.06 689.454,1294.06 689.464,1294.06 689.473,1294.06 689.482,1294.07 689.491,1294.07 689.5,1294.07 689.509,1294.07 689.519,1294.07 689.528,1294.07 689.537,1294.07 689.546,1294.07 689.555,1294.07 689.565,1294.07 689.574,1294.07 689.583,1294.08 689.592,1294.08 689.601,1294.08 689.611,1294.08 689.62,1294.08 689.629,1294.08 689.638,1294.08 689.647,1294.08 689.656,1294.08 689.666,1294.08 689.675,1294.08 689.684,1294.08 689.693,1294.09 689.702,1294.09 689.712,1294.09 689.721,1294.09 689.73,1294.09 689.739,1294.09 689.748,1294.09 689.758,1294.09 689.767,1294.09 689.776,1294.09 689.785,1294.09 689.794,1294.09 689.804,1294.1 689.813,1294.1 689.822,1294.1 689.831,1294.1 689.84,1294.1 689.849,1294.1 689.859,1294.1 689.868,1294.1 689.877,1294.1 689.886,1294.1 689.895,1294.1 689.905,1294.1 689.914,1294.11 689.923,1294.11 689.932,1294.11 689.941,1294.11 689.951,1294.11 689.96,1294.11 689.969,1294.11 689.978,1294.11 689.987,1294.11 689.996,1294.11 690.006,1294.11 690.015,1294.11 690.024,1294.12 690.033,1294.12 690.042,1294.12 690.052,1294.12 690.061,1294.12 690.07,1294.12 690.079,1294.12 690.088,1294.12 690.098,1294.12 690.107,1294.12 690.116,1294.12 690.125,1294.12 690.134,1294.13 690.144,1294.13 690.153,1294.13 690.162,1294.13 690.171,1294.13 690.18,1294.13 690.189,1294.13 690.199,1294.13 690.208,1294.13 690.217,1294.13 690.226,1294.13 690.235,1294.13 690.245,1294.14 690.254,1294.14 690.263,1294.14 690.272,1294.14 690.281,1294.14 690.291,1294.14 690.3,1294.14 690.309,1294.14 690.318,1294.14 690.327,1294.14 690.336,1294.14 690.346,1294.14 690.355,1294.15 690.364,1294.15 690.373,1294.15 690.382,1294.15 690.392,1294.15 690.401,1294.15 690.41,1294.15 690.419,1294.15 690.428,1294.15 690.438,1294.15 690.447,1294.15 690.456,1294.16 690.465,1294.16 690.474,1294.16 690.484,1294.16 690.493,1294.16 690.502,1294.16 690.511,1294.16 690.52,1294.16 690.529,1294.16 690.539,1294.16 690.548,1294.16 690.557,1294.16 690.566,1294.17 690.575,1294.17 690.585,1294.17 690.594,1294.17 690.603,1294.17 690.612,1294.17 690.621,1294.17 690.631,1294.17 690.64,1294.17 690.649,1294.17 690.658,1294.17 690.667,1294.17 690.676,1294.18 690.686,1294.18 690.695,1294.18 690.704,1294.18 690.713,1294.18 690.722,1294.18 690.732,1294.18 690.741,1294.18 690.75,1294.18 690.759,1294.18 690.768,1294.18 690.778,1294.18 690.787,1294.19 690.796,1294.19 690.805,1294.19 690.814,1294.19 690.824,1294.19 690.833,1294.19 690.842,1294.19 690.851,1294.19 690.86,1294.19 690.869,1294.19 690.879,1294.19 690.888,1294.19 690.897,1294.2 690.906,1294.2 690.915,1294.2 690.925,1294.2 690.934,1294.2 690.943,1294.2 690.952,1294.2 690.961,1294.2 690.971,1294.2 690.98,1294.2 690.989,1294.2 690.998,1294.2 691.007,1294.21 691.016,1294.21 691.026,1294.21 691.035,1294.21 691.044,1294.21 691.053,1294.21 691.062,1294.21 691.072,1294.21 691.081,1294.21 691.09,1294.21 691.099,1294.21 691.108,1294.21 691.118,1294.22 691.127,1294.22 691.136,1294.22 691.145,1294.22 691.154,1294.22 691.164,1294.22 691.173,1294.22 691.182,1294.22 691.191,1294.22 691.2,1294.22 691.209,1294.22 691.219,1294.22 691.228,1294.23 691.237,1294.23 691.246,1294.23 691.255,1294.23 691.265,1294.23 691.274,1294.23 691.283,1294.23 691.292,1294.23 691.301,1294.23 691.311,1294.23 691.32,1294.23 691.329,1294.24 691.338,1294.24 691.347,1294.24 691.357,1294.24 691.366,1294.24 691.375,1294.24 691.384,1294.24 691.393,1294.24 691.402,1294.24 691.412,1294.24 691.421,1294.24 691.43,1294.24 691.439,1294.25 691.448,1294.25 691.458,1294.25 691.467,1294.25 691.476,1294.25 691.485,1294.25 691.494,1294.25 691.504,1294.25 691.513,1294.25 691.522,1294.25 691.531,1294.25 691.54,1294.25 691.549,1294.26 691.559,1294.26 691.568,1294.26 691.577,1294.26 691.586,1294.26 691.595,1294.26 691.605,1294.26 691.614,1294.26 691.623,1294.26 691.632,1294.26 691.641,1294.26 691.651,1294.26 691.66,1294.27 691.669,1294.27 691.678,1294.27 691.687,1294.27 691.697,1294.27 691.706,1294.27 691.715,1294.27 691.724,1294.27 691.733,1294.27 691.742,1294.27 691.752,1294.27 691.761,1294.27 691.77,1294.28 691.779,1294.28 691.788,1294.28 691.798,1294.28 691.807,1294.28 691.816,1294.28 691.825,1294.28 691.834,1294.28 691.844,1294.28 691.853,1294.28 691.862,1294.28 691.871,1294.28 691.88,1294.29 691.889,1294.29 691.899,1294.29 691.908,1294.29 691.917,1294.29 691.926,1294.29 691.935,1294.29 691.945,1294.29 691.954,1294.29 691.963,1294.29 691.972,1294.29 691.981,1294.29 691.991,1294.3 692,1294.3 692.009,1294.3 692.018,1294.3 692.027,1294.3 692.037,1294.3 692.046,1294.3 692.055,1294.3 692.064,1294.3 692.073,1294.3 692.082,1294.3 692.092,1294.3 692.101,1294.31 692.11,1294.31 692.119,1294.31 692.128,1294.31 692.138,1294.31 692.147,1294.31 692.156,1294.31 692.165,1294.31 692.174,1294.31 692.184,1294.31 692.193,1294.31 692.202,1294.32 692.211,1294.32 692.22,1294.32 692.229,1294.32 692.239,1294.32 692.248,1294.32 692.257,1294.32 692.266,1294.32 692.275,1294.32 692.285,1294.32 692.294,1294.32 692.303,1294.32 692.312,1294.33 692.321,1294.33 692.331,1294.33 692.34,1294.33 692.349,1294.33 692.358,1294.33 692.367,1294.33 692.377,1294.33 692.386,1294.33 692.395,1294.33 692.404,1294.33 692.413,1294.33 692.422,1294.34 692.432,1294.34 692.441,1294.34 692.45,1294.34 692.459,1294.34 692.468,1294.34 692.478,1294.34 692.487,1294.34 692.496,1294.34 692.505,1294.34 692.514,1294.34 692.524,1294.34 692.533,1294.35 692.542,1294.35 692.551,1294.35 692.56,1294.35 692.569,1294.35 692.579,1294.35 692.588,1294.35 692.597,1294.35 692.606,1294.35 692.615,1294.35 692.625,1294.35 692.634,1294.35 692.643,1294.36 692.652,1294.36 692.661,1294.36 692.671,1294.36 692.68,1294.36 692.689,1294.36 692.698,1294.36 692.707,1294.36 692.717,1294.36 692.726,1294.36 692.735,1294.36 692.744,1294.36 692.753,1294.37 692.762,1294.37 692.772,1294.37 692.781,1294.37 692.79,1294.37 692.799,1294.37 692.808,1294.37 692.818,1294.37 692.827,1294.37 692.836,1294.37 692.845,1294.37 692.854,1294.37 692.864,1294.38 692.873,1294.38 692.882,1294.38 692.891,1294.38 692.9,1294.38 692.909,1294.38 692.919,1294.38 692.928,1294.38 692.937,1294.38 692.946,1294.38 692.955,1294.38 692.965,1294.38 692.974,1294.39 692.983,1294.39 692.992,1294.39 693.001,1294.39 693.011,1294.39 693.02,1294.39 693.029,1294.39 693.038,1294.39 693.047,1294.39 693.057,1294.39 693.066,1294.39 693.075,1294.39 693.084,1294.4 693.093,1294.4 693.102,1294.4 693.112,1294.4 693.121,1294.4 693.13,1294.4 693.139,1294.4 693.148,1294.4 693.158,1294.4 693.167,1294.4 693.176,1294.4 693.185,1294.4 693.194,1294.41 693.204,1294.41 693.213,1294.41 693.222,1294.41 693.231,1294.41 693.24,1294.41 693.249,1294.41 693.259,1294.41 693.268,1294.41 693.277,1294.41 693.286,1294.41 693.295,1294.42 693.305,1294.42 693.314,1294.42 693.323,1294.42 693.332,1294.42 693.341,1294.42 693.351,1294.42 693.36,1294.42 693.369,1294.42 693.378,1294.42 693.387,1294.42 693.397,1294.42 693.406,1294.43 693.415,1294.43 693.424,1294.43 693.433,1294.43 693.442,1294.43 693.452,1294.43 693.461,1294.43 693.47,1294.43 693.479,1294.43 693.488,1294.43 693.498,1294.43 693.507,1294.43 693.516,1294.44 693.525,1294.44 693.534,1294.44 693.544,1294.44 693.553,1294.44 693.562,1294.44 693.571,1294.44 693.58,1294.44 693.589,1294.44 693.599,1294.44 693.608,1294.44 693.617,1294.44 693.626,1294.45 693.635,1294.45 693.645,1294.45 693.654,1294.45 693.663,1294.45 693.672,1294.45 693.681,1294.45 693.691,1294.45 693.7,1294.45 693.709,1294.45 693.718,1294.45 693.727,1294.45 693.737,1294.46 693.746,1294.46 693.755,1294.46 693.764,1294.46 693.773,1294.46 693.782,1294.46 693.792,1294.46 693.801,1294.46 693.81,1294.46 693.819,1294.46 693.828,1294.46 693.838,1294.46 693.847,1294.47 693.856,1294.47 693.865,1294.47 693.874,1294.47 693.884,1294.47 693.893,1294.47 693.902,1294.47 693.911,1294.47 693.92,1294.47 693.93,1294.47 693.939,1294.47 693.948,1294.47 693.957,1294.48 693.966,1294.48 693.975,1294.48 693.985,1294.48 693.994,1294.48 694.003,1294.48 694.012,1294.48 694.021,1294.48 694.031,1294.48 694.04,1294.48 694.049,1294.48 694.058,1294.48 694.067,1294.49 694.077,1294.49 694.086,1294.49 694.095,1294.49 694.104,1294.49 694.113,1294.49 694.122,1294.49 694.132,1294.49 694.141,1294.49 694.15,1294.49 694.159,1294.49 694.168,1294.49 694.178,1294.5 694.187,1294.5 694.196,1294.5 694.205,1294.5 694.214,1294.5 694.224,1294.5 694.233,1294.5 694.242,1294.5 694.251,1294.5 694.26,1294.5 694.27,1294.5 694.279,1294.5 694.288,1294.51 694.297,1294.51 694.306,1294.51 694.315,1294.51 694.325,1294.51 694.334,1294.51 694.343,1294.51 694.352,1294.51 694.361,1294.51 694.371,1294.51 694.38,1294.51 694.389,1294.52 694.398,1294.52 694.407,1294.52 694.417,1294.52 694.426,1294.52 694.435,1294.52 694.444,1294.52 694.453,1294.52 694.462,1294.52 694.472,1294.52 694.481,1294.52 694.49,1294.52 694.499,1294.53 694.508,1294.53 694.518,1294.53 694.527,1294.53 694.536,1294.53 694.545,1294.53 694.554,1294.53 694.564,1294.53 694.573,1294.53 694.582,1294.53 694.591,1294.53 694.6,1294.53 694.61,1294.54 694.619,1294.54 694.628,1294.54 694.637,1294.54 694.646,1294.54 694.655,1294.54 694.665,1294.54 694.674,1294.54 694.683,1294.54 694.692,1294.54 694.701,1294.54 694.711,1294.54 694.72,1294.55 694.729,1294.55 694.738,1294.55 694.747,1294.55 694.757,1294.55 694.766,1294.55 694.775,1294.55 694.784,1294.55 694.793,1294.55 694.802,1294.55 694.812,1294.55 694.821,1294.55 694.83,1294.56 694.839,1294.56 694.848,1294.56 694.858,1294.56 694.867,1294.56 694.876,1294.56 694.885,1294.56 694.894,1294.56 694.904,1294.56 694.913,1294.56 694.922,1294.56 694.931,1294.56 694.94,1294.57 694.95,1294.57 694.959,1294.57 694.968,1294.57 694.977,1294.57 694.986,1294.57 694.995,1294.57 695.005,1294.57 695.014,1294.57 695.023,1294.57 695.032,1294.57 695.041,1294.57 695.051,1294.58 695.06,1294.58 695.069,1294.58 695.078,1294.58 695.087,1294.58 695.097,1294.58 695.106,1294.58 695.115,1294.58 695.124,1294.58 695.133,1294.58 695.142,1294.58 695.152,1294.58 695.161,1294.59 695.17,1294.59 695.179,1294.59 695.188,1294.59 695.198,1294.59 695.207,1294.59 695.216,1294.59 695.225,1294.59 695.234,1294.59 695.244,1294.59 695.253,1294.59 695.262,1294.59 695.271,1294.6 695.28,1294.6 695.29,1294.6 695.299,1294.6 695.308,1294.6 695.317,1294.6 695.326,1294.6 695.335,1294.6 695.345,1294.6 695.354,1294.6 695.363,1294.6 695.372,1294.6 695.381,1294.61 695.391,1294.61 695.4,1294.61 695.409,1294.61 695.418,1294.61 695.427,1294.61 695.437,1294.61 695.446,1294.61 695.455,1294.61 695.464,1294.61 695.473,1294.61 695.482,1294.61 695.492,1294.62 695.501,1294.62 695.51,1294.62 695.519,1294.62 695.528,1294.62 695.538,1294.62 695.547,1294.62 695.556,1294.62 695.565,1294.62 695.574,1294.62 695.584,1294.62 695.593,1294.62 695.602,1294.63 695.611,1294.63 695.62,1294.63 695.63,1294.63 695.639,1294.63 695.648,1294.63 695.657,1294.63 695.666,1294.63 695.675,1294.63 695.685,1294.63 695.694,1294.63 695.703,1294.64 695.712,1294.64 695.721,1294.64 695.731,1294.64 695.74,1294.64 695.749,1294.64 695.758,1294.64 695.767,1294.64 695.777,1294.64 695.786,1294.64 695.795,1294.64 695.804,1294.64 695.813,1294.65 695.822,1294.65 695.832,1294.65 695.841,1294.65 695.85,1294.65 695.859,1294.65 695.868,1294.65 695.878,1294.65 695.887,1294.65 695.896,1294.65 695.905,1294.65 695.914,1294.65 695.924,1294.66 695.933,1294.66 695.942,1294.66 695.951,1294.66 695.96,1294.66 695.97,1294.66 695.979,1294.66 695.988,1294.66 695.997,1294.66 696.006,1294.66 696.015,1294.66 696.025,1294.66 696.034,1294.67 696.043,1294.67 696.052,1294.67 696.061,1294.67 696.071,1294.67 696.08,1294.67 696.089,1294.67 696.098,1294.67 696.107,1294.67 696.117,1294.67 696.126,1294.67 696.135,1294.67 696.144,1294.68 696.153,1294.68 696.162,1294.68 696.172,1294.68 696.181,1294.68 696.19,1294.68 696.199,1294.68 696.208,1294.68 696.218,1294.68 696.227,1294.68 696.236,1294.68 696.245,1294.68 696.254,1294.69 696.264,1294.69 696.273,1294.69 696.282,1294.69 696.291,1294.69 696.3,1294.69 696.31,1294.69 696.319,1294.69 696.328,1294.69 696.337,1294.69 696.346,1294.69 696.355,1294.69 696.365,1294.7 696.374,1294.7 696.383,1294.7 696.392,1294.7 696.401,1294.7 696.411,1294.7 696.42,1294.7 696.429,1294.7 696.438,1294.7 696.447,1294.7 696.457,1294.7 696.466,1294.7 696.475,1294.71 696.484,1294.71 696.493,1294.71 696.503,1294.71 696.512,1294.71 696.521,1294.71 696.53,1294.71 696.539,1294.71 696.548,1294.71 696.558,1294.71 696.567,1294.71 696.576,1294.71 696.585,1294.72 696.594,1294.72 696.604,1294.72 696.613,1294.72 696.622,1294.72 696.631,1294.72 696.64,1294.72 696.65,1294.72 696.659,1294.72 696.668,1294.72 696.677,1294.72 696.686,1294.72 696.695,1294.73 696.705,1294.73 696.714,1294.73 696.723,1294.73 696.732,1294.73 696.741,1294.73 696.751,1294.73 696.76,1294.73 696.769,1294.73 696.778,1294.73 696.787,1294.73 696.797,1294.73 696.806,1294.74 696.815,1294.74 696.824,1294.74 696.833,1294.74 696.843,1294.74 696.852,1294.74 696.861,1294.74 696.87,1294.74 696.879,1294.74 696.888,1294.74 696.898,1294.74 696.907,1294.74 696.916,1294.75 696.925,1294.75 696.934,1294.75 696.944,1294.75 696.953,1294.75 696.962,1294.75 696.971,1294.75 696.98,1294.75 696.99,1294.75 696.999,1294.75 697.008,1294.75 697.017,1294.75 697.026,1294.76 697.035,1294.76 697.045,1294.76 697.054,1294.76 697.063,1294.76 697.072,1294.76 697.081,1294.76 697.091,1294.76 697.1,1294.76 697.109,1294.76 697.118,1294.76 697.127,1294.76 697.137,1294.77 697.146,1294.77 697.155,1294.77 697.164,1294.77 697.173,1294.77 697.183,1294.77 697.192,1294.77 697.201,1294.77 697.21,1294.77 697.219,1294.77 697.228,1294.77 697.238,1294.78 697.247,1294.78 697.256,1294.78 697.265,1294.78 697.274,1294.78 697.284,1294.78 697.293,1294.78 697.302,1294.78 697.311,1294.78 697.32,1294.78 697.33,1294.78 697.339,1294.78 697.348,1294.79 697.357,1294.79 697.366,1294.79 697.375,1294.79 697.385,1294.79 697.394,1294.79 697.403,1294.79 697.412,1294.79 697.421,1294.79 697.431,1294.79 697.44,1294.79 697.449,1294.79 697.458,1294.8 697.467,1294.8 697.477,1294.8 697.486,1294.8 697.495,1294.8 697.504,1294.8 697.513,1294.8 697.523,1294.8 697.532,1294.8 697.541,1294.8 697.55,1294.8 697.559,1294.8 697.568,1294.81 697.578,1294.81 697.587,1294.81 697.596,1294.81 697.605,1294.81 697.614,1294.81 697.624,1294.81 697.633,1294.81 697.642,1294.81 697.651,1294.81 697.66,1294.81 697.67,1294.81 697.679,1294.82 697.688,1294.82 697.697,1294.82 697.706,1294.82 697.715,1294.82 697.725,1294.82 697.734,1294.82 697.743,1294.82 697.752,1294.82 697.761,1294.82 697.771,1294.82 697.78,1294.82 697.789,1294.83 697.798,1294.83 697.807,1294.83 697.817,1294.83 697.826,1294.83 697.835,1294.83 697.844,1294.83 697.853,1294.83 697.863,1294.83 697.872,1294.83 697.881,1294.83 697.89,1294.83 697.899,1294.84 697.908,1294.84 697.918,1294.84 697.927,1294.84 697.936,1294.84 697.945,1294.84 697.954,1294.84 697.964,1294.84 697.973,1294.84 697.982,1294.84 697.991,1294.84 698,1294.84 698.01,1294.85 698.019,1294.85 698.028,1294.85 698.037,1294.85 698.046,1294.85 698.055,1294.85 698.065,1294.85 698.074,1294.85 698.083,1294.85 698.092,1294.85 698.101,1294.85 698.111,1294.85 698.12,1294.86 698.129,1294.86 698.138,1294.86 698.147,1294.86 698.157,1294.86 698.166,1294.86 698.175,1294.86 698.184,1294.86 698.193,1294.86 698.203,1294.86 698.212,1294.86 698.221,1294.86 698.23,1294.87 698.239,1294.87 698.248,1294.87 698.258,1294.87 698.267,1294.87 698.276,1294.87 698.285,1294.87 698.294,1294.87 698.304,1294.87 698.313,1294.87 698.322,1294.87 698.331,1294.87 698.34,1294.88 698.35,1294.88 698.359,1294.88 698.368,1294.88 698.377,1294.88 698.386,1294.88 698.395,1294.88 698.405,1294.88 698.414,1294.88 698.423,1294.88 698.432,1294.88 698.441,1294.88 698.451,1294.89 698.46,1294.89 698.469,1294.89 698.478,1294.89 698.487,1294.89 698.497,1294.89 698.506,1294.89 698.515,1294.89 698.524,1294.89 698.533,1294.89 698.543,1294.89 698.552,1294.89 698.561,1294.9 698.57,1294.9 698.579,1294.9 698.588,1294.9 698.598,1294.9 698.607,1294.9 698.616,1294.9 698.625,1294.9 698.634,1294.9 698.644,1294.9 698.653,1294.9 698.662,1294.9 698.671,1294.91 698.68,1294.91 698.69,1294.91 698.699,1294.91 698.708,1294.91 698.717,1294.91 698.726,1294.91 698.736,1294.91 698.745,1294.91 698.754,1294.91 698.763,1294.91 698.772,1294.91 698.781,1294.92 698.791,1294.92 698.8,1294.92 698.809,1294.92 698.818,1294.92 698.827,1294.92 698.837,1294.92 698.846,1294.92 698.855,1294.92 698.864,1294.92 698.873,1294.92 698.883,1294.92 698.892,1294.93 698.901,1294.93 698.91,1294.93 698.919,1294.93 698.928,1294.93 698.938,1294.93 698.947,1294.93 698.956,1294.93 698.965,1294.93 698.974,1294.93 698.984,1294.93 698.993,1294.93 699.002,1294.94 699.011,1294.94 699.02,1294.94 699.03,1294.94 699.039,1294.94 699.048,1294.94 699.057,1294.94 699.066,1294.94 699.076,1294.94 699.085,1294.94 699.094,1294.94 699.103,1294.94 699.112,1294.95 699.121,1294.95 699.131,1294.95 699.14,1294.95 699.149,1294.95 699.158,1294.95 699.167,1294.95 699.177,1294.95 699.186,1294.95 699.195,1294.95 699.204,1294.95 699.213,1294.96 699.223,1294.96 699.232,1294.96 699.241,1294.96 699.25,1294.96 699.259,1294.96 699.268,1294.96 699.278,1294.96 699.287,1294.96 699.296,1294.96 699.305,1294.96 699.314,1294.96 699.324,1294.97 699.333,1294.97 699.342,1294.97 699.351,1294.97 699.36,1294.97 699.37,1294.97 699.379,1294.97 699.388,1294.97 699.397,1294.97 699.406,1294.97 699.416,1294.97 699.425,1294.97 699.434,1294.98 699.443,1294.98 699.452,1294.98 699.461,1294.98 699.471,1294.98 699.48,1294.98 699.489,1294.98 699.498,1294.98 699.507,1294.98 699.517,1294.98 699.526,1294.98 699.535,1294.98 699.544,1294.99 699.553,1294.99 699.563,1294.99 699.572,1294.99 699.581,1294.99 699.59,1294.99 699.599,1294.99 699.608,1294.99 699.618,1294.99 699.627,1294.99 699.636,1294.99 699.645,1294.99 699.654,1295 699.664,1295 699.673,1295 699.682,1295 699.691,1295 699.7,1295 699.71,1295 699.719,1295 699.728,1295 699.737,1295 699.746,1295 699.756,1295 699.765,1295.01 699.774,1295.01 699.783,1295.01 699.792,1295.01 699.801,1295.01 699.811,1295.01 699.82,1295.01 699.829,1295.01 699.838,1295.01 699.847,1295.01 699.857,1295.01 699.866,1295.01 699.875,1295.02 699.884,1295.02 699.893,1295.02 699.903,1295.02 699.912,1295.02 699.921,1295.02 699.93,1295.02 699.939,1295.02 699.948,1295.02 699.958,1295.02 699.967,1295.02 699.976,1295.02 699.985,1295.03 699.994,1295.03 700.004,1295.03 700.013,1295.03 700.022,1295.03 700.031,1295.03 700.04,1295.03 700.05,1295.03 700.059,1295.03 700.068,1295.03 700.077,1295.03 700.086,1295.03 700.096,1295.04 700.105,1295.04 700.114,1295.04 700.123,1295.04 700.132,1295.04 700.141,1295.04 700.151,1295.04 700.16,1295.04 700.169,1295.04 700.178,1295.04 700.187,1295.04 700.197,1295.04 700.206,1295.05 700.215,1295.05 700.224,1295.05 700.233,1295.05 700.243,1295.05 700.252,1295.05 700.261,1295.05 700.27,1295.05 700.279,1295.05 700.288,1295.05 700.298,1295.05 700.307,1295.05 700.316,1295.06 700.325,1295.06 700.334,1295.06 700.344,1295.06 700.353,1295.06 700.362,1295.06 700.371,1295.06 700.38,1295.06 700.39,1295.06 700.399,1295.06 700.408,1295.06 700.417,1295.06 700.426,1295.07 700.436,1295.07 700.445,1295.07 700.454,1295.07 700.463,1295.07 700.472,1295.07 700.481,1295.07 700.491,1295.07 700.5,1295.07 700.509,1295.07 700.518,1295.07 700.527,1295.07 700.537,1295.08 700.546,1295.08 700.555,1295.08 700.564,1295.08 700.573,1295.08 700.583,1295.08 700.592,1295.08 700.601,1295.08 700.61,1295.08 700.619,1295.08 700.628,1295.08 700.638,1295.08 700.647,1295.09 700.656,1295.09 700.665,1295.09 700.674,1295.09 700.684,1295.09 700.693,1295.09 700.702,1295.09 700.711,1295.09 700.72,1295.09 700.73,1295.09 700.739,1295.09 700.748,1295.09 700.757,1295.1 700.766,1295.1 700.776,1295.1 700.785,1295.1 700.794,1295.1 700.803,1295.1 700.812,1295.1 700.821,1295.1 700.831,1295.1 700.84,1295.1 700.849,1295.1 700.858,1295.1 700.867,1295.11 700.877,1295.11 700.886,1295.11 700.895,1295.11 700.904,1295.11 700.913,1295.11 700.923,1295.11 700.932,1295.11 700.941,1295.11 700.95,1295.11 700.959,1295.11 700.968,1295.11 700.978,1295.12 700.987,1295.12 700.996,1295.12 701.005,1295.12 701.014,1295.12 701.024,1295.12 701.033,1295.12 701.042,1295.12 701.051,1295.12 701.06,1295.12 701.07,1295.12 701.079,1295.12 701.088,1295.13 701.097,1295.13 701.106,1295.13 701.116,1295.13 701.125,1295.13 701.134,1295.13 701.143,1295.13 701.152,1295.13 701.161,1295.13 701.171,1295.13 701.18,1295.13 701.189,1295.13 701.198,1295.14 701.207,1295.14 701.217,1295.14 701.226,1295.14 701.235,1295.14 701.244,1295.14 701.253,1295.14 701.263,1295.14 701.272,1295.14 701.281,1295.14 701.29,1295.14 701.299,1295.14 701.309,1295.15 701.318,1295.15 701.327,1295.15 701.336,1295.15 701.345,1295.15 701.354,1295.15 701.364,1295.15 701.373,1295.15 701.382,1295.15 701.391,1295.15 701.4,1295.15 701.41,1295.15 701.419,1295.16 701.428,1295.16 701.437,1295.16 701.446,1295.16 701.456,1295.16 701.465,1295.16 701.474,1295.16 701.483,1295.16 701.492,1295.16 701.501,1295.16 701.511,1295.16 701.52,1295.16 701.529,1295.17 701.538,1295.17 701.547,1295.17 701.557,1295.17 701.566,1295.17 701.575,1295.17 701.584,1295.17 701.593,1295.17 701.603,1295.17 701.612,1295.17 701.621,1295.17 701.63,1295.17 701.639,1295.18 701.649,1295.18 701.658,1295.18 701.667,1295.18 701.676,1295.18 701.685,1295.18 701.694,1295.18 701.704,1295.18 701.713,1295.18 701.722,1295.18 701.731,1295.18 701.74,1295.18 701.75,1295.19 701.759,1295.19 701.768,1295.19 701.777,1295.19 701.786,1295.19 701.796,1295.19 701.805,1295.19 701.814,1295.19 701.823,1295.19 701.832,1295.19 701.841,1295.19 701.851,1295.19 701.86,1295.2 701.869,1295.2 701.878,1295.2 701.887,1295.2 701.897,1295.2 701.906,1295.2 701.915,1295.2 701.924,1295.2 701.933,1295.2 701.943,1295.2 701.952,1295.2 701.961,1295.2 701.97,1295.21 701.979,1295.21 701.989,1295.21 701.998,1295.21 702.007,1295.21 702.016,1295.21 702.025,1295.21 702.034,1295.21 702.044,1295.21 702.053,1295.21 702.062,1295.21 702.071,1295.21 702.08,1295.22 702.09,1295.22 702.099,1295.22 702.108,1295.22 702.117,1295.22 702.126,1295.22 702.136,1295.22 702.145,1295.22 702.154,1295.22 702.163,1295.22 702.172,1295.22 702.181,1295.22 702.191,1295.23 702.2,1295.23 702.209,1295.23 702.218,1295.23 702.227,1295.23 702.237,1295.23 702.246,1295.23 702.255,1295.23 702.264,1295.23 702.273,1295.23 702.283,1295.23 702.292,1295.23 702.301,1295.24 702.31,1295.24 702.319,1295.24 702.329,1295.24 702.338,1295.24 702.347,1295.24 702.356,1295.24 702.365,1295.24 702.374,1295.24 702.384,1295.24 702.393,1295.24 702.402,1295.24 702.411,1295.25 702.42,1295.25 702.43,1295.25 702.439,1295.25 702.448,1295.25 702.457,1295.25 702.466,1295.25 702.476,1295.25 702.485,1295.25 702.494,1295.25 702.503,1295.25 702.512,1295.25 702.521,1295.26 702.531,1295.26 702.54,1295.26 702.549,1295.26 702.558,1295.26 702.567,1295.26 702.577,1295.26 702.586,1295.26 702.595,1295.26 702.604,1295.26 702.613,1295.26 702.623,1295.26 702.632,1295.27 702.641,1295.27 702.65,1295.27 702.659,1295.27 702.669,1295.27 702.678,1295.27 702.687,1295.27 702.696,1295.27 702.705,1295.27 702.714,1295.27 702.724,1295.27 702.733,1295.27 702.742,1295.28 702.751,1295.28 702.76,1295.28 702.77,1295.28 702.779,1295.28 702.788,1295.28 702.797,1295.28 702.806,1295.28 702.816,1295.28 702.825,1295.28 702.834,1295.28 702.843,1295.28 702.852,1295.29 702.861,1295.29 702.871,1295.29 702.88,1295.29 702.889,1295.29 702.898,1295.29 702.907,1295.29 702.917,1295.29 702.926,1295.29 702.935,1295.29 702.944,1295.29 702.953,1295.29 702.963,1295.3 702.972,1295.3 702.981,1295.3 702.99,1295.3 702.999,1295.3 703.009,1295.3 703.018,1295.3 703.027,1295.3 703.036,1295.3 703.045,1295.3 703.054,1295.3 703.064,1295.3 703.073,1295.31 703.082,1295.31 703.091,1295.31 703.1,1295.31 703.11,1295.31 703.119,1295.31 703.128,1295.31 703.137,1295.31 703.146,1295.31 703.156,1295.31 703.165,1295.31 703.174,1295.31 703.183,1295.32 703.192,1295.32 703.201,1295.32 703.211,1295.32 703.22,1295.32 703.229,1295.32 703.238,1295.32 703.247,1295.32 703.257,1295.32 703.266,1295.32 703.275,1295.32 703.284,1295.32 703.293,1295.33 703.303,1295.33 703.312,1295.33 703.321,1295.33 703.33,1295.33 703.339,1295.33 703.349,1295.33 703.358,1295.33 703.367,1295.33 703.376,1295.33 703.385,1295.33 703.394,1295.33 703.404,1295.34 703.413,1295.34 703.422,1295.34 703.431,1295.34 703.44,1295.34 703.45,1295.34 703.459,1295.34 703.468,1295.34 703.477,1295.34 703.486,1295.34 703.496,1295.34 703.505,1295.34 703.514,1295.35 703.523,1295.35 703.532,1295.35 703.541,1295.35 703.551,1295.35 703.56,1295.35 703.569,1295.35 703.578,1295.35 703.587,1295.35 703.597,1295.35 703.606,1295.35 703.615,1295.35 703.624,1295.36 703.633,1295.36 703.643,1295.36 703.652,1295.36 703.661,1295.36 703.67,1295.36 703.679,1295.36 703.689,1295.36 703.698,1295.36 703.707,1295.36 703.716,1295.36 703.725,1295.36 703.734,1295.37 703.744,1295.37 703.753,1295.37 703.762,1295.37 703.771,1295.37 703.78,1295.37 703.79,1295.37 703.799,1295.37 703.808,1295.37 703.817,1295.37 703.826,1295.37 703.836,1295.37 703.845,1295.38 703.854,1295.38 703.863,1295.38 703.872,1295.38 703.882,1295.38 703.891,1295.38 703.9,1295.38 703.909,1295.38 703.918,1295.38 703.927,1295.38 703.937,1295.38 703.946,1295.38 703.955,1295.39 703.964,1295.39 703.973,1295.39 703.983,1295.39 703.992,1295.39 704.001,1295.39 704.01,1295.39 704.019,1295.39 704.029,1295.39 704.038,1295.39 704.047,1295.39 704.056,1295.39 704.065,1295.4 704.074,1295.4 704.084,1295.4 704.093,1295.4 704.102,1295.4 704.111,1295.4 704.12,1295.4 704.13,1295.4 704.139,1295.4 704.148,1295.4 704.157,1295.4 704.166,1295.4 704.176,1295.41 704.185,1295.41 704.194,1295.41 704.203,1295.41 704.212,1295.41 704.222,1295.41 704.231,1295.41 704.24,1295.41 704.249,1295.41 704.258,1295.41 704.267,1295.41 704.277,1295.41 704.286,1295.42 704.295,1295.42 704.304,1295.42 704.313,1295.42 704.323,1295.42 704.332,1295.42 704.341,1295.42 704.35,1295.42 704.359,1295.42 704.369,1295.42 704.378,1295.42 704.387,1295.42 704.396,1295.43 704.405,1295.43 704.414,1295.43 704.424,1295.43 704.433,1295.43 704.442,1295.43 704.451,1295.43 704.46,1295.43 704.47,1295.43 704.479,1295.43 704.488,1295.43 704.497,1295.43 704.506,1295.44 704.516,1295.44 704.525,1295.44 704.534,1295.44 704.543,1295.44 704.552,1295.44 704.562,1295.44 704.571,1295.44 704.58,1295.44 704.589,1295.44 704.598,1295.44 704.607,1295.44 704.617,1295.45 704.626,1295.45 704.635,1295.45 704.644,1295.45 704.653,1295.45 704.663,1295.45 704.672,1295.45 704.681,1295.45 704.69,1295.45 704.699,1295.45 704.709,1295.45 704.718,1295.45 704.727,1295.46 704.736,1295.46 704.745,1295.46 704.754,1295.46 704.764,1295.46 704.773,1295.46 704.782,1295.46 704.791,1295.46 704.8,1295.46 704.81,1295.46 704.819,1295.46 704.828,1295.46 704.837,1295.47 704.846,1295.47 704.856,1295.47 704.865,1295.47 704.874,1295.47 704.883,1295.47 704.892,1295.47 704.902,1295.47 704.911,1295.47 704.92,1295.47 704.929,1295.47 704.938,1295.47 704.947,1295.48 704.957,1295.48 704.966,1295.48 704.975,1295.48 704.984,1295.48 704.993,1295.48 705.003,1295.48 705.012,1295.48 705.021,1295.48 705.03,1295.48 705.039,1295.48 705.049,1295.48 705.058,1295.49 705.067,1295.49 705.076,1295.49 705.085,1295.49 705.094,1295.49 705.104,1295.49 705.113,1295.49 705.122,1295.49 705.131,1295.49 705.14,1295.49 705.15,1295.49 705.159,1295.49 705.168,1295.5 705.177,1295.5 705.186,1295.5 705.196,1295.5 705.205,1295.5 705.214,1295.5 705.223,1295.5 705.232,1295.5 705.242,1295.5 705.251,1295.5 705.26,1295.5 705.269,1295.5 705.278,1295.51 705.287,1295.51 705.297,1295.51 705.306,1295.51 705.315,1295.51 705.324,1295.51 705.333,1295.51 705.343,1295.51 705.352,1295.51 705.361,1295.51 705.37,1295.51 705.379,1295.51 705.389,1295.52 705.398,1295.52 705.407,1295.52 705.416,1295.52 705.425,1295.52 705.434,1295.52 705.444,1295.52 705.453,1295.52 705.462,1295.52 705.471,1295.52 705.48,1295.52 705.49,1295.52 705.499,1295.53 705.508,1295.53 705.517,1295.53 705.526,1295.53 705.536,1295.53 705.545,1295.53 705.554,1295.53 705.563,1295.53 705.572,1295.53 705.582,1295.53 705.591,1295.53 705.6,1295.53 705.609,1295.54 705.618,1295.54 705.627,1295.54 705.637,1295.54 705.646,1295.54 705.655,1295.54 705.664,1295.54 705.673,1295.54 705.683,1295.54 705.692,1295.54 705.701,1295.54 705.71,1295.54 705.719,1295.55 705.729,1295.55 705.738,1295.55 705.747,1295.55 705.756,1295.55 705.765,1295.55 705.774,1295.55 705.784,1295.55 705.793,1295.55 705.802,1295.55 705.811,1295.55 705.82,1295.55 705.83,1295.56 705.839,1295.56 705.848,1295.56 705.857,1295.56 705.866,1295.56 705.876,1295.56 705.885,1295.56 705.894,1295.56 705.903,1295.56 705.912,1295.56 705.922,1295.56 705.931,1295.56 705.94,1295.57 705.949,1295.57 705.958,1295.57 705.967,1295.57 705.977,1295.57 705.986,1295.57 705.995,1295.57 706.004,1295.57 706.013,1295.57 706.023,1295.57 706.032,1295.57 706.041,1295.57 706.05,1295.58 706.059,1295.58 706.069,1295.58 706.078,1295.58 706.087,1295.58 706.096,1295.58 706.105,1295.58 706.114,1295.58 706.124,1295.58 706.133,1295.58 706.142,1295.58 706.151,1295.58 706.16,1295.59 706.17,1295.59 706.179,1295.59 706.188,1295.59 706.197,1295.59 706.206,1295.59 706.216,1295.59 706.225,1295.59 706.234,1295.59 706.243,1295.59 706.252,1295.59 706.262,1295.59 706.271,1295.6 706.28,1295.6 706.289,1295.6 706.298,1295.6 706.307,1295.6 706.317,1295.6 706.326,1295.6 706.335,1295.6 706.344,1295.6 706.353,1295.6 706.363,1295.6 706.372,1295.6 706.381,1295.61 706.39,1295.61 706.399,1295.61 706.409,1295.61 706.418,1295.61 706.427,1295.61 706.436,1295.61 706.445,1295.61 706.455,1295.61 706.464,1295.61 706.473,1295.61 706.482,1295.61 706.491,1295.62 706.5,1295.62 706.51,1295.62 706.519,1295.62 706.528,1295.62 706.537,1295.62 706.546,1295.62 706.556,1295.62 706.565,1295.62 706.574,1295.62 706.583,1295.62 706.592,1295.62 706.602,1295.63 706.611,1295.63 706.62,1295.63 706.629,1295.63 706.638,1295.63 706.647,1295.63 706.657,1295.63 706.666,1295.63 706.675,1295.63 706.684,1295.63 706.693,1295.63 706.703,1295.63 706.712,1295.64 706.721,1295.64 706.73,1295.64 706.739,1295.64 706.749,1295.64 706.758,1295.64 706.767,1295.64 706.776,1295.64 706.785,1295.64 706.795,1295.64 706.804,1295.64 706.813,1295.64 706.822,1295.65 706.831,1295.65 706.84,1295.65 706.85,1295.65 706.859,1295.65 706.868,1295.65 706.877,1295.65 706.886,1295.65 706.896,1295.65 706.905,1295.65 706.914,1295.65 706.923,1295.65 706.932,1295.66 706.942,1295.66 706.951,1295.66 706.96,1295.66 706.969,1295.66 706.978,1295.66 706.987,1295.66 706.997,1295.66 707.006,1295.66 707.015,1295.66 707.024,1295.66 707.033,1295.66 707.043,1295.67 707.052,1295.67 707.061,1295.67 707.07,1295.67 707.079,1295.67 707.089,1295.67 707.098,1295.67 707.107,1295.67 707.116,1295.67 707.125,1295.67 707.135,1295.67 707.144,1295.67 707.153,1295.68 707.162,1295.68 707.171,1295.68 707.18,1295.68 707.19,1295.68 707.199,1295.68 707.208,1295.68 707.217,1295.68 707.226,1295.68 707.236,1295.68 707.245,1295.68 707.254,1295.68 707.263,1295.69 707.272,1295.69 707.282,1295.69 707.291,1295.69 707.3,1295.69 707.309,1295.69 707.318,1295.69 707.327,1295.69 707.337,1295.69 707.346,1295.69 707.355,1295.69 707.364,1295.69 707.373,1295.7 707.383,1295.7 707.392,1295.7 707.401,1295.7 707.41,1295.7 707.419,1295.7 707.429,1295.7 707.438,1295.7 707.447,1295.7 707.456,1295.7 707.465,1295.7 707.475,1295.7 707.484,1295.71 707.493,1295.71 707.502,1295.71 707.511,1295.71 707.52,1295.71 707.53,1295.71 707.539,1295.71 707.548,1295.71 707.557,1295.71 707.566,1295.71 707.576,1295.71 707.585,1295.71 707.594,1295.72 707.603,1295.72 707.612,1295.72 707.622,1295.72 707.631,1295.72 707.64,1295.72 707.649,1295.72 707.658,1295.72 707.667,1295.72 707.677,1295.72 707.686,1295.72 707.695,1295.72 707.704,1295.73 707.713,1295.73 707.723,1295.73 707.732,1295.73 707.741,1295.73 707.75,1295.73 707.759,1295.73 707.769,1295.73 707.778,1295.73 707.787,1295.73 707.796,1295.73 707.805,1295.73 707.815,1295.74 707.824,1295.74 707.833,1295.74 707.842,1295.74 707.851,1295.74 707.86,1295.74 707.87,1295.74 707.879,1295.74 707.888,1295.74 707.897,1295.74 707.906,1295.74 707.916,1295.74 707.925,1295.75 707.934,1295.75 707.943,1295.75 707.952,1295.75 707.962,1295.75 707.971,1295.75 707.98,1295.75 707.989,1295.75 707.998,1295.75 708.007,1295.75 708.017,1295.75 708.026,1295.75 708.035,1295.76 708.044,1295.76 708.053,1295.76 708.063,1295.76 708.072,1295.76 708.081,1295.76 708.09,1295.76 708.099,1295.76 708.109,1295.76 708.118,1295.76 708.127,1295.76 708.136,1295.76 708.145,1295.77 708.155,1295.77 708.164,1295.77 708.173,1295.77 708.182,1295.77 708.191,1295.77 708.2,1295.77 708.21,1295.77 708.219,1295.77 708.228,1295.77 708.237,1295.77 708.246,1295.77 708.256,1295.78 708.265,1295.78 708.274,1295.78 708.283,1295.78 708.292,1295.78 708.302,1295.78 708.311,1295.78 708.32,1295.78 708.329,1295.78 708.338,1295.78 708.347,1295.78 708.357,1295.78 708.366,1295.78 708.375,1295.79 708.384,1295.79 708.393,1295.79 708.403,1295.79 708.412,1295.79 708.421,1295.79 708.43,1295.79 708.439,1295.79 708.449,1295.79 708.458,1295.79 708.467,1295.79 708.476,1295.79 708.485,1295.8 708.495,1295.8 708.504,1295.8 708.513,1295.8 708.522,1295.8 708.531,1295.8 708.54,1295.8 708.55,1295.8 708.559,1295.8 708.568,1295.8 708.577,1295.8 708.586,1295.8 708.596,1295.81 708.605,1295.81 708.614,1295.81 708.623,1295.81 708.632,1295.81 708.642,1295.81 708.651,1295.81 708.66,1295.81 708.669,1295.81 708.678,1295.81 708.688,1295.81 708.697,1295.81 708.706,1295.82 708.715,1295.82 708.724,1295.82 708.733,1295.82 708.743,1295.82 708.752,1295.82 708.761,1295.82 708.77,1295.82 708.779,1295.82 708.789,1295.82 708.798,1295.82 708.807,1295.82 708.816,1295.83 708.825,1295.83 708.835,1295.83 708.844,1295.83 708.853,1295.83 708.862,1295.83 708.871,1295.83 708.88,1295.83 708.89,1295.83 708.899,1295.83 708.908,1295.83 708.917,1295.83 708.926,1295.84 708.936,1295.84 708.945,1295.84 708.954,1295.84 708.963,1295.84 708.972,1295.84 708.982,1295.84 708.991,1295.84 709,1295.84 709.009,1295.84 709.018,1295.84 709.028,1295.84 709.037,1295.85 709.046,1295.85 709.055,1295.85 709.064,1295.85 709.073,1295.85 709.083,1295.85 709.092,1295.85 709.101,1295.85 709.11,1295.85 709.119,1295.85 709.129,1295.85 709.138,1295.85 709.147,1295.86 709.156,1295.86 709.165,1295.86 709.175,1295.86 709.184,1295.86 709.193,1295.86 709.202,1295.86 709.211,1295.86 709.22,1295.86 709.23,1295.86 709.239,1295.86 709.248,1295.86 709.257,1295.87 709.266,1295.87 709.276,1295.87 709.285,1295.87 709.294,1295.87 709.303,1295.87 709.312,1295.87 709.322,1295.87 709.331,1295.87 709.34,1295.87 709.349,1295.87 709.358,1295.87 709.368,1295.88 709.377,1295.88 709.386,1295.88 709.395,1295.88 709.404,1295.88 709.413,1295.88 709.423,1295.88 709.432,1295.88 709.441,1295.88 709.45,1295.88 709.459,1295.88 709.469,1295.88 709.478,1295.89 709.487,1295.89 709.496,1295.89 709.505,1295.89 709.515,1295.89 709.524,1295.89 709.533,1295.89 709.542,1295.89 709.551,1295.89 709.56,1295.89 709.57,1295.89 709.579,1295.89 709.588,1295.9 709.597,1295.9 709.606,1295.9 709.616,1295.9 709.625,1295.9 709.634,1295.9 709.643,1295.9 709.652,1295.9 709.662,1295.9 709.671,1295.9 709.68,1295.9 709.689,1295.9 709.698,1295.91 709.708,1295.91 709.717,1295.91 709.726,1295.91 709.735,1295.91 709.744,1295.91 709.753,1295.91 709.763,1295.91 709.772,1295.91 709.781,1295.91 709.79,1295.91 709.799,1295.91 709.809,1295.92 709.818,1295.92 709.827,1295.92 709.836,1295.92 709.845,1295.92 709.855,1295.92 709.864,1295.92 709.873,1295.92 709.882,1295.92 709.891,1295.92 709.9,1295.92 709.91,1295.92 709.919,1295.93 709.928,1295.93 709.937,1295.93 709.946,1295.93 709.956,1295.93 709.965,1295.93 709.974,1295.93 709.983,1295.93 709.992,1295.93 710.002,1295.93 710.011,1295.93 710.02,1295.93 710.029,1295.94 710.038,1295.94 710.048,1295.94 710.057,1295.94 710.066,1295.94 710.075,1295.94 710.084,1295.94 710.093,1295.94 710.103,1295.94 710.112,1295.94 710.121,1295.94 710.13,1295.94 710.139,1295.95 710.149,1295.95 710.158,1295.95 710.167,1295.95 710.176,1295.95 710.185,1295.95 710.195,1295.95 710.204,1295.95 710.213,1295.95 710.222,1295.95 710.231,1295.95 710.24,1295.95 710.25,1295.96 710.259,1295.96 710.268,1295.96 710.277,1295.96 710.286,1295.96 710.296,1295.96 710.305,1295.96 710.314,1295.96 710.323,1295.96 710.332,1295.96 710.342,1295.96 710.351,1295.96 710.36,1295.96 710.369,1295.97 710.378,1295.97 710.388,1295.97 710.397,1295.97 710.406,1295.97 710.415,1295.97 710.424,1295.97 710.433,1295.97 710.443,1295.97 710.452,1295.97 710.461,1295.97 710.47,1295.97 710.479,1295.98 710.489,1295.98 710.498,1295.98 710.507,1295.98 710.516,1295.98 710.525,1295.98 710.535,1295.98 710.544,1295.98 710.553,1295.98 710.562,1295.98 710.571,1295.98 710.58,1295.98 710.59,1295.99 710.599,1295.99 710.608,1295.99 710.617,1295.99 710.626,1295.99 710.636,1295.99 710.645,1295.99 710.654,1295.99 710.663,1295.99 710.672,1295.99 710.682,1295.99 710.691,1295.99 710.7,1296 710.709,1296 710.718,1296 710.728,1296 710.737,1296 710.746,1296 710.755,1296 710.764,1296 710.773,1296 710.783,1296 710.792,1296 710.801,1296 710.81,1296.01 710.819,1296.01 710.829,1296.01 710.838,1296.01 710.847,1296.01 710.856,1296.01 710.865,1296.01 710.875,1296.01 710.884,1296.01 710.893,1296.01 710.902,1296.01 710.911,1296.01 710.92,1296.02 710.93,1296.02 710.939,1296.02 710.948,1296.02 710.957,1296.02 710.966,1296.02 710.976,1296.02 710.985,1296.02 710.994,1296.02 711.003,1296.02 711.012,1296.02 711.022,1296.02 711.031,1296.03 711.04,1296.03 711.049,1296.03 711.058,1296.03 711.068,1296.03 711.077,1296.03 711.086,1296.03 711.095,1296.03 711.104,1296.03 711.113,1296.03 711.123,1296.03 711.132,1296.03 711.141,1296.04 711.15,1296.04 711.159,1296.04 711.169,1296.04 711.178,1296.04 711.187,1296.04 711.196,1296.04 711.205,1296.04 711.215,1296.04 711.224,1296.04 711.233,1296.04 711.242,1296.04 711.251,1296.05 711.261,1296.05 711.27,1296.05 711.279,1296.05 711.288,1296.05 711.297,1296.05 711.306,1296.05 711.316,1296.05 711.325,1296.05 711.334,1296.05 711.343,1296.05 711.352,1296.05 711.362,1296.06 711.371,1296.06 711.38,1296.06 711.389,1296.06 711.398,1296.06 711.408,1296.06 711.417,1296.06 711.426,1296.06 711.435,1296.06 711.444,1296.06 711.453,1296.06 711.463,1296.06 711.472,1296.07 711.481,1296.07 711.49,1296.07 711.499,1296.07 711.509,1296.07 711.518,1296.07 711.527,1296.07 711.536,1296.07 711.545,1296.07 711.555,1296.07 711.564,1296.07 711.573,1296.07 711.582,1296.08 711.591,1296.08 711.601,1296.08 711.61,1296.08 711.619,1296.08 711.628,1296.08 711.637,1296.08 711.646,1296.08 711.656,1296.08 711.665,1296.08 711.674,1296.08 711.683,1296.08 711.692,1296.09 711.702,1296.09 711.711,1296.09 711.72,1296.09 711.729,1296.09 711.738,1296.09 711.748,1296.09 711.757,1296.09 711.766,1296.09 711.775,1296.09 711.784,1296.09 711.793,1296.09 711.803,1296.1 711.812,1296.1 711.821,1296.1 711.83,1296.1 711.839,1296.1 711.849,1296.1 711.858,1296.1 711.867,1296.1 711.876,1296.1 711.885,1296.1 711.895,1296.1 711.904,1296.1 711.913,1296.1 711.922,1296.11 711.931,1296.11 711.941,1296.11 711.95,1296.11 711.959,1296.11 711.968,1296.11 711.977,1296.11 711.986,1296.11 711.996,1296.11 712.005,1296.11 712.014,1296.11 712.023,1296.11 712.032,1296.12 712.042,1296.12 712.051,1296.12 712.06,1296.12 712.069,1296.12 712.078,1296.12 712.088,1296.12 712.097,1296.12 712.106,1296.12 712.115,1296.12 712.124,1296.12 712.133,1296.12 712.143,1296.13 712.152,1296.13 712.161,1296.13 712.17,1296.13 712.179,1296.13 712.189,1296.13 712.198,1296.13 712.207,1296.13 712.216,1296.13 712.225,1296.13 712.235,1296.13 712.244,1296.13 712.253,1296.14 712.262,1296.14 712.271,1296.14 712.281,1296.14 712.29,1296.14 712.299,1296.14 712.308,1296.14 712.317,1296.14 712.326,1296.14 712.336,1296.14 712.345,1296.14 712.354,1296.14 712.363,1296.15 712.372,1296.15 712.382,1296.15 712.391,1296.15 712.4,1296.15 712.409,1296.15 712.418,1296.15 712.428,1296.15 712.437,1296.15 712.446,1296.15 712.455,1296.15 712.464,1296.15 712.473,1296.16 712.483,1296.16 712.492,1296.16 712.501,1296.16 712.51,1296.16 712.519,1296.16 712.529,1296.16 712.538,1296.16 712.547,1296.16 712.556,1296.16 712.565,1296.16 712.575,1296.16 712.584,1296.17 712.593,1296.17 712.602,1296.17 712.611,1296.17 712.621,1296.17 712.63,1296.17 712.639,1296.17 712.648,1296.17 712.657,1296.17 712.666,1296.17 712.676,1296.17 712.685,1296.17 712.694,1296.18 712.703,1296.18 712.712,1296.18 712.722,1296.18 712.731,1296.18 712.74,1296.18 712.749,1296.18 712.758,1296.18 712.768,1296.18 712.777,1296.18 712.786,1296.18 712.795,1296.18 712.804,1296.19 712.813,1296.19 712.823,1296.19 712.832,1296.19 712.841,1296.19 712.85,1296.19 712.859,1296.19 712.869,1296.19 712.878,1296.19 712.887,1296.19 712.896,1296.19 712.905,1296.19 712.915,1296.2 712.924,1296.2 712.933,1296.2 712.942,1296.2 712.951,1296.2 712.961,1296.2 712.97,1296.2 712.979,1296.2 712.988,1296.2 712.997,1296.2 713.006,1296.2 713.016,1296.2 713.025,1296.21 713.034,1296.21 713.043,1296.21 713.052,1296.21 713.062,1296.21 713.071,1296.21 713.08,1296.21 713.089,1296.21 713.098,1296.21 713.108,1296.21 713.117,1296.21 713.126,1296.21 713.135,1296.22 713.144,1296.22 713.153,1296.22 713.163,1296.22 713.172,1296.22 713.181,1296.22 713.19,1296.22 713.199,1296.22 713.209,1296.22 713.218,1296.22 713.227,1296.22 713.236,1296.22 713.245,1296.22 713.255,1296.23 713.264,1296.23 713.273,1296.23 713.282,1296.23 713.291,1296.23 713.301,1296.23 713.31,1296.23 713.319,1296.23 713.328,1296.23 713.337,1296.23 713.346,1296.23 713.356,1296.23 713.365,1296.24 713.374,1296.24 713.383,1296.24 713.392,1296.24 713.402,1296.24 713.411,1296.24 713.42,1296.24 713.429,1296.24 713.438,1296.24 713.448,1296.24 713.457,1296.24 713.466,1296.24 713.475,1296.25 713.484,1296.25 713.493,1296.25 713.503,1296.25 713.512,1296.25 713.521,1296.25 713.53,1296.25 713.539,1296.25 713.549,1296.25 713.558,1296.25 713.567,1296.25 713.576,1296.25 713.585,1296.26 713.595,1296.26 713.604,1296.26 713.613,1296.26 713.622,1296.26 713.631,1296.26 713.641,1296.26 713.65,1296.26 713.659,1296.26 713.668,1296.26 713.677,1296.26 713.686,1296.26 713.696,1296.27 713.705,1296.27 713.714,1296.27 713.723,1296.27 713.732,1296.27 713.742,1296.27 713.751,1296.27 713.76,1296.27 713.769,1296.27 713.778,1296.27 713.788,1296.27 713.797,1296.27 713.806,1296.28 713.815,1296.28 713.824,1296.28 713.834,1296.28 713.843,1296.28 713.852,1296.28 713.861,1296.28 713.87,1296.28 713.879,1296.28 713.889,1296.28 713.898,1296.28 713.907,1296.28 713.916,1296.29 713.925,1296.29 713.935,1296.29 713.944,1296.29 713.953,1296.29 713.962,1296.29 713.971,1296.29 713.981,1296.29 713.99,1296.29 713.999,1296.29 714.008,1296.29 714.017,1296.29 714.026,1296.3 714.036,1296.3 714.045,1296.3 714.054,1296.3 714.063,1296.3 714.072,1296.3 714.082,1296.3 714.091,1296.3 714.1,1296.3 714.109,1296.3 714.118,1296.3 714.128,1296.3 714.137,1296.31 714.146,1296.31 714.155,1296.31 714.164,1296.31 714.174,1296.31 714.183,1296.31 714.192,1296.31 714.201,1296.31 714.21,1296.31 714.219,1296.31 714.229,1296.31 714.238,1296.31 714.247,1296.32 714.256,1296.32 714.265,1296.32 714.275,1296.32 714.284,1296.32 714.293,1296.32 714.302,1296.32 714.311,1296.32 714.321,1296.32 714.33,1296.32 714.339,1296.32 714.348,1296.32 714.357,1296.32 714.366,1296.33 714.376,1296.33 714.385,1296.33 714.394,1296.33 714.403,1296.33 714.412,1296.33 714.422,1296.33 714.431,1296.33 714.44,1296.33 714.449,1296.33 714.458,1296.33 714.468,1296.33 714.477,1296.34 714.486,1296.34 714.495,1296.34 714.504,1296.34 714.514,1296.34 714.523,1296.34 714.532,1296.34 714.541,1296.34 714.55,1296.34 714.559,1296.34 714.569,1296.34 714.578,1296.34 714.587,1296.35 714.596,1296.35 714.605,1296.35 714.615,1296.35 714.624,1296.35 714.633,1296.35 714.642,1296.35 714.651,1296.35 714.661,1296.35 714.67,1296.35 714.679,1296.35 714.688,1296.35 714.697,1296.36 714.706,1296.36 714.716,1296.36 714.725,1296.36 714.734,1296.36 714.743,1296.36 714.752,1296.36 714.762,1296.36 714.771,1296.36 714.78,1296.36 714.789,1296.36 714.798,1296.36 714.808,1296.37 714.817,1296.37 714.826,1296.37 714.835,1296.37 714.844,1296.37 714.854,1296.37 714.863,1296.37 714.872,1296.37 714.881,1296.37 714.89,1296.37 714.899,1296.37 714.909,1296.37 714.918,1296.38 714.927,1296.38 714.936,1296.38 714.945,1296.38 714.955,1296.38 714.964,1296.38 714.973,1296.38 714.982,1296.38 714.991,1296.38 715.001,1296.38 715.01,1296.38 715.019,1296.38 715.028,1296.39 715.037,1296.39 715.046,1296.39 715.056,1296.39 715.065,1296.39 715.074,1296.39 715.083,1296.39 715.092,1296.39 715.102,1296.39 715.111,1296.39 715.12,1296.39 715.129,1296.39 715.138,1296.4 715.148,1296.4 715.157,1296.4 715.166,1296.4 715.175,1296.4 715.184,1296.4 715.194,1296.4 715.203,1296.4 715.212,1296.4 715.221,1296.4 715.23,1296.4 715.239,1296.4 715.249,1296.41 715.258,1296.41 715.267,1296.41 715.276,1296.41 715.285,1296.41 715.295,1296.41 715.304,1296.41 715.313,1296.41 715.322,1296.41 715.331,1296.41 715.341,1296.41 715.35,1296.41 715.359,1296.41 715.368,1296.42 715.377,1296.42 715.386,1296.42 715.396,1296.42 715.405,1296.42 715.414,1296.42 715.423,1296.42 715.432,1296.42 715.442,1296.42 715.451,1296.42 715.46,1296.42 715.469,1296.42 715.478,1296.43 715.488,1296.43 715.497,1296.43 715.506,1296.43 715.515,1296.43 715.524,1296.43 715.534,1296.43 715.543,1296.43 715.552,1296.43 715.561,1296.43 715.57,1296.43 715.579,1296.43 715.589,1296.44 715.598,1296.44 715.607,1296.44 715.616,1296.44 715.625,1296.44 715.635,1296.44 715.644,1296.44 715.653,1296.44 715.662,1296.44 715.671,1296.44 715.681,1296.44 715.69,1296.44 715.699,1296.45 715.708,1296.45 715.717,1296.45 715.726,1296.45 715.736,1296.45 715.745,1296.45 715.754,1296.45 715.763,1296.45 715.772,1296.45 715.782,1296.45 715.791,1296.45 715.8,1296.45 715.809,1296.46 715.818,1296.46 715.828,1296.46 715.837,1296.46 715.846,1296.46 715.855,1296.46 715.864,1296.46 715.874,1296.46 715.883,1296.46 715.892,1296.46 715.901,1296.46 715.91,1296.46 715.919,1296.47 715.929,1296.47 715.938,1296.47 715.947,1296.47 715.956,1296.47 715.965,1296.47 715.975,1296.47 715.984,1296.47 715.993,1296.47 716.002,1296.47 716.011,1296.47 716.021,1296.47 716.03,1296.48 716.039,1296.48 716.048,1296.48 716.057,1296.48 716.067,1296.48 716.076,1296.48 716.085,1296.48 716.094,1296.48 716.103,1296.48 716.112,1296.48 716.122,1296.48 716.131,1296.48 716.14,1296.49 716.149,1296.49 716.158,1296.49 716.168,1296.49 716.177,1296.49 716.186,1296.49 716.195,1296.49 716.204,1296.49 716.214,1296.49 716.223,1296.49 716.232,1296.49 716.241,1296.49 716.25,1296.5 716.259,1296.5 716.269,1296.5 716.278,1296.5 716.287,1296.5 716.296,1296.5 716.305,1296.5 716.315,1296.5 716.324,1296.5 716.333,1296.5 716.342,1296.5 716.351,1296.5 716.361,1296.5 716.37,1296.51 716.379,1296.51 716.388,1296.51 716.397,1296.51 716.407,1296.51 716.416,1296.51 716.425,1296.51 716.434,1296.51 716.443,1296.51 716.452,1296.51 716.462,1296.51 716.471,1296.51 716.48,1296.52 716.489,1296.52 716.498,1296.52 716.508,1296.52 716.517,1296.52 716.526,1296.52 716.535,1296.52 716.544,1296.52 716.554,1296.52 716.563,1296.52 716.572,1296.52 716.581,1296.52 716.59,1296.53 716.599,1296.53 716.609,1296.53 716.618,1296.53 716.627,1296.53 716.636,1296.53 716.645,1296.53 716.655,1296.53 716.664,1296.53 716.673,1296.53 716.682,1296.53 716.691,1296.53 716.701,1296.54 716.71,1296.54 716.719,1296.54 716.728,1296.54 716.737,1296.54 716.747,1296.54 716.756,1296.54 716.765,1296.54 716.774,1296.54 716.783,1296.54 716.792,1296.54 716.802,1296.54 716.811,1296.55 716.82,1296.55 716.829,1296.55 716.838,1296.55 716.848,1296.55 716.857,1296.55 716.866,1296.55 716.875,1296.55 716.884,1296.55 716.894,1296.55 716.903,1296.55 716.912,1296.55 716.921,1296.56 716.93,1296.56 716.939,1296.56 716.949,1296.56 716.958,1296.56 716.967,1296.56 716.976,1296.56 716.985,1296.56 716.995,1296.56 717.004,1296.56 717.013,1296.56 717.022,1296.56 717.031,1296.57 717.041,1296.57 717.05,1296.57 717.059,1296.57 717.068,1296.57 717.077,1296.57 717.087,1296.57 717.096,1296.57 717.105,1296.57 717.114,1296.57 717.123,1296.57 717.132,1296.57 717.142,1296.57 717.151,1296.58 717.16,1296.58 717.169,1296.58 717.178,1296.58 717.188,1296.58 717.197,1296.58 717.206,1296.58 717.215,1296.58 717.224,1296.58 717.234,1296.58 717.243,1296.58 717.252,1296.58 717.261,1296.59 717.27,1296.59 717.279,1296.59 717.289,1296.59 717.298,1296.59 717.307,1296.59 717.316,1296.59 717.325,1296.59 717.335,1296.59 717.344,1296.59 717.353,1296.59 717.362,1296.59 717.371,1296.6 717.381,1296.6 717.39,1296.6 717.399,1296.6 717.408,1296.6 717.417,1296.6 717.427,1296.6 717.436,1296.6 717.445,1296.6 717.454,1296.6 717.463,1296.6 717.472,1296.6 717.482,1296.61 717.491,1296.61 717.5,1296.61 717.509,1296.61 717.518,1296.61 717.528,1296.61 717.537,1296.61 717.546,1296.61 717.555,1296.61 717.564,1296.61 717.574,1296.61 717.583,1296.61 717.592,1296.62 717.601,1296.62 717.61,1296.62 717.619,1296.62 717.629,1296.62 717.638,1296.62 717.647,1296.62 717.656,1296.62 717.665,1296.62 717.675,1296.62 717.684,1296.62 717.693,1296.62 717.702,1296.63 717.711,1296.63 717.721,1296.63 717.73,1296.63 717.739,1296.63 717.748,1296.63 717.757,1296.63 717.767,1296.63 717.776,1296.63 717.785,1296.63 717.794,1296.63 717.803,1296.63 717.812,1296.64 717.822,1296.64 717.831,1296.64 717.84,1296.64 717.849,1296.64 717.858,1296.64 717.868,1296.64 717.877,1296.64 717.886,1296.64 717.895,1296.64 717.904,1296.64 717.914,1296.64 717.923,1296.65 717.932,1296.65 717.941,1296.65 717.95,1296.65 717.959,1296.65 717.969,1296.65 717.978,1296.65 717.987,1296.65 717.996,1296.65 718.005,1296.65 718.015,1296.65 718.024,1296.65 718.033,1296.65 718.042,1296.66 718.051,1296.66 718.061,1296.66 718.07,1296.66 718.079,1296.66 718.088,1296.66 718.097,1296.66 718.107,1296.66 718.116,1296.66 718.125,1296.66 718.134,1296.66 718.143,1296.66 718.152,1296.67 718.162,1296.67 718.171,1296.67 718.18,1296.67 718.189,1296.67 718.198,1296.67 718.208,1296.67 718.217,1296.67 718.226,1296.67 718.235,1296.67 718.244,1296.67 718.254,1296.67 718.263,1296.68 718.272,1296.68 718.281,1296.68 718.29,1296.68 718.299,1296.68 718.309,1296.68 718.318,1296.68 718.327,1296.68 718.336,1296.68 718.345,1296.68 718.355,1296.68 718.364,1296.68 718.373,1296.69 718.382,1296.69 718.391,1296.69 718.401,1296.69 718.41,1296.69 718.419,1296.69 718.428,1296.69 718.437,1296.69 718.447,1296.69 718.456,1296.69 718.465,1296.69 718.474,1296.69 718.483,1296.7 718.492,1296.7 718.502,1296.7 718.511,1296.7 718.52,1296.7 718.529,1296.7 718.538,1296.7 718.548,1296.7 718.557,1296.7 718.566,1296.7 718.575,1296.7 718.584,1296.7 718.594,1296.71 718.603,1296.71 718.612,1296.71 718.621,1296.71 718.63,1296.71 718.64,1296.71 718.649,1296.71 718.658,1296.71 718.667,1296.71 718.676,1296.71 718.685,1296.71 718.695,1296.71 718.704,1296.72 718.713,1296.72 718.722,1296.72 718.731,1296.72 718.741,1296.72 718.75,1296.72 718.759,1296.72 718.768,1296.72 718.777,1296.72 718.787,1296.72 718.796,1296.72 718.805,1296.72 718.814,1296.72 718.823,1296.73 718.832,1296.73 718.842,1296.73 718.851,1296.73 718.86,1296.73 718.869,1296.73 718.878,1296.73 718.888,1296.73 718.897,1296.73 718.906,1296.73 718.915,1296.73 718.924,1296.73 718.934,1296.74 718.943,1296.74 718.952,1296.74 718.961,1296.74 718.97,1296.74 718.98,1296.74 718.989,1296.74 718.998,1296.74 719.007,1296.74 719.016,1296.74 719.025,1296.74 719.035,1296.74 719.044,1296.75 719.053,1296.75 719.062,1296.75 719.071,1296.75 719.081,1296.75 719.09,1296.75 719.099,1296.75 719.108,1296.75 719.117,1296.75 719.127,1296.75 719.136,1296.75 719.145,1296.75 719.154,1296.76 719.163,1296.76 719.172,1296.76 719.182,1296.76 719.191,1296.76 719.2,1296.76 719.209,1296.76 719.218,1296.76 719.228,1296.76 719.237,1296.76 719.246,1296.76 719.255,1296.76 719.264,1296.77 719.274,1296.77 719.283,1296.77 719.292,1296.77 719.301,1296.77 719.31,1296.77 719.32,1296.77 719.329,1296.77 719.338,1296.77 719.347,1296.77 719.356,1296.77 719.365,1296.77 719.375,1296.78 719.384,1296.78 719.393,1296.78 719.402,1296.78 719.411,1296.78 719.421,1296.78 719.43,1296.78 719.439,1296.78 719.448,1296.78 719.457,1296.78 719.467,1296.78 719.476,1296.78 719.485,1296.78 719.494,1296.79 719.503,1296.79 719.512,1296.79 719.522,1296.79 719.531,1296.79 719.54,1296.79 719.549,1296.79 719.558,1296.79 719.568,1296.79 719.577,1296.79 719.586,1296.79 719.595,1296.79 719.604,1296.8 719.614,1296.8 719.623,1296.8 719.632,1296.8 719.641,1296.8 719.65,1296.8 719.66,1296.8 719.669,1296.8 719.678,1296.8 719.687,1296.8 719.696,1296.8 719.705,1296.8 719.715,1296.81 719.724,1296.81 719.733,1296.81 719.742,1296.81 719.751,1296.81 719.761,1296.81 719.77,1296.81 719.779,1296.81 719.788,1296.81 719.797,1296.81 719.807,1296.81 719.816,1296.81 719.825,1296.82 719.834,1296.82 719.843,1296.82 719.852,1296.82 719.862,1296.82 719.871,1296.82 719.88,1296.82 719.889,1296.82 719.898,1296.82 719.908,1296.82 719.917,1296.82 719.926,1296.82 719.935,1296.83 719.944,1296.83 719.954,1296.83 719.963,1296.83 719.972,1296.83 719.981,1296.83 719.99,1296.83 720,1296.83 720.009,1296.83 720.018,1296.83 720.027,1296.83 720.036,1296.83 720.045,1296.84 720.055,1296.84 720.064,1296.84 720.073,1296.84 720.082,1296.84 720.091,1296.84 720.101,1296.84 720.11,1296.84 720.119,1296.84 720.128,1296.84 720.137,1296.84 720.147,1296.84 720.156,1296.85 720.165,1296.85 720.174,1296.85 720.183,1296.85 720.192,1296.85 720.202,1296.85 720.211,1296.85 720.22,1296.85 720.229,1296.85 720.238,1296.85 720.248,1296.85 720.257,1296.85 720.266,1296.85 720.275,1296.86 720.284,1296.86 720.294,1296.86 720.303,1296.86 720.312,1296.86 720.321,1296.86 720.33,1296.86 720.34,1296.86 720.349,1296.86 720.358,1296.86 720.367,1296.86 720.376,1296.86 720.385,1296.87 720.395,1296.87 720.404,1296.87 720.413,1296.87 720.422,1296.87 720.431,1296.87 720.441,1296.87 720.45,1296.87 720.459,1296.87 720.468,1296.87 720.477,1296.87 720.487,1296.87 720.496,1296.88 720.505,1296.88 720.514,1296.88 720.523,1296.88 720.532,1296.88 720.542,1296.88 720.551,1296.88 720.56,1296.88 720.569,1296.88 720.578,1296.88 720.588,1296.88 720.597,1296.88 720.606,1296.89 720.615,1296.89 720.624,1296.89 720.634,1296.89 720.643,1296.89 720.652,1296.89 720.661,1296.89 720.67,1296.89 720.68,1296.89 720.689,1296.89 720.698,1296.89 720.707,1296.89 720.716,1296.9 720.725,1296.9 720.735,1296.9 720.744,1296.9 720.753,1296.9 720.762,1296.9 720.771,1296.9 720.781,1296.9 720.79,1296.9 720.799,1296.9 720.808,1296.9 720.817,1296.9 720.827,1296.91 720.836,1296.91 720.845,1296.91 720.854,1296.91 720.863,1296.91 720.872,1296.91 720.882,1296.91 720.891,1296.91 720.9,1296.91 720.909,1296.91 720.918,1296.91 720.928,1296.91 720.937,1296.91 720.946,1296.92 720.955,1296.92 720.964,1296.92 720.974,1296.92 720.983,1296.92 720.992,1296.92 721.001,1296.92 721.01,1296.92 721.02,1296.92 721.029,1296.92 721.038,1296.92 721.047,1296.92 721.056,1296.93 721.065,1296.93 721.075,1296.93 721.084,1296.93 721.093,1296.93 721.102,1296.93 721.111,1296.93 721.121,1296.93 721.13,1296.93 721.139,1296.93 721.148,1296.93 721.157,1296.93 721.167,1296.94 721.176,1296.94 721.185,1296.94 721.194,1296.94 721.203,1296.94 721.213,1296.94 721.222,1296.94 721.231,1296.94 721.24,1296.94 721.249,1296.94 721.258,1296.94 721.268,1296.94 721.277,1296.95 721.286,1296.95 721.295,1296.95 721.304,1296.95 721.314,1296.95 721.323,1296.95 721.332,1296.95 721.341,1296.95 721.35,1296.95 721.36,1296.95 721.369,1296.95 721.378,1296.95 721.387,1296.96 721.396,1296.96 721.405,1296.96 721.415,1296.96 721.424,1296.96 721.433,1296.96 721.442,1296.96 721.451,1296.96 721.461,1296.96 721.47,1296.96 721.479,1296.96 721.488,1296.96 721.497,1296.97 721.507,1296.97 721.516,1296.97 721.525,1296.97 721.534,1296.97 721.543,1296.97 721.553,1296.97 721.562,1296.97 721.571,1296.97 721.58,1296.97 721.589,1296.97 721.598,1296.97 721.608,1296.97 721.617,1296.98 721.626,1296.98 721.635,1296.98 721.644,1296.98 721.654,1296.98 721.663,1296.98 721.672,1296.98 721.681,1296.98 721.69,1296.98 721.7,1296.98 721.709,1296.98 721.718,1296.98 721.727,1296.99 721.736,1296.99 721.745,1296.99 721.755,1296.99 721.764,1296.99 721.773,1296.99 721.782,1296.99 721.791,1296.99 721.801,1296.99 721.81,1296.99 721.819,1296.99 721.828,1296.99 721.837,1297 721.847,1297 721.856,1297 721.865,1297 721.874,1297 721.883,1297 721.893,1297 721.902,1297 721.911,1297 721.92,1297 721.929,1297 721.938,1297 721.948,1297.01 721.957,1297.01 721.966,1297.01 721.975,1297.01 721.984,1297.01 721.994,1297.01 722.003,1297.01 722.012,1297.01 722.021,1297.01 722.03,1297.01 722.04,1297.01 722.049,1297.01 722.058,1297.02 722.067,1297.02 722.076,1297.02 722.085,1297.02 722.095,1297.02 722.104,1297.02 722.113,1297.02 722.122,1297.02 722.131,1297.02 722.141,1297.02 722.15,1297.02 722.159,1297.02 722.168,1297.02 722.177,1297.03 722.187,1297.03 722.196,1297.03 722.205,1297.03 722.214,1297.03 722.223,1297.03 722.233,1297.03 722.242,1297.03 722.251,1297.03 722.26,1297.03 722.269,1297.03 722.278,1297.03 722.288,1297.04 722.297,1297.04 722.306,1297.04 722.315,1297.04 722.324,1297.04 722.334,1297.04 722.343,1297.04 722.352,1297.04 722.361,1297.04 722.37,1297.04 722.38,1297.04 722.389,1297.04 722.398,1297.05 722.407,1297.05 722.416,1297.05 722.425,1297.05 722.435,1297.05 722.444,1297.05 722.453,1297.05 722.462,1297.05 722.471,1297.05 722.481,1297.05 722.49,1297.05 722.499,1297.05 722.508,1297.06 722.517,1297.06 722.527,1297.06 722.536,1297.06 722.545,1297.06 722.554,1297.06 722.563,1297.06 722.573,1297.06 722.582,1297.06 722.591,1297.06 722.6,1297.06 722.609,1297.06 722.618,1297.07 722.628,1297.07 722.637,1297.07 722.646,1297.07 722.655,1297.07 722.664,1297.07 722.674,1297.07 722.683,1297.07 722.692,1297.07 722.701,1297.07 722.71,1297.07 722.72,1297.07 722.729,1297.08 722.738,1297.08 722.747,1297.08 722.756,1297.08 722.765,1297.08 722.775,1297.08 722.784,1297.08 722.793,1297.08 722.802,1297.08 722.811,1297.08 722.821,1297.08 722.83,1297.08 722.839,1297.08 722.848,1297.09 722.857,1297.09 722.867,1297.09 722.876,1297.09 722.885,1297.09 722.894,1297.09 722.903,1297.09 722.913,1297.09 722.922,1297.09 722.931,1297.09 722.94,1297.09 722.949,1297.09 722.958,1297.1 722.968,1297.1 722.977,1297.1 722.986,1297.1 722.995,1297.1 723.004,1297.1 723.014,1297.1 723.023,1297.1 723.032,1297.1 723.041,1297.1 723.05,1297.1 723.06,1297.1 723.069,1297.11 723.078,1297.11 723.087,1297.11 723.096,1297.11 723.105,1297.11 723.115,1297.11 723.124,1297.11 723.133,1297.11 723.142,1297.11 723.151,1297.11 723.161,1297.11 723.17,1297.11 723.179,1297.12 723.188,1297.12 723.197,1297.12 723.207,1297.12 723.216,1297.12 723.225,1297.12 723.234,1297.12 723.243,1297.12 723.253,1297.12 723.262,1297.12 723.271,1297.12 723.28,1297.12 723.289,1297.13 723.298,1297.13 723.308,1297.13 723.317,1297.13 723.326,1297.13 723.335,1297.13 723.344,1297.13 723.354,1297.13 723.363,1297.13 723.372,1297.13 723.381,1297.13 723.39,1297.13 723.4,1297.13 723.409,1297.14 723.418,1297.14 723.427,1297.14 723.436,1297.14 723.446,1297.14 723.455,1297.14 723.464,1297.14 723.473,1297.14 723.482,1297.14 723.491,1297.14 723.501,1297.14 723.51,1297.14 723.519,1297.15 723.528,1297.15 723.537,1297.15 723.547,1297.15 723.556,1297.15 723.565,1297.15 723.574,1297.15 723.583,1297.15 723.593,1297.15 723.602,1297.15 723.611,1297.15 723.62,1297.15 723.629,1297.16 723.638,1297.16 723.648,1297.16 723.657,1297.16 723.666,1297.16 723.675,1297.16 723.684,1297.16 723.694,1297.16 723.703,1297.16 723.712,1297.16 723.721,1297.16 723.73,1297.16 723.74,1297.17 723.749,1297.17 723.758,1297.17 723.767,1297.17 723.776,1297.17 723.786,1297.17 723.795,1297.17 723.804,1297.17 723.813,1297.17 723.822,1297.17 723.831,1297.17 723.841,1297.17 723.85,1297.18 723.859,1297.18 723.868,1297.18 723.877,1297.18 723.887,1297.18 723.896,1297.18 723.905,1297.18 723.914,1297.18 723.923,1297.18 723.933,1297.18 723.942,1297.18 723.951,1297.18 723.96,1297.18 723.969,1297.19 723.978,1297.19 723.988,1297.19 723.997,1297.19 724.006,1297.19 724.015,1297.19 724.024,1297.19 724.034,1297.19 724.043,1297.19 724.052,1297.19 724.061,1297.19 724.07,1297.19 724.08,1297.2 724.089,1297.2 724.098,1297.2 724.107,1297.2 724.116,1297.2 724.126,1297.2 724.135,1297.2 724.144,1297.2 724.153,1297.2 724.162,1297.2 724.171,1297.2 724.181,1297.2 724.19,1297.21 724.199,1297.21 724.208,1297.21 724.217,1297.21 724.227,1297.21 724.236,1297.21 724.245,1297.21 724.254,1297.21 724.263,1297.21 724.273,1297.21 724.282,1297.21 724.291,1297.21 724.3,1297.22 724.309,1297.22 724.318,1297.22 724.328,1297.22 724.337,1297.22 724.346,1297.22 724.355,1297.22 724.364,1297.22 724.374,1297.22 724.383,1297.22 724.392,1297.22 724.401,1297.22 724.41,1297.23 724.42,1297.23 724.429,1297.23 724.438,1297.23 724.447,1297.23 724.456,1297.23 724.466,1297.23 724.475,1297.23 724.484,1297.23 724.493,1297.23 724.502,1297.23 724.511,1297.23 724.521,1297.23 724.53,1297.24 724.539,1297.24 724.548,1297.24 724.557,1297.24 724.567,1297.24 724.576,1297.24 724.585,1297.24 724.594,1297.24 724.603,1297.24 724.613,1297.24 724.622,1297.24 724.631,1297.24 724.64,1297.25 724.649,1297.25 724.658,1297.25 724.668,1297.25 724.677,1297.25 724.686,1297.25 724.695,1297.25 724.704,1297.25 724.714,1297.25 724.723,1297.25 724.732,1297.25 724.741,1297.25 724.75,1297.26 724.76,1297.26 724.769,1297.26 724.778,1297.26 724.787,1297.26 724.796,1297.26 724.806,1297.26 724.815,1297.26 724.824,1297.26 724.833,1297.26 724.842,1297.26 724.851,1297.26 724.861,1297.27 724.87,1297.27 724.879,1297.27 724.888,1297.27 724.897,1297.27 724.907,1297.27 724.916,1297.27 724.925,1297.27 724.934,1297.27 724.943,1297.27 724.953,1297.27 724.962,1297.27 724.971,1297.28 724.98,1297.28 724.989,1297.28 724.998,1297.28 725.008,1297.28 725.017,1297.28 725.026,1297.28 725.035,1297.28 725.044,1297.28 725.054,1297.28 725.063,1297.28 725.072,1297.28 725.081,1297.28 725.09,1297.29 725.1,1297.29 725.109,1297.29 725.118,1297.29 725.127,1297.29 725.136,1297.29 725.146,1297.29 725.155,1297.29 725.164,1297.29 725.173,1297.29 725.182,1297.29 725.191,1297.29 725.201,1297.3 725.21,1297.3 725.219,1297.3 725.228,1297.3 725.237,1297.3 725.247,1297.3 725.256,1297.3 725.265,1297.3 725.274,1297.3 725.283,1297.3 725.293,1297.3 725.302,1297.3 725.311,1297.31 725.32,1297.31 725.329,1297.31 725.338,1297.31 725.348,1297.31 725.357,1297.31 725.366,1297.31 725.375,1297.31 725.384,1297.31 725.394,1297.31 725.403,1297.31 725.412,1297.31 725.421,1297.32 725.43,1297.32 725.44,1297.32 725.449,1297.32 725.458,1297.32 725.467,1297.32 725.476,1297.32 725.486,1297.32 725.495,1297.32 725.504,1297.32 725.513,1297.32 725.522,1297.32 725.531,1297.33 725.541,1297.33 725.55,1297.33 725.559,1297.33 725.568,1297.33 725.577,1297.33 725.587,1297.33 725.596,1297.33 725.605,1297.33 725.614,1297.33 725.623,1297.33 725.633,1297.33 725.642,1297.33 725.651,1297.34 725.66,1297.34 725.669,1297.34 725.678,1297.34 725.688,1297.34 725.697,1297.34 725.706,1297.34 725.715,1297.34 725.724,1297.34 725.734,1297.34 725.743,1297.34 725.752,1297.34 725.761,1297.35 725.77,1297.35 725.78,1297.35 725.789,1297.35 725.798,1297.35 725.807,1297.35 725.816,1297.35 725.826,1297.35 725.835,1297.35 725.844,1297.35 725.853,1297.35 725.862,1297.35 725.871,1297.36 725.881,1297.36 725.89,1297.36 725.899,1297.36 725.908,1297.36 725.917,1297.36 725.927,1297.36 725.936,1297.36 725.945,1297.36 725.954,1297.36 725.963,1297.36 725.973,1297.36 725.982,1297.37 725.991,1297.37 726,1297.37 726.009,1297.37 726.019,1297.37 726.028,1297.37 726.037,1297.37 726.046,1297.37 726.055,1297.37 726.064,1297.37 726.074,1297.37 726.083,1297.37 726.092,1297.37 726.101,1297.38 726.11,1297.38 726.12,1297.38 726.129,1297.38 726.138,1297.38 726.147,1297.38 726.156,1297.38 726.166,1297.38 726.175,1297.38 726.184,1297.38 726.193,1297.38 726.202,1297.38 726.211,1297.39 726.221,1297.39 726.23,1297.39 726.239,1297.39 726.248,1297.39 726.257,1297.39 726.267,1297.39 726.276,1297.39 726.285,1297.39 726.294,1297.39 726.303,1297.39 726.313,1297.39 726.322,1297.4 726.331,1297.4 726.34,1297.4 726.349,1297.4 726.359,1297.4 726.368,1297.4 726.377,1297.4 726.386,1297.4 726.395,1297.4 726.404,1297.4 726.414,1297.4 726.423,1297.4 726.432,1297.41 726.441,1297.41 726.45,1297.41 726.46,1297.41 726.469,1297.41 726.478,1297.41 726.487,1297.41 726.496,1297.41 726.506,1297.41 726.515,1297.41 726.524,1297.41 726.533,1297.41 726.542,1297.42 726.551,1297.42 726.561,1297.42 726.57,1297.42 726.579,1297.42 726.588,1297.42 726.597,1297.42 726.607,1297.42 726.616,1297.42 726.625,1297.42 726.634,1297.42 726.643,1297.42 726.653,1297.42 726.662,1297.43 726.671,1297.43 726.68,1297.43 726.689,1297.43 726.699,1297.43 726.708,1297.43 726.717,1297.43 726.726,1297.43 726.735,1297.43 726.744,1297.43 726.754,1297.43 726.763,1297.43 726.772,1297.44 726.781,1297.44 726.79,1297.44 726.8,1297.44 726.809,1297.44 726.818,1297.44 726.827,1297.44 726.836,1297.44 726.846,1297.44 726.855,1297.44 726.864,1297.44 726.873,1297.44 726.882,1297.45 726.891,1297.45 726.901,1297.45 726.91,1297.45 726.919,1297.45 726.928,1297.45 726.937,1297.45 726.947,1297.45 726.956,1297.45 726.965,1297.45 726.974,1297.45 726.983,1297.45 726.993,1297.46 727.002,1297.46 727.011,1297.46 727.02,1297.46 727.029,1297.46 727.039,1297.46 727.048,1297.46 727.057,1297.46 727.066,1297.46 727.075,1297.46 727.084,1297.46 727.094,1297.46 727.103,1297.46 727.112,1297.47 727.121,1297.47 727.13,1297.47 727.14,1297.47 727.149,1297.47 727.158,1297.47 727.167,1297.47 727.176,1297.47 727.186,1297.47 727.195,1297.47 727.204,1297.47 727.213,1297.47 727.222,1297.48 727.231,1297.48 727.241,1297.48 727.25,1297.48 727.259,1297.48 727.268,1297.48 727.277,1297.48 727.287,1297.48 727.296,1297.48 727.305,1297.48 727.314,1297.48 727.323,1297.48 727.333,1297.49 727.342,1297.49 727.351,1297.49 727.36,1297.49 727.369,1297.49 727.379,1297.49 727.388,1297.49 727.397,1297.49 727.406,1297.49 727.415,1297.49 727.424,1297.49 727.434,1297.49 727.443,1297.5 727.452,1297.5 727.461,1297.5 727.47,1297.5 727.48,1297.5 727.489,1297.5 727.498,1297.5 727.507,1297.5 727.516,1297.5 727.526,1297.5 727.535,1297.5 727.544,1297.5 727.553,1297.5 727.562,1297.51 727.571,1297.51 727.581,1297.51 727.59,1297.51 727.599,1297.51 727.608,1297.51 727.617,1297.51 727.627,1297.51 727.636,1297.51 727.645,1297.51 727.654,1297.51 727.663,1297.51 727.673,1297.52 727.682,1297.52 727.691,1297.52 727.7,1297.52 727.709,1297.52 727.719,1297.52 727.728,1297.52 727.737,1297.52 727.746,1297.52 727.755,1297.52 727.764,1297.52 727.774,1297.52 727.783,1297.53 727.792,1297.53 727.801,1297.53 727.81,1297.53 727.82,1297.53 727.829,1297.53 727.838,1297.53 727.847,1297.53 727.856,1297.53 727.866,1297.53 727.875,1297.53 727.884,1297.53 727.893,1297.54 727.902,1297.54 727.911,1297.54 727.921,1297.54 727.93,1297.54 727.939,1297.54 727.948,1297.54 727.957,1297.54 727.967,1297.54 727.976,1297.54 727.985,1297.54 727.994,1297.54 728.003,1297.55 728.013,1297.55 728.022,1297.55 728.031,1297.55 728.04,1297.55 728.049,1297.55 728.059,1297.55 728.068,1297.55 728.077,1297.55 728.086,1297.55 728.095,1297.55 728.104,1297.55 728.114,1297.55 728.123,1297.56 728.132,1297.56 728.141,1297.56 728.15,1297.56 728.16,1297.56 728.169,1297.56 728.178,1297.56 728.187,1297.56 728.196,1297.56 728.206,1297.56 728.215,1297.56 728.224,1297.56 728.233,1297.57 728.242,1297.57 728.251,1297.57 728.261,1297.57 728.27,1297.57 728.279,1297.57 728.288,1297.57 728.297,1297.57 728.307,1297.57 728.316,1297.57 728.325,1297.57 728.334,1297.57 728.343,1297.58 728.353,1297.58 728.362,1297.58 728.371,1297.58 728.38,1297.58 728.389,1297.58 728.399,1297.58 728.408,1297.58 728.417,1297.58 728.426,1297.58 728.435,1297.58 728.444,1297.58 728.454,1297.59 728.463,1297.59 728.472,1297.59 728.481,1297.59 728.49,1297.59 728.5,1297.59 728.509,1297.59 728.518,1297.59 728.527,1297.59 728.536,1297.59 728.546,1297.59 728.555,1297.59 728.564,1297.59 728.573,1297.6 728.582,1297.6 728.592,1297.6 728.601,1297.6 728.61,1297.6 728.619,1297.6 728.628,1297.6 728.637,1297.6 728.647,1297.6 728.656,1297.6 728.665,1297.6 728.674,1297.6 728.683,1297.61 728.693,1297.61 728.702,1297.61 728.711,1297.61 728.72,1297.61 728.729,1297.61 728.739,1297.61 728.748,1297.61 728.757,1297.61 728.766,1297.61 728.775,1297.61 728.784,1297.61 728.794,1297.62 728.803,1297.62 728.812,1297.62 728.821,1297.62 728.83,1297.62 728.84,1297.62 728.849,1297.62 728.858,1297.62 728.867,1297.62 728.876,1297.62 728.886,1297.62 728.895,1297.62 728.904,1297.63 728.913,1297.63 728.922,1297.63 728.932,1297.63 728.941,1297.63 728.95,1297.63 728.959,1297.63 728.968,1297.63 728.977,1297.63 728.987,1297.63 728.996,1297.63 729.005,1297.63 729.014,1297.63 729.023,1297.64 729.033,1297.64 729.042,1297.64 729.051,1297.64 729.06,1297.64 729.069,1297.64 729.079,1297.64 729.088,1297.64 729.097,1297.64 729.106,1297.64 729.115,1297.64 729.124,1297.64 729.134,1297.65 729.143,1297.65 729.152,1297.65 729.161,1297.65 729.17,1297.65 729.18,1297.65 729.189,1297.65 729.198,1297.65 729.207,1297.65 729.216,1297.65 729.226,1297.65 729.235,1297.65 729.244,1297.66 729.253,1297.66 729.262,1297.66 729.272,1297.66 729.281,1297.66 729.29,1297.66 729.299,1297.66 729.308,1297.66 729.317,1297.66 729.327,1297.66 729.336,1297.66 729.345,1297.66 729.354,1297.67 729.363,1297.67 729.373,1297.67 729.382,1297.67 729.391,1297.67 729.4,1297.67 729.409,1297.67 729.419,1297.67 729.428,1297.67 729.437,1297.67 729.446,1297.67 729.455,1297.67 729.464,1297.67 729.474,1297.68 729.483,1297.68 729.492,1297.68 729.501,1297.68 729.51,1297.68 729.52,1297.68 729.529,1297.68 729.538,1297.68 729.547,1297.68 729.556,1297.68 729.566,1297.68 729.575,1297.68 729.584,1297.69 729.593,1297.69 729.602,1297.69 729.612,1297.69 729.621,1297.69 729.63,1297.69 729.639,1297.69 729.648,1297.69 729.657,1297.69 729.667,1297.69 729.676,1297.69 729.685,1297.69 729.694,1297.7 729.703,1297.7 729.713,1297.7 729.722,1297.7 729.731,1297.7 729.74,1297.7 729.749,1297.7 729.759,1297.7 729.768,1297.7 729.777,1297.7 729.786,1297.7 729.795,1297.7 729.804,1297.71 729.814,1297.71 729.823,1297.71 729.832,1297.71 729.841,1297.71 729.85,1297.71 729.86,1297.71 729.869,1297.71 729.878,1297.71 729.887,1297.71 729.896,1297.71 729.906,1297.71 729.915,1297.71 729.924,1297.72 729.933,1297.72 729.942,1297.72 729.952,1297.72 729.961,1297.72 729.97,1297.72 729.979,1297.72 729.988,1297.72 729.997,1297.72 730.007,1297.72 730.016,1297.72 730.025,1297.72 730.034,1297.73 730.043,1297.73 730.053,1297.73 730.062,1297.73 730.071,1297.73 730.08,1297.73 730.089,1297.73 730.099,1297.73 730.108,1297.73 730.117,1297.73 730.126,1297.73 730.135,1297.73 730.144,1297.74 730.154,1297.74 730.163,1297.74 730.172,1297.74 730.181,1297.74 730.19,1297.74 730.2,1297.74 730.209,1297.74 730.218,1297.74 730.227,1297.74 730.236,1297.74 730.246,1297.74 730.255,1297.75 730.264,1297.75 730.273,1297.75 730.282,1297.75 730.292,1297.75 730.301,1297.75 730.31,1297.75 730.319,1297.75 730.328,1297.75 730.337,1297.75 730.347,1297.75 730.356,1297.75 730.365,1297.75 730.374,1297.76 730.383,1297.76 730.393,1297.76 730.402,1297.76 730.411,1297.76 730.42,1297.76 730.429,1297.76 730.439,1297.76 730.448,1297.76 730.457,1297.76 730.466,1297.76 730.475,1297.76 730.484,1297.77 730.494,1297.77 730.503,1297.77 730.512,1297.77 730.521,1297.77 730.53,1297.77 730.54,1297.77 730.549,1297.77 730.558,1297.77 730.567,1297.77 730.576,1297.77 730.586,1297.77 730.595,1297.78 730.604,1297.78 730.613,1297.78 730.622,1297.78 730.632,1297.78 730.641,1297.78 730.65,1297.78 730.659,1297.78 730.668,1297.78 730.677,1297.78 730.687,1297.78 730.696,1297.78 730.705,1297.78 730.714,1297.79 730.723,1297.79 730.733,1297.79 730.742,1297.79 730.751,1297.79 730.76,1297.79 730.769,1297.79 730.779,1297.79 730.788,1297.79 730.797,1297.79 730.806,1297.79 730.815,1297.79 730.825,1297.8 730.834,1297.8 730.843,1297.8 730.852,1297.8 730.861,1297.8 730.87,1297.8 730.88,1297.8 730.889,1297.8 730.898,1297.8 730.907,1297.8 730.916,1297.8 730.926,1297.8 730.935,1297.81 730.944,1297.81 730.953,1297.81 730.962,1297.81 730.972,1297.81 730.981,1297.81 730.99,1297.81 730.999,1297.81 731.008,1297.81 731.017,1297.81 731.027,1297.81 731.036,1297.81 731.045,1297.82 731.054,1297.82 731.063,1297.82 731.073,1297.82 731.082,1297.82 731.091,1297.82 731.1,1297.82 731.109,1297.82 731.119,1297.82 731.128,1297.82 731.137,1297.82 731.146,1297.82 731.155,1297.82 731.165,1297.83 731.174,1297.83 731.183,1297.83 731.192,1297.83 731.201,1297.83 731.21,1297.83 731.22,1297.83 731.229,1297.83 731.238,1297.83 731.247,1297.83 731.256,1297.83 731.266,1297.83 731.275,1297.84 731.284,1297.84 731.293,1297.84 731.302,1297.84 731.312,1297.84 731.321,1297.84 731.33,1297.84 731.339,1297.84 731.348,1297.84 731.357,1297.84 731.367,1297.84 731.376,1297.84 731.385,1297.85 731.394,1297.85 731.403,1297.85 731.413,1297.85 731.422,1297.85 731.431,1297.85 731.44,1297.85 731.449,1297.85 731.459,1297.85 731.468,1297.85 731.477,1297.85 731.486,1297.85 731.495,1297.86 731.505,1297.86 731.514,1297.86 731.523,1297.86 731.532,1297.86 731.541,1297.86 731.55,1297.86 731.56,1297.86 731.569,1297.86 731.578,1297.86 731.587,1297.86 731.596,1297.86 731.606,1297.86 731.615,1297.87 731.624,1297.87 731.633,1297.87 731.642,1297.87 731.652,1297.87 731.661,1297.87 731.67,1297.87 731.679,1297.87 731.688,1297.87 731.697,1297.87 731.707,1297.87 731.716,1297.87 731.725,1297.88 731.734,1297.88 731.743,1297.88 731.753,1297.88 731.762,1297.88 731.771,1297.88 731.78,1297.88 731.789,1297.88 731.799,1297.88 731.808,1297.88 731.817,1297.88 731.826,1297.88 731.835,1297.89 731.845,1297.89 731.854,1297.89 731.863,1297.89 731.872,1297.89 731.881,1297.89 731.89,1297.89 731.9,1297.89 731.909,1297.89 731.918,1297.89 731.927,1297.89 731.936,1297.89 731.946,1297.89 731.955,1297.9 731.964,1297.9 731.973,1297.9 731.982,1297.9 731.992,1297.9 732.001,1297.9 732.01,1297.9 732.019,1297.9 732.028,1297.9 732.037,1297.9 732.047,1297.9 732.056,1297.9 732.065,1297.91 732.074,1297.91 732.083,1297.91 732.093,1297.91 732.102,1297.91 732.111,1297.91 732.12,1297.91 732.129,1297.91 732.139,1297.91 732.148,1297.91 732.157,1297.91 732.166,1297.91 732.175,1297.92 732.185,1297.92 732.194,1297.92 732.203,1297.92 732.212,1297.92 732.221,1297.92 732.23,1297.92 732.24,1297.92 732.249,1297.92 732.258,1297.92 732.267,1297.92 732.276,1297.92 732.286,1297.93 732.295,1297.93 732.304,1297.93 732.313,1297.93 732.322,1297.93 732.332,1297.93 732.341,1297.93 732.35,1297.93 732.359,1297.93 732.368,1297.93 732.377,1297.93 732.387,1297.93 732.396,1297.93 732.405,1297.94 732.414,1297.94 732.423,1297.94 732.433,1297.94 732.442,1297.94 732.451,1297.94 732.46,1297.94 732.469,1297.94 732.479,1297.94 732.488,1297.94 732.497,1297.94 732.506,1297.94 732.515,1297.95 732.525,1297.95 732.534,1297.95 732.543,1297.95 732.552,1297.95 732.561,1297.95 732.57,1297.95 732.58,1297.95 732.589,1297.95 732.598,1297.95 732.607,1297.95 732.616,1297.95 732.626,1297.96 732.635,1297.96 732.644,1297.96 732.653,1297.96 732.662,1297.96 732.672,1297.96 732.681,1297.96 732.69,1297.96 732.699,1297.96 732.708,1297.96 732.717,1297.96 732.727,1297.96 732.736,1297.96 732.745,1297.97 732.754,1297.97 732.763,1297.97 732.773,1297.97 732.782,1297.97 732.791,1297.97 732.8,1297.97 732.809,1297.97 732.819,1297.97 732.828,1297.97 732.837,1297.97 732.846,1297.97 732.855,1297.98 732.865,1297.98 732.874,1297.98 732.883,1297.98 732.892,1297.98 732.901,1297.98 732.91,1297.98 732.92,1297.98 732.929,1297.98 732.938,1297.98 732.947,1297.98 732.956,1297.98 732.966,1297.99 732.975,1297.99 732.984,1297.99 732.993,1297.99 733.002,1297.99 733.012,1297.99 733.021,1297.99 733.03,1297.99 733.039,1297.99 733.048,1297.99 733.057,1297.99 733.067,1297.99 733.076,1298 733.085,1298 733.094,1298 733.103,1298 733.113,1298 733.122,1298 733.131,1298 733.14,1298 733.149,1298 733.159,1298 733.168,1298 733.177,1298 733.186,1298 733.195,1298.01 733.205,1298.01 733.214,1298.01 733.223,1298.01 733.232,1298.01 733.241,1298.01 733.25,1298.01 733.26,1298.01 733.269,1298.01 733.278,1298.01 733.287,1298.01 733.296,1298.01 733.306,1298.02 733.315,1298.02 733.324,1298.02 733.333,1298.02 733.342,1298.02 733.352,1298.02 733.361,1298.02 733.37,1298.02 733.379,1298.02 733.388,1298.02 733.398,1298.02 733.407,1298.02 733.416,1298.03 733.425,1298.03 733.434,1298.03 733.443,1298.03 733.453,1298.03 733.462,1298.03 733.471,1298.03 733.48,1298.03 733.489,1298.03 733.499,1298.03 733.508,1298.03 733.517,1298.03 733.526,1298.03 733.535,1298.04 733.545,1298.04 733.554,1298.04 733.563,1298.04 733.572,1298.04 733.581,1298.04 733.59,1298.04 733.6,1298.04 733.609,1298.04 733.618,1298.04 733.627,1298.04 733.636,1298.04 733.646,1298.05 733.655,1298.05 733.664,1298.05 733.673,1298.05 733.682,1298.05 733.692,1298.05 733.701,1298.05 733.71,1298.05 733.719,1298.05 733.728,1298.05 733.738,1298.05 733.747,1298.05 733.756,1298.06 733.765,1298.06 733.774,1298.06 733.783,1298.06 733.793,1298.06 733.802,1298.06 733.811,1298.06 733.82,1298.06 733.829,1298.06 733.839,1298.06 733.848,1298.06 733.857,1298.06 733.866,1298.07 733.875,1298.07 733.885,1298.07 733.894,1298.07 733.903,1298.07 733.912,1298.07 733.921,1298.07 733.93,1298.07 733.94,1298.07 733.949,1298.07 733.958,1298.07 733.967,1298.07 733.976,1298.07 733.986,1298.08 733.995,1298.08 734.004,1298.08 734.013,1298.08 734.022,1298.08 734.032,1298.08 734.041,1298.08 734.05,1298.08 734.059,1298.08 734.068,1298.08 734.078,1298.08 734.087,1298.08 734.096,1298.09 734.105,1298.09 734.114,1298.09 734.123,1298.09 734.133,1298.09 734.142,1298.09 734.151,1298.09 734.16,1298.09 734.169,1298.09 734.179,1298.09 734.188,1298.09 734.197,1298.09 734.206,1298.1 734.215,1298.1 734.225,1298.1 734.234,1298.1 734.243,1298.1 734.252,1298.1 734.261,1298.1 734.27,1298.1 734.28,1298.1 734.289,1298.1 734.298,1298.1 734.307,1298.1 734.316,1298.1 734.326,1298.11 734.335,1298.11 734.344,1298.11 734.353,1298.11 734.362,1298.11 734.372,1298.11 734.381,1298.11 734.39,1298.11 734.399,1298.11 734.408,1298.11 734.418,1298.11 734.427,1298.11 734.436,1298.12 734.445,1298.12 734.454,1298.12 734.463,1298.12 734.473,1298.12 734.482,1298.12 734.491,1298.12 734.5,1298.12 734.509,1298.12 734.519,1298.12 734.528,1298.12 734.537,1298.12 734.546,1298.13 734.555,1298.13 734.565,1298.13 734.574,1298.13 734.583,1298.13 734.592,1298.13 734.601,1298.13 734.61,1298.13 734.62,1298.13 734.629,1298.13 734.638,1298.13 734.647,1298.13 734.656,1298.13 734.666,1298.14 734.675,1298.14 734.684,1298.14 734.693,1298.14 734.702,1298.14 734.712,1298.14 734.721,1298.14 734.73,1298.14 734.739,1298.14 734.748,1298.14 734.758,1298.14 734.767,1298.14 734.776,1298.15 734.785,1298.15 734.794,1298.15 734.803,1298.15 734.813,1298.15 734.822,1298.15 734.831,1298.15 734.84,1298.15 734.849,1298.15 734.859,1298.15 734.868,1298.15 734.877,1298.15 734.886,1298.16 734.895,1298.16 734.905,1298.16 734.914,1298.16 734.923,1298.16 734.932,1298.16 734.941,1298.16 734.95,1298.16 734.96,1298.16 734.969,1298.16 734.978,1298.16 734.987,1298.16 734.996,1298.17 735.006,1298.17 735.015,1298.17 735.024,1298.17 735.033,1298.17 735.042,1298.17 735.052,1298.17 735.061,1298.17 735.07,1298.17 735.079,1298.17 735.088,1298.17 735.098,1298.17 735.107,1298.17 735.116,1298.18 735.125,1298.18 735.134,1298.18 735.143,1298.18 735.153,1298.18 735.162,1298.18 735.171,1298.18 735.18,1298.18 735.189,1298.18 735.199,1298.18 735.208,1298.18 735.217,1298.18 735.226,1298.19 735.235,1298.19 735.245,1298.19 735.254,1298.19 735.263,1298.19 735.272,1298.19 735.281,1298.19 735.29,1298.19 735.3,1298.19 735.309,1298.19 735.318,1298.19 735.327,1298.19 735.336,1298.2 735.346,1298.2 735.355,1298.2 735.364,1298.2 735.373,1298.2 735.382,1298.2 735.392,1298.2 735.401,1298.2 735.41,1298.2 735.419,1298.2 735.428,1298.2 735.438,1298.2 735.447,1298.2 735.456,1298.21 735.465,1298.21 735.474,1298.21 735.483,1298.21 735.493,1298.21 735.502,1298.21 735.511,1298.21 735.52,1298.21 735.529,1298.21 735.539,1298.21 735.548,1298.21 735.557,1298.21 735.566,1298.22 735.575,1298.22 735.585,1298.22 735.594,1298.22 735.603,1298.22 735.612,1298.22 735.621,1298.22 735.63,1298.22 735.64,1298.22 735.649,1298.22 735.658,1298.22 735.667,1298.22 735.676,1298.23 735.686,1298.23 735.695,1298.23 735.704,1298.23 735.713,1298.23 735.722,1298.23 735.732,1298.23 735.741,1298.23 735.75,1298.23 735.759,1298.23 735.768,1298.23 735.778,1298.23 735.787,1298.23 735.796,1298.24 735.805,1298.24 735.814,1298.24 735.823,1298.24 735.833,1298.24 735.842,1298.24 735.851,1298.24 735.86,1298.24 735.869,1298.24 735.879,1298.24 735.888,1298.24 735.897,1298.24 735.906,1298.25 735.915,1298.25 735.925,1298.25 735.934,1298.25 735.943,1298.25 735.952,1298.25 735.961,1298.25 735.971,1298.25 735.98,1298.25 735.989,1298.25 735.998,1298.25 736.007,1298.25 736.016,1298.26 736.026,1298.26 736.035,1298.26 736.044,1298.26 736.053,1298.26 736.062,1298.26 736.072,1298.26 736.081,1298.26 736.09,1298.26 736.099,1298.26 736.108,1298.26 736.118,1298.26 736.127,1298.26 736.136,1298.27 736.145,1298.27 736.154,1298.27 736.163,1298.27 736.173,1298.27 736.182,1298.27 736.191,1298.27 736.2,1298.27 736.209,1298.27 736.219,1298.27 736.228,1298.27 736.237,1298.27 736.246,1298.28 736.255,1298.28 736.265,1298.28 736.274,1298.28 736.283,1298.28 736.292,1298.28 736.301,1298.28 736.311,1298.28 736.32,1298.28 736.329,1298.28 736.338,1298.28 736.347,1298.28 736.356,1298.29 736.366,1298.29 736.375,1298.29 736.384,1298.29 736.393,1298.29 736.402,1298.29 736.412,1298.29 736.421,1298.29 736.43,1298.29 736.439,1298.29 736.448,1298.29 736.458,1298.29 736.467,1298.29 736.476,1298.3 736.485,1298.3 736.494,1298.3 736.503,1298.3 736.513,1298.3 736.522,1298.3 736.531,1298.3 736.54,1298.3 736.549,1298.3 736.559,1298.3 736.568,1298.3 736.577,1298.3 736.586,1298.31 736.595,1298.31 736.605,1298.31 736.614,1298.31 736.623,1298.31 736.632,1298.31 736.641,1298.31 736.651,1298.31 736.66,1298.31 736.669,1298.31 736.678,1298.31 736.687,1298.31 736.696,1298.32 736.706,1298.32 736.715,1298.32 736.724,1298.32 736.733,1298.32 736.742,1298.32 736.752,1298.32 736.761,1298.32 736.77,1298.32 736.779,1298.32 736.788,1298.32 736.798,1298.32 736.807,1298.32 736.816,1298.33 736.825,1298.33 736.834,1298.33 736.843,1298.33 736.853,1298.33 736.862,1298.33 736.871,1298.33 736.88,1298.33 736.889,1298.33 736.899,1298.33 736.908,1298.33 736.917,1298.33 736.926,1298.34 736.935,1298.34 736.945,1298.34 736.954,1298.34 736.963,1298.34 736.972,1298.34 736.981,1298.34 736.991,1298.34 737,1298.34 737.009,1298.34 737.018,1298.34 737.027,1298.34 737.036,1298.35 737.046,1298.35 737.055,1298.35 737.064,1298.35 737.073,1298.35 737.082,1298.35 737.092,1298.35 737.101,1298.35 737.11,1298.35 737.119,1298.35 737.128,1298.35 737.138,1298.35 737.147,1298.35 737.156,1298.36 737.165,1298.36 737.174,1298.36 737.183,1298.36 737.193,1298.36 737.202,1298.36 737.211,1298.36 737.22,1298.36 737.229,1298.36 737.239,1298.36 737.248,1298.36 737.257,1298.36 737.266,1298.37 737.275,1298.37 737.285,1298.37 737.294,1298.37 737.303,1298.37 737.312,1298.37 737.321,1298.37 737.331,1298.37 737.34,1298.37 737.349,1298.37 737.358,1298.37 737.367,1298.37 737.376,1298.38 737.386,1298.38 737.395,1298.38 737.404,1298.38 737.413,1298.38 737.422,1298.38 737.432,1298.38 737.441,1298.38 737.45,1298.38 737.459,1298.38 737.468,1298.38 737.478,1298.38 737.487,1298.38 737.496,1298.39 737.505,1298.39 737.514,1298.39 737.523,1298.39 737.533,1298.39 737.542,1298.39 737.551,1298.39 737.56,1298.39 737.569,1298.39 737.579,1298.39 737.588,1298.39 737.597,1298.39 737.606,1298.4 737.615,1298.4 737.625,1298.4 737.634,1298.4 737.643,1298.4 737.652,1298.4 737.661,1298.4 737.671,1298.4 737.68,1298.4 737.689,1298.4 737.698,1298.4 737.707,1298.4 737.716,1298.41 737.726,1298.41 737.735,1298.41 737.744,1298.41 737.753,1298.41 737.762,1298.41 737.772,1298.41 737.781,1298.41 737.79,1298.41 737.799,1298.41 737.808,1298.41 737.818,1298.41 737.827,1298.41 737.836,1298.42 737.845,1298.42 737.854,1298.42 737.863,1298.42 737.873,1298.42 737.882,1298.42 737.891,1298.42 737.9,1298.42 737.909,1298.42 737.919,1298.42 737.928,1298.42 737.937,1298.42 737.946,1298.43 737.955,1298.43 737.965,1298.43 737.974,1298.43 737.983,1298.43 737.992,1298.43 738.001,1298.43 738.011,1298.43 738.02,1298.43 738.029,1298.43 738.038,1298.43 738.047,1298.43 738.056,1298.44 738.066,1298.44 738.075,1298.44 738.084,1298.44 738.093,1298.44 738.102,1298.44 738.112,1298.44 738.121,1298.44 738.13,1298.44 738.139,1298.44 738.148,1298.44 738.158,1298.44 738.167,1298.44 738.176,1298.45 738.185,1298.45 738.194,1298.45 738.204,1298.45 738.213,1298.45 738.222,1298.45 738.231,1298.45 738.24,1298.45 738.249,1298.45 738.259,1298.45 738.268,1298.45 738.277,1298.45 738.286,1298.46 738.295,1298.46 738.305,1298.46 738.314,1298.46 738.323,1298.46 738.332,1298.46 738.341,1298.46 738.351,1298.46 738.36,1298.46 738.369,1298.46 738.378,1298.46 738.387,1298.46 738.396,1298.47 738.406,1298.47 738.415,1298.47 738.424,1298.47 738.433,1298.47 738.442,1298.47 738.452,1298.47 738.461,1298.47 738.47,1298.47 738.479,1298.47 738.488,1298.47 738.498,1298.47 738.507,1298.47 738.516,1298.48 738.525,1298.48 738.534,1298.48 738.544,1298.48 738.553,1298.48 738.562,1298.48 738.571,1298.48 738.58,1298.48 738.589,1298.48 738.599,1298.48 738.608,1298.48 738.617,1298.48 738.626,1298.49 738.635,1298.49 738.645,1298.49 738.654,1298.49 738.663,1298.49 738.672,1298.49 738.681,1298.49 738.691,1298.49 738.7,1298.49 738.709,1298.49 738.718,1298.49 738.727,1298.49 738.736,1298.5 738.746,1298.5 738.755,1298.5 738.764,1298.5 738.773,1298.5 738.782,1298.5 738.792,1298.5 738.801,1298.5 738.81,1298.5 738.819,1298.5 738.828,1298.5 738.838,1298.5 738.847,1298.5 738.856,1298.51 738.865,1298.51 738.874,1298.51 738.884,1298.51 738.893,1298.51 738.902,1298.51 738.911,1298.51 738.92,1298.51 738.929,1298.51 738.939,1298.51 738.948,1298.51 738.957,1298.51 738.966,1298.52 738.975,1298.52 738.985,1298.52 738.994,1298.52 739.003,1298.52 739.012,1298.52 739.021,1298.52 739.031,1298.52 739.04,1298.52 739.049,1298.52 739.058,1298.52 739.067,1298.52 739.076,1298.53 739.086,1298.53 739.095,1298.53 739.104,1298.53 739.113,1298.53 739.122,1298.53 739.132,1298.53 739.141,1298.53 739.15,1298.53 739.159,1298.53 739.168,1298.53 739.178,1298.53 739.187,1298.53 739.196,1298.54 739.205,1298.54 739.214,1298.54 739.224,1298.54 739.233,1298.54 739.242,1298.54 739.251,1298.54 739.26,1298.54 739.269,1298.54 739.279,1298.54 739.288,1298.54 739.297,1298.54 739.306,1298.55 739.315,1298.55 739.325,1298.55 739.334,1298.55 739.343,1298.55 739.352,1298.55 739.361,1298.55 739.371,1298.55 739.38,1298.55 739.389,1298.55 739.398,1298.55 739.407,1298.55 739.416,1298.56 739.426,1298.56 739.435,1298.56 739.444,1298.56 739.453,1298.56 739.462,1298.56 739.472,1298.56 739.481,1298.56 739.49,1298.56 739.499,1298.56 739.508,1298.56 739.518,1298.56 739.527,1298.56 739.536,1298.57 739.545,1298.57 739.554,1298.57 739.564,1298.57 739.573,1298.57 739.582,1298.57 739.591,1298.57 739.6,1298.57 739.609,1298.57 739.619,1298.57 739.628,1298.57 739.637,1298.57 739.646,1298.58 739.655,1298.58 739.665,1298.58 739.674,1298.58 739.683,1298.58 739.692,1298.58 739.701,1298.58 739.711,1298.58 739.72,1298.58 739.729,1298.58 739.738,1298.58 739.747,1298.58 739.756,1298.59 739.766,1298.59 739.775,1298.59 739.784,1298.59 739.793,1298.59 739.802,1298.59 739.812,1298.59 739.821,1298.59 739.83,1298.59 739.839,1298.59 739.848,1298.59 739.858,1298.59 739.867,1298.59 739.876,1298.6 739.885,1298.6 739.894,1298.6 739.904,1298.6 739.913,1298.6 739.922,1298.6 739.931,1298.6 739.94,1298.6 739.949,1298.6 739.959,1298.6 739.968,1298.6 739.977,1298.6 739.986,1298.61 739.995,1298.61 740.005,1298.61 740.014,1298.61 740.023,1298.61 740.032,1298.61 740.041,1298.61 740.051,1298.61 740.06,1298.61 740.069,1298.61 740.078,1298.61 740.087,1298.61 740.096,1298.61 740.106,1298.62 740.115,1298.62 740.124,1298.62 740.133,1298.62 740.142,1298.62 740.152,1298.62 740.161,1298.62 740.17,1298.62 740.179,1298.62 740.188,1298.62 740.198,1298.62 740.207,1298.62 740.216,1298.63 740.225,1298.63 740.234,1298.63 740.244,1298.63 740.253,1298.63 740.262,1298.63 740.271,1298.63 740.28,1298.63 740.289,1298.63 740.299,1298.63 740.308,1298.63 740.317,1298.63 740.326,1298.64 740.335,1298.64 740.345,1298.64 740.354,1298.64 740.363,1298.64 740.372,1298.64 740.381,1298.64 740.391,1298.64 740.4,1298.64 740.409,1298.64 740.418,1298.64 740.427,1298.64 740.436,1298.64 740.446,1298.65 740.455,1298.65 740.464,1298.65 740.473,1298.65 740.482,1298.65 740.492,1298.65 740.501,1298.65 740.51,1298.65 740.519,1298.65 740.528,1298.65 740.538,1298.65 740.547,1298.65 740.556,1298.66 740.565,1298.66 740.574,1298.66 740.584,1298.66 740.593,1298.66 740.602,1298.66 740.611,1298.66 740.62,1298.66 740.629,1298.66 740.639,1298.66 740.648,1298.66 740.657,1298.66 740.666,1298.67 740.675,1298.67 740.685,1298.67 740.694,1298.67 740.703,1298.67 740.712,1298.67 740.721,1298.67 740.731,1298.67 740.74,1298.67 740.749,1298.67 740.758,1298.67 740.767,1298.67 740.777,1298.67 740.786,1298.68 740.795,1298.68 740.804,1298.68 740.813,1298.68 740.822,1298.68 740.832,1298.68 740.841,1298.68 740.85,1298.68 740.859,1298.68 740.868,1298.68 740.878,1298.68 740.887,1298.68 740.896,1298.69 740.905,1298.69 740.914,1298.69 740.924,1298.69 740.933,1298.69 740.942,1298.69 740.951,1298.69 740.96,1298.69 740.969,1298.69 740.979,1298.69 740.988,1298.69 740.997,1298.69 741.006,1298.7 741.015,1298.7 741.025,1298.7 741.034,1298.7 741.043,1298.7 741.052,1298.7 741.061,1298.7 741.071,1298.7 741.08,1298.7 741.089,1298.7 741.098,1298.7 741.107,1298.7 741.117,1298.7 741.126,1298.71 741.135,1298.71 741.144,1298.71 741.153,1298.71 741.162,1298.71 741.172,1298.71 741.181,1298.71 741.19,1298.71 741.199,1298.71 741.208,1298.71 741.218,1298.71 741.227,1298.71 741.236,1298.72 741.245,1298.72 741.254,1298.72 741.264,1298.72 741.273,1298.72 741.282,1298.72 741.291,1298.72 741.3,1298.72 741.309,1298.72 741.319,1298.72 741.328,1298.72 741.337,1298.72 741.346,1298.72 741.355,1298.73 741.365,1298.73 741.374,1298.73 741.383,1298.73 741.392,1298.73 741.401,1298.73 741.411,1298.73 741.42,1298.73 741.429,1298.73 741.438,1298.73 741.447,1298.73 741.457,1298.73 741.466,1298.74 741.475,1298.74 741.484,1298.74 741.493,1298.74 741.502,1298.74 741.512,1298.74 741.521,1298.74 741.53,1298.74 741.539,1298.74 741.548,1298.74 741.558,1298.74 741.567,1298.74 741.576,1298.75 741.585,1298.75 741.594,1298.75 741.604,1298.75 741.613,1298.75 741.622,1298.75 741.631,1298.75 741.64,1298.75 741.649,1298.75 741.659,1298.75 741.668,1298.75 741.677,1298.75 741.686,1298.75 741.695,1298.76 741.705,1298.76 741.714,1298.76 741.723,1298.76 741.732,1298.76 741.741,1298.76 741.751,1298.76 741.76,1298.76 741.769,1298.76 741.778,1298.76 741.787,1298.76 741.797,1298.76 741.806,1298.77 741.815,1298.77 741.824,1298.77 741.833,1298.77 741.842,1298.77 741.852,1298.77 741.861,1298.77 741.87,1298.77 741.879,1298.77 741.888,1298.77 741.898,1298.77 741.907,1298.77 741.916,1298.78 741.925,1298.78 741.934,1298.78 741.944,1298.78 741.953,1298.78 741.962,1298.78 741.971,1298.78 741.98,1298.78 741.989,1298.78 741.999,1298.78 742.008,1298.78 742.017,1298.78 742.026,1298.78 742.035,1298.79 742.045,1298.79 742.054,1298.79 742.063,1298.79 742.072,1298.79 742.081,1298.79 742.091,1298.79 742.1,1298.79 742.109,1298.79 742.118,1298.79 742.127,1298.79 742.137,1298.79 742.146,1298.8 742.155,1298.8 742.164,1298.8 742.173,1298.8 742.182,1298.8 742.192,1298.8 742.201,1298.8 742.21,1298.8 742.219,1298.8 742.228,1298.8 742.238,1298.8 742.247,1298.8 742.256,1298.8 742.265,1298.81 742.274,1298.81 742.284,1298.81 742.293,1298.81 742.302,1298.81 742.311,1298.81 742.32,1298.81 742.329,1298.81 742.339,1298.81 742.348,1298.81 742.357,1298.81 742.366,1298.81 742.375,1298.82 742.385,1298.82 742.394,1298.82 742.403,1298.82 742.412,1298.82 742.421,1298.82 742.431,1298.82 742.44,1298.82 742.449,1298.82 742.458,1298.82 742.467,1298.82 742.477,1298.82 742.486,1298.83 742.495,1298.83 742.504,1298.83 742.513,1298.83 742.522,1298.83 742.532,1298.83 742.541,1298.83 742.55,1298.83 742.559,1298.83 742.568,1298.83 742.578,1298.83 742.587,1298.83 742.596,1298.83 742.605,1298.84 742.614,1298.84 742.624,1298.84 742.633,1298.84 742.642,1298.84 742.651,1298.84 742.66,1298.84 742.669,1298.84 742.679,1298.84 742.688,1298.84 742.697,1298.84 742.706,1298.84 742.715,1298.85 742.725,1298.85 742.734,1298.85 742.743,1298.85 742.752,1298.85 742.761,1298.85 742.771,1298.85 742.78,1298.85 742.789,1298.85 742.798,1298.85 742.807,1298.85 742.817,1298.85 742.826,1298.86 742.835,1298.86 742.844,1298.86 742.853,1298.86 742.862,1298.86 742.872,1298.86 742.881,1298.86 742.89,1298.86 742.899,1298.86 742.908,1298.86 742.918,1298.86 742.927,1298.86 742.936,1298.86 742.945,1298.87 742.954,1298.87 742.964,1298.87 742.973,1298.87 742.982,1298.87 742.991,1298.87 743,1298.87 743.009,1298.87 743.019,1298.87 743.028,1298.87 743.037,1298.87 743.046,1298.87 743.055,1298.88 743.065,1298.88 743.074,1298.88 743.083,1298.88 743.092,1298.88 743.101,1298.88 743.111,1298.88 743.12,1298.88 743.129,1298.88 743.138,1298.88 743.147,1298.88 743.157,1298.88 743.166,1298.88 743.175,1298.89 743.184,1298.89 743.193,1298.89 743.202,1298.89 743.212,1298.89 743.221,1298.89 743.23,1298.89 743.239,1298.89 743.248,1298.89 743.258,1298.89 743.267,1298.89 743.276,1298.89 743.285,1298.9 743.294,1298.9 743.304,1298.9 743.313,1298.9 743.322,1298.9 743.331,1298.9 743.34,1298.9 743.35,1298.9 743.359,1298.9 743.368,1298.9 743.377,1298.9 743.386,1298.9 743.395,1298.91 743.405,1298.91 743.414,1298.91 743.423,1298.91 743.432,1298.91 743.441,1298.91 743.451,1298.91 743.46,1298.91 743.469,1298.91 743.478,1298.91 743.487,1298.91 743.497,1298.91 743.506,1298.91 743.515,1298.92 743.524,1298.92 743.533,1298.92 743.542,1298.92 743.552,1298.92 743.561,1298.92 743.57,1298.92 743.579,1298.92 743.588,1298.92 743.598,1298.92 743.607,1298.92 743.616,1298.92 743.625,1298.93 743.634,1298.93 743.644,1298.93 743.653,1298.93 743.662,1298.93 743.671,1298.93 743.68,1298.93 743.69,1298.93 743.699,1298.93 743.708,1298.93 743.717,1298.93 743.726,1298.93 743.735,1298.93 743.745,1298.94 743.754,1298.94 743.763,1298.94 743.772,1298.94 743.781,1298.94 743.791,1298.94 743.8,1298.94 743.809,1298.94 743.818,1298.94 743.827,1298.94 743.837,1298.94 743.846,1298.94 743.855,1298.95 743.864,1298.95 743.873,1298.95 743.882,1298.95 743.892,1298.95 743.901,1298.95 743.91,1298.95 743.919,1298.95 743.928,1298.95 743.938,1298.95 743.947,1298.95 743.956,1298.95 743.965,1298.96 743.974,1298.96 743.984,1298.96 743.993,1298.96 744.002,1298.96 744.011,1298.96 744.02,1298.96 744.03,1298.96 744.039,1298.96 744.048,1298.96 744.057,1298.96 744.066,1298.96 744.075,1298.96 744.085,1298.97 744.094,1298.97 744.103,1298.97 744.112,1298.97 744.121,1298.97 744.131,1298.97 744.14,1298.97 744.149,1298.97 744.158,1298.97 744.167,1298.97 744.177,1298.97 744.186,1298.97 744.195,1298.98 744.204,1298.98 744.213,1298.98 744.222,1298.98 744.232,1298.98 744.241,1298.98 744.25,1298.98 744.259,1298.98 744.268,1298.98 744.278,1298.98 744.287,1298.98 744.296,1298.98 744.305,1298.98 744.314,1298.99 744.324,1298.99 744.333,1298.99 744.342,1298.99 744.351,1298.99 744.36,1298.99 744.37,1298.99 744.379,1298.99 744.388,1298.99 744.397,1298.99 744.406,1298.99 744.415,1298.99 744.425,1299 744.434,1299 744.443,1299 744.452,1299 744.461,1299 744.471,1299 744.48,1299 744.489,1299 744.498,1299 744.507,1299 744.517,1299 744.526,1299 744.535,1299.01 744.544,1299.01 744.553,1299.01 744.562,1299.01 744.572,1299.01 744.581,1299.01 744.59,1299.01 744.599,1299.01 744.608,1299.01 744.618,1299.01 744.627,1299.01 744.636,1299.01 744.645,1299.01 744.654,1299.02 744.664,1299.02 744.673,1299.02 744.682,1299.02 744.691,1299.02 744.7,1299.02 744.71,1299.02 744.719,1299.02 744.728,1299.02 744.737,1299.02 744.746,1299.02 744.755,1299.02 744.765,1299.03 744.774,1299.03 744.783,1299.03 744.792,1299.03 744.801,1299.03 744.811,1299.03 744.82,1299.03 744.829,1299.03 744.838,1299.03 744.847,1299.03 744.857,1299.03 744.866,1299.03 744.875,1299.03 744.884,1299.04 744.893,1299.04 744.902,1299.04 744.912,1299.04 744.921,1299.04 744.93,1299.04 744.939,1299.04 744.948,1299.04 744.958,1299.04 744.967,1299.04 744.976,1299.04 744.985,1299.04 744.994,1299.05 745.004,1299.05 745.013,1299.05 745.022,1299.05 745.031,1299.05 745.04,1299.05 745.05,1299.05 745.059,1299.05 745.068,1299.05 745.077,1299.05 745.086,1299.05 745.095,1299.05 745.105,1299.06 745.114,1299.06 745.123,1299.06 745.132,1299.06 745.141,1299.06 745.151,1299.06 745.16,1299.06 745.169,1299.06 745.178,1299.06 745.187,1299.06 745.197,1299.06 745.206,1299.06 745.215,1299.06 745.224,1299.07 745.233,1299.07 745.242,1299.07 745.252,1299.07 745.261,1299.07 745.27,1299.07 745.279,1299.07 745.288,1299.07 745.298,1299.07 745.307,1299.07 745.316,1299.07 745.325,1299.07 745.334,1299.08 745.344,1299.08 745.353,1299.08 745.362,1299.08 745.371,1299.08 745.38,1299.08 745.39,1299.08 745.399,1299.08 745.408,1299.08 745.417,1299.08 745.426,1299.08 745.435,1299.08 745.445,1299.08 745.454,1299.09 745.463,1299.09 745.472,1299.09 745.481,1299.09 745.491,1299.09 745.5,1299.09 745.509,1299.09 745.518,1299.09 745.527,1299.09 745.537,1299.09 745.546,1299.09 745.555,1299.09 745.564,1299.1 745.573,1299.1 745.583,1299.1 745.592,1299.1 745.601,1299.1 745.61,1299.1 745.619,1299.1 745.628,1299.1 745.638,1299.1 745.647,1299.1 745.656,1299.1 745.665,1299.1 745.674,1299.1 745.684,1299.11 745.693,1299.11 745.702,1299.11 745.711,1299.11 745.72,1299.11 745.73,1299.11 745.739,1299.11 745.748,1299.11 745.757,1299.11 745.766,1299.11 745.775,1299.11 745.785,1299.11 745.794,1299.12 745.803,1299.12 745.812,1299.12 745.821,1299.12 745.831,1299.12 745.84,1299.12 745.849,1299.12 745.858,1299.12 745.867,1299.12 745.877,1299.12 745.886,1299.12 745.895,1299.12 745.904,1299.13 745.913,1299.13 745.923,1299.13 745.932,1299.13 745.941,1299.13 745.95,1299.13 745.959,1299.13 745.968,1299.13 745.978,1299.13 745.987,1299.13 745.996,1299.13 746.005,1299.13 746.014,1299.13 746.024,1299.14 746.033,1299.14 746.042,1299.14 746.051,1299.14 746.06,1299.14 746.07,1299.14 746.079,1299.14 746.088,1299.14 746.097,1299.14 746.106,1299.14 746.115,1299.14 746.125,1299.14 746.134,1299.15 746.143,1299.15 746.152,1299.15 746.161,1299.15 746.171,1299.15 746.18,1299.15 746.189,1299.15 746.198,1299.15 746.207,1299.15 746.217,1299.15 746.226,1299.15 746.235,1299.15 746.244,1299.15 746.253,1299.16 746.263,1299.16 746.272,1299.16 746.281,1299.16 746.29,1299.16 746.299,1299.16 746.308,1299.16 746.318,1299.16 746.327,1299.16 746.336,1299.16 746.345,1299.16 746.354,1299.16 746.364,1299.17 746.373,1299.17 746.382,1299.17 746.391,1299.17 746.4,1299.17 746.41,1299.17 746.419,1299.17 746.428,1299.17 746.437,1299.17 746.446,1299.17 746.455,1299.17 746.465,1299.17 746.474,1299.18 746.483,1299.18 746.492,1299.18 746.501,1299.18 746.511,1299.18 746.52,1299.18 746.529,1299.18 746.538,1299.18 746.547,1299.18 746.557,1299.18 746.566,1299.18 746.575,1299.18 746.584,1299.18 746.593,1299.19 746.603,1299.19 746.612,1299.19 746.621,1299.19 746.63,1299.19 746.639,1299.19 746.648,1299.19 746.658,1299.19 746.667,1299.19 746.676,1299.19 746.685,1299.19 746.694,1299.19 746.704,1299.2 746.713,1299.2 746.722,1299.2 746.731,1299.2 746.74,1299.2 746.75,1299.2 746.759,1299.2 746.768,1299.2 746.777,1299.2 746.786,1299.2 746.795,1299.2 746.805,1299.2 746.814,1299.2 746.823,1299.21 746.832,1299.21 746.841,1299.21 746.851,1299.21 746.86,1299.21 746.869,1299.21 746.878,1299.21 746.887,1299.21 746.897,1299.21 746.906,1299.21 746.915,1299.21 746.924,1299.21 746.933,1299.22 746.943,1299.22 746.952,1299.22 746.961,1299.22 746.97,1299.22 746.979,1299.22 746.988,1299.22 746.998,1299.22 747.007,1299.22 747.016,1299.22 747.025,1299.22 747.034,1299.22 747.044,1299.22 747.053,1299.23 747.062,1299.23 747.071,1299.23 747.08,1299.23 747.09,1299.23 747.099,1299.23 747.108,1299.23 747.117,1299.23 747.126,1299.23 747.135,1299.23 747.145,1299.23 747.154,1299.23 747.163,1299.24 747.172,1299.24 747.181,1299.24 747.191,1299.24 747.2,1299.24 747.209,1299.24 747.218,1299.24 747.227,1299.24 747.237,1299.24 747.246,1299.24 747.255,1299.24 747.264,1299.24 747.273,1299.25 747.283,1299.25 747.292,1299.25 747.301,1299.25 747.31,1299.25 747.319,1299.25 747.328,1299.25 747.338,1299.25 747.347,1299.25 747.356,1299.25 747.365,1299.25 747.374,1299.25 747.384,1299.25 747.393,1299.26 747.402,1299.26 747.411,1299.26 747.42,1299.26 747.43,1299.26 747.439,1299.26 747.448,1299.26 747.457,1299.26 747.466,1299.26 747.475,1299.26 747.485,1299.26 747.494,1299.26 747.503,1299.27 747.512,1299.27 747.521,1299.27 747.531,1299.27 747.54,1299.27 747.549,1299.27 747.558,1299.27 747.567,1299.27 747.577,1299.27 747.586,1299.27 747.595,1299.27 747.604,1299.27 747.613,1299.27 747.623,1299.28 747.632,1299.28 747.641,1299.28 747.65,1299.28 747.659,1299.28 747.668,1299.28 747.678,1299.28 747.687,1299.28 747.696,1299.28 747.705,1299.28 747.714,1299.28 747.724,1299.28 747.733,1299.29 747.742,1299.29 747.751,1299.29 747.76,1299.29 747.77,1299.29 747.779,1299.29 747.788,1299.29 747.797,1299.29 747.806,1299.29 747.815,1299.29 747.825,1299.29 747.834,1299.29 747.843,1299.29 747.852,1299.3 747.861,1299.3 747.871,1299.3 747.88,1299.3 747.889,1299.3 747.898,1299.3 747.907,1299.3 747.917,1299.3 747.926,1299.3 747.935,1299.3 747.944,1299.3 747.953,1299.3 747.963,1299.31 747.972,1299.31 747.981,1299.31 747.99,1299.31 747.999,1299.31 748.008,1299.31 748.018,1299.31 748.027,1299.31 748.036,1299.31 748.045,1299.31 748.054,1299.31 748.064,1299.31 748.073,1299.31 748.082,1299.32 748.091,1299.32 748.1,1299.32 748.11,1299.32 748.119,1299.32 748.128,1299.32 748.137,1299.32 748.146,1299.32 748.156,1299.32 748.165,1299.32 748.174,1299.32 748.183,1299.32 748.192,1299.33 748.201,1299.33 748.211,1299.33 748.22,1299.33 748.229,1299.33 748.238,1299.33 748.247,1299.33 748.257,1299.33 748.266,1299.33 748.275,1299.33 748.284,1299.33 748.293,1299.33 748.303,1299.34 748.312,1299.34 748.321,1299.34 748.33,1299.34 748.339,1299.34 748.348,1299.34 748.358,1299.34 748.367,1299.34 748.376,1299.34 748.385,1299.34 748.394,1299.34 748.404,1299.34 748.413,1299.34 748.422,1299.35 748.431,1299.35 748.44,1299.35 748.45,1299.35 748.459,1299.35 748.468,1299.35 748.477,1299.35 748.486,1299.35 748.496,1299.35 748.505,1299.35 748.514,1299.35 748.523,1299.35 748.532,1299.36 748.541,1299.36 748.551,1299.36 748.56,1299.36 748.569,1299.36 748.578,1299.36 748.587,1299.36 748.597,1299.36 748.606,1299.36 748.615,1299.36 748.624,1299.36 748.633,1299.36 748.643,1299.36 748.652,1299.37 748.661,1299.37 748.67,1299.37 748.679,1299.37 748.688,1299.37 748.698,1299.37 748.707,1299.37 748.716,1299.37 748.725,1299.37 748.734,1299.37 748.744,1299.37 748.753,1299.37 748.762,1299.38 748.771,1299.38 748.78,1299.38 748.79,1299.38 748.799,1299.38 748.808,1299.38 748.817,1299.38 748.826,1299.38 748.836,1299.38 748.845,1299.38 748.854,1299.38 748.863,1299.38 748.872,1299.38 748.881,1299.39 748.891,1299.39 748.9,1299.39 748.909,1299.39 748.918,1299.39 748.927,1299.39 748.937,1299.39 748.946,1299.39 748.955,1299.39 748.964,1299.39 748.973,1299.39 748.983,1299.39 748.992,1299.4 749.001,1299.4 749.01,1299.4 749.019,1299.4 749.028,1299.4 749.038,1299.4 749.047,1299.4 749.056,1299.4 749.065,1299.4 749.074,1299.4 749.084,1299.4 749.093,1299.4 749.102,1299.4 749.111,1299.41 749.12,1299.41 749.13,1299.41 749.139,1299.41 749.148,1299.41 749.157,1299.41 749.166,1299.41 749.176,1299.41 749.185,1299.41 749.194,1299.41 749.203,1299.41 749.212,1299.41 749.221,1299.42 749.231,1299.42 749.24,1299.42 749.249,1299.42 749.258,1299.42 749.267,1299.42 749.277,1299.42 749.286,1299.42 749.295,1299.42 749.304,1299.42 749.313,1299.42 749.323,1299.42 749.332,1299.43 749.341,1299.43 749.35,1299.43 749.359,1299.43 749.368,1299.43 749.378,1299.43 749.387,1299.43 749.396,1299.43 749.405,1299.43 749.414,1299.43 749.424,1299.43 749.433,1299.43 749.442,1299.43 749.451,1299.44 749.46,1299.44 749.47,1299.44 749.479,1299.44 749.488,1299.44 749.497,1299.44 749.506,1299.44 749.516,1299.44 749.525,1299.44 749.534,1299.44 749.543,1299.44 749.552,1299.44 749.561,1299.45 749.571,1299.45 749.58,1299.45 749.589,1299.45 749.598,1299.45 749.607,1299.45 749.617,1299.45 749.626,1299.45 749.635,1299.45 749.644,1299.45 749.653,1299.45 749.663,1299.45 749.672,1299.45 749.681,1299.46 749.69,1299.46 749.699,1299.46 749.708,1299.46 749.718,1299.46 749.727,1299.46 749.736,1299.46 749.745,1299.46 749.754,1299.46 749.764,1299.46 749.773,1299.46 749.782,1299.46 749.791,1299.47 749.8,1299.47 749.81,1299.47 749.819,1299.47 749.828,1299.47 749.837,1299.47 749.846,1299.47 749.856,1299.47 749.865,1299.47 749.874,1299.47 749.883,1299.47 749.892,1299.47 749.901,1299.47 749.911,1299.48 749.92,1299.48 749.929,1299.48 749.938,1299.48 749.947,1299.48 749.957,1299.48 749.966,1299.48 749.975,1299.48 749.984,1299.48 749.993,1299.48 750.003,1299.48 750.012,1299.48 750.021,1299.49 750.03,1299.49 750.039,1299.49 750.048,1299.49 750.058,1299.49 750.067,1299.49 750.076,1299.49 750.085,1299.49 750.094,1299.49 750.104,1299.49 750.113,1299.49 750.122,1299.49 750.131,1299.49 750.14,1299.5 750.15,1299.5 750.159,1299.5 750.168,1299.5 750.177,1299.5 750.186,1299.5 750.196,1299.5 750.205,1299.5 750.214,1299.5 750.223,1299.5 750.232,1299.5 750.241,1299.5 750.251,1299.51 750.26,1299.51 750.269,1299.51 750.278,1299.51 750.287,1299.51 750.297,1299.51 750.306,1299.51 750.315,1299.51 750.324,1299.51 750.333,1299.51 750.343,1299.51 750.352,1299.51 750.361,1299.51 750.37,1299.52 750.379,1299.52 750.388,1299.52 750.398,1299.52 750.407,1299.52 750.416,1299.52 750.425,1299.52 750.434,1299.52 750.444,1299.52 750.453,1299.52 750.462,1299.52 750.471,1299.52 750.48,1299.53 750.49,1299.53 750.499,1299.53 750.508,1299.53 750.517,1299.53 750.526,1299.53 750.536,1299.53 750.545,1299.53 750.554,1299.53 750.563,1299.53 750.572,1299.53 750.581,1299.53 750.591,1299.53 750.6,1299.54 750.609,1299.54 750.618,1299.54 750.627,1299.54 750.637,1299.54 750.646,1299.54 750.655,1299.54 750.664,1299.54 750.673,1299.54 750.683,1299.54 750.692,1299.54 750.701,1299.54 750.71,1299.55 750.719,1299.55 750.729,1299.55 750.738,1299.55 750.747,1299.55 750.756,1299.55 750.765,1299.55 750.774,1299.55 750.784,1299.55 750.793,1299.55 750.802,1299.55 750.811,1299.55 750.82,1299.56 750.83,1299.56 750.839,1299.56 750.848,1299.56 750.857,1299.56 750.866,1299.56 750.876,1299.56 750.885,1299.56 750.894,1299.56 750.903,1299.56 750.912,1299.56 750.921,1299.56 750.931,1299.56 750.94,1299.57 750.949,1299.57 750.958,1299.57 750.967,1299.57 750.977,1299.57 750.986,1299.57 750.995,1299.57 751.004,1299.57 751.013,1299.57 751.023,1299.57 751.032,1299.57 751.041,1299.57 751.05,1299.58 751.059,1299.58 751.069,1299.58 751.078,1299.58 751.087,1299.58 751.096,1299.58 751.105,1299.58 751.114,1299.58 751.124,1299.58 751.133,1299.58 751.142,1299.58 751.151,1299.58 751.16,1299.58 751.17,1299.59 751.179,1299.59 751.188,1299.59 751.197,1299.59 751.206,1299.59 751.216,1299.59 751.225,1299.59 751.234,1299.59 751.243,1299.59 751.252,1299.59 751.261,1299.59 751.271,1299.59 751.28,1299.6 751.289,1299.6 751.298,1299.6 751.307,1299.6 751.317,1299.6 751.326,1299.6 751.335,1299.6 751.344,1299.6 751.353,1299.6 751.363,1299.6 751.372,1299.6 751.381,1299.6 751.39,1299.6 751.399,1299.61 751.409,1299.61 751.418,1299.61 751.427,1299.61 751.436,1299.61 751.445,1299.61 751.454,1299.61 751.464,1299.61 751.473,1299.61 751.482,1299.61 751.491,1299.61 751.5,1299.61 751.51,1299.62 751.519,1299.62 751.528,1299.62 751.537,1299.62 751.546,1299.62 751.556,1299.62 751.565,1299.62 751.574,1299.62 751.583,1299.62 751.592,1299.62 751.601,1299.62 751.611,1299.62 751.62,1299.62 751.629,1299.63 751.638,1299.63 751.647,1299.63 751.657,1299.63 751.666,1299.63 751.675,1299.63 751.684,1299.63 751.693,1299.63 751.703,1299.63 751.712,1299.63 751.721,1299.63 751.73,1299.63 751.739,1299.64 751.749,1299.64 751.758,1299.64 751.767,1299.64 751.776,1299.64 751.785,1299.64 751.794,1299.64 751.804,1299.64 751.813,1299.64 751.822,1299.64 751.831,1299.64 751.84,1299.64 751.85,1299.64 751.859,1299.65 751.868,1299.65 751.877,1299.65 751.886,1299.65 751.896,1299.65 751.905,1299.65 751.914,1299.65 751.923,1299.65 751.932,1299.65 751.941,1299.65 751.951,1299.65 751.96,1299.65 751.969,1299.66 751.978,1299.66 751.987,1299.66 751.997,1299.66 752.006,1299.66 752.015,1299.66 752.024,1299.66 752.033,1299.66 752.043,1299.66 752.052,1299.66 752.061,1299.66 752.07,1299.66 752.079,1299.66 752.089,1299.67 752.098,1299.67 752.107,1299.67 752.116,1299.67 752.125,1299.67 752.134,1299.67 752.144,1299.67 752.153,1299.67 752.162,1299.67 752.171,1299.67 752.18,1299.67 752.19,1299.67 752.199,1299.68 752.208,1299.68 752.217,1299.68 752.226,1299.68 752.236,1299.68 752.245,1299.68 752.254,1299.68 752.263,1299.68 752.272,1299.68 752.281,1299.68 752.291,1299.68 752.3,1299.68 752.309,1299.68 752.318,1299.69 752.327,1299.69 752.337,1299.69 752.346,1299.69 752.355,1299.69 752.364,1299.69 752.373,1299.69 752.383,1299.69 752.392,1299.69 752.401,1299.69 752.41,1299.69 752.419,1299.69 752.429,1299.7 752.438,1299.7 752.447,1299.7 752.456,1299.7 752.465,1299.7 752.474,1299.7 752.484,1299.7 752.493,1299.7 752.502,1299.7 752.511,1299.7 752.52,1299.7 752.53,1299.7 752.539,1299.7 752.548,1299.71 752.557,1299.71 752.566,1299.71 752.576,1299.71 752.585,1299.71 752.594,1299.71 752.603,1299.71 752.612,1299.71 752.621,1299.71 752.631,1299.71 752.64,1299.71 752.649,1299.71 752.658,1299.72 752.667,1299.72 752.677,1299.72 752.686,1299.72 752.695,1299.72 752.704,1299.72 752.713,1299.72 752.723,1299.72 752.732,1299.72 752.741,1299.72 752.75,1299.72 752.759,1299.72 752.769,1299.72 752.778,1299.73 752.787,1299.73 752.796,1299.73 752.805,1299.73 752.814,1299.73 752.824,1299.73 752.833,1299.73 752.842,1299.73 752.851,1299.73 752.86,1299.73 752.87,1299.73 752.879,1299.73 752.888,1299.74 752.897,1299.74 752.906,1299.74 752.916,1299.74 752.925,1299.74 752.934,1299.74 752.943,1299.74 752.952,1299.74 752.962,1299.74 752.971,1299.74 752.98,1299.74 752.989,1299.74 752.998,1299.74 753.007,1299.75 753.017,1299.75 753.026,1299.75 753.035,1299.75 753.044,1299.75 753.053,1299.75 753.063,1299.75 753.072,1299.75 753.081,1299.75 753.09,1299.75 753.099,1299.75 753.109,1299.75 753.118,1299.76 753.127,1299.76 753.136,1299.76 753.145,1299.76 753.154,1299.76 753.164,1299.76 753.173,1299.76 753.182,1299.76 753.191,1299.76 753.2,1299.76 753.21,1299.76 753.219,1299.76 753.228,1299.76 753.237,1299.77 753.246,1299.77 753.256,1299.77 753.265,1299.77 753.274,1299.77 753.283,1299.77 753.292,1299.77 753.302,1299.77 753.311,1299.77 753.32,1299.77 753.329,1299.77 753.338,1299.77 753.347,1299.78 753.357,1299.78 753.366,1299.78 753.375,1299.78 753.384,1299.78 753.393,1299.78 753.403,1299.78 753.412,1299.78 753.421,1299.78 753.43,1299.78 753.439,1299.78 753.449,1299.78 753.458,1299.78 753.467,1299.79 753.476,1299.79 753.485,1299.79 753.494,1299.79 753.504,1299.79 753.513,1299.79 753.522,1299.79 753.531,1299.79 753.54,1299.79 753.55,1299.79 753.559,1299.79 753.568,1299.79 753.577,1299.8 753.586,1299.8 753.596,1299.8 753.605,1299.8 753.614,1299.8 753.623,1299.8 753.632,1299.8 753.642,1299.8 753.651,1299.8 753.66,1299.8 753.669,1299.8 753.678,1299.8 753.687,1299.8 753.697,1299.81 753.706,1299.81 753.715,1299.81 753.724,1299.81 753.733,1299.81 753.743,1299.81 753.752,1299.81 753.761,1299.81 753.77,1299.81 753.779,1299.81 753.789,1299.81 753.798,1299.81 753.807,1299.82 753.816,1299.82 753.825,1299.82 753.834,1299.82 753.844,1299.82 753.853,1299.82 753.862,1299.82 753.871,1299.82 753.88,1299.82 753.89,1299.82 753.899,1299.82 753.908,1299.82 753.917,1299.82 753.926,1299.83 753.936,1299.83 753.945,1299.83 753.954,1299.83 753.963,1299.83 753.972,1299.83 753.982,1299.83 753.991,1299.83 754,1299.83 754.009,1299.83 754.018,1299.83 754.027,1299.83 754.037,1299.84 754.046,1299.84 754.055,1299.84 754.064,1299.84 754.073,1299.84 754.083,1299.84 754.092,1299.84 754.101,1299.84 754.11,1299.84 754.119,1299.84 754.129,1299.84 754.138,1299.84 754.147,1299.84 754.156,1299.85 754.165,1299.85 754.174,1299.85 754.184,1299.85 754.193,1299.85 754.202,1299.85 754.211,1299.85 754.22,1299.85 754.23,1299.85 754.239,1299.85 754.248,1299.85 754.257,1299.85 754.266,1299.86 754.276,1299.86 754.285,1299.86 754.294,1299.86 754.303,1299.86 754.312,1299.86 754.322,1299.86 754.331,1299.86 754.34,1299.86 754.349,1299.86 754.358,1299.86 754.367,1299.86 754.377,1299.86 754.386,1299.87 754.395,1299.87 754.404,1299.87 754.413,1299.87 754.423,1299.87 754.432,1299.87 754.441,1299.87 754.45,1299.87 754.459,1299.87 754.469,1299.87 754.478,1299.87 754.487,1299.87 754.496,1299.88 754.505,1299.88 754.514,1299.88 754.524,1299.88 754.533,1299.88 754.542,1299.88 754.551,1299.88 754.56,1299.88 754.57,1299.88 754.579,1299.88 754.588,1299.88 754.597,1299.88 754.606,1299.88 754.616,1299.89 754.625,1299.89 754.634,1299.89 754.643,1299.89 754.652,1299.89 754.662,1299.89 754.671,1299.89 754.68,1299.89 754.689,1299.89 754.698,1299.89 754.707,1299.89 754.717,1299.89 754.726,1299.9 754.735,1299.9 754.744,1299.9 754.753,1299.9 754.763,1299.9 754.772,1299.9 754.781,1299.9 754.79,1299.9 754.799,1299.9 754.809,1299.9 754.818,1299.9 754.827,1299.9 754.836,1299.9 754.845,1299.91 754.854,1299.91 754.864,1299.91 754.873,1299.91 754.882,1299.91 754.891,1299.91 754.9,1299.91 754.91,1299.91 754.919,1299.91 754.928,1299.91 754.937,1299.91 754.946,1299.91 754.956,1299.92 754.965,1299.92 754.974,1299.92 754.983,1299.92 754.992,1299.92 755.002,1299.92 755.011,1299.92 755.02,1299.92 755.029,1299.92 755.038,1299.92 755.047,1299.92 755.057,1299.92 755.066,1299.92 755.075,1299.93 755.084,1299.93 755.093,1299.93 755.103,1299.93 755.112,1299.93 755.121,1299.93 755.13,1299.93 755.139,1299.93 755.149,1299.93 755.158,1299.93 755.167,1299.93 755.176,1299.93 755.185,1299.94 755.194,1299.94 755.204,1299.94 755.213,1299.94 755.222,1299.94 755.231,1299.94 755.24,1299.94 755.25,1299.94 755.259,1299.94 755.268,1299.94 755.277,1299.94 755.286,1299.94 755.296,1299.94 755.305,1299.95 755.314,1299.95 755.323,1299.95 755.332,1299.95 755.342,1299.95 755.351,1299.95 755.36,1299.95 755.369,1299.95 755.378,1299.95 755.387,1299.95 755.397,1299.95 755.406,1299.95 755.415,1299.96 755.424,1299.96 755.433,1299.96 755.443,1299.96 755.452,1299.96 755.461,1299.96 755.47,1299.96 755.479,1299.96 755.489,1299.96 755.498,1299.96 755.507,1299.96 755.516,1299.96 755.525,1299.96 755.535,1299.97 755.544,1299.97 755.553,1299.97 755.562,1299.97 755.571,1299.97 755.58,1299.97 755.59,1299.97 755.599,1299.97 755.608,1299.97 755.617,1299.97 755.626,1299.97 755.636,1299.97 755.645,1299.98 755.654,1299.98 755.663,1299.98 755.672,1299.98 755.682,1299.98 755.691,1299.98 755.7,1299.98 755.709,1299.98 755.718,1299.98 755.727,1299.98 755.737,1299.98 755.746,1299.98 755.755,1299.98 755.764,1299.99 755.773,1299.99 755.783,1299.99 755.792,1299.99 755.801,1299.99 755.81,1299.99 755.819,1299.99 755.829,1299.99 755.838,1299.99 755.847,1299.99 755.856,1299.99 755.865,1299.99 755.875,1300 755.884,1300 755.893,1300 755.902,1300 755.911,1300 755.92,1300 755.93,1300 755.939,1300 755.948,1300 755.957,1300 755.966,1300 755.976,1300 755.985,1300 755.994,1300.01 756.003,1300.01 756.012,1300.01 756.022,1300.01 756.031,1300.01 756.04,1300.01 756.049,1300.01 756.058,1300.01 756.067,1300.01 756.077,1300.01 756.086,1300.01 756.095,1300.01 756.104,1300.02 756.113,1300.02 756.123,1300.02 756.132,1300.02 756.141,1300.02 756.15,1300.02 756.159,1300.02 756.169,1300.02 756.178,1300.02 756.187,1300.02 756.196,1300.02 756.205,1300.02 756.215,1300.02 756.224,1300.03 756.233,1300.03 756.242,1300.03 756.251,1300.03 756.26,1300.03 756.27,1300.03 756.279,1300.03 756.288,1300.03 756.297,1300.03 756.306,1300.03 756.316,1300.03 756.325,1300.03 756.334,1300.04 756.343,1300.04 756.352,1300.04 756.362,1300.04 756.371,1300.04 756.38,1300.04 756.389,1300.04 756.398,1300.04 756.407,1300.04 756.417,1300.04 756.426,1300.04 756.435,1300.04 756.444,1300.04 756.453,1300.05 756.463,1300.05 756.472,1300.05 756.481,1300.05 756.49,1300.05 756.499,1300.05 756.509,1300.05 756.518,1300.05 756.527,1300.05 756.536,1300.05 756.545,1300.05 756.555,1300.05 756.564,1300.06 756.573,1300.06 756.582,1300.06 756.591,1300.06 756.6,1300.06 756.61,1300.06 756.619,1300.06 756.628,1300.06 756.637,1300.06 756.646,1300.06 756.656,1300.06 756.665,1300.06 756.674,1300.06 756.683,1300.07 756.692,1300.07 756.702,1300.07 756.711,1300.07 756.72,1300.07 756.729,1300.07 756.738,1300.07 756.747,1300.07 756.757,1300.07 756.766,1300.07 756.775,1300.07 756.784,1300.07 756.793,1300.08 756.803,1300.08 756.812,1300.08 756.821,1300.08 756.83,1300.08 756.839,1300.08 756.849,1300.08 756.858,1300.08 756.867,1300.08 756.876,1300.08 756.885,1300.08 756.895,1300.08 756.904,1300.08 756.913,1300.09 756.922,1300.09 756.931,1300.09 756.94,1300.09 756.95,1300.09 756.959,1300.09 756.968,1300.09 756.977,1300.09 756.986,1300.09 756.996,1300.09 757.005,1300.09 757.014,1300.09 757.023,1300.1 757.032,1300.1 757.042,1300.1 757.051,1300.1 757.06,1300.1 757.069,1300.1 757.078,1300.1 757.087,1300.1 757.097,1300.1 757.106,1300.1 757.115,1300.1 757.124,1300.1 757.133,1300.1 757.143,1300.11 757.152,1300.11 757.161,1300.11 757.17,1300.11 757.179,1300.11 757.189,1300.11 757.198,1300.11 757.207,1300.11 757.216,1300.11 757.225,1300.11 757.235,1300.11 757.244,1300.11 757.253,1300.12 757.262,1300.12 757.271,1300.12 757.28,1300.12 757.29,1300.12 757.299,1300.12 757.308,1300.12 757.317,1300.12 757.326,1300.12 757.336,1300.12 757.345,1300.12 757.354,1300.12 757.363,1300.12 757.372,1300.13 757.382,1300.13 757.391,1300.13 757.4,1300.13 757.409,1300.13 757.418,1300.13 757.427,1300.13 757.437,1300.13 757.446,1300.13 757.455,1300.13 757.464,1300.13 757.473,1300.13 757.483,1300.13 757.492,1300.14 757.501,1300.14 757.51,1300.14 757.519,1300.14 757.529,1300.14 757.538,1300.14 757.547,1300.14 757.556,1300.14 757.565,1300.14 757.575,1300.14 757.584,1300.14 757.593,1300.14 757.602,1300.15 757.611,1300.15 757.62,1300.15 757.63,1300.15 757.639,1300.15 757.648,1300.15 757.657,1300.15 757.666,1300.15 757.676,1300.15 757.685,1300.15 757.694,1300.15 757.703,1300.15 757.712,1300.15 757.722,1300.16 757.731,1300.16 757.74,1300.16 757.749,1300.16 757.758,1300.16 757.767,1300.16 757.777,1300.16 757.786,1300.16 757.795,1300.16 757.804,1300.16 757.813,1300.16 757.823,1300.16 757.832,1300.17 757.841,1300.17 757.85,1300.17 757.859,1300.17 757.869,1300.17 757.878,1300.17 757.887,1300.17 757.896,1300.17 757.905,1300.17 757.915,1300.17 757.924,1300.17 757.933,1300.17 757.942,1300.17 757.951,1300.18 757.96,1300.18 757.97,1300.18 757.979,1300.18 757.988,1300.18 757.997,1300.18 758.006,1300.18 758.016,1300.18 758.025,1300.18 758.034,1300.18 758.043,1300.18 758.052,1300.18 758.062,1300.19 758.071,1300.19 758.08,1300.19 758.089,1300.19 758.098,1300.19 758.108,1300.19 758.117,1300.19 758.126,1300.19 758.135,1300.19 758.144,1300.19 758.153,1300.19 758.163,1300.19 758.172,1300.19 758.181,1300.2 758.19,1300.2 758.199,1300.2 758.209,1300.2 758.218,1300.2 758.227,1300.2 758.236,1300.2 758.245,1300.2 758.255,1300.2 758.264,1300.2 758.273,1300.2 758.282,1300.2 758.291,1300.21 758.3,1300.21 758.31,1300.21 758.319,1300.21 758.328,1300.21 758.337,1300.21 758.346,1300.21 758.356,1300.21 758.365,1300.21 758.374,1300.21 758.383,1300.21 758.392,1300.21 758.402,1300.21 758.411,1300.22 758.42,1300.22 758.429,1300.22 758.438,1300.22 758.448,1300.22 758.457,1300.22 758.466,1300.22 758.475,1300.22 758.484,1300.22 758.493,1300.22 758.503,1300.22 758.512,1300.22 758.521,1300.23 758.53,1300.23 758.539,1300.23 758.549,1300.23 758.558,1300.23 758.567,1300.23 758.576,1300.23 758.585,1300.23 758.595,1300.23 758.604,1300.23 758.613,1300.23 758.622,1300.23 758.631,1300.23 758.64,1300.24 758.65,1300.24 758.659,1300.24 758.668,1300.24 758.677,1300.24 758.686,1300.24 758.696,1300.24 758.705,1300.24 758.714,1300.24 758.723,1300.24 758.732,1300.24 758.742,1300.24 758.751,1300.24 758.76,1300.25 758.769,1300.25 758.778,1300.25 758.788,1300.25 758.797,1300.25 758.806,1300.25 758.815,1300.25 758.824,1300.25 758.833,1300.25 758.843,1300.25 758.852,1300.25 758.861,1300.25 758.87,1300.26 758.879,1300.26 758.889,1300.26 758.898,1300.26 758.907,1300.26 758.916,1300.26 758.925,1300.26 758.935,1300.26 758.944,1300.26 758.953,1300.26 758.962,1300.26 758.971,1300.26 758.98,1300.26 758.99,1300.27 758.999,1300.27 759.008,1300.27 759.017,1300.27 759.026,1300.27 759.036,1300.27 759.045,1300.27 759.054,1300.27 759.063,1300.27 759.072,1300.27 759.082,1300.27 759.091,1300.27 759.1,1300.28 759.109,1300.28 759.118,1300.28 759.128,1300.28 759.137,1300.28 759.146,1300.28 759.155,1300.28 759.164,1300.28 759.173,1300.28 759.183,1300.28 759.192,1300.28 759.201,1300.28 759.21,1300.28 759.219,1300.29 759.229,1300.29 759.238,1300.29 759.247,1300.29 759.256,1300.29 759.265,1300.29 759.275,1300.29 759.284,1300.29 759.293,1300.29 759.302,1300.29 759.311,1300.29 759.32,1300.29 759.33,1300.3 759.339,1300.3 759.348,1300.3 759.357,1300.3 759.366,1300.3 759.376,1300.3 759.385,1300.3 759.394,1300.3 759.403,1300.3 759.412,1300.3 759.422,1300.3 759.431,1300.3 759.44,1300.3 759.449,1300.31 759.458,1300.31 759.468,1300.31 759.477,1300.31 759.486,1300.31 759.495,1300.31 759.504,1300.31 759.513,1300.31 759.523,1300.31 759.532,1300.31 759.541,1300.31 759.55,1300.31 759.559,1300.32 759.569,1300.32 759.578,1300.32 759.587,1300.32 759.596,1300.32 759.605,1300.32 759.615,1300.32 759.624,1300.32 759.633,1300.32 759.642,1300.32 759.651,1300.32 759.66,1300.32 759.67,1300.32 759.679,1300.33 759.688,1300.33 759.697,1300.33 759.706,1300.33 759.716,1300.33 759.725,1300.33 759.734,1300.33 759.743,1300.33 759.752,1300.33 759.762,1300.33 759.771,1300.33 759.78,1300.33 759.789,1300.33 759.798,1300.34 759.808,1300.34 759.817,1300.34 759.826,1300.34 759.835,1300.34 759.844,1300.34 759.853,1300.34 759.863,1300.34 759.872,1300.34 759.881,1300.34 759.89,1300.34 759.899,1300.34 759.909,1300.35 759.918,1300.35 759.927,1300.35 759.936,1300.35 759.945,1300.35 759.955,1300.35 759.964,1300.35 759.973,1300.35 759.982,1300.35 759.991,1300.35 760,1300.35 760.01,1300.35 760.019,1300.35 760.028,1300.36 760.037,1300.36 760.046,1300.36 760.056,1300.36 760.065,1300.36 760.074,1300.36 760.083,1300.36 760.092,1300.36 760.102,1300.36 760.111,1300.36 760.12,1300.36 760.129,1300.36 760.138,1300.37 760.148,1300.37 760.157,1300.37 760.166,1300.37 760.175,1300.37 760.184,1300.37 760.193,1300.37 760.203,1300.37 760.212,1300.37 760.221,1300.37 760.23,1300.37 760.239,1300.37 760.249,1300.37 760.258,1300.38 760.267,1300.38 760.276,1300.38 760.285,1300.38 760.295,1300.38 760.304,1300.38 760.313,1300.38 760.322,1300.38 760.331,1300.38 760.34,1300.38 760.35,1300.38 760.359,1300.38 760.368,1300.39 760.377,1300.39 760.386,1300.39 760.396,1300.39 760.405,1300.39 760.414,1300.39 760.423,1300.39 760.432,1300.39 760.442,1300.39 760.451,1300.39 760.46,1300.39 760.469,1300.39 760.478,1300.39 760.488,1300.4 760.497,1300.4 760.506,1300.4 760.515,1300.4 760.524,1300.4 760.533,1300.4 760.543,1300.4 760.552,1300.4 760.561,1300.4 760.57,1300.4 760.579,1300.4 760.589,1300.4 760.598,1300.41 760.607,1300.41 760.616,1300.41 760.625,1300.41 760.635,1300.41 760.644,1300.41 760.653,1300.41 760.662,1300.41 760.671,1300.41 760.681,1300.41 760.69,1300.41 760.699,1300.41 760.708,1300.41 760.717,1300.42 760.726,1300.42 760.736,1300.42 760.745,1300.42 760.754,1300.42 760.763,1300.42 760.772,1300.42 760.782,1300.42 760.791,1300.42 760.8,1300.42 760.809,1300.42 760.818,1300.42 760.828,1300.42 760.837,1300.43 760.846,1300.43 760.855,1300.43 760.864,1300.43 760.873,1300.43 760.883,1300.43 760.892,1300.43 760.901,1300.43 760.91,1300.43 760.919,1300.43 760.929,1300.43 760.938,1300.43 760.947,1300.44 760.956,1300.44 760.965,1300.44 760.975,1300.44 760.984,1300.44 760.993,1300.44 761.002,1300.44 761.011,1300.44 761.021,1300.44 761.03,1300.44 761.039,1300.44 761.048,1300.44 761.057,1300.44 761.066,1300.45 761.076,1300.45 761.085,1300.45 761.094,1300.45 761.103,1300.45 761.112,1300.45 761.122,1300.45 761.131,1300.45 761.14,1300.45 761.149,1300.45 761.158,1300.45 761.168,1300.45 761.177,1300.46 761.186,1300.46 761.195,1300.46 761.204,1300.46 761.213,1300.46 761.223,1300.46 761.232,1300.46 761.241,1300.46 761.25,1300.46 761.259,1300.46 761.269,1300.46 761.278,1300.46 761.287,1300.46 761.296,1300.47 761.305,1300.47 761.315,1300.47 761.324,1300.47 761.333,1300.47 761.342,1300.47 761.351,1300.47 761.361,1300.47 761.37,1300.47 761.379,1300.47 761.388,1300.47 761.397,1300.47 761.406,1300.48 761.416,1300.48 761.425,1300.48 761.434,1300.48 761.443,1300.48 761.452,1300.48 761.462,1300.48 761.471,1300.48 761.48,1300.48 761.489,1300.48 761.498,1300.48 761.508,1300.48 761.517,1300.48 761.526,1300.49 761.535,1300.49 761.544,1300.49 761.553,1300.49 761.563,1300.49 761.572,1300.49 761.581,1300.49 761.59,1300.49 761.599,1300.49 761.609,1300.49 761.618,1300.49 761.627,1300.49 761.636,1300.49 761.645,1300.5 761.655,1300.5 761.664,1300.5 761.673,1300.5 761.682,1300.5 761.691,1300.5 761.701,1300.5 761.71,1300.5 761.719,1300.5 761.728,1300.5 761.737,1300.5 761.746,1300.5 761.756,1300.51 761.765,1300.51 761.774,1300.51 761.783,1300.51 761.792,1300.51 761.802,1300.51 761.811,1300.51 761.82,1300.51 761.829,1300.51 761.838,1300.51 761.848,1300.51 761.857,1300.51 761.866,1300.51 761.875,1300.52 761.884,1300.52 761.893,1300.52 761.903,1300.52 761.912,1300.52 761.921,1300.52 761.93,1300.52 761.939,1300.52 761.949,1300.52 761.958,1300.52 761.967,1300.52 761.976,1300.52 761.985,1300.53 761.995,1300.53 762.004,1300.53 762.013,1300.53 762.022,1300.53 762.031,1300.53 762.041,1300.53 762.05,1300.53 762.059,1300.53 762.068,1300.53 762.077,1300.53 762.086,1300.53 762.096,1300.53 762.105,1300.54 762.114,1300.54 762.123,1300.54 762.132,1300.54 762.142,1300.54 762.151,1300.54 762.16,1300.54 762.169,1300.54 762.178,1300.54 762.188,1300.54 762.197,1300.54 762.206,1300.54 762.215,1300.54 762.224,1300.55 762.233,1300.55 762.243,1300.55 762.252,1300.55 762.261,1300.55 762.27,1300.55 762.279,1300.55 762.289,1300.55 762.298,1300.55 762.307,1300.55 762.316,1300.55 762.325,1300.55 762.335,1300.56 762.344,1300.56 762.353,1300.56 762.362,1300.56 762.371,1300.56 762.381,1300.56 762.39,1300.56 762.399,1300.56 762.408,1300.56 762.417,1300.56 762.426,1300.56 762.436,1300.56 762.445,1300.56 762.454,1300.57 762.463,1300.57 762.472,1300.57 762.482,1300.57 762.491,1300.57 762.5,1300.57 762.509,1300.57 762.518,1300.57 762.528,1300.57 762.537,1300.57 762.546,1300.57 762.555,1300.57 762.564,1300.58 762.573,1300.58 762.583,1300.58 762.592,1300.58 762.601,1300.58 762.61,1300.58 762.619,1300.58 762.629,1300.58 762.638,1300.58 762.647,1300.58 762.656,1300.58 762.665,1300.58 762.675,1300.58 762.684,1300.59 762.693,1300.59 762.702,1300.59 762.711,1300.59 762.721,1300.59 762.73,1300.59 762.739,1300.59 762.748,1300.59 762.757,1300.59 762.766,1300.59 762.776,1300.59 762.785,1300.59 762.794,1300.6 762.803,1300.6 762.812,1300.6 762.822,1300.6 762.831,1300.6 762.84,1300.6 762.849,1300.6 762.858,1300.6 762.868,1300.6 762.877,1300.6 762.886,1300.6 762.895,1300.6 762.904,1300.6 762.914,1300.61 762.923,1300.61 762.932,1300.61 762.941,1300.61 762.95,1300.61 762.959,1300.61 762.969,1300.61 762.978,1300.61 762.987,1300.61 762.996,1300.61 763.005,1300.61 763.015,1300.61 763.024,1300.61 763.033,1300.62 763.042,1300.62 763.051,1300.62 763.061,1300.62 763.07,1300.62 763.079,1300.62 763.088,1300.62 763.097,1300.62 763.106,1300.62 763.116,1300.62 763.125,1300.62 763.134,1300.62 763.143,1300.63 763.152,1300.63 763.162,1300.63 763.171,1300.63 763.18,1300.63 763.189,1300.63 763.198,1300.63 763.208,1300.63 763.217,1300.63 763.226,1300.63 763.235,1300.63 763.244,1300.63 763.254,1300.63 763.263,1300.64 763.272,1300.64 763.281,1300.64 763.29,1300.64 763.299,1300.64 763.309,1300.64 763.318,1300.64 763.327,1300.64 763.336,1300.64 763.345,1300.64 763.355,1300.64 763.364,1300.64 763.373,1300.65 763.382,1300.65 763.391,1300.65 763.401,1300.65 763.41,1300.65 763.419,1300.65 763.428,1300.65 763.437,1300.65 763.446,1300.65 763.456,1300.65 763.465,1300.65 763.474,1300.65 763.483,1300.65 763.492,1300.66 763.502,1300.66 763.511,1300.66 763.52,1300.66 763.529,1300.66 763.538,1300.66 763.548,1300.66 763.557,1300.66 763.566,1300.66 763.575,1300.66 763.584,1300.66 763.594,1300.66 763.603,1300.66 763.612,1300.67 763.621,1300.67 763.63,1300.67 763.639,1300.67 763.649,1300.67 763.658,1300.67 763.667,1300.67 763.676,1300.67 763.685,1300.67 763.695,1300.67 763.704,1300.67 763.713,1300.67 763.722,1300.68 763.731,1300.68 763.741,1300.68 763.75,1300.68 763.759,1300.68 763.768,1300.68 763.777,1300.68 763.786,1300.68 763.796,1300.68 763.805,1300.68 763.814,1300.68 763.823,1300.68 763.832,1300.68 763.842,1300.69 763.851,1300.69 763.86,1300.69 763.869,1300.69 763.878,1300.69 763.888,1300.69 763.897,1300.69 763.906,1300.69 763.915,1300.69 763.924,1300.69 763.934,1300.69 763.943,1300.69 763.952,1300.7 763.961,1300.7 763.97,1300.7 763.979,1300.7 763.989,1300.7 763.998,1300.7 764.007,1300.7 764.016,1300.7 764.025,1300.7 764.035,1300.7 764.044,1300.7 764.053,1300.7 764.062,1300.7 764.071,1300.71 764.081,1300.71 764.09,1300.71 764.099,1300.71 764.108,1300.71 764.117,1300.71 764.126,1300.71 764.136,1300.71 764.145,1300.71 764.154,1300.71 764.163,1300.71 764.172,1300.71 764.182,1300.71 764.191,1300.72 764.2,1300.72 764.209,1300.72 764.218,1300.72 764.228,1300.72 764.237,1300.72 764.246,1300.72 764.255,1300.72 764.264,1300.72 764.274,1300.72 764.283,1300.72 764.292,1300.72 764.301,1300.73 764.31,1300.73 764.319,1300.73 764.329,1300.73 764.338,1300.73 764.347,1300.73 764.356,1300.73 764.365,1300.73 764.375,1300.73 764.384,1300.73 764.393,1300.73 764.402,1300.73 764.411,1300.73 764.421,1300.74 764.43,1300.74 764.439,1300.74 764.448,1300.74 764.457,1300.74 764.466,1300.74 764.476,1300.74 764.485,1300.74 764.494,1300.74 764.503,1300.74 764.512,1300.74 764.522,1300.74 764.531,1300.75 764.54,1300.75 764.549,1300.75 764.558,1300.75 764.568,1300.75 764.577,1300.75 764.586,1300.75 764.595,1300.75 764.604,1300.75 764.614,1300.75 764.623,1300.75 764.632,1300.75 764.641,1300.75 764.65,1300.76 764.659,1300.76 764.669,1300.76 764.678,1300.76 764.687,1300.76 764.696,1300.76 764.705,1300.76 764.715,1300.76 764.724,1300.76 764.733,1300.76 764.742,1300.76 764.751,1300.76 764.761,1300.76 764.77,1300.77 764.779,1300.77 764.788,1300.77 764.797,1300.77 764.806,1300.77 764.816,1300.77 764.825,1300.77 764.834,1300.77 764.843,1300.77 764.852,1300.77 764.862,1300.77 764.871,1300.77 764.88,1300.78 764.889,1300.78 764.898,1300.78 764.908,1300.78 764.917,1300.78 764.926,1300.78 764.935,1300.78 764.944,1300.78 764.954,1300.78 764.963,1300.78 764.972,1300.78 764.981,1300.78 764.99,1300.78 764.999,1300.79 765.009,1300.79 765.018,1300.79 765.027,1300.79 765.036,1300.79 765.045,1300.79 765.055,1300.79 765.064,1300.79 765.073,1300.79 765.082,1300.79 765.091,1300.79 765.101,1300.79 765.11,1300.79 765.119,1300.8 765.128,1300.8 765.137,1300.8 765.146,1300.8 765.156,1300.8 765.165,1300.8 765.174,1300.8 765.183,1300.8 765.192,1300.8 765.202,1300.8 765.211,1300.8 765.22,1300.8 765.229,1300.81 765.238,1300.81 765.248,1300.81 765.257,1300.81 765.266,1300.81 765.275,1300.81 765.284,1300.81 765.294,1300.81 765.303,1300.81 765.312,1300.81 765.321,1300.81 765.33,1300.81 765.339,1300.81 765.349,1300.82 765.358,1300.82 765.367,1300.82 765.376,1300.82 765.385,1300.82 765.395,1300.82 765.404,1300.82 765.413,1300.82 765.422,1300.82 765.431,1300.82 765.441,1300.82 765.45,1300.82 765.459,1300.83 765.468,1300.83 765.477,1300.83 765.487,1300.83 765.496,1300.83 765.505,1300.83 765.514,1300.83 765.523,1300.83 765.532,1300.83 765.542,1300.83 765.551,1300.83 765.56,1300.83 765.569,1300.83 765.578,1300.84 765.588,1300.84 765.597,1300.84 765.606,1300.84 765.615,1300.84 765.624,1300.84 765.634,1300.84 765.643,1300.84 765.652,1300.84 765.661,1300.84 765.67,1300.84 765.679,1300.84 765.689,1300.84 765.698,1300.85 765.707,1300.85 765.716,1300.85 765.725,1300.85 765.735,1300.85 765.744,1300.85 765.753,1300.85 765.762,1300.85 765.771,1300.85 765.781,1300.85 765.79,1300.85 765.799,1300.85 765.808,1300.86 765.817,1300.86 765.827,1300.86 765.836,1300.86 765.845,1300.86 765.854,1300.86 765.863,1300.86 765.872,1300.86 765.882,1300.86 765.891,1300.86 765.9,1300.86 765.909,1300.86 765.918,1300.86 765.928,1300.87 765.937,1300.87 765.946,1300.87 765.955,1300.87 765.964,1300.87 765.974,1300.87 765.983,1300.87 765.992,1300.87 766.001,1300.87 766.01,1300.87 766.019,1300.87 766.029,1300.87 766.038,1300.88 766.047,1300.88 766.056,1300.88 766.065,1300.88 766.075,1300.88 766.084,1300.88 766.093,1300.88 766.102,1300.88 766.111,1300.88 766.121,1300.88 766.13,1300.88 766.139,1300.88 766.148,1300.88 766.157,1300.89 766.167,1300.89 766.176,1300.89 766.185,1300.89 766.194,1300.89 766.203,1300.89 766.212,1300.89 766.222,1300.89 766.231,1300.89 766.24,1300.89 766.249,1300.89 766.258,1300.89 766.268,1300.89 766.277,1300.9 766.286,1300.9 766.295,1300.9 766.304,1300.9 766.314,1300.9 766.323,1300.9 766.332,1300.9 766.341,1300.9 766.35,1300.9 766.359,1300.9 766.369,1300.9 766.378,1300.9 766.387,1300.91 766.396,1300.91 766.405,1300.91 766.415,1300.91 766.424,1300.91 766.433,1300.91 766.442,1300.91 766.451,1300.91 766.461,1300.91 766.47,1300.91 766.479,1300.91 766.488,1300.91 766.497,1300.91 766.507,1300.92 766.516,1300.92 766.525,1300.92 766.534,1300.92 766.543,1300.92 766.552,1300.92 766.562,1300.92 766.571,1300.92 766.58,1300.92 766.589,1300.92 766.598,1300.92 766.608,1300.92 766.617,1300.92 766.626,1300.93 766.635,1300.93 766.644,1300.93 766.654,1300.93 766.663,1300.93 766.672,1300.93 766.681,1300.93 766.69,1300.93 766.699,1300.93 766.709,1300.93 766.718,1300.93 766.727,1300.93 766.736,1300.94 766.745,1300.94 766.755,1300.94 766.764,1300.94 766.773,1300.94 766.782,1300.94 766.791,1300.94 766.801,1300.94 766.81,1300.94 766.819,1300.94 766.828,1300.94 766.837,1300.94 766.847,1300.94 766.856,1300.95 766.865,1300.95 766.874,1300.95 766.883,1300.95 766.892,1300.95 766.902,1300.95 766.911,1300.95 766.92,1300.95 766.929,1300.95 766.938,1300.95 766.948,1300.95 766.957,1300.95 766.966,1300.96 766.975,1300.96 766.984,1300.96 766.994,1300.96 767.003,1300.96 767.012,1300.96 767.021,1300.96 767.03,1300.96 767.039,1300.96 767.049,1300.96 767.058,1300.96 767.067,1300.96 767.076,1300.96 767.085,1300.97 767.095,1300.97 767.104,1300.97 767.113,1300.97 767.122,1300.97 767.131,1300.97 767.141,1300.97 767.15,1300.97 767.159,1300.97 767.168,1300.97 767.177,1300.97 767.187,1300.97 767.196,1300.97 767.205,1300.98 767.214,1300.98 767.223,1300.98 767.232,1300.98 767.242,1300.98 767.251,1300.98 767.26,1300.98 767.269,1300.98 767.278,1300.98 767.288,1300.98 767.297,1300.98 767.306,1300.98 767.315,1300.99 767.324,1300.99 767.334,1300.99 767.343,1300.99 767.352,1300.99 767.361,1300.99 767.37,1300.99 767.379,1300.99 767.389,1300.99 767.398,1300.99 767.407,1300.99 767.416,1300.99 767.425,1300.99 767.435,1301 767.444,1301 767.453,1301 767.462,1301 767.471,1301 767.481,1301 767.49,1301 767.499,1301 767.508,1301 767.517,1301 767.527,1301 767.536,1301 767.545,1301 767.554,1301.01 767.563,1301.01 767.572,1301.01 767.582,1301.01 767.591,1301.01 767.6,1301.01 767.609,1301.01 767.618,1301.01 767.628,1301.01 767.637,1301.01 767.646,1301.01 767.655,1301.01 767.664,1301.02 767.674,1301.02 767.683,1301.02 767.692,1301.02 767.701,1301.02 767.71,1301.02 767.719,1301.02 767.729,1301.02 767.738,1301.02 767.747,1301.02 767.756,1301.02 767.765,1301.02 767.775,1301.02 767.784,1301.03 767.793,1301.03 767.802,1301.03 767.811,1301.03 767.821,1301.03 767.83,1301.03 767.839,1301.03 767.848,1301.03 767.857,1301.03 767.867,1301.03 767.876,1301.03 767.885,1301.03 767.894,1301.03 767.903,1301.04 767.912,1301.04 767.922,1301.04 767.931,1301.04 767.94,1301.04 767.949,1301.04 767.958,1301.04 767.968,1301.04 767.977,1301.04 767.986,1301.04 767.995,1301.04 768.004,1301.04 768.014,1301.05 768.023,1301.05 768.032,1301.05 768.041,1301.05 768.05,1301.05 768.06,1301.05 768.069,1301.05 768.078,1301.05 768.087,1301.05 768.096,1301.05 768.105,1301.05 768.115,1301.05 768.124,1301.05 768.133,1301.06 768.142,1301.06 768.151,1301.06 768.161,1301.06 768.17,1301.06 768.179,1301.06 768.188,1301.06 768.197,1301.06 768.207,1301.06 768.216,1301.06 768.225,1301.06 768.234,1301.06 768.243,1301.06 768.252,1301.07 768.262,1301.07 768.271,1301.07 768.28,1301.07 768.289,1301.07 768.298,1301.07 768.308,1301.07 768.317,1301.07 768.326,1301.07 768.335,1301.07 768.344,1301.07 768.354,1301.07 768.363,1301.08 768.372,1301.08 768.381,1301.08 768.39,1301.08 768.4,1301.08 768.409,1301.08 768.418,1301.08 768.427,1301.08 768.436,1301.08 768.445,1301.08 768.455,1301.08 768.464,1301.08 768.473,1301.08 768.482,1301.09 768.491,1301.09 768.501,1301.09 768.51,1301.09 768.519,1301.09 768.528,1301.09 768.537,1301.09 768.547,1301.09 768.556,1301.09 768.565,1301.09 768.574,1301.09 768.583,1301.09 768.592,1301.1 768.602,1301.1 768.611,1301.1 768.62,1301.1 768.629,1301.1 768.638,1301.1 768.648,1301.1 768.657,1301.1 768.666,1301.1 768.675,1301.1 768.684,1301.1 768.694,1301.1 768.703,1301.1 768.712,1301.11 768.721,1301.11 768.73,1301.11 768.74,1301.11 768.749,1301.11 768.758,1301.11 768.767,1301.11 768.776,1301.11 768.785,1301.11 768.795,1301.11 768.804,1301.11 768.813,1301.11 768.822,1301.11 768.831,1301.12 768.841,1301.12 768.85,1301.12 768.859,1301.12 768.868,1301.12 768.877,1301.12 768.887,1301.12 768.896,1301.12 768.905,1301.12 768.914,1301.12 768.923,1301.12 768.932,1301.12 768.942,1301.13 768.951,1301.13 768.96,1301.13 768.969,1301.13 768.978,1301.13 768.988,1301.13 768.997,1301.13 769.006,1301.13 769.015,1301.13 769.024,1301.13 769.034,1301.13 769.043,1301.13 769.052,1301.13 769.061,1301.14 769.07,1301.14 769.08,1301.14 769.089,1301.14 769.098,1301.14 769.107,1301.14 769.116,1301.14 769.125,1301.14 769.135,1301.14 769.144,1301.14 769.153,1301.14 769.162,1301.14 769.171,1301.14 769.181,1301.15 769.19,1301.15 769.199,1301.15 769.208,1301.15 769.217,1301.15 769.227,1301.15 769.236,1301.15 769.245,1301.15 769.254,1301.15 769.263,1301.15 769.272,1301.15 769.282,1301.15 769.291,1301.16 769.3,1301.16 769.309,1301.16 769.318,1301.16 769.328,1301.16 769.337,1301.16 769.346,1301.16 769.355,1301.16 769.364,1301.16 769.374,1301.16 769.383,1301.16 769.392,1301.16 769.401,1301.16 769.41,1301.17 769.42,1301.17 769.429,1301.17 769.438,1301.17 769.447,1301.17 769.456,1301.17 769.465,1301.17 769.475,1301.17 769.484,1301.17 769.493,1301.17 769.502,1301.17 769.511,1301.17 769.521,1301.17 769.53,1301.18 769.539,1301.18 769.548,1301.18 769.557,1301.18 769.567,1301.18 769.576,1301.18 769.585,1301.18 769.594,1301.18 769.603,1301.18 769.612,1301.18 769.622,1301.18 769.631,1301.18 769.64,1301.19 769.649,1301.19 769.658,1301.19 769.668,1301.19 769.677,1301.19 769.686,1301.19 769.695,1301.19 769.704,1301.19 769.714,1301.19 769.723,1301.19 769.732,1301.19 769.741,1301.19 769.75,1301.19 769.76,1301.2 769.769,1301.2 769.778,1301.2 769.787,1301.2 769.796,1301.2 769.805,1301.2 769.815,1301.2 769.824,1301.2 769.833,1301.2 769.842,1301.2 769.851,1301.2 769.861,1301.2 769.87,1301.2 769.879,1301.21 769.888,1301.21 769.897,1301.21 769.907,1301.21 769.916,1301.21 769.925,1301.21 769.934,1301.21 769.943,1301.21 769.952,1301.21 769.962,1301.21 769.971,1301.21 769.98,1301.21 769.989,1301.22 769.998,1301.22 770.008,1301.22 770.017,1301.22 770.026,1301.22 770.035,1301.22 770.044,1301.22 770.054,1301.22 770.063,1301.22 770.072,1301.22 770.081,1301.22 770.09,1301.22 770.1,1301.22 770.109,1301.23 770.118,1301.23 770.127,1301.23 770.136,1301.23 770.145,1301.23 770.155,1301.23 770.164,1301.23 770.173,1301.23 770.182,1301.23 770.191,1301.23 770.201,1301.23 770.21,1301.23 770.219,1301.23 770.228,1301.24 770.237,1301.24 770.247,1301.24 770.256,1301.24 770.265,1301.24 770.274,1301.24 770.283,1301.24 770.293,1301.24 770.302,1301.24 770.311,1301.24 770.32,1301.24 770.329,1301.24 770.338,1301.25 770.348,1301.25 770.357,1301.25 770.366,1301.25 770.375,1301.25 770.384,1301.25 770.394,1301.25 770.403,1301.25 770.412,1301.25 770.421,1301.25 770.43,1301.25 770.44,1301.25 770.449,1301.25 770.458,1301.26 770.467,1301.26 770.476,1301.26 770.485,1301.26 770.495,1301.26 770.504,1301.26 770.513,1301.26 770.522,1301.26 770.531,1301.26 770.541,1301.26 770.55,1301.26 770.559,1301.26 770.568,1301.26 770.577,1301.27 770.587,1301.27 770.596,1301.27 770.605,1301.27 770.614,1301.27 770.623,1301.27 770.633,1301.27 770.642,1301.27 770.651,1301.27 770.66,1301.27 770.669,1301.27 770.678,1301.27 770.688,1301.28 770.697,1301.28 770.706,1301.28 770.715,1301.28 770.724,1301.28 770.734,1301.28 770.743,1301.28 770.752,1301.28 770.761,1301.28 770.77,1301.28 770.78,1301.28 770.789,1301.28 770.798,1301.28 770.807,1301.29 770.816,1301.29 770.825,1301.29 770.835,1301.29 770.844,1301.29 770.853,1301.29 770.862,1301.29 770.871,1301.29 770.881,1301.29 770.89,1301.29 770.899,1301.29 770.908,1301.29 770.917,1301.29 770.927,1301.3 770.936,1301.3 770.945,1301.3 770.954,1301.3 770.963,1301.3 770.973,1301.3 770.982,1301.3 770.991,1301.3 771,1301.3 771.009,1301.3 771.018,1301.3 771.028,1301.3 771.037,1301.31 771.046,1301.31 771.055,1301.31 771.064,1301.31 771.074,1301.31 771.083,1301.31 771.092,1301.31 771.101,1301.31 771.11,1301.31 771.12,1301.31 771.129,1301.31 771.138,1301.31 771.147,1301.31 771.156,1301.32 771.165,1301.32 771.175,1301.32 771.184,1301.32 771.193,1301.32 771.202,1301.32 771.211,1301.32 771.221,1301.32 771.23,1301.32 771.239,1301.32 771.248,1301.32 771.257,1301.32 771.267,1301.32 771.276,1301.33 771.285,1301.33 771.294,1301.33 771.303,1301.33 771.313,1301.33 771.322,1301.33 771.331,1301.33 771.34,1301.33 771.349,1301.33 771.358,1301.33 771.368,1301.33 771.377,1301.33 771.386,1301.34 771.395,1301.34 771.404,1301.34 771.414,1301.34 771.423,1301.34 771.432,1301.34 771.441,1301.34 771.45,1301.34 771.46,1301.34 771.469,1301.34 771.478,1301.34 771.487,1301.34 771.496,1301.34 771.505,1301.35 771.515,1301.35 771.524,1301.35 771.533,1301.35 771.542,1301.35 771.551,1301.35 771.561,1301.35 771.57,1301.35 771.579,1301.35 771.588,1301.35 771.597,1301.35 771.607,1301.35 771.616,1301.35 771.625,1301.36 771.634,1301.36 771.643,1301.36 771.653,1301.36 771.662,1301.36 771.671,1301.36 771.68,1301.36 771.689,1301.36 771.698,1301.36 771.708,1301.36 771.717,1301.36 771.726,1301.36 771.735,1301.36 771.744,1301.37 771.754,1301.37 771.763,1301.37 771.772,1301.37 771.781,1301.37 771.79,1301.37 771.8,1301.37 771.809,1301.37 771.818,1301.37 771.827,1301.37 771.836,1301.37 771.845,1301.37 771.855,1301.37 771.864,1301.38 771.873,1301.38 771.882,1301.38 771.891,1301.38 771.901,1301.38 771.91,1301.38 771.919,1301.38 771.928,1301.38 771.937,1301.38 771.947,1301.38 771.956,1301.38 771.965,1301.38 771.974,1301.38 771.983,1301.39 771.993,1301.39 772.002,1301.39 772.011,1301.39 772.02,1301.39 772.029,1301.39 772.038,1301.39 772.048,1301.39 772.057,1301.39 772.066,1301.39 772.075,1301.39 772.084,1301.39 772.094,1301.39 772.103,1301.4 772.112,1301.4 772.121,1301.4 772.13,1301.4 772.14,1301.4 772.149,1301.4 772.158,1301.4 772.167,1301.4 772.176,1301.4 772.185,1301.4 772.195,1301.4 772.204,1301.4 772.213,1301.4 772.222,1301.41 772.231,1301.41 772.241,1301.41 772.25,1301.41 772.259,1301.41 772.268,1301.41 772.277,1301.41 772.287,1301.41 772.296,1301.41 772.305,1301.41 772.314,1301.41 772.323,1301.41 772.333,1301.41 772.342,1301.41 772.351,1301.42 772.36,1301.42 772.369,1301.42 772.378,1301.42 772.388,1301.42 772.397,1301.42 772.406,1301.42 772.415,1301.42 772.424,1301.42 772.434,1301.42 772.443,1301.42 772.452,1301.42 772.461,1301.42 772.47,1301.43 772.48,1301.43 772.489,1301.43 772.498,1301.43 772.507,1301.43 772.516,1301.43 772.525,1301.43 772.535,1301.43 772.544,1301.43 772.553,1301.43 772.562,1301.43 772.571,1301.43 772.581,1301.43 772.59,1301.44 772.599,1301.44 772.608,1301.44 772.617,1301.44 772.627,1301.44 772.636,1301.44 772.645,1301.44 772.654,1301.44 772.663,1301.44 772.673,1301.44 772.682,1301.44 772.691,1301.44 772.7,1301.44 772.709,1301.44 772.718,1301.45 772.728,1301.45 772.737,1301.45 772.746,1301.45 772.755,1301.45 772.764,1301.45 772.774,1301.45 772.783,1301.45 772.792,1301.45 772.801,1301.45 772.81,1301.45 772.82,1301.45 772.829,1301.45 772.838,1301.45 772.847,1301.46 772.856,1301.46 772.866,1301.46 772.875,1301.46 772.884,1301.46 772.893,1301.46 772.902,1301.46 772.911,1301.46 772.921,1301.46 772.93,1301.46 772.939,1301.46 772.948,1301.46 772.957,1301.46 772.967,1301.47 772.976,1301.47 772.985,1301.47 772.994,1301.47 773.003,1301.47 773.013,1301.47 773.022,1301.47 773.031,1301.47 773.04,1301.47 773.049,1301.47 773.058,1301.47 773.068,1301.47 773.077,1301.47 773.086,1301.47 773.095,1301.48 773.104,1301.48 773.114,1301.48 773.123,1301.48 773.132,1301.48 773.141,1301.48 773.15,1301.48 773.16,1301.48 773.169,1301.48 773.178,1301.48 773.187,1301.48 773.196,1301.48 773.206,1301.48 773.215,1301.48 773.224,1301.49 773.233,1301.49 773.242,1301.49 773.251,1301.49 773.261,1301.49 773.27,1301.49 773.279,1301.49 773.288,1301.49 773.297,1301.49 773.307,1301.49 773.316,1301.49 773.325,1301.49 773.334,1301.49 773.343,1301.49 773.353,1301.5 773.362,1301.5 773.371,1301.5 773.38,1301.5 773.389,1301.5 773.398,1301.5 773.408,1301.5 773.417,1301.5 773.426,1301.5 773.435,1301.5 773.444,1301.5 773.454,1301.5 773.463,1301.5 773.472,1301.51 773.481,1301.51 773.49,1301.51 773.5,1301.51 773.509,1301.51 773.518,1301.51 773.527,1301.51 773.536,1301.51 773.546,1301.51 773.555,1301.51 773.564,1301.51 773.573,1301.51 773.582,1301.51 773.591,1301.51 773.601,1301.52 773.61,1301.52 773.619,1301.52 773.628,1301.52 773.637,1301.52 773.647,1301.52 773.656,1301.52 773.665,1301.52 773.674,1301.52 773.683,1301.52 773.693,1301.52 773.702,1301.52 773.711,1301.52 773.72,1301.52 773.729,1301.52 773.738,1301.53 773.748,1301.53 773.757,1301.53 773.766,1301.53 773.775,1301.53 773.784,1301.53 773.794,1301.53 773.803,1301.53 773.812,1301.53 773.821,1301.53 773.83,1301.53 773.84,1301.53 773.849,1301.53 773.858,1301.53 773.867,1301.54 773.876,1301.54 773.886,1301.54 773.895,1301.54 773.904,1301.54 773.913,1301.54 773.922,1301.54 773.931,1301.54 773.941,1301.54 773.95,1301.54 773.959,1301.54 773.968,1301.54 773.977,1301.54 773.987,1301.54 773.996,1301.55 774.005,1301.55 774.014,1301.55 774.023,1301.55 774.033,1301.55 774.042,1301.55 774.051,1301.55 774.06,1301.55 774.069,1301.55 774.078,1301.55 774.088,1301.55 774.097,1301.55 774.106,1301.55 774.115,1301.55 774.124,1301.56 774.134,1301.56 774.143,1301.56 774.152,1301.56 774.161,1301.56 774.17,1301.56 774.18,1301.56 774.189,1301.56 774.198,1301.56 774.207,1301.56 774.216,1301.56 774.226,1301.56 774.235,1301.56 774.244,1301.56 774.253,1301.56 774.262,1301.57 774.271,1301.57 774.281,1301.57 774.29,1301.57 774.299,1301.57 774.308,1301.57 774.317,1301.57 774.327,1301.57 774.336,1301.57 774.345,1301.57 774.354,1301.57 774.363,1301.57 774.373,1301.57 774.382,1301.57 774.391,1301.58 774.4,1301.58 774.409,1301.58 774.418,1301.58 774.428,1301.58 774.437,1301.58 774.446,1301.58 774.455,1301.58 774.464,1301.58 774.474,1301.58 774.483,1301.58 774.492,1301.58 774.501,1301.58 774.51,1301.58 774.52,1301.58 774.529,1301.59 774.538,1301.59 774.547,1301.59 774.556,1301.59 774.566,1301.59 774.575,1301.59 774.584,1301.59 774.593,1301.59 774.602,1301.59 774.611,1301.59 774.621,1301.59 774.63,1301.59 774.639,1301.59 774.648,1301.59 774.657,1301.6 774.667,1301.6 774.676,1301.6 774.685,1301.6 774.694,1301.6 774.703,1301.6 774.713,1301.6 774.722,1301.6 774.731,1301.6 774.74,1301.6 774.749,1301.6 774.758,1301.6 774.768,1301.6 774.777,1301.6 774.786,1301.6 774.795,1301.61 774.804,1301.61 774.814,1301.61 774.823,1301.61 774.832,1301.61 774.841,1301.61 774.85,1301.61 774.86,1301.61 774.869,1301.61 774.878,1301.61 774.887,1301.61 774.896,1301.61 774.906,1301.61 774.915,1301.61 774.924,1301.61 774.933,1301.62 774.942,1301.62 774.951,1301.62 774.961,1301.62 774.97,1301.62 774.979,1301.62 774.988,1301.62 774.997,1301.62 775.007,1301.62 775.016,1301.62 775.025,1301.62 775.034,1301.62 775.043,1301.62 775.053,1301.62 775.062,1301.62 775.071,1301.63 775.08,1301.63 775.089,1301.63 775.098,1301.63 775.108,1301.63 775.117,1301.63 775.126,1301.63 775.135,1301.63 775.144,1301.63 775.154,1301.63 775.163,1301.63 775.172,1301.63 775.181,1301.63 775.19,1301.63 775.2,1301.63 775.209,1301.64 775.218,1301.64 775.227,1301.64 775.236,1301.64 775.246,1301.64 775.255,1301.64 775.264,1301.64 775.273,1301.64 775.282,1301.64 775.291,1301.64 775.301,1301.64 775.31,1301.64 775.319,1301.64 775.328,1301.64 775.337,1301.64 775.347,1301.65 775.356,1301.65 775.365,1301.65 775.374,1301.65 775.383,1301.65 775.393,1301.65 775.402,1301.65 775.411,1301.65 775.42,1301.65 775.429,1301.65 775.439,1301.65 775.448,1301.65 775.457,1301.65 775.466,1301.65 775.475,1301.65 775.484,1301.66 775.494,1301.66 775.503,1301.66 775.512,1301.66 775.521,1301.66 775.53,1301.66 775.54,1301.66 775.549,1301.66 775.558,1301.66 775.567,1301.66 775.576,1301.66 775.586,1301.66 775.595,1301.66 775.604,1301.66 775.613,1301.66 775.622,1301.67 775.631,1301.67 775.641,1301.67 775.65,1301.67 775.659,1301.67 775.668,1301.67 775.677,1301.67 775.687,1301.67 775.696,1301.67 775.705,1301.67 775.714,1301.67 775.723,1301.67 775.733,1301.67 775.742,1301.67 775.751,1301.67 775.76,1301.68 775.769,1301.68 775.779,1301.68 775.788,1301.68 775.797,1301.68 775.806,1301.68 775.815,1301.68 775.824,1301.68 775.834,1301.68 775.843,1301.68 775.852,1301.68 775.861,1301.68 775.87,1301.68 775.88,1301.68 775.889,1301.68 775.898,1301.68 775.907,1301.69 775.916,1301.69 775.926,1301.69 775.935,1301.69 775.944,1301.69 775.953,1301.69 775.962,1301.69 775.971,1301.69 775.981,1301.69 775.99,1301.69 775.999,1301.69 776.008,1301.69 776.017,1301.69 776.027,1301.69 776.036,1301.69 776.045,1301.7 776.054,1301.7 776.063,1301.7 776.073,1301.7 776.082,1301.7 776.091,1301.7 776.1,1301.7 776.109,1301.7 776.119,1301.7 776.128,1301.7 776.137,1301.7 776.146,1301.7 776.155,1301.7 776.164,1301.7 776.174,1301.7 776.183,1301.7 776.192,1301.71 776.201,1301.71 776.21,1301.71 776.22,1301.71 776.229,1301.71 776.238,1301.71 776.247,1301.71 776.256,1301.71 776.266,1301.71 776.275,1301.71 776.284,1301.71 776.293,1301.71 776.302,1301.71 776.311,1301.71 776.321,1301.71 776.33,1301.72 776.339,1301.72 776.348,1301.72 776.357,1301.72 776.367,1301.72 776.376,1301.72 776.385,1301.72 776.394,1301.72 776.403,1301.72 776.413,1301.72 776.422,1301.72 776.431,1301.72 776.44,1301.72 776.449,1301.72 776.459,1301.72 776.468,1301.72 776.477,1301.73 776.486,1301.73 776.495,1301.73 776.504,1301.73 776.514,1301.73 776.523,1301.73 776.532,1301.73 776.541,1301.73 776.55,1301.73 776.56,1301.73 776.569,1301.73 776.578,1301.73 776.587,1301.73 776.596,1301.73 776.606,1301.73 776.615,1301.73 776.624,1301.74 776.633,1301.74 776.642,1301.74 776.651,1301.74 776.661,1301.74 776.67,1301.74 776.679,1301.74 776.688,1301.74 776.697,1301.74 776.707,1301.74 776.716,1301.74 776.725,1301.74 776.734,1301.74 776.743,1301.74 776.753,1301.74 776.762,1301.74 776.771,1301.75 776.78,1301.75 776.789,1301.75 776.799,1301.75 776.808,1301.75 776.817,1301.75 776.826,1301.75 776.835,1301.75 776.844,1301.75 776.854,1301.75 776.863,1301.75 776.872,1301.75 776.881,1301.75 776.89,1301.75 776.9,1301.75 776.909,1301.75 776.918,1301.76 776.927,1301.76 776.936,1301.76 776.946,1301.76 776.955,1301.76 776.964,1301.76 776.973,1301.76 776.982,1301.76 776.991,1301.76 777.001,1301.76 777.01,1301.76 777.019,1301.76 777.028,1301.76 777.037,1301.76 777.047,1301.76 777.056,1301.76 777.065,1301.77 777.074,1301.77 777.083,1301.77 777.093,1301.77 777.102,1301.77 777.111,1301.77 777.12,1301.77 777.129,1301.77 777.139,1301.77 777.148,1301.77 777.157,1301.77 777.166,1301.77 777.175,1301.77 777.184,1301.77 777.194,1301.77 777.203,1301.77 777.212,1301.78 777.221,1301.78 777.23,1301.78 777.24,1301.78 777.249,1301.78 777.258,1301.78 777.267,1301.78 777.276,1301.78 777.286,1301.78 777.295,1301.78 777.304,1301.78 777.313,1301.78 777.322,1301.78 777.331,1301.78 777.341,1301.78 777.35,1301.78 777.359,1301.79 777.368,1301.79 777.377,1301.79 777.387,1301.79 777.396,1301.79 777.405,1301.79 777.414,1301.79 777.423,1301.79 777.433,1301.79 777.442,1301.79 777.451,1301.79 777.46,1301.79 777.469,1301.79 777.479,1301.79 777.488,1301.79 777.497,1301.79 777.506,1301.79 777.515,1301.8 777.524,1301.8 777.534,1301.8 777.543,1301.8 777.552,1301.8 777.561,1301.8 777.57,1301.8 777.58,1301.8 777.589,1301.8 777.598,1301.8 777.607,1301.8 777.616,1301.8 777.626,1301.8 777.635,1301.8 777.644,1301.8 777.653,1301.8 777.662,1301.81 777.672,1301.81 777.681,1301.81 777.69,1301.81 777.699,1301.81 777.708,1301.81 777.717,1301.81 777.727,1301.81 777.736,1301.81 777.745,1301.81 777.754,1301.81 777.763,1301.81 777.773,1301.81 777.782,1301.81 777.791,1301.81 777.8,1301.81 777.809,1301.81 777.819,1301.82 777.828,1301.82 777.837,1301.82 777.846,1301.82 777.855,1301.82 777.864,1301.82 777.874,1301.82 777.883,1301.82 777.892,1301.82 777.901,1301.82 777.91,1301.82 777.92,1301.82 777.929,1301.82 777.938,1301.82 777.947,1301.82 777.956,1301.82 777.966,1301.82 777.975,1301.83 777.984,1301.83 777.993,1301.83 778.002,1301.83 778.012,1301.83 778.021,1301.83 778.03,1301.83 778.039,1301.83 778.048,1301.83 778.057,1301.83 778.067,1301.83 778.076,1301.83 778.085,1301.83 778.094,1301.83 778.103,1301.83 778.113,1301.83 778.122,1301.84 778.131,1301.84 778.14,1301.84 778.149,1301.84 778.159,1301.84 778.168,1301.84 778.177,1301.84 778.186,1301.84 778.195,1301.84 778.204,1301.84 778.214,1301.84 778.223,1301.84 778.232,1301.84 778.241,1301.84 778.25,1301.84 778.26,1301.84 778.269,1301.84 778.278,1301.85 778.287,1301.85 778.296,1301.85 778.306,1301.85 778.315,1301.85 778.324,1301.85 778.333,1301.85 778.342,1301.85 778.352,1301.85 778.361,1301.85 778.37,1301.85 778.379,1301.85 778.388,1301.85 778.397,1301.85 778.407,1301.85 778.416,1301.85 778.425,1301.85 778.434,1301.86 778.443,1301.86 778.453,1301.86 778.462,1301.86 778.471,1301.86 778.48,1301.86 778.489,1301.86 778.499,1301.86 778.508,1301.86 778.517,1301.86 778.526,1301.86 778.535,1301.86 778.544,1301.86 778.554,1301.86 778.563,1301.86 778.572,1301.86 778.581,1301.86 778.59,1301.87 778.6,1301.87 778.609,1301.87 778.618,1301.87 778.627,1301.87 778.636,1301.87 778.646,1301.87 778.655,1301.87 778.664,1301.87 778.673,1301.87 778.682,1301.87 778.692,1301.87 778.701,1301.87 778.71,1301.87 778.719,1301.87 778.728,1301.87 778.737,1301.87 778.747,1301.88 778.756,1301.88 778.765,1301.88 778.774,1301.88 778.783,1301.88 778.793,1301.88 778.802,1301.88 778.811,1301.88 778.82,1301.88 778.829,1301.88 778.839,1301.88 778.848,1301.88 778.857,1301.88 778.866,1301.88 778.875,1301.88 778.884,1301.88 778.894,1301.88 778.903,1301.88 778.912,1301.89 778.921,1301.89 778.93,1301.89 778.94,1301.89 778.949,1301.89 778.958,1301.89 778.967,1301.89 778.976,1301.89 778.986,1301.89 778.995,1301.89 779.004,1301.89 779.013,1301.89 779.022,1301.89 779.032,1301.89 779.041,1301.89 779.05,1301.89 779.059,1301.89 779.068,1301.9 779.077,1301.9 779.087,1301.9 779.096,1301.9 779.105,1301.9 779.114,1301.9 779.123,1301.9 779.133,1301.9 779.142,1301.9 779.151,1301.9 779.16,1301.9 779.169,1301.9 779.179,1301.9 779.188,1301.9 779.197,1301.9 779.206,1301.9 779.215,1301.9 779.224,1301.91 779.234,1301.91 779.243,1301.91 779.252,1301.91 779.261,1301.91 779.27,1301.91 779.28,1301.91 779.289,1301.91 779.298,1301.91 779.307,1301.91 779.316,1301.91 779.326,1301.91 779.335,1301.91 779.344,1301.91 779.353,1301.91 779.362,1301.91 779.372,1301.91 779.381,1301.91 779.39,1301.92 779.399,1301.92 779.408,1301.92 779.417,1301.92 779.427,1301.92 779.436,1301.92 779.445,1301.92 779.454,1301.92 779.463,1301.92 779.473,1301.92 779.482,1301.92 779.491,1301.92 779.5,1301.92 779.509,1301.92 779.519,1301.92 779.528,1301.92 779.537,1301.92 779.546,1301.93 779.555,1301.93 779.564,1301.93 779.574,1301.93 779.583,1301.93 779.592,1301.93 779.601,1301.93 779.61,1301.93 779.62,1301.93 779.629,1301.93 779.638,1301.93 779.647,1301.93 779.656,1301.93 779.666,1301.93 779.675,1301.93 779.684,1301.93 779.693,1301.93 779.702,1301.93 779.712,1301.94 779.721,1301.94 779.73,1301.94 779.739,1301.94 779.748,1301.94 779.757,1301.94 779.767,1301.94 779.776,1301.94 779.785,1301.94 779.794,1301.94 779.803,1301.94 779.813,1301.94 779.822,1301.94 779.831,1301.94 779.84,1301.94 779.849,1301.94 779.859,1301.94 779.868,1301.94 779.877,1301.95 779.886,1301.95 779.895,1301.95 779.904,1301.95 779.914,1301.95 779.923,1301.95 779.932,1301.95 779.941,1301.95 779.95,1301.95 779.96,1301.95 779.969,1301.95 779.978,1301.95 779.987,1301.95 779.996,1301.95 780.006,1301.95 780.015,1301.95 780.024,1301.95 780.033,1301.95 780.042,1301.96 780.052,1301.96 780.061,1301.96 780.07,1301.96 780.079,1301.96 780.088,1301.96 780.097,1301.96 780.107,1301.96 780.116,1301.96 780.125,1301.96 780.134,1301.96 780.143,1301.96 780.153,1301.96 780.162,1301.96 780.171,1301.96 780.18,1301.96 780.189,1301.96 780.199,1301.96 780.208,1301.97 780.217,1301.97 780.226,1301.97 780.235,1301.97 780.245,1301.97 780.254,1301.97 780.263,1301.97 780.272,1301.97 780.281,1301.97 780.29,1301.97 780.3,1301.97 780.309,1301.97 780.318,1301.97 780.327,1301.97 780.336,1301.97 780.346,1301.97 780.355,1301.97 780.364,1301.97 780.373,1301.98 780.382,1301.98 780.392,1301.98 780.401,1301.98 780.41,1301.98 780.419,1301.98 780.428,1301.98 780.437,1301.98 780.447,1301.98 780.456,1301.98 780.465,1301.98 780.474,1301.98 780.483,1301.98 780.493,1301.98 780.502,1301.98 780.511,1301.98 780.52,1301.98 780.529,1301.98 780.539,1301.98 780.548,1301.99 780.557,1301.99 780.566,1301.99 780.575,1301.99 780.585,1301.99 780.594,1301.99 780.603,1301.99 780.612,1301.99 780.621,1301.99 780.63,1301.99 780.64,1301.99 780.649,1301.99 780.658,1301.99 780.667,1301.99 780.676,1301.99 780.686,1301.99 780.695,1301.99 780.704,1301.99 780.713,1302 780.722,1302 780.732,1302 780.741,1302 780.75,1302 780.759,1302 780.768,1302 780.777,1302 780.787,1302 780.796,1302 780.805,1302 780.814,1302 780.823,1302 780.833,1302 780.842,1302 780.851,1302 780.86,1302 780.869,1302 780.879,1302.01 780.888,1302.01 780.897,1302.01 780.906,1302.01 780.915,1302.01 780.925,1302.01 780.934,1302.01 780.943,1302.01 780.952,1302.01 780.961,1302.01 780.97,1302.01 780.98,1302.01 780.989,1302.01 780.998,1302.01 781.007,1302.01 781.016,1302.01 781.026,1302.01 781.035,1302.01 781.044,1302.01 781.053,1302.02 781.062,1302.02 781.072,1302.02 781.081,1302.02 781.09,1302.02 781.099,1302.02 781.108,1302.02 781.117,1302.02 781.127,1302.02 781.136,1302.02 781.145,1302.02 781.154,1302.02 781.163,1302.02 781.173,1302.02 781.182,1302.02 781.191,1302.02 781.2,1302.02 781.209,1302.02 781.219,1302.02 781.228,1302.03 781.237,1302.03 781.246,1302.03 781.255,1302.03 781.265,1302.03 781.274,1302.03 781.283,1302.03 781.292,1302.03 781.301,1302.03 781.31,1302.03 781.32,1302.03 781.329,1302.03 781.338,1302.03 781.347,1302.03 781.356,1302.03 781.366,1302.03 781.375,1302.03 781.384,1302.03 781.393,1302.04 781.402,1302.04 781.412,1302.04 781.421,1302.04 781.43,1302.04 781.439,1302.04 781.448,1302.04 781.457,1302.04 781.467,1302.04 781.476,1302.04 781.485,1302.04 781.494,1302.04 781.503,1302.04 781.513,1302.04 781.522,1302.04 781.531,1302.04 781.54,1302.04 781.549,1302.04 781.559,1302.04 781.568,1302.05 781.577,1302.05 781.586,1302.05 781.595,1302.05 781.605,1302.05 781.614,1302.05 781.623,1302.05 781.632,1302.05 781.641,1302.05 781.65,1302.05 781.66,1302.05 781.669,1302.05 781.678,1302.05 781.687,1302.05 781.696,1302.05 781.706,1302.05 781.715,1302.05 781.724,1302.05 781.733,1302.05 781.742,1302.06 781.752,1302.06 781.761,1302.06 781.77,1302.06 781.779,1302.06 781.788,1302.06 781.797,1302.06 781.807,1302.06 781.816,1302.06 781.825,1302.06 781.834,1302.06 781.843,1302.06 781.853,1302.06 781.862,1302.06 781.871,1302.06 781.88,1302.06 781.889,1302.06 781.899,1302.06 781.908,1302.06 781.917,1302.06 781.926,1302.07 781.935,1302.07 781.945,1302.07 781.954,1302.07 781.963,1302.07 781.972,1302.07 781.981,1302.07 781.99,1302.07 782,1302.07 782.009,1302.07 782.018,1302.07 782.027,1302.07 782.036,1302.07 782.046,1302.07 782.055,1302.07 782.064,1302.07 782.073,1302.07 782.082,1302.07 782.092,1302.07 782.101,1302.08 782.11,1302.08 782.119,1302.08 782.128,1302.08 782.137,1302.08 782.147,1302.08 782.156,1302.08 782.165,1302.08 782.174,1302.08 782.183,1302.08 782.193,1302.08 782.202,1302.08 782.211,1302.08 782.22,1302.08 782.229,1302.08 782.239,1302.08 782.248,1302.08 782.257,1302.08 782.266,1302.08 782.275,1302.09 782.285,1302.09 782.294,1302.09 782.303,1302.09 782.312,1302.09 782.321,1302.09 782.33,1302.09 782.34,1302.09 782.349,1302.09 782.358,1302.09 782.367,1302.09 782.376,1302.09 782.386,1302.09 782.395,1302.09 782.404,1302.09 782.413,1302.09 782.422,1302.09 782.432,1302.09 782.441,1302.09 782.45,1302.09 782.459,1302.1 782.468,1302.1 782.477,1302.1 782.487,1302.1 782.496,1302.1 782.505,1302.1 782.514,1302.1 782.523,1302.1 782.533,1302.1 782.542,1302.1 782.551,1302.1 782.56,1302.1 782.569,1302.1 782.579,1302.1 782.588,1302.1 782.597,1302.1 782.606,1302.1 782.615,1302.1 782.625,1302.1 782.634,1302.11 782.643,1302.11 782.652,1302.11 782.661,1302.11 782.67,1302.11 782.68,1302.11 782.689,1302.11 782.698,1302.11 782.707,1302.11 782.716,1302.11 782.726,1302.11 782.735,1302.11 782.744,1302.11 782.753,1302.11 782.762,1302.11 782.772,1302.11 782.781,1302.11 782.79,1302.11 782.799,1302.11 782.808,1302.11 782.818,1302.12 782.827,1302.12 782.836,1302.12 782.845,1302.12 782.854,1302.12 782.863,1302.12 782.873,1302.12 782.882,1302.12 782.891,1302.12 782.9,1302.12 782.909,1302.12 782.919,1302.12 782.928,1302.12 782.937,1302.12 782.946,1302.12 782.955,1302.12 782.965,1302.12 782.974,1302.12 782.983,1302.12 782.992,1302.12 783.001,1302.13 783.01,1302.13 783.02,1302.13 783.029,1302.13 783.038,1302.13 783.047,1302.13 783.056,1302.13 783.066,1302.13 783.075,1302.13 783.084,1302.13 783.093,1302.13 783.102,1302.13 783.112,1302.13 783.121,1302.13 783.13,1302.13 783.139,1302.13 783.148,1302.13 783.158,1302.13 783.167,1302.13 783.176,1302.13 783.185,1302.14 783.194,1302.14 783.203,1302.14 783.213,1302.14 783.222,1302.14 783.231,1302.14 783.24,1302.14 783.249,1302.14 783.259,1302.14 783.268,1302.14 783.277,1302.14 783.286,1302.14 783.295,1302.14 783.305,1302.14 783.314,1302.14 783.323,1302.14 783.332,1302.14 783.341,1302.14 783.35,1302.14 783.36,1302.14 783.369,1302.15 783.378,1302.15 783.387,1302.15 783.396,1302.15 783.406,1302.15 783.415,1302.15 783.424,1302.15 783.433,1302.15 783.442,1302.15 783.452,1302.15 783.461,1302.15 783.47,1302.15 783.479,1302.15 783.488,1302.15 783.498,1302.15 783.507,1302.15 783.516,1302.15 783.525,1302.15 783.534,1302.15 783.543,1302.15 783.553,1302.16 783.562,1302.16 783.571,1302.16 783.58,1302.16 783.589,1302.16 783.599,1302.16 783.608,1302.16 783.617,1302.16 783.626,1302.16 783.635,1302.16 783.645,1302.16 783.654,1302.16 783.663,1302.16 783.672,1302.16 783.681,1302.16 783.69,1302.16 783.7,1302.16 783.709,1302.16 783.718,1302.16 783.727,1302.16 783.736,1302.17 783.746,1302.17 783.755,1302.17 783.764,1302.17 783.773,1302.17 783.782,1302.17 783.792,1302.17 783.801,1302.17 783.81,1302.17 783.819,1302.17 783.828,1302.17 783.838,1302.17 783.847,1302.17 783.856,1302.17 783.865,1302.17 783.874,1302.17 783.883,1302.17 783.893,1302.17 783.902,1302.17 783.911,1302.17 783.92,1302.17 783.929,1302.18 783.939,1302.18 783.948,1302.18 783.957,1302.18 783.966,1302.18 783.975,1302.18 783.985,1302.18 783.994,1302.18 784.003,1302.18 784.012,1302.18 784.021,1302.18 784.03,1302.18 784.04,1302.18 784.049,1302.18 784.058,1302.18 784.067,1302.18 784.076,1302.18 784.086,1302.18 784.095,1302.18 784.104,1302.18 784.113,1302.19 784.122,1302.19 784.132,1302.19 784.141,1302.19 784.15,1302.19 784.159,1302.19 784.168,1302.19 784.178,1302.19 784.187,1302.19 784.196,1302.19 784.205,1302.19 784.214,1302.19 784.223,1302.19 784.233,1302.19 784.242,1302.19 784.251,1302.19 784.26,1302.19 784.269,1302.19 784.279,1302.19 784.288,1302.19 784.297,1302.19 784.306,1302.2 784.315,1302.2 784.325,1302.2 784.334,1302.2 784.343,1302.2 784.352,1302.2 784.361,1302.2 784.37,1302.2 784.38,1302.2 784.389,1302.2 784.398,1302.2 784.407,1302.2 784.416,1302.2 784.426,1302.2 784.435,1302.2 784.444,1302.2 784.453,1302.2 784.462,1302.2 784.472,1302.2 784.481,1302.2 784.49,1302.21 784.499,1302.21 784.508,1302.21 784.518,1302.21 784.527,1302.21 784.536,1302.21 784.545,1302.21 784.554,1302.21 784.563,1302.21 784.573,1302.21 784.582,1302.21 784.591,1302.21 784.6,1302.21 784.609,1302.21 784.619,1302.21 784.628,1302.21 784.637,1302.21 784.646,1302.21 784.655,1302.21 784.665,1302.21 784.674,1302.21 784.683,1302.22 784.692,1302.22 784.701,1302.22 784.71,1302.22 784.72,1302.22 784.729,1302.22 784.738,1302.22 784.747,1302.22 784.756,1302.22 784.766,1302.22 784.775,1302.22 784.784,1302.22 784.793,1302.22 784.802,1302.22 784.812,1302.22 784.821,1302.22 784.83,1302.22 784.839,1302.22 784.848,1302.22 784.858,1302.22 784.867,1302.22 784.876,1302.23 784.885,1302.23 784.894,1302.23 784.903,1302.23 784.913,1302.23 784.922,1302.23 784.931,1302.23 784.94,1302.23 784.949,1302.23 784.959,1302.23 784.968,1302.23 784.977,1302.23 784.986,1302.23 784.995,1302.23 785.005,1302.23 785.014,1302.23 785.023,1302.23 785.032,1302.23 785.041,1302.23 785.051,1302.23 785.06,1302.23 785.069,1302.24 785.078,1302.24 785.087,1302.24 785.096,1302.24 785.106,1302.24 785.115,1302.24 785.124,1302.24 785.133,1302.24 785.142,1302.24 785.152,1302.24 785.161,1302.24 785.17,1302.24 785.179,1302.24 785.188,1302.24 785.198,1302.24 785.207,1302.24 785.216,1302.24 785.225,1302.24 785.234,1302.24 785.243,1302.24 785.253,1302.24 785.262,1302.24 785.271,1302.25 785.28,1302.25 785.289,1302.25 785.299,1302.25 785.308,1302.25 785.317,1302.25 785.326,1302.25 785.335,1302.25 785.345,1302.25 785.354,1302.25 785.363,1302.25 785.372,1302.25 785.381,1302.25 785.391,1302.25 785.4,1302.25 785.409,1302.25 785.418,1302.25 785.427,1302.25 785.436,1302.25 785.446,1302.25 785.455,1302.25 785.464,1302.26 785.473,1302.26 785.482,1302.26 785.492,1302.26 785.501,1302.26 785.51,1302.26 785.519,1302.26 785.528,1302.26 785.538,1302.26 785.547,1302.26 785.556,1302.26 785.565,1302.26 785.574,1302.26 785.583,1302.26 785.593,1302.26 785.602,1302.26 785.611,1302.26 785.62,1302.26 785.629,1302.26 785.639,1302.26 785.648,1302.26 785.657,1302.27 785.666,1302.27 785.675,1302.27 785.685,1302.27 785.694,1302.27 785.703,1302.27 785.712,1302.27 785.721,1302.27 785.731,1302.27 785.74,1302.27 785.749,1302.27 785.758,1302.27 785.767,1302.27 785.776,1302.27 785.786,1302.27 785.795,1302.27 785.804,1302.27 785.813,1302.27 785.822,1302.27 785.832,1302.27 785.841,1302.27 785.85,1302.27 785.859,1302.28 785.868,1302.28 785.878,1302.28 785.887,1302.28 785.896,1302.28 785.905,1302.28 785.914,1302.28 785.923,1302.28 785.933,1302.28 785.942,1302.28 785.951,1302.28 785.96,1302.28 785.969,1302.28 785.979,1302.28 785.988,1302.28 785.997,1302.28 786.006,1302.28 786.015,1302.28 786.025,1302.28 786.034,1302.28 786.043,1302.28 786.052,1302.28 786.061,1302.29 786.071,1302.29 786.08,1302.29 786.089,1302.29 786.098,1302.29 786.107,1302.29 786.116,1302.29 786.126,1302.29 786.135,1302.29 786.144,1302.29 786.153,1302.29 786.162,1302.29 786.172,1302.29 786.181,1302.29 786.19,1302.29 786.199,1302.29 786.208,1302.29 786.218,1302.29 786.227,1302.29 786.236,1302.29 786.245,1302.29 786.254,1302.3 786.263,1302.3 786.273,1302.3 786.282,1302.3 786.291,1302.3 786.3,1302.3 786.309,1302.3 786.319,1302.3 786.328,1302.3 786.337,1302.3 786.346,1302.3 786.355,1302.3 786.365,1302.3 786.374,1302.3 786.383,1302.3 786.392,1302.3 786.401,1302.3 786.411,1302.3 786.42,1302.3 786.429,1302.3 786.438,1302.3 786.447,1302.3 786.456,1302.31 786.466,1302.31 786.475,1302.31 786.484,1302.31 786.493,1302.31 786.502,1302.31 786.512,1302.31 786.521,1302.31 786.53,1302.31 786.539,1302.31 786.548,1302.31 786.558,1302.31 786.567,1302.31 786.576,1302.31 786.585,1302.31 786.594,1302.31 786.603,1302.31 786.613,1302.31 786.622,1302.31 786.631,1302.31 786.64,1302.31 786.649,1302.31 786.659,1302.32 786.668,1302.32 786.677,1302.32 786.686,1302.32 786.695,1302.32 786.705,1302.32 786.714,1302.32 786.723,1302.32 786.732,1302.32 786.741,1302.32 786.751,1302.32 786.76,1302.32 786.769,1302.32 786.778,1302.32 786.787,1302.32 786.796,1302.32 786.806,1302.32 786.815,1302.32 786.824,1302.32 786.833,1302.32 786.842,1302.32 786.852,1302.32 786.861,1302.32 786.87,1302.33 786.879,1302.33 786.888,1302.33 786.898,1302.33 786.907,1302.33 786.916,1302.33 786.925,1302.33 786.934,1302.33 786.943,1302.33 786.953,1302.33 786.962,1302.33 786.971,1302.33 786.98,1302.33 786.989,1302.33 786.999,1302.33 787.008,1302.33 787.017,1302.33 787.026,1302.33 787.035,1302.33 787.045,1302.33 787.054,1302.33 787.063,1302.33 787.072,1302.34 787.081,1302.34 787.091,1302.34 787.1,1302.34 787.109,1302.34 787.118,1302.34 787.127,1302.34 787.136,1302.34 787.146,1302.34 787.155,1302.34 787.164,1302.34 787.173,1302.34 787.182,1302.34 787.192,1302.34 787.201,1302.34 787.21,1302.34 787.219,1302.34 787.228,1302.34 787.238,1302.34 787.247,1302.34 787.256,1302.34 787.265,1302.34 787.274,1302.35 787.283,1302.35 787.293,1302.35 787.302,1302.35 787.311,1302.35 787.32,1302.35 787.329,1302.35 787.339,1302.35 787.348,1302.35 787.357,1302.35 787.366,1302.35 787.375,1302.35 787.385,1302.35 787.394,1302.35 787.403,1302.35 787.412,1302.35 787.421,1302.35 787.431,1302.35 787.44,1302.35 787.449,1302.35 787.458,1302.35 787.467,1302.35 787.476,1302.35 787.486,1302.36 787.495,1302.36 787.504,1302.36 787.513,1302.36 787.522,1302.36 787.532,1302.36 787.541,1302.36 787.55,1302.36 787.559,1302.36 787.568,1302.36 787.578,1302.36 787.587,1302.36 787.596,1302.36 787.605,1302.36 787.614,1302.36 787.624,1302.36 787.633,1302.36 787.642,1302.36 787.651,1302.36 787.66,1302.36 787.669,1302.36 787.679,1302.36 787.688,1302.36 787.697,1302.37 787.706,1302.37 787.715,1302.37 787.725,1302.37 787.734,1302.37 787.743,1302.37 787.752,1302.37 787.761,1302.37 787.771,1302.37 787.78,1302.37 787.789,1302.37 787.798,1302.37 787.807,1302.37 787.816,1302.37 787.826,1302.37 787.835,1302.37 787.844,1302.37 787.853,1302.37 787.862,1302.37 787.872,1302.37 787.881,1302.37 787.89,1302.37 787.899,1302.38 787.908,1302.38 787.918,1302.38 787.927,1302.38 787.936,1302.38 787.945,1302.38 787.954,1302.38 787.964,1302.38 787.973,1302.38 787.982,1302.38 787.991,1302.38 788,1302.38 788.009,1302.38 788.019,1302.38 788.028,1302.38 788.037,1302.38 788.046,1302.38 788.055,1302.38 788.065,1302.38 788.074,1302.38 788.083,1302.38 788.092,1302.38 788.101,1302.38 788.111,1302.39 788.12,1302.39 788.129,1302.39 788.138,1302.39 788.147,1302.39 788.156,1302.39 788.166,1302.39 788.175,1302.39 788.184,1302.39 788.193,1302.39 788.202,1302.39 788.212,1302.39 788.221,1302.39 788.23,1302.39 788.239,1302.39 788.248,1302.39 788.258,1302.39 788.267,1302.39 788.276,1302.39 788.285,1302.39 788.294,1302.39 788.304,1302.39 788.313,1302.39 788.322,1302.4 788.331,1302.4 788.34,1302.4 788.349,1302.4 788.359,1302.4 788.368,1302.4 788.377,1302.4 788.386,1302.4 788.395,1302.4 788.405,1302.4 788.414,1302.4 788.423,1302.4 788.432,1302.4 788.441,1302.4 788.451,1302.4 788.46,1302.4 788.469,1302.4 788.478,1302.4 788.487,1302.4 788.496,1302.4 788.506,1302.4 788.515,1302.4 788.524,1302.4 788.533,1302.4 788.542,1302.41 788.552,1302.41 788.561,1302.41 788.57,1302.41 788.579,1302.41 788.588,1302.41 788.598,1302.41 788.607,1302.41 788.616,1302.41 788.625,1302.41 788.634,1302.41 788.644,1302.41 788.653,1302.41 788.662,1302.41 788.671,1302.41 788.68,1302.41 788.689,1302.41 788.699,1302.41 788.708,1302.41 788.717,1302.41 788.726,1302.41 788.735,1302.41 788.745,1302.41 788.754,1302.42 788.763,1302.42 788.772,1302.42 788.781,1302.42 788.791,1302.42 788.8,1302.42 788.809,1302.42 788.818,1302.42 788.827,1302.42 788.836,1302.42 788.846,1302.42 788.855,1302.42 788.864,1302.42 788.873,1302.42 788.882,1302.42 788.892,1302.42 788.901,1302.42 788.91,1302.42 788.919,1302.42 788.928,1302.42 788.938,1302.42 788.947,1302.42 788.956,1302.42 788.965,1302.43 788.974,1302.43 788.984,1302.43 788.993,1302.43 789.002,1302.43 789.011,1302.43 789.02,1302.43 789.029,1302.43 789.039,1302.43 789.048,1302.43 789.057,1302.43 789.066,1302.43 789.075,1302.43 789.085,1302.43 789.094,1302.43 789.103,1302.43 789.112,1302.43 789.121,1302.43 789.131,1302.43 789.14,1302.43 789.149,1302.43 789.158,1302.43 789.167,1302.43 789.176,1302.43 789.186,1302.44 789.195,1302.44 789.204,1302.44 789.213,1302.44 789.222,1302.44 789.232,1302.44 789.241,1302.44 789.25,1302.44 789.259,1302.44 789.268,1302.44 789.278,1302.44 789.287,1302.44 789.296,1302.44 789.305,1302.44 789.314,1302.44 789.324,1302.44 789.333,1302.44 789.342,1302.44 789.351,1302.44 789.36,1302.44 789.369,1302.44 789.379,1302.44 789.388,1302.44 789.397,1302.45 789.406,1302.45 789.415,1302.45 789.425,1302.45 789.434,1302.45 789.443,1302.45 789.452,1302.45 789.461,1302.45 789.471,1302.45 789.48,1302.45 789.489,1302.45 789.498,1302.45 789.507,1302.45 789.516,1302.45 789.526,1302.45 789.535,1302.45 789.544,1302.45 789.553,1302.45 789.562,1302.45 789.572,1302.45 789.581,1302.45 789.59,1302.45 789.599,1302.45 789.608,1302.45 789.618,1302.46 789.627,1302.46 789.636,1302.46 789.645,1302.46 789.654,1302.46 789.664,1302.46 789.673,1302.46 789.682,1302.46 789.691,1302.46 789.7,1302.46 789.709,1302.46 789.719,1302.46 789.728,1302.46 789.737,1302.46 789.746,1302.46 789.755,1302.46 789.765,1302.46 789.774,1302.46 789.783,1302.46 789.792,1302.46 789.801,1302.46 789.811,1302.46 789.82,1302.46 789.829,1302.46 789.838,1302.47 789.847,1302.47 789.856,1302.47 789.866,1302.47 789.875,1302.47 789.884,1302.47 789.893,1302.47 789.902,1302.47 789.912,1302.47 789.921,1302.47 789.93,1302.47 789.939,1302.47 789.948,1302.47 789.958,1302.47 789.967,1302.47 789.976,1302.47 789.985,1302.47 789.994,1302.47 790.004,1302.47 790.013,1302.47 790.022,1302.47 790.031,1302.47 790.04,1302.47 790.049,1302.47 790.059,1302.48 790.068,1302.48 790.077,1302.48 790.086,1302.48 790.095,1302.48 790.105,1302.48 790.114,1302.48 790.123,1302.48 790.132,1302.48 790.141,1302.48 790.151,1302.48 790.16,1302.48 790.169,1302.48 790.178,1302.48 790.187,1302.48 790.197,1302.48 790.206,1302.48 790.215,1302.48 790.224,1302.48 790.233,1302.48 790.242,1302.48 790.252,1302.48 790.261,1302.48 790.27,1302.48 790.279,1302.49 790.288,1302.49 790.298,1302.49 790.307,1302.49 790.316,1302.49 790.325,1302.49 790.334,1302.49 790.344,1302.49 790.353,1302.49 790.362,1302.49 790.371,1302.49 790.38,1302.49 790.389,1302.49 790.399,1302.49 790.408,1302.49 790.417,1302.49 790.426,1302.49 790.435,1302.49 790.445,1302.49 790.454,1302.49 790.463,1302.49 790.472,1302.49 790.481,1302.49 790.491,1302.49 790.5,1302.49 790.509,1302.5 790.518,1302.5 790.527,1302.5 790.537,1302.5 790.546,1302.5 790.555,1302.5 790.564,1302.5 790.573,1302.5 790.582,1302.5 790.592,1302.5 790.601,1302.5 790.61,1302.5 790.619,1302.5 790.628,1302.5 790.638,1302.5 790.647,1302.5 790.656,1302.5 790.665,1302.5 790.674,1302.5 790.684,1302.5 790.693,1302.5 790.702,1302.5 790.711,1302.5 790.72,1302.5 790.729,1302.51 790.739,1302.51 790.748,1302.51 790.757,1302.51 790.766,1302.51 790.775,1302.51 790.785,1302.51 790.794,1302.51 790.803,1302.51 790.812,1302.51 790.821,1302.51 790.831,1302.51 790.84,1302.51 790.849,1302.51 790.858,1302.51 790.867,1302.51 790.877,1302.51 790.886,1302.51 790.895,1302.51 790.904,1302.51 790.913,1302.51 790.922,1302.51 790.932,1302.51 790.941,1302.51 790.95,1302.52 790.959,1302.52 790.968,1302.52 790.978,1302.52 790.987,1302.52 790.996,1302.52 791.005,1302.52 791.014,1302.52 791.024,1302.52 791.033,1302.52 791.042,1302.52 791.051,1302.52 791.06,1302.52 791.069,1302.52 791.079,1302.52 791.088,1302.52 791.097,1302.52 791.106,1302.52 791.115,1302.52 791.125,1302.52 791.134,1302.52 791.143,1302.52 791.152,1302.52 791.161,1302.52 791.171,1302.52 791.18,1302.53 791.189,1302.53 791.198,1302.53 791.207,1302.53 791.217,1302.53 791.226,1302.53 791.235,1302.53 791.244,1302.53 791.253,1302.53 791.262,1302.53 791.272,1302.53 791.281,1302.53 791.29,1302.53 791.299,1302.53 791.308,1302.53 791.318,1302.53 791.327,1302.53 791.336,1302.53 791.345,1302.53 791.354,1302.53 791.364,1302.53 791.373,1302.53 791.382,1302.53 791.391,1302.53 791.4,1302.53 791.409,1302.54 791.419,1302.54 791.428,1302.54 791.437,1302.54 791.446,1302.54 791.455,1302.54 791.465,1302.54 791.474,1302.54 791.483,1302.54 791.492,1302.54 791.501,1302.54 791.511,1302.54 791.52,1302.54 791.529,1302.54 791.538,1302.54 791.547,1302.54 791.557,1302.54 791.566,1302.54 791.575,1302.54 791.584,1302.54 791.593,1302.54 791.602,1302.54 791.612,1302.54 791.621,1302.54 791.63,1302.54 791.639,1302.55 791.648,1302.55 791.658,1302.55 791.667,1302.55 791.676,1302.55 791.685,1302.55 791.694,1302.55 791.704,1302.55 791.713,1302.55 791.722,1302.55 791.731,1302.55 791.74,1302.55 791.749,1302.55 791.759,1302.55 791.768,1302.55 791.777,1302.55 791.786,1302.55 791.795,1302.55 791.805,1302.55 791.814,1302.55 791.823,1302.55 791.832,1302.55 791.841,1302.55 791.851,1302.55 791.86,1302.55 791.869,1302.56 791.878,1302.56 791.887,1302.56 791.897,1302.56 791.906,1302.56 791.915,1302.56 791.924,1302.56 791.933,1302.56 791.942,1302.56 791.952,1302.56 791.961,1302.56 791.97,1302.56 791.979,1302.56 791.988,1302.56 791.998,1302.56 792.007,1302.56 792.016,1302.56 792.025,1302.56 792.034,1302.56 792.044,1302.56 792.053,1302.56 792.062,1302.56 792.071,1302.56 792.08,1302.56 792.089,1302.56 792.099,1302.57 792.108,1302.57 792.117,1302.57 792.126,1302.57 792.135,1302.57 792.145,1302.57 792.154,1302.57 792.163,1302.57 792.172,1302.57 792.181,1302.57 792.191,1302.57 792.2,1302.57 792.209,1302.57 792.218,1302.57 792.227,1302.57 792.237,1302.57 792.246,1302.57 792.255,1302.57 792.264,1302.57 792.273,1302.57 792.282,1302.57 792.292,1302.57 792.301,1302.57 792.31,1302.57 792.319,1302.57 792.328,1302.58 792.338,1302.58 792.347,1302.58 792.356,1302.58 792.365,1302.58 792.374,1302.58 792.384,1302.58 792.393,1302.58 792.402,1302.58 792.411,1302.58 792.42,1302.58 792.43,1302.58 792.439,1302.58 792.448,1302.58 792.457,1302.58 792.466,1302.58 792.475,1302.58 792.485,1302.58 792.494,1302.58 792.503,1302.58 792.512,1302.58 792.521,1302.58 792.531,1302.58 792.54,1302.58 792.549,1302.58 792.558,1302.59 792.567,1302.59 792.577,1302.59 792.586,1302.59 792.595,1302.59 792.604,1302.59 792.613,1302.59 792.622,1302.59 792.632,1302.59 792.641,1302.59 792.65,1302.59 792.659,1302.59 792.668,1302.59 792.678,1302.59 792.687,1302.59 792.696,1302.59 792.705,1302.59 792.714,1302.59 792.724,1302.59 792.733,1302.59 792.742,1302.59 792.751,1302.59 792.76,1302.59 792.77,1302.59 792.779,1302.59 792.788,1302.59 792.797,1302.6 792.806,1302.6 792.815,1302.6 792.825,1302.6 792.834,1302.6 792.843,1302.6 792.852,1302.6 792.861,1302.6 792.871,1302.6 792.88,1302.6 792.889,1302.6 792.898,1302.6 792.907,1302.6 792.917,1302.6 792.926,1302.6 792.935,1302.6 792.944,1302.6 792.953,1302.6 792.962,1302.6 792.972,1302.6 792.981,1302.6 792.99,1302.6 792.999,1302.6 793.008,1302.6 793.018,1302.6 793.027,1302.61 793.036,1302.61 793.045,1302.61 793.054,1302.61 793.064,1302.61 793.073,1302.61 793.082,1302.61 793.091,1302.61 793.1,1302.61 793.11,1302.61 793.119,1302.61 793.128,1302.61 793.137,1302.61 793.146,1302.61 793.155,1302.61 793.165,1302.61 793.174,1302.61 793.183,1302.61 793.192,1302.61 793.201,1302.61 793.211,1302.61 793.22,1302.61 793.229,1302.61 793.238,1302.61 793.247,1302.61 793.257,1302.61 793.266,1302.62 793.275,1302.62 793.284,1302.62 793.293,1302.62 793.302,1302.62 793.312,1302.62 793.321,1302.62 793.33,1302.62 793.339,1302.62 793.348,1302.62 793.358,1302.62 793.367,1302.62 793.376,1302.62 793.385,1302.62 793.394,1302.62 793.404,1302.62 793.413,1302.62 793.422,1302.62 793.431,1302.62 793.44,1302.62 793.45,1302.62 793.459,1302.62 793.468,1302.62 793.477,1302.62 793.486,1302.62 793.495,1302.62 793.505,1302.63 793.514,1302.63 793.523,1302.63 793.532,1302.63 793.541,1302.63 793.551,1302.63 793.56,1302.63 793.569,1302.63 793.578,1302.63 793.587,1302.63 793.597,1302.63 793.606,1302.63 793.615,1302.63 793.624,1302.63 793.633,1302.63 793.642,1302.63 793.652,1302.63 793.661,1302.63 793.67,1302.63 793.679,1302.63 793.688,1302.63 793.698,1302.63 793.707,1302.63 793.716,1302.63 793.725,1302.63 793.734,1302.63 793.744,1302.64 793.753,1302.64 793.762,1302.64 793.771,1302.64 793.78,1302.64 793.79,1302.64 793.799,1302.64 793.808,1302.64 793.817,1302.64 793.826,1302.64 793.835,1302.64 793.845,1302.64 793.854,1302.64 793.863,1302.64 793.872,1302.64 793.881,1302.64 793.891,1302.64 793.9,1302.64 793.909,1302.64 793.918,1302.64 793.927,1302.64 793.937,1302.64 793.946,1302.64 793.955,1302.64 793.964,1302.64 793.973,1302.64 793.982,1302.65 793.992,1302.65 794.001,1302.65 794.01,1302.65 794.019,1302.65 794.028,1302.65 794.038,1302.65 794.047,1302.65 794.056,1302.65 794.065,1302.65 794.074,1302.65 794.084,1302.65 794.093,1302.65 794.102,1302.65 794.111,1302.65 794.12,1302.65 794.13,1302.65 794.139,1302.65 794.148,1302.65 794.157,1302.65 794.166,1302.65 794.175,1302.65 794.185,1302.65 794.194,1302.65 794.203,1302.65 794.212,1302.65 794.221,1302.66 794.231,1302.66 794.24,1302.66 794.249,1302.66 794.258,1302.66 794.267,1302.66 794.277,1302.66 794.286,1302.66 794.295,1302.66 794.304,1302.66 794.313,1302.66 794.322,1302.66 794.332,1302.66 794.341,1302.66 794.35,1302.66 794.359,1302.66 794.368,1302.66 794.378,1302.66 794.387,1302.66 794.396,1302.66 794.405,1302.66 794.414,1302.66 794.424,1302.66 794.433,1302.66 794.442,1302.66 794.451,1302.66 794.46,1302.67 794.47,1302.67 794.479,1302.67 794.488,1302.67 794.497,1302.67 794.506,1302.67 794.515,1302.67 794.525,1302.67 794.534,1302.67 794.543,1302.67 794.552,1302.67 794.561,1302.67 794.571,1302.67 794.58,1302.67 794.589,1302.67 794.598,1302.67 794.607,1302.67 794.617,1302.67 794.626,1302.67 794.635,1302.67 794.644,1302.67 794.653,1302.67 794.662,1302.67 794.672,1302.67 794.681,1302.67 794.69,1302.67 794.699,1302.67 794.708,1302.68 794.718,1302.68 794.727,1302.68 794.736,1302.68 794.745,1302.68 794.754,1302.68 794.764,1302.68 794.773,1302.68 794.782,1302.68 794.791,1302.68 794.8,1302.68 794.81,1302.68 794.819,1302.68 794.828,1302.68 794.837,1302.68 794.846,1302.68 794.855,1302.68 794.865,1302.68 794.874,1302.68 794.883,1302.68 794.892,1302.68 794.901,1302.68 794.911,1302.68 794.92,1302.68 794.929,1302.68 794.938,1302.68 794.947,1302.69 794.957,1302.69 794.966,1302.69 794.975,1302.69 794.984,1302.69 794.993,1302.69 795.003,1302.69 795.012,1302.69 795.021,1302.69 795.03,1302.69 795.039,1302.69 795.048,1302.69 795.058,1302.69 795.067,1302.69 795.076,1302.69 795.085,1302.69 795.094,1302.69 795.104,1302.69 795.113,1302.69 795.122,1302.69 795.131,1302.69 795.14,1302.69 795.15,1302.69 795.159,1302.69 795.168,1302.69 795.177,1302.69 795.186,1302.69 795.195,1302.7 795.205,1302.7 795.214,1302.7 795.223,1302.7 795.232,1302.7 795.241,1302.7 795.251,1302.7 795.26,1302.7 795.269,1302.7 795.278,1302.7 795.287,1302.7 795.297,1302.7 795.306,1302.7 795.315,1302.7 795.324,1302.7 795.333,1302.7 795.343,1302.7 795.352,1302.7 795.361,1302.7 795.37,1302.7 795.379,1302.7 795.388,1302.7 795.398,1302.7 795.407,1302.7 795.416,1302.7 795.425,1302.7 795.434,1302.71 795.444,1302.71 795.453,1302.71 795.462,1302.71 795.471,1302.71 795.48,1302.71 795.49,1302.71 795.499,1302.71 795.508,1302.71 795.517,1302.71 795.526,1302.71 795.535,1302.71 795.545,1302.71 795.554,1302.71 795.563,1302.71 795.572,1302.71 795.581,1302.71 795.591,1302.71 795.6,1302.71 795.609,1302.71 795.618,1302.71 795.627,1302.71 795.637,1302.71 795.646,1302.71 795.655,1302.71 795.664,1302.71 795.673,1302.71 795.683,1302.72 795.692,1302.72 795.701,1302.72 795.71,1302.72 795.719,1302.72 795.728,1302.72 795.738,1302.72 795.747,1302.72 795.756,1302.72 795.765,1302.72 795.774,1302.72 795.784,1302.72 795.793,1302.72 795.802,1302.72 795.811,1302.72 795.82,1302.72 795.83,1302.72 795.839,1302.72 795.848,1302.72 795.857,1302.72 795.866,1302.72 795.875,1302.72 795.885,1302.72 795.894,1302.72 795.903,1302.72 795.912,1302.72 795.921,1302.72 795.931,1302.73 795.94,1302.73 795.949,1302.73 795.958,1302.73 795.967,1302.73 795.977,1302.73 795.986,1302.73 795.995,1302.73 796.004,1302.73 796.013,1302.73 796.023,1302.73 796.032,1302.73 796.041,1302.73 796.05,1302.73 796.059,1302.73 796.068,1302.73 796.078,1302.73 796.087,1302.73 796.096,1302.73 796.105,1302.73 796.114,1302.73 796.124,1302.73 796.133,1302.73 796.142,1302.73 796.151,1302.73 796.16,1302.73 796.17,1302.73 796.179,1302.74 796.188,1302.74 796.197,1302.74 796.206,1302.74 796.215,1302.74 796.225,1302.74 796.234,1302.74 796.243,1302.74 796.252,1302.74 796.261,1302.74 796.271,1302.74 796.28,1302.74 796.289,1302.74 796.298,1302.74 796.307,1302.74 796.317,1302.74 796.326,1302.74 796.335,1302.74 796.344,1302.74 796.353,1302.74 796.363,1302.74 796.372,1302.74 796.381,1302.74 796.39,1302.74 796.399,1302.74 796.408,1302.74 796.418,1302.74 796.427,1302.75 796.436,1302.75 796.445,1302.75 796.454,1302.75 796.464,1302.75 796.473,1302.75 796.482,1302.75 796.491,1302.75 796.5,1302.75 796.51,1302.75 796.519,1302.75 796.528,1302.75 796.537,1302.75 796.546,1302.75 796.555,1302.75 796.565,1302.75 796.574,1302.75 796.583,1302.75 796.592,1302.75 796.601,1302.75 796.611,1302.75 796.62,1302.75 796.629,1302.75 796.638,1302.75 796.647,1302.75 796.657,1302.75 796.666,1302.75 796.675,1302.76 796.684,1302.76 796.693,1302.76 796.703,1302.76 796.712,1302.76 796.721,1302.76 796.73,1302.76 796.739,1302.76 796.748,1302.76 796.758,1302.76 796.767,1302.76 796.776,1302.76 796.785,1302.76 796.794,1302.76 796.804,1302.76 796.813,1302.76 796.822,1302.76 796.831,1302.76 796.84,1302.76 796.85,1302.76 796.859,1302.76 796.868,1302.76 796.877,1302.76 796.886,1302.76 796.895,1302.76 796.905,1302.76 796.914,1302.76 796.923,1302.76 796.932,1302.77 796.941,1302.77 796.951,1302.77 796.96,1302.77 796.969,1302.77 796.978,1302.77 796.987,1302.77 796.997,1302.77 797.006,1302.77 797.015,1302.77 797.024,1302.77 797.033,1302.77 797.043,1302.77 797.052,1302.77 797.061,1302.77 797.07,1302.77 797.079,1302.77 797.088,1302.77 797.098,1302.77 797.107,1302.77 797.116,1302.77 797.125,1302.77 797.134,1302.77 797.144,1302.77 797.153,1302.77 797.162,1302.77 797.171,1302.77 797.18,1302.78 797.19,1302.78 797.199,1302.78 797.208,1302.78 797.217,1302.78 797.226,1302.78 797.235,1302.78 797.245,1302.78 797.254,1302.78 797.263,1302.78 797.272,1302.78 797.281,1302.78 797.291,1302.78 797.3,1302.78 797.309,1302.78 797.318,1302.78 797.327,1302.78 797.337,1302.78 797.346,1302.78 797.355,1302.78 797.364,1302.78 797.373,1302.78 797.383,1302.78 797.392,1302.78 797.401,1302.78 797.41,1302.78 797.419,1302.78 797.428,1302.78 797.438,1302.79 797.447,1302.79 797.456,1302.79 797.465,1302.79 797.474,1302.79 797.484,1302.79 797.493,1302.79 797.502,1302.79 797.511,1302.79 797.52,1302.79 797.53,1302.79 797.539,1302.79 797.548,1302.79 797.557,1302.79 797.566,1302.79 797.576,1302.79 797.585,1302.79 797.594,1302.79 797.603,1302.79 797.612,1302.79 797.621,1302.79 797.631,1302.79 797.64,1302.79 797.649,1302.79 797.658,1302.79 797.667,1302.79 797.677,1302.79 797.686,1302.8 797.695,1302.8 797.704,1302.8 797.713,1302.8 797.723,1302.8 797.732,1302.8 797.741,1302.8 797.75,1302.8 797.759,1302.8 797.768,1302.8 797.778,1302.8 797.787,1302.8 797.796,1302.8 797.805,1302.8 797.814,1302.8 797.824,1302.8 797.833,1302.8 797.842,1302.8 797.851,1302.8 797.86,1302.8 797.87,1302.8 797.879,1302.8 797.888,1302.8 797.897,1302.8 797.906,1302.8 797.916,1302.8 797.925,1302.8 797.934,1302.8 797.943,1302.81 797.952,1302.81 797.961,1302.81 797.971,1302.81 797.98,1302.81 797.989,1302.81 797.998,1302.81 798.007,1302.81 798.017,1302.81 798.026,1302.81 798.035,1302.81 798.044,1302.81 798.053,1302.81 798.063,1302.81 798.072,1302.81 798.081,1302.81 798.09,1302.81 798.099,1302.81 798.108,1302.81 798.118,1302.81 798.127,1302.81 798.136,1302.81 798.145,1302.81 798.154,1302.81 798.164,1302.81 798.173,1302.81 798.182,1302.81 798.191,1302.81 798.2,1302.82 798.21,1302.82 798.219,1302.82 798.228,1302.82 798.237,1302.82 798.246,1302.82 798.256,1302.82 798.265,1302.82 798.274,1302.82 798.283,1302.82 798.292,1302.82 798.301,1302.82 798.311,1302.82 798.32,1302.82 798.329,1302.82 798.338,1302.82 798.347,1302.82 798.357,1302.82 798.366,1302.82 798.375,1302.82 798.384,1302.82 798.393,1302.82 798.403,1302.82 798.412,1302.82 798.421,1302.82 798.43,1302.82 798.439,1302.82 798.448,1302.82 798.458,1302.83 798.467,1302.83 798.476,1302.83 798.485,1302.83 798.494,1302.83 798.504,1302.83 798.513,1302.83 798.522,1302.83 798.531,1302.83 798.54,1302.83 798.55,1302.83 798.559,1302.83 798.568,1302.83 798.577,1302.83 798.586,1302.83 798.596,1302.83 798.605,1302.83 798.614,1302.83 798.623,1302.83 798.632,1302.83 798.641,1302.83 798.651,1302.83 798.66,1302.83 798.669,1302.83 798.678,1302.83 798.687,1302.83 798.697,1302.83 798.706,1302.83 798.715,1302.84 798.724,1302.84 798.733,1302.84 798.743,1302.84 798.752,1302.84 798.761,1302.84 798.77,1302.84 798.779,1302.84 798.788,1302.84 798.798,1302.84 798.807,1302.84 798.816,1302.84 798.825,1302.84 798.834,1302.84 798.844,1302.84 798.853,1302.84 798.862,1302.84 798.871,1302.84 798.88,1302.84 798.89,1302.84 798.899,1302.84 798.908,1302.84 798.917,1302.84 798.926,1302.84 798.936,1302.84 798.945,1302.84 798.954,1302.84 798.963,1302.84 798.972,1302.85 798.981,1302.85 798.991,1302.85 799,1302.85 799.009,1302.85 799.018,1302.85 799.027,1302.85 799.037,1302.85 799.046,1302.85 799.055,1302.85 799.064,1302.85 799.073,1302.85 799.083,1302.85 799.092,1302.85 799.101,1302.85 799.11,1302.85 799.119,1302.85 799.128,1302.85 799.138,1302.85 799.147,1302.85 799.156,1302.85 799.165,1302.85 799.174,1302.85 799.184,1302.85 799.193,1302.85 799.202,1302.85 799.211,1302.85 799.22,1302.85 799.23,1302.86 799.239,1302.86 799.248,1302.86 799.257,1302.86 799.266,1302.86 799.276,1302.86 799.285,1302.86 799.294,1302.86 799.303,1302.86 799.312,1302.86 799.321,1302.86 799.331,1302.86 799.34,1302.86 799.349,1302.86 799.358,1302.86 799.367,1302.86 799.377,1302.86 799.386,1302.86 799.395,1302.86 799.404,1302.86 799.413,1302.86 799.423,1302.86 799.432,1302.86 799.441,1302.86 799.45,1302.86 799.459,1302.86 799.468,1302.86 799.478,1302.86 799.487,1302.87 799.496,1302.87 799.505,1302.87 799.514,1302.87 799.524,1302.87 799.533,1302.87 799.542,1302.87 799.551,1302.87 799.56,1302.87 799.57,1302.87 799.579,1302.87 799.588,1302.87 799.597,1302.87 799.606,1302.87 799.616,1302.87 799.625,1302.87 799.634,1302.87 799.643,1302.87 799.652,1302.87 799.661,1302.87 799.671,1302.87 799.68,1302.87 799.689,1302.87 799.698,1302.87 799.707,1302.87 799.717,1302.87 799.726,1302.87 799.735,1302.87 799.744,1302.87 799.753,1302.88 799.763,1302.88 799.772,1302.88 799.781,1302.88 799.79,1302.88 799.799,1302.88 799.809,1302.88 799.818,1302.88 799.827,1302.88 799.836,1302.88 799.845,1302.88 799.854,1302.88 799.864,1302.88 799.873,1302.88 799.882,1302.88 799.891,1302.88 799.9,1302.88 799.91,1302.88 799.919,1302.88 799.928,1302.88 799.937,1302.88 799.946,1302.88 799.956,1302.88 799.965,1302.88 799.974,1302.88 799.983,1302.88 799.992,1302.88 800.001,1302.88 800.011,1302.89 800.02,1302.89 800.029,1302.89 800.038,1302.89 800.047,1302.89 800.057,1302.89 800.066,1302.89 800.075,1302.89 800.084,1302.89 800.093,1302.89 800.103,1302.89 800.112,1302.89 800.121,1302.89 800.13,1302.89 800.139,1302.89 800.149,1302.89 800.158,1302.89 800.167,1302.89 800.176,1302.89 800.185,1302.89 800.194,1302.89 800.204,1302.89 800.213,1302.89 800.222,1302.89 800.231,1302.89 800.24,1302.89 800.25,1302.89 800.259,1302.89 800.268,1302.89 800.277,1302.9 800.286,1302.9 800.296,1302.9 800.305,1302.9 800.314,1302.9 800.323,1302.9 800.332,1302.9 800.341,1302.9 800.351,1302.9 800.36,1302.9 800.369,1302.9 800.378,1302.9 800.387,1302.9 800.397,1302.9 800.406,1302.9 800.415,1302.9 800.424,1302.9 800.433,1302.9 800.443,1302.9 800.452,1302.9 800.461,1302.9 800.47,1302.9 800.479,1302.9 800.489,1302.9 800.498,1302.9 800.507,1302.9 800.516,1302.9 800.525,1302.9 800.534,1302.91 800.544,1302.91 800.553,1302.91 800.562,1302.91 800.571,1302.91 800.58,1302.91 800.59,1302.91 800.599,1302.91 800.608,1302.91 800.617,1302.91 800.626,1302.91 800.636,1302.91 800.645,1302.91 800.654,1302.91 800.663,1302.91 800.672,1302.91 800.681,1302.91 800.691,1302.91 800.7,1302.91 800.709,1302.91 800.718,1302.91 800.727,1302.91 800.737,1302.91 800.746,1302.91 800.755,1302.91 800.764,1302.91 800.773,1302.91 800.783,1302.91 800.792,1302.91 800.801,1302.92 800.81,1302.92 800.819,1302.92 800.829,1302.92 800.838,1302.92 800.847,1302.92 800.856,1302.92 800.865,1302.92 800.874,1302.92 800.884,1302.92 800.893,1302.92 800.902,1302.92 800.911,1302.92 800.92,1302.92 800.93,1302.92 800.939,1302.92 800.948,1302.92 800.957,1302.92 800.966,1302.92 800.976,1302.92 800.985,1302.92 800.994,1302.92 801.003,1302.92 801.012,1302.92 801.021,1302.92 801.031,1302.92 801.04,1302.92 801.049,1302.92 801.058,1302.92 801.067,1302.93 801.077,1302.93 801.086,1302.93 801.095,1302.93 801.104,1302.93 801.113,1302.93 801.123,1302.93 801.132,1302.93 801.141,1302.93 801.15,1302.93 801.159,1302.93 801.169,1302.93 801.178,1302.93 801.187,1302.93 801.196,1302.93 801.205,1302.93 801.214,1302.93 801.224,1302.93 801.233,1302.93 801.242,1302.93 801.251,1302.93 801.26,1302.93 801.27,1302.93 801.279,1302.93 801.288,1302.93 801.297,1302.93 801.306,1302.93 801.316,1302.93 801.325,1302.93 801.334,1302.94 801.343,1302.94 801.352,1302.94 801.361,1302.94 801.371,1302.94 801.38,1302.94 801.389,1302.94 801.398,1302.94 801.407,1302.94 801.417,1302.94 801.426,1302.94 801.435,1302.94 801.444,1302.94 801.453,1302.94 801.463,1302.94 801.472,1302.94 801.481,1302.94 801.49,1302.94 801.499,1302.94 801.509,1302.94 801.518,1302.94 801.527,1302.94 801.536,1302.94 801.545,1302.94 801.554,1302.94 801.564,1302.94 801.573,1302.94 801.582,1302.94 801.591,1302.95 801.6,1302.95 801.61,1302.95 801.619,1302.95 801.628,1302.95 801.637,1302.95 801.646,1302.95 801.656,1302.95 801.665,1302.95 801.674,1302.95 801.683,1302.95 801.692,1302.95 801.701,1302.95 801.711,1302.95 801.72,1302.95 801.729,1302.95 801.738,1302.95 801.747,1302.95 801.757,1302.95 801.766,1302.95 801.775,1302.95 801.784,1302.95 801.793,1302.95 801.803,1302.95 801.812,1302.95 801.821,1302.95 801.83,1302.95 801.839,1302.95 801.849,1302.95 801.858,1302.96 801.867,1302.96 801.876,1302.96 801.885,1302.96 801.894,1302.96 801.904,1302.96 801.913,1302.96 801.922,1302.96 801.931,1302.96 801.94,1302.96 801.95,1302.96 801.959,1302.96 801.968,1302.96 801.977,1302.96 801.986,1302.96 801.996,1302.96 802.005,1302.96 802.014,1302.96 802.023,1302.96 802.032,1302.96 802.041,1302.96 802.051,1302.96 802.06,1302.96 802.069,1302.96 802.078,1302.96 802.087,1302.96 802.097,1302.96 802.106,1302.96 802.115,1302.96 802.124,1302.97 802.133,1302.97 802.143,1302.97 802.152,1302.97 802.161,1302.97 802.17,1302.97 802.179,1302.97 802.189,1302.97 802.198,1302.97 802.207,1302.97 802.216,1302.97 802.225,1302.97 802.234,1302.97 802.244,1302.97 802.253,1302.97 802.262,1302.97 802.271,1302.97 802.28,1302.97 802.29,1302.97 802.299,1302.97 802.308,1302.97 802.317,1302.97 802.326,1302.97 802.336,1302.97 802.345,1302.97 802.354,1302.97 802.363,1302.97 802.372,1302.97 802.382,1302.97 802.391,1302.97 802.4,1302.98 802.409,1302.98 802.418,1302.98 802.427,1302.98 802.437,1302.98 802.446,1302.98 802.455,1302.98 802.464,1302.98 802.473,1302.98 802.483,1302.98 802.492,1302.98 802.501,1302.98 802.51,1302.98 802.519,1302.98 802.529,1302.98 802.538,1302.98 802.547,1302.98 802.556,1302.98 802.565,1302.98 802.574,1302.98 802.584,1302.98 802.593,1302.98 802.602,1302.98 802.611,1302.98 802.62,1302.98 802.63,1302.98 802.639,1302.98 802.648,1302.98 802.657,1302.98 802.666,1302.99 802.676,1302.99 802.685,1302.99 802.694,1302.99 802.703,1302.99 802.712,1302.99 802.722,1302.99 802.731,1302.99 802.74,1302.99 802.749,1302.99 802.758,1302.99 802.767,1302.99 802.777,1302.99 802.786,1302.99 802.795,1302.99 802.804,1302.99 802.813,1302.99 802.823,1302.99 802.832,1302.99 802.841,1302.99 802.85,1302.99 802.859,1302.99 802.869,1302.99 802.878,1302.99 802.887,1302.99 802.896,1302.99 802.905,1302.99 802.914,1302.99 802.924,1302.99 802.933,1303 802.942,1303 802.951,1303 802.96,1303 802.97,1303 802.979,1303 802.988,1303 802.997,1303 803.006,1303 803.016,1303 803.025,1303 803.034,1303 803.043,1303 803.052,1303 803.062,1303 803.071,1303 803.08,1303 803.089,1303 803.098,1303 803.107,1303 803.117,1303 803.126,1303 803.135,1303 803.144,1303 803.153,1303 803.163,1303 803.172,1303 803.181,1303 803.19,1303 803.199,1303.01 803.209,1303.01 803.218,1303.01 803.227,1303.01 803.236,1303.01 803.245,1303.01 803.254,1303.01 803.264,1303.01 803.273,1303.01 803.282,1303.01 803.291,1303.01 803.3,1303.01 803.31,1303.01 803.319,1303.01 803.328,1303.01 803.337,1303.01 803.346,1303.01 803.356,1303.01 803.365,1303.01 803.374,1303.01 803.383,1303.01 803.392,1303.01 803.402,1303.01 803.411,1303.01 803.42,1303.01 803.429,1303.01 803.438,1303.01 803.447,1303.01 803.457,1303.01 803.466,1303.01 803.475,1303.02 803.484,1303.02 803.493,1303.02 803.503,1303.02 803.512,1303.02 803.521,1303.02 803.53,1303.02 803.539,1303.02 803.549,1303.02 803.558,1303.02 803.567,1303.02 803.576,1303.02 803.585,1303.02 803.594,1303.02 803.604,1303.02 803.613,1303.02 803.622,1303.02 803.631,1303.02 803.64,1303.02 803.65,1303.02 803.659,1303.02 803.668,1303.02 803.677,1303.02 803.686,1303.02 803.696,1303.02 803.705,1303.02 803.714,1303.02 803.723,1303.02 803.732,1303.02 803.742,1303.03 803.751,1303.03 803.76,1303.03 803.769,1303.03 803.778,1303.03 803.787,1303.03 803.797,1303.03 803.806,1303.03 803.815,1303.03 803.824,1303.03 803.833,1303.03 803.843,1303.03 803.852,1303.03 803.861,1303.03 803.87,1303.03 803.879,1303.03 803.889,1303.03 803.898,1303.03 803.907,1303.03 803.916,1303.03 803.925,1303.03 803.934,1303.03 803.944,1303.03 803.953,1303.03 803.962,1303.03 803.971,1303.03 803.98,1303.03 803.99,1303.03 803.999,1303.03 804.008,1303.03 804.017,1303.04 804.026,1303.04 804.036,1303.04 804.045,1303.04 804.054,1303.04 804.063,1303.04 804.072,1303.04 804.082,1303.04 804.091,1303.04 804.1,1303.04 804.109,1303.04 804.118,1303.04 804.127,1303.04 804.137,1303.04 804.146,1303.04 804.155,1303.04 804.164,1303.04 804.173,1303.04 804.183,1303.04 804.192,1303.04 804.201,1303.04 804.21,1303.04 804.219,1303.04 804.229,1303.04 804.238,1303.04 804.247,1303.04 804.256,1303.04 804.265,1303.04 804.274,1303.04 804.284,1303.05 804.293,1303.05 804.302,1303.05 804.311,1303.05 804.32,1303.05 804.33,1303.05 804.339,1303.05 804.348,1303.05 804.357,1303.05 804.366,1303.05 804.376,1303.05 804.385,1303.05 804.394,1303.05 804.403,1303.05 804.412,1303.05 804.422,1303.05 804.431,1303.05 804.44,1303.05 804.449,1303.05 804.458,1303.05 804.467,1303.05 804.477,1303.05 804.486,1303.05 804.495,1303.05 804.504,1303.05 804.513,1303.05 804.523,1303.05 804.532,1303.05 804.541,1303.05 804.55,1303.05 804.559,1303.06 804.569,1303.06 804.578,1303.06 804.587,1303.06 804.596,1303.06 804.605,1303.06 804.614,1303.06 804.624,1303.06 804.633,1303.06 804.642,1303.06 804.651,1303.06 804.66,1303.06 804.67,1303.06 804.679,1303.06 804.688,1303.06 804.697,1303.06 804.706,1303.06 804.716,1303.06 804.725,1303.06 804.734,1303.06 804.743,1303.06 804.752,1303.06 804.762,1303.06 804.771,1303.06 804.78,1303.06 804.789,1303.06 804.798,1303.06 804.807,1303.06 804.817,1303.06 804.826,1303.07 804.835,1303.07 804.844,1303.07 804.853,1303.07 804.863,1303.07 804.872,1303.07 804.881,1303.07 804.89,1303.07 804.899,1303.07 804.909,1303.07 804.918,1303.07 804.927,1303.07 804.936,1303.07 804.945,1303.07 804.955,1303.07 804.964,1303.07 804.973,1303.07 804.982,1303.07 804.991,1303.07 805,1303.07 805.01,1303.07 805.019,1303.07 805.028,1303.07 805.037,1303.07 805.046,1303.07 805.056,1303.07 805.065,1303.07 805.074,1303.07 805.083,1303.07 805.092,1303.07 805.102,1303.08 805.111,1303.08 805.12,1303.08 805.129,1303.08 805.138,1303.08 805.147,1303.08 805.157,1303.08 805.166,1303.08 805.175,1303.08 805.184,1303.08 805.193,1303.08 805.203,1303.08 805.212,1303.08 805.221,1303.08 805.23,1303.08 805.239,1303.08 805.249,1303.08 805.258,1303.08 805.267,1303.08 805.276,1303.08 805.285,1303.08 805.295,1303.08 805.304,1303.08 805.313,1303.08 805.322,1303.08 805.331,1303.08 805.34,1303.08 805.35,1303.08 805.359,1303.08 805.368,1303.08 805.377,1303.09 805.386,1303.09 805.396,1303.09 805.405,1303.09 805.414,1303.09 805.423,1303.09 805.432,1303.09 805.442,1303.09 805.451,1303.09 805.46,1303.09 805.469,1303.09 805.478,1303.09 805.487,1303.09 805.497,1303.09 805.506,1303.09 805.515,1303.09 805.524,1303.09 805.533,1303.09 805.543,1303.09 805.552,1303.09 805.561,1303.09 805.57,1303.09 805.579,1303.09 805.589,1303.09 805.598,1303.09 805.607,1303.09 805.616,1303.09 805.625,1303.09 805.635,1303.09 805.644,1303.09 805.653,1303.1 805.662,1303.1 805.671,1303.1 805.68,1303.1 805.69,1303.1 805.699,1303.1 805.708,1303.1 805.717,1303.1 805.726,1303.1 805.736,1303.1 805.745,1303.1 805.754,1303.1 805.763,1303.1 805.772,1303.1 805.782,1303.1 805.791,1303.1 805.8,1303.1 805.809,1303.1 805.818,1303.1 805.827,1303.1 805.837,1303.1 805.846,1303.1 805.855,1303.1 805.864,1303.1 805.873,1303.1 805.883,1303.1 805.892,1303.1 805.901,1303.1 805.91,1303.1 805.919,1303.11 805.929,1303.11 805.938,1303.11 805.947,1303.11 805.956,1303.11 805.965,1303.11 805.975,1303.11 805.984,1303.11 805.993,1303.11 806.002,1303.11 806.011,1303.11 806.02,1303.11 806.03,1303.11 806.039,1303.11 806.048,1303.11 806.057,1303.11 806.066,1303.11 806.076,1303.11 806.085,1303.11 806.094,1303.11 806.103,1303.11 806.112,1303.11 806.122,1303.11 806.131,1303.11 806.14,1303.11 806.149,1303.11 806.158,1303.11 806.167,1303.11 806.177,1303.11 806.186,1303.11 806.195,1303.12 806.204,1303.12 806.213,1303.12 806.223,1303.12 806.232,1303.12 806.241,1303.12 806.25,1303.12 806.259,1303.12 806.269,1303.12 806.278,1303.12 806.287,1303.12 806.296,1303.12 806.305,1303.12 806.315,1303.12 806.324,1303.12 806.333,1303.12 806.342,1303.12 806.351,1303.12 806.36,1303.12 806.37,1303.12 806.379,1303.12 806.388,1303.12 806.397,1303.12 806.406,1303.12 806.416,1303.12 806.425,1303.12 806.434,1303.12 806.443,1303.12 806.452,1303.12 806.462,1303.12 806.471,1303.13 806.48,1303.13 806.489,1303.13 806.498,1303.13 806.507,1303.13 806.517,1303.13 806.526,1303.13 806.535,1303.13 806.544,1303.13 806.553,1303.13 806.563,1303.13 806.572,1303.13 806.581,1303.13 806.59,1303.13 806.599,1303.13 806.609,1303.13 806.618,1303.13 806.627,1303.13 806.636,1303.13 806.645,1303.13 806.655,1303.13 806.664,1303.13 806.673,1303.13 806.682,1303.13 806.691,1303.13 806.7,1303.13 806.71,1303.13 806.719,1303.13 806.728,1303.13 806.737,1303.13 806.746,1303.14 806.756,1303.14 806.765,1303.14 806.774,1303.14 806.783,1303.14 806.792,1303.14 806.802,1303.14 806.811,1303.14 806.82,1303.14 806.829,1303.14 806.838,1303.14 806.847,1303.14 806.857,1303.14 806.866,1303.14 806.875,1303.14 806.884,1303.14 806.893,1303.14 806.903,1303.14 806.912,1303.14 806.921,1303.14 806.93,1303.14 806.939,1303.14 806.949,1303.14 806.958,1303.14 806.967,1303.14 806.976,1303.14 806.985,1303.14 806.995,1303.14 807.004,1303.14 807.013,1303.14 807.022,1303.15 807.031,1303.15 807.04,1303.15 807.05,1303.15 807.059,1303.15 807.068,1303.15 807.077,1303.15 807.086,1303.15 807.096,1303.15 807.105,1303.15 807.114,1303.15 807.123,1303.15 807.132,1303.15 807.142,1303.15 807.151,1303.15 807.16,1303.15 807.169,1303.15 807.178,1303.15 807.188,1303.15 807.197,1303.15 807.206,1303.15 807.215,1303.15 807.224,1303.15 807.233,1303.15 807.243,1303.15 807.252,1303.15 807.261,1303.15 807.27,1303.15 807.279,1303.15 807.289,1303.15 807.298,1303.16 807.307,1303.16 807.316,1303.16 807.325,1303.16 807.335,1303.16 807.344,1303.16 807.353,1303.16 807.362,1303.16 807.371,1303.16 807.38,1303.16 807.39,1303.16 807.399,1303.16 807.408,1303.16 807.417,1303.16 807.426,1303.16 807.436,1303.16 807.445,1303.16 807.454,1303.16 807.463,1303.16 807.472,1303.16 807.482,1303.16 807.491,1303.16 807.5,1303.16 807.509,1303.16 807.518,1303.16 807.528,1303.16 807.537,1303.16 807.546,1303.16 807.555,1303.16 807.564,1303.16 807.573,1303.17 807.583,1303.17 807.592,1303.17 807.601,1303.17 807.61,1303.17 807.619,1303.17 807.629,1303.17 807.638,1303.17 807.647,1303.17 807.656,1303.17 807.665,1303.17 807.675,1303.17 807.684,1303.17 807.693,1303.17 807.702,1303.17 807.711,1303.17 807.72,1303.17 807.73,1303.17 807.739,1303.17 807.748,1303.17 807.757,1303.17 807.766,1303.17 807.776,1303.17 807.785,1303.17 807.794,1303.17 807.803,1303.17 807.812,1303.17 807.822,1303.17 807.831,1303.17 807.84,1303.17 807.849,1303.18 807.858,1303.18 807.868,1303.18 807.877,1303.18 807.886,1303.18 807.895,1303.18 807.904,1303.18 807.913,1303.18 807.923,1303.18 807.932,1303.18 807.941,1303.18 807.95,1303.18 807.959,1303.18 807.969,1303.18 807.978,1303.18 807.987,1303.18 807.996,1303.18 808.005,1303.18 808.015,1303.18 808.024,1303.18 808.033,1303.18 808.042,1303.18 808.051,1303.18 808.06,1303.18 808.07,1303.18 808.079,1303.18 808.088,1303.18 808.097,1303.18 808.106,1303.18 808.116,1303.18 808.125,1303.19 808.134,1303.19 808.143,1303.19 808.152,1303.19 808.162,1303.19 808.171,1303.19 808.18,1303.19 808.189,1303.19 808.198,1303.19 808.208,1303.19 808.217,1303.19 808.226,1303.19 808.235,1303.19 808.244,1303.19 808.253,1303.19 808.263,1303.19 808.272,1303.19 808.281,1303.19 808.29,1303.19 808.299,1303.19 808.309,1303.19 808.318,1303.19 808.327,1303.19 808.336,1303.19 808.345,1303.19 808.355,1303.19 808.364,1303.19 808.373,1303.19 808.382,1303.19 808.391,1303.19 808.4,1303.19 808.41,1303.2 808.419,1303.2 808.428,1303.2 808.437,1303.2 808.446,1303.2 808.456,1303.2 808.465,1303.2 808.474,1303.2 808.483,1303.2 808.492,1303.2 808.502,1303.2 808.511,1303.2 808.52,1303.2 808.529,1303.2 808.538,1303.2 808.548,1303.2 808.557,1303.2 808.566,1303.2 808.575,1303.2 808.584,1303.2 808.593,1303.2 808.603,1303.2 808.612,1303.2 808.621,1303.2 808.63,1303.2 808.639,1303.2 808.649,1303.2 808.658,1303.2 808.667,1303.2 808.676,1303.2 808.685,1303.21 808.695,1303.21 808.704,1303.21 808.713,1303.21 808.722,1303.21 808.731,1303.21 808.74,1303.21 808.75,1303.21 808.759,1303.21 808.768,1303.21 808.777,1303.21 808.786,1303.21 808.796,1303.21 808.805,1303.21 808.814,1303.21 808.823,1303.21 808.832,1303.21 808.842,1303.21 808.851,1303.21 808.86,1303.21 808.869,1303.21 808.878,1303.21 808.888,1303.21 808.897,1303.21 808.906,1303.21 808.915,1303.21 808.924,1303.21 808.933,1303.21 808.943,1303.21 808.952,1303.21 808.961,1303.22 808.97,1303.22 808.979,1303.22 808.989,1303.22 808.998,1303.22 809.007,1303.22 809.016,1303.22 809.025,1303.22 809.035,1303.22 809.044,1303.22 809.053,1303.22 809.062,1303.22 809.071,1303.22 809.08,1303.22 809.09,1303.22 809.099,1303.22 809.108,1303.22 809.117,1303.22 809.126,1303.22 809.136,1303.22 809.145,1303.22 809.154,1303.22 809.163,1303.22 809.172,1303.22 809.182,1303.22 809.191,1303.22 809.2,1303.22 809.209,1303.22 809.218,1303.22 809.228,1303.22 809.237,1303.23 809.246,1303.23 809.255,1303.23 809.264,1303.23 809.273,1303.23 809.283,1303.23 809.292,1303.23 809.301,1303.23 809.31,1303.23 809.319,1303.23 809.329,1303.23 809.338,1303.23 809.347,1303.23 809.356,1303.23 809.365,1303.23 809.375,1303.23 809.384,1303.23 809.393,1303.23 809.402,1303.23 809.411,1303.23 809.42,1303.23 809.43,1303.23 809.439,1303.23 809.448,1303.23 809.457,1303.23 809.466,1303.23 809.476,1303.23 809.485,1303.23 809.494,1303.23 809.503,1303.23 809.512,1303.24 809.522,1303.24 809.531,1303.24 809.54,1303.24 809.549,1303.24 809.558,1303.24 809.568,1303.24 809.577,1303.24 809.586,1303.24 809.595,1303.24 809.604,1303.24 809.613,1303.24 809.623,1303.24 809.632,1303.24 809.641,1303.24 809.65,1303.24 809.659,1303.24 809.669,1303.24 809.678,1303.24 809.687,1303.24 809.696,1303.24 809.705,1303.24 809.715,1303.24 809.724,1303.24 809.733,1303.24 809.742,1303.24 809.751,1303.24 809.761,1303.24 809.77,1303.24 809.779,1303.24 809.788,1303.24 809.797,1303.25 809.806,1303.25 809.816,1303.25 809.825,1303.25 809.834,1303.25 809.843,1303.25 809.852,1303.25 809.862,1303.25 809.871,1303.25 809.88,1303.25 809.889,1303.25 809.898,1303.25 809.908,1303.25 809.917,1303.25 809.926,1303.25 809.935,1303.25 809.944,1303.25 809.953,1303.25 809.963,1303.25 809.972,1303.25 809.981,1303.25 809.99,1303.25 809.999,1303.25 810.009,1303.25 810.018,1303.25 810.027,1303.25 810.036,1303.25 810.045,1303.25 810.055,1303.25 810.064,1303.25 810.073,1303.26 810.082,1303.26 810.091,1303.26 810.101,1303.26 810.11,1303.26 810.119,1303.26 810.128,1303.26 810.137,1303.26 810.146,1303.26 810.156,1303.26 810.165,1303.26 810.174,1303.26 810.183,1303.26 810.192,1303.26 810.202,1303.26 810.211,1303.26 810.22,1303.26 810.229,1303.26 810.238,1303.26 810.248,1303.26 810.257,1303.26 810.266,1303.26 810.275,1303.26 810.284,1303.26 810.293,1303.26 810.303,1303.26 810.312,1303.26 810.321,1303.26 810.33,1303.26 810.339,1303.26 810.349,1303.27 810.358,1303.27 810.367,1303.27 810.376,1303.27 810.385,1303.27 810.395,1303.27 810.404,1303.27 810.413,1303.27 810.422,1303.27 810.431,1303.27 810.441,1303.27 810.45,1303.27 810.459,1303.27 810.468,1303.27 810.477,1303.27 810.486,1303.27 810.496,1303.27 810.505,1303.27 810.514,1303.27 810.523,1303.27 810.532,1303.27 810.542,1303.27 810.551,1303.27 810.56,1303.27 810.569,1303.27 810.578,1303.27 810.588,1303.27 810.597,1303.27 810.606,1303.27 810.615,1303.27 810.624,1303.28 810.633,1303.28 810.643,1303.28 810.652,1303.28 810.661,1303.28 810.67,1303.28 810.679,1303.28 810.689,1303.28 810.698,1303.28 810.707,1303.28 810.716,1303.28 810.725,1303.28 810.735,1303.28 810.744,1303.28 810.753,1303.28 810.762,1303.28 810.771,1303.28 810.781,1303.28 810.79,1303.28 810.799,1303.28 810.808,1303.28 810.817,1303.28 810.826,1303.28 810.836,1303.28 810.845,1303.28 810.854,1303.28 810.863,1303.28 810.872,1303.28 810.882,1303.28 810.891,1303.28 810.9,1303.28 810.909,1303.29 810.918,1303.29 810.928,1303.29 810.937,1303.29 810.946,1303.29 810.955,1303.29 810.964,1303.29 810.973,1303.29 810.983,1303.29 810.992,1303.29 811.001,1303.29 811.01,1303.29 811.019,1303.29 811.029,1303.29 811.038,1303.29 811.047,1303.29 811.056,1303.29 811.065,1303.29 811.075,1303.29 811.084,1303.29 811.093,1303.29 811.102,1303.29 811.111,1303.29 811.121,1303.29 811.13,1303.29 811.139,1303.29 811.148,1303.29 811.157,1303.29 811.166,1303.29 811.176,1303.29 811.185,1303.3 811.194,1303.3 811.203,1303.3 811.212,1303.3 811.222,1303.3 811.231,1303.3 811.24,1303.3 811.249,1303.3 811.258,1303.3 811.268,1303.3 811.277,1303.3 811.286,1303.3 811.295,1303.3 811.304,1303.3 811.313,1303.3 811.323,1303.3 811.332,1303.3 811.341,1303.3 811.35,1303.3 811.359,1303.3 811.369,1303.3 811.378,1303.3 811.387,1303.3 811.396,1303.3 811.405,1303.3 811.415,1303.3 811.424,1303.3 811.433,1303.3 811.442,1303.3 811.451,1303.3 811.461,1303.31 811.47,1303.31 811.479,1303.31 811.488,1303.31 811.497,1303.31 811.506,1303.31 811.516,1303.31 811.525,1303.31 811.534,1303.31 811.543,1303.31 811.552,1303.31 811.562,1303.31 811.571,1303.31 811.58,1303.31 811.589,1303.31 811.598,1303.31 811.608,1303.31 811.617,1303.31 811.626,1303.31 811.635,1303.31 811.644,1303.31 811.653,1303.31 811.663,1303.31 811.672,1303.31 811.681,1303.31 811.69,1303.31 811.699,1303.31 811.709,1303.31 811.718,1303.31 811.727,1303.31 811.736,1303.31 811.745,1303.32 811.755,1303.32 811.764,1303.32 811.773,1303.32 811.782,1303.32 811.791,1303.32 811.801,1303.32 811.81,1303.32 811.819,1303.32 811.828,1303.32 811.837,1303.32 811.846,1303.32 811.856,1303.32 811.865,1303.32 811.874,1303.32 811.883,1303.32 811.892,1303.32 811.902,1303.32 811.911,1303.32 811.92,1303.32 811.929,1303.32 811.938,1303.32 811.948,1303.32 811.957,1303.32 811.966,1303.32 811.975,1303.32 811.984,1303.32 811.993,1303.32 812.003,1303.32 812.012,1303.32 812.021,1303.33 812.03,1303.33 812.039,1303.33 812.049,1303.33 812.058,1303.33 812.067,1303.33 812.076,1303.33 812.085,1303.33 812.095,1303.33 812.104,1303.33 812.113,1303.33 812.122,1303.33 812.131,1303.33 812.141,1303.33 812.15,1303.33 812.159,1303.33 812.168,1303.33 812.177,1303.33 812.186,1303.33 812.196,1303.33 812.205,1303.33 812.214,1303.33 812.223,1303.33 812.232,1303.33 812.242,1303.33 812.251,1303.33 812.26,1303.33 812.269,1303.33 812.278,1303.33 812.288,1303.33 812.297,1303.34 812.306,1303.34 812.315,1303.34 812.324,1303.34 812.334,1303.34 812.343,1303.34 812.352,1303.34 812.361,1303.34 812.37,1303.34 812.379,1303.34 812.389,1303.34 812.398,1303.34 812.407,1303.34 812.416,1303.34 812.425,1303.34 812.435,1303.34 812.444,1303.34 812.453,1303.34 812.462,1303.34 812.471,1303.34 812.481,1303.34 812.49,1303.34 812.499,1303.34 812.508,1303.34 812.517,1303.34 812.526,1303.34 812.536,1303.34 812.545,1303.34 812.554,1303.34 812.563,1303.34 812.572,1303.35 812.582,1303.35 812.591,1303.35 812.6,1303.35 812.609,1303.35 812.618,1303.35 812.628,1303.35 812.637,1303.35 812.646,1303.35 812.655,1303.35 812.664,1303.35 812.674,1303.35 812.683,1303.35 812.692,1303.35 812.701,1303.35 812.71,1303.35 812.719,1303.35 812.729,1303.35 812.738,1303.35 812.747,1303.35 812.756,1303.35 812.765,1303.35 812.775,1303.35 812.784,1303.35 812.793,1303.35 812.802,1303.35 812.811,1303.35 812.821,1303.35 812.83,1303.35 812.839,1303.35 812.848,1303.35 812.857,1303.36 812.866,1303.36 812.876,1303.36 812.885,1303.36 812.894,1303.36 812.903,1303.36 812.912,1303.36 812.922,1303.36 812.931,1303.36 812.94,1303.36 812.949,1303.36 812.958,1303.36 812.968,1303.36 812.977,1303.36 812.986,1303.36 812.995,1303.36 813.004,1303.36 813.014,1303.36 813.023,1303.36 813.032,1303.36 813.041,1303.36 813.05,1303.36 813.059,1303.36 813.069,1303.36 813.078,1303.36 813.087,1303.36 813.096,1303.36 813.105,1303.36 813.115,1303.36 813.124,1303.36 813.133,1303.37 813.142,1303.37 813.151,1303.37 813.161,1303.37 813.17,1303.37 813.179,1303.37 813.188,1303.37 813.197,1303.37 813.206,1303.37 813.216,1303.37 813.225,1303.37 813.234,1303.37 813.243,1303.37 813.252,1303.37 813.262,1303.37 813.271,1303.37 813.28,1303.37 813.289,1303.37 813.298,1303.37 813.308,1303.37 813.317,1303.37 813.326,1303.37 813.335,1303.37 813.344,1303.37 813.354,1303.37 813.363,1303.37 813.372,1303.37 813.381,1303.37 813.39,1303.37 813.399,1303.37 813.409,1303.38 813.418,1303.38 813.427,1303.38 813.436,1303.38 813.445,1303.38 813.455,1303.38 813.464,1303.38 813.473,1303.38 813.482,1303.38 813.491,1303.38 813.501,1303.38 813.51,1303.38 813.519,1303.38 813.528,1303.38 813.537,1303.38 813.546,1303.38 813.556,1303.38 813.565,1303.38 813.574,1303.38 813.583,1303.38 813.592,1303.38 813.602,1303.38 813.611,1303.38 813.62,1303.38 813.629,1303.38 813.638,1303.38 813.648,1303.38 813.657,1303.38 813.666,1303.38 813.675,1303.38 813.684,1303.38 813.694,1303.39 813.703,1303.39 813.712,1303.39 813.721,1303.39 813.73,1303.39 813.739,1303.39 813.749,1303.39 813.758,1303.39 813.767,1303.39 813.776,1303.39 813.785,1303.39 813.795,1303.39 813.804,1303.39 813.813,1303.39 813.822,1303.39 813.831,1303.39 813.841,1303.39 813.85,1303.39 813.859,1303.39 813.868,1303.39 813.877,1303.39 813.886,1303.39 813.896,1303.39 813.905,1303.39 813.914,1303.39 813.923,1303.39 813.932,1303.39 813.942,1303.39 813.951,1303.39 813.96,1303.39 813.969,1303.4 813.978,1303.4 813.988,1303.4 813.997,1303.4 814.006,1303.4 814.015,1303.4 814.024,1303.4 814.034,1303.4 814.043,1303.4 814.052,1303.4 814.061,1303.4 814.07,1303.4 814.079,1303.4 814.089,1303.4 814.098,1303.4 814.107,1303.4 814.116,1303.4 814.125,1303.4 814.135,1303.4 814.144,1303.4 814.153,1303.4 814.162,1303.4 814.171,1303.4 814.181,1303.4 814.19,1303.4 814.199,1303.4 814.208,1303.4 814.217,1303.4 814.226,1303.4 814.236,1303.4 814.245,1303.41 814.254,1303.41 814.263,1303.41 814.272,1303.41 814.282,1303.41 814.291,1303.41 814.3,1303.41 814.309,1303.41 814.318,1303.41 814.328,1303.41 814.337,1303.41 814.346,1303.41 814.355,1303.41 814.364,1303.41 814.374,1303.41 814.383,1303.41 814.392,1303.41 814.401,1303.41 814.41,1303.41 814.419,1303.41 814.429,1303.41 814.438,1303.41 814.447,1303.41 814.456,1303.41 814.465,1303.41 814.475,1303.41 814.484,1303.41 814.493,1303.41 814.502,1303.41 814.511,1303.41 814.521,1303.41 814.53,1303.42 814.539,1303.42 814.548,1303.42 814.557,1303.42 814.566,1303.42 814.576,1303.42 814.585,1303.42 814.594,1303.42 814.603,1303.42 814.612,1303.42 814.622,1303.42 814.631,1303.42 814.64,1303.42 814.649,1303.42 814.658,1303.42 814.668,1303.42 814.677,1303.42 814.686,1303.42 814.695,1303.42 814.704,1303.42 814.714,1303.42 814.723,1303.42 814.732,1303.42 814.741,1303.42 814.75,1303.42 814.759,1303.42 814.769,1303.42 814.778,1303.42 814.787,1303.42 814.796,1303.42 814.805,1303.43 814.815,1303.43 814.824,1303.43 814.833,1303.43 814.842,1303.43 814.851,1303.43 814.861,1303.43 814.87,1303.43 814.879,1303.43 814.888,1303.43 814.897,1303.43 814.907,1303.43 814.916,1303.43 814.925,1303.43 814.934,1303.43 814.943,1303.43 814.952,1303.43 814.962,1303.43 814.971,1303.43 814.98,1303.43 814.989,1303.43 814.998,1303.43 815.008,1303.43 815.017,1303.43 815.026,1303.43 815.035,1303.43 815.044,1303.43 815.054,1303.43 815.063,1303.43 815.072,1303.43 815.081,1303.44 815.09,1303.44 815.099,1303.44 815.109,1303.44 815.118,1303.44 815.127,1303.44 815.136,1303.44 815.145,1303.44 815.155,1303.44 815.164,1303.44 815.173,1303.44 815.182,1303.44 815.191,1303.44 815.201,1303.44 815.21,1303.44 815.219,1303.44 815.228,1303.44 815.237,1303.44 815.247,1303.44 815.256,1303.44 815.265,1303.44 815.274,1303.44 815.283,1303.44 815.292,1303.44 815.302,1303.44 815.311,1303.44 815.32,1303.44 815.329,1303.44 815.338,1303.44 815.348,1303.44 815.357,1303.45 815.366,1303.45 815.375,1303.45 815.384,1303.45 815.394,1303.45 815.403,1303.45 815.412,1303.45 815.421,1303.45 815.43,1303.45 815.439,1303.45 815.449,1303.45 815.458,1303.45 815.467,1303.45 815.476,1303.45 815.485,1303.45 815.495,1303.45 815.504,1303.45 815.513,1303.45 815.522,1303.45 815.531,1303.45 815.541,1303.45 815.55,1303.45 815.559,1303.45 815.568,1303.45 815.577,1303.45 815.587,1303.45 815.596,1303.45 815.605,1303.45 815.614,1303.45 815.623,1303.45 815.632,1303.45 815.642,1303.46 815.651,1303.46 815.66,1303.46 815.669,1303.46 815.678,1303.46 815.688,1303.46 815.697,1303.46 815.706,1303.46 815.715,1303.46 815.724,1303.46 815.734,1303.46 815.743,1303.46 815.752,1303.46 815.761,1303.46 815.77,1303.46 815.779,1303.46 815.789,1303.46 815.798,1303.46 815.807,1303.46 815.816,1303.46 815.825,1303.46 815.835,1303.46 815.844,1303.46 815.853,1303.46 815.862,1303.46 815.871,1303.46 815.881,1303.46 815.89,1303.46 815.899,1303.46 815.908,1303.46 815.917,1303.47 815.927,1303.47 815.936,1303.47 815.945,1303.47 815.954,1303.47 815.963,1303.47 815.972,1303.47 815.982,1303.47 815.991,1303.47 816,1303.47 816.009,1303.47 816.018,1303.47 816.028,1303.47 816.037,1303.47 816.046,1303.47 816.055,1303.47 816.064,1303.47 816.074,1303.47 816.083,1303.47 816.092,1303.47 816.101,1303.47 816.11,1303.47 816.119,1303.47 816.129,1303.47 816.138,1303.47 816.147,1303.47 816.156,1303.47 816.165,1303.47 816.175,1303.47 816.184,1303.47 816.193,1303.48 816.202,1303.48 816.211,1303.48 816.221,1303.48 816.23,1303.48 816.239,1303.48 816.248,1303.48 816.257,1303.48 816.267,1303.48 816.276,1303.48 816.285,1303.48 816.294,1303.48 816.303,1303.48 816.312,1303.48 816.322,1303.48 816.331,1303.48 816.34,1303.48 816.349,1303.48 816.358,1303.48 816.368,1303.48 816.377,1303.48 816.386,1303.48 816.395,1303.48 816.404,1303.48 816.414,1303.48 816.423,1303.48 816.432,1303.48 816.441,1303.48 816.45,1303.48 816.459,1303.48 816.469,1303.49 816.478,1303.49 816.487,1303.49 816.496,1303.49 816.505,1303.49 816.515,1303.49 816.524,1303.49 816.533,1303.49 816.542,1303.49 816.551,1303.49 816.561,1303.49 816.57,1303.49 816.579,1303.49 816.588,1303.49 816.597,1303.49 816.607,1303.49 816.616,1303.49 816.625,1303.49 816.634,1303.49 816.643,1303.49 816.652,1303.49 816.662,1303.49 816.671,1303.49 816.68,1303.49 816.689,1303.49 816.698,1303.49 816.708,1303.49 816.717,1303.49 816.726,1303.49 816.735,1303.49 816.744,1303.5 816.754,1303.5 816.763,1303.5 816.772,1303.5 816.781,1303.5 816.79,1303.5 816.799,1303.5 816.809,1303.5 816.818,1303.5 816.827,1303.5 816.836,1303.5 816.845,1303.5 816.855,1303.5 816.864,1303.5 816.873,1303.5 816.882,1303.5 816.891,1303.5 816.901,1303.5 816.91,1303.5 816.919,1303.5 816.928,1303.5 816.937,1303.5 816.947,1303.5 816.956,1303.5 816.965,1303.5 816.974,1303.5 816.983,1303.5 816.992,1303.5 817.002,1303.5 817.011,1303.5 817.02,1303.51 817.029,1303.51 817.038,1303.51 817.048,1303.51 817.057,1303.51 817.066,1303.51 817.075,1303.51 817.084,1303.51 817.094,1303.51 817.103,1303.51 817.112,1303.51 817.121,1303.51 817.13,1303.51 817.14,1303.51 817.149,1303.51 817.158,1303.51 817.167,1303.51 817.176,1303.51 817.185,1303.51 817.195,1303.51 817.204,1303.51 817.213,1303.51 817.222,1303.51 817.231,1303.51 817.241,1303.51 817.25,1303.51 817.259,1303.51 817.268,1303.51 817.277,1303.51 817.287,1303.51 817.296,1303.51 817.305,1303.52 817.314,1303.52 817.323,1303.52 817.332,1303.52 817.342,1303.52 817.351,1303.52 817.36,1303.52 817.369,1303.52 817.378,1303.52 817.388,1303.52 817.397,1303.52 817.406,1303.52 817.415,1303.52 817.424,1303.52 817.434,1303.52 817.443,1303.52 817.452,1303.52 817.461,1303.52 817.47,1303.52 817.48,1303.52 817.489,1303.52 817.498,1303.52 817.507,1303.52 817.516,1303.52 817.525,1303.52 817.535,1303.52 817.544,1303.52 817.553,1303.52 817.562,1303.52 817.571,1303.52 817.581,1303.53 817.59,1303.53 817.599,1303.53 817.608,1303.53 817.617,1303.53 817.627,1303.53 817.636,1303.53 817.645,1303.53 817.654,1303.53 817.663,1303.53 817.672,1303.53 817.682,1303.53 817.691,1303.53 817.7,1303.53 817.709,1303.53 817.718,1303.53 817.728,1303.53 817.737,1303.53 817.746,1303.53 817.755,1303.53 817.764,1303.53 817.774,1303.53 817.783,1303.53 817.792,1303.53 817.801,1303.53 817.81,1303.53 817.82,1303.53 817.829,1303.53 817.838,1303.53 817.847,1303.53 817.856,1303.54 817.865,1303.54 817.875,1303.54 817.884,1303.54 817.893,1303.54 817.902,1303.54 817.911,1303.54 817.921,1303.54 817.93,1303.54 817.939,1303.54 817.948,1303.54 817.957,1303.54 817.967,1303.54 817.976,1303.54 817.985,1303.54 817.994,1303.54 818.003,1303.54 818.012,1303.54 818.022,1303.54 818.031,1303.54 818.04,1303.54 818.049,1303.54 818.058,1303.54 818.068,1303.54 818.077,1303.54 818.086,1303.54 818.095,1303.54 818.104,1303.54 818.114,1303.54 818.123,1303.54 818.132,1303.55 818.141,1303.55 818.15,1303.55 818.16,1303.55 818.169,1303.55 818.178,1303.55 818.187,1303.55 818.196,1303.55 818.205,1303.55 818.215,1303.55 818.224,1303.55 818.233,1303.55 818.242,1303.55 818.251,1303.55 818.261,1303.55 818.27,1303.55 818.279,1303.55 818.288,1303.55 818.297,1303.55 818.307,1303.55 818.316,1303.55 818.325,1303.55 818.334,1303.55 818.343,1303.55 818.352,1303.55 818.362,1303.55 818.371,1303.55 818.38,1303.55 818.389,1303.55 818.398,1303.55 818.408,1303.56 818.417,1303.56 818.426,1303.56 818.435,1303.56 818.444,1303.56 818.454,1303.56 818.463,1303.56 818.472,1303.56 818.481,1303.56 818.49,1303.56 818.5,1303.56 818.509,1303.56 818.518,1303.56 818.527,1303.56 818.536,1303.56 818.545,1303.56 818.555,1303.56 818.564,1303.56 818.573,1303.56 818.582,1303.56 818.591,1303.56 818.601,1303.56 818.61,1303.56 818.619,1303.56 818.628,1303.56 818.637,1303.56 818.647,1303.56 818.656,1303.56 818.665,1303.56 818.674,1303.56 818.683,1303.57 818.692,1303.57 818.702,1303.57 818.711,1303.57 818.72,1303.57 818.729,1303.57 818.738,1303.57 818.748,1303.57 818.757,1303.57 818.766,1303.57 818.775,1303.57 818.784,1303.57 818.794,1303.57 818.803,1303.57 818.812,1303.57 818.821,1303.57 818.83,1303.57 818.84,1303.57 818.849,1303.57 818.858,1303.57 818.867,1303.57 818.876,1303.57 818.885,1303.57 818.895,1303.57 818.904,1303.57 818.913,1303.57 818.922,1303.57 818.931,1303.57 818.941,1303.57 818.95,1303.57 818.959,1303.58 818.968,1303.58 818.977,1303.58 818.987,1303.58 818.996,1303.58 819.005,1303.58 819.014,1303.58 819.023,1303.58 819.032,1303.58 819.042,1303.58 819.051,1303.58 819.06,1303.58 819.069,1303.58 819.078,1303.58 819.088,1303.58 819.097,1303.58 819.106,1303.58 819.115,1303.58 819.124,1303.58 819.134,1303.58 819.143,1303.58 819.152,1303.58 819.161,1303.58 819.17,1303.58 819.18,1303.58 819.189,1303.58 819.198,1303.58 819.207,1303.58 819.216,1303.58 819.225,1303.58 819.235,1303.59 819.244,1303.59 819.253,1303.59 819.262,1303.59 819.271,1303.59 819.281,1303.59 819.29,1303.59 819.299,1303.59 819.308,1303.59 819.317,1303.59 819.327,1303.59 819.336,1303.59 819.345,1303.59 819.354,1303.59 819.363,1303.59 819.372,1303.59 819.382,1303.59 819.391,1303.59 819.4,1303.59 819.409,1303.59 819.418,1303.59 819.428,1303.59 819.437,1303.59 819.446,1303.59 819.455,1303.59 819.464,1303.59 819.474,1303.59 819.483,1303.59 819.492,1303.59 819.501,1303.6 819.51,1303.6 819.52,1303.6 819.529,1303.6 819.538,1303.6 819.547,1303.6 819.556,1303.6 819.565,1303.6 819.575,1303.6 819.584,1303.6 819.593,1303.6 819.602,1303.6 819.611,1303.6 819.621,1303.6 819.63,1303.6 819.639,1303.6 819.648,1303.6 819.657,1303.6 819.667,1303.6 819.676,1303.6 819.685,1303.6 819.694,1303.6 819.703,1303.6 819.713,1303.6 819.722,1303.6 819.731,1303.6 819.74,1303.6 819.749,1303.6 819.758,1303.6 819.768,1303.6 819.777,1303.61 819.786,1303.61 819.795,1303.61 819.804,1303.61 819.814,1303.61 819.823,1303.61 819.832,1303.61 819.841,1303.61 819.85,1303.61 819.86,1303.61 819.869,1303.61 819.878,1303.61 819.887,1303.61 819.896,1303.61 819.905,1303.61 819.915,1303.61 819.924,1303.61 819.933,1303.61 819.942,1303.61 819.951,1303.61 819.961,1303.61 819.97,1303.61 819.979,1303.61 819.988,1303.61 819.997,1303.61 820.007,1303.61 820.016,1303.61 820.025,1303.61 820.034,1303.61 820.043,1303.61 820.053,1303.62 820.062,1303.62 820.071,1303.62 820.08,1303.62 820.089,1303.62 820.098,1303.62 820.108,1303.62 820.117,1303.62 820.126,1303.62 820.135,1303.62 820.144,1303.62 820.154,1303.62 820.163,1303.62 820.172,1303.62 820.181,1303.62 820.19,1303.62 820.2,1303.62 820.209,1303.62 820.218,1303.62 820.227,1303.62 820.236,1303.62 820.245,1303.62 820.255,1303.62 820.264,1303.62 820.273,1303.62 820.282,1303.62 820.291,1303.62 820.301,1303.62 820.31,1303.62 820.319,1303.62 820.328,1303.63 820.337,1303.63 820.347,1303.63 820.356,1303.63 820.365,1303.63 820.374,1303.63 820.383,1303.63 820.393,1303.63 820.402,1303.63 820.411,1303.63 820.42,1303.63 820.429,1303.63 820.438,1303.63 820.448,1303.63 820.457,1303.63 820.466,1303.63 820.475,1303.63 820.484,1303.63 820.494,1303.63 820.503,1303.63 820.512,1303.63 820.521,1303.63 820.53,1303.63 820.54,1303.63 820.549,1303.63 820.558,1303.63 820.567,1303.63 820.576,1303.63 820.585,1303.63 820.595,1303.63 820.604,1303.64 820.613,1303.64 820.622,1303.64 820.631,1303.64 820.641,1303.64 820.65,1303.64 820.659,1303.64 820.668,1303.64 820.677,1303.64 820.687,1303.64 820.696,1303.64 820.705,1303.64 820.714,1303.64 820.723,1303.64 820.733,1303.64 820.742,1303.64 820.751,1303.64 820.76,1303.64 820.769,1303.64 820.778,1303.64 820.788,1303.64 820.797,1303.64 820.806,1303.64 820.815,1303.64 820.824,1303.64 820.834,1303.64 820.843,1303.64 820.852,1303.64 820.861,1303.64 820.87,1303.65 820.88,1303.65 820.889,1303.65 820.898,1303.65 820.907,1303.65 820.916,1303.65 820.925,1303.65 820.935,1303.65 820.944,1303.65 820.953,1303.65 820.962,1303.65 820.971,1303.65 820.981,1303.65 820.99,1303.65 820.999,1303.65 821.008,1303.65 821.017,1303.65 821.027,1303.65 821.036,1303.65 821.045,1303.65 821.054,1303.65 821.063,1303.65 821.073,1303.65 821.082,1303.65 821.091,1303.65 821.1,1303.65 821.109,1303.65 821.118,1303.65 821.128,1303.65 821.137,1303.65 821.146,1303.66 821.155,1303.66 821.164,1303.66 821.174,1303.66 821.183,1303.66 821.192,1303.66 821.201,1303.66 821.21,1303.66 821.22,1303.66 821.229,1303.66 821.238,1303.66 821.247,1303.66 821.256,1303.66 821.265,1303.66 821.275,1303.66 821.284,1303.66 821.293,1303.66 821.302,1303.66 821.311,1303.66 821.321,1303.66 821.33,1303.66 821.339,1303.66 821.348,1303.66 821.357,1303.66 821.367,1303.66 821.376,1303.66 821.385,1303.66 821.394,1303.66 821.403,1303.66 821.413,1303.66 821.422,1303.67 821.431,1303.67 821.44,1303.67 821.449,1303.67 821.458,1303.67 821.468,1303.67 821.477,1303.67 821.486,1303.67 821.495,1303.67 821.504,1303.67 821.514,1303.67 821.523,1303.67 821.532,1303.67 821.541,1303.67 821.55,1303.67 821.56,1303.67 821.569,1303.67 821.578,1303.67 821.587,1303.67 821.596,1303.67 821.605,1303.67 821.615,1303.67 821.624,1303.67 821.633,1303.67 821.642,1303.67 821.651,1303.67 821.661,1303.67 821.67,1303.67 821.679,1303.67 821.688,1303.68 821.697,1303.68 821.707,1303.68 821.716,1303.68 821.725,1303.68 821.734,1303.68 821.743,1303.68 821.753,1303.68 821.762,1303.68 821.771,1303.68 821.78,1303.68 821.789,1303.68 821.798,1303.68 821.808,1303.68 821.817,1303.68 821.826,1303.68 821.835,1303.68 821.844,1303.68 821.854,1303.68 821.863,1303.68 821.872,1303.68 821.881,1303.68 821.89,1303.68 821.9,1303.68 821.909,1303.68 821.918,1303.68 821.927,1303.68 821.936,1303.68 821.945,1303.68 821.955,1303.68 821.964,1303.69 821.973,1303.69 821.982,1303.69 821.991,1303.69 822.001,1303.69 822.01,1303.69 822.019,1303.69 822.028,1303.69 822.037,1303.69 822.047,1303.69 822.056,1303.69 822.065,1303.69 822.074,1303.69 822.083,1303.69 822.093,1303.69 822.102,1303.69 822.111,1303.69 822.12,1303.69 822.129,1303.69 822.138,1303.69 822.148,1303.69 822.157,1303.69 822.166,1303.69 822.175,1303.69 822.184,1303.69 822.194,1303.69 822.203,1303.69 822.212,1303.69 822.221,1303.69 822.23,1303.7 822.24,1303.7 822.249,1303.7 822.258,1303.7 822.267,1303.7 822.276,1303.7 822.286,1303.7 822.295,1303.7 822.304,1303.7 822.313,1303.7 822.322,1303.7 822.331,1303.7 822.341,1303.7 822.35,1303.7 822.359,1303.7 822.368,1303.7 822.377,1303.7 822.387,1303.7 822.396,1303.7 822.405,1303.7 822.414,1303.7 822.423,1303.7 822.433,1303.7 822.442,1303.7 822.451,1303.7 822.46,1303.7 822.469,1303.7 822.478,1303.7 822.488,1303.7 822.497,1303.7 822.506,1303.71 822.515,1303.71 822.524,1303.71 822.534,1303.71 822.543,1303.71 822.552,1303.71 822.561,1303.71 822.57,1303.71 822.58,1303.71 822.589,1303.71 822.598,1303.71 822.607,1303.71 822.616,1303.71 822.626,1303.71 822.635,1303.71 822.644,1303.71 822.653,1303.71 822.662,1303.71 822.671,1303.71 822.681,1303.71 822.69,1303.71 822.699,1303.71 822.708,1303.71 822.717,1303.71 822.727,1303.71 822.736,1303.71 822.745,1303.71 822.754,1303.71 822.763,1303.71 822.773,1303.72 822.782,1303.72 822.791,1303.72 822.8,1303.72 822.809,1303.72 822.818,1303.72 822.828,1303.72 822.837,1303.72 822.846,1303.72 822.855,1303.72 822.864,1303.72 822.874,1303.72 822.883,1303.72 822.892,1303.72 822.901,1303.72 822.91,1303.72 822.92,1303.72 822.929,1303.72 822.938,1303.72 822.947,1303.72 822.956,1303.72 822.966,1303.72 822.975,1303.72 822.984,1303.72 822.993,1303.72 823.002,1303.72 823.011,1303.72 823.021,1303.72 823.03,1303.72 823.039,1303.72 823.048,1303.73 823.057,1303.73 823.067,1303.73 823.076,1303.73 823.085,1303.73 823.094,1303.73 823.103,1303.73 823.113,1303.73 823.122,1303.73 823.131,1303.73 823.14,1303.73 823.149,1303.73 823.158,1303.73 823.168,1303.73 823.177,1303.73 823.186,1303.73 823.195,1303.73 823.204,1303.73 823.214,1303.73 823.223,1303.73 823.232,1303.73 823.241,1303.73 823.25,1303.73 823.26,1303.73 823.269,1303.73 823.278,1303.73 823.287,1303.73 823.296,1303.73 823.306,1303.73 823.315,1303.74 823.324,1303.74 823.333,1303.74 823.342,1303.74 823.351,1303.74 823.361,1303.74 823.37,1303.74 823.379,1303.74 823.388,1303.74 823.397,1303.74 823.407,1303.74 823.416,1303.74 823.425,1303.74 823.434,1303.74 823.443,1303.74 823.453,1303.74 823.462,1303.74 823.471,1303.74 823.48,1303.74 823.489,1303.74 823.498,1303.74 823.508,1303.74 823.517,1303.74 823.526,1303.74 823.535,1303.74 823.544,1303.74 823.554,1303.74 823.563,1303.74 823.572,1303.74 823.581,1303.75 823.59,1303.75 823.6,1303.75 823.609,1303.75 823.618,1303.75 823.627,1303.75 823.636,1303.75 823.646,1303.75 823.655,1303.75 823.664,1303.75 823.673,1303.75 823.682,1303.75 823.691,1303.75 823.701,1303.75 823.71,1303.75 823.719,1303.75 823.728,1303.75 823.737,1303.75 823.747,1303.75 823.756,1303.75 823.765,1303.75 823.774,1303.75 823.783,1303.75 823.793,1303.75 823.802,1303.75 823.811,1303.75 823.82,1303.75 823.829,1303.75 823.838,1303.75 823.848,1303.75 823.857,1303.76 823.866,1303.76 823.875,1303.76 823.884,1303.76 823.894,1303.76 823.903,1303.76 823.912,1303.76 823.921,1303.76 823.93,1303.76 823.94,1303.76 823.949,1303.76 823.958,1303.76 823.967,1303.76 823.976,1303.76 823.986,1303.76 823.995,1303.76 824.004,1303.76 824.013,1303.76 824.022,1303.76 824.031,1303.76 824.041,1303.76 824.05,1303.76 824.059,1303.76 824.068,1303.76 824.077,1303.76 824.087,1303.76 824.096,1303.76 824.105,1303.76 824.114,1303.76 824.123,1303.77 824.133,1303.77 824.142,1303.77 824.151,1303.77 824.16,1303.77 824.169,1303.77 824.178,1303.77 824.188,1303.77 824.197,1303.77 824.206,1303.77 824.215,1303.77 824.224,1303.77 824.234,1303.77 824.243,1303.77 824.252,1303.77 824.261,1303.77 824.27,1303.77 824.28,1303.77 824.289,1303.77 824.298,1303.77 824.307,1303.77 824.316,1303.77 824.326,1303.77 824.335,1303.77 824.344,1303.77 824.353,1303.77 824.362,1303.77 824.371,1303.77 824.381,1303.77 824.39,1303.78 824.399,1303.78 824.408,1303.78 824.417,1303.78 824.427,1303.78 824.436,1303.78 824.445,1303.78 824.454,1303.78 824.463,1303.78 824.473,1303.78 824.482,1303.78 824.491,1303.78 824.5,1303.78 824.509,1303.78 824.519,1303.78 824.528,1303.78 824.537,1303.78 824.546,1303.78 824.555,1303.78 824.564,1303.78 824.574,1303.78 824.583,1303.78 824.592,1303.78 824.601,1303.78 824.61,1303.78 824.62,1303.78 824.629,1303.78 824.638,1303.78 824.647,1303.78 824.656,1303.79 824.666,1303.79 824.675,1303.79 824.684,1303.79 824.693,1303.79 824.702,1303.79 824.711,1303.79 824.721,1303.79 824.73,1303.79 824.739,1303.79 824.748,1303.79 824.757,1303.79 824.767,1303.79 824.776,1303.79 824.785,1303.79 824.794,1303.79 824.803,1303.79 824.813,1303.79 824.822,1303.79 824.831,1303.79 824.84,1303.79 824.849,1303.79 824.859,1303.79 824.868,1303.79 824.877,1303.79 824.886,1303.79 824.895,1303.79 824.904,1303.79 824.914,1303.79 824.923,1303.8 824.932,1303.8 824.941,1303.8 824.95,1303.8 824.96,1303.8 824.969,1303.8 824.978,1303.8 824.987,1303.8 824.996,1303.8 825.006,1303.8 825.015,1303.8 825.024,1303.8 825.033,1303.8 825.042,1303.8 825.051,1303.8 825.061,1303.8 825.07,1303.8 825.079,1303.8 825.088,1303.8 825.097,1303.8 825.107,1303.8 825.116,1303.8 825.125,1303.8 825.134,1303.8 825.143,1303.8 825.153,1303.8 825.162,1303.8 825.171,1303.8 825.18,1303.8 825.189,1303.81 825.199,1303.81 825.208,1303.81 825.217,1303.81 825.226,1303.81 825.235,1303.81 825.244,1303.81 825.254,1303.81 825.263,1303.81 825.272,1303.81 825.281,1303.81 825.29,1303.81 825.3,1303.81 825.309,1303.81 825.318,1303.81 825.327,1303.81 825.336,1303.81 825.346,1303.81 825.355,1303.81 825.364,1303.81 825.373,1303.81 825.382,1303.81 825.391,1303.81 825.401,1303.81 825.41,1303.81 825.419,1303.81 825.428,1303.81 825.437,1303.81 825.447,1303.81 825.456,1303.82 825.465,1303.82 825.474,1303.82 825.483,1303.82 825.493,1303.82 825.502,1303.82 825.511,1303.82 825.52,1303.82 825.529,1303.82 825.539,1303.82 825.548,1303.82 825.557,1303.82 825.566,1303.82 825.575,1303.82 825.584,1303.82 825.594,1303.82 825.603,1303.82 825.612,1303.82 825.621,1303.82 825.63,1303.82 825.64,1303.82 825.649,1303.82 825.658,1303.82 825.667,1303.82 825.676,1303.82 825.686,1303.82 825.695,1303.82 825.704,1303.82 825.713,1303.82 825.722,1303.83 825.731,1303.83 825.741,1303.83 825.75,1303.83 825.759,1303.83 825.768,1303.83 825.777,1303.83 825.787,1303.83 825.796,1303.83 825.805,1303.83 825.814,1303.83 825.823,1303.83 825.833,1303.83 825.842,1303.83 825.851,1303.83 825.86,1303.83 825.869,1303.83 825.879,1303.83 825.888,1303.83 825.897,1303.83 825.906,1303.83 825.915,1303.83 825.924,1303.83 825.934,1303.83 825.943,1303.83 825.952,1303.83 825.961,1303.83 825.97,1303.83 825.98,1303.83 825.989,1303.84 825.998,1303.84 826.007,1303.84 826.016,1303.84 826.026,1303.84 826.035,1303.84 826.044,1303.84 826.053,1303.84 826.062,1303.84 826.071,1303.84 826.081,1303.84 826.09,1303.84 826.099,1303.84 826.108,1303.84 826.117,1303.84 826.127,1303.84 826.136,1303.84 826.145,1303.84 826.154,1303.84 826.163,1303.84 826.173,1303.84 826.182,1303.84 826.191,1303.84 826.2,1303.84 826.209,1303.84 826.219,1303.84 826.228,1303.84 826.237,1303.84 826.246,1303.84 826.255,1303.85 826.264,1303.85 826.274,1303.85 826.283,1303.85 826.292,1303.85 826.301,1303.85 826.31,1303.85 826.32,1303.85 826.329,1303.85 826.338,1303.85 826.347,1303.85 826.356,1303.85 826.366,1303.85 826.375,1303.85 826.384,1303.85 826.393,1303.85 826.402,1303.85 826.411,1303.85 826.421,1303.85 826.43,1303.85 826.439,1303.85 826.448,1303.85 826.457,1303.85 826.467,1303.85 826.476,1303.85 826.485,1303.85 826.494,1303.85 826.503,1303.85 826.513,1303.85 826.522,1303.86 826.531,1303.86 826.54,1303.86 826.549,1303.86 826.559,1303.86 826.568,1303.86 826.577,1303.86 826.586,1303.86 826.595,1303.86 826.604,1303.86 826.614,1303.86 826.623,1303.86 826.632,1303.86 826.641,1303.86 826.65,1303.86 826.66,1303.86 826.669,1303.86 826.678,1303.86 826.687,1303.86 826.696,1303.86 826.706,1303.86 826.715,1303.86 826.724,1303.86 826.733,1303.86 826.742,1303.86 826.751,1303.86 826.761,1303.86 826.77,1303.86 826.779,1303.86 826.788,1303.87 826.797,1303.87 826.807,1303.87 826.816,1303.87 826.825,1303.87 826.834,1303.87 826.843,1303.87 826.853,1303.87 826.862,1303.87 826.871,1303.87 826.88,1303.87 826.889,1303.87 826.899,1303.87 826.908,1303.87 826.917,1303.87 826.926,1303.87 826.935,1303.87 826.944,1303.87 826.954,1303.87 826.963,1303.87 826.972,1303.87 826.981,1303.87 826.99,1303.87 827,1303.87 827.009,1303.87 827.018,1303.87 827.027,1303.87 827.036,1303.87 827.046,1303.87 827.055,1303.88 827.064,1303.88 827.073,1303.88 827.082,1303.88 827.092,1303.88 827.101,1303.88 827.11,1303.88 827.119,1303.88 827.128,1303.88 827.137,1303.88 827.147,1303.88 827.156,1303.88 827.165,1303.88 827.174,1303.88 827.183,1303.88 827.193,1303.88 827.202,1303.88 827.211,1303.88 827.22,1303.88 827.229,1303.88 827.239,1303.88 827.248,1303.88 827.257,1303.88 827.266,1303.88 827.275,1303.88 827.284,1303.88 827.294,1303.88 827.303,1303.88 827.312,1303.89 827.321,1303.89 827.33,1303.89 827.34,1303.89 827.349,1303.89 827.358,1303.89 827.367,1303.89 827.376,1303.89 827.386,1303.89 827.395,1303.89 827.404,1303.89 827.413,1303.89 827.422,1303.89 827.432,1303.89 827.441,1303.89 827.45,1303.89 827.459,1303.89 827.468,1303.89 827.477,1303.89 827.487,1303.89 827.496,1303.89 827.505,1303.89 827.514,1303.89 827.523,1303.89 827.533,1303.89 827.542,1303.89 827.551,1303.89 827.56,1303.89 827.569,1303.89 827.579,1303.9 827.588,1303.9 827.597,1303.9 827.606,1303.9 827.615,1303.9 827.624,1303.9 827.634,1303.9 827.643,1303.9 827.652,1303.9 827.661,1303.9 827.67,1303.9 827.68,1303.9 827.689,1303.9 827.698,1303.9 827.707,1303.9 827.716,1303.9 827.726,1303.9 827.735,1303.9 827.744,1303.9 827.753,1303.9 827.762,1303.9 827.772,1303.9 827.781,1303.9 827.79,1303.9 827.799,1303.9 827.808,1303.9 827.817,1303.9 827.827,1303.9 827.836,1303.9 827.845,1303.91 827.854,1303.91 827.863,1303.91 827.873,1303.91 827.882,1303.91 827.891,1303.91 827.9,1303.91 827.909,1303.91 827.919,1303.91 827.928,1303.91 827.937,1303.91 827.946,1303.91 827.955,1303.91 827.964,1303.91 827.974,1303.91 827.983,1303.91 827.992,1303.91 828.001,1303.91 828.01,1303.91 828.02,1303.91 828.029,1303.91 828.038,1303.91 828.047,1303.91 828.056,1303.91 828.066,1303.91 828.075,1303.91 828.084,1303.91 828.093,1303.91 828.102,1303.92 828.112,1303.92 828.121,1303.92 828.13,1303.92 828.139,1303.92 828.148,1303.92 828.157,1303.92 828.167,1303.92 828.176,1303.92 828.185,1303.92 828.194,1303.92 828.203,1303.92 828.213,1303.92 828.222,1303.92 828.231,1303.92 828.24,1303.92 828.249,1303.92 828.259,1303.92 828.268,1303.92 828.277,1303.92 828.286,1303.92 828.295,1303.92 828.304,1303.92 828.314,1303.92 828.323,1303.92 828.332,1303.92 828.341,1303.92 828.35,1303.92 828.36,1303.92 828.369,1303.93 828.378,1303.93 828.387,1303.93 828.396,1303.93 828.406,1303.93 828.415,1303.93 828.424,1303.93 828.433,1303.93 828.442,1303.93 828.452,1303.93 828.461,1303.93 828.47,1303.93 828.479,1303.93 828.488,1303.93 828.497,1303.93 828.507,1303.93 828.516,1303.93 828.525,1303.93 828.534,1303.93 828.543,1303.93 828.553,1303.93 828.562,1303.93 828.571,1303.93 828.58,1303.93 828.589,1303.93 828.599,1303.93 828.608,1303.93 828.617,1303.93 828.626,1303.94 828.635,1303.94 828.644,1303.94 828.654,1303.94 828.663,1303.94 828.672,1303.94 828.681,1303.94 828.69,1303.94 828.7,1303.94 828.709,1303.94 828.718,1303.94 828.727,1303.94 828.736,1303.94 828.746,1303.94 828.755,1303.94 828.764,1303.94 828.773,1303.94 828.782,1303.94 828.792,1303.94 828.801,1303.94 828.81,1303.94 828.819,1303.94 828.828,1303.94 828.837,1303.94 828.847,1303.94 828.856,1303.94 828.865,1303.94 828.874,1303.94 828.883,1303.95 828.893,1303.95 828.902,1303.95 828.911,1303.95 828.92,1303.95 828.929,1303.95 828.939,1303.95 828.948,1303.95 828.957,1303.95 828.966,1303.95 828.975,1303.95 828.984,1303.95 828.994,1303.95 829.003,1303.95 829.012,1303.95 829.021,1303.95 829.03,1303.95 829.04,1303.95 829.049,1303.95 829.058,1303.95 829.067,1303.95 829.076,1303.95 829.086,1303.95 829.095,1303.95 829.104,1303.95 829.113,1303.95 829.122,1303.95 829.132,1303.95 829.141,1303.95 829.15,1303.96 829.159,1303.96 829.168,1303.96 829.177,1303.96 829.187,1303.96 829.196,1303.96 829.205,1303.96 829.214,1303.96 829.223,1303.96 829.233,1303.96 829.242,1303.96 829.251,1303.96 829.26,1303.96 829.269,1303.96 829.279,1303.96 829.288,1303.96 829.297,1303.96 829.306,1303.96 829.315,1303.96 829.324,1303.96 829.334,1303.96 829.343,1303.96 829.352,1303.96 829.361,1303.96 829.37,1303.96 829.38,1303.96 829.389,1303.96 829.398,1303.96 829.407,1303.97 829.416,1303.97 829.426,1303.97 829.435,1303.97 829.444,1303.97 829.453,1303.97 829.462,1303.97 829.472,1303.97 829.481,1303.97 829.49,1303.97 829.499,1303.97 829.508,1303.97 829.517,1303.97 829.527,1303.97 829.536,1303.97 829.545,1303.97 829.554,1303.97 829.563,1303.97 829.573,1303.97 829.582,1303.97 829.591,1303.97 829.6,1303.97 829.609,1303.97 829.619,1303.97 829.628,1303.97 829.637,1303.97 829.646,1303.97 829.655,1303.97 829.665,1303.98 829.674,1303.98 829.683,1303.98 829.692,1303.98 829.701,1303.98 829.71,1303.98 829.72,1303.98 829.729,1303.98 829.738,1303.98 829.747,1303.98 829.756,1303.98 829.766,1303.98 829.775,1303.98 829.784,1303.98 829.793,1303.98 829.802,1303.98 829.812,1303.98 829.821,1303.98 829.83,1303.98 829.839,1303.98 829.848,1303.98 829.857,1303.98 829.867,1303.98 829.876,1303.98 829.885,1303.98 829.894,1303.98 829.903,1303.98 829.913,1303.98 829.922,1303.98 829.931,1303.99 829.94,1303.99 829.949,1303.99 829.959,1303.99 829.968,1303.99 829.977,1303.99 829.986,1303.99 829.995,1303.99 830.005,1303.99 830.014,1303.99 830.023,1303.99 830.032,1303.99 830.041,1303.99 830.05,1303.99 830.06,1303.99 830.069,1303.99 830.078,1303.99 830.087,1303.99 830.096,1303.99 830.106,1303.99 830.115,1303.99 830.124,1303.99 830.133,1303.99 830.142,1303.99 830.152,1303.99 830.161,1303.99 830.17,1303.99 830.179,1303.99 830.188,1304 830.197,1304 830.207,1304 830.216,1304 830.225,1304 830.234,1304 830.243,1304 830.253,1304 830.262,1304 830.271,1304 830.28,1304 830.289,1304 830.299,1304 830.308,1304 830.317,1304 830.326,1304 830.335,1304 830.345,1304 830.354,1304 830.363,1304 830.372,1304 830.381,1304 830.39,1304 830.4,1304 830.409,1304 830.418,1304 830.427,1304 830.436,1304 830.446,1304.01 830.455,1304.01 830.464,1304.01 830.473,1304.01 830.482,1304.01 830.492,1304.01 830.501,1304.01 830.51,1304.01 830.519,1304.01 830.528,1304.01 830.537,1304.01 830.547,1304.01 830.556,1304.01 830.565,1304.01 830.574,1304.01 830.583,1304.01 830.593,1304.01 830.602,1304.01 830.611,1304.01 830.62,1304.01 830.629,1304.01 830.639,1304.01 830.648,1304.01 830.657,1304.01 830.666,1304.01 830.675,1304.01 830.685,1304.01 830.694,1304.01 830.703,1304.02 830.712,1304.02 830.721,1304.02 830.73,1304.02 830.74,1304.02 830.749,1304.02 830.758,1304.02 830.767,1304.02 830.776,1304.02 830.786,1304.02 830.795,1304.02 830.804,1304.02 830.813,1304.02 830.822,1304.02 830.832,1304.02 830.841,1304.02 830.85,1304.02 830.859,1304.02 830.868,1304.02 830.877,1304.02 830.887,1304.02 830.896,1304.02 830.905,1304.02 830.914,1304.02 830.923,1304.02 830.933,1304.02 830.942,1304.02 830.951,1304.02 830.96,1304.03 830.969,1304.03 830.979,1304.03 830.988,1304.03 830.997,1304.03 831.006,1304.03 831.015,1304.03 831.025,1304.03 831.034,1304.03 831.043,1304.03 831.052,1304.03 831.061,1304.03 831.07,1304.03 831.08,1304.03 831.089,1304.03 831.098,1304.03 831.107,1304.03 831.116,1304.03 831.126,1304.03 831.135,1304.03 831.144,1304.03 831.153,1304.03 831.162,1304.03 831.172,1304.03 831.181,1304.03 831.19,1304.03 831.199,1304.03 831.208,1304.03 831.217,1304.04 831.227,1304.04 831.236,1304.04 831.245,1304.04 831.254,1304.04 831.263,1304.04 831.273,1304.04 831.282,1304.04 831.291,1304.04 831.3,1304.04 831.309,1304.04 831.319,1304.04 831.328,1304.04 831.337,1304.04 831.346,1304.04 831.355,1304.04 831.365,1304.04 831.374,1304.04 831.383,1304.04 831.392,1304.04 831.401,1304.04 831.41,1304.04 831.42,1304.04 831.429,1304.04 831.438,1304.04 831.447,1304.04 831.456,1304.04 831.466,1304.04 831.475,1304.05 831.484,1304.05 831.493,1304.05 831.502,1304.05 831.512,1304.05 831.521,1304.05 831.53,1304.05 831.539,1304.05 831.548,1304.05 831.557,1304.05 831.567,1304.05 831.576,1304.05 831.585,1304.05 831.594,1304.05 831.603,1304.05 831.613,1304.05 831.622,1304.05 831.631,1304.05 831.64,1304.05 831.649,1304.05 831.659,1304.05 831.668,1304.05 831.677,1304.05 831.686,1304.05 831.695,1304.05 831.705,1304.05 831.714,1304.05 831.723,1304.05 831.732,1304.06 831.741,1304.06 831.75,1304.06 831.76,1304.06 831.769,1304.06 831.778,1304.06 831.787,1304.06 831.796,1304.06 831.806,1304.06 831.815,1304.06 831.824,1304.06 831.833,1304.06 831.842,1304.06 831.852,1304.06 831.861,1304.06 831.87,1304.06 831.879,1304.06 831.888,1304.06 831.898,1304.06 831.907,1304.06 831.916,1304.06 831.925,1304.06 831.934,1304.06 831.943,1304.06 831.953,1304.06 831.962,1304.06 831.971,1304.06 831.98,1304.07 831.989,1304.07 831.999,1304.07 832.008,1304.07 832.017,1304.07 832.026,1304.07 832.035,1304.07 832.045,1304.07 832.054,1304.07 832.063,1304.07 832.072,1304.07 832.081,1304.07 832.09,1304.07 832.1,1304.07 832.109,1304.07 832.118,1304.07 832.127,1304.07 832.136,1304.07 832.146,1304.07 832.155,1304.07 832.164,1304.07 832.173,1304.07 832.182,1304.07 832.192,1304.07 832.201,1304.07 832.21,1304.07 832.219,1304.07 832.228,1304.07 832.238,1304.08 832.247,1304.08 832.256,1304.08 832.265,1304.08 832.274,1304.08 832.283,1304.08 832.293,1304.08 832.302,1304.08 832.311,1304.08 832.32,1304.08 832.329,1304.08 832.339,1304.08 832.348,1304.08 832.357,1304.08 832.366,1304.08 832.375,1304.08 832.385,1304.08 832.394,1304.08 832.403,1304.08 832.412,1304.08 832.421,1304.08 832.43,1304.08 832.44,1304.08 832.449,1304.08 832.458,1304.08 832.467,1304.08 832.476,1304.08 832.486,1304.08 832.495,1304.09 832.504,1304.09 832.513,1304.09 832.522,1304.09 832.532,1304.09 832.541,1304.09 832.55,1304.09 832.559,1304.09 832.568,1304.09 832.578,1304.09 832.587,1304.09 832.596,1304.09 832.605,1304.09 832.614,1304.09 832.623,1304.09 832.633,1304.09 832.642,1304.09 832.651,1304.09 832.66,1304.09 832.669,1304.09 832.679,1304.09 832.688,1304.09 832.697,1304.09 832.706,1304.09 832.715,1304.09 832.725,1304.09 832.734,1304.09 832.743,1304.1 832.752,1304.1 832.761,1304.1 832.77,1304.1 832.78,1304.1 832.789,1304.1 832.798,1304.1 832.807,1304.1 832.816,1304.1 832.826,1304.1 832.835,1304.1 832.844,1304.1 832.853,1304.1 832.862,1304.1 832.872,1304.1 832.881,1304.1 832.89,1304.1 832.899,1304.1 832.908,1304.1 832.918,1304.1 832.927,1304.1 832.936,1304.1 832.945,1304.1 832.954,1304.1 832.963,1304.1 832.973,1304.1 832.982,1304.1 832.991,1304.1 833,1304.11 833.009,1304.11 833.019,1304.11 833.028,1304.11 833.037,1304.11 833.046,1304.11 833.055,1304.11 833.065,1304.11 833.074,1304.11 833.083,1304.11 833.092,1304.11 833.101,1304.11 833.11,1304.11 833.12,1304.11 833.129,1304.11 833.138,1304.11 833.147,1304.11 833.156,1304.11 833.166,1304.11 833.175,1304.11 833.184,1304.11 833.193,1304.11 833.202,1304.11 833.212,1304.11 833.221,1304.11 833.23,1304.11 833.239,1304.11 833.248,1304.11 833.258,1304.12 833.267,1304.12 833.276,1304.12 833.285,1304.12 833.294,1304.12 833.303,1304.12 833.313,1304.12 833.322,1304.12 833.331,1304.12 833.34,1304.12 833.349,1304.12 833.359,1304.12 833.368,1304.12 833.377,1304.12 833.386,1304.12 833.395,1304.12 833.405,1304.12 833.414,1304.12 833.423,1304.12 833.432,1304.12 833.441,1304.12 833.45,1304.12 833.46,1304.12 833.469,1304.12 833.478,1304.12 833.487,1304.12 833.496,1304.12 833.506,1304.13 833.515,1304.13 833.524,1304.13 833.533,1304.13 833.542,1304.13 833.552,1304.13 833.561,1304.13 833.57,1304.13 833.579,1304.13 833.588,1304.13 833.598,1304.13 833.607,1304.13 833.616,1304.13 833.625,1304.13 833.634,1304.13 833.643,1304.13 833.653,1304.13 833.662,1304.13 833.671,1304.13 833.68,1304.13 833.689,1304.13 833.699,1304.13 833.708,1304.13 833.717,1304.13 833.726,1304.13 833.735,1304.13 833.745,1304.13 833.754,1304.13 833.763,1304.14 833.772,1304.14 833.781,1304.14 833.79,1304.14 833.8,1304.14 833.809,1304.14 833.818,1304.14 833.827,1304.14 833.836,1304.14 833.846,1304.14 833.855,1304.14 833.864,1304.14 833.873,1304.14 833.882,1304.14 833.892,1304.14 833.901,1304.14 833.91,1304.14 833.919,1304.14 833.928,1304.14 833.938,1304.14 833.947,1304.14 833.956,1304.14 833.965,1304.14 833.974,1304.14 833.983,1304.14 833.993,1304.14 834.002,1304.14 834.011,1304.15 834.02,1304.15 834.029,1304.15 834.039,1304.15 834.048,1304.15 834.057,1304.15 834.066,1304.15 834.075,1304.15 834.085,1304.15 834.094,1304.15 834.103,1304.15 834.112,1304.15 834.121,1304.15 834.13,1304.15 834.14,1304.15 834.149,1304.15 834.158,1304.15 834.167,1304.15 834.176,1304.15 834.186,1304.15 834.195,1304.15 834.204,1304.15 834.213,1304.15 834.222,1304.15 834.232,1304.15 834.241,1304.15 834.25,1304.15 834.259,1304.16 834.268,1304.16 834.278,1304.16 834.287,1304.16 834.296,1304.16 834.305,1304.16 834.314,1304.16 834.323,1304.16 834.333,1304.16 834.342,1304.16 834.351,1304.16 834.36,1304.16 834.369,1304.16 834.379,1304.16 834.388,1304.16 834.397,1304.16 834.406,1304.16 834.415,1304.16 834.425,1304.16 834.434,1304.16 834.443,1304.16 834.452,1304.16 834.461,1304.16 834.471,1304.16 834.48,1304.16 834.489,1304.16 834.498,1304.16 834.507,1304.16 834.516,1304.17 834.526,1304.17 834.535,1304.17 834.544,1304.17 834.553,1304.17 834.562,1304.17 834.572,1304.17 834.581,1304.17 834.59,1304.17 834.599,1304.17 834.608,1304.17 834.618,1304.17 834.627,1304.17 834.636,1304.17 834.645,1304.17 834.654,1304.17 834.663,1304.17 834.673,1304.17 834.682,1304.17 834.691,1304.17 834.7,1304.17 834.709,1304.17 834.719,1304.17 834.728,1304.17 834.737,1304.17 834.746,1304.17 834.755,1304.17 834.765,1304.18 834.774,1304.18 834.783,1304.18 834.792,1304.18 834.801,1304.18 834.811,1304.18 834.82,1304.18 834.829,1304.18 834.838,1304.18 834.847,1304.18 834.856,1304.18 834.866,1304.18 834.875,1304.18 834.884,1304.18 834.893,1304.18 834.902,1304.18 834.912,1304.18 834.921,1304.18 834.93,1304.18 834.939,1304.18 834.948,1304.18 834.958,1304.18 834.967,1304.18 834.976,1304.18 834.985,1304.18 834.994,1304.18 835.003,1304.18 835.013,1304.19 835.022,1304.19 835.031,1304.19 835.04,1304.19 835.049,1304.19 835.059,1304.19 835.068,1304.19 835.077,1304.19 835.086,1304.19 835.095,1304.19 835.105,1304.19 835.114,1304.19 835.123,1304.19 835.132,1304.19 835.141,1304.19 835.151,1304.19 835.16,1304.19 835.169,1304.19 835.178,1304.19 835.187,1304.19 835.196,1304.19 835.206,1304.19 835.215,1304.19 835.224,1304.19 835.233,1304.19 835.242,1304.19 835.252,1304.19 835.261,1304.2 835.27,1304.2 835.279,1304.2 835.288,1304.2 835.298,1304.2 835.307,1304.2 835.316,1304.2 835.325,1304.2 835.334,1304.2 835.343,1304.2 835.353,1304.2 835.362,1304.2 835.371,1304.2 835.38,1304.2 835.389,1304.2 835.399,1304.2 835.408,1304.2 835.417,1304.2 835.426,1304.2 835.435,1304.2 835.445,1304.2 835.454,1304.2 835.463,1304.2 835.472,1304.2 835.481,1304.2 835.491,1304.2 835.5,1304.2 835.509,1304.21 835.518,1304.21 835.527,1304.21 835.536,1304.21 835.546,1304.21 835.555,1304.21 835.564,1304.21 835.573,1304.21 835.582,1304.21 835.592,1304.21 835.601,1304.21 835.61,1304.21 835.619,1304.21 835.628,1304.21 835.638,1304.21 835.647,1304.21 835.656,1304.21 835.665,1304.21 835.674,1304.21 835.683,1304.21 835.693,1304.21 835.702,1304.21 835.711,1304.21 835.72,1304.21 835.729,1304.21 835.739,1304.21 835.748,1304.21 835.757,1304.22 835.766,1304.22 835.775,1304.22 835.785,1304.22 835.794,1304.22 835.803,1304.22 835.812,1304.22 835.821,1304.22 835.831,1304.22 835.84,1304.22 835.849,1304.22 835.858,1304.22 835.867,1304.22 835.876,1304.22 835.886,1304.22 835.895,1304.22 835.904,1304.22 835.913,1304.22 835.922,1304.22 835.932,1304.22 835.941,1304.22 835.95,1304.22 835.959,1304.22 835.968,1304.22 835.978,1304.22 835.987,1304.22 835.996,1304.22 836.005,1304.23 836.014,1304.23 836.023,1304.23 836.033,1304.23 836.042,1304.23 836.051,1304.23 836.06,1304.23 836.069,1304.23 836.079,1304.23 836.088,1304.23 836.097,1304.23 836.106,1304.23 836.115,1304.23 836.125,1304.23 836.134,1304.23 836.143,1304.23 836.152,1304.23 836.161,1304.23 836.171,1304.23 836.18,1304.23 836.189,1304.23 836.198,1304.23 836.207,1304.23 836.216,1304.23 836.226,1304.23 836.235,1304.23 836.244,1304.23 836.253,1304.24 836.262,1304.24 836.272,1304.24 836.281,1304.24 836.29,1304.24 836.299,1304.24 836.308,1304.24 836.318,1304.24 836.327,1304.24 836.336,1304.24 836.345,1304.24 836.354,1304.24 836.363,1304.24 836.373,1304.24 836.382,1304.24 836.391,1304.24 836.4,1304.24 836.409,1304.24 836.419,1304.24 836.428,1304.24 836.437,1304.24 836.446,1304.24 836.455,1304.24 836.465,1304.24 836.474,1304.24 836.483,1304.24 836.492,1304.24 836.501,1304.25 836.511,1304.25 836.52,1304.25 836.529,1304.25 836.538,1304.25 836.547,1304.25 836.556,1304.25 836.566,1304.25 836.575,1304.25 836.584,1304.25 836.593,1304.25 836.602,1304.25 836.612,1304.25 836.621,1304.25 836.63,1304.25 836.639,1304.25 836.648,1304.25 836.658,1304.25 836.667,1304.25 836.676,1304.25 836.685,1304.25 836.694,1304.25 836.703,1304.25 836.713,1304.25 836.722,1304.25 836.731,1304.25 836.74,1304.25 836.749,1304.26 836.759,1304.26 836.768,1304.26 836.777,1304.26 836.786,1304.26 836.795,1304.26 836.805,1304.26 836.814,1304.26 836.823,1304.26 836.832,1304.26 836.841,1304.26 836.851,1304.26 836.86,1304.26 836.869,1304.26 836.878,1304.26 836.887,1304.26 836.896,1304.26 836.906,1304.26 836.915,1304.26 836.924,1304.26 836.933,1304.26 836.942,1304.26 836.952,1304.26 836.961,1304.26 836.97,1304.26 836.979,1304.26 836.988,1304.26 836.998,1304.27 837.007,1304.27 837.016,1304.27 837.025,1304.27 837.034,1304.27 837.044,1304.27 837.053,1304.27 837.062,1304.27 837.071,1304.27 837.08,1304.27 837.089,1304.27 837.099,1304.27 837.108,1304.27 837.117,1304.27 837.126,1304.27 837.135,1304.27 837.145,1304.27 837.154,1304.27 837.163,1304.27 837.172,1304.27 837.181,1304.27 837.191,1304.27 837.2,1304.27 837.209,1304.27 837.218,1304.27 837.227,1304.27 837.236,1304.28 837.246,1304.28 837.255,1304.28 837.264,1304.28 837.273,1304.28 837.282,1304.28 837.292,1304.28 837.301,1304.28 837.31,1304.28 837.319,1304.28 837.328,1304.28 837.338,1304.28 837.347,1304.28 837.356,1304.28 837.365,1304.28 837.374,1304.28 837.384,1304.28 837.393,1304.28 837.402,1304.28 837.411,1304.28 837.42,1304.28 837.429,1304.28 837.439,1304.28 837.448,1304.28 837.457,1304.28 837.466,1304.28 837.475,1304.28 837.485,1304.29 837.494,1304.29 837.503,1304.29 837.512,1304.29 837.521,1304.29 837.531,1304.29 837.54,1304.29 837.549,1304.29 837.558,1304.29 837.567,1304.29 837.576,1304.29 837.586,1304.29 837.595,1304.29 837.604,1304.29 837.613,1304.29 837.622,1304.29 837.632,1304.29 837.641,1304.29 837.65,1304.29 837.659,1304.29 837.668,1304.29 837.678,1304.29 837.687,1304.29 837.696,1304.29 837.705,1304.29 837.714,1304.29 837.724,1304.29 837.733,1304.3 837.742,1304.3 837.751,1304.3 837.76,1304.3 837.769,1304.3 837.779,1304.3 837.788,1304.3 837.797,1304.3 837.806,1304.3 837.815,1304.3 837.825,1304.3 837.834,1304.3 837.843,1304.3 837.852,1304.3 837.861,1304.3 837.871,1304.3 837.88,1304.3 837.889,1304.3 837.898,1304.3 837.907,1304.3 837.916,1304.3 837.926,1304.3 837.935,1304.3 837.944,1304.3 837.953,1304.3 837.962,1304.3 837.972,1304.31 837.981,1304.31 837.99,1304.31 837.999,1304.31 838.008,1304.31 838.018,1304.31 838.027,1304.31 838.036,1304.31 838.045,1304.31 838.054,1304.31 838.064,1304.31 838.073,1304.31 838.082,1304.31 838.091,1304.31 838.1,1304.31 838.109,1304.31 838.119,1304.31 838.128,1304.31 838.137,1304.31 838.146,1304.31 838.155,1304.31 838.165,1304.31 838.174,1304.31 838.183,1304.31 838.192,1304.31 838.201,1304.31 838.211,1304.31 838.22,1304.32 838.229,1304.32 838.238,1304.32 838.247,1304.32 838.256,1304.32 838.266,1304.32 838.275,1304.32 838.284,1304.32 838.293,1304.32 838.302,1304.32 838.312,1304.32 838.321,1304.32 838.33,1304.32 838.339,1304.32 838.348,1304.32 838.358,1304.32 838.367,1304.32 838.376,1304.32 838.385,1304.32 838.394,1304.32 838.404,1304.32 838.413,1304.32 838.422,1304.32 838.431,1304.32 838.44,1304.32 838.449,1304.32 838.459,1304.33 838.468,1304.33 838.477,1304.33 838.486,1304.33 838.495,1304.33 838.505,1304.33 838.514,1304.33 838.523,1304.33 838.532,1304.33 838.541,1304.33 838.551,1304.33 838.56,1304.33 838.569,1304.33 838.578,1304.33 838.587,1304.33 838.596,1304.33 838.606,1304.33 838.615,1304.33 838.624,1304.33 838.633,1304.33 838.642,1304.33 838.652,1304.33 838.661,1304.33 838.67,1304.33 838.679,1304.33 838.688,1304.33 838.698,1304.33 838.707,1304.34 838.716,1304.34 838.725,1304.34 838.734,1304.34 838.744,1304.34 838.753,1304.34 838.762,1304.34 838.771,1304.34 838.78,1304.34 838.789,1304.34 838.799,1304.34 838.808,1304.34 838.817,1304.34 838.826,1304.34 838.835,1304.34 838.845,1304.34 838.854,1304.34 838.863,1304.34 838.872,1304.34 838.881,1304.34 838.891,1304.34 838.9,1304.34 838.909,1304.34 838.918,1304.34 838.927,1304.34 838.936,1304.34 838.946,1304.35 838.955,1304.35 838.964,1304.35 838.973,1304.35 838.982,1304.35 838.992,1304.35 839.001,1304.35 839.01,1304.35 839.019,1304.35 839.028,1304.35 839.038,1304.35 839.047,1304.35 839.056,1304.35 839.065,1304.35 839.074,1304.35 839.084,1304.35 839.093,1304.35 839.102,1304.35 839.111,1304.35 839.12,1304.35 839.129,1304.35 839.139,1304.35 839.148,1304.35 839.157,1304.35 839.166,1304.35 839.175,1304.35 839.185,1304.35 839.194,1304.36 839.203,1304.36 839.212,1304.36 839.221,1304.36 839.231,1304.36 839.24,1304.36 839.249,1304.36 839.258,1304.36 839.267,1304.36 839.277,1304.36 839.286,1304.36 839.295,1304.36 839.304,1304.36 839.313,1304.36 839.322,1304.36 839.332,1304.36 839.341,1304.36 839.35,1304.36 839.359,1304.36 839.368,1304.36 839.378,1304.36 839.387,1304.36 839.396,1304.36 839.405,1304.36 839.414,1304.36 839.424,1304.36 839.433,1304.37 839.442,1304.37 839.451,1304.37 839.46,1304.37 839.469,1304.37 839.479,1304.37 839.488,1304.37 839.497,1304.37 839.506,1304.37 839.515,1304.37 839.525,1304.37 839.534,1304.37 839.543,1304.37 839.552,1304.37 839.561,1304.37 839.571,1304.37 839.58,1304.37 839.589,1304.37 839.598,1304.37 839.607,1304.37 839.617,1304.37 839.626,1304.37 839.635,1304.37 839.644,1304.37 839.653,1304.37 839.662,1304.37 839.672,1304.38 839.681,1304.38 839.69,1304.38 839.699,1304.38 839.708,1304.38 839.718,1304.38 839.727,1304.38 839.736,1304.38 839.745,1304.38 839.754,1304.38 839.764,1304.38 839.773,1304.38 839.782,1304.38 839.791,1304.38 839.8,1304.38 839.809,1304.38 839.819,1304.38 839.828,1304.38 839.837,1304.38 839.846,1304.38 839.855,1304.38 839.865,1304.38 839.874,1304.38 839.883,1304.38 839.892,1304.38 839.901,1304.38 839.911,1304.39 839.92,1304.39 839.929,1304.39 839.938,1304.39 839.947,1304.39 839.957,1304.39 839.966,1304.39 839.975,1304.39 839.984,1304.39 839.993,1304.39 840.002,1304.39 840.012,1304.39 840.021,1304.39 840.03,1304.39 840.039,1304.39 840.048,1304.39 840.058,1304.39 840.067,1304.39 840.076,1304.39 840.085,1304.39 840.094,1304.39 840.104,1304.39 840.113,1304.39 840.122,1304.39 840.131,1304.39 840.14,1304.39 840.149,1304.39 840.159,1304.4 840.168,1304.4 840.177,1304.4 840.186,1304.4 840.195,1304.4 840.205,1304.4 840.214,1304.4 840.223,1304.4 840.232,1304.4 840.241,1304.4 840.251,1304.4 840.26,1304.4 840.269,1304.4 840.278,1304.4 840.287,1304.4 840.297,1304.4 840.306,1304.4 840.315,1304.4 840.324,1304.4 840.333,1304.4 840.342,1304.4 840.352,1304.4 840.361,1304.4 840.37,1304.4 840.379,1304.4 840.388,1304.4 840.398,1304.41 840.407,1304.41 840.416,1304.41 840.425,1304.41 840.434,1304.41 840.444,1304.41 840.453,1304.41 840.462,1304.41 840.471,1304.41 840.48,1304.41 840.489,1304.41 840.499,1304.41 840.508,1304.41 840.517,1304.41 840.526,1304.41 840.535,1304.41 840.545,1304.41 840.554,1304.41 840.563,1304.41 840.572,1304.41 840.581,1304.41 840.591,1304.41 840.6,1304.41 840.609,1304.41 840.618,1304.41 840.627,1304.41 840.637,1304.42 840.646,1304.42 840.655,1304.42 840.664,1304.42 840.673,1304.42 840.682,1304.42 840.692,1304.42 840.701,1304.42 840.71,1304.42 840.719,1304.42 840.728,1304.42 840.738,1304.42 840.747,1304.42 840.756,1304.42 840.765,1304.42 840.774,1304.42 840.784,1304.42 840.793,1304.42 840.802,1304.42 840.811,1304.42 840.82,1304.42 840.829,1304.42 840.839,1304.42 840.848,1304.42 840.857,1304.42 840.866,1304.42 840.875,1304.43 840.885,1304.43 840.894,1304.43 840.903,1304.43 840.912,1304.43 840.921,1304.43 840.931,1304.43 840.94,1304.43 840.949,1304.43 840.958,1304.43 840.967,1304.43 840.977,1304.43 840.986,1304.43 840.995,1304.43 841.004,1304.43 841.013,1304.43 841.022,1304.43 841.032,1304.43 841.041,1304.43 841.05,1304.43 841.059,1304.43 841.068,1304.43 841.078,1304.43 841.087,1304.43 841.096,1304.43 841.105,1304.43 841.114,1304.44 841.124,1304.44 841.133,1304.44 841.142,1304.44 841.151,1304.44 841.16,1304.44 841.169,1304.44 841.179,1304.44 841.188,1304.44 841.197,1304.44 841.206,1304.44 841.215,1304.44 841.225,1304.44 841.234,1304.44 841.243,1304.44 841.252,1304.44 841.261,1304.44 841.271,1304.44 841.28,1304.44 841.289,1304.44 841.298,1304.44 841.307,1304.44 841.317,1304.44 841.326,1304.44 841.335,1304.44 841.344,1304.44 841.353,1304.45 841.362,1304.45 841.372,1304.45 841.381,1304.45 841.39,1304.45 841.399,1304.45 841.408,1304.45 841.418,1304.45 841.427,1304.45 841.436,1304.45 841.445,1304.45 841.454,1304.45 841.464,1304.45 841.473,1304.45 841.482,1304.45 841.491,1304.45 841.5,1304.45 841.509,1304.45 841.519,1304.45 841.528,1304.45 841.537,1304.45 841.546,1304.45 841.555,1304.45 841.565,1304.45 841.574,1304.45 841.583,1304.46 841.592,1304.46 841.601,1304.46 841.611,1304.46 841.62,1304.46 841.629,1304.46 841.638,1304.46 841.647,1304.46 841.657,1304.46 841.666,1304.46 841.675,1304.46 841.684,1304.46 841.693,1304.46 841.702,1304.46 841.712,1304.46 841.721,1304.46 841.73,1304.46 841.739,1304.46 841.748,1304.46 841.758,1304.46 841.767,1304.46 841.776,1304.46 841.785,1304.46 841.794,1304.46 841.804,1304.46 841.813,1304.46 841.822,1304.47 841.831,1304.47 841.84,1304.47 841.85,1304.47 841.859,1304.47 841.868,1304.47 841.877,1304.47 841.886,1304.47 841.895,1304.47 841.905,1304.47 841.914,1304.47 841.923,1304.47 841.932,1304.47 841.941,1304.47 841.951,1304.47 841.96,1304.47 841.969,1304.47 841.978,1304.47 841.987,1304.47 841.997,1304.47 842.006,1304.47 842.015,1304.47 842.024,1304.47 842.033,1304.47 842.042,1304.47 842.052,1304.47 842.061,1304.48 842.07,1304.48 842.079,1304.48 842.088,1304.48 842.098,1304.48 842.107,1304.48 842.116,1304.48 842.125,1304.48 842.134,1304.48 842.144,1304.48 842.153,1304.48 842.162,1304.48 842.171,1304.48 842.18,1304.48 842.19,1304.48 842.199,1304.48 842.208,1304.48 842.217,1304.48 842.226,1304.48 842.235,1304.48 842.245,1304.48 842.254,1304.48 842.263,1304.48 842.272,1304.48 842.281,1304.48 842.291,1304.48 842.3,1304.49 842.309,1304.49 842.318,1304.49 842.327,1304.49 842.337,1304.49 842.346,1304.49 842.355,1304.49 842.364,1304.49 842.373,1304.49 842.382,1304.49 842.392,1304.49 842.401,1304.49 842.41,1304.49 842.419,1304.49 842.428,1304.49 842.438,1304.49 842.447,1304.49 842.456,1304.49 842.465,1304.49 842.474,1304.49 842.484,1304.49 842.493,1304.49 842.502,1304.49 842.511,1304.49 842.52,1304.49 842.53,1304.5 842.539,1304.5 842.548,1304.5 842.557,1304.5 842.566,1304.5 842.575,1304.5 842.585,1304.5 842.594,1304.5 842.603,1304.5 842.612,1304.5 842.621,1304.5 842.631,1304.5 842.64,1304.5 842.649,1304.5 842.658,1304.5 842.667,1304.5 842.677,1304.5 842.686,1304.5 842.695,1304.5 842.704,1304.5 842.713,1304.5 842.722,1304.5 842.732,1304.5 842.741,1304.5 842.75,1304.5 842.759,1304.5 842.768,1304.51 842.778,1304.51 842.787,1304.51 842.796,1304.51 842.805,1304.51 842.814,1304.51 842.824,1304.51 842.833,1304.51 842.842,1304.51 842.851,1304.51 842.86,1304.51 842.87,1304.51 842.879,1304.51 842.888,1304.51 842.897,1304.51 842.906,1304.51 842.915,1304.51 842.925,1304.51 842.934,1304.51 842.943,1304.51 842.952,1304.51 842.961,1304.51 842.971,1304.51 842.98,1304.51 842.989,1304.51 842.998,1304.51 843.007,1304.52 843.017,1304.52 843.026,1304.52 843.035,1304.52 843.044,1304.52 843.053,1304.52 843.062,1304.52 843.072,1304.52 843.081,1304.52 843.09,1304.52 843.099,1304.52 843.108,1304.52 843.118,1304.52 843.127,1304.52 843.136,1304.52 843.145,1304.52 843.154,1304.52 843.164,1304.52 843.173,1304.52 843.182,1304.52 843.191,1304.52 843.2,1304.52 843.21,1304.52 843.219,1304.52 843.228,1304.52 843.237,1304.53 843.246,1304.53 843.255,1304.53 843.265,1304.53 843.274,1304.53 843.283,1304.53 843.292,1304.53 843.301,1304.53 843.311,1304.53 843.32,1304.53 843.329,1304.53 843.338,1304.53 843.347,1304.53 843.357,1304.53 843.366,1304.53 843.375,1304.53 843.384,1304.53 843.393,1304.53 843.402,1304.53 843.412,1304.53 843.421,1304.53 843.43,1304.53 843.439,1304.53 843.448,1304.53 843.458,1304.53 843.467,1304.53 843.476,1304.54 843.485,1304.54 843.494,1304.54 843.504,1304.54 843.513,1304.54 843.522,1304.54 843.531,1304.54 843.54,1304.54 843.55,1304.54 843.559,1304.54 843.568,1304.54 843.577,1304.54 843.586,1304.54 843.595,1304.54 843.605,1304.54 843.614,1304.54 843.623,1304.54 843.632,1304.54 843.641,1304.54 843.651,1304.54 843.66,1304.54 843.669,1304.54 843.678,1304.54 843.687,1304.54 843.697,1304.54 843.706,1304.55 843.715,1304.55 843.724,1304.55 843.733,1304.55 843.742,1304.55 843.752,1304.55 843.761,1304.55 843.77,1304.55 843.779,1304.55 843.788,1304.55 843.798,1304.55 843.807,1304.55 843.816,1304.55 843.825,1304.55 843.834,1304.55 843.844,1304.55 843.853,1304.55 843.862,1304.55 843.871,1304.55 843.88,1304.55 843.89,1304.55 843.899,1304.55 843.908,1304.55 843.917,1304.55 843.926,1304.55 843.935,1304.56 843.945,1304.56 843.954,1304.56 843.963,1304.56 843.972,1304.56 843.981,1304.56 843.991,1304.56 844,1304.56 844.009,1304.56 844.018,1304.56 844.027,1304.56 844.037,1304.56 844.046,1304.56 844.055,1304.56 844.064,1304.56 844.073,1304.56 844.082,1304.56 844.092,1304.56 844.101,1304.56 844.11,1304.56 844.119,1304.56 844.128,1304.56 844.138,1304.56 844.147,1304.56 844.156,1304.56 844.165,1304.56 844.174,1304.57 844.184,1304.57 844.193,1304.57 844.202,1304.57 844.211,1304.57 844.22,1304.57 844.23,1304.57 844.239,1304.57 844.248,1304.57 844.257,1304.57 844.266,1304.57 844.275,1304.57 844.285,1304.57 844.294,1304.57 844.303,1304.57 844.312,1304.57 844.321,1304.57 844.331,1304.57 844.34,1304.57 844.349,1304.57 844.358,1304.57 844.367,1304.57 844.377,1304.57 844.386,1304.57 844.395,1304.57 844.404,1304.58 844.413,1304.58 844.423,1304.58 844.432,1304.58 844.441,1304.58 844.45,1304.58 844.459,1304.58 844.468,1304.58 844.478,1304.58 844.487,1304.58 844.496,1304.58 844.505,1304.58 844.514,1304.58 844.524,1304.58 844.533,1304.58 844.542,1304.58 844.551,1304.58 844.56,1304.58 844.57,1304.58 844.579,1304.58 844.588,1304.58 844.597,1304.58 844.606,1304.58 844.615,1304.58 844.625,1304.58 844.634,1304.59 844.643,1304.59 844.652,1304.59 844.661,1304.59 844.671,1304.59 844.68,1304.59 844.689,1304.59 844.698,1304.59 844.707,1304.59 844.717,1304.59 844.726,1304.59 844.735,1304.59 844.744,1304.59 844.753,1304.59 844.763,1304.59 844.772,1304.59 844.781,1304.59 844.79,1304.59 844.799,1304.59 844.808,1304.59 844.818,1304.59 844.827,1304.59 844.836,1304.59 844.845,1304.59 844.854,1304.59 844.864,1304.59 844.873,1304.6 844.882,1304.6 844.891,1304.6 844.9,1304.6 844.91,1304.6 844.919,1304.6 844.928,1304.6 844.937,1304.6 844.946,1304.6 844.955,1304.6 844.965,1304.6 844.974,1304.6 844.983,1304.6 844.992,1304.6 845.001,1304.6 845.011,1304.6 845.02,1304.6 845.029,1304.6 845.038,1304.6 845.047,1304.6 845.057,1304.6 845.066,1304.6 845.075,1304.6 845.084,1304.6 845.093,1304.6 845.103,1304.61 845.112,1304.61 845.121,1304.61 845.13,1304.61 845.139,1304.61 845.148,1304.61 845.158,1304.61 845.167,1304.61 845.176,1304.61 845.185,1304.61 845.194,1304.61 845.204,1304.61 845.213,1304.61 845.222,1304.61 845.231,1304.61 845.24,1304.61 845.25,1304.61 845.259,1304.61 845.268,1304.61 845.277,1304.61 845.286,1304.61 845.295,1304.61 845.305,1304.61 845.314,1304.61 845.323,1304.61 845.332,1304.62 845.341,1304.62 845.351,1304.62 845.36,1304.62 845.369,1304.62 845.378,1304.62 845.387,1304.62 845.397,1304.62 845.406,1304.62 845.415,1304.62 845.424,1304.62 845.433,1304.62 845.443,1304.62 845.452,1304.62 845.461,1304.62 845.47,1304.62 845.479,1304.62 845.488,1304.62 845.498,1304.62 845.507,1304.62 845.516,1304.62 845.525,1304.62 845.534,1304.62 845.544,1304.62 845.553,1304.62 845.562,1304.63 845.571,1304.63 845.58,1304.63 845.59,1304.63 845.599,1304.63 845.608,1304.63 845.617,1304.63 845.626,1304.63 845.635,1304.63 845.645,1304.63 845.654,1304.63 845.663,1304.63 845.672,1304.63 845.681,1304.63 845.691,1304.63 845.7,1304.63 845.709,1304.63 845.718,1304.63 845.727,1304.63 845.737,1304.63 845.746,1304.63 845.755,1304.63 845.764,1304.63 845.773,1304.63 845.783,1304.63 845.792,1304.64 845.801,1304.64 845.81,1304.64 845.819,1304.64 845.828,1304.64 845.838,1304.64 845.847,1304.64 845.856,1304.64 845.865,1304.64 845.874,1304.64 845.884,1304.64 845.893,1304.64 845.902,1304.64 845.911,1304.64 845.92,1304.64 845.93,1304.64 845.939,1304.64 845.948,1304.64 845.957,1304.64 845.966,1304.64 845.975,1304.64 845.985,1304.64 845.994,1304.64 846.003,1304.64 846.012,1304.64 846.021,1304.65 846.031,1304.65 846.04,1304.65 846.049,1304.65 846.058,1304.65 846.067,1304.65 846.077,1304.65 846.086,1304.65 846.095,1304.65 846.104,1304.65 846.113,1304.65 846.123,1304.65 846.132,1304.65 846.141,1304.65 846.15,1304.65 846.159,1304.65 846.168,1304.65 846.178,1304.65 846.187,1304.65 846.196,1304.65 846.205,1304.65 846.214,1304.65 846.224,1304.65 846.233,1304.65 846.242,1304.65 846.251,1304.66 846.26,1304.66 846.27,1304.66 846.279,1304.66 846.288,1304.66 846.297,1304.66 846.306,1304.66 846.315,1304.66 846.325,1304.66 846.334,1304.66 846.343,1304.66 846.352,1304.66 846.361,1304.66 846.371,1304.66 846.38,1304.66 846.389,1304.66 846.398,1304.66 846.407,1304.66 846.417,1304.66 846.426,1304.66 846.435,1304.66 846.444,1304.66 846.453,1304.66 846.463,1304.66 846.472,1304.66 846.481,1304.67 846.49,1304.67 846.499,1304.67 846.508,1304.67 846.518,1304.67 846.527,1304.67 846.536,1304.67 846.545,1304.67 846.554,1304.67 846.564,1304.67 846.573,1304.67 846.582,1304.67 846.591,1304.67 846.6,1304.67 846.61,1304.67 846.619,1304.67 846.628,1304.67 846.637,1304.67 846.646,1304.67 846.656,1304.67 846.665,1304.67 846.674,1304.67 846.683,1304.67 846.692,1304.67 846.701,1304.67 846.711,1304.68 846.72,1304.68 846.729,1304.68 846.738,1304.68 846.747,1304.68 846.757,1304.68 846.766,1304.68 846.775,1304.68 846.784,1304.68 846.793,1304.68 846.803,1304.68 846.812,1304.68 846.821,1304.68 846.83,1304.68 846.839,1304.68 846.848,1304.68 846.858,1304.68 846.867,1304.68 846.876,1304.68 846.885,1304.68 846.894,1304.68 846.904,1304.68 846.913,1304.68 846.922,1304.68 846.931,1304.68 846.94,1304.69 846.95,1304.69 846.959,1304.69 846.968,1304.69 846.977,1304.69 846.986,1304.69 846.996,1304.69 847.005,1304.69 847.014,1304.69 847.023,1304.69 847.032,1304.69 847.041,1304.69 847.051,1304.69 847.06,1304.69 847.069,1304.69 847.078,1304.69 847.087,1304.69 847.097,1304.69 847.106,1304.69 847.115,1304.69 847.124,1304.69 847.133,1304.69 847.143,1304.69 847.152,1304.69 847.161,1304.7 847.17,1304.7 847.179,1304.7 847.188,1304.7 847.198,1304.7 847.207,1304.7 847.216,1304.7 847.225,1304.7 847.234,1304.7 847.244,1304.7 847.253,1304.7 847.262,1304.7 847.271,1304.7 847.28,1304.7 847.29,1304.7 847.299,1304.7 847.308,1304.7 847.317,1304.7 847.326,1304.7 847.336,1304.7 847.345,1304.7 847.354,1304.7 847.363,1304.7 847.372,1304.7 847.381,1304.7 847.391,1304.71 847.4,1304.71 847.409,1304.71 847.418,1304.71 847.427,1304.71 847.437,1304.71 847.446,1304.71 847.455,1304.71 847.464,1304.71 847.473,1304.71 847.483,1304.71 847.492,1304.71 847.501,1304.71 847.51,1304.71 847.519,1304.71 847.528,1304.71 847.538,1304.71 847.547,1304.71 847.556,1304.71 847.565,1304.71 847.574,1304.71 847.584,1304.71 847.593,1304.71 847.602,1304.71 847.611,1304.71 847.62,1304.72 847.63,1304.72 847.639,1304.72 847.648,1304.72 847.657,1304.72 847.666,1304.72 847.676,1304.72 847.685,1304.72 847.694,1304.72 847.703,1304.72 847.712,1304.72 847.721,1304.72 847.731,1304.72 847.74,1304.72 847.749,1304.72 847.758,1304.72 847.767,1304.72 847.777,1304.72 847.786,1304.72 847.795,1304.72 847.804,1304.72 847.813,1304.72 847.823,1304.72 847.832,1304.72 847.841,1304.72 847.85,1304.73 847.859,1304.73 847.868,1304.73 847.878,1304.73 847.887,1304.73 847.896,1304.73 847.905,1304.73 847.914,1304.73 847.924,1304.73 847.933,1304.73 847.942,1304.73 847.951,1304.73 847.96,1304.73 847.97,1304.73 847.979,1304.73 847.988,1304.73 847.997,1304.73 848.006,1304.73 848.016,1304.73 848.025,1304.73 848.034,1304.73 848.043,1304.73 848.052,1304.73 848.061,1304.73 848.071,1304.74 848.08,1304.74 848.089,1304.74 848.098,1304.74 848.107,1304.74 848.117,1304.74 848.126,1304.74 848.135,1304.74 848.144,1304.74 848.153,1304.74 848.163,1304.74 848.172,1304.74 848.181,1304.74 848.19,1304.74 848.199,1304.74 848.208,1304.74 848.218,1304.74 848.227,1304.74 848.236,1304.74 848.245,1304.74 848.254,1304.74 848.264,1304.74 848.273,1304.74 848.282,1304.74 848.291,1304.74 848.3,1304.75 848.31,1304.75 848.319,1304.75 848.328,1304.75 848.337,1304.75 848.346,1304.75 848.356,1304.75 848.365,1304.75 848.374,1304.75 848.383,1304.75 848.392,1304.75 848.401,1304.75 848.411,1304.75 848.42,1304.75 848.429,1304.75 848.438,1304.75 848.447,1304.75 848.457,1304.75 848.466,1304.75 848.475,1304.75 848.484,1304.75 848.493,1304.75 848.503,1304.75 848.512,1304.75 848.521,1304.76 848.53,1304.76 848.539,1304.76 848.548,1304.76 848.558,1304.76 848.567,1304.76 848.576,1304.76 848.585,1304.76 848.594,1304.76 848.604,1304.76 848.613,1304.76 848.622,1304.76 848.631,1304.76 848.64,1304.76 848.65,1304.76 848.659,1304.76 848.668,1304.76 848.677,1304.76 848.686,1304.76 848.696,1304.76 848.705,1304.76 848.714,1304.76 848.723,1304.76 848.732,1304.76 848.741,1304.76 848.751,1304.77 848.76,1304.77 848.769,1304.77 848.778,1304.77 848.787,1304.77 848.797,1304.77 848.806,1304.77 848.815,1304.77 848.824,1304.77 848.833,1304.77 848.843,1304.77 848.852,1304.77 848.861,1304.77 848.87,1304.77 848.879,1304.77 848.888,1304.77 848.898,1304.77 848.907,1304.77 848.916,1304.77 848.925,1304.77 848.934,1304.77 848.944,1304.77 848.953,1304.77 848.962,1304.77 848.971,1304.78 848.98,1304.78 848.99,1304.78 848.999,1304.78 849.008,1304.78 849.017,1304.78 849.026,1304.78 849.036,1304.78 849.045,1304.78 849.054,1304.78 849.063,1304.78 849.072,1304.78 849.081,1304.78 849.091,1304.78 849.1,1304.78 849.109,1304.78 849.118,1304.78 849.127,1304.78 849.137,1304.78 849.146,1304.78 849.155,1304.78 849.164,1304.78 849.173,1304.78 849.183,1304.78 849.192,1304.78 849.201,1304.79 849.21,1304.79 849.219,1304.79 849.229,1304.79 849.238,1304.79 849.247,1304.79 849.256,1304.79 849.265,1304.79 849.274,1304.79 849.284,1304.79 849.293,1304.79 849.302,1304.79 849.311,1304.79 849.32,1304.79 849.33,1304.79 849.339,1304.79 849.348,1304.79 849.357,1304.79 849.366,1304.79 849.376,1304.79 849.385,1304.79 849.394,1304.79 849.403,1304.79 849.412,1304.79 849.421,1304.8 849.431,1304.8 849.44,1304.8 849.449,1304.8 849.458,1304.8 849.467,1304.8 849.477,1304.8 849.486,1304.8 849.495,1304.8 849.504,1304.8 849.513,1304.8 849.523,1304.8 849.532,1304.8 849.541,1304.8 849.55,1304.8 849.559,1304.8 849.569,1304.8 849.578,1304.8 849.587,1304.8 849.596,1304.8 849.605,1304.8 849.614,1304.8 849.624,1304.8 849.633,1304.8 849.642,1304.81 849.651,1304.81 849.66,1304.81 849.67,1304.81 849.679,1304.81 849.688,1304.81 849.697,1304.81 849.706,1304.81 849.716,1304.81 849.725,1304.81 849.734,1304.81 849.743,1304.81 849.752,1304.81 849.761,1304.81 849.771,1304.81 849.78,1304.81 849.789,1304.81 849.798,1304.81 849.807,1304.81 849.817,1304.81 849.826,1304.81 849.835,1304.81 849.844,1304.81 849.853,1304.81 849.863,1304.81 849.872,1304.82 849.881,1304.82 849.89,1304.82 849.899,1304.82 849.909,1304.82 849.918,1304.82 849.927,1304.82 849.936,1304.82 849.945,1304.82 849.954,1304.82 849.964,1304.82 849.973,1304.82 849.982,1304.82 849.991,1304.82 850,1304.82 850.01,1304.82 850.019,1304.82 850.028,1304.82 850.037,1304.82 850.046,1304.82 850.056,1304.82 850.065,1304.82 850.074,1304.82 850.083,1304.82 850.092,1304.83 850.101,1304.83 850.111,1304.83 850.12,1304.83 850.129,1304.83 850.138,1304.83 850.147,1304.83 850.157,1304.83 850.166,1304.83 850.175,1304.83 850.184,1304.83 850.193,1304.83 850.203,1304.83 850.212,1304.83 850.221,1304.83 850.23,1304.83 850.239,1304.83 850.249,1304.83 850.258,1304.83 850.267,1304.83 850.276,1304.83 850.285,1304.83 850.294,1304.83 850.304,1304.83 850.313,1304.84 850.322,1304.84 850.331,1304.84 850.34,1304.84 850.35,1304.84 850.359,1304.84 850.368,1304.84 850.377,1304.84 850.386,1304.84 850.396,1304.84 850.405,1304.84 850.414,1304.84 850.423,1304.84 850.432,1304.84 850.441,1304.84 850.451,1304.84 850.46,1304.84 850.469,1304.84 850.478,1304.84 850.487,1304.84 850.497,1304.84 850.506,1304.84 850.515,1304.84 850.524,1304.84 850.533,1304.85 850.543,1304.85 850.552,1304.85 850.561,1304.85 850.57,1304.85 850.579,1304.85 850.589,1304.85 850.598,1304.85 850.607,1304.85 850.616,1304.85 850.625,1304.85 850.634,1304.85 850.644,1304.85 850.653,1304.85 850.662,1304.85 850.671,1304.85 850.68,1304.85 850.69,1304.85 850.699,1304.85 850.708,1304.85 850.717,1304.85 850.726,1304.85 850.736,1304.85 850.745,1304.85 850.754,1304.86 850.763,1304.86 850.772,1304.86 850.781,1304.86 850.791,1304.86 850.8,1304.86 850.809,1304.86 850.818,1304.86 850.827,1304.86 850.837,1304.86 850.846,1304.86 850.855,1304.86 850.864,1304.86 850.873,1304.86 850.883,1304.86 850.892,1304.86 850.901,1304.86 850.91,1304.86 850.919,1304.86 850.929,1304.86 850.938,1304.86 850.947,1304.86 850.956,1304.86 850.965,1304.86 850.974,1304.87 850.984,1304.87 850.993,1304.87 851.002,1304.87 851.011,1304.87 851.02,1304.87 851.03,1304.87 851.039,1304.87 851.048,1304.87 851.057,1304.87 851.066,1304.87 851.076,1304.87 851.085,1304.87 851.094,1304.87 851.103,1304.87 851.112,1304.87 851.121,1304.87 851.131,1304.87 851.14,1304.87 851.149,1304.87 851.158,1304.87 851.167,1304.87 851.177,1304.87 851.186,1304.87 851.195,1304.88 851.204,1304.88 851.213,1304.88 851.223,1304.88 851.232,1304.88 851.241,1304.88 851.25,1304.88 851.259,1304.88 851.269,1304.88 851.278,1304.88 851.287,1304.88 851.296,1304.88 851.305,1304.88 851.314,1304.88 851.324,1304.88 851.333,1304.88 851.342,1304.88 851.351,1304.88 851.36,1304.88 851.37,1304.88 851.379,1304.88 851.388,1304.88 851.397,1304.88 851.406,1304.88 851.416,1304.89 851.425,1304.89 851.434,1304.89 851.443,1304.89 851.452,1304.89 851.461,1304.89 851.471,1304.89 851.48,1304.89 851.489,1304.89 851.498,1304.89 851.507,1304.89 851.517,1304.89 851.526,1304.89 851.535,1304.89 851.544,1304.89 851.553,1304.89 851.563,1304.89 851.572,1304.89 851.581,1304.89 851.59,1304.89 851.599,1304.89 851.609,1304.89 851.618,1304.89 851.627,1304.89 851.636,1304.9 851.645,1304.9 851.654,1304.9 851.664,1304.9 851.673,1304.9 851.682,1304.9 851.691,1304.9 851.7,1304.9 851.71,1304.9 851.719,1304.9 851.728,1304.9 851.737,1304.9 851.746,1304.9 851.756,1304.9 851.765,1304.9 851.774,1304.9 851.783,1304.9 851.792,1304.9 851.802,1304.9 851.811,1304.9 851.82,1304.9 851.829,1304.9 851.838,1304.9 851.847,1304.9 851.857,1304.91 851.866,1304.91 851.875,1304.91 851.884,1304.91 851.893,1304.91 851.903,1304.91 851.912,1304.91 851.921,1304.91 851.93,1304.91 851.939,1304.91 851.949,1304.91 851.958,1304.91 851.967,1304.91 851.976,1304.91 851.985,1304.91 851.994,1304.91 852.004,1304.91 852.013,1304.91 852.022,1304.91 852.031,1304.91 852.04,1304.91 852.05,1304.91 852.059,1304.91 852.068,1304.91 852.077,1304.92 852.086,1304.92 852.096,1304.92 852.105,1304.92 852.114,1304.92 852.123,1304.92 852.132,1304.92 852.142,1304.92 852.151,1304.92 852.16,1304.92 852.169,1304.92 852.178,1304.92 852.187,1304.92 852.197,1304.92 852.206,1304.92 852.215,1304.92 852.224,1304.92 852.233,1304.92 852.243,1304.92 852.252,1304.92 852.261,1304.92 852.27,1304.92 852.279,1304.92 852.289,1304.92 852.298,1304.93 852.307,1304.93 852.316,1304.93 852.325,1304.93 852.334,1304.93 852.344,1304.93 852.353,1304.93 852.362,1304.93 852.371,1304.93 852.38,1304.93 852.39,1304.93 852.399,1304.93 852.408,1304.93 852.417,1304.93 852.426,1304.93 852.436,1304.93 852.445,1304.93 852.454,1304.93 852.463,1304.93 852.472,1304.93 852.482,1304.93 852.491,1304.93 852.5,1304.93 852.509,1304.93 852.518,1304.94 852.527,1304.94 852.537,1304.94 852.546,1304.94 852.555,1304.94 852.564,1304.94 852.573,1304.94 852.583,1304.94 852.592,1304.94 852.601,1304.94 852.61,1304.94 852.619,1304.94 852.629,1304.94 852.638,1304.94 852.647,1304.94 852.656,1304.94 852.665,1304.94 852.674,1304.94 852.684,1304.94 852.693,1304.94 852.702,1304.94 852.711,1304.94 852.72,1304.94 852.73,1304.94 852.739,1304.95 852.748,1304.95 852.757,1304.95 852.766,1304.95 852.776,1304.95 852.785,1304.95 852.794,1304.95 852.803,1304.95 852.812,1304.95 852.822,1304.95 852.831,1304.95 852.84,1304.95 852.849,1304.95 852.858,1304.95 852.867,1304.95 852.877,1304.95 852.886,1304.95 852.895,1304.95 852.904,1304.95 852.913,1304.95 852.923,1304.95 852.932,1304.95 852.941,1304.95 852.95,1304.96 852.959,1304.96 852.969,1304.96 852.978,1304.96 852.987,1304.96 852.996,1304.96 853.005,1304.96 853.014,1304.96 853.024,1304.96 853.033,1304.96 853.042,1304.96 853.051,1304.96 853.06,1304.96 853.07,1304.96 853.079,1304.96 853.088,1304.96 853.097,1304.96 853.106,1304.96 853.116,1304.96 853.125,1304.96 853.134,1304.96 853.143,1304.96 853.152,1304.96 853.162,1304.96 853.171,1304.97 853.18,1304.97 853.189,1304.97 853.198,1304.97 853.207,1304.97 853.217,1304.97 853.226,1304.97 853.235,1304.97 853.244,1304.97 853.253,1304.97 853.263,1304.97 853.272,1304.97 853.281,1304.97 853.29,1304.97 853.299,1304.97 853.309,1304.97 853.318,1304.97 853.327,1304.97 853.336,1304.97 853.345,1304.97 853.354,1304.97 853.364,1304.97 853.373,1304.97 853.382,1304.97 853.391,1304.98 853.4,1304.98 853.41,1304.98 853.419,1304.98 853.428,1304.98 853.437,1304.98 853.446,1304.98 853.456,1304.98 853.465,1304.98 853.474,1304.98 853.483,1304.98 853.492,1304.98 853.502,1304.98 853.511,1304.98 853.52,1304.98 853.529,1304.98 853.538,1304.98 853.547,1304.98 853.557,1304.98 853.566,1304.98 853.575,1304.98 853.584,1304.98 853.593,1304.98 853.603,1304.99 853.612,1304.99 853.621,1304.99 853.63,1304.99 853.639,1304.99 853.649,1304.99 853.658,1304.99 853.667,1304.99 853.676,1304.99 853.685,1304.99 853.694,1304.99 853.704,1304.99 853.713,1304.99 853.722,1304.99 853.731,1304.99 853.74,1304.99 853.75,1304.99 853.759,1304.99 853.768,1304.99 853.777,1304.99 853.786,1304.99 853.796,1304.99 853.805,1304.99 853.814,1304.99 853.823,1305 853.832,1305 853.842,1305 853.851,1305 853.86,1305 853.869,1305 853.878,1305 853.887,1305 853.897,1305 853.906,1305 853.915,1305 853.924,1305 853.933,1305 853.943,1305 853.952,1305 853.961,1305 853.97,1305 853.979,1305 853.989,1305 853.998,1305 854.007,1305 854.016,1305 854.025,1305 854.035,1305.01 854.044,1305.01 854.053,1305.01 854.062,1305.01 854.071,1305.01 854.08,1305.01 854.09,1305.01 854.099,1305.01 854.108,1305.01 854.117,1305.01 854.126,1305.01 854.136,1305.01 854.145,1305.01 854.154,1305.01 854.163,1305.01 854.172,1305.01 854.182,1305.01 854.191,1305.01 854.2,1305.01 854.209,1305.01 854.218,1305.01 854.227,1305.01 854.237,1305.01 854.246,1305.01 854.255,1305.02 854.264,1305.02 854.273,1305.02 854.283,1305.02 854.292,1305.02 854.301,1305.02 854.31,1305.02 854.319,1305.02 854.329,1305.02 854.338,1305.02 854.347,1305.02 854.356,1305.02 854.365,1305.02 854.375,1305.02 854.384,1305.02 854.393,1305.02 854.402,1305.02 854.411,1305.02 854.42,1305.02 854.43,1305.02 854.439,1305.02 854.448,1305.02 854.457,1305.02 854.466,1305.03 854.476,1305.03 854.485,1305.03 854.494,1305.03 854.503,1305.03 854.512,1305.03 854.522,1305.03 854.531,1305.03 854.54,1305.03 854.549,1305.03 854.558,1305.03 854.567,1305.03 854.577,1305.03 854.586,1305.03 854.595,1305.03 854.604,1305.03 854.613,1305.03 854.623,1305.03 854.632,1305.03 854.641,1305.03 854.65,1305.03 854.659,1305.03 854.669,1305.03 854.678,1305.03 854.687,1305.04 854.696,1305.04 854.705,1305.04 854.715,1305.04 854.724,1305.04 854.733,1305.04 854.742,1305.04 854.751,1305.04 854.76,1305.04 854.77,1305.04 854.779,1305.04 854.788,1305.04 854.797,1305.04 854.806,1305.04 854.816,1305.04 854.825,1305.04 854.834,1305.04 854.843,1305.04 854.852,1305.04 854.862,1305.04 854.871,1305.04 854.88,1305.04 854.889,1305.04 854.898,1305.05 854.907,1305.05 854.917,1305.05 854.926,1305.05 854.935,1305.05 854.944,1305.05 854.953,1305.05 854.963,1305.05 854.972,1305.05 854.981,1305.05 854.99,1305.05 854.999,1305.05 855.009,1305.05 855.018,1305.05 855.027,1305.05 855.036,1305.05 855.045,1305.05 855.055,1305.05 855.064,1305.05 855.073,1305.05 855.082,1305.05 855.091,1305.05 855.1,1305.05 855.11,1305.05 855.119,1305.06 855.128,1305.06 855.137,1305.06 855.146,1305.06 855.156,1305.06 855.165,1305.06 855.174,1305.06 855.183,1305.06 855.192,1305.06 855.202,1305.06 855.211,1305.06 855.22,1305.06 855.229,1305.06 855.238,1305.06 855.247,1305.06 855.257,1305.06 855.266,1305.06 855.275,1305.06 855.284,1305.06 855.293,1305.06 855.303,1305.06 855.312,1305.06 855.321,1305.06 855.33,1305.07 855.339,1305.07 855.349,1305.07 855.358,1305.07 855.367,1305.07 855.376,1305.07 855.385,1305.07 855.395,1305.07 855.404,1305.07 855.413,1305.07 855.422,1305.07 855.431,1305.07 855.44,1305.07 855.45,1305.07 855.459,1305.07 855.468,1305.07 855.477,1305.07 855.486,1305.07 855.496,1305.07 855.505,1305.07 855.514,1305.07 855.523,1305.07 855.532,1305.07 855.542,1305.08 855.551,1305.08 855.56,1305.08 855.569,1305.08 855.578,1305.08 855.587,1305.08 855.597,1305.08 855.606,1305.08 855.615,1305.08 855.624,1305.08 855.633,1305.08 855.643,1305.08 855.652,1305.08 855.661,1305.08 855.67,1305.08 855.679,1305.08 855.689,1305.08 855.698,1305.08 855.707,1305.08 855.716,1305.08 855.725,1305.08 855.735,1305.08 855.744,1305.08 855.753,1305.08 855.762,1305.09 855.771,1305.09 855.78,1305.09 855.79,1305.09 855.799,1305.09 855.808,1305.09 855.817,1305.09 855.826,1305.09 855.836,1305.09 855.845,1305.09 855.854,1305.09 855.863,1305.09 855.872,1305.09 855.882,1305.09 855.891,1305.09 855.9,1305.09 855.909,1305.09 855.918,1305.09 855.927,1305.09 855.937,1305.09 855.946,1305.09 855.955,1305.09 855.964,1305.09 855.973,1305.1 855.983,1305.1 855.992,1305.1 856.001,1305.1 856.01,1305.1 856.019,1305.1 856.029,1305.1 856.038,1305.1 856.047,1305.1 856.056,1305.1 856.065,1305.1 856.075,1305.1 856.084,1305.1 856.093,1305.1 856.102,1305.1 856.111,1305.1 856.12,1305.1 856.13,1305.1 856.139,1305.1 856.148,1305.1 856.157,1305.1 856.166,1305.1 856.176,1305.1 856.185,1305.11 856.194,1305.11 856.203,1305.11 856.212,1305.11 856.222,1305.11 856.231,1305.11 856.24,1305.11 856.249,1305.11 856.258,1305.11 856.267,1305.11 856.277,1305.11 856.286,1305.11 856.295,1305.11 856.304,1305.11 856.313,1305.11 856.323,1305.11 856.332,1305.11 856.341,1305.11 856.35,1305.11 856.359,1305.11 856.369,1305.11 856.378,1305.11 856.387,1305.11 856.396,1305.12 856.405,1305.12 856.415,1305.12 856.424,1305.12 856.433,1305.12 856.442,1305.12 856.451,1305.12 856.46,1305.12 856.47,1305.12 856.479,1305.12 856.488,1305.12 856.497,1305.12 856.506,1305.12 856.516,1305.12 856.525,1305.12 856.534,1305.12 856.543,1305.12 856.552,1305.12 856.562,1305.12 856.571,1305.12 856.58,1305.12 856.589,1305.12 856.598,1305.12 856.608,1305.13 856.617,1305.13 856.626,1305.13 856.635,1305.13 856.644,1305.13 856.653,1305.13 856.663,1305.13 856.672,1305.13 856.681,1305.13 856.69,1305.13 856.699,1305.13 856.709,1305.13 856.718,1305.13 856.727,1305.13 856.736,1305.13 856.745,1305.13 856.755,1305.13 856.764,1305.13 856.773,1305.13 856.782,1305.13 856.791,1305.13 856.8,1305.13 856.81,1305.13 856.819,1305.14 856.828,1305.14 856.837,1305.14 856.846,1305.14 856.856,1305.14 856.865,1305.14 856.874,1305.14 856.883,1305.14 856.892,1305.14 856.902,1305.14 856.911,1305.14 856.92,1305.14 856.929,1305.14 856.938,1305.14 856.948,1305.14 856.957,1305.14 856.966,1305.14 856.975,1305.14 856.984,1305.14 856.993,1305.14 857.003,1305.14 857.012,1305.14 857.021,1305.14 857.03,1305.15 857.039,1305.15 857.049,1305.15 857.058,1305.15 857.067,1305.15 857.076,1305.15 857.085,1305.15 857.095,1305.15 857.104,1305.15 857.113,1305.15 857.122,1305.15 857.131,1305.15 857.14,1305.15 857.15,1305.15 857.159,1305.15 857.168,1305.15 857.177,1305.15 857.186,1305.15 857.196,1305.15 857.205,1305.15 857.214,1305.15 857.223,1305.15 857.232,1305.15 857.242,1305.16 857.251,1305.16 857.26,1305.16 857.269,1305.16 857.278,1305.16 857.288,1305.16 857.297,1305.16 857.306,1305.16 857.315,1305.16 857.324,1305.16 857.333,1305.16 857.343,1305.16 857.352,1305.16 857.361,1305.16 857.37,1305.16 857.379,1305.16 857.389,1305.16 857.398,1305.16 857.407,1305.16 857.416,1305.16 857.425,1305.16 857.435,1305.16 857.444,1305.16 857.453,1305.17 857.462,1305.17 857.471,1305.17 857.48,1305.17 857.49,1305.17 857.499,1305.17 857.508,1305.17 857.517,1305.17 857.526,1305.17 857.536,1305.17 857.545,1305.17 857.554,1305.17 857.563,1305.17 857.572,1305.17 857.582,1305.17 857.591,1305.17 857.6,1305.17 857.609,1305.17 857.618,1305.17 857.628,1305.17 857.637,1305.17 857.646,1305.17 857.655,1305.17 857.664,1305.18 857.673,1305.18 857.683,1305.18 857.692,1305.18 857.701,1305.18 857.71,1305.18 857.719,1305.18 857.729,1305.18 857.738,1305.18 857.747,1305.18 857.756,1305.18 857.765,1305.18 857.775,1305.18 857.784,1305.18 857.793,1305.18 857.802,1305.18 857.811,1305.18 857.82,1305.18 857.83,1305.18 857.839,1305.18 857.848,1305.18 857.857,1305.18 857.866,1305.18 857.876,1305.19 857.885,1305.19 857.894,1305.19 857.903,1305.19 857.912,1305.19 857.922,1305.19 857.931,1305.19 857.94,1305.19 857.949,1305.19 857.958,1305.19 857.968,1305.19 857.977,1305.19 857.986,1305.19 857.995,1305.19 858.004,1305.19 858.013,1305.19 858.023,1305.19 858.032,1305.19 858.041,1305.19 858.05,1305.19 858.059,1305.19 858.069,1305.19 858.078,1305.19 858.087,1305.2 858.096,1305.2 858.105,1305.2 858.115,1305.2 858.124,1305.2 858.133,1305.2 858.142,1305.2 858.151,1305.2 858.16,1305.2 858.17,1305.2 858.179,1305.2 858.188,1305.2 858.197,1305.2 858.206,1305.2 858.216,1305.2 858.225,1305.2 858.234,1305.2 858.243,1305.2 858.252,1305.2 858.262,1305.2 858.271,1305.2 858.28,1305.2 858.289,1305.2 858.298,1305.21 858.308,1305.21 858.317,1305.21 858.326,1305.21 858.335,1305.21 858.344,1305.21 858.353,1305.21 858.363,1305.21 858.372,1305.21 858.381,1305.21 858.39,1305.21 858.399,1305.21 858.409,1305.21 858.418,1305.21 858.427,1305.21 858.436,1305.21 858.445,1305.21 858.455,1305.21 858.464,1305.21 858.473,1305.21 858.482,1305.21 858.491,1305.21 858.5,1305.21 858.51,1305.22 858.519,1305.22 858.528,1305.22 858.537,1305.22 858.546,1305.22 858.556,1305.22 858.565,1305.22 858.574,1305.22 858.583,1305.22 858.592,1305.22 858.602,1305.22 858.611,1305.22 858.62,1305.22 858.629,1305.22 858.638,1305.22 858.648,1305.22 858.657,1305.22 858.666,1305.22 858.675,1305.22 858.684,1305.22 858.693,1305.22 858.703,1305.22 858.712,1305.22 858.721,1305.23 858.73,1305.23 858.739,1305.23 858.749,1305.23 858.758,1305.23 858.767,1305.23 858.776,1305.23 858.785,1305.23 858.795,1305.23 858.804,1305.23 858.813,1305.23 858.822,1305.23 858.831,1305.23 858.84,1305.23 858.85,1305.23 858.859,1305.23 858.868,1305.23 858.877,1305.23 858.886,1305.23 858.896,1305.23 858.905,1305.23 858.914,1305.23 858.923,1305.24 858.932,1305.24 858.942,1305.24 858.951,1305.24 858.96,1305.24 858.969,1305.24 858.978,1305.24 858.988,1305.24 858.997,1305.24 859.006,1305.24 859.015,1305.24 859.024,1305.24 859.033,1305.24 859.043,1305.24 859.052,1305.24 859.061,1305.24 859.07,1305.24 859.079,1305.24 859.089,1305.24 859.098,1305.24 859.107,1305.24 859.116,1305.24 859.125,1305.24 859.135,1305.25 859.144,1305.25 859.153,1305.25 859.162,1305.25 859.171,1305.25 859.181,1305.25 859.19,1305.25 859.199,1305.25 859.208,1305.25 859.217,1305.25 859.226,1305.25 859.236,1305.25 859.245,1305.25 859.254,1305.25 859.263,1305.25 859.272,1305.25 859.282,1305.25 859.291,1305.25 859.3,1305.25 859.309,1305.25 859.318,1305.25 859.328,1305.25 859.337,1305.25 859.346,1305.26 859.355,1305.26 859.364,1305.26 859.373,1305.26 859.383,1305.26 859.392,1305.26 859.401,1305.26 859.41,1305.26 859.419,1305.26 859.429,1305.26 859.438,1305.26 859.447,1305.26 859.456,1305.26 859.465,1305.26 859.475,1305.26 859.484,1305.26 859.493,1305.26 859.502,1305.26 859.511,1305.26 859.521,1305.26 859.53,1305.26 859.539,1305.26 859.548,1305.27 859.557,1305.27 859.566,1305.27 859.576,1305.27 859.585,1305.27 859.594,1305.27 859.603,1305.27 859.612,1305.27 859.622,1305.27 859.631,1305.27 859.64,1305.27 859.649,1305.27 859.658,1305.27 859.668,1305.27 859.677,1305.27 859.686,1305.27 859.695,1305.27 859.704,1305.27 859.713,1305.27 859.723,1305.27 859.732,1305.27 859.741,1305.27 859.75,1305.27 859.759,1305.28 859.769,1305.28 859.778,1305.28 859.787,1305.28 859.796,1305.28 859.805,1305.28 859.815,1305.28 859.824,1305.28 859.833,1305.28 859.842,1305.28 859.851,1305.28 859.861,1305.28 859.87,1305.28 859.879,1305.28 859.888,1305.28 859.897,1305.28 859.906,1305.28 859.916,1305.28 859.925,1305.28 859.934,1305.28 859.943,1305.28 859.952,1305.28 859.962,1305.28 859.971,1305.29 859.98,1305.29 859.989,1305.29 859.998,1305.29 860.008,1305.29 860.017,1305.29 860.026,1305.29 860.035,1305.29 860.044,1305.29 860.053,1305.29 860.063,1305.29 860.072,1305.29 860.081,1305.29 860.09,1305.29 860.099,1305.29 860.109,1305.29 860.118,1305.29 860.127,1305.29 860.136,1305.29 860.145,1305.29 860.155,1305.29 860.164,1305.29 860.173,1305.3 860.182,1305.3 860.191,1305.3 860.201,1305.3 860.21,1305.3 860.219,1305.3 860.228,1305.3 860.237,1305.3 860.246,1305.3 860.256,1305.3 860.265,1305.3 860.274,1305.3 860.283,1305.3 860.292,1305.3 860.302,1305.3 860.311,1305.3 860.32,1305.3 860.329,1305.3 860.338,1305.3 860.348,1305.3 860.357,1305.3 860.366,1305.3 860.375,1305.3 860.384,1305.31 860.393,1305.31 860.403,1305.31 860.412,1305.31 860.421,1305.31 860.43,1305.31 860.439,1305.31 860.449,1305.31 860.458,1305.31 860.467,1305.31 860.476,1305.31 860.485,1305.31 860.495,1305.31 860.504,1305.31 860.513,1305.31 860.522,1305.31 860.531,1305.31 860.541,1305.31 860.55,1305.31 860.559,1305.31 860.568,1305.31 860.577,1305.31 860.586,1305.32 860.596,1305.32 860.605,1305.32 860.614,1305.32 860.623,1305.32 860.632,1305.32 860.642,1305.32 860.651,1305.32 860.66,1305.32 860.669,1305.32 860.678,1305.32 860.688,1305.32 860.697,1305.32 860.706,1305.32 860.715,1305.32 860.724,1305.32 860.733,1305.32 860.743,1305.32 860.752,1305.32 860.761,1305.32 860.77,1305.32 860.779,1305.32 860.789,1305.32 860.798,1305.33 860.807,1305.33 860.816,1305.33 860.825,1305.33 860.835,1305.33 860.844,1305.33 860.853,1305.33 860.862,1305.33 860.871,1305.33 860.881,1305.33 860.89,1305.33 860.899,1305.33 860.908,1305.33 860.917,1305.33 860.926,1305.33 860.936,1305.33 860.945,1305.33 860.954,1305.33 860.963,1305.33 860.972,1305.33 860.982,1305.33 860.991,1305.33 861,1305.34 861.009,1305.34 861.018,1305.34 861.028,1305.34 861.037,1305.34 861.046,1305.34 861.055,1305.34 861.064,1305.34 861.073,1305.34 861.083,1305.34 861.092,1305.34 861.101,1305.34 861.11,1305.34 861.119,1305.34 861.129,1305.34 861.138,1305.34 861.147,1305.34 861.156,1305.34 861.165,1305.34 861.175,1305.34 861.184,1305.34 861.193,1305.34 861.202,1305.35 861.211,1305.35 861.221,1305.35 861.23,1305.35 861.239,1305.35 861.248,1305.35 861.257,1305.35 861.266,1305.35 861.276,1305.35 861.285,1305.35 861.294,1305.35 861.303,1305.35 861.312,1305.35 861.322,1305.35 861.331,1305.35 861.34,1305.35 861.349,1305.35 861.358,1305.35 861.368,1305.35 861.377,1305.35 861.386,1305.35 861.395,1305.35 861.404,1305.35 861.414,1305.36 861.423,1305.36 861.432,1305.36 861.441,1305.36 861.45,1305.36 861.459,1305.36 861.469,1305.36 861.478,1305.36 861.487,1305.36 861.496,1305.36 861.505,1305.36 861.515,1305.36 861.524,1305.36 861.533,1305.36 861.542,1305.36 861.551,1305.36 861.561,1305.36 861.57,1305.36 861.579,1305.36 861.588,1305.36 861.597,1305.36 861.606,1305.36 861.616,1305.37 861.625,1305.37 861.634,1305.37 861.643,1305.37 861.652,1305.37 861.662,1305.37 861.671,1305.37 861.68,1305.37 861.689,1305.37 861.698,1305.37 861.708,1305.37 861.717,1305.37 861.726,1305.37 861.735,1305.37 861.744,1305.37 861.754,1305.37 861.763,1305.37 861.772,1305.37 861.781,1305.37 861.79,1305.37 861.799,1305.37 861.809,1305.37 861.818,1305.37 861.827,1305.38 861.836,1305.38 861.845,1305.38 861.855,1305.38 861.864,1305.38 861.873,1305.38 861.882,1305.38 861.891,1305.38 861.901,1305.38 861.91,1305.38 861.919,1305.38 861.928,1305.38 861.937,1305.38 861.946,1305.38 861.956,1305.38 861.965,1305.38 861.974,1305.38 861.983,1305.38 861.992,1305.38 862.002,1305.38 862.011,1305.38 862.02,1305.38 862.029,1305.39 862.038,1305.39 862.048,1305.39 862.057,1305.39 862.066,1305.39 862.075,1305.39 862.084,1305.39 862.094,1305.39 862.103,1305.39 862.112,1305.39 862.121,1305.39 862.13,1305.39 862.139,1305.39 862.149,1305.39 862.158,1305.39 862.167,1305.39 862.176,1305.39 862.185,1305.39 862.195,1305.39 862.204,1305.39 862.213,1305.39 862.222,1305.39 862.231,1305.4 862.241,1305.4 862.25,1305.4 862.259,1305.4 862.268,1305.4 862.277,1305.4 862.286,1305.4 862.296,1305.4 862.305,1305.4 862.314,1305.4 862.323,1305.4 862.332,1305.4 862.342,1305.4 862.351,1305.4 862.36,1305.4 862.369,1305.4 862.378,1305.4 862.388,1305.4 862.397,1305.4 862.406,1305.4 862.415,1305.4 862.424,1305.4 862.434,1305.41 862.443,1305.41 862.452,1305.41 862.461,1305.41 862.47,1305.41 862.479,1305.41 862.489,1305.41 862.498,1305.41 862.507,1305.41 862.516,1305.41 862.525,1305.41 862.535,1305.41 862.544,1305.41 862.553,1305.41 862.562,1305.41 862.571,1305.41 862.581,1305.41 862.59,1305.41 862.599,1305.41 862.608,1305.41 862.617,1305.41 862.626,1305.41 862.636,1305.42 862.645,1305.42 862.654,1305.42 862.663,1305.42 862.672,1305.42 862.682,1305.42 862.691,1305.42 862.7,1305.42 862.709,1305.42 862.718,1305.42 862.728,1305.42 862.737,1305.42 862.746,1305.42 862.755,1305.42 862.764,1305.42 862.774,1305.42 862.783,1305.42 862.792,1305.42 862.801,1305.42 862.81,1305.42 862.819,1305.42 862.829,1305.42 862.838,1305.42 862.847,1305.43 862.856,1305.43 862.865,1305.43 862.875,1305.43 862.884,1305.43 862.893,1305.43 862.902,1305.43 862.911,1305.43 862.921,1305.43 862.93,1305.43 862.939,1305.43 862.948,1305.43 862.957,1305.43 862.966,1305.43 862.976,1305.43 862.985,1305.43 862.994,1305.43 863.003,1305.43 863.012,1305.43 863.022,1305.43 863.031,1305.43 863.04,1305.43 863.049,1305.44 863.058,1305.44 863.068,1305.44 863.077,1305.44 863.086,1305.44 863.095,1305.44 863.104,1305.44 863.114,1305.44 863.123,1305.44 863.132,1305.44 863.141,1305.44 863.15,1305.44 863.159,1305.44 863.169,1305.44 863.178,1305.44 863.187,1305.44 863.196,1305.44 863.205,1305.44 863.215,1305.44 863.224,1305.44 863.233,1305.44 863.242,1305.44 863.251,1305.45 863.261,1305.45 863.27,1305.45 863.279,1305.45 863.288,1305.45 863.297,1305.45 863.306,1305.45 863.316,1305.45 863.325,1305.45 863.334,1305.45 863.343,1305.45 863.352,1305.45 863.362,1305.45 863.371,1305.45 863.38,1305.45 863.389,1305.45 863.398,1305.45 863.408,1305.45 863.417,1305.45 863.426,1305.45 863.435,1305.45 863.444,1305.45 863.454,1305.46 863.463,1305.46 863.472,1305.46 863.481,1305.46 863.49,1305.46 863.499,1305.46 863.509,1305.46 863.518,1305.46 863.527,1305.46 863.536,1305.46 863.545,1305.46 863.555,1305.46 863.564,1305.46 863.573,1305.46 863.582,1305.46 863.591,1305.46 863.601,1305.46 863.61,1305.46 863.619,1305.46 863.628,1305.46 863.637,1305.46 863.646,1305.46 863.656,1305.47 863.665,1305.47 863.674,1305.47 863.683,1305.47 863.692,1305.47 863.702,1305.47 863.711,1305.47 863.72,1305.47 863.729,1305.47 863.738,1305.47 863.748,1305.47 863.757,1305.47 863.766,1305.47 863.775,1305.47 863.784,1305.47 863.794,1305.47 863.803,1305.47 863.812,1305.47 863.821,1305.47 863.83,1305.47 863.839,1305.47 863.849,1305.47 863.858,1305.48 863.867,1305.48 863.876,1305.48 863.885,1305.48 863.895,1305.48 863.904,1305.48 863.913,1305.48 863.922,1305.48 863.931,1305.48 863.941,1305.48 863.95,1305.48 863.959,1305.48 863.968,1305.48 863.977,1305.48 863.987,1305.48 863.996,1305.48 864.005,1305.48 864.014,1305.48 864.023,1305.48 864.032,1305.48 864.042,1305.48 864.051,1305.48 864.06,1305.49 864.069,1305.49 864.078,1305.49 864.088,1305.49 864.097,1305.49 864.106,1305.49 864.115,1305.49 864.124,1305.49 864.134,1305.49 864.143,1305.49 864.152,1305.49 864.161,1305.49 864.17,1305.49 864.179,1305.49 864.189,1305.49 864.198,1305.49 864.207,1305.49 864.216,1305.49 864.225,1305.49 864.235,1305.49 864.244,1305.49 864.253,1305.49 864.262,1305.5 864.271,1305.5 864.281,1305.5 864.29,1305.5 864.299,1305.5 864.308,1305.5 864.317,1305.5 864.327,1305.5 864.336,1305.5 864.345,1305.5 864.354,1305.5 864.363,1305.5 864.372,1305.5 864.382,1305.5 864.391,1305.5 864.4,1305.5 864.409,1305.5 864.418,1305.5 864.428,1305.5 864.437,1305.5 864.446,1305.5 864.455,1305.5 864.464,1305.51 864.474,1305.51 864.483,1305.51 864.492,1305.51 864.501,1305.51 864.51,1305.51 864.519,1305.51 864.529,1305.51 864.538,1305.51 864.547,1305.51 864.556,1305.51 864.565,1305.51 864.575,1305.51 864.584,1305.51 864.593,1305.51 864.602,1305.51 864.611,1305.51 864.621,1305.51 864.63,1305.51 864.639,1305.51 864.648,1305.51 864.657,1305.51 864.667,1305.52 864.676,1305.52 864.685,1305.52 864.694,1305.52 864.703,1305.52 864.712,1305.52 864.722,1305.52 864.731,1305.52 864.74,1305.52 864.749,1305.52 864.758,1305.52 864.768,1305.52 864.777,1305.52 864.786,1305.52 864.795,1305.52 864.804,1305.52 864.814,1305.52 864.823,1305.52 864.832,1305.52 864.841,1305.52 864.85,1305.52 864.859,1305.52 864.869,1305.53 864.878,1305.53 864.887,1305.53 864.896,1305.53 864.905,1305.53 864.915,1305.53 864.924,1305.53 864.933,1305.53 864.942,1305.53 864.951,1305.53 864.961,1305.53 864.97,1305.53 864.979,1305.53 864.988,1305.53 864.997,1305.53 865.007,1305.53 865.016,1305.53 865.025,1305.53 865.034,1305.53 865.043,1305.53 865.052,1305.53 865.062,1305.54 865.071,1305.54 865.08,1305.54 865.089,1305.54 865.098,1305.54 865.108,1305.54 865.117,1305.54 865.126,1305.54 865.135,1305.54 865.144,1305.54 865.154,1305.54 865.163,1305.54 865.172,1305.54 865.181,1305.54 865.19,1305.54 865.199,1305.54 865.209,1305.54 865.218,1305.54 865.227,1305.54 865.236,1305.54 865.245,1305.54 865.255,1305.54 865.264,1305.55 865.273,1305.55 865.282,1305.55 865.291,1305.55 865.301,1305.55 865.31,1305.55 865.319,1305.55 865.328,1305.55 865.337,1305.55 865.347,1305.55 865.356,1305.55 865.365,1305.55 865.374,1305.55 865.383,1305.55 865.392,1305.55 865.402,1305.55 865.411,1305.55 865.42,1305.55 865.429,1305.55 865.438,1305.55 865.448,1305.55 865.457,1305.55 865.466,1305.56 865.475,1305.56 865.484,1305.56 865.494,1305.56 865.503,1305.56 865.512,1305.56 865.521,1305.56 865.53,1305.56 865.539,1305.56 865.549,1305.56 865.558,1305.56 865.567,1305.56 865.576,1305.56 865.585,1305.56 865.595,1305.56 865.604,1305.56 865.613,1305.56 865.622,1305.56 865.631,1305.56 865.641,1305.56 865.65,1305.56 865.659,1305.56 865.668,1305.57 865.677,1305.57 865.687,1305.57 865.696,1305.57 865.705,1305.57 865.714,1305.57 865.723,1305.57 865.732,1305.57 865.742,1305.57 865.751,1305.57 865.76,1305.57 865.769,1305.57 865.778,1305.57 865.788,1305.57 865.797,1305.57 865.806,1305.57 865.815,1305.57 865.824,1305.57 865.834,1305.57 865.843,1305.57 865.852,1305.57 865.861,1305.57 865.87,1305.58 865.879,1305.58 865.889,1305.58 865.898,1305.58 865.907,1305.58 865.916,1305.58 865.925,1305.58 865.935,1305.58 865.944,1305.58 865.953,1305.58 865.962,1305.58 865.971,1305.58 865.981,1305.58 865.99,1305.58 865.999,1305.58 866.008,1305.58 866.017,1305.58 866.027,1305.58 866.036,1305.58 866.045,1305.58 866.054,1305.58 866.063,1305.59 866.072,1305.59 866.082,1305.59 866.091,1305.59 866.1,1305.59 866.109,1305.59 866.118,1305.59 866.128,1305.59 866.137,1305.59 866.146,1305.59 866.155,1305.59 866.164,1305.59 866.174,1305.59 866.183,1305.59 866.192,1305.59 866.201,1305.59 866.21,1305.59 866.219,1305.59 866.229,1305.59 866.238,1305.59 866.247,1305.59 866.256,1305.59 866.265,1305.6 866.275,1305.6 866.284,1305.6 866.293,1305.6 866.302,1305.6 866.311,1305.6 866.321,1305.6 866.33,1305.6 866.339,1305.6 866.348,1305.6 866.357,1305.6 866.367,1305.6 866.376,1305.6 866.385,1305.6 866.394,1305.6 866.403,1305.6 866.412,1305.6 866.422,1305.6 866.431,1305.6 866.44,1305.6 866.449,1305.6 866.458,1305.6 866.468,1305.61 866.477,1305.61 866.486,1305.61 866.495,1305.61 866.504,1305.61 866.514,1305.61 866.523,1305.61 866.532,1305.61 866.541,1305.61 866.55,1305.61 866.56,1305.61 866.569,1305.61 866.578,1305.61 866.587,1305.61 866.596,1305.61 866.605,1305.61 866.615,1305.61 866.624,1305.61 866.633,1305.61 866.642,1305.61 866.651,1305.61 866.661,1305.62 866.67,1305.62 866.679,1305.62 866.688,1305.62 866.697,1305.62 866.707,1305.62 866.716,1305.62 866.725,1305.62 866.734,1305.62 866.743,1305.62 866.752,1305.62 866.762,1305.62 866.771,1305.62 866.78,1305.62 866.789,1305.62 866.798,1305.62 866.808,1305.62 866.817,1305.62 866.826,1305.62 866.835,1305.62 866.844,1305.62 866.854,1305.62 866.863,1305.63 866.872,1305.63 866.881,1305.63 866.89,1305.63 866.9,1305.63 866.909,1305.63 866.918,1305.63 866.927,1305.63 866.936,1305.63 866.945,1305.63 866.955,1305.63 866.964,1305.63 866.973,1305.63 866.982,1305.63 866.991,1305.63 867.001,1305.63 867.01,1305.63 867.019,1305.63 867.028,1305.63 867.037,1305.63 867.047,1305.63 867.056,1305.64 867.065,1305.64 867.074,1305.64 867.083,1305.64 867.092,1305.64 867.102,1305.64 867.111,1305.64 867.12,1305.64 867.129,1305.64 867.138,1305.64 867.148,1305.64 867.157,1305.64 867.166,1305.64 867.175,1305.64 867.184,1305.64 867.194,1305.64 867.203,1305.64 867.212,1305.64 867.221,1305.64 867.23,1305.64 867.24,1305.64 867.249,1305.64 867.258,1305.65 867.267,1305.65 867.276,1305.65 867.285,1305.65 867.295,1305.65 867.304,1305.65 867.313,1305.65 867.322,1305.65 867.331,1305.65 867.341,1305.65 867.35,1305.65 867.359,1305.65 867.368,1305.65 867.377,1305.65 867.387,1305.65 867.396,1305.65 867.405,1305.65 867.414,1305.65 867.423,1305.65 867.432,1305.65 867.442,1305.65 867.451,1305.66 867.46,1305.66 867.469,1305.66 867.478,1305.66 867.488,1305.66 867.497,1305.66 867.506,1305.66 867.515,1305.66 867.524,1305.66 867.534,1305.66 867.543,1305.66 867.552,1305.66 867.561,1305.66 867.57,1305.66 867.58,1305.66 867.589,1305.66 867.598,1305.66 867.607,1305.66 867.616,1305.66 867.625,1305.66 867.635,1305.66 867.644,1305.66 867.653,1305.67 867.662,1305.67 867.671,1305.67 867.681,1305.67 867.69,1305.67 867.699,1305.67 867.708,1305.67 867.717,1305.67 867.727,1305.67 867.736,1305.67 867.745,1305.67 867.754,1305.67 867.763,1305.67 867.772,1305.67 867.782,1305.67 867.791,1305.67 867.8,1305.67 867.809,1305.67 867.818,1305.67 867.828,1305.67 867.837,1305.67 867.846,1305.68 867.855,1305.68 867.864,1305.68 867.874,1305.68 867.883,1305.68 867.892,1305.68 867.901,1305.68 867.91,1305.68 867.92,1305.68 867.929,1305.68 867.938,1305.68 867.947,1305.68 867.956,1305.68 867.965,1305.68 867.975,1305.68 867.984,1305.68 867.993,1305.68 868.002,1305.68 868.011,1305.68 868.021,1305.68 868.03,1305.68 868.039,1305.68 868.048,1305.69 868.057,1305.69 868.067,1305.69 868.076,1305.69 868.085,1305.69 868.094,1305.69 868.103,1305.69 868.112,1305.69 868.122,1305.69 868.131,1305.69 868.14,1305.69 868.149,1305.69 868.158,1305.69 868.168,1305.69 868.177,1305.69 868.186,1305.69 868.195,1305.69 868.204,1305.69 868.214,1305.69 868.223,1305.69 868.232,1305.69 868.241,1305.7 868.25,1305.7 868.26,1305.7 868.269,1305.7 868.278,1305.7 868.287,1305.7 868.296,1305.7 868.305,1305.7 868.315,1305.7 868.324,1305.7 868.333,1305.7 868.342,1305.7 868.351,1305.7 868.361,1305.7 868.37,1305.7 868.379,1305.7 868.388,1305.7 868.397,1305.7 868.407,1305.7 868.416,1305.7 868.425,1305.7 868.434,1305.7 868.443,1305.71 868.452,1305.71 868.462,1305.71 868.471,1305.71 868.48,1305.71 868.489,1305.71 868.498,1305.71 868.508,1305.71 868.517,1305.71 868.526,1305.71 868.535,1305.71 868.544,1305.71 868.554,1305.71 868.563,1305.71 868.572,1305.71 868.581,1305.71 868.59,1305.71 868.6,1305.71 868.609,1305.71 868.618,1305.71 868.627,1305.71 868.636,1305.72 868.645,1305.72 868.655,1305.72 868.664,1305.72 868.673,1305.72 868.682,1305.72 868.691,1305.72 868.701,1305.72 868.71,1305.72 868.719,1305.72 868.728,1305.72 868.737,1305.72 868.747,1305.72 868.756,1305.72 868.765,1305.72 868.774,1305.72 868.783,1305.72 868.793,1305.72 868.802,1305.72 868.811,1305.72 868.82,1305.72 868.829,1305.73 868.838,1305.73 868.848,1305.73 868.857,1305.73 868.866,1305.73 868.875,1305.73 868.884,1305.73 868.894,1305.73 868.903,1305.73 868.912,1305.73 868.921,1305.73 868.93,1305.73 868.94,1305.73 868.949,1305.73 868.958,1305.73 868.967,1305.73 868.976,1305.73 868.985,1305.73 868.995,1305.73 869.004,1305.73 869.013,1305.73 869.022,1305.73 869.031,1305.74 869.041,1305.74 869.05,1305.74 869.059,1305.74 869.068,1305.74 869.077,1305.74 869.087,1305.74 869.096,1305.74 869.105,1305.74 869.114,1305.74 869.123,1305.74 869.133,1305.74 869.142,1305.74 869.151,1305.74 869.16,1305.74 869.169,1305.74 869.178,1305.74 869.188,1305.74 869.197,1305.74 869.206,1305.74 869.215,1305.74 869.224,1305.75 869.234,1305.75 869.243,1305.75 869.252,1305.75 869.261,1305.75 869.27,1305.75 869.28,1305.75 869.289,1305.75 869.298,1305.75 869.307,1305.75 869.316,1305.75 869.325,1305.75 869.335,1305.75 869.344,1305.75 869.353,1305.75 869.362,1305.75 869.371,1305.75 869.381,1305.75 869.39,1305.75 869.399,1305.75 869.408,1305.75 869.417,1305.76 869.427,1305.76 869.436,1305.76 869.445,1305.76 869.454,1305.76 869.463,1305.76 869.473,1305.76 869.482,1305.76 869.491,1305.76 869.5,1305.76 869.509,1305.76 869.518,1305.76 869.528,1305.76 869.537,1305.76 869.546,1305.76 869.555,1305.76 869.564,1305.76 869.574,1305.76 869.583,1305.76 869.592,1305.76 869.601,1305.76 869.61,1305.76 869.62,1305.77 869.629,1305.77 869.638,1305.77 869.647,1305.77 869.656,1305.77 869.665,1305.77 869.675,1305.77 869.684,1305.77 869.693,1305.77 869.702,1305.77 869.711,1305.77 869.721,1305.77 869.73,1305.77 869.739,1305.77 869.748,1305.77 869.757,1305.77 869.767,1305.77 869.776,1305.77 869.785,1305.77 869.794,1305.77 869.803,1305.77 869.813,1305.78 869.822,1305.78 869.831,1305.78 869.84,1305.78 869.849,1305.78 869.858,1305.78 869.868,1305.78 869.877,1305.78 869.886,1305.78 869.895,1305.78 869.904,1305.78 869.914,1305.78 869.923,1305.78 869.932,1305.78 869.941,1305.78 869.95,1305.78 869.96,1305.78 869.969,1305.78 869.978,1305.78 869.987,1305.78 869.996,1305.78 870.005,1305.79 870.015,1305.79 870.024,1305.79 870.033,1305.79 870.042,1305.79 870.051,1305.79 870.061,1305.79 870.07,1305.79 870.079,1305.79 870.088,1305.79 870.097,1305.79 870.107,1305.79 870.116,1305.79 870.125,1305.79 870.134,1305.79 870.143,1305.79 870.153,1305.79 870.162,1305.79 870.171,1305.79 870.18,1305.79 870.189,1305.79 870.198,1305.8 870.208,1305.8 870.217,1305.8 870.226,1305.8 870.235,1305.8 870.244,1305.8 870.254,1305.8 870.263,1305.8 870.272,1305.8 870.281,1305.8 870.29,1305.8 870.3,1305.8 870.309,1305.8 870.318,1305.8 870.327,1305.8 870.336,1305.8 870.345,1305.8 870.355,1305.8 870.364,1305.8 870.373,1305.8 870.382,1305.8 870.391,1305.81 870.401,1305.81 870.41,1305.81 870.419,1305.81 870.428,1305.81 870.437,1305.81 870.447,1305.81 870.456,1305.81 870.465,1305.81 870.474,1305.81 870.483,1305.81 870.493,1305.81 870.502,1305.81 870.511,1305.81 870.52,1305.81 870.529,1305.81 870.538,1305.81 870.548,1305.81 870.557,1305.81 870.566,1305.81 870.575,1305.81 870.584,1305.82 870.594,1305.82 870.603,1305.82 870.612,1305.82 870.621,1305.82 870.63,1305.82 870.64,1305.82 870.649,1305.82 870.658,1305.82 870.667,1305.82 870.676,1305.82 870.685,1305.82 870.695,1305.82 870.704,1305.82 870.713,1305.82 870.722,1305.82 870.731,1305.82 870.741,1305.82 870.75,1305.82 870.759,1305.82 870.768,1305.82 870.777,1305.83 870.787,1305.83 870.796,1305.83 870.805,1305.83 870.814,1305.83 870.823,1305.83 870.833,1305.83 870.842,1305.83 870.851,1305.83 870.86,1305.83 870.869,1305.83 870.878,1305.83 870.888,1305.83 870.897,1305.83 870.906,1305.83 870.915,1305.83 870.924,1305.83 870.934,1305.83 870.943,1305.83 870.952,1305.83 870.961,1305.83 870.97,1305.83 870.98,1305.84 870.989,1305.84 870.998,1305.84 871.007,1305.84 871.016,1305.84 871.025,1305.84 871.035,1305.84 871.044,1305.84 871.053,1305.84 871.062,1305.84 871.071,1305.84 871.081,1305.84 871.09,1305.84 871.099,1305.84 871.108,1305.84 871.117,1305.84 871.127,1305.84 871.136,1305.84 871.145,1305.84 871.154,1305.84 871.163,1305.84 871.173,1305.85 871.182,1305.85 871.191,1305.85 871.2,1305.85 871.209,1305.85 871.218,1305.85 871.228,1305.85 871.237,1305.85 871.246,1305.85 871.255,1305.85 871.264,1305.85 871.274,1305.85 871.283,1305.85 871.292,1305.85 871.301,1305.85 871.31,1305.85 871.32,1305.85 871.329,1305.85 871.338,1305.85 871.347,1305.85 871.356,1305.85 871.366,1305.86 871.375,1305.86 871.384,1305.86 871.393,1305.86 871.402,1305.86 871.411,1305.86 871.421,1305.86 871.43,1305.86 871.439,1305.86 871.448,1305.86 871.457,1305.86 871.467,1305.86 871.476,1305.86 871.485,1305.86 871.494,1305.86 871.503,1305.86 871.513,1305.86 871.522,1305.86 871.531,1305.86 871.54,1305.86 871.549,1305.86 871.558,1305.87 871.568,1305.87 871.577,1305.87 871.586,1305.87 871.595,1305.87 871.604,1305.87 871.614,1305.87 871.623,1305.87 871.632,1305.87 871.641,1305.87 871.65,1305.87 871.66,1305.87 871.669,1305.87 871.678,1305.87 871.687,1305.87 871.696,1305.87 871.706,1305.87 871.715,1305.87 871.724,1305.87 871.733,1305.87 871.742,1305.87 871.751,1305.88 871.761,1305.88 871.77,1305.88 871.779,1305.88 871.788,1305.88 871.797,1305.88 871.807,1305.88 871.816,1305.88 871.825,1305.88 871.834,1305.88 871.843,1305.88 871.853,1305.88 871.862,1305.88 871.871,1305.88 871.88,1305.88 871.889,1305.88 871.898,1305.88 871.908,1305.88 871.917,1305.88 871.926,1305.88 871.935,1305.88 871.944,1305.89 871.954,1305.89 871.963,1305.89 871.972,1305.89 871.981,1305.89 871.99,1305.89 872,1305.89 872.009,1305.89 872.018,1305.89 872.027,1305.89 872.036,1305.89 872.046,1305.89 872.055,1305.89 872.064,1305.89 872.073,1305.89 872.082,1305.89 872.091,1305.89 872.101,1305.89 872.11,1305.89 872.119,1305.89 872.128,1305.9 872.137,1305.9 872.147,1305.9 872.156,1305.9 872.165,1305.9 872.174,1305.9 872.183,1305.9 872.193,1305.9 872.202,1305.9 872.211,1305.9 872.22,1305.9 872.229,1305.9 872.238,1305.9 872.248,1305.9 872.257,1305.9 872.266,1305.9 872.275,1305.9 872.284,1305.9 872.294,1305.9 872.303,1305.9 872.312,1305.9 872.321,1305.91 872.33,1305.91 872.34,1305.91 872.349,1305.91 872.358,1305.91 872.367,1305.91 872.376,1305.91 872.386,1305.91 872.395,1305.91 872.404,1305.91 872.413,1305.91 872.422,1305.91 872.431,1305.91 872.441,1305.91 872.45,1305.91 872.459,1305.91 872.468,1305.91 872.477,1305.91 872.487,1305.91 872.496,1305.91 872.505,1305.91 872.514,1305.92 872.523,1305.92 872.533,1305.92 872.542,1305.92 872.551,1305.92 872.56,1305.92 872.569,1305.92 872.578,1305.92 872.588,1305.92 872.597,1305.92 872.606,1305.92 872.615,1305.92 872.624,1305.92 872.634,1305.92 872.643,1305.92 872.652,1305.92 872.661,1305.92 872.67,1305.92 872.68,1305.92 872.689,1305.92 872.698,1305.92 872.707,1305.93 872.716,1305.93 872.726,1305.93 872.735,1305.93 872.744,1305.93 872.753,1305.93 872.762,1305.93 872.771,1305.93 872.781,1305.93 872.79,1305.93 872.799,1305.93 872.808,1305.93 872.817,1305.93 872.827,1305.93 872.836,1305.93 872.845,1305.93 872.854,1305.93 872.863,1305.93 872.873,1305.93 872.882,1305.93 872.891,1305.93 872.9,1305.94 872.909,1305.94 872.918,1305.94 872.928,1305.94 872.937,1305.94 872.946,1305.94 872.955,1305.94 872.964,1305.94 872.974,1305.94 872.983,1305.94 872.992,1305.94 873.001,1305.94 873.01,1305.94 873.02,1305.94 873.029,1305.94 873.038,1305.94 873.047,1305.94 873.056,1305.94 873.066,1305.94 873.075,1305.94 873.084,1305.94 873.093,1305.95 873.102,1305.95 873.111,1305.95 873.121,1305.95 873.13,1305.95 873.139,1305.95 873.148,1305.95 873.157,1305.95 873.167,1305.95 873.176,1305.95 873.185,1305.95 873.194,1305.95 873.203,1305.95 873.213,1305.95 873.222,1305.95 873.231,1305.95 873.24,1305.95 873.249,1305.95 873.258,1305.95 873.268,1305.95 873.277,1305.95 873.286,1305.96 873.295,1305.96 873.304,1305.96 873.314,1305.96 873.323,1305.96 873.332,1305.96 873.341,1305.96 873.35,1305.96 873.36,1305.96 873.369,1305.96 873.378,1305.96 873.387,1305.96 873.396,1305.96 873.406,1305.96 873.415,1305.96 873.424,1305.96 873.433,1305.96 873.442,1305.96 873.451,1305.96 873.461,1305.96 873.47,1305.97 873.479,1305.97 873.488,1305.97 873.497,1305.97 873.507,1305.97 873.516,1305.97 873.525,1305.97 873.534,1305.97 873.543,1305.97 873.553,1305.97 873.562,1305.97 873.571,1305.97 873.58,1305.97 873.589,1305.97 873.598,1305.97 873.608,1305.97 873.617,1305.97 873.626,1305.97 873.635,1305.97 873.644,1305.97 873.654,1305.97 873.663,1305.98 873.672,1305.98 873.681,1305.98 873.69,1305.98 873.7,1305.98 873.709,1305.98 873.718,1305.98 873.727,1305.98 873.736,1305.98 873.746,1305.98 873.755,1305.98 873.764,1305.98 873.773,1305.98 873.782,1305.98 873.791,1305.98 873.801,1305.98 873.81,1305.98 873.819,1305.98 873.828,1305.98 873.837,1305.98 873.847,1305.98 873.856,1305.99 873.865,1305.99 873.874,1305.99 873.883,1305.99 873.893,1305.99 873.902,1305.99 873.911,1305.99 873.92,1305.99 873.929,1305.99 873.939,1305.99 873.948,1305.99 873.957,1305.99 873.966,1305.99 873.975,1305.99 873.984,1305.99 873.994,1305.99 874.003,1305.99 874.012,1305.99 874.021,1305.99 874.03,1305.99 874.04,1305.99 874.049,1306 874.058,1306 874.067,1306 874.076,1306 874.086,1306 874.095,1306 874.104,1306 874.113,1306 874.122,1306 874.131,1306 874.141,1306 874.15,1306 874.159,1306 874.168,1306 874.177,1306 874.187,1306 874.196,1306 874.205,1306 874.214,1306 874.223,1306 874.233,1306.01 874.242,1306.01 874.251,1306.01 874.26,1306.01 874.269,1306.01 874.279,1306.01 874.288,1306.01 874.297,1306.01 874.306,1306.01 874.315,1306.01 874.324,1306.01 874.334,1306.01 874.343,1306.01 874.352,1306.01 874.361,1306.01 874.37,1306.01 874.38,1306.01 874.389,1306.01 874.398,1306.01 874.407,1306.01 874.416,1306.01 874.426,1306.02 874.435,1306.02 874.444,1306.02 874.453,1306.02 874.462,1306.02 874.471,1306.02 874.481,1306.02 874.49,1306.02 874.499,1306.02 874.508,1306.02 874.517,1306.02 874.527,1306.02 874.536,1306.02 874.545,1306.02 874.554,1306.02 874.563,1306.02 874.573,1306.02 874.582,1306.02 874.591,1306.02 874.6,1306.02 874.609,1306.02 874.619,1306.03 874.628,1306.03 874.637,1306.03 874.646,1306.03 874.655,1306.03 874.664,1306.03 874.674,1306.03 874.683,1306.03 874.692,1306.03 874.701,1306.03 874.71,1306.03 874.72,1306.03 874.729,1306.03 874.738,1306.03 874.747,1306.03 874.756,1306.03 874.766,1306.03 874.775,1306.03 874.784,1306.03 874.793,1306.03 874.802,1306.04 874.811,1306.04 874.821,1306.04 874.83,1306.04 874.839,1306.04 874.848,1306.04 874.857,1306.04 874.867,1306.04 874.876,1306.04 874.885,1306.04 874.894,1306.04 874.903,1306.04 874.913,1306.04 874.922,1306.04 874.931,1306.04 874.94,1306.04 874.949,1306.04 874.959,1306.04 874.968,1306.04 874.977,1306.04 874.986,1306.04 874.995,1306.05 875.004,1306.05 875.014,1306.05 875.023,1306.05 875.032,1306.05 875.041,1306.05 875.05,1306.05 875.06,1306.05 875.069,1306.05 875.078,1306.05 875.087,1306.05 875.096,1306.05 875.106,1306.05 875.115,1306.05 875.124,1306.05 875.133,1306.05 875.142,1306.05 875.151,1306.05 875.161,1306.05 875.17,1306.05 875.179,1306.06 875.188,1306.06 875.197,1306.06 875.207,1306.06 875.216,1306.06 875.225,1306.06 875.234,1306.06 875.243,1306.06 875.253,1306.06 875.262,1306.06 875.271,1306.06 875.28,1306.06 875.289,1306.06 875.299,1306.06 875.308,1306.06 875.317,1306.06 875.326,1306.06 875.335,1306.06 875.344,1306.06 875.354,1306.06 875.363,1306.06 875.372,1306.07 875.381,1306.07 875.39,1306.07 875.4,1306.07 875.409,1306.07 875.418,1306.07 875.427,1306.07 875.436,1306.07 875.446,1306.07 875.455,1306.07 875.464,1306.07 875.473,1306.07 875.482,1306.07 875.491,1306.07 875.501,1306.07 875.51,1306.07 875.519,1306.07 875.528,1306.07 875.537,1306.07 875.547,1306.07 875.556,1306.08 875.565,1306.08 875.574,1306.08 875.583,1306.08 875.593,1306.08 875.602,1306.08 875.611,1306.08 875.62,1306.08 875.629,1306.08 875.639,1306.08 875.648,1306.08 875.657,1306.08 875.666,1306.08 875.675,1306.08 875.684,1306.08 875.694,1306.08 875.703,1306.08 875.712,1306.08 875.721,1306.08 875.73,1306.08 875.74,1306.08 875.749,1306.09 875.758,1306.09 875.767,1306.09 875.776,1306.09 875.786,1306.09 875.795,1306.09 875.804,1306.09 875.813,1306.09 875.822,1306.09 875.831,1306.09 875.841,1306.09 875.85,1306.09 875.859,1306.09 875.868,1306.09 875.877,1306.09 875.887,1306.09 875.896,1306.09 875.905,1306.09 875.914,1306.09 875.923,1306.09 875.933,1306.1 875.942,1306.1 875.951,1306.1 875.96,1306.1 875.969,1306.1 875.979,1306.1 875.988,1306.1 875.997,1306.1 876.006,1306.1 876.015,1306.1 876.024,1306.1 876.034,1306.1 876.043,1306.1 876.052,1306.1 876.061,1306.1 876.07,1306.1 876.08,1306.1 876.089,1306.1 876.098,1306.1 876.107,1306.1 876.116,1306.1 876.126,1306.11 876.135,1306.11 876.144,1306.11 876.153,1306.11 876.162,1306.11 876.171,1306.11 876.181,1306.11 876.19,1306.11 876.199,1306.11 876.208,1306.11 876.217,1306.11 876.227,1306.11 876.236,1306.11 876.245,1306.11 876.254,1306.11 876.263,1306.11 876.273,1306.11 876.282,1306.11 876.291,1306.11 876.3,1306.11 876.309,1306.12 876.319,1306.12 876.328,1306.12 876.337,1306.12 876.346,1306.12 876.355,1306.12 876.364,1306.12 876.374,1306.12 876.383,1306.12 876.392,1306.12 876.401,1306.12 876.41,1306.12 876.42,1306.12 876.429,1306.12 876.438,1306.12 876.447,1306.12 876.456,1306.12 876.466,1306.12 876.475,1306.12 876.484,1306.12 876.493,1306.12 876.502,1306.13 876.512,1306.13 876.521,1306.13 876.53,1306.13 876.539,1306.13 876.548,1306.13 876.557,1306.13 876.567,1306.13 876.576,1306.13 876.585,1306.13 876.594,1306.13 876.603,1306.13 876.613,1306.13 876.622,1306.13 876.631,1306.13 876.64,1306.13 876.649,1306.13 876.659,1306.13 876.668,1306.13 876.677,1306.13 876.686,1306.14 876.695,1306.14 876.704,1306.14 876.714,1306.14 876.723,1306.14 876.732,1306.14 876.741,1306.14 876.75,1306.14 876.76,1306.14 876.769,1306.14 876.778,1306.14 876.787,1306.14 876.796,1306.14 876.806,1306.14 876.815,1306.14 876.824,1306.14 876.833,1306.14 876.842,1306.14 876.852,1306.14 876.861,1306.14 876.87,1306.14 876.879,1306.15 876.888,1306.15 876.897,1306.15 876.907,1306.15 876.916,1306.15 876.925,1306.15 876.934,1306.15 876.943,1306.15 876.953,1306.15 876.962,1306.15 876.971,1306.15 876.98,1306.15 876.989,1306.15 876.999,1306.15 877.008,1306.15 877.017,1306.15 877.026,1306.15 877.035,1306.15 877.044,1306.15 877.054,1306.15 877.063,1306.16 877.072,1306.16 877.081,1306.16 877.09,1306.16 877.1,1306.16 877.109,1306.16 877.118,1306.16 877.127,1306.16 877.136,1306.16 877.146,1306.16 877.155,1306.16 877.164,1306.16 877.173,1306.16 877.182,1306.16 877.192,1306.16 877.201,1306.16 877.21,1306.16 877.219,1306.16 877.228,1306.16 877.237,1306.16 877.247,1306.17 877.256,1306.17 877.265,1306.17 877.274,1306.17 877.283,1306.17 877.293,1306.17 877.302,1306.17 877.311,1306.17 877.32,1306.17 877.329,1306.17 877.339,1306.17 877.348,1306.17 877.357,1306.17 877.366,1306.17 877.375,1306.17 877.384,1306.17 877.394,1306.17 877.403,1306.17 877.412,1306.17 877.421,1306.17 877.43,1306.17 877.44,1306.18 877.449,1306.18 877.458,1306.18 877.467,1306.18 877.476,1306.18 877.486,1306.18 877.495,1306.18 877.504,1306.18 877.513,1306.18 877.522,1306.18 877.532,1306.18 877.541,1306.18 877.55,1306.18 877.559,1306.18 877.568,1306.18 877.577,1306.18 877.587,1306.18 877.596,1306.18 877.605,1306.18 877.614,1306.18 877.623,1306.19 877.633,1306.19 877.642,1306.19 877.651,1306.19 877.66,1306.19 877.669,1306.19 877.679,1306.19 877.688,1306.19 877.697,1306.19 877.706,1306.19 877.715,1306.19 877.724,1306.19 877.734,1306.19 877.743,1306.19 877.752,1306.19 877.761,1306.19 877.77,1306.19 877.78,1306.19 877.789,1306.19 877.798,1306.19 877.807,1306.2 877.816,1306.2 877.826,1306.2 877.835,1306.2 877.844,1306.2 877.853,1306.2 877.862,1306.2 877.872,1306.2 877.881,1306.2 877.89,1306.2 877.899,1306.2 877.908,1306.2 877.917,1306.2 877.927,1306.2 877.936,1306.2 877.945,1306.2 877.954,1306.2 877.963,1306.2 877.973,1306.2 877.982,1306.2 877.991,1306.2 878,1306.21 878.009,1306.21 878.019,1306.21 878.028,1306.21 878.037,1306.21 878.046,1306.21 878.055,1306.21 878.064,1306.21 878.074,1306.21 878.083,1306.21 878.092,1306.21 878.101,1306.21 878.11,1306.21 878.12,1306.21 878.129,1306.21 878.138,1306.21 878.147,1306.21 878.156,1306.21 878.166,1306.21 878.175,1306.21 878.184,1306.22 878.193,1306.22 878.202,1306.22 878.212,1306.22 878.221,1306.22 878.23,1306.22 878.239,1306.22 878.248,1306.22 878.257,1306.22 878.267,1306.22 878.276,1306.22 878.285,1306.22 878.294,1306.22 878.303,1306.22 878.313,1306.22 878.322,1306.22 878.331,1306.22 878.34,1306.22 878.349,1306.22 878.359,1306.22 878.368,1306.23 878.377,1306.23 878.386,1306.23 878.395,1306.23 878.404,1306.23 878.414,1306.23 878.423,1306.23 878.432,1306.23 878.441,1306.23 878.45,1306.23 878.46,1306.23 878.469,1306.23 878.478,1306.23 878.487,1306.23 878.496,1306.23 878.506,1306.23 878.515,1306.23 878.524,1306.23 878.533,1306.23 878.542,1306.23 878.552,1306.24 878.561,1306.24 878.57,1306.24 878.579,1306.24 878.588,1306.24 878.597,1306.24 878.607,1306.24 878.616,1306.24 878.625,1306.24 878.634,1306.24 878.643,1306.24 878.653,1306.24 878.662,1306.24 878.671,1306.24 878.68,1306.24 878.689,1306.24 878.699,1306.24 878.708,1306.24 878.717,1306.24 878.726,1306.24 878.735,1306.25 878.745,1306.25 878.754,1306.25 878.763,1306.25 878.772,1306.25 878.781,1306.25 878.79,1306.25 878.8,1306.25 878.809,1306.25 878.818,1306.25 878.827,1306.25 878.836,1306.25 878.846,1306.25 878.855,1306.25 878.864,1306.25 878.873,1306.25 878.882,1306.25 878.892,1306.25 878.901,1306.25 878.91,1306.25 878.919,1306.25 878.928,1306.26 878.937,1306.26 878.947,1306.26 878.956,1306.26 878.965,1306.26 878.974,1306.26 878.983,1306.26 878.993,1306.26 879.002,1306.26 879.011,1306.26 879.02,1306.26 879.029,1306.26 879.039,1306.26 879.048,1306.26 879.057,1306.26 879.066,1306.26 879.075,1306.26 879.085,1306.26 879.094,1306.26 879.103,1306.26 879.112,1306.27 879.121,1306.27 879.13,1306.27 879.14,1306.27 879.149,1306.27 879.158,1306.27 879.167,1306.27 879.176,1306.27 879.186,1306.27 879.195,1306.27 879.204,1306.27 879.213,1306.27 879.222,1306.27 879.232,1306.27 879.241,1306.27 879.25,1306.27 879.259,1306.27 879.268,1306.27 879.277,1306.27 879.287,1306.27 879.296,1306.28 879.305,1306.28 879.314,1306.28 879.323,1306.28 879.333,1306.28 879.342,1306.28 879.351,1306.28 879.36,1306.28 879.369,1306.28 879.379,1306.28 879.388,1306.28 879.397,1306.28 879.406,1306.28 879.415,1306.28 879.425,1306.28 879.434,1306.28 879.443,1306.28 879.452,1306.28 879.461,1306.28 879.47,1306.28 879.48,1306.29 879.489,1306.29 879.498,1306.29 879.507,1306.29 879.516,1306.29 879.526,1306.29 879.535,1306.29 879.544,1306.29 879.553,1306.29 879.562,1306.29 879.572,1306.29 879.581,1306.29 879.59,1306.29 879.599,1306.29 879.608,1306.29 879.617,1306.29 879.627,1306.29 879.636,1306.29 879.645,1306.29 879.654,1306.29 879.663,1306.3 879.673,1306.3 879.682,1306.3 879.691,1306.3 879.7,1306.3 879.709,1306.3 879.719,1306.3 879.728,1306.3 879.737,1306.3 879.746,1306.3 879.755,1306.3 879.765,1306.3 879.774,1306.3 879.783,1306.3 879.792,1306.3 879.801,1306.3 879.81,1306.3 879.82,1306.3 879.829,1306.3 879.838,1306.3 879.847,1306.31 879.856,1306.31 879.866,1306.31 879.875,1306.31 879.884,1306.31 879.893,1306.31 879.902,1306.31 879.912,1306.31 879.921,1306.31 879.93,1306.31 879.939,1306.31 879.948,1306.31 879.957,1306.31 879.967,1306.31 879.976,1306.31 879.985,1306.31 879.994,1306.31 880.003,1306.31 880.013,1306.31 880.022,1306.31 880.031,1306.32 880.04,1306.32 880.049,1306.32 880.059,1306.32 880.068,1306.32 880.077,1306.32 880.086,1306.32 880.095,1306.32 880.105,1306.32 880.114,1306.32 880.123,1306.32 880.132,1306.32 880.141,1306.32 880.15,1306.32 880.16,1306.32 880.169,1306.32 880.178,1306.32 880.187,1306.32 880.196,1306.32 880.206,1306.32 880.215,1306.33 880.224,1306.33 880.233,1306.33 880.242,1306.33 880.252,1306.33 880.261,1306.33 880.27,1306.33 880.279,1306.33 880.288,1306.33 880.297,1306.33 880.307,1306.33 880.316,1306.33 880.325,1306.33 880.334,1306.33 880.343,1306.33 880.353,1306.33 880.362,1306.33 880.371,1306.33 880.38,1306.33 880.389,1306.33 880.399,1306.34 880.408,1306.34 880.417,1306.34 880.426,1306.34 880.435,1306.34 880.445,1306.34 880.454,1306.34 880.463,1306.34 880.472,1306.34 880.481,1306.34 880.49,1306.34 880.5,1306.34 880.509,1306.34 880.518,1306.34 880.527,1306.34 880.536,1306.34 880.546,1306.34 880.555,1306.34 880.564,1306.34 880.573,1306.34 880.582,1306.35 880.592,1306.35 880.601,1306.35 880.61,1306.35 880.619,1306.35 880.628,1306.35 880.637,1306.35 880.647,1306.35 880.656,1306.35 880.665,1306.35 880.674,1306.35 880.683,1306.35 880.693,1306.35 880.702,1306.35 880.711,1306.35 880.72,1306.35 880.729,1306.35 880.739,1306.35 880.748,1306.35 880.757,1306.35 880.766,1306.36 880.775,1306.36 880.785,1306.36 880.794,1306.36 880.803,1306.36 880.812,1306.36 880.821,1306.36 880.83,1306.36 880.84,1306.36 880.849,1306.36 880.858,1306.36 880.867,1306.36 880.876,1306.36 880.886,1306.36 880.895,1306.36 880.904,1306.36 880.913,1306.36 880.922,1306.36 880.932,1306.36 880.941,1306.36 880.95,1306.37 880.959,1306.37 880.968,1306.37 880.977,1306.37 880.987,1306.37 880.996,1306.37 881.005,1306.37 881.014,1306.37 881.023,1306.37 881.033,1306.37 881.042,1306.37 881.051,1306.37 881.06,1306.37 881.069,1306.37 881.079,1306.37 881.088,1306.37 881.097,1306.37 881.106,1306.37 881.115,1306.37 881.125,1306.37 881.134,1306.38 881.143,1306.38 881.152,1306.38 881.161,1306.38 881.17,1306.38 881.18,1306.38 881.189,1306.38 881.198,1306.38 881.207,1306.38 881.216,1306.38 881.226,1306.38 881.235,1306.38 881.244,1306.38 881.253,1306.38 881.262,1306.38 881.272,1306.38 881.281,1306.38 881.29,1306.38 881.299,1306.38 881.308,1306.38 881.318,1306.39 881.327,1306.39 881.336,1306.39 881.345,1306.39 881.354,1306.39 881.363,1306.39 881.373,1306.39 881.382,1306.39 881.391,1306.39 881.4,1306.39 881.409,1306.39 881.419,1306.39 881.428,1306.39 881.437,1306.39 881.446,1306.39 881.455,1306.39 881.465,1306.39 881.474,1306.39 881.483,1306.39 881.492,1306.39 881.501,1306.4 881.51,1306.4 881.52,1306.4 881.529,1306.4 881.538,1306.4 881.547,1306.4 881.556,1306.4 881.566,1306.4 881.575,1306.4 881.584,1306.4 881.593,1306.4 881.602,1306.4 881.612,1306.4 881.621,1306.4 881.63,1306.4 881.639,1306.4 881.648,1306.4 881.658,1306.4 881.667,1306.4 881.676,1306.4 881.685,1306.41 881.694,1306.41 881.703,1306.41 881.713,1306.41 881.722,1306.41 881.731,1306.41 881.74,1306.41 881.749,1306.41 881.759,1306.41 881.768,1306.41 881.777,1306.41 881.786,1306.41 881.795,1306.41 881.805,1306.41 881.814,1306.41 881.823,1306.41 881.832,1306.41 881.841,1306.41 881.85,1306.41 881.86,1306.41 881.869,1306.42 881.878,1306.42 881.887,1306.42 881.896,1306.42 881.906,1306.42 881.915,1306.42 881.924,1306.42 881.933,1306.42 881.942,1306.42 881.952,1306.42 881.961,1306.42 881.97,1306.42 881.979,1306.42 881.988,1306.42 881.998,1306.42 882.007,1306.42 882.016,1306.42 882.025,1306.42 882.034,1306.42 882.043,1306.42 882.053,1306.43 882.062,1306.43 882.071,1306.43 882.08,1306.43 882.089,1306.43 882.099,1306.43 882.108,1306.43 882.117,1306.43 882.126,1306.43 882.135,1306.43 882.145,1306.43 882.154,1306.43 882.163,1306.43 882.172,1306.43 882.181,1306.43 882.19,1306.43 882.2,1306.43 882.209,1306.43 882.218,1306.43 882.227,1306.43 882.236,1306.44 882.246,1306.44 882.255,1306.44 882.264,1306.44 882.273,1306.44 882.282,1306.44 882.292,1306.44 882.301,1306.44 882.31,1306.44 882.319,1306.44 882.328,1306.44 882.338,1306.44 882.347,1306.44 882.356,1306.44 882.365,1306.44 882.374,1306.44 882.383,1306.44 882.393,1306.44 882.402,1306.44 882.411,1306.45 882.42,1306.45 882.429,1306.45 882.439,1306.45 882.448,1306.45 882.457,1306.45 882.466,1306.45 882.475,1306.45 882.485,1306.45 882.494,1306.45 882.503,1306.45 882.512,1306.45 882.521,1306.45 882.53,1306.45 882.54,1306.45 882.549,1306.45 882.558,1306.45 882.567,1306.45 882.576,1306.45 882.586,1306.45 882.595,1306.46 882.604,1306.46 882.613,1306.46 882.622,1306.46 882.632,1306.46 882.641,1306.46 882.65,1306.46 882.659,1306.46 882.668,1306.46 882.678,1306.46 882.687,1306.46 882.696,1306.46 882.705,1306.46 882.714,1306.46 882.723,1306.46 882.733,1306.46 882.742,1306.46 882.751,1306.46 882.76,1306.46 882.769,1306.46 882.779,1306.47 882.788,1306.47 882.797,1306.47 882.806,1306.47 882.815,1306.47 882.825,1306.47 882.834,1306.47 882.843,1306.47 882.852,1306.47 882.861,1306.47 882.87,1306.47 882.88,1306.47 882.889,1306.47 882.898,1306.47 882.907,1306.47 882.916,1306.47 882.926,1306.47 882.935,1306.47 882.944,1306.47 882.953,1306.47 882.962,1306.48 882.972,1306.48 882.981,1306.48 882.99,1306.48 882.999,1306.48 883.008,1306.48 883.018,1306.48 883.027,1306.48 883.036,1306.48 883.045,1306.48 883.054,1306.48 883.063,1306.48 883.073,1306.48 883.082,1306.48 883.091,1306.48 883.1,1306.48 883.109,1306.48 883.119,1306.48 883.128,1306.48 883.137,1306.48 883.146,1306.49 883.155,1306.49 883.165,1306.49 883.174,1306.49 883.183,1306.49 883.192,1306.49 883.201,1306.49 883.21,1306.49 883.22,1306.49 883.229,1306.49 883.238,1306.49 883.247,1306.49 883.256,1306.49 883.266,1306.49 883.275,1306.49 883.284,1306.49 883.293,1306.49 883.302,1306.49 883.312,1306.49 883.321,1306.5 883.33,1306.5 883.339,1306.5 883.348,1306.5 883.358,1306.5 883.367,1306.5 883.376,1306.5 883.385,1306.5 883.394,1306.5 883.403,1306.5 883.413,1306.5 883.422,1306.5 883.431,1306.5 883.44,1306.5 883.449,1306.5 883.459,1306.5 883.468,1306.5 883.477,1306.5 883.486,1306.5 883.495,1306.5 883.505,1306.51 883.514,1306.51 883.523,1306.51 883.532,1306.51 883.541,1306.51 883.55,1306.51 883.56,1306.51 883.569,1306.51 883.578,1306.51 883.587,1306.51 883.596,1306.51 883.606,1306.51 883.615,1306.51 883.624,1306.51 883.633,1306.51 883.642,1306.51 883.652,1306.51 883.661,1306.51 883.67,1306.51 883.679,1306.51 883.688,1306.52 883.698,1306.52 883.707,1306.52 883.716,1306.52 883.725,1306.52 883.734,1306.52 883.743,1306.52 883.753,1306.52 883.762,1306.52 883.771,1306.52 883.78,1306.52 883.789,1306.52 883.799,1306.52 883.808,1306.52 883.817,1306.52 883.826,1306.52 883.835,1306.52 883.845,1306.52 883.854,1306.52 883.863,1306.53 883.872,1306.53 883.881,1306.53 883.891,1306.53 883.9,1306.53 883.909,1306.53 883.918,1306.53 883.927,1306.53 883.936,1306.53 883.946,1306.53 883.955,1306.53 883.964,1306.53 883.973,1306.53 883.982,1306.53 883.992,1306.53 884.001,1306.53 884.01,1306.53 884.019,1306.53 884.028,1306.53 884.038,1306.53 884.047,1306.54 884.056,1306.54 884.065,1306.54 884.074,1306.54 884.083,1306.54 884.093,1306.54 884.102,1306.54 884.111,1306.54 884.12,1306.54 884.129,1306.54 884.139,1306.54 884.148,1306.54 884.157,1306.54 884.166,1306.54 884.175,1306.54 884.185,1306.54 884.194,1306.54 884.203,1306.54 884.212,1306.54 884.221,1306.54 884.231,1306.55 884.24,1306.55 884.249,1306.55 884.258,1306.55 884.267,1306.55 884.276,1306.55 884.286,1306.55 884.295,1306.55 884.304,1306.55 884.313,1306.55 884.322,1306.55 884.332,1306.55 884.341,1306.55 884.35,1306.55 884.359,1306.55 884.368,1306.55 884.378,1306.55 884.387,1306.55 884.396,1306.55 884.405,1306.56 884.414,1306.56 884.423,1306.56 884.433,1306.56 884.442,1306.56 884.451,1306.56 884.46,1306.56 884.469,1306.56 884.479,1306.56 884.488,1306.56 884.497,1306.56 884.506,1306.56 884.515,1306.56 884.525,1306.56 884.534,1306.56 884.543,1306.56 884.552,1306.56 884.561,1306.56 884.571,1306.56 884.58,1306.56 884.589,1306.57 884.598,1306.57 884.607,1306.57 884.616,1306.57 884.626,1306.57 884.635,1306.57 884.644,1306.57 884.653,1306.57 884.662,1306.57 884.672,1306.57 884.681,1306.57 884.69,1306.57 884.699,1306.57 884.708,1306.57 884.718,1306.57 884.727,1306.57 884.736,1306.57 884.745,1306.57 884.754,1306.57 884.763,1306.57 884.773,1306.58 884.782,1306.58 884.791,1306.58 884.8,1306.58 884.809,1306.58 884.819,1306.58 884.828,1306.58 884.837,1306.58 884.846,1306.58 884.855,1306.58 884.865,1306.58 884.874,1306.58 884.883,1306.58 884.892,1306.58 884.901,1306.58 884.911,1306.58 884.92,1306.58 884.929,1306.58 884.938,1306.58 884.947,1306.59 884.956,1306.59 884.966,1306.59 884.975,1306.59 884.984,1306.59 884.993,1306.59 885.002,1306.59 885.012,1306.59 885.021,1306.59 885.03,1306.59 885.039,1306.59 885.048,1306.59 885.058,1306.59 885.067,1306.59 885.076,1306.59 885.085,1306.59 885.094,1306.59 885.103,1306.59 885.113,1306.59 885.122,1306.59 885.131,1306.6 885.14,1306.6 885.149,1306.6 885.159,1306.6 885.168,1306.6 885.177,1306.6 885.186,1306.6 885.195,1306.6 885.205,1306.6 885.214,1306.6 885.223,1306.6 885.232,1306.6 885.241,1306.6 885.251,1306.6 885.26,1306.6 885.269,1306.6 885.278,1306.6 885.287,1306.6 885.296,1306.6 885.306,1306.61 885.315,1306.61 885.324,1306.61 885.333,1306.61 885.342,1306.61 885.352,1306.61 885.361,1306.61 885.37,1306.61 885.379,1306.61 885.388,1306.61 885.398,1306.61 885.407,1306.61 885.416,1306.61 885.425,1306.61 885.434,1306.61 885.443,1306.61 885.453,1306.61 885.462,1306.61 885.471,1306.61 885.48,1306.61 885.489,1306.62 885.499,1306.62 885.508,1306.62 885.517,1306.62 885.526,1306.62 885.535,1306.62 885.545,1306.62 885.554,1306.62 885.563,1306.62 885.572,1306.62 885.581,1306.62 885.591,1306.62 885.6,1306.62 885.609,1306.62 885.618,1306.62 885.627,1306.62 885.636,1306.62 885.646,1306.62 885.655,1306.62 885.664,1306.63 885.673,1306.63 885.682,1306.63 885.692,1306.63 885.701,1306.63 885.71,1306.63 885.719,1306.63 885.728,1306.63 885.738,1306.63 885.747,1306.63 885.756,1306.63 885.765,1306.63 885.774,1306.63 885.783,1306.63 885.793,1306.63 885.802,1306.63 885.811,1306.63 885.82,1306.63 885.829,1306.63 885.839,1306.63 885.848,1306.64 885.857,1306.64 885.866,1306.64 885.875,1306.64 885.885,1306.64 885.894,1306.64 885.903,1306.64 885.912,1306.64 885.921,1306.64 885.931,1306.64 885.94,1306.64 885.949,1306.64 885.958,1306.64 885.967,1306.64 885.976,1306.64 885.986,1306.64 885.995,1306.64 886.004,1306.64 886.013,1306.64 886.022,1306.65 886.032,1306.65 886.041,1306.65 886.05,1306.65 886.059,1306.65 886.068,1306.65 886.078,1306.65 886.087,1306.65 886.096,1306.65 886.105,1306.65 886.114,1306.65 886.124,1306.65 886.133,1306.65 886.142,1306.65 886.151,1306.65 886.16,1306.65 886.169,1306.65 886.179,1306.65 886.188,1306.65 886.197,1306.65 886.206,1306.66 886.215,1306.66 886.225,1306.66 886.234,1306.66 886.243,1306.66 886.252,1306.66 886.261,1306.66 886.271,1306.66 886.28,1306.66 886.289,1306.66 886.298,1306.66 886.307,1306.66 886.316,1306.66 886.326,1306.66 886.335,1306.66 886.344,1306.66 886.353,1306.66 886.362,1306.66 886.372,1306.66 886.381,1306.67 886.39,1306.67 886.399,1306.67 886.408,1306.67 886.418,1306.67 886.427,1306.67 886.436,1306.67 886.445,1306.67 886.454,1306.67 886.464,1306.67 886.473,1306.67 886.482,1306.67 886.491,1306.67 886.5,1306.67 886.509,1306.67 886.519,1306.67 886.528,1306.67 886.537,1306.67 886.546,1306.67 886.555,1306.67 886.565,1306.68 886.574,1306.68 886.583,1306.68 886.592,1306.68 886.601,1306.68 886.611,1306.68 886.62,1306.68 886.629,1306.68 886.638,1306.68 886.647,1306.68 886.656,1306.68 886.666,1306.68 886.675,1306.68 886.684,1306.68 886.693,1306.68 886.702,1306.68 886.712,1306.68 886.721,1306.68 886.73,1306.68 886.739,1306.69 886.748,1306.69 886.758,1306.69 886.767,1306.69 886.776,1306.69 886.785,1306.69 886.794,1306.69 886.804,1306.69 886.813,1306.69 886.822,1306.69 886.831,1306.69 886.84,1306.69 886.849,1306.69 886.859,1306.69 886.868,1306.69 886.877,1306.69 886.886,1306.69 886.895,1306.69 886.905,1306.69 886.914,1306.69 886.923,1306.7 886.932,1306.7 886.941,1306.7 886.951,1306.7 886.96,1306.7 886.969,1306.7 886.978,1306.7 886.987,1306.7 886.996,1306.7 887.006,1306.7 887.015,1306.7 887.024,1306.7 887.033,1306.7 887.042,1306.7 887.052,1306.7 887.061,1306.7 887.07,1306.7 887.079,1306.7 887.088,1306.7 887.098,1306.71 887.107,1306.71 887.116,1306.71 887.125,1306.71 887.134,1306.71 887.144,1306.71 887.153,1306.71 887.162,1306.71 887.171,1306.71 887.18,1306.71 887.189,1306.71 887.199,1306.71 887.208,1306.71 887.217,1306.71 887.226,1306.71 887.235,1306.71 887.245,1306.71 887.254,1306.71 887.263,1306.71 887.272,1306.72 887.281,1306.72 887.291,1306.72 887.3,1306.72 887.309,1306.72 887.318,1306.72 887.327,1306.72 887.336,1306.72 887.346,1306.72 887.355,1306.72 887.364,1306.72 887.373,1306.72 887.382,1306.72 887.392,1306.72 887.401,1306.72 887.41,1306.72 887.419,1306.72 887.428,1306.72 887.438,1306.72 887.447,1306.72 887.456,1306.73 887.465,1306.73 887.474,1306.73 887.484,1306.73 887.493,1306.73 887.502,1306.73 887.511,1306.73 887.52,1306.73 887.529,1306.73 887.539,1306.73 887.548,1306.73 887.557,1306.73 887.566,1306.73 887.575,1306.73 887.585,1306.73 887.594,1306.73 887.603,1306.73 887.612,1306.73 887.621,1306.73 887.631,1306.74 887.64,1306.74 887.649,1306.74 887.658,1306.74 887.667,1306.74 887.676,1306.74 887.686,1306.74 887.695,1306.74 887.704,1306.74 887.713,1306.74 887.722,1306.74 887.732,1306.74 887.741,1306.74 887.75,1306.74 887.759,1306.74 887.768,1306.74 887.778,1306.74 887.787,1306.74 887.796,1306.74 887.805,1306.75 887.814,1306.75 887.824,1306.75 887.833,1306.75 887.842,1306.75 887.851,1306.75 887.86,1306.75 887.869,1306.75 887.879,1306.75 887.888,1306.75 887.897,1306.75 887.906,1306.75 887.915,1306.75 887.925,1306.75 887.934,1306.75 887.943,1306.75 887.952,1306.75 887.961,1306.75 887.971,1306.75 887.98,1306.75 887.989,1306.76 887.998,1306.76 888.007,1306.76 888.016,1306.76 888.026,1306.76 888.035,1306.76 888.044,1306.76 888.053,1306.76 888.062,1306.76 888.072,1306.76 888.081,1306.76 888.09,1306.76 888.099,1306.76 888.108,1306.76 888.118,1306.76 888.127,1306.76 888.136,1306.76 888.145,1306.76 888.154,1306.76 888.164,1306.77 888.173,1306.77 888.182,1306.77 888.191,1306.77 888.2,1306.77 888.209,1306.77 888.219,1306.77 888.228,1306.77 888.237,1306.77 888.246,1306.77 888.255,1306.77 888.265,1306.77 888.274,1306.77 888.283,1306.77 888.292,1306.77 888.301,1306.77 888.311,1306.77 888.32,1306.77 888.329,1306.77 888.338,1306.78 888.347,1306.78 888.356,1306.78 888.366,1306.78 888.375,1306.78 888.384,1306.78 888.393,1306.78 888.402,1306.78 888.412,1306.78 888.421,1306.78 888.43,1306.78 888.439,1306.78 888.448,1306.78 888.458,1306.78 888.467,1306.78 888.476,1306.78 888.485,1306.78 888.494,1306.78 888.504,1306.78 888.513,1306.78 888.522,1306.79 888.531,1306.79 888.54,1306.79 888.549,1306.79 888.559,1306.79 888.568,1306.79 888.577,1306.79 888.586,1306.79 888.595,1306.79 888.605,1306.79 888.614,1306.79 888.623,1306.79 888.632,1306.79 888.641,1306.79 888.651,1306.79 888.66,1306.79 888.669,1306.79 888.678,1306.79 888.687,1306.79 888.697,1306.8 888.706,1306.8 888.715,1306.8 888.724,1306.8 888.733,1306.8 888.742,1306.8 888.752,1306.8 888.761,1306.8 888.77,1306.8 888.779,1306.8 888.788,1306.8 888.798,1306.8 888.807,1306.8 888.816,1306.8 888.825,1306.8 888.834,1306.8 888.844,1306.8 888.853,1306.8 888.862,1306.8 888.871,1306.81 888.88,1306.81 888.889,1306.81 888.899,1306.81 888.908,1306.81 888.917,1306.81 888.926,1306.81 888.935,1306.81 888.945,1306.81 888.954,1306.81 888.963,1306.81 888.972,1306.81 888.981,1306.81 888.991,1306.81 889,1306.81 889.009,1306.81 889.018,1306.81 889.027,1306.81 889.037,1306.81 889.046,1306.82 889.055,1306.82 889.064,1306.82 889.073,1306.82 889.082,1306.82 889.092,1306.82 889.101,1306.82 889.11,1306.82 889.119,1306.82 889.128,1306.82 889.138,1306.82 889.147,1306.82 889.156,1306.82 889.165,1306.82 889.174,1306.82 889.184,1306.82 889.193,1306.82 889.202,1306.82 889.211,1306.82 889.22,1306.82 889.229,1306.83 889.239,1306.83 889.248,1306.83 889.257,1306.83 889.266,1306.83 889.275,1306.83 889.285,1306.83 889.294,1306.83 889.303,1306.83 889.312,1306.83 889.321,1306.83 889.331,1306.83 889.34,1306.83 889.349,1306.83 889.358,1306.83 889.367,1306.83 889.377,1306.83 889.386,1306.83 889.395,1306.83 889.404,1306.84 889.413,1306.84 889.422,1306.84 889.432,1306.84 889.441,1306.84 889.45,1306.84 889.459,1306.84 889.468,1306.84 889.478,1306.84 889.487,1306.84 889.496,1306.84 889.505,1306.84 889.514,1306.84 889.524,1306.84 889.533,1306.84 889.542,1306.84 889.551,1306.84 889.56,1306.84 889.569,1306.84 889.579,1306.85 889.588,1306.85 889.597,1306.85 889.606,1306.85 889.615,1306.85 889.625,1306.85 889.634,1306.85 889.643,1306.85 889.652,1306.85 889.661,1306.85 889.671,1306.85 889.68,1306.85 889.689,1306.85 889.698,1306.85 889.707,1306.85 889.717,1306.85 889.726,1306.85 889.735,1306.85 889.744,1306.85 889.753,1306.86 889.762,1306.86 889.772,1306.86 889.781,1306.86 889.79,1306.86 889.799,1306.86 889.808,1306.86 889.818,1306.86 889.827,1306.86 889.836,1306.86 889.845,1306.86 889.854,1306.86 889.864,1306.86 889.873,1306.86 889.882,1306.86 889.891,1306.86 889.9,1306.86 889.909,1306.86 889.919,1306.86 889.928,1306.87 889.937,1306.87 889.946,1306.87 889.955,1306.87 889.965,1306.87 889.974,1306.87 889.983,1306.87 889.992,1306.87 890.001,1306.87 890.011,1306.87 890.02,1306.87 890.029,1306.87 890.038,1306.87 890.047,1306.87 890.057,1306.87 890.066,1306.87 890.075,1306.87 890.084,1306.87 890.093,1306.87 890.102,1306.87 890.112,1306.88 890.121,1306.88 890.13,1306.88 890.139,1306.88 890.148,1306.88 890.158,1306.88 890.167,1306.88 890.176,1306.88 890.185,1306.88 890.194,1306.88 890.204,1306.88 890.213,1306.88 890.222,1306.88 890.231,1306.88 890.24,1306.88 890.249,1306.88 890.259,1306.88 890.268,1306.88 890.277,1306.88 890.286,1306.89 890.295,1306.89 890.305,1306.89 890.314,1306.89 890.323,1306.89 890.332,1306.89 890.341,1306.89 890.351,1306.89 890.36,1306.89 890.369,1306.89 890.378,1306.89 890.387,1306.89 890.397,1306.89 890.406,1306.89 890.415,1306.89 890.424,1306.89 890.433,1306.89 890.442,1306.89 890.452,1306.89 890.461,1306.9 890.47,1306.9 890.479,1306.9 890.488,1306.9 890.498,1306.9 890.507,1306.9 890.516,1306.9 890.525,1306.9 890.534,1306.9 890.544,1306.9 890.553,1306.9 890.562,1306.9 890.571,1306.9 890.58,1306.9 890.589,1306.9 890.599,1306.9 890.608,1306.9 890.617,1306.9 890.626,1306.9 890.635,1306.91 890.645,1306.91 890.654,1306.91 890.663,1306.91 890.672,1306.91 890.681,1306.91 890.691,1306.91 890.7,1306.91 890.709,1306.91 890.718,1306.91 890.727,1306.91 890.737,1306.91 890.746,1306.91 890.755,1306.91 890.764,1306.91 890.773,1306.91 890.782,1306.91 890.792,1306.91 890.801,1306.91 890.81,1306.92 890.819,1306.92 890.828,1306.92 890.838,1306.92 890.847,1306.92 890.856,1306.92 890.865,1306.92 890.874,1306.92 890.884,1306.92 890.893,1306.92 890.902,1306.92 890.911,1306.92 890.92,1306.92 890.929,1306.92 890.939,1306.92 890.948,1306.92 890.957,1306.92 890.966,1306.92 890.975,1306.92 890.985,1306.93 890.994,1306.93 891.003,1306.93 891.012,1306.93 891.021,1306.93 891.031,1306.93 891.04,1306.93 891.049,1306.93 891.058,1306.93 891.067,1306.93 891.077,1306.93 891.086,1306.93 891.095,1306.93 891.104,1306.93 891.113,1306.93 891.122,1306.93 891.132,1306.93 891.141,1306.93 891.15,1306.93 891.159,1306.94 891.168,1306.94 891.178,1306.94 891.187,1306.94 891.196,1306.94 891.205,1306.94 891.214,1306.94 891.224,1306.94 891.233,1306.94 891.242,1306.94 891.251,1306.94 891.26,1306.94 891.27,1306.94 891.279,1306.94 891.288,1306.94 891.297,1306.94 891.306,1306.94 891.315,1306.94 891.325,1306.94 891.334,1306.95 891.343,1306.95 891.352,1306.95 891.361,1306.95 891.371,1306.95 891.38,1306.95 891.389,1306.95 891.398,1306.95 891.407,1306.95 891.417,1306.95 891.426,1306.95 891.435,1306.95 891.444,1306.95 891.453,1306.95 891.462,1306.95 891.472,1306.95 891.481,1306.95 891.49,1306.95 891.499,1306.95 891.508,1306.96 891.518,1306.96 891.527,1306.96 891.536,1306.96 891.545,1306.96 891.554,1306.96 891.564,1306.96 891.573,1306.96 891.582,1306.96 891.591,1306.96 891.6,1306.96 891.61,1306.96 891.619,1306.96 891.628,1306.96 891.637,1306.96 891.646,1306.96 891.655,1306.96 891.665,1306.96 891.674,1306.96 891.683,1306.97 891.692,1306.97 891.701,1306.97 891.711,1306.97 891.72,1306.97 891.729,1306.97 891.738,1306.97 891.747,1306.97 891.757,1306.97 891.766,1306.97 891.775,1306.97 891.784,1306.97 891.793,1306.97 891.802,1306.97 891.812,1306.97 891.821,1306.97 891.83,1306.97 891.839,1306.97 891.848,1306.97 891.858,1306.98 891.867,1306.98 891.876,1306.98 891.885,1306.98 891.894,1306.98 891.904,1306.98 891.913,1306.98 891.922,1306.98 891.931,1306.98 891.94,1306.98 891.95,1306.98 891.959,1306.98 891.968,1306.98 891.977,1306.98 891.986,1306.98 891.995,1306.98 892.005,1306.98 892.014,1306.98 892.023,1306.98 892.032,1306.99 892.041,1306.99 892.051,1306.99 892.06,1306.99 892.069,1306.99 892.078,1306.99 892.087,1306.99 892.097,1306.99 892.106,1306.99 892.115,1306.99 892.124,1306.99 892.133,1306.99 892.142,1306.99 892.152,1306.99 892.161,1306.99 892.17,1306.99 892.179,1306.99 892.188,1306.99 892.198,1306.99 892.207,1307 892.216,1307 892.225,1307 892.234,1307 892.244,1307 892.253,1307 892.262,1307 892.271,1307 892.28,1307 892.29,1307 892.299,1307 892.308,1307 892.317,1307 892.326,1307 892.335,1307 892.345,1307 892.354,1307 892.363,1307 892.372,1307 892.381,1307.01 892.391,1307.01 892.4,1307.01 892.409,1307.01 892.418,1307.01 892.427,1307.01 892.437,1307.01 892.446,1307.01 892.455,1307.01 892.464,1307.01 892.473,1307.01 892.482,1307.01 892.492,1307.01 892.501,1307.01 892.51,1307.01 892.519,1307.01 892.528,1307.01 892.538,1307.01 892.547,1307.01 892.556,1307.02 892.565,1307.02 892.574,1307.02 892.584,1307.02 892.593,1307.02 892.602,1307.02 892.611,1307.02 892.62,1307.02 892.63,1307.02 892.639,1307.02 892.648,1307.02 892.657,1307.02 892.666,1307.02 892.675,1307.02 892.685,1307.02 892.694,1307.02 892.703,1307.02 892.712,1307.02 892.721,1307.02 892.731,1307.03 892.74,1307.03 892.749,1307.03 892.758,1307.03 892.767,1307.03 892.777,1307.03 892.786,1307.03 892.795,1307.03 892.804,1307.03 892.813,1307.03 892.822,1307.03 892.832,1307.03 892.841,1307.03 892.85,1307.03 892.859,1307.03 892.868,1307.03 892.878,1307.03 892.887,1307.03 892.896,1307.03 892.905,1307.04 892.914,1307.04 892.924,1307.04 892.933,1307.04 892.942,1307.04 892.951,1307.04 892.96,1307.04 892.97,1307.04 892.979,1307.04 892.988,1307.04 892.997,1307.04 893.006,1307.04 893.015,1307.04 893.025,1307.04 893.034,1307.04 893.043,1307.04 893.052,1307.04 893.061,1307.04 893.071,1307.04 893.08,1307.05 893.089,1307.05 893.098,1307.05 893.107,1307.05 893.117,1307.05 893.126,1307.05 893.135,1307.05 893.144,1307.05 893.153,1307.05 893.162,1307.05 893.172,1307.05 893.181,1307.05 893.19,1307.05 893.199,1307.05 893.208,1307.05 893.218,1307.05 893.227,1307.05 893.236,1307.05 893.245,1307.05 893.254,1307.06 893.264,1307.06 893.273,1307.06 893.282,1307.06 893.291,1307.06 893.3,1307.06 893.31,1307.06 893.319,1307.06 893.328,1307.06 893.337,1307.06 893.346,1307.06 893.355,1307.06 893.365,1307.06 893.374,1307.06 893.383,1307.06 893.392,1307.06 893.401,1307.06 893.411,1307.06 893.42,1307.06 893.429,1307.07 893.438,1307.07 893.447,1307.07 893.457,1307.07 893.466,1307.07 893.475,1307.07 893.484,1307.07 893.493,1307.07 893.503,1307.07 893.512,1307.07 893.521,1307.07 893.53,1307.07 893.539,1307.07 893.548,1307.07 893.558,1307.07 893.567,1307.07 893.576,1307.07 893.585,1307.07 893.594,1307.07 893.604,1307.08 893.613,1307.08 893.622,1307.08 893.631,1307.08 893.64,1307.08 893.65,1307.08 893.659,1307.08 893.668,1307.08 893.677,1307.08 893.686,1307.08 893.695,1307.08 893.705,1307.08 893.714,1307.08 893.723,1307.08 893.732,1307.08 893.741,1307.08 893.751,1307.08 893.76,1307.08 893.769,1307.09 893.778,1307.09 893.787,1307.09 893.797,1307.09 893.806,1307.09 893.815,1307.09 893.824,1307.09 893.833,1307.09 893.843,1307.09 893.852,1307.09 893.861,1307.09 893.87,1307.09 893.879,1307.09 893.888,1307.09 893.898,1307.09 893.907,1307.09 893.916,1307.09 893.925,1307.09 893.934,1307.09 893.944,1307.1 893.953,1307.1 893.962,1307.1 893.971,1307.1 893.98,1307.1 893.99,1307.1 893.999,1307.1 894.008,1307.1 894.017,1307.1 894.026,1307.1 894.035,1307.1 894.045,1307.1 894.054,1307.1 894.063,1307.1 894.072,1307.1 894.081,1307.1 894.091,1307.1 894.1,1307.1 894.109,1307.1 894.118,1307.11 894.127,1307.11 894.137,1307.11 894.146,1307.11 894.155,1307.11 894.164,1307.11 894.173,1307.11 894.183,1307.11 894.192,1307.11 894.201,1307.11 894.21,1307.11 894.219,1307.11 894.228,1307.11 894.238,1307.11 894.247,1307.11 894.256,1307.11 894.265,1307.11 894.274,1307.11 894.284,1307.11 894.293,1307.12 894.302,1307.12 894.311,1307.12 894.32,1307.12 894.33,1307.12 894.339,1307.12 894.348,1307.12 894.357,1307.12 894.366,1307.12 894.375,1307.12 894.385,1307.12 894.394,1307.12 894.403,1307.12 894.412,1307.12 894.421,1307.12 894.431,1307.12 894.44,1307.12 894.449,1307.12 894.458,1307.12 894.467,1307.13 894.477,1307.13 894.486,1307.13 894.495,1307.13 894.504,1307.13 894.513,1307.13 894.523,1307.13 894.532,1307.13 894.541,1307.13 894.55,1307.13 894.559,1307.13 894.568,1307.13 894.578,1307.13 894.587,1307.13 894.596,1307.13 894.605,1307.13 894.614,1307.13 894.624,1307.13 894.633,1307.13 894.642,1307.14 894.651,1307.14 894.66,1307.14 894.67,1307.14 894.679,1307.14 894.688,1307.14 894.697,1307.14 894.706,1307.14 894.715,1307.14 894.725,1307.14 894.734,1307.14 894.743,1307.14 894.752,1307.14 894.761,1307.14 894.771,1307.14 894.78,1307.14 894.789,1307.14 894.798,1307.14 894.807,1307.15 894.817,1307.15 894.826,1307.15 894.835,1307.15 894.844,1307.15 894.853,1307.15 894.863,1307.15 894.872,1307.15 894.881,1307.15 894.89,1307.15 894.899,1307.15 894.908,1307.15 894.918,1307.15 894.927,1307.15 894.936,1307.15 894.945,1307.15 894.954,1307.15 894.964,1307.15 894.973,1307.15 894.982,1307.16 894.991,1307.16 895,1307.16 895.01,1307.16 895.019,1307.16 895.028,1307.16 895.037,1307.16 895.046,1307.16 895.055,1307.16 895.065,1307.16 895.074,1307.16 895.083,1307.16 895.092,1307.16 895.101,1307.16 895.111,1307.16 895.12,1307.16 895.129,1307.16 895.138,1307.16 895.147,1307.16 895.157,1307.17 895.166,1307.17 895.175,1307.17 895.184,1307.17 895.193,1307.17 895.203,1307.17 895.212,1307.17 895.221,1307.17 895.23,1307.17 895.239,1307.17 895.248,1307.17 895.258,1307.17 895.267,1307.17 895.276,1307.17 895.285,1307.17 895.294,1307.17 895.304,1307.17 895.313,1307.17 895.322,1307.17 895.331,1307.18 895.34,1307.18 895.35,1307.18 895.359,1307.18 895.368,1307.18 895.377,1307.18 895.386,1307.18 895.395,1307.18 895.405,1307.18 895.414,1307.18 895.423,1307.18 895.432,1307.18 895.441,1307.18 895.451,1307.18 895.46,1307.18 895.469,1307.18 895.478,1307.18 895.487,1307.18 895.497,1307.19 895.506,1307.19 895.515,1307.19 895.524,1307.19 895.533,1307.19 895.543,1307.19 895.552,1307.19 895.561,1307.19 895.57,1307.19 895.579,1307.19 895.588,1307.19 895.598,1307.19 895.607,1307.19 895.616,1307.19 895.625,1307.19 895.634,1307.19 895.644,1307.19 895.653,1307.19 895.662,1307.19 895.671,1307.2 895.68,1307.2 895.69,1307.2 895.699,1307.2 895.708,1307.2 895.717,1307.2 895.726,1307.2 895.735,1307.2 895.745,1307.2 895.754,1307.2 895.763,1307.2 895.772,1307.2 895.781,1307.2 895.791,1307.2 895.8,1307.2 895.809,1307.2 895.818,1307.2 895.827,1307.2 895.837,1307.2 895.846,1307.21 895.855,1307.21 895.864,1307.21 895.873,1307.21 895.883,1307.21 895.892,1307.21 895.901,1307.21 895.91,1307.21 895.919,1307.21 895.928,1307.21 895.938,1307.21 895.947,1307.21 895.956,1307.21 895.965,1307.21 895.974,1307.21 895.984,1307.21 895.993,1307.21 896.002,1307.21 896.011,1307.21 896.02,1307.22 896.03,1307.22 896.039,1307.22 896.048,1307.22 896.057,1307.22 896.066,1307.22 896.076,1307.22 896.085,1307.22 896.094,1307.22 896.103,1307.22 896.112,1307.22 896.121,1307.22 896.131,1307.22 896.14,1307.22 896.149,1307.22 896.158,1307.22 896.167,1307.22 896.177,1307.22 896.186,1307.23 896.195,1307.23 896.204,1307.23 896.213,1307.23 896.223,1307.23 896.232,1307.23 896.241,1307.23 896.25,1307.23 896.259,1307.23 896.268,1307.23 896.278,1307.23 896.287,1307.23 896.296,1307.23 896.305,1307.23 896.314,1307.23 896.324,1307.23 896.333,1307.23 896.342,1307.23 896.351,1307.23 896.36,1307.24 896.37,1307.24 896.379,1307.24 896.388,1307.24 896.397,1307.24 896.406,1307.24 896.416,1307.24 896.425,1307.24 896.434,1307.24 896.443,1307.24 896.452,1307.24 896.461,1307.24 896.471,1307.24 896.48,1307.24 896.489,1307.24 896.498,1307.24 896.507,1307.24 896.517,1307.24 896.526,1307.24 896.535,1307.25 896.544,1307.25 896.553,1307.25 896.563,1307.25 896.572,1307.25 896.581,1307.25 896.59,1307.25 896.599,1307.25 896.608,1307.25 896.618,1307.25 896.627,1307.25 896.636,1307.25 896.645,1307.25 896.654,1307.25 896.664,1307.25 896.673,1307.25 896.682,1307.25 896.691,1307.25 896.7,1307.26 896.71,1307.26 896.719,1307.26 896.728,1307.26 896.737,1307.26 896.746,1307.26 896.756,1307.26 896.765,1307.26 896.774,1307.26 896.783,1307.26 896.792,1307.26 896.801,1307.26 896.811,1307.26 896.82,1307.26 896.829,1307.26 896.838,1307.26 896.847,1307.26 896.857,1307.26 896.866,1307.26 896.875,1307.27 896.884,1307.27 896.893,1307.27 896.903,1307.27 896.912,1307.27 896.921,1307.27 896.93,1307.27 896.939,1307.27 896.948,1307.27 896.958,1307.27 896.967,1307.27 896.976,1307.27 896.985,1307.27 896.994,1307.27 897.004,1307.27 897.013,1307.27 897.022,1307.27 897.031,1307.27 897.04,1307.27 897.05,1307.28 897.059,1307.28 897.068,1307.28 897.077,1307.28 897.086,1307.28 897.096,1307.28 897.105,1307.28 897.114,1307.28 897.123,1307.28 897.132,1307.28 897.141,1307.28 897.151,1307.28 897.16,1307.28 897.169,1307.28 897.178,1307.28 897.187,1307.28 897.197,1307.28 897.206,1307.28 897.215,1307.29 897.224,1307.29 897.233,1307.29 897.243,1307.29 897.252,1307.29 897.261,1307.29 897.27,1307.29 897.279,1307.29 897.288,1307.29 897.298,1307.29 897.307,1307.29 897.316,1307.29 897.325,1307.29 897.334,1307.29 897.344,1307.29 897.353,1307.29 897.362,1307.29 897.371,1307.29 897.38,1307.29 897.39,1307.3 897.399,1307.3 897.408,1307.3 897.417,1307.3 897.426,1307.3 897.436,1307.3 897.445,1307.3 897.454,1307.3 897.463,1307.3 897.472,1307.3 897.481,1307.3 897.491,1307.3 897.5,1307.3 897.509,1307.3 897.518,1307.3 897.527,1307.3 897.537,1307.3 897.546,1307.3 897.555,1307.31 897.564,1307.31 897.573,1307.31 897.583,1307.31 897.592,1307.31 897.601,1307.31 897.61,1307.31 897.619,1307.31 897.628,1307.31 897.638,1307.31 897.647,1307.31 897.656,1307.31 897.665,1307.31 897.674,1307.31 897.684,1307.31 897.693,1307.31 897.702,1307.31 897.711,1307.31 897.72,1307.31 897.73,1307.32 897.739,1307.32 897.748,1307.32 897.757,1307.32 897.766,1307.32 897.776,1307.32 897.785,1307.32 897.794,1307.32 897.803,1307.32 897.812,1307.32 897.821,1307.32 897.831,1307.32 897.84,1307.32 897.849,1307.32 897.858,1307.32 897.867,1307.32 897.877,1307.32 897.886,1307.32 897.895,1307.32 897.904,1307.33 897.913,1307.33 897.923,1307.33 897.932,1307.33 897.941,1307.33 897.95,1307.33 897.959,1307.33 897.968,1307.33 897.978,1307.33 897.987,1307.33 897.996,1307.33 898.005,1307.33 898.014,1307.33 898.024,1307.33 898.033,1307.33 898.042,1307.33 898.051,1307.33 898.06,1307.33 898.07,1307.34 898.079,1307.34 898.088,1307.34 898.097,1307.34 898.106,1307.34 898.116,1307.34 898.125,1307.34 898.134,1307.34 898.143,1307.34 898.152,1307.34 898.161,1307.34 898.171,1307.34 898.18,1307.34 898.189,1307.34 898.198,1307.34 898.207,1307.34 898.217,1307.34 898.226,1307.34 898.235,1307.34 898.244,1307.35 898.253,1307.35 898.263,1307.35 898.272,1307.35 898.281,1307.35 898.29,1307.35 898.299,1307.35 898.308,1307.35 898.318,1307.35 898.327,1307.35 898.336,1307.35 898.345,1307.35 898.354,1307.35 898.364,1307.35 898.373,1307.35 898.382,1307.35 898.391,1307.35 898.4,1307.35 898.41,1307.36 898.419,1307.36 898.428,1307.36 898.437,1307.36 898.446,1307.36 898.456,1307.36 898.465,1307.36 898.474,1307.36 898.483,1307.36 898.492,1307.36 898.501,1307.36 898.511,1307.36 898.52,1307.36 898.529,1307.36 898.538,1307.36 898.547,1307.36 898.557,1307.36 898.566,1307.36 898.575,1307.36 898.584,1307.37 898.593,1307.37 898.603,1307.37 898.612,1307.37 898.621,1307.37 898.63,1307.37 898.639,1307.37 898.649,1307.37 898.658,1307.37 898.667,1307.37 898.676,1307.37 898.685,1307.37 898.694,1307.37 898.704,1307.37 898.713,1307.37 898.722,1307.37 898.731,1307.37 898.74,1307.37 898.75,1307.38 898.759,1307.38 898.768,1307.38 898.777,1307.38 898.786,1307.38 898.796,1307.38 898.805,1307.38 898.814,1307.38 898.823,1307.38 898.832,1307.38 898.841,1307.38 898.851,1307.38 898.86,1307.38 898.869,1307.38 898.878,1307.38 898.887,1307.38 898.897,1307.38 898.906,1307.38 898.915,1307.38 898.924,1307.39 898.933,1307.39 898.943,1307.39 898.952,1307.39 898.961,1307.39 898.97,1307.39 898.979,1307.39 898.989,1307.39 898.998,1307.39 899.007,1307.39 899.016,1307.39 899.025,1307.39 899.034,1307.39 899.044,1307.39 899.053,1307.39 899.062,1307.39 899.071,1307.39 899.08,1307.39 899.09,1307.4 899.099,1307.4 899.108,1307.4 899.117,1307.4 899.126,1307.4 899.136,1307.4 899.145,1307.4 899.154,1307.4 899.163,1307.4 899.172,1307.4 899.181,1307.4 899.191,1307.4 899.2,1307.4 899.209,1307.4 899.218,1307.4 899.227,1307.4 899.237,1307.4 899.246,1307.4 899.255,1307.4 899.264,1307.41 899.273,1307.41 899.283,1307.41 899.292,1307.41 899.301,1307.41 899.31,1307.41 899.319,1307.41 899.329,1307.41 899.338,1307.41 899.347,1307.41 899.356,1307.41 899.365,1307.41 899.374,1307.41 899.384,1307.41 899.393,1307.41 899.402,1307.41 899.411,1307.41 899.42,1307.41 899.43,1307.42 899.439,1307.42 899.448,1307.42 899.457,1307.42 899.466,1307.42 899.476,1307.42 899.485,1307.42 899.494,1307.42 899.503,1307.42 899.512,1307.42 899.521,1307.42 899.531,1307.42 899.54,1307.42 899.549,1307.42 899.558,1307.42 899.567,1307.42 899.577,1307.42 899.586,1307.42 899.595,1307.42 899.604,1307.43 899.613,1307.43 899.623,1307.43 899.632,1307.43 899.641,1307.43 899.65,1307.43 899.659,1307.43 899.669,1307.43 899.678,1307.43 899.687,1307.43 899.696,1307.43 899.705,1307.43 899.714,1307.43 899.724,1307.43 899.733,1307.43 899.742,1307.43 899.751,1307.43 899.76,1307.43 899.77,1307.44 899.779,1307.44 899.788,1307.44 899.797,1307.44 899.806,1307.44 899.816,1307.44 899.825,1307.44 899.834,1307.44 899.843,1307.44 899.852,1307.44 899.861,1307.44 899.871,1307.44 899.88,1307.44 899.889,1307.44 899.898,1307.44 899.907,1307.44 899.917,1307.44 899.926,1307.44 899.935,1307.45 899.944,1307.45 899.953,1307.45 899.963,1307.45 899.972,1307.45 899.981,1307.45 899.99,1307.45 899.999,1307.45 900.009,1307.45 900.018,1307.45 900.027,1307.45 900.036,1307.45 900.045,1307.45 900.054,1307.45 900.064,1307.45 900.073,1307.45 900.082,1307.45 900.091,1307.45 900.1,1307.45 900.11,1307.46 900.119,1307.46 900.128,1307.46 900.137,1307.46 900.146,1307.46 900.156,1307.46 900.165,1307.46 900.174,1307.46 900.183,1307.46 900.192,1307.46 900.201,1307.46 900.211,1307.46 900.22,1307.46 900.229,1307.46 900.238,1307.46 900.247,1307.46 900.257,1307.46 900.266,1307.46 900.275,1307.47 900.284,1307.47 900.293,1307.47 900.303,1307.47 900.312,1307.47 900.321,1307.47 900.33,1307.47 900.339,1307.47 900.349,1307.47 900.358,1307.47 900.367,1307.47 900.376,1307.47 900.385,1307.47 900.394,1307.47 900.404,1307.47 900.413,1307.47 900.422,1307.47 900.431,1307.47 900.44,1307.47 900.45,1307.48 900.459,1307.48 900.468,1307.48 900.477,1307.48 900.486,1307.48 900.496,1307.48 900.505,1307.48 900.514,1307.48 900.523,1307.48 900.532,1307.48 900.541,1307.48 900.551,1307.48 900.56,1307.48 900.569,1307.48 900.578,1307.48 900.587,1307.48 900.597,1307.48 900.606,1307.48 900.615,1307.49 900.624,1307.49 900.633,1307.49 900.643,1307.49 900.652,1307.49 900.661,1307.49 900.67,1307.49 900.679,1307.49 900.689,1307.49 900.698,1307.49 900.707,1307.49 900.716,1307.49 900.725,1307.49 900.734,1307.49 900.744,1307.49 900.753,1307.49 900.762,1307.49 900.771,1307.49 900.78,1307.49 900.79,1307.5 900.799,1307.5 900.808,1307.5 900.817,1307.5 900.826,1307.5 900.836,1307.5 900.845,1307.5 900.854,1307.5 900.863,1307.5 900.872,1307.5 900.882,1307.5 900.891,1307.5 900.9,1307.5 900.909,1307.5 900.918,1307.5 900.927,1307.5 900.937,1307.5 900.946,1307.5 900.955,1307.51 900.964,1307.51 900.973,1307.51 900.983,1307.51 900.992,1307.51 901.001,1307.51 901.01,1307.51 901.019,1307.51 901.029,1307.51 901.038,1307.51 901.047,1307.51 901.056,1307.51 901.065,1307.51 901.074,1307.51 901.084,1307.51 901.093,1307.51 901.102,1307.51 901.111,1307.51 901.12,1307.52 901.13,1307.52 901.139,1307.52 901.148,1307.52 901.157,1307.52 901.166,1307.52 901.176,1307.52 901.185,1307.52 901.194,1307.52 901.203,1307.52 901.212,1307.52 901.222,1307.52 901.231,1307.52 901.24,1307.52 901.249,1307.52 901.258,1307.52 901.267,1307.52 901.277,1307.52 901.286,1307.52 901.295,1307.53 901.304,1307.53 901.313,1307.53 901.323,1307.53 901.332,1307.53 901.341,1307.53 901.35,1307.53 901.359,1307.53 901.369,1307.53 901.378,1307.53 901.387,1307.53 901.396,1307.53 901.405,1307.53 901.414,1307.53 901.424,1307.53 901.433,1307.53 901.442,1307.53 901.451,1307.53 901.46,1307.54 901.47,1307.54 901.479,1307.54 901.488,1307.54 901.497,1307.54 901.506,1307.54 901.516,1307.54 901.525,1307.54 901.534,1307.54 901.543,1307.54 901.552,1307.54 901.562,1307.54 901.571,1307.54 901.58,1307.54 901.589,1307.54 901.598,1307.54 901.607,1307.54 901.617,1307.54 901.626,1307.55 901.635,1307.55 901.644,1307.55 901.653,1307.55 901.663,1307.55 901.672,1307.55 901.681,1307.55 901.69,1307.55 901.699,1307.55 901.709,1307.55 901.718,1307.55 901.727,1307.55 901.736,1307.55 901.745,1307.55 901.754,1307.55 901.764,1307.55 901.773,1307.55 901.782,1307.55 901.791,1307.55 901.8,1307.56 901.81,1307.56 901.819,1307.56 901.828,1307.56 901.837,1307.56 901.846,1307.56 901.856,1307.56 901.865,1307.56 901.874,1307.56 901.883,1307.56 901.892,1307.56 901.902,1307.56 901.911,1307.56 901.92,1307.56 901.929,1307.56 901.938,1307.56 901.947,1307.56 901.957,1307.56 901.966,1307.57 901.975,1307.57 901.984,1307.57 901.993,1307.57 902.003,1307.57 902.012,1307.57 902.021,1307.57 902.03,1307.57 902.039,1307.57 902.049,1307.57 902.058,1307.57 902.067,1307.57 902.076,1307.57 902.085,1307.57 902.094,1307.57 902.104,1307.57 902.113,1307.57 902.122,1307.57 902.131,1307.58 902.14,1307.58 902.15,1307.58 902.159,1307.58 902.168,1307.58 902.177,1307.58 902.186,1307.58 902.196,1307.58 902.205,1307.58 902.214,1307.58 902.223,1307.58 902.232,1307.58 902.242,1307.58 902.251,1307.58 902.26,1307.58 902.269,1307.58 902.278,1307.58 902.287,1307.58 902.297,1307.59 902.306,1307.59 902.315,1307.59 902.324,1307.59 902.333,1307.59 902.343,1307.59 902.352,1307.59 902.361,1307.59 902.37,1307.59 902.379,1307.59 902.389,1307.59 902.398,1307.59 902.407,1307.59 902.416,1307.59 902.425,1307.59 902.434,1307.59 902.444,1307.59 902.453,1307.59 902.462,1307.59 902.471,1307.6 902.48,1307.6 902.49,1307.6 902.499,1307.6 902.508,1307.6 902.517,1307.6 902.526,1307.6 902.536,1307.6 902.545,1307.6 902.554,1307.6 902.563,1307.6 902.572,1307.6 902.582,1307.6 902.591,1307.6 902.6,1307.6 902.609,1307.6 902.618,1307.6 902.627,1307.6 902.637,1307.61 902.646,1307.61 902.655,1307.61 902.664,1307.61 902.673,1307.61 902.683,1307.61 902.692,1307.61 902.701,1307.61 902.71,1307.61 902.719,1307.61 902.729,1307.61 902.738,1307.61 902.747,1307.61 902.756,1307.61 902.765,1307.61 902.774,1307.61 902.784,1307.61 902.793,1307.61 902.802,1307.62 902.811,1307.62 902.82,1307.62 902.83,1307.62 902.839,1307.62 902.848,1307.62 902.857,1307.62 902.866,1307.62 902.876,1307.62 902.885,1307.62 902.894,1307.62 902.903,1307.62 902.912,1307.62 902.922,1307.62 902.931,1307.62 902.94,1307.62 902.949,1307.62 902.958,1307.62 902.967,1307.62 902.977,1307.63 902.986,1307.63 902.995,1307.63 903.004,1307.63 903.013,1307.63 903.023,1307.63 903.032,1307.63 903.041,1307.63 903.05,1307.63 903.059,1307.63 903.069,1307.63 903.078,1307.63 903.087,1307.63 903.096,1307.63 903.105,1307.63 903.114,1307.63 903.124,1307.63 903.133,1307.63 903.142,1307.64 903.151,1307.64 903.16,1307.64 903.17,1307.64 903.179,1307.64 903.188,1307.64 903.197,1307.64 903.206,1307.64 903.216,1307.64 903.225,1307.64 903.234,1307.64 903.243,1307.64 903.252,1307.64 903.262,1307.64 903.271,1307.64 903.28,1307.64 903.289,1307.64 903.298,1307.64 903.307,1307.65 903.317,1307.65 903.326,1307.65 903.335,1307.65 903.344,1307.65 903.353,1307.65 903.363,1307.65 903.372,1307.65 903.381,1307.65 903.39,1307.65 903.399,1307.65 903.409,1307.65 903.418,1307.65 903.427,1307.65 903.436,1307.65 903.445,1307.65 903.455,1307.65 903.464,1307.65 903.473,1307.66 903.482,1307.66 903.491,1307.66 903.5,1307.66 903.51,1307.66 903.519,1307.66 903.528,1307.66 903.537,1307.66 903.546,1307.66 903.556,1307.66 903.565,1307.66 903.574,1307.66 903.583,1307.66 903.592,1307.66 903.602,1307.66 903.611,1307.66 903.62,1307.66 903.629,1307.66 903.638,1307.67 903.647,1307.67 903.657,1307.67 903.666,1307.67 903.675,1307.67 903.684,1307.67 903.693,1307.67 903.703,1307.67 903.712,1307.67 903.721,1307.67 903.73,1307.67 903.739,1307.67 903.749,1307.67 903.758,1307.67 903.767,1307.67 903.776,1307.67 903.785,1307.67 903.795,1307.67 903.804,1307.67 903.813,1307.68 903.822,1307.68 903.831,1307.68 903.84,1307.68 903.85,1307.68 903.859,1307.68 903.868,1307.68 903.877,1307.68 903.886,1307.68 903.896,1307.68 903.905,1307.68 903.914,1307.68 903.923,1307.68 903.932,1307.68 903.942,1307.68 903.951,1307.68 903.96,1307.68 903.969,1307.68 903.978,1307.69 903.987,1307.69 903.997,1307.69 904.006,1307.69 904.015,1307.69 904.024,1307.69 904.033,1307.69 904.043,1307.69 904.052,1307.69 904.061,1307.69 904.07,1307.69 904.079,1307.69 904.089,1307.69 904.098,1307.69 904.107,1307.69 904.116,1307.69 904.125,1307.69 904.135,1307.69 904.144,1307.7 904.153,1307.7 904.162,1307.7 904.171,1307.7 904.18,1307.7 904.19,1307.7 904.199,1307.7 904.208,1307.7 904.217,1307.7 904.226,1307.7 904.236,1307.7 904.245,1307.7 904.254,1307.7 904.263,1307.7 904.272,1307.7 904.282,1307.7 904.291,1307.7 904.3,1307.7 904.309,1307.71 904.318,1307.71 904.327,1307.71 904.337,1307.71 904.346,1307.71 904.355,1307.71 904.364,1307.71 904.373,1307.71 904.383,1307.71 904.392,1307.71 904.401,1307.71 904.41,1307.71 904.419,1307.71 904.429,1307.71 904.438,1307.71 904.447,1307.71 904.456,1307.71 904.465,1307.71 904.475,1307.72 904.484,1307.72 904.493,1307.72 904.502,1307.72 904.511,1307.72 904.52,1307.72 904.53,1307.72 904.539,1307.72 904.548,1307.72 904.557,1307.72 904.566,1307.72 904.576,1307.72 904.585,1307.72 904.594,1307.72 904.603,1307.72 904.612,1307.72 904.622,1307.72 904.631,1307.72 904.64,1307.72 904.649,1307.73 904.658,1307.73 904.667,1307.73 904.677,1307.73 904.686,1307.73 904.695,1307.73 904.704,1307.73 904.713,1307.73 904.723,1307.73 904.732,1307.73 904.741,1307.73 904.75,1307.73 904.759,1307.73 904.769,1307.73 904.778,1307.73 904.787,1307.73 904.796,1307.73 904.805,1307.73 904.815,1307.74 904.824,1307.74 904.833,1307.74 904.842,1307.74 904.851,1307.74 904.86,1307.74 904.87,1307.74 904.879,1307.74 904.888,1307.74 904.897,1307.74 904.906,1307.74 904.916,1307.74 904.925,1307.74 904.934,1307.74 904.943,1307.74 904.952,1307.74 904.962,1307.74 904.971,1307.74 904.98,1307.75 904.989,1307.75 904.998,1307.75 905.007,1307.75 905.017,1307.75 905.026,1307.75 905.035,1307.75 905.044,1307.75 905.053,1307.75 905.063,1307.75 905.072,1307.75 905.081,1307.75 905.09,1307.75 905.099,1307.75 905.109,1307.75 905.118,1307.75 905.127,1307.75 905.136,1307.75 905.145,1307.76 905.155,1307.76 905.164,1307.76 905.173,1307.76 905.182,1307.76 905.191,1307.76 905.2,1307.76 905.21,1307.76 905.219,1307.76 905.228,1307.76 905.237,1307.76 905.246,1307.76 905.256,1307.76 905.265,1307.76 905.274,1307.76 905.283,1307.76 905.292,1307.76 905.302,1307.76 905.311,1307.77 905.32,1307.77 905.329,1307.77 905.338,1307.77 905.347,1307.77 905.357,1307.77 905.366,1307.77 905.375,1307.77 905.384,1307.77 905.393,1307.77 905.403,1307.77 905.412,1307.77 905.421,1307.77 905.43,1307.77 905.439,1307.77 905.449,1307.77 905.458,1307.77 905.467,1307.77 905.476,1307.78 905.485,1307.78 905.495,1307.78 905.504,1307.78 905.513,1307.78 905.522,1307.78 905.531,1307.78 905.54,1307.78 905.55,1307.78 905.559,1307.78 905.568,1307.78 905.577,1307.78 905.586,1307.78 905.596,1307.78 905.605,1307.78 905.614,1307.78 905.623,1307.78 905.632,1307.78 905.642,1307.79 905.651,1307.79 905.66,1307.79 905.669,1307.79 905.678,1307.79 905.687,1307.79 905.697,1307.79 905.706,1307.79 905.715,1307.79 905.724,1307.79 905.733,1307.79 905.743,1307.79 905.752,1307.79 905.761,1307.79 905.77,1307.79 905.779,1307.79 905.789,1307.79 905.798,1307.79 905.807,1307.8 905.816,1307.8 905.825,1307.8 905.835,1307.8 905.844,1307.8 905.853,1307.8 905.862,1307.8 905.871,1307.8 905.88,1307.8 905.89,1307.8 905.899,1307.8 905.908,1307.8 905.917,1307.8 905.926,1307.8 905.936,1307.8 905.945,1307.8 905.954,1307.8 905.963,1307.8 905.972,1307.81 905.982,1307.81 905.991,1307.81 906,1307.81 906.009,1307.81 906.018,1307.81 906.028,1307.81 906.037,1307.81 906.046,1307.81 906.055,1307.81 906.064,1307.81 906.073,1307.81 906.083,1307.81 906.092,1307.81 906.101,1307.81 906.11,1307.81 906.119,1307.81 906.129,1307.81 906.138,1307.82 906.147,1307.82 906.156,1307.82 906.165,1307.82 906.175,1307.82 906.184,1307.82 906.193,1307.82 906.202,1307.82 906.211,1307.82 906.22,1307.82 906.23,1307.82 906.239,1307.82 906.248,1307.82 906.257,1307.82 906.266,1307.82 906.276,1307.82 906.285,1307.82 906.294,1307.82 906.303,1307.83 906.312,1307.83 906.322,1307.83 906.331,1307.83 906.34,1307.83 906.349,1307.83 906.358,1307.83 906.368,1307.83 906.377,1307.83 906.386,1307.83 906.395,1307.83 906.404,1307.83 906.413,1307.83 906.423,1307.83 906.432,1307.83 906.441,1307.83 906.45,1307.83 906.459,1307.83 906.469,1307.83 906.478,1307.84 906.487,1307.84 906.496,1307.84 906.505,1307.84 906.515,1307.84 906.524,1307.84 906.533,1307.84 906.542,1307.84 906.551,1307.84 906.56,1307.84 906.57,1307.84 906.579,1307.84 906.588,1307.84 906.597,1307.84 906.606,1307.84 906.616,1307.84 906.625,1307.84 906.634,1307.84 906.643,1307.85 906.652,1307.85 906.662,1307.85 906.671,1307.85 906.68,1307.85 906.689,1307.85 906.698,1307.85 906.708,1307.85 906.717,1307.85 906.726,1307.85 906.735,1307.85 906.744,1307.85 906.753,1307.85 906.763,1307.85 906.772,1307.85 906.781,1307.85 906.79,1307.85 906.799,1307.85 906.809,1307.86 906.818,1307.86 906.827,1307.86 906.836,1307.86 906.845,1307.86 906.855,1307.86 906.864,1307.86 906.873,1307.86 906.882,1307.86 906.891,1307.86 906.9,1307.86 906.91,1307.86 906.919,1307.86 906.928,1307.86 906.937,1307.86 906.946,1307.86 906.956,1307.86 906.965,1307.86 906.974,1307.87 906.983,1307.87 906.992,1307.87 907.002,1307.87 907.011,1307.87 907.02,1307.87 907.029,1307.87 907.038,1307.87 907.048,1307.87 907.057,1307.87 907.066,1307.87 907.075,1307.87 907.084,1307.87 907.093,1307.87 907.103,1307.87 907.112,1307.87 907.121,1307.87 907.13,1307.87 907.139,1307.88 907.149,1307.88 907.158,1307.88 907.167,1307.88 907.176,1307.88 907.185,1307.88 907.195,1307.88 907.204,1307.88 907.213,1307.88 907.222,1307.88 907.231,1307.88 907.24,1307.88 907.25,1307.88 907.259,1307.88 907.268,1307.88 907.277,1307.88 907.286,1307.88 907.296,1307.88 907.305,1307.89 907.314,1307.89 907.323,1307.89 907.332,1307.89 907.342,1307.89 907.351,1307.89 907.36,1307.89 907.369,1307.89 907.378,1307.89 907.388,1307.89 907.397,1307.89 907.406,1307.89 907.415,1307.89 907.424,1307.89 907.433,1307.89 907.443,1307.89 907.452,1307.89 907.461,1307.89 907.47,1307.9 907.479,1307.9 907.489,1307.9 907.498,1307.9 907.507,1307.9 907.516,1307.9 907.525,1307.9 907.535,1307.9 907.544,1307.9 907.553,1307.9 907.562,1307.9 907.571,1307.9 907.58,1307.9 907.59,1307.9 907.599,1307.9 907.608,1307.9 907.617,1307.9 907.626,1307.9 907.636,1307.91 907.645,1307.91 907.654,1307.91 907.663,1307.91 907.672,1307.91 907.682,1307.91 907.691,1307.91 907.7,1307.91 907.709,1307.91 907.718,1307.91 907.728,1307.91 907.737,1307.91 907.746,1307.91 907.755,1307.91 907.764,1307.91 907.773,1307.91 907.783,1307.91 907.792,1307.91 907.801,1307.92 907.81,1307.92 907.819,1307.92 907.829,1307.92 907.838,1307.92 907.847,1307.92 907.856,1307.92 907.865,1307.92 907.875,1307.92 907.884,1307.92 907.893,1307.92 907.902,1307.92 907.911,1307.92 907.92,1307.92 907.93,1307.92 907.939,1307.92 907.948,1307.92 907.957,1307.92 907.966,1307.93 907.976,1307.93 907.985,1307.93 907.994,1307.93 908.003,1307.93 908.012,1307.93 908.022,1307.93 908.031,1307.93 908.04,1307.93 908.049,1307.93 908.058,1307.93 908.068,1307.93 908.077,1307.93 908.086,1307.93 908.095,1307.93 908.104,1307.93 908.113,1307.93 908.123,1307.93 908.132,1307.94 908.141,1307.94 908.15,1307.94 908.159,1307.94 908.169,1307.94 908.178,1307.94 908.187,1307.94 908.196,1307.94 908.205,1307.94 908.215,1307.94 908.224,1307.94 908.233,1307.94 908.242,1307.94 908.251,1307.94 908.261,1307.94 908.27,1307.94 908.279,1307.94 908.288,1307.95 908.297,1307.95 908.306,1307.95 908.316,1307.95 908.325,1307.95 908.334,1307.95 908.343,1307.95 908.352,1307.95 908.362,1307.95 908.371,1307.95 908.38,1307.95 908.389,1307.95 908.398,1307.95 908.408,1307.95 908.417,1307.95 908.426,1307.95 908.435,1307.95 908.444,1307.95 908.453,1307.96 908.463,1307.96 908.472,1307.96 908.481,1307.96 908.49,1307.96 908.499,1307.96 908.509,1307.96 908.518,1307.96 908.527,1307.96 908.536,1307.96 908.545,1307.96 908.555,1307.96 908.564,1307.96 908.573,1307.96 908.582,1307.96 908.591,1307.96 908.601,1307.96 908.61,1307.96 908.619,1307.97 908.628,1307.97 908.637,1307.97 908.646,1307.97 908.656,1307.97 908.665,1307.97 908.674,1307.97 908.683,1307.97 908.692,1307.97 908.702,1307.97 908.711,1307.97 908.72,1307.97 908.729,1307.97 908.738,1307.97 908.748,1307.97 908.757,1307.97 908.766,1307.97 908.775,1307.97 908.784,1307.98 908.793,1307.98 908.803,1307.98 908.812,1307.98 908.821,1307.98 908.83,1307.98 908.839,1307.98 908.849,1307.98 908.858,1307.98 908.867,1307.98 908.876,1307.98 908.885,1307.98 908.895,1307.98 908.904,1307.98 908.913,1307.98 908.922,1307.98 908.931,1307.98 908.941,1307.98 908.95,1307.99 908.959,1307.99 908.968,1307.99 908.977,1307.99 908.986,1307.99 908.996,1307.99 909.005,1307.99 909.014,1307.99 909.023,1307.99 909.032,1307.99 909.042,1307.99 909.051,1307.99 909.06,1307.99 909.069,1307.99 909.078,1307.99 909.088,1307.99 909.097,1307.99 909.106,1307.99 909.115,1308 909.124,1308 909.133,1308 909.143,1308 909.152,1308 909.161,1308 909.17,1308 909.179,1308 909.189,1308 909.198,1308 909.207,1308 909.216,1308 909.225,1308 909.235,1308 909.244,1308 909.253,1308 909.262,1308 909.271,1308 909.281,1308.01 909.29,1308.01 909.299,1308.01 909.308,1308.01 909.317,1308.01 909.326,1308.01 909.336,1308.01 909.345,1308.01 909.354,1308.01 909.363,1308.01 909.372,1308.01 909.382,1308.01 909.391,1308.01 909.4,1308.01 909.409,1308.01 909.418,1308.01 909.428,1308.01 909.437,1308.01 909.446,1308.02 909.455,1308.02 909.464,1308.02 909.473,1308.02 909.483,1308.02 909.492,1308.02 909.501,1308.02 909.51,1308.02 909.519,1308.02 909.529,1308.02 909.538,1308.02 909.547,1308.02 909.556,1308.02 909.565,1308.02 909.575,1308.02 909.584,1308.02 909.593,1308.02 909.602,1308.02 909.611,1308.03 909.621,1308.03 909.63,1308.03 909.639,1308.03 909.648,1308.03 909.657,1308.03 909.666,1308.03 909.676,1308.03 909.685,1308.03 909.694,1308.03 909.703,1308.03 909.712,1308.03 909.722,1308.03 909.731,1308.03 909.74,1308.03 909.749,1308.03 909.758,1308.03 909.768,1308.03 909.777,1308.04 909.786,1308.04 909.795,1308.04 909.804,1308.04 909.813,1308.04 909.823,1308.04 909.832,1308.04 909.841,1308.04 909.85,1308.04 909.859,1308.04 909.869,1308.04 909.878,1308.04 909.887,1308.04 909.896,1308.04 909.905,1308.04 909.915,1308.04 909.924,1308.04 909.933,1308.05 909.942,1308.05 909.951,1308.05 909.961,1308.05 909.97,1308.05 909.979,1308.05 909.988,1308.05 909.997,1308.05 910.006,1308.05 910.016,1308.05 910.025,1308.05 910.034,1308.05 910.043,1308.05 910.052,1308.05 910.062,1308.05 910.071,1308.05 910.08,1308.05 910.089,1308.05 910.098,1308.06 910.108,1308.06 910.117,1308.06 910.126,1308.06 910.135,1308.06 910.144,1308.06 910.153,1308.06 910.163,1308.06 910.172,1308.06 910.181,1308.06 910.19,1308.06 910.199,1308.06 910.209,1308.06 910.218,1308.06 910.227,1308.06 910.236,1308.06 910.245,1308.06 910.255,1308.06 910.264,1308.07 910.273,1308.07 910.282,1308.07 910.291,1308.07 910.301,1308.07 910.31,1308.07 910.319,1308.07 910.328,1308.07 910.337,1308.07 910.346,1308.07 910.356,1308.07 910.365,1308.07 910.374,1308.07 910.383,1308.07 910.392,1308.07 910.402,1308.07 910.411,1308.07 910.42,1308.07 910.429,1308.08 910.438,1308.08 910.448,1308.08 910.457,1308.08 910.466,1308.08 910.475,1308.08 910.484,1308.08 910.493,1308.08 910.503,1308.08 910.512,1308.08 910.521,1308.08 910.53,1308.08 910.539,1308.08 910.549,1308.08 910.558,1308.08 910.567,1308.08 910.576,1308.08 910.585,1308.08 910.595,1308.09 910.604,1308.09 910.613,1308.09 910.622,1308.09 910.631,1308.09 910.641,1308.09 910.65,1308.09 910.659,1308.09 910.668,1308.09 910.677,1308.09 910.686,1308.09 910.696,1308.09 910.705,1308.09 910.714,1308.09 910.723,1308.09 910.732,1308.09 910.742,1308.09 910.751,1308.09 910.76,1308.1 910.769,1308.1 910.778,1308.1 910.788,1308.1 910.797,1308.1 910.806,1308.1 910.815,1308.1 910.824,1308.1 910.834,1308.1 910.843,1308.1 910.852,1308.1 910.861,1308.1 910.87,1308.1 910.879,1308.1 910.889,1308.1 910.898,1308.1 910.907,1308.1 910.916,1308.11 910.925,1308.11 910.935,1308.11 910.944,1308.11 910.953,1308.11 910.962,1308.11 910.971,1308.11 910.981,1308.11 910.99,1308.11 910.999,1308.11 911.008,1308.11 911.017,1308.11 911.026,1308.11 911.036,1308.11 911.045,1308.11 911.054,1308.11 911.063,1308.11 911.072,1308.11 911.082,1308.12 911.091,1308.12 911.1,1308.12 911.109,1308.12 911.118,1308.12 911.128,1308.12 911.137,1308.12 911.146,1308.12 911.155,1308.12 911.164,1308.12 911.174,1308.12 911.183,1308.12 911.192,1308.12 911.201,1308.12 911.21,1308.12 911.219,1308.12 911.229,1308.12 911.238,1308.12 911.247,1308.13 911.256,1308.13 911.265,1308.13 911.275,1308.13 911.284,1308.13 911.293,1308.13 911.302,1308.13 911.311,1308.13 911.321,1308.13 911.33,1308.13 911.339,1308.13 911.348,1308.13 911.357,1308.13 911.366,1308.13 911.376,1308.13 911.385,1308.13 911.394,1308.13 911.403,1308.13 911.412,1308.14 911.422,1308.14 911.431,1308.14 911.44,1308.14 911.449,1308.14 911.458,1308.14 911.468,1308.14 911.477,1308.14 911.486,1308.14 911.495,1308.14 911.504,1308.14 911.514,1308.14 911.523,1308.14 911.532,1308.14 911.541,1308.14 911.55,1308.14 911.559,1308.14 911.569,1308.14 911.578,1308.15 911.587,1308.15 911.596,1308.15 911.605,1308.15 911.615,1308.15 911.624,1308.15 911.633,1308.15 911.642,1308.15 911.651,1308.15 911.661,1308.15 911.67,1308.15 911.679,1308.15 911.688,1308.15 911.697,1308.15 911.706,1308.15 911.716,1308.15 911.725,1308.15 911.734,1308.16 911.743,1308.16 911.752,1308.16 911.762,1308.16 911.771,1308.16 911.78,1308.16 911.789,1308.16 911.798,1308.16 911.808,1308.16 911.817,1308.16 911.826,1308.16 911.835,1308.16 911.844,1308.16 911.854,1308.16 911.863,1308.16 911.872,1308.16 911.881,1308.16 911.89,1308.16 911.899,1308.17 911.909,1308.17 911.918,1308.17 911.927,1308.17 911.936,1308.17 911.945,1308.17 911.955,1308.17 911.964,1308.17 911.973,1308.17 911.982,1308.17 911.991,1308.17 912.001,1308.17 912.01,1308.17 912.019,1308.17 912.028,1308.17 912.037,1308.17 912.046,1308.17 912.056,1308.17 912.065,1308.18 912.074,1308.18 912.083,1308.18 912.092,1308.18 912.102,1308.18 912.111,1308.18 912.12,1308.18 912.129,1308.18 912.138,1308.18 912.148,1308.18 912.157,1308.18 912.166,1308.18 912.175,1308.18 912.184,1308.18 912.194,1308.18 912.203,1308.18 912.212,1308.18 912.221,1308.18 912.23,1308.19 912.239,1308.19 912.249,1308.19 912.258,1308.19 912.267,1308.19 912.276,1308.19 912.285,1308.19 912.295,1308.19 912.304,1308.19 912.313,1308.19 912.322,1308.19 912.331,1308.19 912.341,1308.19 912.35,1308.19 912.359,1308.19 912.368,1308.19 912.377,1308.19 912.386,1308.2 912.396,1308.2 912.405,1308.2 912.414,1308.2 912.423,1308.2 912.432,1308.2 912.442,1308.2 912.451,1308.2 912.46,1308.2 912.469,1308.2 912.478,1308.2 912.488,1308.2 912.497,1308.2 912.506,1308.2 912.515,1308.2 912.524,1308.2 912.534,1308.2 912.543,1308.2 912.552,1308.21 912.561,1308.21 912.57,1308.21 912.579,1308.21 912.589,1308.21 912.598,1308.21 912.607,1308.21 912.616,1308.21 912.625,1308.21 912.635,1308.21 912.644,1308.21 912.653,1308.21 912.662,1308.21 912.671,1308.21 912.681,1308.21 912.69,1308.21 912.699,1308.21 912.708,1308.21 912.717,1308.22 912.726,1308.22 912.736,1308.22 912.745,1308.22 912.754,1308.22 912.763,1308.22 912.772,1308.22 912.782,1308.22 912.791,1308.22 912.8,1308.22 912.809,1308.22 912.818,1308.22 912.828,1308.22 912.837,1308.22 912.846,1308.22 912.855,1308.22 912.864,1308.22 912.874,1308.22 912.883,1308.23 912.892,1308.23 912.901,1308.23 912.91,1308.23 912.919,1308.23 912.929,1308.23 912.938,1308.23 912.947,1308.23 912.956,1308.23 912.965,1308.23 912.975,1308.23 912.984,1308.23 912.993,1308.23 913.002,1308.23 913.011,1308.23 913.021,1308.23 913.03,1308.23 913.039,1308.24 913.048,1308.24 913.057,1308.24 913.066,1308.24 913.076,1308.24 913.085,1308.24 913.094,1308.24 913.103,1308.24 913.112,1308.24 913.122,1308.24 913.131,1308.24 913.14,1308.24 913.149,1308.24 913.158,1308.24 913.168,1308.24 913.177,1308.24 913.186,1308.24 913.195,1308.24 913.204,1308.25 913.214,1308.25 913.223,1308.25 913.232,1308.25 913.241,1308.25 913.25,1308.25 913.259,1308.25 913.269,1308.25 913.278,1308.25 913.287,1308.25 913.296,1308.25 913.305,1308.25 913.315,1308.25 913.324,1308.25 913.333,1308.25 913.342,1308.25 913.351,1308.25 913.361,1308.25 913.37,1308.26 913.379,1308.26 913.388,1308.26 913.397,1308.26 913.407,1308.26 913.416,1308.26 913.425,1308.26 913.434,1308.26 913.443,1308.26 913.452,1308.26 913.462,1308.26 913.471,1308.26 913.48,1308.26 913.489,1308.26 913.498,1308.26 913.508,1308.26 913.517,1308.26 913.526,1308.27 913.535,1308.27 913.544,1308.27 913.554,1308.27 913.563,1308.27 913.572,1308.27 913.581,1308.27 913.59,1308.27 913.599,1308.27 913.609,1308.27 913.618,1308.27 913.627,1308.27 913.636,1308.27 913.645,1308.27 913.655,1308.27 913.664,1308.27 913.673,1308.27 913.682,1308.27 913.691,1308.28 913.701,1308.28 913.71,1308.28 913.719,1308.28 913.728,1308.28 913.737,1308.28 913.747,1308.28 913.756,1308.28 913.765,1308.28 913.774,1308.28 913.783,1308.28 913.792,1308.28 913.802,1308.28 913.811,1308.28 913.82,1308.28 913.829,1308.28 913.838,1308.28 913.848,1308.28 913.857,1308.29 913.866,1308.29 913.875,1308.29 913.884,1308.29 913.894,1308.29 913.903,1308.29 913.912,1308.29 913.921,1308.29 913.93,1308.29 913.939,1308.29 913.949,1308.29 913.958,1308.29 913.967,1308.29 913.976,1308.29 913.985,1308.29 913.995,1308.29 914.004,1308.29 914.013,1308.3 914.022,1308.3 914.031,1308.3 914.041,1308.3 914.05,1308.3 914.059,1308.3 914.068,1308.3 914.077,1308.3 914.087,1308.3 914.096,1308.3 914.105,1308.3 914.114,1308.3 914.123,1308.3 914.132,1308.3 914.142,1308.3 914.151,1308.3 914.16,1308.3 914.169,1308.3 914.178,1308.31 914.188,1308.31 914.197,1308.31 914.206,1308.31 914.215,1308.31 914.224,1308.31 914.234,1308.31 914.243,1308.31 914.252,1308.31 914.261,1308.31 914.27,1308.31 914.279,1308.31 914.289,1308.31 914.298,1308.31 914.307,1308.31 914.316,1308.31 914.325,1308.31 914.335,1308.31 914.344,1308.32 914.353,1308.32 914.362,1308.32 914.371,1308.32 914.381,1308.32 914.39,1308.32 914.399,1308.32 914.408,1308.32 914.417,1308.32 914.427,1308.32 914.436,1308.32 914.445,1308.32 914.454,1308.32 914.463,1308.32 914.472,1308.32 914.482,1308.32 914.491,1308.32 914.5,1308.33 914.509,1308.33 914.518,1308.33 914.528,1308.33 914.537,1308.33 914.546,1308.33 914.555,1308.33 914.564,1308.33 914.574,1308.33 914.583,1308.33 914.592,1308.33 914.601,1308.33 914.61,1308.33 914.619,1308.33 914.629,1308.33 914.638,1308.33 914.647,1308.33 914.656,1308.33 914.665,1308.34 914.675,1308.34 914.684,1308.34 914.693,1308.34 914.702,1308.34 914.711,1308.34 914.721,1308.34 914.73,1308.34 914.739,1308.34 914.748,1308.34 914.757,1308.34 914.767,1308.34 914.776,1308.34 914.785,1308.34 914.794,1308.34 914.803,1308.34 914.812,1308.34 914.822,1308.34 914.831,1308.35 914.84,1308.35 914.849,1308.35 914.858,1308.35 914.868,1308.35 914.877,1308.35 914.886,1308.35 914.895,1308.35 914.904,1308.35 914.914,1308.35 914.923,1308.35 914.932,1308.35 914.941,1308.35 914.95,1308.35 914.959,1308.35 914.969,1308.35 914.978,1308.35 914.987,1308.36 914.996,1308.36 915.005,1308.36 915.015,1308.36 915.024,1308.36 915.033,1308.36 915.042,1308.36 915.051,1308.36 915.061,1308.36 915.07,1308.36 915.079,1308.36 915.088,1308.36 915.097,1308.36 915.107,1308.36 915.116,1308.36 915.125,1308.36 915.134,1308.36 915.143,1308.36 915.152,1308.37 915.162,1308.37 915.171,1308.37 915.18,1308.37 915.189,1308.37 915.198,1308.37 915.208,1308.37 915.217,1308.37 915.226,1308.37 915.235,1308.37 915.244,1308.37 915.254,1308.37 915.263,1308.37 915.272,1308.37 915.281,1308.37 915.29,1308.37 915.299,1308.37 915.309,1308.37 915.318,1308.38 915.327,1308.38 915.336,1308.38 915.345,1308.38 915.355,1308.38 915.364,1308.38 915.373,1308.38 915.382,1308.38 915.391,1308.38 915.401,1308.38 915.41,1308.38 915.419,1308.38 915.428,1308.38 915.437,1308.38 915.447,1308.38 915.456,1308.38 915.465,1308.38 915.474,1308.39 915.483,1308.39 915.492,1308.39 915.502,1308.39 915.511,1308.39 915.52,1308.39 915.529,1308.39 915.538,1308.39 915.548,1308.39 915.557,1308.39 915.566,1308.39 915.575,1308.39 915.584,1308.39 915.594,1308.39 915.603,1308.39 915.612,1308.39 915.621,1308.39 915.63,1308.39 915.64,1308.4 915.649,1308.4 915.658,1308.4 915.667,1308.4 915.676,1308.4 915.685,1308.4 915.695,1308.4 915.704,1308.4 915.713,1308.4 915.722,1308.4 915.731,1308.4 915.741,1308.4 915.75,1308.4 915.759,1308.4 915.768,1308.4 915.777,1308.4 915.787,1308.4 915.796,1308.41 915.805,1308.41 915.814,1308.41 915.823,1308.41 915.832,1308.41 915.842,1308.41 915.851,1308.41 915.86,1308.41 915.869,1308.41 915.878,1308.41 915.888,1308.41 915.897,1308.41 915.906,1308.41 915.915,1308.41 915.924,1308.41 915.934,1308.41 915.943,1308.41 915.952,1308.41 915.961,1308.42 915.97,1308.42 915.98,1308.42 915.989,1308.42 915.998,1308.42 916.007,1308.42 916.016,1308.42 916.025,1308.42 916.035,1308.42 916.044,1308.42 916.053,1308.42 916.062,1308.42 916.071,1308.42 916.081,1308.42 916.09,1308.42 916.099,1308.42 916.108,1308.42 916.117,1308.43 916.127,1308.43 916.136,1308.43 916.145,1308.43 916.154,1308.43 916.163,1308.43 916.172,1308.43 916.182,1308.43 916.191,1308.43 916.2,1308.43 916.209,1308.43 916.218,1308.43 916.228,1308.43 916.237,1308.43 916.246,1308.43 916.255,1308.43 916.264,1308.43 916.274,1308.43 916.283,1308.44 916.292,1308.44 916.301,1308.44 916.31,1308.44 916.32,1308.44 916.329,1308.44 916.338,1308.44 916.347,1308.44 916.356,1308.44 916.365,1308.44 916.375,1308.44 916.384,1308.44 916.393,1308.44 916.402,1308.44 916.411,1308.44 916.421,1308.44 916.43,1308.44 916.439,1308.44 916.448,1308.45 916.457,1308.45 916.467,1308.45 916.476,1308.45 916.485,1308.45 916.494,1308.45 916.503,1308.45 916.512,1308.45 916.522,1308.45 916.531,1308.45 916.54,1308.45 916.549,1308.45 916.558,1308.45 916.568,1308.45 916.577,1308.45 916.586,1308.45 916.595,1308.45 916.604,1308.46 916.614,1308.46 916.623,1308.46 916.632,1308.46 916.641,1308.46 916.65,1308.46 916.66,1308.46 916.669,1308.46 916.678,1308.46 916.687,1308.46 916.696,1308.46 916.705,1308.46 916.715,1308.46 916.724,1308.46 916.733,1308.46 916.742,1308.46 916.751,1308.46 916.761,1308.46 916.77,1308.47 916.779,1308.47 916.788,1308.47 916.797,1308.47 916.807,1308.47 916.816,1308.47 916.825,1308.47 916.834,1308.47 916.843,1308.47 916.852,1308.47 916.862,1308.47 916.871,1308.47 916.88,1308.47 916.889,1308.47 916.898,1308.47 916.908,1308.47 916.917,1308.47 916.926,1308.48 916.935,1308.48 916.944,1308.48 916.954,1308.48 916.963,1308.48 916.972,1308.48 916.981,1308.48 916.99,1308.48 917,1308.48 917.009,1308.48 917.018,1308.48 917.027,1308.48 917.036,1308.48 917.045,1308.48 917.055,1308.48 917.064,1308.48 917.073,1308.48 917.082,1308.48 917.091,1308.49 917.101,1308.49 917.11,1308.49 917.119,1308.49 917.128,1308.49 917.137,1308.49 917.147,1308.49 917.156,1308.49 917.165,1308.49 917.174,1308.49 917.183,1308.49 917.192,1308.49 917.202,1308.49 917.211,1308.49 917.22,1308.49 917.229,1308.49 917.238,1308.49 917.248,1308.5 917.257,1308.5 917.266,1308.5 917.275,1308.5 917.284,1308.5 917.294,1308.5 917.303,1308.5 917.312,1308.5 917.321,1308.5 917.33,1308.5 917.34,1308.5 917.349,1308.5 917.358,1308.5 917.367,1308.5 917.376,1308.5 917.385,1308.5 917.395,1308.5 917.404,1308.5 917.413,1308.51 917.422,1308.51 917.431,1308.51 917.441,1308.51 917.45,1308.51 917.459,1308.51 917.468,1308.51 917.477,1308.51 917.487,1308.51 917.496,1308.51 917.505,1308.51 917.514,1308.51 917.523,1308.51 917.532,1308.51 917.542,1308.51 917.551,1308.51 917.56,1308.51 917.569,1308.52 917.578,1308.52 917.588,1308.52 917.597,1308.52 917.606,1308.52 917.615,1308.52 917.624,1308.52 917.634,1308.52 917.643,1308.52 917.652,1308.52 917.661,1308.52 917.67,1308.52 917.68,1308.52 917.689,1308.52 917.698,1308.52 917.707,1308.52 917.716,1308.52 917.725,1308.52 917.735,1308.53 917.744,1308.53 917.753,1308.53 917.762,1308.53 917.771,1308.53 917.781,1308.53 917.79,1308.53 917.799,1308.53 917.808,1308.53 917.817,1308.53 917.827,1308.53 917.836,1308.53 917.845,1308.53 917.854,1308.53 917.863,1308.53 917.872,1308.53 917.882,1308.53 917.891,1308.54 917.9,1308.54 917.909,1308.54 917.918,1308.54 917.928,1308.54 917.937,1308.54 917.946,1308.54 917.955,1308.54 917.964,1308.54 917.974,1308.54 917.983,1308.54 917.992,1308.54 918.001,1308.54 918.01,1308.54 918.02,1308.54 918.029,1308.54 918.038,1308.54 918.047,1308.54 918.056,1308.55 918.065,1308.55 918.075,1308.55 918.084,1308.55 918.093,1308.55 918.102,1308.55 918.111,1308.55 918.121,1308.55 918.13,1308.55 918.139,1308.55 918.148,1308.55 918.157,1308.55 918.167,1308.55 918.176,1308.55 918.185,1308.55 918.194,1308.55 918.203,1308.55 918.213,1308.56 918.222,1308.56 918.231,1308.56 918.24,1308.56 918.249,1308.56 918.258,1308.56 918.268,1308.56 918.277,1308.56 918.286,1308.56 918.295,1308.56 918.304,1308.56 918.314,1308.56 918.323,1308.56 918.332,1308.56 918.341,1308.56 918.35,1308.56 918.36,1308.56 918.369,1308.56 918.378,1308.57 918.387,1308.57 918.396,1308.57 918.405,1308.57 918.415,1308.57 918.424,1308.57 918.433,1308.57 918.442,1308.57 918.451,1308.57 918.461,1308.57 918.47,1308.57 918.479,1308.57 918.488,1308.57 918.497,1308.57 918.507,1308.57 918.516,1308.57 918.525,1308.57 918.534,1308.58 918.543,1308.58 918.553,1308.58 918.562,1308.58 918.571,1308.58 918.58,1308.58 918.589,1308.58 918.598,1308.58 918.608,1308.58 918.617,1308.58 918.626,1308.58 918.635,1308.58 918.644,1308.58 918.654,1308.58 918.663,1308.58 918.672,1308.58 918.681,1308.58 918.69,1308.58 918.7,1308.59 918.709,1308.59 918.718,1308.59 918.727,1308.59 918.736,1308.59 918.745,1308.59 918.755,1308.59 918.764,1308.59 918.773,1308.59 918.782,1308.59 918.791,1308.59 918.801,1308.59 918.81,1308.59 918.819,1308.59 918.828,1308.59 918.837,1308.59 918.847,1308.59 918.856,1308.6 918.865,1308.6 918.874,1308.6 918.883,1308.6 918.893,1308.6 918.902,1308.6 918.911,1308.6 918.92,1308.6 918.929,1308.6 918.938,1308.6 918.948,1308.6 918.957,1308.6 918.966,1308.6 918.975,1308.6 918.984,1308.6 918.994,1308.6 919.003,1308.6 919.012,1308.6 919.021,1308.61 919.03,1308.61 919.04,1308.61 919.049,1308.61 919.058,1308.61 919.067,1308.61 919.076,1308.61 919.085,1308.61 919.095,1308.61 919.104,1308.61 919.113,1308.61 919.122,1308.61 919.131,1308.61 919.141,1308.61 919.15,1308.61 919.159,1308.61 919.168,1308.61 919.177,1308.62 919.187,1308.62 919.196,1308.62 919.205,1308.62 919.214,1308.62 919.223,1308.62 919.233,1308.62 919.242,1308.62 919.251,1308.62 919.26,1308.62 919.269,1308.62 919.278,1308.62 919.288,1308.62 919.297,1308.62 919.306,1308.62 919.315,1308.62 919.324,1308.62 919.334,1308.63 919.343,1308.63 919.352,1308.63 919.361,1308.63 919.37,1308.63 919.38,1308.63 919.389,1308.63 919.398,1308.63 919.407,1308.63 919.416,1308.63 919.425,1308.63 919.435,1308.63 919.444,1308.63 919.453,1308.63 919.462,1308.63 919.471,1308.63 919.481,1308.63 919.49,1308.63 919.499,1308.64 919.508,1308.64 919.517,1308.64 919.527,1308.64 919.536,1308.64 919.545,1308.64 919.554,1308.64 919.563,1308.64 919.573,1308.64 919.582,1308.64 919.591,1308.64 919.6,1308.64 919.609,1308.64 919.618,1308.64 919.628,1308.64 919.637,1308.64 919.646,1308.64 919.655,1308.65 919.664,1308.65 919.674,1308.65 919.683,1308.65 919.692,1308.65 919.701,1308.65 919.71,1308.65 919.72,1308.65 919.729,1308.65 919.738,1308.65 919.747,1308.65 919.756,1308.65 919.765,1308.65 919.775,1308.65 919.784,1308.65 919.793,1308.65 919.802,1308.65 919.811,1308.65 919.821,1308.66 919.83,1308.66 919.839,1308.66 919.848,1308.66 919.857,1308.66 919.867,1308.66 919.876,1308.66 919.885,1308.66 919.894,1308.66 919.903,1308.66 919.913,1308.66 919.922,1308.66 919.931,1308.66 919.94,1308.66 919.949,1308.66 919.958,1308.66 919.968,1308.66 919.977,1308.67 919.986,1308.67 919.995,1308.67 920.004,1308.67 920.014,1308.67 920.023,1308.67 920.032,1308.67 920.041,1308.67 920.05,1308.67 920.06,1308.67 920.069,1308.67 920.078,1308.67 920.087,1308.67 920.096,1308.67 920.105,1308.67 920.115,1308.67 920.124,1308.67 920.133,1308.67 920.142,1308.68 920.151,1308.68 920.161,1308.68 920.17,1308.68 920.179,1308.68 920.188,1308.68 920.197,1308.68 920.207,1308.68 920.216,1308.68 920.225,1308.68 920.234,1308.68 920.243,1308.68 920.253,1308.68 920.262,1308.68 920.271,1308.68 920.28,1308.68 920.289,1308.68 920.298,1308.69 920.308,1308.69 920.317,1308.69 920.326,1308.69 920.335,1308.69 920.344,1308.69 920.354,1308.69 920.363,1308.69 920.372,1308.69 920.381,1308.69 920.39,1308.69 920.4,1308.69 920.409,1308.69 920.418,1308.69 920.427,1308.69 920.436,1308.69 920.445,1308.69 920.455,1308.7 920.464,1308.7 920.473,1308.7 920.482,1308.7 920.491,1308.7 920.501,1308.7 920.51,1308.7 920.519,1308.7 920.528,1308.7 920.537,1308.7 920.547,1308.7 920.556,1308.7 920.565,1308.7 920.574,1308.7 920.583,1308.7 920.593,1308.7 920.602,1308.7 920.611,1308.7 920.62,1308.71 920.629,1308.71 920.638,1308.71 920.648,1308.71 920.657,1308.71 920.666,1308.71 920.675,1308.71 920.684,1308.71 920.694,1308.71 920.703,1308.71 920.712,1308.71 920.721,1308.71 920.73,1308.71 920.74,1308.71 920.749,1308.71 920.758,1308.71 920.767,1308.71 920.776,1308.72 920.786,1308.72 920.795,1308.72 920.804,1308.72 920.813,1308.72 920.822,1308.72 920.831,1308.72 920.841,1308.72 920.85,1308.72 920.859,1308.72 920.868,1308.72 920.877,1308.72 920.887,1308.72 920.896,1308.72 920.905,1308.72 920.914,1308.72 920.923,1308.72 920.933,1308.73 920.942,1308.73 920.951,1308.73 920.96,1308.73 920.969,1308.73 920.978,1308.73 920.988,1308.73 920.997,1308.73 921.006,1308.73 921.015,1308.73 921.024,1308.73 921.034,1308.73 921.043,1308.73 921.052,1308.73 921.061,1308.73 921.07,1308.73 921.08,1308.73 921.089,1308.73 921.098,1308.74 921.107,1308.74 921.116,1308.74 921.126,1308.74 921.135,1308.74 921.144,1308.74 921.153,1308.74 921.162,1308.74 921.171,1308.74 921.181,1308.74 921.19,1308.74 921.199,1308.74 921.208,1308.74 921.217,1308.74 921.227,1308.74 921.236,1308.74 921.245,1308.74 921.254,1308.75 921.263,1308.75 921.273,1308.75 921.282,1308.75 921.291,1308.75 921.3,1308.75 921.309,1308.75 921.318,1308.75 921.328,1308.75 921.337,1308.75 921.346,1308.75 921.355,1308.75 921.364,1308.75 921.374,1308.75 921.383,1308.75 921.392,1308.75 921.401,1308.75 921.41,1308.75 921.42,1308.76 921.429,1308.76 921.438,1308.76 921.447,1308.76 921.456,1308.76 921.466,1308.76 921.475,1308.76 921.484,1308.76 921.493,1308.76 921.502,1308.76 921.511,1308.76 921.521,1308.76 921.53,1308.76 921.539,1308.76 921.548,1308.76 921.557,1308.76 921.567,1308.76 921.576,1308.77 921.585,1308.77 921.594,1308.77 921.603,1308.77 921.613,1308.77 921.622,1308.77 921.631,1308.77 921.64,1308.77 921.649,1308.77 921.658,1308.77 921.668,1308.77 921.677,1308.77 921.686,1308.77 921.695,1308.77 921.704,1308.77 921.714,1308.77 921.723,1308.77 921.732,1308.78 921.741,1308.78 921.75,1308.78 921.76,1308.78 921.769,1308.78 921.778,1308.78 921.787,1308.78 921.796,1308.78 921.806,1308.78 921.815,1308.78 921.824,1308.78 921.833,1308.78 921.842,1308.78 921.851,1308.78 921.861,1308.78 921.87,1308.78 921.879,1308.78 921.888,1308.78 921.897,1308.79 921.907,1308.79 921.916,1308.79 921.925,1308.79 921.934,1308.79 921.943,1308.79 921.953,1308.79 921.962,1308.79 921.971,1308.79 921.98,1308.79 921.989,1308.79 921.998,1308.79 922.008,1308.79 922.017,1308.79 922.026,1308.79 922.035,1308.79 922.044,1308.79 922.054,1308.8 922.063,1308.8 922.072,1308.8 922.081,1308.8 922.09,1308.8 922.1,1308.8 922.109,1308.8 922.118,1308.8 922.127,1308.8 922.136,1308.8 922.146,1308.8 922.155,1308.8 922.164,1308.8 922.173,1308.8 922.182,1308.8 922.191,1308.8 922.201,1308.8 922.21,1308.81 922.219,1308.81 922.228,1308.81 922.237,1308.81 922.247,1308.81 922.256,1308.81 922.265,1308.81 922.274,1308.81 922.283,1308.81 922.293,1308.81 922.302,1308.81 922.311,1308.81 922.32,1308.81 922.329,1308.81 922.338,1308.81 922.348,1308.81 922.357,1308.81 922.366,1308.81 922.375,1308.82 922.384,1308.82 922.394,1308.82 922.403,1308.82 922.412,1308.82 922.421,1308.82 922.43,1308.82 922.44,1308.82 922.449,1308.82 922.458,1308.82 922.467,1308.82 922.476,1308.82 922.486,1308.82 922.495,1308.82 922.504,1308.82 922.513,1308.82 922.522,1308.82 922.531,1308.83 922.541,1308.83 922.55,1308.83 922.559,1308.83 922.568,1308.83 922.577,1308.83 922.587,1308.83 922.596,1308.83 922.605,1308.83 922.614,1308.83 922.623,1308.83 922.633,1308.83 922.642,1308.83 922.651,1308.83 922.66,1308.83 922.669,1308.83 922.678,1308.83 922.688,1308.84 922.697,1308.84 922.706,1308.84 922.715,1308.84 922.724,1308.84 922.734,1308.84 922.743,1308.84 922.752,1308.84 922.761,1308.84 922.77,1308.84 922.78,1308.84 922.789,1308.84 922.798,1308.84 922.807,1308.84 922.816,1308.84 922.826,1308.84 922.835,1308.84 922.844,1308.85 922.853,1308.85 922.862,1308.85 922.871,1308.85 922.881,1308.85 922.89,1308.85 922.899,1308.85 922.908,1308.85 922.917,1308.85 922.927,1308.85 922.936,1308.85 922.945,1308.85 922.954,1308.85 922.963,1308.85 922.973,1308.85 922.982,1308.85 922.991,1308.85 923,1308.85 923.009,1308.86 923.019,1308.86 923.028,1308.86 923.037,1308.86 923.046,1308.86 923.055,1308.86 923.064,1308.86 923.074,1308.86 923.083,1308.86 923.092,1308.86 923.101,1308.86 923.11,1308.86 923.12,1308.86 923.129,1308.86 923.138,1308.86 923.147,1308.86 923.156,1308.86 923.166,1308.87 923.175,1308.87 923.184,1308.87 923.193,1308.87 923.202,1308.87 923.211,1308.87 923.221,1308.87 923.23,1308.87 923.239,1308.87 923.248,1308.87 923.257,1308.87 923.267,1308.87 923.276,1308.87 923.285,1308.87 923.294,1308.87 923.303,1308.87 923.313,1308.87 923.322,1308.88 923.331,1308.88 923.34,1308.88 923.349,1308.88 923.359,1308.88 923.368,1308.88 923.377,1308.88 923.386,1308.88 923.395,1308.88 923.404,1308.88 923.414,1308.88 923.423,1308.88 923.432,1308.88 923.441,1308.88 923.45,1308.88 923.46,1308.88 923.469,1308.88 923.478,1308.88 923.487,1308.89 923.496,1308.89 923.506,1308.89 923.515,1308.89 923.524,1308.89 923.533,1308.89 923.542,1308.89 923.551,1308.89 923.561,1308.89 923.57,1308.89 923.579,1308.89 923.588,1308.89 923.597,1308.89 923.607,1308.89 923.616,1308.89 923.625,1308.89 923.634,1308.89 923.643,1308.9 923.653,1308.9 923.662,1308.9 923.671,1308.9 923.68,1308.9 923.689,1308.9 923.699,1308.9 923.708,1308.9 923.717,1308.9 923.726,1308.9 923.735,1308.9 923.744,1308.9 923.754,1308.9 923.763,1308.9 923.772,1308.9 923.781,1308.9 923.79,1308.9 923.8,1308.91 923.809,1308.91 923.818,1308.91 923.827,1308.91 923.836,1308.91 923.846,1308.91 923.855,1308.91 923.864,1308.91 923.873,1308.91 923.882,1308.91 923.891,1308.91 923.901,1308.91 923.91,1308.91 923.919,1308.91 923.928,1308.91 923.937,1308.91 923.947,1308.91 923.956,1308.92 923.965,1308.92 923.974,1308.92 923.983,1308.92 923.993,1308.92 924.002,1308.92 924.011,1308.92 924.02,1308.92 924.029,1308.92 924.039,1308.92 924.048,1308.92 924.057,1308.92 924.066,1308.92 924.075,1308.92 924.084,1308.92 924.094,1308.92 924.103,1308.92 924.112,1308.92 924.121,1308.93 924.13,1308.93 924.14,1308.93 924.149,1308.93 924.158,1308.93 924.167,1308.93 924.176,1308.93 924.186,1308.93 924.195,1308.93 924.204,1308.93 924.213,1308.93 924.222,1308.93 924.231,1308.93 924.241,1308.93 924.25,1308.93 924.259,1308.93 924.268,1308.93 924.277,1308.94 924.287,1308.94 924.296,1308.94 924.305,1308.94 924.314,1308.94 924.323,1308.94 924.333,1308.94 924.342,1308.94 924.351,1308.94 924.36,1308.94 924.369,1308.94 924.379,1308.94 924.388,1308.94 924.397,1308.94 924.406,1308.94 924.415,1308.94 924.424,1308.94 924.434,1308.95 924.443,1308.95 924.452,1308.95 924.461,1308.95 924.47,1308.95 924.48,1308.95 924.489,1308.95 924.498,1308.95 924.507,1308.95 924.516,1308.95 924.526,1308.95 924.535,1308.95 924.544,1308.95 924.553,1308.95 924.562,1308.95 924.571,1308.95 924.581,1308.95 924.59,1308.96 924.599,1308.96 924.608,1308.96 924.617,1308.96 924.627,1308.96 924.636,1308.96 924.645,1308.96 924.654,1308.96 924.663,1308.96 924.673,1308.96 924.682,1308.96 924.691,1308.96 924.7,1308.96 924.709,1308.96 924.719,1308.96 924.728,1308.96 924.737,1308.96 924.746,1308.96 924.755,1308.97 924.764,1308.97 924.774,1308.97 924.783,1308.97 924.792,1308.97 924.801,1308.97 924.81,1308.97 924.82,1308.97 924.829,1308.97 924.838,1308.97 924.847,1308.97 924.856,1308.97 924.866,1308.97 924.875,1308.97 924.884,1308.97 924.893,1308.97 924.902,1308.97 924.911,1308.98 924.921,1308.98 924.93,1308.98 924.939,1308.98 924.948,1308.98 924.957,1308.98 924.967,1308.98 924.976,1308.98 924.985,1308.98 924.994,1308.98 925.003,1308.98 925.013,1308.98 925.022,1308.98 925.031,1308.98 925.04,1308.98 925.049,1308.98 925.059,1308.98 925.068,1308.99 925.077,1308.99 925.086,1308.99 925.095,1308.99 925.104,1308.99 925.114,1308.99 925.123,1308.99 925.132,1308.99 925.141,1308.99 925.15,1308.99 925.16,1308.99 925.169,1308.99 925.178,1308.99 925.187,1308.99 925.196,1308.99 925.206,1308.99 925.215,1308.99 925.224,1309 925.233,1309 925.242,1309 925.251,1309 925.261,1309 925.27,1309 925.279,1309 925.288,1309 925.297,1309 925.307,1309 925.316,1309 925.325,1309 925.334,1309 925.343,1309 925.353,1309 925.362,1309 925.371,1309 925.38,1309.01 925.389,1309.01 925.399,1309.01 925.408,1309.01 925.417,1309.01 925.426,1309.01 925.435,1309.01 925.444,1309.01 925.454,1309.01 925.463,1309.01 925.472,1309.01 925.481,1309.01 925.49,1309.01 925.5,1309.01 925.509,1309.01 925.518,1309.01 925.527,1309.01 925.536,1309.01 925.546,1309.02 925.555,1309.02 925.564,1309.02 925.573,1309.02 925.582,1309.02 925.592,1309.02 925.601,1309.02 925.61,1309.02 925.619,1309.02 925.628,1309.02 925.637,1309.02 925.647,1309.02 925.656,1309.02 925.665,1309.02 925.674,1309.02 925.683,1309.02 925.693,1309.02 925.702,1309.03 925.711,1309.03 925.72,1309.03 925.729,1309.03 925.739,1309.03 925.748,1309.03 925.757,1309.03 925.766,1309.03 925.775,1309.03 925.784,1309.03 925.794,1309.03 925.803,1309.03 925.812,1309.03 925.821,1309.03 925.83,1309.03 925.84,1309.03 925.849,1309.03 925.858,1309.04 925.867,1309.04 925.876,1309.04 925.886,1309.04 925.895,1309.04 925.904,1309.04 925.913,1309.04 925.922,1309.04 925.932,1309.04 925.941,1309.04 925.95,1309.04 925.959,1309.04 925.968,1309.04 925.977,1309.04 925.987,1309.04 925.996,1309.04 926.005,1309.04 926.014,1309.05 926.023,1309.05 926.033,1309.05 926.042,1309.05 926.051,1309.05 926.06,1309.05 926.069,1309.05 926.079,1309.05 926.088,1309.05 926.097,1309.05 926.106,1309.05 926.115,1309.05 926.124,1309.05 926.134,1309.05 926.143,1309.05 926.152,1309.05 926.161,1309.05 926.17,1309.06 926.18,1309.06 926.189,1309.06 926.198,1309.06 926.207,1309.06 926.216,1309.06 926.226,1309.06 926.235,1309.06 926.244,1309.06 926.253,1309.06 926.262,1309.06 926.272,1309.06 926.281,1309.06 926.29,1309.06 926.299,1309.06 926.308,1309.06 926.317,1309.06 926.327,1309.06 926.336,1309.07 926.345,1309.07 926.354,1309.07 926.363,1309.07 926.373,1309.07 926.382,1309.07 926.391,1309.07 926.4,1309.07 926.409,1309.07 926.419,1309.07 926.428,1309.07 926.437,1309.07 926.446,1309.07 926.455,1309.07 926.464,1309.07 926.474,1309.07 926.483,1309.07 926.492,1309.08 926.501,1309.08 926.51,1309.08 926.52,1309.08 926.529,1309.08 926.538,1309.08 926.547,1309.08 926.556,1309.08 926.566,1309.08 926.575,1309.08 926.584,1309.08 926.593,1309.08 926.602,1309.08 926.612,1309.08 926.621,1309.08 926.63,1309.08 926.639,1309.08 926.648,1309.09 926.657,1309.09 926.667,1309.09 926.676,1309.09 926.685,1309.09 926.694,1309.09 926.703,1309.09 926.713,1309.09 926.722,1309.09 926.731,1309.09 926.74,1309.09 926.749,1309.09 926.759,1309.09 926.768,1309.09 926.777,1309.09 926.786,1309.09 926.795,1309.09 926.804,1309.1 926.814,1309.1 926.823,1309.1 926.832,1309.1 926.841,1309.1 926.85,1309.1 926.86,1309.1 926.869,1309.1 926.878,1309.1 926.887,1309.1 926.896,1309.1 926.906,1309.1 926.915,1309.1 926.924,1309.1 926.933,1309.1 926.942,1309.1 926.952,1309.1 926.961,1309.11 926.97,1309.11 926.979,1309.11 926.988,1309.11 926.997,1309.11 927.007,1309.11 927.016,1309.11 927.025,1309.11 927.034,1309.11 927.043,1309.11 927.053,1309.11 927.062,1309.11 927.071,1309.11 927.08,1309.11 927.089,1309.11 927.099,1309.11 927.108,1309.11 927.117,1309.12 927.126,1309.12 927.135,1309.12 927.144,1309.12 927.154,1309.12 927.163,1309.12 927.172,1309.12 927.181,1309.12 927.19,1309.12 927.2,1309.12 927.209,1309.12 927.218,1309.12 927.227,1309.12 927.236,1309.12 927.246,1309.12 927.255,1309.12 927.264,1309.12 927.273,1309.12 927.282,1309.13 927.292,1309.13 927.301,1309.13 927.31,1309.13 927.319,1309.13 927.328,1309.13 927.337,1309.13 927.347,1309.13 927.356,1309.13 927.365,1309.13 927.374,1309.13 927.383,1309.13 927.393,1309.13 927.402,1309.13 927.411,1309.13 927.42,1309.13 927.429,1309.13 927.439,1309.14 927.448,1309.14 927.457,1309.14 927.466,1309.14 927.475,1309.14 927.484,1309.14 927.494,1309.14 927.503,1309.14 927.512,1309.14 927.521,1309.14 927.53,1309.14 927.54,1309.14 927.549,1309.14 927.558,1309.14 927.567,1309.14 927.576,1309.14 927.586,1309.14 927.595,1309.15 927.604,1309.15 927.613,1309.15 927.622,1309.15 927.632,1309.15 927.641,1309.15 927.65,1309.15 927.659,1309.15 927.668,1309.15 927.677,1309.15 927.687,1309.15 927.696,1309.15 927.705,1309.15 927.714,1309.15 927.723,1309.15 927.733,1309.15 927.742,1309.15 927.751,1309.16 927.76,1309.16 927.769,1309.16 927.779,1309.16 927.788,1309.16 927.797,1309.16 927.806,1309.16 927.815,1309.16 927.824,1309.16 927.834,1309.16 927.843,1309.16 927.852,1309.16 927.861,1309.16 927.87,1309.16 927.88,1309.16 927.889,1309.16 927.898,1309.16 927.907,1309.17 927.916,1309.17 927.926,1309.17 927.935,1309.17 927.944,1309.17 927.953,1309.17 927.962,1309.17 927.972,1309.17 927.981,1309.17 927.99,1309.17 927.999,1309.17 928.008,1309.17 928.017,1309.17 928.027,1309.17 928.036,1309.17 928.045,1309.17 928.054,1309.17 928.063,1309.18 928.073,1309.18 928.082,1309.18 928.091,1309.18 928.1,1309.18 928.109,1309.18 928.119,1309.18 928.128,1309.18 928.137,1309.18 928.146,1309.18 928.155,1309.18 928.165,1309.18 928.174,1309.18 928.183,1309.18 928.192,1309.18 928.201,1309.18 928.21,1309.18 928.22,1309.19 928.229,1309.19 928.238,1309.19 928.247,1309.19 928.256,1309.19 928.266,1309.19 928.275,1309.19 928.284,1309.19 928.293,1309.19 928.302,1309.19 928.312,1309.19 928.321,1309.19 928.33,1309.19 928.339,1309.19 928.348,1309.19 928.357,1309.19 928.367,1309.19 928.376,1309.2 928.385,1309.2 928.394,1309.2 928.403,1309.2 928.413,1309.2 928.422,1309.2 928.431,1309.2 928.44,1309.2 928.449,1309.2 928.459,1309.2 928.468,1309.2 928.477,1309.2 928.486,1309.2 928.495,1309.2 928.505,1309.2 928.514,1309.2 928.523,1309.2 928.532,1309.21 928.541,1309.21 928.55,1309.21 928.56,1309.21 928.569,1309.21 928.578,1309.21 928.587,1309.21 928.596,1309.21 928.606,1309.21 928.615,1309.21 928.624,1309.21 928.633,1309.21 928.642,1309.21 928.652,1309.21 928.661,1309.21 928.67,1309.21 928.679,1309.21 928.688,1309.21 928.697,1309.22 928.707,1309.22 928.716,1309.22 928.725,1309.22 928.734,1309.22 928.743,1309.22 928.753,1309.22 928.762,1309.22 928.771,1309.22 928.78,1309.22 928.789,1309.22 928.799,1309.22 928.808,1309.22 928.817,1309.22 928.826,1309.22 928.835,1309.22 928.845,1309.22 928.854,1309.23 928.863,1309.23 928.872,1309.23 928.881,1309.23 928.89,1309.23 928.9,1309.23 928.909,1309.23 928.918,1309.23 928.927,1309.23 928.936,1309.23 928.946,1309.23 928.955,1309.23 928.964,1309.23 928.973,1309.23 928.982,1309.23 928.992,1309.23 929.001,1309.23 929.01,1309.24 929.019,1309.24 929.028,1309.24 929.037,1309.24 929.047,1309.24 929.056,1309.24 929.065,1309.24 929.074,1309.24 929.083,1309.24 929.093,1309.24 929.102,1309.24 929.111,1309.24 929.12,1309.24 929.129,1309.24 929.139,1309.24 929.148,1309.24 929.157,1309.24 929.166,1309.25 929.175,1309.25 929.185,1309.25 929.194,1309.25 929.203,1309.25 929.212,1309.25 929.221,1309.25 929.23,1309.25 929.24,1309.25 929.249,1309.25 929.258,1309.25 929.267,1309.25 929.276,1309.25 929.286,1309.25 929.295,1309.25 929.304,1309.25 929.313,1309.25 929.322,1309.26 929.332,1309.26 929.341,1309.26 929.35,1309.26 929.359,1309.26 929.368,1309.26 929.377,1309.26 929.387,1309.26 929.396,1309.26 929.405,1309.26 929.414,1309.26 929.423,1309.26 929.433,1309.26 929.442,1309.26 929.451,1309.26 929.46,1309.26 929.469,1309.26 929.479,1309.27 929.488,1309.27 929.497,1309.27 929.506,1309.27 929.515,1309.27 929.525,1309.27 929.534,1309.27 929.543,1309.27 929.552,1309.27 929.561,1309.27 929.57,1309.27 929.58,1309.27 929.589,1309.27 929.598,1309.27 929.607,1309.27 929.616,1309.27 929.626,1309.27 929.635,1309.28 929.644,1309.28 929.653,1309.28 929.662,1309.28 929.672,1309.28 929.681,1309.28 929.69,1309.28 929.699,1309.28 929.708,1309.28 929.717,1309.28 929.727,1309.28 929.736,1309.28 929.745,1309.28 929.754,1309.28 929.763,1309.28 929.773,1309.28 929.782,1309.28 929.791,1309.29 929.8,1309.29 929.809,1309.29 929.819,1309.29 929.828,1309.29 929.837,1309.29 929.846,1309.29 929.855,1309.29 929.865,1309.29 929.874,1309.29 929.883,1309.29 929.892,1309.29 929.901,1309.29 929.91,1309.29 929.92,1309.29 929.929,1309.29 929.938,1309.29 929.947,1309.3 929.956,1309.3 929.966,1309.3 929.975,1309.3 929.984,1309.3 929.993,1309.3 930.002,1309.3 930.012,1309.3 930.021,1309.3 930.03,1309.3 930.039,1309.3 930.048,1309.3 930.057,1309.3 930.067,1309.3 930.076,1309.3 930.085,1309.3 930.094,1309.3 930.103,1309.31 930.113,1309.31 930.122,1309.31 930.131,1309.31 930.14,1309.31 930.149,1309.31 930.159,1309.31 930.168,1309.31 930.177,1309.31 930.186,1309.31 930.195,1309.31 930.205,1309.31 930.214,1309.31 930.223,1309.31 930.232,1309.31 930.241,1309.31 930.25,1309.31 930.26,1309.32 930.269,1309.32 930.278,1309.32 930.287,1309.32 930.296,1309.32 930.306,1309.32 930.315,1309.32 930.324,1309.32 930.333,1309.32 930.342,1309.32 930.352,1309.32 930.361,1309.32 930.37,1309.32 930.379,1309.32 930.388,1309.32 930.397,1309.32 930.407,1309.32 930.416,1309.33 930.425,1309.33 930.434,1309.33 930.443,1309.33 930.453,1309.33 930.462,1309.33 930.471,1309.33 930.48,1309.33 930.489,1309.33 930.499,1309.33 930.508,1309.33 930.517,1309.33 930.526,1309.33 930.535,1309.33 930.545,1309.33 930.554,1309.33 930.563,1309.33 930.572,1309.34 930.581,1309.34 930.59,1309.34 930.6,1309.34 930.609,1309.34 930.618,1309.34 930.627,1309.34 930.636,1309.34 930.646,1309.34 930.655,1309.34 930.664,1309.34 930.673,1309.34 930.682,1309.34 930.692,1309.34 930.701,1309.34 930.71,1309.34 930.719,1309.34 930.728,1309.35 930.738,1309.35 930.747,1309.35 930.756,1309.35 930.765,1309.35 930.774,1309.35 930.783,1309.35 930.793,1309.35 930.802,1309.35 930.811,1309.35 930.82,1309.35 930.829,1309.35 930.839,1309.35 930.848,1309.35 930.857,1309.35 930.866,1309.35 930.875,1309.35 930.885,1309.36 930.894,1309.36 930.903,1309.36 930.912,1309.36 930.921,1309.36 930.93,1309.36 930.94,1309.36 930.949,1309.36 930.958,1309.36 930.967,1309.36 930.976,1309.36 930.986,1309.36 930.995,1309.36 931.004,1309.36 931.013,1309.36 931.022,1309.36 931.032,1309.36 931.041,1309.37 931.05,1309.37 931.059,1309.37 931.068,1309.37 931.078,1309.37 931.087,1309.37 931.096,1309.37 931.105,1309.37 931.114,1309.37 931.123,1309.37 931.133,1309.37 931.142,1309.37 931.151,1309.37 931.16,1309.37 931.169,1309.37 931.179,1309.37 931.188,1309.37 931.197,1309.38 931.206,1309.38 931.215,1309.38 931.225,1309.38 931.234,1309.38 931.243,1309.38 931.252,1309.38 931.261,1309.38 931.27,1309.38 931.28,1309.38 931.289,1309.38 931.298,1309.38 931.307,1309.38 931.316,1309.38 931.326,1309.38 931.335,1309.38 931.344,1309.38 931.353,1309.39 931.362,1309.39 931.372,1309.39 931.381,1309.39 931.39,1309.39 931.399,1309.39 931.408,1309.39 931.418,1309.39 931.427,1309.39 931.436,1309.39 931.445,1309.39 931.454,1309.39 931.463,1309.39 931.473,1309.39 931.482,1309.39 931.491,1309.39 931.5,1309.39 931.509,1309.4 931.519,1309.4 931.528,1309.4 931.537,1309.4 931.546,1309.4 931.555,1309.4 931.565,1309.4 931.574,1309.4 931.583,1309.4 931.592,1309.4 931.601,1309.4 931.61,1309.4 931.62,1309.4 931.629,1309.4 931.638,1309.4 931.647,1309.4 931.656,1309.4 931.666,1309.41 931.675,1309.41 931.684,1309.41 931.693,1309.41 931.702,1309.41 931.712,1309.41 931.721,1309.41 931.73,1309.41 931.739,1309.41 931.748,1309.41 931.758,1309.41 931.767,1309.41 931.776,1309.41 931.785,1309.41 931.794,1309.41 931.803,1309.41 931.813,1309.41 931.822,1309.42 931.831,1309.42 931.84,1309.42 931.849,1309.42 931.859,1309.42 931.868,1309.42 931.877,1309.42 931.886,1309.42 931.895,1309.42 931.905,1309.42 931.914,1309.42 931.923,1309.42 931.932,1309.42 931.941,1309.42 931.95,1309.42 931.96,1309.42 931.969,1309.42 931.978,1309.43 931.987,1309.43 931.996,1309.43 932.006,1309.43 932.015,1309.43 932.024,1309.43 932.033,1309.43 932.042,1309.43 932.052,1309.43 932.061,1309.43 932.07,1309.43 932.079,1309.43 932.088,1309.43 932.098,1309.43 932.107,1309.43 932.116,1309.43 932.125,1309.43 932.134,1309.44 932.143,1309.44 932.153,1309.44 932.162,1309.44 932.171,1309.44 932.18,1309.44 932.189,1309.44 932.199,1309.44 932.208,1309.44 932.217,1309.44 932.226,1309.44 932.235,1309.44 932.245,1309.44 932.254,1309.44 932.263,1309.44 932.272,1309.44 932.281,1309.44 932.29,1309.45 932.3,1309.45 932.309,1309.45 932.318,1309.45 932.327,1309.45 932.336,1309.45 932.346,1309.45 932.355,1309.45 932.364,1309.45 932.373,1309.45 932.382,1309.45 932.392,1309.45 932.401,1309.45 932.41,1309.45 932.419,1309.45 932.428,1309.45 932.438,1309.45 932.447,1309.46 932.456,1309.46 932.465,1309.46 932.474,1309.46 932.483,1309.46 932.493,1309.46 932.502,1309.46 932.511,1309.46 932.52,1309.46 932.529,1309.46 932.539,1309.46 932.548,1309.46 932.557,1309.46 932.566,1309.46 932.575,1309.46 932.585,1309.46 932.594,1309.46 932.603,1309.47 932.612,1309.47 932.621,1309.47 932.63,1309.47 932.64,1309.47 932.649,1309.47 932.658,1309.47 932.667,1309.47 932.676,1309.47 932.686,1309.47 932.695,1309.47 932.704,1309.47 932.713,1309.47 932.722,1309.47 932.732,1309.47 932.741,1309.47 932.75,1309.47 932.759,1309.48 932.768,1309.48 932.778,1309.48 932.787,1309.48 932.796,1309.48 932.805,1309.48 932.814,1309.48 932.823,1309.48 932.833,1309.48 932.842,1309.48 932.851,1309.48 932.86,1309.48 932.869,1309.48 932.879,1309.48 932.888,1309.48 932.897,1309.48 932.906,1309.48 932.915,1309.49 932.925,1309.49 932.934,1309.49 932.943,1309.49 932.952,1309.49 932.961,1309.49 932.971,1309.49 932.98,1309.49 932.989,1309.49 932.998,1309.49 933.007,1309.49 933.016,1309.49 933.026,1309.49 933.035,1309.49 933.044,1309.49 933.053,1309.49 933.062,1309.49 933.072,1309.5 933.081,1309.5 933.09,1309.5 933.099,1309.5 933.108,1309.5 933.118,1309.5 933.127,1309.5 933.136,1309.5 933.145,1309.5 933.154,1309.5 933.163,1309.5 933.173,1309.5 933.182,1309.5 933.191,1309.5 933.2,1309.5 933.209,1309.5 933.219,1309.5 933.228,1309.51 933.237,1309.51 933.246,1309.51 933.255,1309.51 933.265,1309.51 933.274,1309.51 933.283,1309.51 933.292,1309.51 933.301,1309.51 933.311,1309.51 933.32,1309.51 933.329,1309.51 933.338,1309.51 933.347,1309.51 933.356,1309.51 933.366,1309.51 933.375,1309.51 933.384,1309.52 933.393,1309.52 933.402,1309.52 933.412,1309.52 933.421,1309.52 933.43,1309.52 933.439,1309.52 933.448,1309.52 933.458,1309.52 933.467,1309.52 933.476,1309.52 933.485,1309.52 933.494,1309.52 933.503,1309.52 933.513,1309.52 933.522,1309.52 933.531,1309.52 933.54,1309.53 933.549,1309.53 933.559,1309.53 933.568,1309.53 933.577,1309.53 933.586,1309.53 933.595,1309.53 933.605,1309.53 933.614,1309.53 933.623,1309.53 933.632,1309.53 933.641,1309.53 933.651,1309.53 933.66,1309.53 933.669,1309.53 933.678,1309.53 933.687,1309.53 933.696,1309.54 933.706,1309.54 933.715,1309.54 933.724,1309.54 933.733,1309.54 933.742,1309.54 933.752,1309.54 933.761,1309.54 933.77,1309.54 933.779,1309.54 933.788,1309.54 933.798,1309.54 933.807,1309.54 933.816,1309.54 933.825,1309.54 933.834,1309.54 933.843,1309.54 933.853,1309.55 933.862,1309.55 933.871,1309.55 933.88,1309.55 933.889,1309.55 933.899,1309.55 933.908,1309.55 933.917,1309.55 933.926,1309.55 933.935,1309.55 933.945,1309.55 933.954,1309.55 933.963,1309.55 933.972,1309.55 933.981,1309.55 933.991,1309.55 934,1309.55 934.009,1309.56 934.018,1309.56 934.027,1309.56 934.036,1309.56 934.046,1309.56 934.055,1309.56 934.064,1309.56 934.073,1309.56 934.082,1309.56 934.092,1309.56 934.101,1309.56 934.11,1309.56 934.119,1309.56 934.128,1309.56 934.138,1309.56 934.147,1309.56 934.156,1309.56 934.165,1309.57 934.174,1309.57 934.183,1309.57 934.193,1309.57 934.202,1309.57 934.211,1309.57 934.22,1309.57 934.229,1309.57 934.239,1309.57 934.248,1309.57 934.257,1309.57 934.266,1309.57 934.275,1309.57 934.285,1309.57 934.294,1309.57 934.303,1309.57 934.312,1309.57 934.321,1309.58 934.331,1309.58 934.34,1309.58 934.349,1309.58 934.358,1309.58 934.367,1309.58 934.376,1309.58 934.386,1309.58 934.395,1309.58 934.404,1309.58 934.413,1309.58 934.422,1309.58 934.432,1309.58 934.441,1309.58 934.45,1309.58 934.459,1309.58 934.468,1309.58 934.478,1309.59 934.487,1309.59 934.496,1309.59 934.505,1309.59 934.514,1309.59 934.523,1309.59 934.533,1309.59 934.542,1309.59 934.551,1309.59 934.56,1309.59 934.569,1309.59 934.579,1309.59 934.588,1309.59 934.597,1309.59 934.606,1309.59 934.615,1309.59 934.625,1309.59 934.634,1309.6 934.643,1309.6 934.652,1309.6 934.661,1309.6 934.671,1309.6 934.68,1309.6 934.689,1309.6 934.698,1309.6 934.707,1309.6 934.716,1309.6 934.726,1309.6 934.735,1309.6 934.744,1309.6 934.753,1309.6 934.762,1309.6 934.772,1309.6 934.781,1309.6 934.79,1309.61 934.799,1309.61 934.808,1309.61 934.818,1309.61 934.827,1309.61 934.836,1309.61 934.845,1309.61 934.854,1309.61 934.863,1309.61 934.873,1309.61 934.882,1309.61 934.891,1309.61 934.9,1309.61 934.909,1309.61 934.919,1309.61 934.928,1309.61 934.937,1309.61 934.946,1309.62 934.955,1309.62 934.965,1309.62 934.974,1309.62 934.983,1309.62 934.992,1309.62 935.001,1309.62 935.011,1309.62 935.02,1309.62 935.029,1309.62 935.038,1309.62 935.047,1309.62 935.056,1309.62 935.066,1309.62 935.075,1309.62 935.084,1309.62 935.093,1309.63 935.102,1309.63 935.112,1309.63 935.121,1309.63 935.13,1309.63 935.139,1309.63 935.148,1309.63 935.158,1309.63 935.167,1309.63 935.176,1309.63 935.185,1309.63 935.194,1309.63 935.203,1309.63 935.213,1309.63 935.222,1309.63 935.231,1309.63 935.24,1309.63 935.249,1309.64 935.259,1309.64 935.268,1309.64 935.277,1309.64 935.286,1309.64 935.295,1309.64 935.305,1309.64 935.314,1309.64 935.323,1309.64 935.332,1309.64 935.341,1309.64 935.351,1309.64 935.36,1309.64 935.369,1309.64 935.378,1309.64 935.387,1309.64 935.396,1309.64 935.406,1309.65 935.415,1309.65 935.424,1309.65 935.433,1309.65 935.442,1309.65 935.452,1309.65 935.461,1309.65 935.47,1309.65 935.479,1309.65 935.488,1309.65 935.498,1309.65 935.507,1309.65 935.516,1309.65 935.525,1309.65 935.534,1309.65 935.544,1309.65 935.553,1309.65 935.562,1309.66 935.571,1309.66 935.58,1309.66 935.589,1309.66 935.599,1309.66 935.608,1309.66 935.617,1309.66 935.626,1309.66 935.635,1309.66 935.645,1309.66 935.654,1309.66 935.663,1309.66 935.672,1309.66 935.681,1309.66 935.691,1309.66 935.7,1309.66 935.709,1309.66 935.718,1309.67 935.727,1309.67 935.736,1309.67 935.746,1309.67 935.755,1309.67 935.764,1309.67 935.773,1309.67 935.782,1309.67 935.792,1309.67 935.801,1309.67 935.81,1309.67 935.819,1309.67 935.828,1309.67 935.838,1309.67 935.847,1309.67 935.856,1309.67 935.865,1309.67 935.874,1309.68 935.884,1309.68 935.893,1309.68 935.902,1309.68 935.911,1309.68 935.92,1309.68 935.929,1309.68 935.939,1309.68 935.948,1309.68 935.957,1309.68 935.966,1309.68 935.975,1309.68 935.985,1309.68 935.994,1309.68 936.003,1309.68 936.012,1309.68 936.021,1309.68 936.031,1309.69 936.04,1309.69 936.049,1309.69 936.058,1309.69 936.067,1309.69 936.076,1309.69 936.086,1309.69 936.095,1309.69 936.104,1309.69 936.113,1309.69 936.122,1309.69 936.132,1309.69 936.141,1309.69 936.15,1309.69 936.159,1309.69 936.168,1309.69 936.178,1309.69 936.187,1309.7 936.196,1309.7 936.205,1309.7 936.214,1309.7 936.224,1309.7 936.233,1309.7 936.242,1309.7 936.251,1309.7 936.26,1309.7 936.269,1309.7 936.279,1309.7 936.288,1309.7 936.297,1309.7 936.306,1309.7 936.315,1309.7 936.325,1309.7 936.334,1309.7 936.343,1309.71 936.352,1309.71 936.361,1309.71 936.371,1309.71 936.38,1309.71 936.389,1309.71 936.398,1309.71 936.407,1309.71 936.416,1309.71 936.426,1309.71 936.435,1309.71 936.444,1309.71 936.453,1309.71 936.462,1309.71 936.472,1309.71 936.481,1309.71 936.49,1309.72 936.499,1309.72 936.508,1309.72 936.518,1309.72 936.527,1309.72 936.536,1309.72 936.545,1309.72 936.554,1309.72 936.564,1309.72 936.573,1309.72 936.582,1309.72 936.591,1309.72 936.6,1309.72 936.609,1309.72 936.619,1309.72 936.628,1309.72 936.637,1309.72 936.646,1309.73 936.655,1309.73 936.665,1309.73 936.674,1309.73 936.683,1309.73 936.692,1309.73 936.701,1309.73 936.711,1309.73 936.72,1309.73 936.729,1309.73 936.738,1309.73 936.747,1309.73 936.756,1309.73 936.766,1309.73 936.775,1309.73 936.784,1309.73 936.793,1309.73 936.802,1309.74 936.812,1309.74 936.821,1309.74 936.83,1309.74 936.839,1309.74 936.848,1309.74 936.858,1309.74 936.867,1309.74 936.876,1309.74 936.885,1309.74 936.894,1309.74 936.904,1309.74 936.913,1309.74 936.922,1309.74 936.931,1309.74 936.94,1309.74 936.949,1309.74 936.959,1309.75 936.968,1309.75 936.977,1309.75 936.986,1309.75 936.995,1309.75 937.005,1309.75 937.014,1309.75 937.023,1309.75 937.032,1309.75 937.041,1309.75 937.051,1309.75 937.06,1309.75 937.069,1309.75 937.078,1309.75 937.087,1309.75 937.096,1309.75 937.106,1309.75 937.115,1309.76 937.124,1309.76 937.133,1309.76 937.142,1309.76 937.152,1309.76 937.161,1309.76 937.17,1309.76 937.179,1309.76 937.188,1309.76 937.198,1309.76 937.207,1309.76 937.216,1309.76 937.225,1309.76 937.234,1309.76 937.244,1309.76 937.253,1309.76 937.262,1309.76 937.271,1309.77 937.28,1309.77 937.289,1309.77 937.299,1309.77 937.308,1309.77 937.317,1309.77 937.326,1309.77 937.335,1309.77 937.345,1309.77 937.354,1309.77 937.363,1309.77 937.372,1309.77 937.381,1309.77 937.391,1309.77 937.4,1309.77 937.409,1309.77 937.418,1309.77 937.427,1309.78 937.436,1309.78 937.446,1309.78 937.455,1309.78 937.464,1309.78 937.473,1309.78 937.482,1309.78 937.492,1309.78 937.501,1309.78 937.51,1309.78 937.519,1309.78 937.528,1309.78 937.538,1309.78 937.547,1309.78 937.556,1309.78 937.565,1309.78 937.574,1309.79 937.584,1309.79 937.593,1309.79 937.602,1309.79 937.611,1309.79 937.62,1309.79 937.629,1309.79 937.639,1309.79 937.648,1309.79 937.657,1309.79 937.666,1309.79 937.675,1309.79 937.685,1309.79 937.694,1309.79 937.703,1309.79 937.712,1309.79 937.721,1309.79 937.731,1309.8 937.74,1309.8 937.749,1309.8 937.758,1309.8 937.767,1309.8 937.776,1309.8 937.786,1309.8 937.795,1309.8 937.804,1309.8 937.813,1309.8 937.822,1309.8 937.832,1309.8 937.841,1309.8 937.85,1309.8 937.859,1309.8 937.868,1309.8 937.878,1309.8 937.887,1309.81 937.896,1309.81 937.905,1309.81 937.914,1309.81 937.924,1309.81 937.933,1309.81 937.942,1309.81 937.951,1309.81 937.96,1309.81 937.969,1309.81 937.979,1309.81 937.988,1309.81 937.997,1309.81 938.006,1309.81 938.015,1309.81 938.025,1309.81 938.034,1309.81 938.043,1309.82 938.052,1309.82 938.061,1309.82 938.071,1309.82 938.08,1309.82 938.089,1309.82 938.098,1309.82 938.107,1309.82 938.117,1309.82 938.126,1309.82 938.135,1309.82 938.144,1309.82 938.153,1309.82 938.162,1309.82 938.172,1309.82 938.181,1309.82 938.19,1309.82 938.199,1309.83 938.208,1309.83 938.218,1309.83 938.227,1309.83 938.236,1309.83 938.245,1309.83 938.254,1309.83 938.264,1309.83 938.273,1309.83 938.282,1309.83 938.291,1309.83 938.3,1309.83 938.309,1309.83 938.319,1309.83 938.328,1309.83 938.337,1309.83 938.346,1309.83 938.355,1309.84 938.365,1309.84 938.374,1309.84 938.383,1309.84 938.392,1309.84 938.401,1309.84 938.411,1309.84 938.42,1309.84 938.429,1309.84 938.438,1309.84 938.447,1309.84 938.457,1309.84 938.466,1309.84 938.475,1309.84 938.484,1309.84 938.493,1309.84 938.502,1309.85 938.512,1309.85 938.521,1309.85 938.53,1309.85 938.539,1309.85 938.548,1309.85 938.558,1309.85 938.567,1309.85 938.576,1309.85 938.585,1309.85 938.594,1309.85 938.604,1309.85 938.613,1309.85 938.622,1309.85 938.631,1309.85 938.64,1309.85 938.649,1309.85 938.659,1309.86 938.668,1309.86 938.677,1309.86 938.686,1309.86 938.695,1309.86 938.705,1309.86 938.714,1309.86 938.723,1309.86 938.732,1309.86 938.741,1309.86 938.751,1309.86 938.76,1309.86 938.769,1309.86 938.778,1309.86 938.787,1309.86 938.797,1309.86 938.806,1309.86 938.815,1309.87 938.824,1309.87 938.833,1309.87 938.842,1309.87 938.852,1309.87 938.861,1309.87 938.87,1309.87 938.879,1309.87 938.888,1309.87 938.898,1309.87 938.907,1309.87 938.916,1309.87 938.925,1309.87 938.934,1309.87 938.944,1309.87 938.953,1309.87 938.962,1309.87 938.971,1309.88 938.98,1309.88 938.989,1309.88 938.999,1309.88 939.008,1309.88 939.017,1309.88 939.026,1309.88 939.035,1309.88 939.045,1309.88 939.054,1309.88 939.063,1309.88 939.072,1309.88 939.081,1309.88 939.091,1309.88 939.1,1309.88 939.109,1309.88 939.118,1309.88 939.127,1309.89 939.137,1309.89 939.146,1309.89 939.155,1309.89 939.164,1309.89 939.173,1309.89 939.182,1309.89 939.192,1309.89 939.201,1309.89 939.21,1309.89 939.219,1309.89 939.228,1309.89 939.238,1309.89 939.247,1309.89 939.256,1309.89 939.265,1309.89 939.274,1309.9 939.284,1309.9 939.293,1309.9 939.302,1309.9 939.311,1309.9 939.32,1309.9 939.329,1309.9 939.339,1309.9 939.348,1309.9 939.357,1309.9 939.366,1309.9 939.375,1309.9 939.385,1309.9 939.394,1309.9 939.403,1309.9 939.412,1309.9 939.421,1309.9 939.431,1309.91 939.44,1309.91 939.449,1309.91 939.458,1309.91 939.467,1309.91 939.477,1309.91 939.486,1309.91 939.495,1309.91 939.504,1309.91 939.513,1309.91 939.522,1309.91 939.532,1309.91 939.541,1309.91 939.55,1309.91 939.559,1309.91 939.568,1309.91 939.578,1309.91 939.587,1309.92 939.596,1309.92 939.605,1309.92 939.614,1309.92 939.624,1309.92 939.633,1309.92 939.642,1309.92 939.651,1309.92 939.66,1309.92 939.669,1309.92 939.679,1309.92 939.688,1309.92 939.697,1309.92 939.706,1309.92 939.715,1309.92 939.725,1309.92 939.734,1309.92 939.743,1309.93 939.752,1309.93 939.761,1309.93 939.771,1309.93 939.78,1309.93 939.789,1309.93 939.798,1309.93 939.807,1309.93 939.817,1309.93 939.826,1309.93 939.835,1309.93 939.844,1309.93 939.853,1309.93 939.862,1309.93 939.872,1309.93 939.881,1309.93 939.89,1309.93 939.899,1309.94 939.908,1309.94 939.918,1309.94 939.927,1309.94 939.936,1309.94 939.945,1309.94 939.954,1309.94 939.964,1309.94 939.973,1309.94 939.982,1309.94 939.991,1309.94 940,1309.94 940.009,1309.94 940.019,1309.94 940.028,1309.94 940.037,1309.94 940.046,1309.95 940.055,1309.95 940.065,1309.95 940.074,1309.95 940.083,1309.95 940.092,1309.95 940.101,1309.95 940.111,1309.95 940.12,1309.95 940.129,1309.95 940.138,1309.95 940.147,1309.95 940.157,1309.95 940.166,1309.95 940.175,1309.95 940.184,1309.95 940.193,1309.95 940.202,1309.96 940.212,1309.96 940.221,1309.96 940.23,1309.96 940.239,1309.96 940.248,1309.96 940.258,1309.96 940.267,1309.96 940.276,1309.96 940.285,1309.96 940.294,1309.96 940.304,1309.96 940.313,1309.96 940.322,1309.96 940.331,1309.96 940.34,1309.96 940.35,1309.96 940.359,1309.97 940.368,1309.97 940.377,1309.97 940.386,1309.97 940.395,1309.97 940.405,1309.97 940.414,1309.97 940.423,1309.97 940.432,1309.97 940.441,1309.97 940.451,1309.97 940.46,1309.97 940.469,1309.97 940.478,1309.97 940.487,1309.97 940.497,1309.97 940.506,1309.97 940.515,1309.98 940.524,1309.98 940.533,1309.98 940.542,1309.98 940.552,1309.98 940.561,1309.98 940.57,1309.98 940.579,1309.98 940.588,1309.98 940.598,1309.98 940.607,1309.98 940.616,1309.98 940.625,1309.98 940.634,1309.98 940.644,1309.98 940.653,1309.98 940.662,1309.98 940.671,1309.99 940.68,1309.99 940.69,1309.99 940.699,1309.99 940.708,1309.99 940.717,1309.99 940.726,1309.99 940.735,1309.99 940.745,1309.99 940.754,1309.99 940.763,1309.99 940.772,1309.99 940.781,1309.99 940.791,1309.99 940.8,1309.99 940.809,1309.99 940.818,1310 940.827,1310 940.837,1310 940.846,1310 940.855,1310 940.864,1310 940.873,1310 940.882,1310 940.892,1310 940.901,1310 940.91,1310 940.919,1310 940.928,1310 940.938,1310 940.947,1310 940.956,1310 940.965,1310 940.974,1310.01 940.984,1310.01 940.993,1310.01 941.002,1310.01 941.011,1310.01 941.02,1310.01 941.03,1310.01 941.039,1310.01 941.048,1310.01 941.057,1310.01 941.066,1310.01 941.075,1310.01 941.085,1310.01 941.094,1310.01 941.103,1310.01 941.112,1310.01 941.121,1310.01 941.131,1310.02 941.14,1310.02 941.149,1310.02 941.158,1310.02 941.167,1310.02 941.177,1310.02 941.186,1310.02 941.195,1310.02 941.204,1310.02 941.213,1310.02 941.222,1310.02 941.232,1310.02 941.241,1310.02 941.25,1310.02 941.259,1310.02 941.268,1310.02 941.278,1310.02 941.287,1310.03 941.296,1310.03 941.305,1310.03 941.314,1310.03 941.324,1310.03 941.333,1310.03 941.342,1310.03 941.351,1310.03 941.36,1310.03 941.37,1310.03 941.379,1310.03 941.388,1310.03 941.397,1310.03 941.406,1310.03 941.415,1310.03 941.425,1310.03 941.434,1310.04 941.443,1310.04 941.452,1310.04 941.461,1310.04 941.471,1310.04 941.48,1310.04 941.489,1310.04 941.498,1310.04 941.507,1310.04 941.517,1310.04 941.526,1310.04 941.535,1310.04 941.544,1310.04 941.553,1310.04 941.562,1310.04 941.572,1310.04 941.581,1310.04 941.59,1310.05 941.599,1310.05 941.608,1310.05 941.618,1310.05 941.627,1310.05 941.636,1310.05 941.645,1310.05 941.654,1310.05 941.664,1310.05 941.673,1310.05 941.682,1310.05 941.691,1310.05 941.7,1310.05 941.71,1310.05 941.719,1310.05 941.728,1310.05 941.737,1310.05 941.746,1310.06 941.755,1310.06 941.765,1310.06 941.774,1310.06 941.783,1310.06 941.792,1310.06 941.801,1310.06 941.811,1310.06 941.82,1310.06 941.829,1310.06 941.838,1310.06 941.847,1310.06 941.857,1310.06 941.866,1310.06 941.875,1310.06 941.884,1310.06 941.893,1310.06 941.902,1310.07 941.912,1310.07 941.921,1310.07 941.93,1310.07 941.939,1310.07 941.948,1310.07 941.958,1310.07 941.967,1310.07 941.976,1310.07 941.985,1310.07 941.994,1310.07 942.004,1310.07 942.013,1310.07 942.022,1310.07 942.031,1310.07 942.04,1310.07 942.05,1310.08 942.059,1310.08 942.068,1310.08 942.077,1310.08 942.086,1310.08 942.095,1310.08 942.105,1310.08 942.114,1310.08 942.123,1310.08 942.132,1310.08 942.141,1310.08 942.151,1310.08 942.16,1310.08 942.169,1310.08 942.178,1310.08 942.187,1310.08 942.197,1310.08 942.206,1310.09 942.215,1310.09 942.224,1310.09 942.233,1310.09 942.242,1310.09 942.252,1310.09 942.261,1310.09 942.27,1310.09 942.279,1310.09 942.288,1310.09 942.298,1310.09 942.307,1310.09 942.316,1310.09 942.325,1310.09 942.334,1310.09 942.344,1310.09 942.353,1310.09 942.362,1310.1 942.371,1310.1 942.38,1310.1 942.39,1310.1 942.399,1310.1 942.408,1310.1 942.417,1310.1 942.426,1310.1 942.435,1310.1 942.445,1310.1 942.454,1310.1 942.463,1310.1 942.472,1310.1 942.481,1310.1 942.491,1310.1 942.5,1310.1 942.509,1310.11 942.518,1310.11 942.527,1310.11 942.537,1310.11 942.546,1310.11 942.555,1310.11 942.564,1310.11 942.573,1310.11 942.582,1310.11 942.592,1310.11 942.601,1310.11 942.61,1310.11 942.619,1310.11 942.628,1310.11 942.638,1310.11 942.647,1310.11 942.656,1310.11 942.665,1310.12 942.674,1310.12 942.684,1310.12 942.693,1310.12 942.702,1310.12 942.711,1310.12 942.72,1310.12 942.73,1310.12 942.739,1310.12 942.748,1310.12 942.757,1310.12 942.766,1310.12 942.775,1310.12 942.785,1310.12 942.794,1310.12 942.803,1310.12 942.812,1310.12 942.821,1310.13 942.831,1310.13 942.84,1310.13 942.849,1310.13 942.858,1310.13 942.867,1310.13 942.877,1310.13 942.886,1310.13 942.895,1310.13 942.904,1310.13 942.913,1310.13 942.923,1310.13 942.932,1310.13 942.941,1310.13 942.95,1310.13 942.959,1310.13 942.968,1310.13 942.978,1310.14 942.987,1310.14 942.996,1310.14 943.005,1310.14 943.014,1310.14 943.024,1310.14 943.033,1310.14 943.042,1310.14 943.051,1310.14 943.06,1310.14 943.07,1310.14 943.079,1310.14 943.088,1310.14 943.097,1310.14 943.106,1310.14 943.115,1310.14 943.125,1310.15 943.134,1310.15 943.143,1310.15 943.152,1310.15 943.161,1310.15 943.171,1310.15 943.18,1310.15 943.189,1310.15 943.198,1310.15 943.207,1310.15 943.217,1310.15 943.226,1310.15 943.235,1310.15 943.244,1310.15 943.253,1310.15 943.263,1310.15 943.272,1310.15 943.281,1310.16 943.29,1310.16 943.299,1310.16 943.308,1310.16 943.318,1310.16 943.327,1310.16 943.336,1310.16 943.345,1310.16 943.354,1310.16 943.364,1310.16 943.373,1310.16 943.382,1310.16 943.391,1310.16 943.4,1310.16 943.41,1310.16 943.419,1310.16 943.428,1310.16 943.437,1310.17 943.446,1310.17 943.455,1310.17 943.465,1310.17 943.474,1310.17 943.483,1310.17 943.492,1310.17 943.501,1310.17 943.511,1310.17 943.52,1310.17 943.529,1310.17 943.538,1310.17 943.547,1310.17 943.557,1310.17 943.566,1310.17 943.575,1310.17 943.584,1310.18 943.593,1310.18 943.603,1310.18 943.612,1310.18 943.621,1310.18 943.63,1310.18 943.639,1310.18 943.648,1310.18 943.658,1310.18 943.667,1310.18 943.676,1310.18 943.685,1310.18 943.694,1310.18 943.704,1310.18 943.713,1310.18 943.722,1310.18 943.731,1310.18 943.74,1310.19 943.75,1310.19 943.759,1310.19 943.768,1310.19 943.777,1310.19 943.786,1310.19 943.795,1310.19 943.805,1310.19 943.814,1310.19 943.823,1310.19 943.832,1310.19 943.841,1310.19 943.851,1310.19 943.86,1310.19 943.869,1310.19 943.878,1310.19 943.887,1310.19 943.897,1310.2 943.906,1310.2 943.915,1310.2 943.924,1310.2 943.933,1310.2 943.943,1310.2 943.952,1310.2 943.961,1310.2 943.97,1310.2 943.979,1310.2 943.988,1310.2 943.998,1310.2 944.007,1310.2 944.016,1310.2 944.025,1310.2 944.034,1310.2 944.044,1310.2 944.053,1310.21 944.062,1310.21 944.071,1310.21 944.08,1310.21 944.09,1310.21 944.099,1310.21 944.108,1310.21 944.117,1310.21 944.126,1310.21 944.135,1310.21 944.145,1310.21 944.154,1310.21 944.163,1310.21 944.172,1310.21 944.181,1310.21 944.191,1310.21 944.2,1310.22 944.209,1310.22 944.218,1310.22 944.227,1310.22 944.237,1310.22 944.246,1310.22 944.255,1310.22 944.264,1310.22 944.273,1310.22 944.283,1310.22 944.292,1310.22 944.301,1310.22 944.31,1310.22 944.319,1310.22 944.328,1310.22 944.338,1310.22 944.347,1310.22 944.356,1310.23 944.365,1310.23 944.374,1310.23 944.384,1310.23 944.393,1310.23 944.402,1310.23 944.411,1310.23 944.42,1310.23 944.43,1310.23 944.439,1310.23 944.448,1310.23 944.457,1310.23 944.466,1310.23 944.475,1310.23 944.485,1310.23 944.494,1310.23 944.503,1310.23 944.512,1310.24 944.521,1310.24 944.531,1310.24 944.54,1310.24 944.549,1310.24 944.558,1310.24 944.567,1310.24 944.577,1310.24 944.586,1310.24 944.595,1310.24 944.604,1310.24 944.613,1310.24 944.623,1310.24 944.632,1310.24 944.641,1310.24 944.65,1310.24 944.659,1310.25 944.668,1310.25 944.678,1310.25 944.687,1310.25 944.696,1310.25 944.705,1310.25 944.714,1310.25 944.724,1310.25 944.733,1310.25 944.742,1310.25 944.751,1310.25 944.76,1310.25 944.77,1310.25 944.779,1310.25 944.788,1310.25 944.797,1310.25 944.806,1310.25 944.815,1310.26 944.825,1310.26 944.834,1310.26 944.843,1310.26 944.852,1310.26 944.861,1310.26 944.871,1310.26 944.88,1310.26 944.889,1310.26 944.898,1310.26 944.907,1310.26 944.917,1310.26 944.926,1310.26 944.935,1310.26 944.944,1310.26 944.953,1310.26 944.963,1310.26 944.972,1310.27 944.981,1310.27 944.99,1310.27 944.999,1310.27 945.008,1310.27 945.018,1310.27 945.027,1310.27 945.036,1310.27 945.045,1310.27 945.054,1310.27 945.064,1310.27 945.073,1310.27 945.082,1310.27 945.091,1310.27 945.1,1310.27 945.11,1310.27 945.119,1310.28 945.128,1310.28 945.137,1310.28 945.146,1310.28 945.155,1310.28 945.165,1310.28 945.174,1310.28 945.183,1310.28 945.192,1310.28 945.201,1310.28 945.211,1310.28 945.22,1310.28 945.229,1310.28 945.238,1310.28 945.247,1310.28 945.257,1310.28 945.266,1310.28 945.275,1310.29 945.284,1310.29 945.293,1310.29 945.303,1310.29 945.312,1310.29 945.321,1310.29 945.33,1310.29 945.339,1310.29 945.348,1310.29 945.358,1310.29 945.367,1310.29 945.376,1310.29 945.385,1310.29 945.394,1310.29 945.404,1310.29 945.413,1310.29 945.422,1310.29 945.431,1310.3 945.44,1310.3 945.45,1310.3 945.459,1310.3 945.468,1310.3 945.477,1310.3 945.486,1310.3 945.496,1310.3 945.505,1310.3 945.514,1310.3 945.523,1310.3 945.532,1310.3 945.541,1310.3 945.551,1310.3 945.56,1310.3 945.569,1310.3 945.578,1310.31 945.587,1310.31 945.597,1310.31 945.606,1310.31 945.615,1310.31 945.624,1310.31 945.633,1310.31 945.643,1310.31 945.652,1310.31 945.661,1310.31 945.67,1310.31 945.679,1310.31 945.688,1310.31 945.698,1310.31 945.707,1310.31 945.716,1310.31 945.725,1310.31 945.734,1310.32 945.744,1310.32 945.753,1310.32 945.762,1310.32 945.771,1310.32 945.78,1310.32 945.79,1310.32 945.799,1310.32 945.808,1310.32 945.817,1310.32 945.826,1310.32 945.836,1310.32 945.845,1310.32 945.854,1310.32 945.863,1310.32 945.872,1310.32 945.881,1310.32 945.891,1310.33 945.9,1310.33 945.909,1310.33 945.918,1310.33 945.927,1310.33 945.937,1310.33 945.946,1310.33 945.955,1310.33 945.964,1310.33 945.973,1310.33 945.983,1310.33 945.992,1310.33 946.001,1310.33 946.01,1310.33 946.019,1310.33 946.028,1310.33 946.038,1310.34 946.047,1310.34 946.056,1310.34 946.065,1310.34 946.074,1310.34 946.084,1310.34 946.093,1310.34 946.102,1310.34 946.111,1310.34 946.12,1310.34 946.13,1310.34 946.139,1310.34 946.148,1310.34 946.157,1310.34 946.166,1310.34 946.176,1310.34 946.185,1310.34 946.194,1310.35 946.203,1310.35 946.212,1310.35 946.221,1310.35 946.231,1310.35 946.24,1310.35 946.249,1310.35 946.258,1310.35 946.267,1310.35 946.277,1310.35 946.286,1310.35 946.295,1310.35 946.304,1310.35 946.313,1310.35 946.323,1310.35 946.332,1310.35 946.341,1310.35 946.35,1310.36 946.359,1310.36 946.368,1310.36 946.378,1310.36 946.387,1310.36 946.396,1310.36 946.405,1310.36 946.414,1310.36 946.424,1310.36 946.433,1310.36 946.442,1310.36 946.451,1310.36 946.46,1310.36 946.47,1310.36 946.479,1310.36 946.488,1310.36 946.497,1310.37 946.506,1310.37 946.516,1310.37 946.525,1310.37 946.534,1310.37 946.543,1310.37 946.552,1310.37 946.561,1310.37 946.571,1310.37 946.58,1310.37 946.589,1310.37 946.598,1310.37 946.607,1310.37 946.617,1310.37 946.626,1310.37 946.635,1310.37 946.644,1310.37 946.653,1310.38 946.663,1310.38 946.672,1310.38 946.681,1310.38 946.69,1310.38 946.699,1310.38 946.708,1310.38 946.718,1310.38 946.727,1310.38 946.736,1310.38 946.745,1310.38 946.754,1310.38 946.764,1310.38 946.773,1310.38 946.782,1310.38 946.791,1310.38 946.8,1310.39 946.81,1310.39 946.819,1310.39 946.828,1310.39 946.837,1310.39 946.846,1310.39 946.856,1310.39 946.865,1310.39 946.874,1310.39 946.883,1310.39 946.892,1310.39 946.901,1310.39 946.911,1310.39 946.92,1310.39 946.929,1310.39 946.938,1310.39 946.947,1310.39 946.957,1310.4 946.966,1310.4 946.975,1310.4 946.984,1310.4 946.993,1310.4 947.003,1310.4 947.012,1310.4 947.021,1310.4 947.03,1310.4 947.039,1310.4 947.048,1310.4 947.058,1310.4 947.067,1310.4 947.076,1310.4 947.085,1310.4 947.094,1310.4 947.104,1310.4 947.113,1310.41 947.122,1310.41 947.131,1310.41 947.14,1310.41 947.15,1310.41 947.159,1310.41 947.168,1310.41 947.177,1310.41 947.186,1310.41 947.196,1310.41 947.205,1310.41 947.214,1310.41 947.223,1310.41 947.232,1310.41 947.241,1310.41 947.251,1310.41 947.26,1310.42 947.269,1310.42 947.278,1310.42 947.287,1310.42 947.297,1310.42 947.306,1310.42 947.315,1310.42 947.324,1310.42 947.333,1310.42 947.343,1310.42 947.352,1310.42 947.361,1310.42 947.37,1310.42 947.379,1310.42 947.388,1310.42 947.398,1310.42 947.407,1310.42 947.416,1310.43 947.425,1310.43 947.434,1310.43 947.444,1310.43 947.453,1310.43 947.462,1310.43 947.471,1310.43 947.48,1310.43 947.49,1310.43 947.499,1310.43 947.508,1310.43 947.517,1310.43 947.526,1310.43 947.536,1310.43 947.545,1310.43 947.554,1310.43 947.563,1310.43 947.572,1310.44 947.581,1310.44 947.591,1310.44 947.6,1310.44 947.609,1310.44 947.618,1310.44 947.627,1310.44 947.637,1310.44 947.646,1310.44 947.655,1310.44 947.664,1310.44 947.673,1310.44 947.683,1310.44 947.692,1310.44 947.701,1310.44 947.71,1310.44 947.719,1310.45 947.729,1310.45 947.738,1310.45 947.747,1310.45 947.756,1310.45 947.765,1310.45 947.774,1310.45 947.784,1310.45 947.793,1310.45 947.802,1310.45 947.811,1310.45 947.82,1310.45 947.83,1310.45 947.839,1310.45 947.848,1310.45 947.857,1310.45 947.866,1310.45 947.876,1310.46 947.885,1310.46 947.894,1310.46 947.903,1310.46 947.912,1310.46 947.921,1310.46 947.931,1310.46 947.94,1310.46 947.949,1310.46 947.958,1310.46 947.967,1310.46 947.977,1310.46 947.986,1310.46 947.995,1310.46 948.004,1310.46 948.013,1310.46 948.023,1310.47 948.032,1310.47 948.041,1310.47 948.05,1310.47 948.059,1310.47 948.069,1310.47 948.078,1310.47 948.087,1310.47 948.096,1310.47 948.105,1310.47 948.114,1310.47 948.124,1310.47 948.133,1310.47 948.142,1310.47 948.151,1310.47 948.16,1310.47 948.17,1310.47 948.179,1310.48 948.188,1310.48 948.197,1310.48 948.206,1310.48 948.216,1310.48 948.225,1310.48 948.234,1310.48 948.243,1310.48 948.252,1310.48 948.261,1310.48 948.271,1310.48 948.28,1310.48 948.289,1310.48 948.298,1310.48 948.307,1310.48 948.317,1310.48 948.326,1310.48 948.335,1310.49 948.344,1310.49 948.353,1310.49 948.363,1310.49 948.372,1310.49 948.381,1310.49 948.39,1310.49 948.399,1310.49 948.409,1310.49 948.418,1310.49 948.427,1310.49 948.436,1310.49 948.445,1310.49 948.454,1310.49 948.464,1310.49 948.473,1310.49 948.482,1310.5 948.491,1310.5 948.5,1310.5 948.51,1310.5 948.519,1310.5 948.528,1310.5 948.537,1310.5 948.546,1310.5 948.556,1310.5 948.565,1310.5 948.574,1310.5 948.583,1310.5 948.592,1310.5 948.601,1310.5 948.611,1310.5 948.62,1310.5 948.629,1310.5 948.638,1310.51 948.647,1310.51 948.657,1310.51 948.666,1310.51 948.675,1310.51 948.684,1310.51 948.693,1310.51 948.703,1310.51 948.712,1310.51 948.721,1310.51 948.73,1310.51 948.739,1310.51 948.749,1310.51 948.758,1310.51 948.767,1310.51 948.776,1310.51 948.785,1310.52 948.794,1310.52 948.804,1310.52 948.813,1310.52 948.822,1310.52 948.831,1310.52 948.84,1310.52 948.85,1310.52 948.859,1310.52 948.868,1310.52 948.877,1310.52 948.886,1310.52 948.896,1310.52 948.905,1310.52 948.914,1310.52 948.923,1310.52 948.932,1310.52 948.941,1310.53 948.951,1310.53 948.96,1310.53 948.969,1310.53 948.978,1310.53 948.987,1310.53 948.997,1310.53 949.006,1310.53 949.015,1310.53 949.024,1310.53 949.033,1310.53 949.043,1310.53 949.052,1310.53 949.061,1310.53 949.07,1310.53 949.079,1310.53 949.089,1310.53 949.098,1310.54 949.107,1310.54 949.116,1310.54 949.125,1310.54 949.134,1310.54 949.144,1310.54 949.153,1310.54 949.162,1310.54 949.171,1310.54 949.18,1310.54 949.19,1310.54 949.199,1310.54 949.208,1310.54 949.217,1310.54 949.226,1310.54 949.236,1310.54 949.245,1310.55 949.254,1310.55 949.263,1310.55 949.272,1310.55 949.281,1310.55 949.291,1310.55 949.3,1310.55 949.309,1310.55 949.318,1310.55 949.327,1310.55 949.337,1310.55 949.346,1310.55 949.355,1310.55 949.364,1310.55 949.373,1310.55 949.383,1310.55 949.392,1310.55 949.401,1310.56 949.41,1310.56 949.419,1310.56 949.429,1310.56 949.438,1310.56 949.447,1310.56 949.456,1310.56 949.465,1310.56 949.474,1310.56 949.484,1310.56 949.493,1310.56 949.502,1310.56 949.511,1310.56 949.52,1310.56 949.53,1310.56 949.539,1310.56 949.548,1310.57 949.557,1310.57 949.566,1310.57 949.576,1310.57 949.585,1310.57 949.594,1310.57 949.603,1310.57 949.612,1310.57 949.621,1310.57 949.631,1310.57 949.64,1310.57 949.649,1310.57 949.658,1310.57 949.667,1310.57 949.677,1310.57 949.686,1310.57 949.695,1310.57 949.704,1310.58 949.713,1310.58 949.723,1310.58 949.732,1310.58 949.741,1310.58 949.75,1310.58 949.759,1310.58 949.769,1310.58 949.778,1310.58 949.787,1310.58 949.796,1310.58 949.805,1310.58 949.814,1310.58 949.824,1310.58 949.833,1310.58 949.842,1310.58 949.851,1310.58 949.86,1310.59 949.87,1310.59 949.879,1310.59 949.888,1310.59 949.897,1310.59 949.906,1310.59 949.916,1310.59 949.925,1310.59 949.934,1310.59 949.943,1310.59 949.952,1310.59 949.961,1310.59 949.971,1310.59 949.98,1310.59 949.989,1310.59 949.998,1310.59 950.007,1310.6 950.017,1310.6 950.026,1310.6 950.035,1310.6 950.044,1310.6 950.053,1310.6 950.063,1310.6 950.072,1310.6 950.081,1310.6 950.09,1310.6 950.099,1310.6 950.109,1310.6 950.118,1310.6 950.127,1310.6 950.136,1310.6 950.145,1310.6 950.154,1310.6 950.164,1310.61 950.173,1310.61 950.182,1310.61 950.191,1310.61 950.2,1310.61 950.21,1310.61 950.219,1310.61 950.228,1310.61 950.237,1310.61 950.246,1310.61 950.256,1310.61 950.265,1310.61 950.274,1310.61 950.283,1310.61 950.292,1310.61 950.302,1310.61 950.311,1310.62 950.32,1310.62 950.329,1310.62 950.338,1310.62 950.347,1310.62 950.357,1310.62 950.366,1310.62 950.375,1310.62 950.384,1310.62 950.393,1310.62 950.403,1310.62 950.412,1310.62 950.421,1310.62 950.43,1310.62 950.439,1310.62 950.449,1310.62 950.458,1310.62 950.467,1310.63 950.476,1310.63 950.485,1310.63 950.494,1310.63 950.504,1310.63 950.513,1310.63 950.522,1310.63 950.531,1310.63 950.54,1310.63 950.55,1310.63 950.559,1310.63 950.568,1310.63 950.577,1310.63 950.586,1310.63 950.596,1310.63 950.605,1310.63 950.614,1310.64 950.623,1310.64 950.632,1310.64 950.642,1310.64 950.651,1310.64 950.66,1310.64 950.669,1310.64 950.678,1310.64 950.687,1310.64 950.697,1310.64 950.706,1310.64 950.715,1310.64 950.724,1310.64 950.733,1310.64 950.743,1310.64 950.752,1310.64 950.761,1310.64 950.77,1310.65 950.779,1310.65 950.789,1310.65 950.798,1310.65 950.807,1310.65 950.816,1310.65 950.825,1310.65 950.834,1310.65 950.844,1310.65 950.853,1310.65 950.862,1310.65 950.871,1310.65 950.88,1310.65 950.89,1310.65 950.899,1310.65 950.908,1310.65 950.917,1310.65 950.926,1310.66 950.936,1310.66 950.945,1310.66 950.954,1310.66 950.963,1310.66 950.972,1310.66 950.982,1310.66 950.991,1310.66 951,1310.66 951.009,1310.66 951.018,1310.66 951.027,1310.66 951.037,1310.66 951.046,1310.66 951.055,1310.66 951.064,1310.66 951.073,1310.67 951.083,1310.67 951.092,1310.67 951.101,1310.67 951.11,1310.67 951.119,1310.67 951.129,1310.67 951.138,1310.67 951.147,1310.67 951.156,1310.67 951.165,1310.67 951.174,1310.67 951.184,1310.67 951.193,1310.67 951.202,1310.67 951.211,1310.67 951.22,1310.67 951.23,1310.68 951.239,1310.68 951.248,1310.68 951.257,1310.68 951.266,1310.68 951.276,1310.68 951.285,1310.68 951.294,1310.68 951.303,1310.68 951.312,1310.68 951.322,1310.68 951.331,1310.68 951.34,1310.68 951.349,1310.68 951.358,1310.68 951.367,1310.68 951.377,1310.69 951.386,1310.69 951.395,1310.69 951.404,1310.69 951.413,1310.69 951.423,1310.69 951.432,1310.69 951.441,1310.69 951.45,1310.69 951.459,1310.69 951.469,1310.69 951.478,1310.69 951.487,1310.69 951.496,1310.69 951.505,1310.69 951.514,1310.69 951.524,1310.69 951.533,1310.7 951.542,1310.7 951.551,1310.7 951.56,1310.7 951.57,1310.7 951.579,1310.7 951.588,1310.7 951.597,1310.7 951.606,1310.7 951.616,1310.7 951.625,1310.7 951.634,1310.7 951.643,1310.7 951.652,1310.7 951.662,1310.7 951.671,1310.7 951.68,1310.71 951.689,1310.71 951.698,1310.71 951.707,1310.71 951.717,1310.71 951.726,1310.71 951.735,1310.71 951.744,1310.71 951.753,1310.71 951.763,1310.71 951.772,1310.71 951.781,1310.71 951.79,1310.71 951.799,1310.71 951.809,1310.71 951.818,1310.71 951.827,1310.71 951.836,1310.72 951.845,1310.72 951.854,1310.72 951.864,1310.72 951.873,1310.72 951.882,1310.72 951.891,1310.72 951.9,1310.72 951.91,1310.72 951.919,1310.72 951.928,1310.72 951.937,1310.72 951.946,1310.72 951.956,1310.72 951.965,1310.72 951.974,1310.72 951.983,1310.73 951.992,1310.73 952.002,1310.73 952.011,1310.73 952.02,1310.73 952.029,1310.73 952.038,1310.73 952.047,1310.73 952.057,1310.73 952.066,1310.73 952.075,1310.73 952.084,1310.73 952.093,1310.73 952.103,1310.73 952.112,1310.73 952.121,1310.73 952.13,1310.73 952.139,1310.74 952.149,1310.74 952.158,1310.74 952.167,1310.74 952.176,1310.74 952.185,1310.74 952.194,1310.74 952.204,1310.74 952.213,1310.74 952.222,1310.74 952.231,1310.74 952.24,1310.74 952.25,1310.74 952.259,1310.74 952.268,1310.74 952.277,1310.74 952.286,1310.74 952.296,1310.75 952.305,1310.75 952.314,1310.75 952.323,1310.75 952.332,1310.75 952.342,1310.75 952.351,1310.75 952.36,1310.75 952.369,1310.75 952.378,1310.75 952.387,1310.75 952.397,1310.75 952.406,1310.75 952.415,1310.75 952.424,1310.75 952.433,1310.75 952.443,1310.76 952.452,1310.76 952.461,1310.76 952.47,1310.76 952.479,1310.76 952.489,1310.76 952.498,1310.76 952.507,1310.76 952.516,1310.76 952.525,1310.76 952.534,1310.76 952.544,1310.76 952.553,1310.76 952.562,1310.76 952.571,1310.76 952.58,1310.76 952.59,1310.76 952.599,1310.77 952.608,1310.77 952.617,1310.77 952.626,1310.77 952.636,1310.77 952.645,1310.77 952.654,1310.77 952.663,1310.77 952.672,1310.77 952.682,1310.77 952.691,1310.77 952.7,1310.77 952.709,1310.77 952.718,1310.77 952.727,1310.77 952.737,1310.77 952.746,1310.78 952.755,1310.78 952.764,1310.78 952.773,1310.78 952.783,1310.78 952.792,1310.78 952.801,1310.78 952.81,1310.78 952.819,1310.78 952.829,1310.78 952.838,1310.78 952.847,1310.78 952.856,1310.78 952.865,1310.78 952.875,1310.78 952.884,1310.78 952.893,1310.78 952.902,1310.79 952.911,1310.79 952.92,1310.79 952.93,1310.79 952.939,1310.79 952.948,1310.79 952.957,1310.79 952.966,1310.79 952.976,1310.79 952.985,1310.79 952.994,1310.79 953.003,1310.79 953.012,1310.79 953.022,1310.79 953.031,1310.79 953.04,1310.79 953.049,1310.8 953.058,1310.8 953.067,1310.8 953.077,1310.8 953.086,1310.8 953.095,1310.8 953.104,1310.8 953.113,1310.8 953.123,1310.8 953.132,1310.8 953.141,1310.8 953.15,1310.8 953.159,1310.8 953.169,1310.8 953.178,1310.8 953.187,1310.8 953.196,1310.8 953.205,1310.81 953.215,1310.81 953.224,1310.81 953.233,1310.81 953.242,1310.81 953.251,1310.81 953.26,1310.81 953.27,1310.81 953.279,1310.81 953.288,1310.81 953.297,1310.81 953.306,1310.81 953.316,1310.81 953.325,1310.81 953.334,1310.81 953.343,1310.81 953.352,1310.82 953.362,1310.82 953.371,1310.82 953.38,1310.82 953.389,1310.82 953.398,1310.82 953.407,1310.82 953.417,1310.82 953.426,1310.82 953.435,1310.82 953.444,1310.82 953.453,1310.82 953.463,1310.82 953.472,1310.82 953.481,1310.82 953.49,1310.82 953.499,1310.82 953.509,1310.83 953.518,1310.83 953.527,1310.83 953.536,1310.83 953.545,1310.83 953.555,1310.83 953.564,1310.83 953.573,1310.83 953.582,1310.83 953.591,1310.83 953.6,1310.83 953.61,1310.83 953.619,1310.83 953.628,1310.83 953.637,1310.83 953.646,1310.83 953.656,1310.84 953.665,1310.84 953.674,1310.84 953.683,1310.84 953.692,1310.84 953.702,1310.84 953.711,1310.84 953.72,1310.84 953.729,1310.84 953.738,1310.84 953.747,1310.84 953.757,1310.84 953.766,1310.84 953.775,1310.84 953.784,1310.84 953.793,1310.84 953.803,1310.84 953.812,1310.85 953.821,1310.85 953.83,1310.85 953.839,1310.85 953.849,1310.85 953.858,1310.85 953.867,1310.85 953.876,1310.85 953.885,1310.85 953.895,1310.85 953.904,1310.85 953.913,1310.85 953.922,1310.85 953.931,1310.85 953.94,1310.85 953.95,1310.85 953.959,1310.86 953.968,1310.86 953.977,1310.86 953.986,1310.86 953.996,1310.86 954.005,1310.86 954.014,1310.86 954.023,1310.86 954.032,1310.86 954.042,1310.86 954.051,1310.86 954.06,1310.86 954.069,1310.86 954.078,1310.86 954.087,1310.86 954.097,1310.86 954.106,1310.86 954.115,1310.87 954.124,1310.87 954.133,1310.87 954.143,1310.87 954.152,1310.87 954.161,1310.87 954.17,1310.87 954.179,1310.87 954.189,1310.87 954.198,1310.87 954.207,1310.87 954.216,1310.87 954.225,1310.87 954.235,1310.87 954.244,1310.87 954.253,1310.87 954.262,1310.88 954.271,1310.88 954.28,1310.88 954.29,1310.88 954.299,1310.88 954.308,1310.88 954.317,1310.88 954.326,1310.88 954.336,1310.88 954.345,1310.88 954.354,1310.88 954.363,1310.88 954.372,1310.88 954.382,1310.88 954.391,1310.88 954.4,1310.88 954.409,1310.88 954.418,1310.89 954.427,1310.89 954.437,1310.89 954.446,1310.89 954.455,1310.89 954.464,1310.89 954.473,1310.89 954.483,1310.89 954.492,1310.89 954.501,1310.89 954.51,1310.89 954.519,1310.89 954.529,1310.89 954.538,1310.89 954.547,1310.89 954.556,1310.89 954.565,1310.9 954.575,1310.9 954.584,1310.9 954.593,1310.9 954.602,1310.9 954.611,1310.9 954.62,1310.9 954.63,1310.9 954.639,1310.9 954.648,1310.9 954.657,1310.9 954.666,1310.9 954.676,1310.9 954.685,1310.9 954.694,1310.9 954.703,1310.9 954.712,1310.9 954.722,1310.91 954.731,1310.91 954.74,1310.91 954.749,1310.91 954.758,1310.91 954.767,1310.91 954.777,1310.91 954.786,1310.91 954.795,1310.91 954.804,1310.91 954.813,1310.91 954.823,1310.91 954.832,1310.91 954.841,1310.91 954.85,1310.91 954.859,1310.91 954.869,1310.92 954.878,1310.92 954.887,1310.92 954.896,1310.92 954.905,1310.92 954.915,1310.92 954.924,1310.92 954.933,1310.92 954.942,1310.92 954.951,1310.92 954.96,1310.92 954.97,1310.92 954.979,1310.92 954.988,1310.92 954.997,1310.92 955.006,1310.92 955.016,1310.92 955.025,1310.93 955.034,1310.93 955.043,1310.93 955.052,1310.93 955.062,1310.93 955.071,1310.93 955.08,1310.93 955.089,1310.93 955.098,1310.93 955.108,1310.93 955.117,1310.93 955.126,1310.93 955.135,1310.93 955.144,1310.93 955.153,1310.93 955.163,1310.93 955.172,1310.94 955.181,1310.94 955.19,1310.94 955.199,1310.94 955.209,1310.94 955.218,1310.94 955.227,1310.94 955.236,1310.94 955.245,1310.94 955.255,1310.94 955.264,1310.94 955.273,1310.94 955.282,1310.94 955.291,1310.94 955.3,1310.94 955.31,1310.94 955.319,1310.94 955.328,1310.95 955.337,1310.95 955.346,1310.95 955.356,1310.95 955.365,1310.95 955.374,1310.95 955.383,1310.95 955.392,1310.95 955.402,1310.95 955.411,1310.95 955.42,1310.95 955.429,1310.95 955.438,1310.95 955.448,1310.95 955.457,1310.95 955.466,1310.95 955.475,1310.96 955.484,1310.96 955.493,1310.96 955.503,1310.96 955.512,1310.96 955.521,1310.96 955.53,1310.96 955.539,1310.96 955.549,1310.96 955.558,1310.96 955.567,1310.96 955.576,1310.96 955.585,1310.96 955.595,1310.96 955.604,1310.96 955.613,1310.96 955.622,1310.96 955.631,1310.97 955.64,1310.97 955.65,1310.97 955.659,1310.97 955.668,1310.97 955.677,1310.97 955.686,1310.97 955.696,1310.97 955.705,1310.97 955.714,1310.97 955.723,1310.97 955.732,1310.97 955.742,1310.97 955.751,1310.97 955.76,1310.97 955.769,1310.97 955.778,1310.98 955.788,1310.98 955.797,1310.98 955.806,1310.98 955.815,1310.98 955.824,1310.98 955.833,1310.98 955.843,1310.98 955.852,1310.98 955.861,1310.98 955.87,1310.98 955.879,1310.98 955.889,1310.98 955.898,1310.98 955.907,1310.98 955.916,1310.98 955.925,1310.98 955.935,1310.99 955.944,1310.99 955.953,1310.99 955.962,1310.99 955.971,1310.99 955.98,1310.99 955.99,1310.99 955.999,1310.99 956.008,1310.99 956.017,1310.99 956.026,1310.99 956.036,1310.99 956.045,1310.99 956.054,1310.99 956.063,1310.99 956.072,1310.99 956.082,1311 956.091,1311 956.1,1311 956.109,1311 956.118,1311 956.128,1311 956.137,1311 956.146,1311 956.155,1311 956.164,1311 956.173,1311 956.183,1311 956.192,1311 956.201,1311 956.21,1311 956.219,1311 956.229,1311 956.238,1311.01 956.247,1311.01 956.256,1311.01 956.265,1311.01 956.275,1311.01 956.284,1311.01 956.293,1311.01 956.302,1311.01 956.311,1311.01 956.32,1311.01 956.33,1311.01 956.339,1311.01 956.348,1311.01 956.357,1311.01 956.366,1311.01 956.376,1311.01 956.385,1311.02 956.394,1311.02 956.403,1311.02 956.412,1311.02 956.422,1311.02 956.431,1311.02 956.44,1311.02 956.449,1311.02 956.458,1311.02 956.468,1311.02 956.477,1311.02 956.486,1311.02 956.495,1311.02 956.504,1311.02 956.513,1311.02 956.523,1311.02 956.532,1311.02 956.541,1311.03 956.55,1311.03 956.559,1311.03 956.569,1311.03 956.578,1311.03 956.587,1311.03 956.596,1311.03 956.605,1311.03 956.615,1311.03 956.624,1311.03 956.633,1311.03 956.642,1311.03 956.651,1311.03 956.66,1311.03 956.67,1311.03 956.679,1311.03 956.688,1311.04 956.697,1311.04 956.706,1311.04 956.716,1311.04 956.725,1311.04 956.734,1311.04 956.743,1311.04 956.752,1311.04 956.762,1311.04 956.771,1311.04 956.78,1311.04 956.789,1311.04 956.798,1311.04 956.808,1311.04 956.817,1311.04 956.826,1311.04 956.835,1311.04 956.844,1311.05 956.853,1311.05 956.863,1311.05 956.872,1311.05 956.881,1311.05 956.89,1311.05 956.899,1311.05 956.909,1311.05 956.918,1311.05 956.927,1311.05 956.936,1311.05 956.945,1311.05 956.955,1311.05 956.964,1311.05 956.973,1311.05 956.982,1311.05 956.991,1311.06 957,1311.06 957.01,1311.06 957.019,1311.06 957.028,1311.06 957.037,1311.06 957.046,1311.06 957.056,1311.06 957.065,1311.06 957.074,1311.06 957.083,1311.06 957.092,1311.06 957.102,1311.06 957.111,1311.06 957.12,1311.06 957.129,1311.06 957.138,1311.06 957.148,1311.07 957.157,1311.07 957.166,1311.07 957.175,1311.07 957.184,1311.07 957.193,1311.07 957.203,1311.07 957.212,1311.07 957.221,1311.07 957.23,1311.07 957.239,1311.07 957.249,1311.07 957.258,1311.07 957.267,1311.07 957.276,1311.07 957.285,1311.07 957.295,1311.08 957.304,1311.08 957.313,1311.08 957.322,1311.08 957.331,1311.08 957.34,1311.08 957.35,1311.08 957.359,1311.08 957.368,1311.08 957.377,1311.08 957.386,1311.08 957.396,1311.08 957.405,1311.08 957.414,1311.08 957.423,1311.08 957.432,1311.08 957.442,1311.09 957.451,1311.09 957.46,1311.09 957.469,1311.09 957.478,1311.09 957.488,1311.09 957.497,1311.09 957.506,1311.09 957.515,1311.09 957.524,1311.09 957.533,1311.09 957.543,1311.09 957.552,1311.09 957.561,1311.09 957.57,1311.09 957.579,1311.09 957.589,1311.09 957.598,1311.1 957.607,1311.1 957.616,1311.1 957.625,1311.1 957.635,1311.1 957.644,1311.1 957.653,1311.1 957.662,1311.1 957.671,1311.1 957.681,1311.1 957.69,1311.1 957.699,1311.1 957.708,1311.1 957.717,1311.1 957.726,1311.1 957.736,1311.1 957.745,1311.11 957.754,1311.11 957.763,1311.11 957.772,1311.11 957.782,1311.11 957.791,1311.11 957.8,1311.11 957.809,1311.11 957.818,1311.11 957.828,1311.11 957.837,1311.11 957.846,1311.11 957.855,1311.11 957.864,1311.11 957.873,1311.11 957.883,1311.11 957.892,1311.11 957.901,1311.12 957.91,1311.12 957.919,1311.12 957.929,1311.12 957.938,1311.12 957.947,1311.12 957.956,1311.12 957.965,1311.12 957.975,1311.12 957.984,1311.12 957.993,1311.12 958.002,1311.12 958.011,1311.12 958.021,1311.12 958.03,1311.12 958.039,1311.12 958.048,1311.13 958.057,1311.13 958.066,1311.13 958.076,1311.13 958.085,1311.13 958.094,1311.13 958.103,1311.13 958.112,1311.13 958.122,1311.13 958.131,1311.13 958.14,1311.13 958.149,1311.13 958.158,1311.13 958.168,1311.13 958.177,1311.13 958.186,1311.13 958.195,1311.13 958.204,1311.14 958.213,1311.14 958.223,1311.14 958.232,1311.14 958.241,1311.14 958.25,1311.14 958.259,1311.14 958.269,1311.14 958.278,1311.14 958.287,1311.14 958.296,1311.14 958.305,1311.14 958.315,1311.14 958.324,1311.14 958.333,1311.14 958.342,1311.14 958.351,1311.15 958.361,1311.15 958.37,1311.15 958.379,1311.15 958.388,1311.15 958.397,1311.15 958.406,1311.15 958.416,1311.15 958.425,1311.15 958.434,1311.15 958.443,1311.15 958.452,1311.15 958.462,1311.15 958.471,1311.15 958.48,1311.15 958.489,1311.15 958.498,1311.15 958.508,1311.16 958.517,1311.16 958.526,1311.16 958.535,1311.16 958.544,1311.16 958.553,1311.16 958.563,1311.16 958.572,1311.16 958.581,1311.16 958.59,1311.16 958.599,1311.16 958.609,1311.16 958.618,1311.16 958.627,1311.16 958.636,1311.16 958.645,1311.16 958.655,1311.17 958.664,1311.17 958.673,1311.17 958.682,1311.17 958.691,1311.17 958.701,1311.17 958.71,1311.17 958.719,1311.17 958.728,1311.17 958.737,1311.17 958.746,1311.17 958.756,1311.17 958.765,1311.17 958.774,1311.17 958.783,1311.17 958.792,1311.17 958.802,1311.18 958.811,1311.18 958.82,1311.18 958.829,1311.18 958.838,1311.18 958.848,1311.18 958.857,1311.18 958.866,1311.18 958.875,1311.18 958.884,1311.18 958.893,1311.18 958.903,1311.18 958.912,1311.18 958.921,1311.18 958.93,1311.18 958.939,1311.18 958.949,1311.18 958.958,1311.19 958.967,1311.19 958.976,1311.19 958.985,1311.19 958.995,1311.19 959.004,1311.19 959.013,1311.19 959.022,1311.19 959.031,1311.19 959.041,1311.19 959.05,1311.19 959.059,1311.19 959.068,1311.19 959.077,1311.19 959.086,1311.19 959.096,1311.19 959.105,1311.2 959.114,1311.2 959.123,1311.2 959.132,1311.2 959.142,1311.2 959.151,1311.2 959.16,1311.2 959.169,1311.2 959.178,1311.2 959.188,1311.2 959.197,1311.2 959.206,1311.2 959.215,1311.2 959.224,1311.2 959.233,1311.2 959.243,1311.2 959.252,1311.2 959.261,1311.21 959.27,1311.21 959.279,1311.21 959.289,1311.21 959.298,1311.21 959.307,1311.21 959.316,1311.21 959.325,1311.21 959.335,1311.21 959.344,1311.21 959.353,1311.21 959.362,1311.21 959.371,1311.21 959.381,1311.21 959.39,1311.21 959.399,1311.21 959.408,1311.22 959.417,1311.22 959.426,1311.22 959.436,1311.22 959.445,1311.22 959.454,1311.22 959.463,1311.22 959.472,1311.22 959.482,1311.22 959.491,1311.22 959.5,1311.22 959.509,1311.22 959.518,1311.22 959.528,1311.22 959.537,1311.22 959.546,1311.22 959.555,1311.22 959.564,1311.23 959.573,1311.23 959.583,1311.23 959.592,1311.23 959.601,1311.23 959.61,1311.23 959.619,1311.23 959.629,1311.23 959.638,1311.23 959.647,1311.23 959.656,1311.23 959.665,1311.23 959.675,1311.23 959.684,1311.23 959.693,1311.23 959.702,1311.23 959.711,1311.24 959.721,1311.24 959.73,1311.24 959.739,1311.24 959.748,1311.24 959.757,1311.24 959.766,1311.24 959.776,1311.24 959.785,1311.24 959.794,1311.24 959.803,1311.24 959.812,1311.24 959.822,1311.24 959.831,1311.24 959.84,1311.24 959.849,1311.24 959.858,1311.24 959.868,1311.25 959.877,1311.25 959.886,1311.25 959.895,1311.25 959.904,1311.25 959.913,1311.25 959.923,1311.25 959.932,1311.25 959.941,1311.25 959.95,1311.25 959.959,1311.25 959.969,1311.25 959.978,1311.25 959.987,1311.25 959.996,1311.25 960.005,1311.25 960.015,1311.26 960.024,1311.26 960.033,1311.26 960.042,1311.26 960.051,1311.26 960.061,1311.26 960.07,1311.26 960.079,1311.26 960.088,1311.26 960.097,1311.26 960.106,1311.26 960.116,1311.26 960.125,1311.26 960.134,1311.26 960.143,1311.26 960.152,1311.26 960.162,1311.27 960.171,1311.27 960.18,1311.27 960.189,1311.27 960.198,1311.27 960.208,1311.27 960.217,1311.27 960.226,1311.27 960.235,1311.27 960.244,1311.27 960.254,1311.27 960.263,1311.27 960.272,1311.27 960.281,1311.27 960.29,1311.27 960.299,1311.27 960.309,1311.27 960.318,1311.28 960.327,1311.28 960.336,1311.28 960.345,1311.28 960.355,1311.28 960.364,1311.28 960.373,1311.28 960.382,1311.28 960.391,1311.28 960.401,1311.28 960.41,1311.28 960.419,1311.28 960.428,1311.28 960.437,1311.28 960.446,1311.28 960.456,1311.28 960.465,1311.29 960.474,1311.29 960.483,1311.29 960.492,1311.29 960.502,1311.29 960.511,1311.29 960.52,1311.29 960.529,1311.29 960.538,1311.29 960.548,1311.29 960.557,1311.29 960.566,1311.29 960.575,1311.29 960.584,1311.29 960.594,1311.29 960.603,1311.29 960.612,1311.29 960.621,1311.3 960.63,1311.3 960.639,1311.3 960.649,1311.3 960.658,1311.3 960.667,1311.3 960.676,1311.3 960.685,1311.3 960.695,1311.3 960.704,1311.3 960.713,1311.3 960.722,1311.3 960.731,1311.3 960.741,1311.3 960.75,1311.3 960.759,1311.3 960.768,1311.31 960.777,1311.31 960.786,1311.31 960.796,1311.31 960.805,1311.31 960.814,1311.31 960.823,1311.31 960.832,1311.31 960.842,1311.31 960.851,1311.31 960.86,1311.31 960.869,1311.31 960.878,1311.31 960.888,1311.31 960.897,1311.31 960.906,1311.31 960.915,1311.32 960.924,1311.32 960.934,1311.32 960.943,1311.32 960.952,1311.32 960.961,1311.32 960.97,1311.32 960.979,1311.32 960.989,1311.32 960.998,1311.32 961.007,1311.32 961.016,1311.32 961.025,1311.32 961.035,1311.32 961.044,1311.32 961.053,1311.32 961.062,1311.32 961.071,1311.33 961.081,1311.33 961.09,1311.33 961.099,1311.33 961.108,1311.33 961.117,1311.33 961.126,1311.33 961.136,1311.33 961.145,1311.33 961.154,1311.33 961.163,1311.33 961.172,1311.33 961.182,1311.33 961.191,1311.33 961.2,1311.33 961.209,1311.33 961.218,1311.34 961.228,1311.34 961.237,1311.34 961.246,1311.34 961.255,1311.34 961.264,1311.34 961.274,1311.34 961.283,1311.34 961.292,1311.34 961.301,1311.34 961.31,1311.34 961.319,1311.34 961.329,1311.34 961.338,1311.34 961.347,1311.34 961.356,1311.34 961.365,1311.34 961.375,1311.35 961.384,1311.35 961.393,1311.35 961.402,1311.35 961.411,1311.35 961.421,1311.35 961.43,1311.35 961.439,1311.35 961.448,1311.35 961.457,1311.35 961.466,1311.35 961.476,1311.35 961.485,1311.35 961.494,1311.35 961.503,1311.35 961.512,1311.35 961.522,1311.36 961.531,1311.36 961.54,1311.36 961.549,1311.36 961.558,1311.36 961.568,1311.36 961.577,1311.36 961.586,1311.36 961.595,1311.36 961.604,1311.36 961.614,1311.36 961.623,1311.36 961.632,1311.36 961.641,1311.36 961.65,1311.36 961.659,1311.36 961.669,1311.37 961.678,1311.37 961.687,1311.37 961.696,1311.37 961.705,1311.37 961.715,1311.37 961.724,1311.37 961.733,1311.37 961.742,1311.37 961.751,1311.37 961.761,1311.37 961.77,1311.37 961.779,1311.37 961.788,1311.37 961.797,1311.37 961.806,1311.37 961.816,1311.37 961.825,1311.38 961.834,1311.38 961.843,1311.38 961.852,1311.38 961.862,1311.38 961.871,1311.38 961.88,1311.38 961.889,1311.38 961.898,1311.38 961.908,1311.38 961.917,1311.38 961.926,1311.38 961.935,1311.38 961.944,1311.38 961.954,1311.38 961.963,1311.38 961.972,1311.39 961.981,1311.39 961.99,1311.39 961.999,1311.39 962.009,1311.39 962.018,1311.39 962.027,1311.39 962.036,1311.39 962.045,1311.39 962.055,1311.39 962.064,1311.39 962.073,1311.39 962.082,1311.39 962.091,1311.39 962.101,1311.39 962.11,1311.39 962.119,1311.39 962.128,1311.4 962.137,1311.4 962.146,1311.4 962.156,1311.4 962.165,1311.4 962.174,1311.4 962.183,1311.4 962.192,1311.4 962.202,1311.4 962.211,1311.4 962.22,1311.4 962.229,1311.4 962.238,1311.4 962.248,1311.4 962.257,1311.4 962.266,1311.4 962.275,1311.41 962.284,1311.41 962.294,1311.41 962.303,1311.41 962.312,1311.41 962.321,1311.41 962.33,1311.41 962.339,1311.41 962.349,1311.41 962.358,1311.41 962.367,1311.41 962.376,1311.41 962.385,1311.41 962.395,1311.41 962.404,1311.41 962.413,1311.41 962.422,1311.42 962.431,1311.42 962.441,1311.42 962.45,1311.42 962.459,1311.42 962.468,1311.42 962.477,1311.42 962.487,1311.42 962.496,1311.42 962.505,1311.42 962.514,1311.42 962.523,1311.42 962.532,1311.42 962.542,1311.42 962.551,1311.42 962.56,1311.42 962.569,1311.42 962.578,1311.43 962.588,1311.43 962.597,1311.43 962.606,1311.43 962.615,1311.43 962.624,1311.43 962.634,1311.43 962.643,1311.43 962.652,1311.43 962.661,1311.43 962.67,1311.43 962.679,1311.43 962.689,1311.43 962.698,1311.43 962.707,1311.43 962.716,1311.43 962.725,1311.44 962.735,1311.44 962.744,1311.44 962.753,1311.44 962.762,1311.44 962.771,1311.44 962.781,1311.44 962.79,1311.44 962.799,1311.44 962.808,1311.44 962.817,1311.44 962.827,1311.44 962.836,1311.44 962.845,1311.44 962.854,1311.44 962.863,1311.44 962.872,1311.44 962.882,1311.45 962.891,1311.45 962.9,1311.45 962.909,1311.45 962.918,1311.45 962.928,1311.45 962.937,1311.45 962.946,1311.45 962.955,1311.45 962.964,1311.45 962.974,1311.45 962.983,1311.45 962.992,1311.45 963.001,1311.45 963.01,1311.45 963.019,1311.45 963.029,1311.46 963.038,1311.46 963.047,1311.46 963.056,1311.46 963.065,1311.46 963.075,1311.46 963.084,1311.46 963.093,1311.46 963.102,1311.46 963.111,1311.46 963.121,1311.46 963.13,1311.46 963.139,1311.46 963.148,1311.46 963.157,1311.46 963.167,1311.46 963.176,1311.47 963.185,1311.47 963.194,1311.47 963.203,1311.47 963.212,1311.47 963.222,1311.47 963.231,1311.47 963.24,1311.47 963.249,1311.47 963.258,1311.47 963.268,1311.47 963.277,1311.47 963.286,1311.47 963.295,1311.47 963.304,1311.47 963.314,1311.47 963.323,1311.47 963.332,1311.48 963.341,1311.48 963.35,1311.48 963.359,1311.48 963.369,1311.48 963.378,1311.48 963.387,1311.48 963.396,1311.48 963.405,1311.48 963.415,1311.48 963.424,1311.48 963.433,1311.48 963.442,1311.48 963.451,1311.48 963.461,1311.48 963.47,1311.48 963.479,1311.49 963.488,1311.49 963.497,1311.49 963.507,1311.49 963.516,1311.49 963.525,1311.49 963.534,1311.49 963.543,1311.49 963.552,1311.49 963.562,1311.49 963.571,1311.49 963.58,1311.49 963.589,1311.49 963.598,1311.49 963.608,1311.49 963.617,1311.49 963.626,1311.49 963.635,1311.5 963.644,1311.5 963.654,1311.5 963.663,1311.5 963.672,1311.5 963.681,1311.5 963.69,1311.5 963.699,1311.5 963.709,1311.5 963.718,1311.5 963.727,1311.5 963.736,1311.5 963.745,1311.5 963.755,1311.5 963.764,1311.5 963.773,1311.5 963.782,1311.51 963.791,1311.51 963.801,1311.51 963.81,1311.51 963.819,1311.51 963.828,1311.51 963.837,1311.51 963.847,1311.51 963.856,1311.51 963.865,1311.51 963.874,1311.51 963.883,1311.51 963.892,1311.51 963.902,1311.51 963.911,1311.51 963.92,1311.51 963.929,1311.52 963.938,1311.52 963.948,1311.52 963.957,1311.52 963.966,1311.52 963.975,1311.52 963.984,1311.52 963.994,1311.52 964.003,1311.52 964.012,1311.52 964.021,1311.52 964.03,1311.52 964.039,1311.52 964.049,1311.52 964.058,1311.52 964.067,1311.52 964.076,1311.52 964.085,1311.53 964.095,1311.53 964.104,1311.53 964.113,1311.53 964.122,1311.53 964.131,1311.53 964.141,1311.53 964.15,1311.53 964.159,1311.53 964.168,1311.53 964.177,1311.53 964.187,1311.53 964.196,1311.53 964.205,1311.53 964.214,1311.53 964.223,1311.53 964.232,1311.54 964.242,1311.54 964.251,1311.54 964.26,1311.54 964.269,1311.54 964.278,1311.54 964.288,1311.54 964.297,1311.54 964.306,1311.54 964.315,1311.54 964.324,1311.54 964.334,1311.54 964.343,1311.54 964.352,1311.54 964.361,1311.54 964.37,1311.54 964.379,1311.55 964.389,1311.55 964.398,1311.55 964.407,1311.55 964.416,1311.55 964.425,1311.55 964.435,1311.55 964.444,1311.55 964.453,1311.55 964.462,1311.55 964.471,1311.55 964.481,1311.55 964.49,1311.55 964.499,1311.55 964.508,1311.55 964.517,1311.55 964.527,1311.55 964.536,1311.56 964.545,1311.56 964.554,1311.56 964.563,1311.56 964.572,1311.56 964.582,1311.56 964.591,1311.56 964.6,1311.56 964.609,1311.56 964.618,1311.56 964.628,1311.56 964.637,1311.56 964.646,1311.56 964.655,1311.56 964.664,1311.56 964.674,1311.56 964.683,1311.57 964.692,1311.57 964.701,1311.57 964.71,1311.57 964.719,1311.57 964.729,1311.57 964.738,1311.57 964.747,1311.57 964.756,1311.57 964.765,1311.57 964.775,1311.57 964.784,1311.57 964.793,1311.57 964.802,1311.57 964.811,1311.57 964.821,1311.57 964.83,1311.57 964.839,1311.58 964.848,1311.58 964.857,1311.58 964.867,1311.58 964.876,1311.58 964.885,1311.58 964.894,1311.58 964.903,1311.58 964.912,1311.58 964.922,1311.58 964.931,1311.58 964.94,1311.58 964.949,1311.58 964.958,1311.58 964.968,1311.58 964.977,1311.58 964.986,1311.59 964.995,1311.59 965.004,1311.59 965.014,1311.59 965.023,1311.59 965.032,1311.59 965.041,1311.59 965.05,1311.59 965.06,1311.59 965.069,1311.59 965.078,1311.59 965.087,1311.59 965.096,1311.59 965.105,1311.59 965.115,1311.59 965.124,1311.59 965.133,1311.6 965.142,1311.6 965.151,1311.6 965.161,1311.6 965.17,1311.6 965.179,1311.6 965.188,1311.6 965.197,1311.6 965.207,1311.6 965.216,1311.6 965.225,1311.6 965.234,1311.6 965.243,1311.6 965.252,1311.6 965.262,1311.6 965.271,1311.6 965.28,1311.6 965.289,1311.61 965.298,1311.61 965.308,1311.61 965.317,1311.61 965.326,1311.61 965.335,1311.61 965.344,1311.61 965.354,1311.61 965.363,1311.61 965.372,1311.61 965.381,1311.61 965.39,1311.61 965.4,1311.61 965.409,1311.61 965.418,1311.61 965.427,1311.61 965.436,1311.62 965.445,1311.62 965.455,1311.62 965.464,1311.62 965.473,1311.62 965.482,1311.62 965.491,1311.62 965.501,1311.62 965.51,1311.62 965.519,1311.62 965.528,1311.62 965.537,1311.62 965.547,1311.62 965.556,1311.62 965.565,1311.62 965.574,1311.62 965.583,1311.63 965.592,1311.63 965.602,1311.63 965.611,1311.63 965.62,1311.63 965.629,1311.63 965.638,1311.63 965.648,1311.63 965.657,1311.63 965.666,1311.63 965.675,1311.63 965.684,1311.63 965.694,1311.63 965.703,1311.63 965.712,1311.63 965.721,1311.63 965.73,1311.63 965.74,1311.64 965.749,1311.64 965.758,1311.64 965.767,1311.64 965.776,1311.64 965.785,1311.64 965.795,1311.64 965.804,1311.64 965.813,1311.64 965.822,1311.64 965.831,1311.64 965.841,1311.64 965.85,1311.64 965.859,1311.64 965.868,1311.64 965.877,1311.64 965.887,1311.65 965.896,1311.65 965.905,1311.65 965.914,1311.65 965.923,1311.65 965.932,1311.65 965.942,1311.65 965.951,1311.65 965.96,1311.65 965.969,1311.65 965.978,1311.65 965.988,1311.65 965.997,1311.65 966.006,1311.65 966.015,1311.65 966.024,1311.65 966.034,1311.66 966.043,1311.66 966.052,1311.66 966.061,1311.66 966.07,1311.66 966.08,1311.66 966.089,1311.66 966.098,1311.66 966.107,1311.66 966.116,1311.66 966.125,1311.66 966.135,1311.66 966.144,1311.66 966.153,1311.66 966.162,1311.66 966.171,1311.66 966.181,1311.66 966.19,1311.67 966.199,1311.67 966.208,1311.67 966.217,1311.67 966.227,1311.67 966.236,1311.67 966.245,1311.67 966.254,1311.67 966.263,1311.67 966.272,1311.67 966.282,1311.67 966.291,1311.67 966.3,1311.67 966.309,1311.67 966.318,1311.67 966.328,1311.67 966.337,1311.68 966.346,1311.68 966.355,1311.68 966.364,1311.68 966.374,1311.68 966.383,1311.68 966.392,1311.68 966.401,1311.68 966.41,1311.68 966.42,1311.68 966.429,1311.68 966.438,1311.68 966.447,1311.68 966.456,1311.68 966.465,1311.68 966.475,1311.68 966.484,1311.68 966.493,1311.69 966.502,1311.69 966.511,1311.69 966.521,1311.69 966.53,1311.69 966.539,1311.69 966.548,1311.69 966.557,1311.69 966.567,1311.69 966.576,1311.69 966.585,1311.69 966.594,1311.69 966.603,1311.69 966.612,1311.69 966.622,1311.69 966.631,1311.69 966.64,1311.7 966.649,1311.7 966.658,1311.7 966.668,1311.7 966.677,1311.7 966.686,1311.7 966.695,1311.7 966.704,1311.7 966.714,1311.7 966.723,1311.7 966.732,1311.7 966.741,1311.7 966.75,1311.7 966.76,1311.7 966.769,1311.7 966.778,1311.7 966.787,1311.71 966.796,1311.71 966.805,1311.71 966.815,1311.71 966.824,1311.71 966.833,1311.71 966.842,1311.71 966.851,1311.71 966.861,1311.71 966.87,1311.71 966.879,1311.71 966.888,1311.71 966.897,1311.71 966.907,1311.71 966.916,1311.71 966.925,1311.71 966.934,1311.71 966.943,1311.72 966.952,1311.72 966.962,1311.72 966.971,1311.72 966.98,1311.72 966.989,1311.72 966.998,1311.72 967.008,1311.72 967.017,1311.72 967.026,1311.72 967.035,1311.72 967.044,1311.72 967.054,1311.72 967.063,1311.72 967.072,1311.72 967.081,1311.72 967.09,1311.73 967.1,1311.73 967.109,1311.73 967.118,1311.73 967.127,1311.73 967.136,1311.73 967.145,1311.73 967.155,1311.73 967.164,1311.73 967.173,1311.73 967.182,1311.73 967.191,1311.73 967.201,1311.73 967.21,1311.73 967.219,1311.73 967.228,1311.73 967.237,1311.74 967.247,1311.74 967.256,1311.74 967.265,1311.74 967.274,1311.74 967.283,1311.74 967.292,1311.74 967.302,1311.74 967.311,1311.74 967.32,1311.74 967.329,1311.74 967.338,1311.74 967.348,1311.74 967.357,1311.74 967.366,1311.74 967.375,1311.74 967.384,1311.74 967.394,1311.75 967.403,1311.75 967.412,1311.75 967.421,1311.75 967.43,1311.75 967.44,1311.75 967.449,1311.75 967.458,1311.75 967.467,1311.75 967.476,1311.75 967.485,1311.75 967.495,1311.75 967.504,1311.75 967.513,1311.75 967.522,1311.75 967.531,1311.75 967.541,1311.76 967.55,1311.76 967.559,1311.76 967.568,1311.76 967.577,1311.76 967.587,1311.76 967.596,1311.76 967.605,1311.76 967.614,1311.76 967.623,1311.76 967.633,1311.76 967.642,1311.76 967.651,1311.76 967.66,1311.76 967.669,1311.76 967.678,1311.76 967.688,1311.77 967.697,1311.77 967.706,1311.77 967.715,1311.77 967.724,1311.77 967.734,1311.77 967.743,1311.77 967.752,1311.77 967.761,1311.77 967.77,1311.77 967.78,1311.77 967.789,1311.77 967.798,1311.77 967.807,1311.77 967.816,1311.77 967.825,1311.77 967.835,1311.77 967.844,1311.78 967.853,1311.78 967.862,1311.78 967.871,1311.78 967.881,1311.78 967.89,1311.78 967.899,1311.78 967.908,1311.78 967.917,1311.78 967.927,1311.78 967.936,1311.78 967.945,1311.78 967.954,1311.78 967.963,1311.78 967.973,1311.78 967.982,1311.78 967.991,1311.79 968,1311.79 968.009,1311.79 968.018,1311.79 968.028,1311.79 968.037,1311.79 968.046,1311.79 968.055,1311.79 968.064,1311.79 968.074,1311.79 968.083,1311.79 968.092,1311.79 968.101,1311.79 968.11,1311.79 968.12,1311.79 968.129,1311.79 968.138,1311.8 968.147,1311.8 968.156,1311.8 968.165,1311.8 968.175,1311.8 968.184,1311.8 968.193,1311.8 968.202,1311.8 968.211,1311.8 968.221,1311.8 968.23,1311.8 968.239,1311.8 968.248,1311.8 968.257,1311.8 968.267,1311.8 968.276,1311.8 968.285,1311.8 968.294,1311.81 968.303,1311.81 968.313,1311.81 968.322,1311.81 968.331,1311.81 968.34,1311.81 968.349,1311.81 968.358,1311.81 968.368,1311.81 968.377,1311.81 968.386,1311.81 968.395,1311.81 968.404,1311.81 968.414,1311.81 968.423,1311.81 968.432,1311.81 968.441,1311.82 968.45,1311.82 968.46,1311.82 968.469,1311.82 968.478,1311.82 968.487,1311.82 968.496,1311.82 968.505,1311.82 968.515,1311.82 968.524,1311.82 968.533,1311.82 968.542,1311.82 968.551,1311.82 968.561,1311.82 968.57,1311.82 968.579,1311.82 968.588,1311.83 968.597,1311.83 968.607,1311.83 968.616,1311.83 968.625,1311.83 968.634,1311.83 968.643,1311.83 968.653,1311.83 968.662,1311.83 968.671,1311.83 968.68,1311.83 968.689,1311.83 968.698,1311.83 968.708,1311.83 968.717,1311.83 968.726,1311.83 968.735,1311.83 968.744,1311.84 968.754,1311.84 968.763,1311.84 968.772,1311.84 968.781,1311.84 968.79,1311.84 968.8,1311.84 968.809,1311.84 968.818,1311.84 968.827,1311.84 968.836,1311.84 968.845,1311.84 968.855,1311.84 968.864,1311.84 968.873,1311.84 968.882,1311.84 968.891,1311.85 968.901,1311.85 968.91,1311.85 968.919,1311.85 968.928,1311.85 968.937,1311.85 968.947,1311.85 968.956,1311.85 968.965,1311.85 968.974,1311.85 968.983,1311.85 968.993,1311.85 969.002,1311.85 969.011,1311.85 969.02,1311.85 969.029,1311.85 969.038,1311.86 969.048,1311.86 969.057,1311.86 969.066,1311.86 969.075,1311.86 969.084,1311.86 969.094,1311.86 969.103,1311.86 969.112,1311.86 969.121,1311.86 969.13,1311.86 969.14,1311.86 969.149,1311.86 969.158,1311.86 969.167,1311.86 969.176,1311.86 969.185,1311.86 969.195,1311.87 969.204,1311.87 969.213,1311.87 969.222,1311.87 969.231,1311.87 969.241,1311.87 969.25,1311.87 969.259,1311.87 969.268,1311.87 969.277,1311.87 969.287,1311.87 969.296,1311.87 969.305,1311.87 969.314,1311.87 969.323,1311.87 969.333,1311.87 969.342,1311.88 969.351,1311.88 969.36,1311.88 969.369,1311.88 969.378,1311.88 969.388,1311.88 969.397,1311.88 969.406,1311.88 969.415,1311.88 969.424,1311.88 969.434,1311.88 969.443,1311.88 969.452,1311.88 969.461,1311.88 969.47,1311.88 969.48,1311.88 969.489,1311.89 969.498,1311.89 969.507,1311.89 969.516,1311.89 969.525,1311.89 969.535,1311.89 969.544,1311.89 969.553,1311.89 969.562,1311.89 969.571,1311.89 969.581,1311.89 969.59,1311.89 969.599,1311.89 969.608,1311.89 969.617,1311.89 969.627,1311.89 969.636,1311.89 969.645,1311.9 969.654,1311.9 969.663,1311.9 969.673,1311.9 969.682,1311.9 969.691,1311.9 969.7,1311.9 969.709,1311.9 969.718,1311.9 969.728,1311.9 969.737,1311.9 969.746,1311.9 969.755,1311.9 969.764,1311.9 969.774,1311.9 969.783,1311.9 969.792,1311.91 969.801,1311.91 969.81,1311.91 969.82,1311.91 969.829,1311.91 969.838,1311.91 969.847,1311.91 969.856,1311.91 969.866,1311.91 969.875,1311.91 969.884,1311.91 969.893,1311.91 969.902,1311.91 969.911,1311.91 969.921,1311.91 969.93,1311.91 969.939,1311.92 969.948,1311.92 969.957,1311.92 969.967,1311.92 969.976,1311.92 969.985,1311.92 969.994,1311.92 970.003,1311.92 970.013,1311.92 970.022,1311.92 970.031,1311.92 970.04,1311.92 970.049,1311.92 970.058,1311.92 970.068,1311.92 970.077,1311.92 970.086,1311.92 970.095,1311.93 970.104,1311.93 970.114,1311.93 970.123,1311.93 970.132,1311.93 970.141,1311.93 970.15,1311.93 970.16,1311.93 970.169,1311.93 970.178,1311.93 970.187,1311.93 970.196,1311.93 970.206,1311.93 970.215,1311.93 970.224,1311.93 970.233,1311.93 970.242,1311.94 970.251,1311.94 970.261,1311.94 970.27,1311.94 970.279,1311.94 970.288,1311.94 970.297,1311.94 970.307,1311.94 970.316,1311.94 970.325,1311.94 970.334,1311.94 970.343,1311.94 970.353,1311.94 970.362,1311.94 970.371,1311.94 970.38,1311.94 970.389,1311.95 970.398,1311.95 970.408,1311.95 970.417,1311.95 970.426,1311.95 970.435,1311.95 970.444,1311.95 970.454,1311.95 970.463,1311.95 970.472,1311.95 970.481,1311.95 970.49,1311.95 970.5,1311.95 970.509,1311.95 970.518,1311.95 970.527,1311.95 970.536,1311.96 970.546,1311.96 970.555,1311.96 970.564,1311.96 970.573,1311.96 970.582,1311.96 970.591,1311.96 970.601,1311.96 970.61,1311.96 970.619,1311.96 970.628,1311.96 970.637,1311.96 970.647,1311.96 970.656,1311.96 970.665,1311.96 970.674,1311.96 970.683,1311.96 970.693,1311.97 970.702,1311.97 970.711,1311.97 970.72,1311.97 970.729,1311.97 970.738,1311.97 970.748,1311.97 970.757,1311.97 970.766,1311.97 970.775,1311.97 970.784,1311.97 970.794,1311.97 970.803,1311.97 970.812,1311.97 970.821,1311.97 970.83,1311.97 970.84,1311.98 970.849,1311.98 970.858,1311.98 970.867,1311.98 970.876,1311.98 970.886,1311.98 970.895,1311.98 970.904,1311.98 970.913,1311.98 970.922,1311.98 970.931,1311.98 970.941,1311.98 970.95,1311.98 970.959,1311.98 970.968,1311.98 970.977,1311.98 970.987,1311.99 970.996,1311.99 971.005,1311.99 971.014,1311.99 971.023,1311.99 971.033,1311.99 971.042,1311.99 971.051,1311.99 971.06,1311.99 971.069,1311.99 971.078,1311.99 971.088,1311.99 971.097,1311.99 971.106,1311.99 971.115,1311.99 971.124,1311.99 971.134,1311.99 971.143,1312 971.152,1312 971.161,1312 971.17,1312 971.18,1312 971.189,1312 971.198,1312 971.207,1312 971.216,1312 971.226,1312 971.235,1312 971.244,1312 971.253,1312 971.262,1312 971.271,1312 971.281,1312 971.29,1312.01 971.299,1312.01 971.308,1312.01 971.317,1312.01 971.327,1312.01 971.336,1312.01 971.345,1312.01 971.354,1312.01 971.363,1312.01 971.373,1312.01 971.382,1312.01 971.391,1312.01 971.4,1312.01 971.409,1312.01 971.418,1312.01 971.428,1312.01 971.437,1312.02 971.446,1312.02 971.455,1312.02 971.464,1312.02 971.474,1312.02 971.483,1312.02 971.492,1312.02 971.501,1312.02 971.51,1312.02 971.52,1312.02 971.529,1312.02 971.538,1312.02 971.547,1312.02 971.556,1312.02 971.566,1312.02 971.575,1312.02 971.584,1312.02 971.593,1312.03 971.602,1312.03 971.611,1312.03 971.621,1312.03 971.63,1312.03 971.639,1312.03 971.648,1312.03 971.657,1312.03 971.667,1312.03 971.676,1312.03 971.685,1312.03 971.694,1312.03 971.703,1312.03 971.713,1312.03 971.722,1312.03 971.731,1312.03 971.74,1312.04 971.749,1312.04 971.758,1312.04 971.768,1312.04 971.777,1312.04 971.786,1312.04 971.795,1312.04 971.804,1312.04 971.814,1312.04 971.823,1312.04 971.832,1312.04 971.841,1312.04 971.85,1312.04 971.86,1312.04 971.869,1312.04 971.878,1312.04 971.887,1312.05 971.896,1312.05 971.906,1312.05 971.915,1312.05 971.924,1312.05 971.933,1312.05 971.942,1312.05 971.951,1312.05 971.961,1312.05 971.97,1312.05 971.979,1312.05 971.988,1312.05 971.997,1312.05 972.007,1312.05 972.016,1312.05 972.025,1312.05 972.034,1312.05 972.043,1312.06 972.053,1312.06 972.062,1312.06 972.071,1312.06 972.08,1312.06 972.089,1312.06 972.098,1312.06 972.108,1312.06 972.117,1312.06 972.126,1312.06 972.135,1312.06 972.144,1312.06 972.154,1312.06 972.163,1312.06 972.172,1312.06 972.181,1312.06 972.19,1312.07 972.2,1312.07 972.209,1312.07 972.218,1312.07 972.227,1312.07 972.236,1312.07 972.246,1312.07 972.255,1312.07 972.264,1312.07 972.273,1312.07 972.282,1312.07 972.291,1312.07 972.301,1312.07 972.31,1312.07 972.319,1312.07 972.328,1312.07 972.337,1312.08 972.347,1312.08 972.356,1312.08 972.365,1312.08 972.374,1312.08 972.383,1312.08 972.393,1312.08 972.402,1312.08 972.411,1312.08 972.42,1312.08 972.429,1312.08 972.439,1312.08 972.448,1312.08 972.457,1312.08 972.466,1312.08 972.475,1312.08 972.484,1312.09 972.494,1312.09 972.503,1312.09 972.512,1312.09 972.521,1312.09 972.53,1312.09 972.54,1312.09 972.549,1312.09 972.558,1312.09 972.567,1312.09 972.576,1312.09 972.586,1312.09 972.595,1312.09 972.604,1312.09 972.613,1312.09 972.622,1312.09 972.631,1312.09 972.641,1312.1 972.65,1312.1 972.659,1312.1 972.668,1312.1 972.677,1312.1 972.687,1312.1 972.696,1312.1 972.705,1312.1 972.714,1312.1 972.723,1312.1 972.733,1312.1 972.742,1312.1 972.751,1312.1 972.76,1312.1 972.769,1312.1 972.779,1312.1 972.788,1312.11 972.797,1312.11 972.806,1312.11 972.815,1312.11 972.824,1312.11 972.834,1312.11 972.843,1312.11 972.852,1312.11 972.861,1312.11 972.87,1312.11 972.88,1312.11 972.889,1312.11 972.898,1312.11 972.907,1312.11 972.916,1312.11 972.926,1312.11 972.935,1312.12 972.944,1312.12 972.953,1312.12 972.962,1312.12 972.971,1312.12 972.981,1312.12 972.99,1312.12 972.999,1312.12 973.008,1312.12 973.017,1312.12 973.027,1312.12 973.036,1312.12 973.045,1312.12 973.054,1312.12 973.063,1312.12 973.073,1312.12 973.082,1312.12 973.091,1312.13 973.1,1312.13 973.109,1312.13 973.119,1312.13 973.128,1312.13 973.137,1312.13 973.146,1312.13 973.155,1312.13 973.164,1312.13 973.174,1312.13 973.183,1312.13 973.192,1312.13 973.201,1312.13 973.21,1312.13 973.22,1312.13 973.229,1312.13 973.238,1312.14 973.247,1312.14 973.256,1312.14 973.266,1312.14 973.275,1312.14 973.284,1312.14 973.293,1312.14 973.302,1312.14 973.311,1312.14 973.321,1312.14 973.33,1312.14 973.339,1312.14 973.348,1312.14 973.357,1312.14 973.367,1312.14 973.376,1312.14 973.385,1312.15 973.394,1312.15 973.403,1312.15 973.413,1312.15 973.422,1312.15 973.431,1312.15 973.44,1312.15 973.449,1312.15 973.459,1312.15 973.468,1312.15 973.477,1312.15 973.486,1312.15 973.495,1312.15 973.504,1312.15 973.514,1312.15 973.523,1312.15 973.532,1312.16 973.541,1312.16 973.55,1312.16 973.56,1312.16 973.569,1312.16 973.578,1312.16 973.587,1312.16 973.596,1312.16 973.606,1312.16 973.615,1312.16 973.624,1312.16 973.633,1312.16 973.642,1312.16 973.651,1312.16 973.661,1312.16 973.67,1312.16 973.679,1312.16 973.688,1312.17 973.697,1312.17 973.707,1312.17 973.716,1312.17 973.725,1312.17 973.734,1312.17 973.743,1312.17 973.753,1312.17 973.762,1312.17 973.771,1312.17 973.78,1312.17 973.789,1312.17 973.799,1312.17 973.808,1312.17 973.817,1312.17 973.826,1312.17 973.835,1312.18 973.844,1312.18 973.854,1312.18 973.863,1312.18 973.872,1312.18 973.881,1312.18 973.89,1312.18 973.9,1312.18 973.909,1312.18 973.918,1312.18 973.927,1312.18 973.936,1312.18 973.946,1312.18 973.955,1312.18 973.964,1312.18 973.973,1312.18 973.982,1312.19 973.991,1312.19 974.001,1312.19 974.01,1312.19 974.019,1312.19 974.028,1312.19 974.037,1312.19 974.047,1312.19 974.056,1312.19 974.065,1312.19 974.074,1312.19 974.083,1312.19 974.093,1312.19 974.102,1312.19 974.111,1312.19 974.12,1312.19 974.129,1312.19 974.139,1312.2 974.148,1312.2 974.157,1312.2 974.166,1312.2 974.175,1312.2 974.184,1312.2 974.194,1312.2 974.203,1312.2 974.212,1312.2 974.221,1312.2 974.23,1312.2 974.24,1312.2 974.249,1312.2 974.258,1312.2 974.267,1312.2 974.276,1312.2 974.286,1312.21 974.295,1312.21 974.304,1312.21 974.313,1312.21 974.322,1312.21 974.331,1312.21 974.341,1312.21 974.35,1312.21 974.359,1312.21 974.368,1312.21 974.377,1312.21 974.387,1312.21 974.396,1312.21 974.405,1312.21 974.414,1312.21 974.423,1312.21 974.433,1312.22 974.442,1312.22 974.451,1312.22 974.46,1312.22 974.469,1312.22 974.479,1312.22 974.488,1312.22 974.497,1312.22 974.506,1312.22 974.515,1312.22 974.524,1312.22 974.534,1312.22 974.543,1312.22 974.552,1312.22 974.561,1312.22 974.57,1312.22 974.58,1312.23 974.589,1312.23 974.598,1312.23 974.607,1312.23 974.616,1312.23 974.626,1312.23 974.635,1312.23 974.644,1312.23 974.653,1312.23 974.662,1312.23 974.671,1312.23 974.681,1312.23 974.69,1312.23 974.699,1312.23 974.708,1312.23 974.717,1312.23 974.727,1312.23 974.736,1312.24 974.745,1312.24 974.754,1312.24 974.763,1312.24 974.773,1312.24 974.782,1312.24 974.791,1312.24 974.8,1312.24 974.809,1312.24 974.819,1312.24 974.828,1312.24 974.837,1312.24 974.846,1312.24 974.855,1312.24 974.864,1312.24 974.874,1312.24 974.883,1312.25 974.892,1312.25 974.901,1312.25 974.91,1312.25 974.92,1312.25 974.929,1312.25 974.938,1312.25 974.947,1312.25 974.956,1312.25 974.966,1312.25 974.975,1312.25 974.984,1312.25 974.993,1312.25 975.002,1312.25 975.012,1312.25 975.021,1312.25 975.03,1312.26 975.039,1312.26 975.048,1312.26 975.057,1312.26 975.067,1312.26 975.076,1312.26 975.085,1312.26 975.094,1312.26 975.103,1312.26 975.113,1312.26 975.122,1312.26 975.131,1312.26 975.14,1312.26 975.149,1312.26 975.159,1312.26 975.168,1312.26 975.177,1312.26 975.186,1312.27 975.195,1312.27 975.204,1312.27 975.214,1312.27 975.223,1312.27 975.232,1312.27 975.241,1312.27 975.25,1312.27 975.26,1312.27 975.269,1312.27 975.278,1312.27 975.287,1312.27 975.296,1312.27 975.306,1312.27 975.315,1312.27 975.324,1312.27 975.333,1312.28 975.342,1312.28 975.352,1312.28 975.361,1312.28 975.37,1312.28 975.379,1312.28 975.388,1312.28 975.397,1312.28 975.407,1312.28 975.416,1312.28 975.425,1312.28 975.434,1312.28 975.443,1312.28 975.453,1312.28 975.462,1312.28 975.471,1312.28 975.48,1312.29 975.489,1312.29 975.499,1312.29 975.508,1312.29 975.517,1312.29 975.526,1312.29 975.535,1312.29 975.544,1312.29 975.554,1312.29 975.563,1312.29 975.572,1312.29 975.581,1312.29 975.59,1312.29 975.6,1312.29 975.609,1312.29 975.618,1312.29 975.627,1312.3 975.636,1312.3 975.646,1312.3 975.655,1312.3 975.664,1312.3 975.673,1312.3 975.682,1312.3 975.692,1312.3 975.701,1312.3 975.71,1312.3 975.719,1312.3 975.728,1312.3 975.737,1312.3 975.747,1312.3 975.756,1312.3 975.765,1312.3 975.774,1312.3 975.783,1312.31 975.793,1312.31 975.802,1312.31 975.811,1312.31 975.82,1312.31 975.829,1312.31 975.839,1312.31 975.848,1312.31 975.857,1312.31 975.866,1312.31 975.875,1312.31 975.884,1312.31 975.894,1312.31 975.903,1312.31 975.912,1312.31 975.921,1312.31 975.93,1312.32 975.94,1312.32 975.949,1312.32 975.958,1312.32 975.967,1312.32 975.976,1312.32 975.986,1312.32 975.995,1312.32 976.004,1312.32 976.013,1312.32 976.022,1312.32 976.032,1312.32 976.041,1312.32 976.05,1312.32 976.059,1312.32 976.068,1312.32 976.077,1312.33 976.087,1312.33 976.096,1312.33 976.105,1312.33 976.114,1312.33 976.123,1312.33 976.133,1312.33 976.142,1312.33 976.151,1312.33 976.16,1312.33 976.169,1312.33 976.179,1312.33 976.188,1312.33 976.197,1312.33 976.206,1312.33 976.215,1312.33 976.224,1312.34 976.234,1312.34 976.243,1312.34 976.252,1312.34 976.261,1312.34 976.27,1312.34 976.28,1312.34 976.289,1312.34 976.298,1312.34 976.307,1312.34 976.316,1312.34 976.326,1312.34 976.335,1312.34 976.344,1312.34 976.353,1312.34 976.362,1312.34 976.372,1312.34 976.381,1312.35 976.39,1312.35 976.399,1312.35 976.408,1312.35 976.417,1312.35 976.427,1312.35 976.436,1312.35 976.445,1312.35 976.454,1312.35 976.463,1312.35 976.473,1312.35 976.482,1312.35 976.491,1312.35 976.5,1312.35 976.509,1312.35 976.519,1312.35 976.528,1312.36 976.537,1312.36 976.546,1312.36 976.555,1312.36 976.564,1312.36 976.574,1312.36 976.583,1312.36 976.592,1312.36 976.601,1312.36 976.61,1312.36 976.62,1312.36 976.629,1312.36 976.638,1312.36 976.647,1312.36 976.656,1312.36 976.666,1312.36 976.675,1312.37 976.684,1312.37 976.693,1312.37 976.702,1312.37 976.712,1312.37 976.721,1312.37 976.73,1312.37 976.739,1312.37 976.748,1312.37 976.757,1312.37 976.767,1312.37 976.776,1312.37 976.785,1312.37 976.794,1312.37 976.803,1312.37 976.813,1312.37 976.822,1312.37 976.831,1312.38 976.84,1312.38 976.849,1312.38 976.859,1312.38 976.868,1312.38 976.877,1312.38 976.886,1312.38 976.895,1312.38 976.904,1312.38 976.914,1312.38 976.923,1312.38 976.932,1312.38 976.941,1312.38 976.95,1312.38 976.96,1312.38 976.969,1312.38 976.978,1312.39 976.987,1312.39 976.996,1312.39 977.006,1312.39 977.015,1312.39 977.024,1312.39 977.033,1312.39 977.042,1312.39 977.052,1312.39 977.061,1312.39 977.07,1312.39 977.079,1312.39 977.088,1312.39 977.097,1312.39 977.107,1312.39 977.116,1312.39 977.125,1312.4 977.134,1312.4 977.143,1312.4 977.153,1312.4 977.162,1312.4 977.171,1312.4 977.18,1312.4 977.189,1312.4 977.199,1312.4 977.208,1312.4 977.217,1312.4 977.226,1312.4 977.235,1312.4 977.245,1312.4 977.254,1312.4 977.263,1312.4 977.272,1312.41 977.281,1312.41 977.29,1312.41 977.3,1312.41 977.309,1312.41 977.318,1312.41 977.327,1312.41 977.336,1312.41 977.346,1312.41 977.355,1312.41 977.364,1312.41 977.373,1312.41 977.382,1312.41 977.392,1312.41 977.401,1312.41 977.41,1312.41 977.419,1312.41 977.428,1312.42 977.437,1312.42 977.447,1312.42 977.456,1312.42 977.465,1312.42 977.474,1312.42 977.483,1312.42 977.493,1312.42 977.502,1312.42 977.511,1312.42 977.52,1312.42 977.529,1312.42 977.539,1312.42 977.548,1312.42 977.557,1312.42 977.566,1312.42 977.575,1312.43 977.585,1312.43 977.594,1312.43 977.603,1312.43 977.612,1312.43 977.621,1312.43 977.63,1312.43 977.64,1312.43 977.649,1312.43 977.658,1312.43 977.667,1312.43 977.676,1312.43 977.686,1312.43 977.695,1312.43 977.704,1312.43 977.713,1312.43 977.722,1312.44 977.732,1312.44 977.741,1312.44 977.75,1312.44 977.759,1312.44 977.768,1312.44 977.777,1312.44 977.787,1312.44 977.796,1312.44 977.805,1312.44 977.814,1312.44 977.823,1312.44 977.833,1312.44 977.842,1312.44 977.851,1312.44 977.86,1312.44 977.869,1312.45 977.879,1312.45 977.888,1312.45 977.897,1312.45 977.906,1312.45 977.915,1312.45 977.925,1312.45 977.934,1312.45 977.943,1312.45 977.952,1312.45 977.961,1312.45 977.97,1312.45 977.98,1312.45 977.989,1312.45 977.998,1312.45 978.007,1312.45 978.016,1312.45 978.026,1312.46 978.035,1312.46 978.044,1312.46 978.053,1312.46 978.062,1312.46 978.072,1312.46 978.081,1312.46 978.09,1312.46 978.099,1312.46 978.108,1312.46 978.117,1312.46 978.127,1312.46 978.136,1312.46 978.145,1312.46 978.154,1312.46 978.163,1312.46 978.173,1312.47 978.182,1312.47 978.191,1312.47 978.2,1312.47 978.209,1312.47 978.219,1312.47 978.228,1312.47 978.237,1312.47 978.246,1312.47 978.255,1312.47 978.265,1312.47 978.274,1312.47 978.283,1312.47 978.292,1312.47 978.301,1312.47 978.31,1312.47 978.32,1312.48 978.329,1312.48 978.338,1312.48 978.347,1312.48 978.356,1312.48 978.366,1312.48 978.375,1312.48 978.384,1312.48 978.393,1312.48 978.402,1312.48 978.412,1312.48 978.421,1312.48 978.43,1312.48 978.439,1312.48 978.448,1312.48 978.457,1312.48 978.467,1312.49 978.476,1312.49 978.485,1312.49 978.494,1312.49 978.503,1312.49 978.513,1312.49 978.522,1312.49 978.531,1312.49 978.54,1312.49 978.549,1312.49 978.559,1312.49 978.568,1312.49 978.577,1312.49 978.586,1312.49 978.595,1312.49 978.605,1312.49 978.614,1312.49 978.623,1312.5 978.632,1312.5 978.641,1312.5 978.65,1312.5 978.66,1312.5 978.669,1312.5 978.678,1312.5 978.687,1312.5 978.696,1312.5 978.706,1312.5 978.715,1312.5 978.724,1312.5 978.733,1312.5 978.742,1312.5 978.752,1312.5 978.761,1312.5 978.77,1312.51 978.779,1312.51 978.788,1312.51 978.797,1312.51 978.807,1312.51 978.816,1312.51 978.825,1312.51 978.834,1312.51 978.843,1312.51 978.853,1312.51 978.862,1312.51 978.871,1312.51 978.88,1312.51 978.889,1312.51 978.899,1312.51 978.908,1312.51 978.917,1312.52 978.926,1312.52 978.935,1312.52 978.945,1312.52 978.954,1312.52 978.963,1312.52 978.972,1312.52 978.981,1312.52 978.99,1312.52 979,1312.52 979.009,1312.52 979.018,1312.52 979.027,1312.52 979.036,1312.52 979.046,1312.52 979.055,1312.52 979.064,1312.53 979.073,1312.53 979.082,1312.53 979.092,1312.53 979.101,1312.53 979.11,1312.53 979.119,1312.53 979.128,1312.53 979.137,1312.53 979.147,1312.53 979.156,1312.53 979.165,1312.53 979.174,1312.53 979.183,1312.53 979.193,1312.53 979.202,1312.53 979.211,1312.53 979.22,1312.54 979.229,1312.54 979.239,1312.54 979.248,1312.54 979.257,1312.54 979.266,1312.54 979.275,1312.54 979.285,1312.54 979.294,1312.54 979.303,1312.54 979.312,1312.54 979.321,1312.54 979.33,1312.54 979.34,1312.54 979.349,1312.54 979.358,1312.54 979.367,1312.55 979.376,1312.55 979.386,1312.55 979.395,1312.55 979.404,1312.55 979.413,1312.55 979.422,1312.55 979.432,1312.55 979.441,1312.55 979.45,1312.55 979.459,1312.55 979.468,1312.55 979.477,1312.55 979.487,1312.55 979.496,1312.55 979.505,1312.55 979.514,1312.56 979.523,1312.56 979.533,1312.56 979.542,1312.56 979.551,1312.56 979.56,1312.56 979.569,1312.56 979.579,1312.56 979.588,1312.56 979.597,1312.56 979.606,1312.56 979.615,1312.56 979.625,1312.56 979.634,1312.56 979.643,1312.56 979.652,1312.56 979.661,1312.57 979.67,1312.57 979.68,1312.57 979.689,1312.57 979.698,1312.57 979.707,1312.57 979.716,1312.57 979.726,1312.57 979.735,1312.57 979.744,1312.57 979.753,1312.57 979.762,1312.57 979.772,1312.57 979.781,1312.57 979.79,1312.57 979.799,1312.57 979.808,1312.57 979.818,1312.58 979.827,1312.58 979.836,1312.58 979.845,1312.58 979.854,1312.58 979.863,1312.58 979.873,1312.58 979.882,1312.58 979.891,1312.58 979.9,1312.58 979.909,1312.58 979.919,1312.58 979.928,1312.58 979.937,1312.58 979.946,1312.58 979.955,1312.58 979.965,1312.59 979.974,1312.59 979.983,1312.59 979.992,1312.59 980.001,1312.59 980.01,1312.59 980.02,1312.59 980.029,1312.59 980.038,1312.59 980.047,1312.59 980.056,1312.59 980.066,1312.59 980.075,1312.59 980.084,1312.59 980.093,1312.59 980.102,1312.59 980.112,1312.6 980.121,1312.6 980.13,1312.6 980.139,1312.6 980.148,1312.6 980.158,1312.6 980.167,1312.6 980.176,1312.6 980.185,1312.6 980.194,1312.6 980.203,1312.6 980.213,1312.6 980.222,1312.6 980.231,1312.6 980.24,1312.6 980.249,1312.6 980.259,1312.61 980.268,1312.61 980.277,1312.61 980.286,1312.61 980.295,1312.61 980.305,1312.61 980.314,1312.61 980.323,1312.61 980.332,1312.61 980.341,1312.61 980.35,1312.61 980.36,1312.61 980.369,1312.61 980.378,1312.61 980.387,1312.61 980.396,1312.61 980.406,1312.61 980.415,1312.62 980.424,1312.62 980.433,1312.62 980.442,1312.62 980.452,1312.62 980.461,1312.62 980.47,1312.62 980.479,1312.62 980.488,1312.62 980.498,1312.62 980.507,1312.62 980.516,1312.62 980.525,1312.62 980.534,1312.62 980.543,1312.62 980.553,1312.62 980.562,1312.63 980.571,1312.63 980.58,1312.63 980.589,1312.63 980.599,1312.63 980.608,1312.63 980.617,1312.63 980.626,1312.63 980.635,1312.63 980.645,1312.63 980.654,1312.63 980.663,1312.63 980.672,1312.63 980.681,1312.63 980.69,1312.63 980.7,1312.63 980.709,1312.64 980.718,1312.64 980.727,1312.64 980.736,1312.64 980.746,1312.64 980.755,1312.64 980.764,1312.64 980.773,1312.64 980.782,1312.64 980.792,1312.64 980.801,1312.64 980.81,1312.64 980.819,1312.64 980.828,1312.64 980.838,1312.64 980.847,1312.64 980.856,1312.65 980.865,1312.65 980.874,1312.65 980.883,1312.65 980.893,1312.65 980.902,1312.65 980.911,1312.65 980.92,1312.65 980.929,1312.65 980.939,1312.65 980.948,1312.65 980.957,1312.65 980.966,1312.65 980.975,1312.65 980.985,1312.65 980.994,1312.65 981.003,1312.65 981.012,1312.66 981.021,1312.66 981.03,1312.66 981.04,1312.66 981.049,1312.66 981.058,1312.66 981.067,1312.66 981.076,1312.66 981.086,1312.66 981.095,1312.66 981.104,1312.66 981.113,1312.66 981.122,1312.66 981.132,1312.66 981.141,1312.66 981.15,1312.66 981.159,1312.67 981.168,1312.67 981.178,1312.67 981.187,1312.67 981.196,1312.67 981.205,1312.67 981.214,1312.67 981.223,1312.67 981.233,1312.67 981.242,1312.67 981.251,1312.67 981.26,1312.67 981.269,1312.67 981.279,1312.67 981.288,1312.67 981.297,1312.67 981.306,1312.68 981.315,1312.68 981.325,1312.68 981.334,1312.68 981.343,1312.68 981.352,1312.68 981.361,1312.68 981.37,1312.68 981.38,1312.68 981.389,1312.68 981.398,1312.68 981.407,1312.68 981.416,1312.68 981.426,1312.68 981.435,1312.68 981.444,1312.68 981.453,1312.69 981.462,1312.69 981.472,1312.69 981.481,1312.69 981.49,1312.69 981.499,1312.69 981.508,1312.69 981.518,1312.69 981.527,1312.69 981.536,1312.69 981.545,1312.69 981.554,1312.69 981.563,1312.69 981.573,1312.69 981.582,1312.69 981.591,1312.69 981.6,1312.69 981.609,1312.7 981.619,1312.7 981.628,1312.7 981.637,1312.7 981.646,1312.7 981.655,1312.7 981.665,1312.7 981.674,1312.7 981.683,1312.7 981.692,1312.7 981.701,1312.7 981.71,1312.7 981.72,1312.7 981.729,1312.7 981.738,1312.7 981.747,1312.7 981.756,1312.71 981.766,1312.71 981.775,1312.71 981.784,1312.71 981.793,1312.71 981.802,1312.71 981.812,1312.71 981.821,1312.71 981.83,1312.71 981.839,1312.71 981.848,1312.71 981.858,1312.71 981.867,1312.71 981.876,1312.71 981.885,1312.71 981.894,1312.71 981.903,1312.72 981.913,1312.72 981.922,1312.72 981.931,1312.72 981.94,1312.72 981.949,1312.72 981.959,1312.72 981.968,1312.72 981.977,1312.72 981.986,1312.72 981.995,1312.72 982.005,1312.72 982.014,1312.72 982.023,1312.72 982.032,1312.72 982.041,1312.72 982.05,1312.73 982.06,1312.73 982.069,1312.73 982.078,1312.73 982.087,1312.73 982.096,1312.73 982.106,1312.73 982.115,1312.73 982.124,1312.73 982.133,1312.73 982.142,1312.73 982.152,1312.73 982.161,1312.73 982.17,1312.73 982.179,1312.73 982.188,1312.73 982.198,1312.73 982.207,1312.74 982.216,1312.74 982.225,1312.74 982.234,1312.74 982.243,1312.74 982.253,1312.74 982.262,1312.74 982.271,1312.74 982.28,1312.74 982.289,1312.74 982.299,1312.74 982.308,1312.74 982.317,1312.74 982.326,1312.74 982.335,1312.74 982.345,1312.74 982.354,1312.75 982.363,1312.75 982.372,1312.75 982.381,1312.75 982.391,1312.75 982.4,1312.75 982.409,1312.75 982.418,1312.75 982.427,1312.75 982.436,1312.75 982.446,1312.75 982.455,1312.75 982.464,1312.75 982.473,1312.75 982.482,1312.75 982.492,1312.75 982.501,1312.76 982.51,1312.76 982.519,1312.76 982.528,1312.76 982.538,1312.76 982.547,1312.76 982.556,1312.76 982.565,1312.76 982.574,1312.76 982.583,1312.76 982.593,1312.76 982.602,1312.76 982.611,1312.76 982.62,1312.76 982.629,1312.76 982.639,1312.76 982.648,1312.77 982.657,1312.77 982.666,1312.77 982.675,1312.77 982.685,1312.77 982.694,1312.77 982.703,1312.77 982.712,1312.77 982.721,1312.77 982.731,1312.77 982.74,1312.77 982.749,1312.77 982.758,1312.77 982.767,1312.77 982.776,1312.77 982.786,1312.77 982.795,1312.77 982.804,1312.78 982.813,1312.78 982.822,1312.78 982.832,1312.78 982.841,1312.78 982.85,1312.78 982.859,1312.78 982.868,1312.78 982.878,1312.78 982.887,1312.78 982.896,1312.78 982.905,1312.78 982.914,1312.78 982.923,1312.78 982.933,1312.78 982.942,1312.78 982.951,1312.79 982.96,1312.79 982.969,1312.79 982.979,1312.79 982.988,1312.79 982.997,1312.79 983.006,1312.79 983.015,1312.79 983.025,1312.79 983.034,1312.79 983.043,1312.79 983.052,1312.79 983.061,1312.79 983.071,1312.79 983.08,1312.79 983.089,1312.79 983.098,1312.8 983.107,1312.8 983.116,1312.8 983.126,1312.8 983.135,1312.8 983.144,1312.8 983.153,1312.8 983.162,1312.8 983.172,1312.8 983.181,1312.8 983.19,1312.8 983.199,1312.8 983.208,1312.8 983.218,1312.8 983.227,1312.8 983.236,1312.8 983.245,1312.81 983.254,1312.81 983.263,1312.81 983.273,1312.81 983.282,1312.81 983.291,1312.81 983.3,1312.81 983.309,1312.81 983.319,1312.81 983.328,1312.81 983.337,1312.81 983.346,1312.81 983.355,1312.81 983.365,1312.81 983.374,1312.81 983.383,1312.81 983.392,1312.82 983.401,1312.82 983.411,1312.82 983.42,1312.82 983.429,1312.82 983.438,1312.82 983.447,1312.82 983.456,1312.82 983.466,1312.82 983.475,1312.82 983.484,1312.82 983.493,1312.82 983.502,1312.82 983.512,1312.82 983.521,1312.82 983.53,1312.82 983.539,1312.82 983.548,1312.83 983.558,1312.83 983.567,1312.83 983.576,1312.83 983.585,1312.83 983.594,1312.83 983.603,1312.83 983.613,1312.83 983.622,1312.83 983.631,1312.83 983.64,1312.83 983.649,1312.83 983.659,1312.83 983.668,1312.83 983.677,1312.83 983.686,1312.83 983.695,1312.84 983.705,1312.84 983.714,1312.84 983.723,1312.84 983.732,1312.84 983.741,1312.84 983.751,1312.84 983.76,1312.84 983.769,1312.84 983.778,1312.84 983.787,1312.84 983.796,1312.84 983.806,1312.84 983.815,1312.84 983.824,1312.84 983.833,1312.84 983.842,1312.85 983.852,1312.85 983.861,1312.85 983.87,1312.85 983.879,1312.85 983.888,1312.85 983.898,1312.85 983.907,1312.85 983.916,1312.85 983.925,1312.85 983.934,1312.85 983.943,1312.85 983.953,1312.85 983.962,1312.85 983.971,1312.85 983.98,1312.85 983.989,1312.86 983.999,1312.86 984.008,1312.86 984.017,1312.86 984.026,1312.86 984.035,1312.86 984.045,1312.86 984.054,1312.86 984.063,1312.86 984.072,1312.86 984.081,1312.86 984.091,1312.86 984.1,1312.86 984.109,1312.86 984.118,1312.86 984.127,1312.86 984.136,1312.86 984.146,1312.87 984.155,1312.87 984.164,1312.87 984.173,1312.87 984.182,1312.87 984.192,1312.87 984.201,1312.87 984.21,1312.87 984.219,1312.87 984.228,1312.87 984.238,1312.87 984.247,1312.87 984.256,1312.87 984.265,1312.87 984.274,1312.87 984.283,1312.87 984.293,1312.88 984.302,1312.88 984.311,1312.88 984.32,1312.88 984.329,1312.88 984.339,1312.88 984.348,1312.88 984.357,1312.88 984.366,1312.88 984.375,1312.88 984.385,1312.88 984.394,1312.88 984.403,1312.88 984.412,1312.88 984.421,1312.88 984.431,1312.88 984.44,1312.89 984.449,1312.89 984.458,1312.89 984.467,1312.89 984.476,1312.89 984.486,1312.89 984.495,1312.89 984.504,1312.89 984.513,1312.89 984.522,1312.89 984.532,1312.89 984.541,1312.89 984.55,1312.89 984.559,1312.89 984.568,1312.89 984.578,1312.89 984.587,1312.9 984.596,1312.9 984.605,1312.9 984.614,1312.9 984.624,1312.9 984.633,1312.9 984.642,1312.9 984.651,1312.9 984.66,1312.9 984.669,1312.9 984.679,1312.9 984.688,1312.9 984.697,1312.9 984.706,1312.9 984.715,1312.9 984.725,1312.9 984.734,1312.91 984.743,1312.91 984.752,1312.91 984.761,1312.91 984.771,1312.91 984.78,1312.91 984.789,1312.91 984.798,1312.91 984.807,1312.91 984.816,1312.91 984.826,1312.91 984.835,1312.91 984.844,1312.91 984.853,1312.91 984.862,1312.91 984.872,1312.91 984.881,1312.91 984.89,1312.92 984.899,1312.92 984.908,1312.92 984.918,1312.92 984.927,1312.92 984.936,1312.92 984.945,1312.92 984.954,1312.92 984.964,1312.92 984.973,1312.92 984.982,1312.92 984.991,1312.92 985,1312.92 985.009,1312.92 985.019,1312.92 985.028,1312.92 985.037,1312.93 985.046,1312.93 985.055,1312.93 985.065,1312.93 985.074,1312.93 985.083,1312.93 985.092,1312.93 985.101,1312.93 985.111,1312.93 985.12,1312.93 985.129,1312.93 985.138,1312.93 985.147,1312.93 985.156,1312.93 985.166,1312.93 985.175,1312.93 985.184,1312.94 985.193,1312.94 985.202,1312.94 985.212,1312.94 985.221,1312.94 985.23,1312.94 985.239,1312.94 985.248,1312.94 985.258,1312.94 985.267,1312.94 985.276,1312.94 985.285,1312.94 985.294,1312.94 985.304,1312.94 985.313,1312.94 985.322,1312.94 985.331,1312.95 985.34,1312.95 985.349,1312.95 985.359,1312.95 985.368,1312.95 985.377,1312.95 985.386,1312.95 985.395,1312.95 985.405,1312.95 985.414,1312.95 985.423,1312.95 985.432,1312.95 985.441,1312.95 985.451,1312.95 985.46,1312.95 985.469,1312.95 985.478,1312.95 985.487,1312.96 985.496,1312.96 985.506,1312.96 985.515,1312.96 985.524,1312.96 985.533,1312.96 985.542,1312.96 985.552,1312.96 985.561,1312.96 985.57,1312.96 985.579,1312.96 985.588,1312.96 985.598,1312.96 985.607,1312.96 985.616,1312.96 985.625,1312.96 985.634,1312.97 985.644,1312.97 985.653,1312.97 985.662,1312.97 985.671,1312.97 985.68,1312.97 985.689,1312.97 985.699,1312.97 985.708,1312.97 985.717,1312.97 985.726,1312.97 985.735,1312.97 985.745,1312.97 985.754,1312.97 985.763,1312.97 985.772,1312.97 985.781,1312.98 985.791,1312.98 985.8,1312.98 985.809,1312.98 985.818,1312.98 985.827,1312.98 985.836,1312.98 985.846,1312.98 985.855,1312.98 985.864,1312.98 985.873,1312.98 985.882,1312.98 985.892,1312.98 985.901,1312.98 985.91,1312.98 985.919,1312.98 985.928,1312.99 985.938,1312.99 985.947,1312.99 985.956,1312.99 985.965,1312.99 985.974,1312.99 985.984,1312.99 985.993,1312.99 986.002,1312.99 986.011,1312.99 986.02,1312.99 986.029,1312.99 986.039,1312.99 986.048,1312.99 986.057,1312.99 986.066,1312.99 986.075,1313 986.085,1313 986.094,1313 986.103,1313 986.112,1313 986.121,1313 986.131,1313 986.14,1313 986.149,1313 986.158,1313 986.167,1313 986.176,1313 986.186,1313 986.195,1313 986.204,1313 986.213,1313 986.222,1313 986.232,1313.01 986.241,1313.01 986.25,1313.01 986.259,1313.01 986.268,1313.01 986.278,1313.01 986.287,1313.01 986.296,1313.01 986.305,1313.01 986.314,1313.01 986.324,1313.01 986.333,1313.01 986.342,1313.01 986.351,1313.01 986.36,1313.01 986.369,1313.01 986.379,1313.02 986.388,1313.02 986.397,1313.02 986.406,1313.02 986.415,1313.02 986.425,1313.02 986.434,1313.02 986.443,1313.02 986.452,1313.02 986.461,1313.02 986.471,1313.02 986.48,1313.02 986.489,1313.02 986.498,1313.02 986.507,1313.02 986.516,1313.02 986.526,1313.03 986.535,1313.03 986.544,1313.03 986.553,1313.03 986.562,1313.03 986.572,1313.03 986.581,1313.03 986.59,1313.03 986.599,1313.03 986.608,1313.03 986.618,1313.03 986.627,1313.03 986.636,1313.03 986.645,1313.03 986.654,1313.03 986.664,1313.03 986.673,1313.04 986.682,1313.04 986.691,1313.04 986.7,1313.04 986.709,1313.04 986.719,1313.04 986.728,1313.04 986.737,1313.04 986.746,1313.04 986.755,1313.04 986.765,1313.04 986.774,1313.04 986.783,1313.04 986.792,1313.04 986.801,1313.04 986.811,1313.04 986.82,1313.04 986.829,1313.05 986.838,1313.05 986.847,1313.05 986.856,1313.05 986.866,1313.05 986.875,1313.05 986.884,1313.05 986.893,1313.05 986.902,1313.05 986.912,1313.05 986.921,1313.05 986.93,1313.05 986.939,1313.05 986.948,1313.05 986.958,1313.05 986.967,1313.05 986.976,1313.06 986.985,1313.06 986.994,1313.06 987.004,1313.06 987.013,1313.06 987.022,1313.06 987.031,1313.06 987.04,1313.06 987.049,1313.06 987.059,1313.06 987.068,1313.06 987.077,1313.06 987.086,1313.06 987.095,1313.06 987.105,1313.06 987.114,1313.06 987.123,1313.07 987.132,1313.07 987.141,1313.07 987.151,1313.07 987.16,1313.07 987.169,1313.07 987.178,1313.07 987.187,1313.07 987.197,1313.07 987.206,1313.07 987.215,1313.07 987.224,1313.07 987.233,1313.07 987.242,1313.07 987.252,1313.07 987.261,1313.07 987.27,1313.08 987.279,1313.08 987.288,1313.08 987.298,1313.08 987.307,1313.08 987.316,1313.08 987.325,1313.08 987.334,1313.08 987.344,1313.08 987.353,1313.08 987.362,1313.08 987.371,1313.08 987.38,1313.08 987.389,1313.08 987.399,1313.08 987.408,1313.08 987.417,1313.09 987.426,1313.09 987.435,1313.09 987.445,1313.09 987.454,1313.09 987.463,1313.09 987.472,1313.09 987.481,1313.09 987.491,1313.09 987.5,1313.09 987.509,1313.09 987.518,1313.09 987.527,1313.09 987.537,1313.09 987.546,1313.09 987.555,1313.09 987.564,1313.09 987.573,1313.1 987.582,1313.1 987.592,1313.1 987.601,1313.1 987.61,1313.1 987.619,1313.1 987.628,1313.1 987.638,1313.1 987.647,1313.1 987.656,1313.1 987.665,1313.1 987.674,1313.1 987.684,1313.1 987.693,1313.1 987.702,1313.1 987.711,1313.1 987.72,1313.11 987.729,1313.11 987.739,1313.11 987.748,1313.11 987.757,1313.11 987.766,1313.11 987.775,1313.11 987.785,1313.11 987.794,1313.11 987.803,1313.11 987.812,1313.11 987.821,1313.11 987.831,1313.11 987.84,1313.11 987.849,1313.11 987.858,1313.11 987.867,1313.12 987.877,1313.12 987.886,1313.12 987.895,1313.12 987.904,1313.12 987.913,1313.12 987.922,1313.12 987.932,1313.12 987.941,1313.12 987.95,1313.12 987.959,1313.12 987.968,1313.12 987.978,1313.12 987.987,1313.12 987.996,1313.12 988.005,1313.12 988.014,1313.13 988.024,1313.13 988.033,1313.13 988.042,1313.13 988.051,1313.13 988.06,1313.13 988.069,1313.13 988.079,1313.13 988.088,1313.13 988.097,1313.13 988.106,1313.13 988.115,1313.13 988.125,1313.13 988.134,1313.13 988.143,1313.13 988.152,1313.13 988.161,1313.13 988.171,1313.14 988.18,1313.14 988.189,1313.14 988.198,1313.14 988.207,1313.14 988.217,1313.14 988.226,1313.14 988.235,1313.14 988.244,1313.14 988.253,1313.14 988.262,1313.14 988.272,1313.14 988.281,1313.14 988.29,1313.14 988.299,1313.14 988.308,1313.14 988.318,1313.15 988.327,1313.15 988.336,1313.15 988.345,1313.15 988.354,1313.15 988.364,1313.15 988.373,1313.15 988.382,1313.15 988.391,1313.15 988.4,1313.15 988.409,1313.15 988.419,1313.15 988.428,1313.15 988.437,1313.15 988.446,1313.15 988.455,1313.15 988.465,1313.16 988.474,1313.16 988.483,1313.16 988.492,1313.16 988.501,1313.16 988.511,1313.16 988.52,1313.16 988.529,1313.16 988.538,1313.16 988.547,1313.16 988.557,1313.16 988.566,1313.16 988.575,1313.16 988.584,1313.16 988.593,1313.16 988.602,1313.16 988.612,1313.17 988.621,1313.17 988.63,1313.17 988.639,1313.17 988.648,1313.17 988.658,1313.17 988.667,1313.17 988.676,1313.17 988.685,1313.17 988.694,1313.17 988.704,1313.17 988.713,1313.17 988.722,1313.17 988.731,1313.17 988.74,1313.17 988.749,1313.17 988.759,1313.18 988.768,1313.18 988.777,1313.18 988.786,1313.18 988.795,1313.18 988.805,1313.18 988.814,1313.18 988.823,1313.18 988.832,1313.18 988.841,1313.18 988.851,1313.18 988.86,1313.18 988.869,1313.18 988.878,1313.18 988.887,1313.18 988.897,1313.18 988.906,1313.18 988.915,1313.19 988.924,1313.19 988.933,1313.19 988.942,1313.19 988.952,1313.19 988.961,1313.19 988.97,1313.19 988.979,1313.19 988.988,1313.19 988.998,1313.19 989.007,1313.19 989.016,1313.19 989.025,1313.19 989.034,1313.19 989.044,1313.19 989.053,1313.19 989.062,1313.2 989.071,1313.2 989.08,1313.2 989.089,1313.2 989.099,1313.2 989.108,1313.2 989.117,1313.2 989.126,1313.2 989.135,1313.2 989.145,1313.2 989.154,1313.2 989.163,1313.2 989.172,1313.2 989.181,1313.2 989.191,1313.2 989.2,1313.2 989.209,1313.21 989.218,1313.21 989.227,1313.21 989.237,1313.21 989.246,1313.21 989.255,1313.21 989.264,1313.21 989.273,1313.21 989.282,1313.21 989.292,1313.21 989.301,1313.21 989.31,1313.21 989.319,1313.21 989.328,1313.21 989.338,1313.21 989.347,1313.21 989.356,1313.22 989.365,1313.22 989.374,1313.22 989.384,1313.22 989.393,1313.22 989.402,1313.22 989.411,1313.22 989.42,1313.22 989.429,1313.22 989.439,1313.22 989.448,1313.22 989.457,1313.22 989.466,1313.22 989.475,1313.22 989.485,1313.22 989.494,1313.22 989.503,1313.23 989.512,1313.23 989.521,1313.23 989.531,1313.23 989.54,1313.23 989.549,1313.23 989.558,1313.23 989.567,1313.23 989.577,1313.23 989.586,1313.23 989.595,1313.23 989.604,1313.23 989.613,1313.23 989.622,1313.23 989.632,1313.23 989.641,1313.23 989.65,1313.23 989.659,1313.24 989.668,1313.24 989.678,1313.24 989.687,1313.24 989.696,1313.24 989.705,1313.24 989.714,1313.24 989.724,1313.24 989.733,1313.24 989.742,1313.24 989.751,1313.24 989.76,1313.24 989.77,1313.24 989.779,1313.24 989.788,1313.24 989.797,1313.24 989.806,1313.25 989.815,1313.25 989.825,1313.25 989.834,1313.25 989.843,1313.25 989.852,1313.25 989.861,1313.25 989.871,1313.25 989.88,1313.25 989.889,1313.25 989.898,1313.25 989.907,1313.25 989.917,1313.25 989.926,1313.25 989.935,1313.25 989.944,1313.25 989.953,1313.26 989.962,1313.26 989.972,1313.26 989.981,1313.26 989.99,1313.26 989.999,1313.26 990.008,1313.26 990.018,1313.26 990.027,1313.26 990.036,1313.26 990.045,1313.26 990.054,1313.26 990.064,1313.26 990.073,1313.26 990.082,1313.26 990.091,1313.26 990.1,1313.27 990.11,1313.27 990.119,1313.27 990.128,1313.27 990.137,1313.27 990.146,1313.27 990.155,1313.27 990.165,1313.27 990.174,1313.27 990.183,1313.27 990.192,1313.27 990.201,1313.27 990.211,1313.27 990.22,1313.27 990.229,1313.27 990.238,1313.27 990.247,1313.28 990.257,1313.28 990.266,1313.28 990.275,1313.28 990.284,1313.28 990.293,1313.28 990.302,1313.28 990.312,1313.28 990.321,1313.28 990.33,1313.28 990.339,1313.28 990.348,1313.28 990.358,1313.28 990.367,1313.28 990.376,1313.28 990.385,1313.28 990.394,1313.28 990.404,1313.29 990.413,1313.29 990.422,1313.29 990.431,1313.29 990.44,1313.29 990.45,1313.29 990.459,1313.29 990.468,1313.29 990.477,1313.29 990.486,1313.29 990.495,1313.29 990.505,1313.29 990.514,1313.29 990.523,1313.29 990.532,1313.29 990.541,1313.29 990.551,1313.3 990.56,1313.3 990.569,1313.3 990.578,1313.3 990.587,1313.3 990.597,1313.3 990.606,1313.3 990.615,1313.3 990.624,1313.3 990.633,1313.3 990.642,1313.3 990.652,1313.3 990.661,1313.3 990.67,1313.3 990.679,1313.3 990.688,1313.3 990.698,1313.31 990.707,1313.31 990.716,1313.31 990.725,1313.31 990.734,1313.31 990.744,1313.31 990.753,1313.31 990.762,1313.31 990.771,1313.31 990.78,1313.31 990.79,1313.31 990.799,1313.31 990.808,1313.31 990.817,1313.31 990.826,1313.31 990.835,1313.31 990.845,1313.32 990.854,1313.32 990.863,1313.32 990.872,1313.32 990.881,1313.32 990.891,1313.32 990.9,1313.32 990.909,1313.32 990.918,1313.32 990.927,1313.32 990.937,1313.32 990.946,1313.32 990.955,1313.32 990.964,1313.32 990.973,1313.32 990.982,1313.32 990.992,1313.33 991.001,1313.33 991.01,1313.33 991.019,1313.33 991.028,1313.33 991.038,1313.33 991.047,1313.33 991.056,1313.33 991.065,1313.33 991.074,1313.33 991.084,1313.33 991.093,1313.33 991.102,1313.33 991.111,1313.33 991.12,1313.33 991.13,1313.33 991.139,1313.33 991.148,1313.34 991.157,1313.34 991.166,1313.34 991.175,1313.34 991.185,1313.34 991.194,1313.34 991.203,1313.34 991.212,1313.34 991.221,1313.34 991.231,1313.34 991.24,1313.34 991.249,1313.34 991.258,1313.34 991.267,1313.34 991.277,1313.34 991.286,1313.34 991.295,1313.35 991.304,1313.35 991.313,1313.35 991.322,1313.35 991.332,1313.35 991.341,1313.35 991.35,1313.35 991.359,1313.35 991.368,1313.35 991.378,1313.35 991.387,1313.35 991.396,1313.35 991.405,1313.35 991.414,1313.35 991.424,1313.35 991.433,1313.35 991.442,1313.36 991.451,1313.36 991.46,1313.36 991.47,1313.36 991.479,1313.36 991.488,1313.36 991.497,1313.36 991.506,1313.36 991.515,1313.36 991.525,1313.36 991.534,1313.36 991.543,1313.36 991.552,1313.36 991.561,1313.36 991.571,1313.36 991.58,1313.36 991.589,1313.37 991.598,1313.37 991.607,1313.37 991.617,1313.37 991.626,1313.37 991.635,1313.37 991.644,1313.37 991.653,1313.37 991.662,1313.37 991.672,1313.37 991.681,1313.37 991.69,1313.37 991.699,1313.37 991.708,1313.37 991.718,1313.37 991.727,1313.37 991.736,1313.37 991.745,1313.38 991.754,1313.38 991.764,1313.38 991.773,1313.38 991.782,1313.38 991.791,1313.38 991.8,1313.38 991.81,1313.38 991.819,1313.38 991.828,1313.38 991.837,1313.38 991.846,1313.38 991.855,1313.38 991.865,1313.38 991.874,1313.38 991.883,1313.38 991.892,1313.39 991.901,1313.39 991.911,1313.39 991.92,1313.39 991.929,1313.39 991.938,1313.39 991.947,1313.39 991.957,1313.39 991.966,1313.39 991.975,1313.39 991.984,1313.39 991.993,1313.39 992.002,1313.39 992.012,1313.39 992.021,1313.39 992.03,1313.39 992.039,1313.4 992.048,1313.4 992.058,1313.4 992.067,1313.4 992.076,1313.4 992.085,1313.4 992.094,1313.4 992.104,1313.4 992.113,1313.4 992.122,1313.4 992.131,1313.4 992.14,1313.4 992.15,1313.4 992.159,1313.4 992.168,1313.4 992.177,1313.4 992.186,1313.41 992.195,1313.41 992.205,1313.41 992.214,1313.41 992.223,1313.41 992.232,1313.41 992.241,1313.41 992.251,1313.41 992.26,1313.41 992.269,1313.41 992.278,1313.41 992.287,1313.41 992.297,1313.41 992.306,1313.41 992.315,1313.41 992.324,1313.41 992.333,1313.42 992.343,1313.42 992.352,1313.42 992.361,1313.42 992.37,1313.42 992.379,1313.42 992.388,1313.42 992.398,1313.42 992.407,1313.42 992.416,1313.42 992.425,1313.42 992.434,1313.42 992.444,1313.42 992.453,1313.42 992.462,1313.42 992.471,1313.42 992.48,1313.42 992.49,1313.43 992.499,1313.43 992.508,1313.43 992.517,1313.43 992.526,1313.43 992.535,1313.43 992.545,1313.43 992.554,1313.43 992.563,1313.43 992.572,1313.43 992.581,1313.43 992.591,1313.43 992.6,1313.43 992.609,1313.43 992.618,1313.43 992.627,1313.43 992.637,1313.44 992.646,1313.44 992.655,1313.44 992.664,1313.44 992.673,1313.44 992.683,1313.44 992.692,1313.44 992.701,1313.44 992.71,1313.44 992.719,1313.44 992.728,1313.44 992.738,1313.44 992.747,1313.44 992.756,1313.44 992.765,1313.44 992.774,1313.44 992.784,1313.45 992.793,1313.45 992.802,1313.45 992.811,1313.45 992.82,1313.45 992.83,1313.45 992.839,1313.45 992.848,1313.45 992.857,1313.45 992.866,1313.45 992.875,1313.45 992.885,1313.45 992.894,1313.45 992.903,1313.45 992.912,1313.45 992.921,1313.45 992.931,1313.46 992.94,1313.46 992.949,1313.46 992.958,1313.46 992.967,1313.46 992.977,1313.46 992.986,1313.46 992.995,1313.46 993.004,1313.46 993.013,1313.46 993.023,1313.46 993.032,1313.46 993.041,1313.46 993.05,1313.46 993.059,1313.46 993.068,1313.46 993.078,1313.47 993.087,1313.47 993.096,1313.47 993.105,1313.47 993.114,1313.47 993.124,1313.47 993.133,1313.47 993.142,1313.47 993.151,1313.47 993.16,1313.47 993.17,1313.47 993.179,1313.47 993.188,1313.47 993.197,1313.47 993.206,1313.47 993.215,1313.47 993.225,1313.47 993.234,1313.48 993.243,1313.48 993.252,1313.48 993.261,1313.48 993.271,1313.48 993.28,1313.48 993.289,1313.48 993.298,1313.48 993.307,1313.48 993.317,1313.48 993.326,1313.48 993.335,1313.48 993.344,1313.48 993.353,1313.48 993.363,1313.48 993.372,1313.48 993.381,1313.49 993.39,1313.49 993.399,1313.49 993.408,1313.49 993.418,1313.49 993.427,1313.49 993.436,1313.49 993.445,1313.49 993.454,1313.49 993.464,1313.49 993.473,1313.49 993.482,1313.49 993.491,1313.49 993.5,1313.49 993.51,1313.49 993.519,1313.49 993.528,1313.5 993.537,1313.5 993.546,1313.5 993.555,1313.5 993.565,1313.5 993.574,1313.5 993.583,1313.5 993.592,1313.5 993.601,1313.5 993.611,1313.5 993.62,1313.5 993.629,1313.5 993.638,1313.5 993.647,1313.5 993.657,1313.5 993.666,1313.5 993.675,1313.51 993.684,1313.51 993.693,1313.51 993.703,1313.51 993.712,1313.51 993.721,1313.51 993.73,1313.51 993.739,1313.51 993.748,1313.51 993.758,1313.51 993.767,1313.51 993.776,1313.51 993.785,1313.51 993.794,1313.51 993.804,1313.51 993.813,1313.51 993.822,1313.52 993.831,1313.52 993.84,1313.52 993.85,1313.52 993.859,1313.52 993.868,1313.52 993.877,1313.52 993.886,1313.52 993.895,1313.52 993.905,1313.52 993.914,1313.52 993.923,1313.52 993.932,1313.52 993.941,1313.52 993.951,1313.52 993.96,1313.52 993.969,1313.52 993.978,1313.53 993.987,1313.53 993.997,1313.53 994.006,1313.53 994.015,1313.53 994.024,1313.53 994.033,1313.53 994.043,1313.53 994.052,1313.53 994.061,1313.53 994.07,1313.53 994.079,1313.53 994.088,1313.53 994.098,1313.53 994.107,1313.53 994.116,1313.53 994.125,1313.54 994.134,1313.54 994.144,1313.54 994.153,1313.54 994.162,1313.54 994.171,1313.54 994.18,1313.54 994.19,1313.54 994.199,1313.54 994.208,1313.54 994.217,1313.54 994.226,1313.54 994.235,1313.54 994.245,1313.54 994.254,1313.54 994.263,1313.54 994.272,1313.55 994.281,1313.55 994.291,1313.55 994.3,1313.55 994.309,1313.55 994.318,1313.55 994.327,1313.55 994.337,1313.55 994.346,1313.55 994.355,1313.55 994.364,1313.55 994.373,1313.55 994.383,1313.55 994.392,1313.55 994.401,1313.55 994.41,1313.55 994.419,1313.56 994.428,1313.56 994.438,1313.56 994.447,1313.56 994.456,1313.56 994.465,1313.56 994.474,1313.56 994.484,1313.56 994.493,1313.56 994.502,1313.56 994.511,1313.56 994.52,1313.56 994.53,1313.56 994.539,1313.56 994.548,1313.56 994.557,1313.56 994.566,1313.57 994.576,1313.57 994.585,1313.57 994.594,1313.57 994.603,1313.57 994.612,1313.57 994.621,1313.57 994.631,1313.57 994.64,1313.57 994.649,1313.57 994.658,1313.57 994.667,1313.57 994.677,1313.57 994.686,1313.57 994.695,1313.57 994.704,1313.57 994.713,1313.57 994.723,1313.58 994.732,1313.58 994.741,1313.58 994.75,1313.58 994.759,1313.58 994.768,1313.58 994.778,1313.58 994.787,1313.58 994.796,1313.58 994.805,1313.58 994.814,1313.58 994.824,1313.58 994.833,1313.58 994.842,1313.58 994.851,1313.58 994.86,1313.58 994.87,1313.59 994.879,1313.59 994.888,1313.59 994.897,1313.59 994.906,1313.59 994.916,1313.59 994.925,1313.59 994.934,1313.59 994.943,1313.59 994.952,1313.59 994.961,1313.59 994.971,1313.59 994.98,1313.59 994.989,1313.59 994.998,1313.59 995.007,1313.59 995.017,1313.6 995.026,1313.6 995.035,1313.6 995.044,1313.6 995.053,1313.6 995.063,1313.6 995.072,1313.6 995.081,1313.6 995.09,1313.6 995.099,1313.6 995.108,1313.6 995.118,1313.6 995.127,1313.6 995.136,1313.6 995.145,1313.6 995.154,1313.6 995.164,1313.61 995.173,1313.61 995.182,1313.61 995.191,1313.61 995.2,1313.61 995.21,1313.61 995.219,1313.61 995.228,1313.61 995.237,1313.61 995.246,1313.61 995.256,1313.61 995.265,1313.61 995.274,1313.61 995.283,1313.61 995.292,1313.61 995.301,1313.61 995.311,1313.62 995.32,1313.62 995.329,1313.62 995.338,1313.62 995.347,1313.62 995.357,1313.62 995.366,1313.62 995.375,1313.62 995.384,1313.62 995.393,1313.62 995.403,1313.62 995.412,1313.62 995.421,1313.62 995.43,1313.62 995.439,1313.62 995.448,1313.62 995.458,1313.62 995.467,1313.63 995.476,1313.63 995.485,1313.63 995.494,1313.63 995.504,1313.63 995.513,1313.63 995.522,1313.63 995.531,1313.63 995.54,1313.63 995.55,1313.63 995.559,1313.63 995.568,1313.63 995.577,1313.63 995.586,1313.63 995.596,1313.63 995.605,1313.63 995.614,1313.64 995.623,1313.64 995.632,1313.64 995.641,1313.64 995.651,1313.64 995.66,1313.64 995.669,1313.64 995.678,1313.64 995.687,1313.64 995.697,1313.64 995.706,1313.64 995.715,1313.64 995.724,1313.64 995.733,1313.64 995.743,1313.64 995.752,1313.64 995.761,1313.65 995.77,1313.65 995.779,1313.65 995.788,1313.65 995.798,1313.65 995.807,1313.65 995.816,1313.65 995.825,1313.65 995.834,1313.65 995.844,1313.65 995.853,1313.65 995.862,1313.65 995.871,1313.65 995.88,1313.65 995.89,1313.65 995.899,1313.65 995.908,1313.66 995.917,1313.66 995.926,1313.66 995.936,1313.66 995.945,1313.66 995.954,1313.66 995.963,1313.66 995.972,1313.66 995.981,1313.66 995.991,1313.66 996,1313.66 996.009,1313.66 996.018,1313.66 996.027,1313.66 996.037,1313.66 996.046,1313.66 996.055,1313.67 996.064,1313.67 996.073,1313.67 996.083,1313.67 996.092,1313.67 996.101,1313.67 996.11,1313.67 996.119,1313.67 996.128,1313.67 996.138,1313.67 996.147,1313.67 996.156,1313.67 996.165,1313.67 996.174,1313.67 996.184,1313.67 996.193,1313.67 996.202,1313.67 996.211,1313.68 996.22,1313.68 996.23,1313.68 996.239,1313.68 996.248,1313.68 996.257,1313.68 996.266,1313.68 996.276,1313.68 996.285,1313.68 996.294,1313.68 996.303,1313.68 996.312,1313.68 996.321,1313.68 996.331,1313.68 996.34,1313.68 996.349,1313.68 996.358,1313.69 996.367,1313.69 996.377,1313.69 996.386,1313.69 996.395,1313.69 996.404,1313.69 996.413,1313.69 996.423,1313.69 996.432,1313.69 996.441,1313.69 996.45,1313.69 996.459,1313.69 996.468,1313.69 996.478,1313.69 996.487,1313.69 996.496,1313.69 996.505,1313.7 996.514,1313.7 996.524,1313.7 996.533,1313.7 996.542,1313.7 996.551,1313.7 996.56,1313.7 996.57,1313.7 996.579,1313.7 996.588,1313.7 996.597,1313.7 996.606,1313.7 996.616,1313.7 996.625,1313.7 996.634,1313.7 996.643,1313.7 996.652,1313.71 996.661,1313.71 996.671,1313.71 996.68,1313.71 996.689,1313.71 996.698,1313.71 996.707,1313.71 996.717,1313.71 996.726,1313.71 996.735,1313.71 996.744,1313.71 996.753,1313.71 996.763,1313.71 996.772,1313.71 996.781,1313.71 996.79,1313.71 996.799,1313.72 996.808,1313.72 996.818,1313.72 996.827,1313.72 996.836,1313.72 996.845,1313.72 996.854,1313.72 996.864,1313.72 996.873,1313.72 996.882,1313.72 996.891,1313.72 996.9,1313.72 996.91,1313.72 996.919,1313.72 996.928,1313.72 996.937,1313.72 996.946,1313.73 996.956,1313.73 996.965,1313.73 996.974,1313.73 996.983,1313.73 996.992,1313.73 997.001,1313.73 997.011,1313.73 997.02,1313.73 997.029,1313.73 997.038,1313.73 997.047,1313.73 997.057,1313.73 997.066,1313.73 997.075,1313.73 997.084,1313.73 997.093,1313.73 997.103,1313.74 997.112,1313.74 997.121,1313.74 997.13,1313.74 997.139,1313.74 997.149,1313.74 997.158,1313.74 997.167,1313.74 997.176,1313.74 997.185,1313.74 997.194,1313.74 997.204,1313.74 997.213,1313.74 997.222,1313.74 997.231,1313.74 997.24,1313.74 997.25,1313.75 997.259,1313.75 997.268,1313.75 997.277,1313.75 997.286,1313.75 997.296,1313.75 997.305,1313.75 997.314,1313.75 997.323,1313.75 997.332,1313.75 997.341,1313.75 997.351,1313.75 997.36,1313.75 997.369,1313.75 997.378,1313.75 997.387,1313.75 997.397,1313.76 997.406,1313.76 997.415,1313.76 997.424,1313.76 997.433,1313.76 997.443,1313.76 997.452,1313.76 997.461,1313.76 997.47,1313.76 997.479,1313.76 997.489,1313.76 997.498,1313.76 997.507,1313.76 997.516,1313.76 997.525,1313.76 997.534,1313.76 997.544,1313.77 997.553,1313.77 997.562,1313.77 997.571,1313.77 997.58,1313.77 997.59,1313.77 997.599,1313.77 997.608,1313.77 997.617,1313.77 997.626,1313.77 997.636,1313.77 997.645,1313.77 997.654,1313.77 997.663,1313.77 997.672,1313.77 997.681,1313.77 997.691,1313.78 997.7,1313.78 997.709,1313.78 997.718,1313.78 997.727,1313.78 997.737,1313.78 997.746,1313.78 997.755,1313.78 997.764,1313.78 997.773,1313.78 997.783,1313.78 997.792,1313.78 997.801,1313.78 997.81,1313.78 997.819,1313.78 997.829,1313.78 997.838,1313.78 997.847,1313.79 997.856,1313.79 997.865,1313.79 997.874,1313.79 997.884,1313.79 997.893,1313.79 997.902,1313.79 997.911,1313.79 997.92,1313.79 997.93,1313.79 997.939,1313.79 997.948,1313.79 997.957,1313.79 997.966,1313.79 997.976,1313.79 997.985,1313.79 997.994,1313.8 998.003,1313.8 998.012,1313.8 998.021,1313.8 998.031,1313.8 998.04,1313.8 998.049,1313.8 998.058,1313.8 998.067,1313.8 998.077,1313.8 998.086,1313.8 998.095,1313.8 998.104,1313.8 998.113,1313.8 998.123,1313.8 998.132,1313.8 998.141,1313.81 998.15,1313.81 998.159,1313.81 998.169,1313.81 998.178,1313.81 998.187,1313.81 998.196,1313.81 998.205,1313.81 998.214,1313.81 998.224,1313.81 998.233,1313.81 998.242,1313.81 998.251,1313.81 998.26,1313.81 998.27,1313.81 998.279,1313.81 998.288,1313.82 998.297,1313.82 998.306,1313.82 998.316,1313.82 998.325,1313.82 998.334,1313.82 998.343,1313.82 998.352,1313.82 998.361,1313.82 998.371,1313.82 998.38,1313.82 998.389,1313.82 998.398,1313.82 998.407,1313.82 998.417,1313.82 998.426,1313.82 998.435,1313.83 998.444,1313.83 998.453,1313.83 998.463,1313.83 998.472,1313.83 998.481,1313.83 998.49,1313.83 998.499,1313.83 998.509,1313.83 998.518,1313.83 998.527,1313.83 998.536,1313.83 998.545,1313.83 998.554,1313.83 998.564,1313.83 998.573,1313.83 998.582,1313.83 998.591,1313.84 998.6,1313.84 998.61,1313.84 998.619,1313.84 998.628,1313.84 998.637,1313.84 998.646,1313.84 998.656,1313.84 998.665,1313.84 998.674,1313.84 998.683,1313.84 998.692,1313.84 998.701,1313.84 998.711,1313.84 998.72,1313.84 998.729,1313.84 998.738,1313.85 998.747,1313.85 998.757,1313.85 998.766,1313.85 998.775,1313.85 998.784,1313.85 998.793,1313.85 998.803,1313.85 998.812,1313.85 998.821,1313.85 998.83,1313.85 998.839,1313.85 998.849,1313.85 998.858,1313.85 998.867,1313.85 998.876,1313.85 998.885,1313.86 998.894,1313.86 998.904,1313.86 998.913,1313.86 998.922,1313.86 998.931,1313.86 998.94,1313.86 998.95,1313.86 998.959,1313.86 998.968,1313.86 998.977,1313.86 998.986,1313.86 998.996,1313.86 999.005,1313.86 999.014,1313.86 999.023,1313.86 999.032,1313.87 999.041,1313.87 999.051,1313.87 999.06,1313.87 999.069,1313.87 999.078,1313.87 999.087,1313.87 999.097,1313.87 999.106,1313.87 999.115,1313.87 999.124,1313.87 999.133,1313.87 999.143,1313.87 999.152,1313.87 999.161,1313.87 999.17,1313.87 999.179,1313.88 999.189,1313.88 999.198,1313.88 999.207,1313.88 999.216,1313.88 999.225,1313.88 999.234,1313.88 999.244,1313.88 999.253,1313.88 999.262,1313.88 999.271,1313.88 999.28,1313.88 999.29,1313.88 999.299,1313.88 999.308,1313.88 999.317,1313.88 999.326,1313.88 999.336,1313.89 999.345,1313.89 999.354,1313.89 999.363,1313.89 999.372,1313.89 999.381,1313.89 999.391,1313.89 999.4,1313.89 999.409,1313.89 999.418,1313.89 999.427,1313.89 999.437,1313.89 999.446,1313.89 999.455,1313.89 999.464,1313.89 999.473,1313.89 999.483,1313.9 999.492,1313.9 999.501,1313.9 999.51,1313.9 999.519,1313.9 999.529,1313.9 999.538,1313.9 999.547,1313.9 999.556,1313.9 999.565,1313.9 999.574,1313.9 999.584,1313.9 999.593,1313.9 999.602,1313.9 999.611,1313.9 999.62,1313.9 999.63,1313.91 999.639,1313.91 999.648,1313.91 999.657,1313.91 999.666,1313.91 999.676,1313.91 999.685,1313.91 999.694,1313.91 999.703,1313.91 999.712,1313.91 999.722,1313.91 999.731,1313.91 999.74,1313.91 999.749,1313.91 999.758,1313.91 999.767,1313.91 999.777,1313.92 999.786,1313.92 999.795,1313.92 999.804,1313.92 999.813,1313.92 999.823,1313.92 999.832,1313.92 999.841,1313.92 999.85,1313.92 999.859,1313.92 999.869,1313.92 999.878,1313.92 999.887,1313.92 999.896,1313.92 999.905,1313.92 999.914,1313.92 999.924,1313.93 999.933,1313.93 999.942,1313.93 999.951,1313.93 999.96,1313.93 999.97,1313.93 999.979,1313.93 999.988,1313.93 999.997,1313.93 1000.01,1313.93 1000.02,1313.93 1000.02,1313.93 1000.03,1313.93 1000.04,1313.93 1000.05,1313.93 1000.06,1313.93 1000.07,1313.93 1000.08,1313.94 1000.09,1313.94 1000.1,1313.94 1000.11,1313.94 1000.12,1313.94 1000.13,1313.94 1000.14,1313.94 1000.14,1313.94 1000.15,1313.94 1000.16,1313.94 1000.17,1313.94 1000.18,1313.94 1000.19,1313.94 1000.2,1313.94 1000.21,1313.94 1000.22,1313.94 1000.23,1313.95 1000.24,1313.95 1000.25,1313.95 1000.25,1313.95 1000.26,1313.95 1000.27,1313.95 1000.28,1313.95 1000.29,1313.95 1000.3,1313.95 1000.31,1313.95 1000.32,1313.95 1000.33,1313.95 1000.34,1313.95 1000.35,1313.95 1000.36,1313.95 1000.36,1313.95 1000.37,1313.96 1000.38,1313.96 1000.39,1313.96 1000.4,1313.96 1000.41,1313.96 1000.42,1313.96 1000.43,1313.96 1000.44,1313.96 1000.45,1313.96 1000.46,1313.96 1000.47,1313.96 1000.48,1313.96 1000.48,1313.96 1000.49,1313.96 1000.5,1313.96 1000.51,1313.96 1000.52,1313.97 1000.53,1313.97 1000.54,1313.97 1000.55,1313.97 1000.56,1313.97 1000.57,1313.97 1000.58,1313.97 1000.59,1313.97 1000.59,1313.97 1000.6,1313.97 1000.61,1313.97 1000.62,1313.97 1000.63,1313.97 1000.64,1313.97 1000.65,1313.97 1000.66,1313.97 1000.67,1313.98 1000.68,1313.98 1000.69,1313.98 1000.7,1313.98 1000.7,1313.98 1000.71,1313.98 1000.72,1313.98 1000.73,1313.98 1000.74,1313.98 1000.75,1313.98 1000.76,1313.98 1000.77,1313.98 1000.78,1313.98 1000.79,1313.98 1000.8,1313.98 1000.81,1313.98 1000.82,1313.98 1000.82,1313.99 1000.83,1313.99 1000.84,1313.99 1000.85,1313.99 1000.86,1313.99 1000.87,1313.99 1000.88,1313.99 1000.89,1313.99 1000.9,1313.99 1000.91,1313.99 1000.92,1313.99 1000.93,1313.99 1000.93,1313.99 1000.94,1313.99 1000.95,1313.99 1000.96,1313.99 1000.97,1314 1000.98,1314 1000.99,1314 1001,1314 1001.01,1314 1001.02,1314 1001.03,1314 1001.04,1314 1001.04,1314 1001.05,1314 1001.06,1314 1001.07,1314 1001.08,1314 1001.09,1314 1001.1,1314 1001.11,1314 1001.12,1314.01 1001.13,1314.01 1001.14,1314.01 1001.15,1314.01 1001.16,1314.01 1001.16,1314.01 1001.17,1314.01 1001.18,1314.01 1001.19,1314.01 1001.2,1314.01 1001.21,1314.01 1001.22,1314.01 1001.23,1314.01 1001.24,1314.01 1001.25,1314.01 1001.26,1314.01 1001.27,1314.02 1001.27,1314.02 1001.28,1314.02 1001.29,1314.02 1001.3,1314.02 1001.31,1314.02 1001.32,1314.02 1001.33,1314.02 1001.34,1314.02 1001.35,1314.02 1001.36,1314.02 1001.37,1314.02 1001.38,1314.02 1001.38,1314.02 1001.39,1314.02 1001.4,1314.02 1001.41,1314.03 1001.42,1314.03 1001.43,1314.03 1001.44,1314.03 1001.45,1314.03 1001.46,1314.03 1001.47,1314.03 1001.48,1314.03 1001.49,1314.03 1001.5,1314.03 1001.5,1314.03 1001.51,1314.03 1001.52,1314.03 1001.53,1314.03 1001.54,1314.03 1001.55,1314.03 1001.56,1314.03 1001.57,1314.04 1001.58,1314.04 1001.59,1314.04 1001.6,1314.04 1001.61,1314.04 1001.61,1314.04 1001.62,1314.04 1001.63,1314.04 1001.64,1314.04 1001.65,1314.04 1001.66,1314.04 1001.67,1314.04 1001.68,1314.04 1001.69,1314.04 1001.7,1314.04 1001.71,1314.04 1001.72,1314.05 1001.72,1314.05 1001.73,1314.05 1001.74,1314.05 1001.75,1314.05 1001.76,1314.05 1001.77,1314.05 1001.78,1314.05 1001.79,1314.05 1001.8,1314.05 1001.81,1314.05 1001.82,1314.05 1001.83,1314.05 1001.84,1314.05 1001.84,1314.05 1001.85,1314.05 1001.86,1314.06 1001.87,1314.06 1001.88,1314.06 1001.89,1314.06 1001.9,1314.06 1001.91,1314.06 1001.92,1314.06 1001.93,1314.06 1001.94,1314.06 1001.95,1314.06 1001.95,1314.06 1001.96,1314.06 1001.97,1314.06 1001.98,1314.06 1001.99,1314.06 1002,1314.06 1002.01,1314.07 1002.02,1314.07 1002.03,1314.07 1002.04,1314.07 1002.05,1314.07 1002.06,1314.07 1002.06,1314.07 1002.07,1314.07 1002.08,1314.07 1002.09,1314.07 1002.1,1314.07 1002.11,1314.07 1002.12,1314.07 1002.13,1314.07 1002.14,1314.07 1002.15,1314.07 1002.16,1314.08 1002.17,1314.08 1002.18,1314.08 1002.18,1314.08 1002.19,1314.08 1002.2,1314.08 1002.21,1314.08 1002.22,1314.08 1002.23,1314.08 1002.24,1314.08 1002.25,1314.08 1002.26,1314.08 1002.27,1314.08 1002.28,1314.08 1002.29,1314.08 1002.29,1314.08 1002.3,1314.08 1002.31,1314.09 1002.32,1314.09 1002.33,1314.09 1002.34,1314.09 1002.35,1314.09 1002.36,1314.09 1002.37,1314.09 1002.38,1314.09 1002.39,1314.09 1002.4,1314.09 1002.4,1314.09 1002.41,1314.09 1002.42,1314.09 1002.43,1314.09 1002.44,1314.09 1002.45,1314.09 1002.46,1314.1 1002.47,1314.1 1002.48,1314.1 1002.49,1314.1 1002.5,1314.1 1002.51,1314.1 1002.52,1314.1 1002.52,1314.1 1002.53,1314.1 1002.54,1314.1 1002.55,1314.1 1002.56,1314.1 1002.57,1314.1 1002.58,1314.1 1002.59,1314.1 1002.6,1314.1 1002.61,1314.11 1002.62,1314.11 1002.63,1314.11 1002.63,1314.11 1002.64,1314.11 1002.65,1314.11 1002.66,1314.11 1002.67,1314.11 1002.68,1314.11 1002.69,1314.11 1002.7,1314.11 1002.71,1314.11 1002.72,1314.11 1002.73,1314.11 1002.74,1314.11 1002.74,1314.11 1002.75,1314.12 1002.76,1314.12 1002.77,1314.12 1002.78,1314.12 1002.79,1314.12 1002.8,1314.12 1002.81,1314.12 1002.82,1314.12 1002.83,1314.12 1002.84,1314.12 1002.85,1314.12 1002.86,1314.12 1002.86,1314.12 1002.87,1314.12 1002.88,1314.12 1002.89,1314.12 1002.9,1314.13 1002.91,1314.13 1002.92,1314.13 1002.93,1314.13 1002.94,1314.13 1002.95,1314.13 1002.96,1314.13 1002.97,1314.13 1002.97,1314.13 1002.98,1314.13 1002.99,1314.13 1003,1314.13 1003.01,1314.13 1003.02,1314.13 1003.03,1314.13 1003.04,1314.13 1003.05,1314.14 1003.06,1314.14 1003.07,1314.14 1003.08,1314.14 1003.08,1314.14 1003.09,1314.14 1003.1,1314.14 1003.11,1314.14 1003.12,1314.14 1003.13,1314.14 1003.14,1314.14 1003.15,1314.14 1003.16,1314.14 1003.17,1314.14 1003.18,1314.14 1003.19,1314.14 1003.2,1314.14 1003.2,1314.15 1003.21,1314.15 1003.22,1314.15 1003.23,1314.15 1003.24,1314.15 1003.25,1314.15 1003.26,1314.15 1003.27,1314.15 1003.28,1314.15 1003.29,1314.15 1003.3,1314.15 1003.31,1314.15 1003.31,1314.15 1003.32,1314.15 1003.33,1314.15 1003.34,1314.15 1003.35,1314.16 1003.36,1314.16 1003.37,1314.16 1003.38,1314.16 1003.39,1314.16 1003.4,1314.16 1003.41,1314.16 1003.42,1314.16 1003.42,1314.16 1003.43,1314.16 1003.44,1314.16 1003.45,1314.16 1003.46,1314.16 1003.47,1314.16 1003.48,1314.16 1003.49,1314.16 1003.5,1314.17 1003.51,1314.17 1003.52,1314.17 1003.53,1314.17 1003.54,1314.17 1003.54,1314.17 1003.55,1314.17 1003.56,1314.17 1003.57,1314.17 1003.58,1314.17 1003.59,1314.17 1003.6,1314.17 1003.61,1314.17 1003.62,1314.17 1003.63,1314.17 1003.64,1314.17 1003.65,1314.18 1003.65,1314.18 1003.66,1314.18 1003.67,1314.18 1003.68,1314.18 1003.69,1314.18 1003.7,1314.18 1003.71,1314.18 1003.72,1314.18 1003.73,1314.18 1003.74,1314.18 1003.75,1314.18 1003.76,1314.18 1003.76,1314.18 1003.77,1314.18 1003.78,1314.18 1003.79,1314.19 1003.8,1314.19 1003.81,1314.19 1003.82,1314.19 1003.83,1314.19 1003.84,1314.19 1003.85,1314.19 1003.86,1314.19 1003.87,1314.19 1003.88,1314.19 1003.88,1314.19 1003.89,1314.19 1003.9,1314.19 1003.91,1314.19 1003.92,1314.19 1003.93,1314.19 1003.94,1314.19 1003.95,1314.2 1003.96,1314.2 1003.97,1314.2 1003.98,1314.2 1003.99,1314.2 1003.99,1314.2 1004,1314.2 1004.01,1314.2 1004.02,1314.2 1004.03,1314.2 1004.04,1314.2 1004.05,1314.2 1004.06,1314.2 1004.07,1314.2 1004.08,1314.2 1004.09,1314.2 1004.1,1314.21 1004.1,1314.21 1004.11,1314.21 1004.12,1314.21 1004.13,1314.21 1004.14,1314.21 1004.15,1314.21 1004.16,1314.21 1004.17,1314.21 1004.18,1314.21 1004.19,1314.21 1004.2,1314.21 1004.21,1314.21 1004.22,1314.21 1004.22,1314.21 1004.23,1314.21 1004.24,1314.22 1004.25,1314.22 1004.26,1314.22 1004.27,1314.22 1004.28,1314.22 1004.29,1314.22 1004.3,1314.22 1004.31,1314.22 1004.32,1314.22 1004.33,1314.22 1004.33,1314.22 1004.34,1314.22 1004.35,1314.22 1004.36,1314.22 1004.37,1314.22 1004.38,1314.22 1004.39,1314.23 1004.4,1314.23 1004.41,1314.23 1004.42,1314.23 1004.43,1314.23 1004.44,1314.23 1004.44,1314.23 1004.45,1314.23 1004.46,1314.23 1004.47,1314.23 1004.48,1314.23 1004.49,1314.23 1004.5,1314.23 1004.51,1314.23 1004.52,1314.23 1004.53,1314.23 1004.54,1314.24 1004.55,1314.24 1004.56,1314.24 1004.56,1314.24 1004.57,1314.24 1004.58,1314.24 1004.59,1314.24 1004.6,1314.24 1004.61,1314.24 1004.62,1314.24 1004.63,1314.24 1004.64,1314.24 1004.65,1314.24 1004.66,1314.24 1004.67,1314.24 1004.67,1314.24 1004.68,1314.24 1004.69,1314.25 1004.7,1314.25 1004.71,1314.25 1004.72,1314.25 1004.73,1314.25 1004.74,1314.25 1004.75,1314.25 1004.76,1314.25 1004.77,1314.25 1004.78,1314.25 1004.78,1314.25 1004.79,1314.25 1004.8,1314.25 1004.81,1314.25 1004.82,1314.25 1004.83,1314.25 1004.84,1314.26 1004.85,1314.26 1004.86,1314.26 1004.87,1314.26 1004.88,1314.26 1004.89,1314.26 1004.9,1314.26 1004.9,1314.26 1004.91,1314.26 1004.92,1314.26 1004.93,1314.26 1004.94,1314.26 1004.95,1314.26 1004.96,1314.26 1004.97,1314.26 1004.98,1314.26 1004.99,1314.27 1005,1314.27 1005.01,1314.27 1005.01,1314.27 1005.02,1314.27 1005.03,1314.27 1005.04,1314.27 1005.05,1314.27 1005.06,1314.27 1005.07,1314.27 1005.08,1314.27 1005.09,1314.27 1005.1,1314.27 1005.11,1314.27 1005.12,1314.27 1005.12,1314.27 1005.13,1314.28 1005.14,1314.28 1005.15,1314.28 1005.16,1314.28 1005.17,1314.28 1005.18,1314.28 1005.19,1314.28 1005.2,1314.28 1005.21,1314.28 1005.22,1314.28 1005.23,1314.28 1005.24,1314.28 1005.24,1314.28 1005.25,1314.28 1005.26,1314.28 1005.27,1314.28 1005.28,1314.29 1005.29,1314.29 1005.3,1314.29 1005.31,1314.29 1005.32,1314.29 1005.33,1314.29 1005.34,1314.29 1005.35,1314.29 1005.35,1314.29 1005.36,1314.29 1005.37,1314.29 1005.38,1314.29 1005.39,1314.29 1005.4,1314.29 1005.41,1314.29 1005.42,1314.29 1005.43,1314.29 1005.44,1314.3 1005.45,1314.3 1005.46,1314.3 1005.46,1314.3 1005.47,1314.3 1005.48,1314.3 1005.49,1314.3 1005.5,1314.3 1005.51,1314.3 1005.52,1314.3 1005.53,1314.3 1005.54,1314.3 1005.55,1314.3 1005.56,1314.3 1005.57,1314.3 1005.58,1314.3 1005.58,1314.31 1005.59,1314.31 1005.6,1314.31 1005.61,1314.31 1005.62,1314.31 1005.63,1314.31 1005.64,1314.31 1005.65,1314.31 1005.66,1314.31 1005.67,1314.31 1005.68,1314.31 1005.69,1314.31 1005.69,1314.31 1005.7,1314.31 1005.71,1314.31 1005.72,1314.31 1005.73,1314.32 1005.74,1314.32 1005.75,1314.32 1005.76,1314.32 1005.77,1314.32 1005.78,1314.32 1005.79,1314.32 1005.8,1314.32 1005.8,1314.32 1005.81,1314.32 1005.82,1314.32 1005.83,1314.32 1005.84,1314.32 1005.85,1314.32 1005.86,1314.32 1005.87,1314.32 1005.88,1314.33 1005.89,1314.33 1005.9,1314.33 1005.91,1314.33 1005.92,1314.33 1005.92,1314.33 1005.93,1314.33 1005.94,1314.33 1005.95,1314.33 1005.96,1314.33 1005.97,1314.33 1005.98,1314.33 1005.99,1314.33 1006,1314.33 1006.01,1314.33 1006.02,1314.33 1006.03,1314.34 1006.03,1314.34 1006.04,1314.34 1006.05,1314.34 1006.06,1314.34 1006.07,1314.34 1006.08,1314.34 1006.09,1314.34 1006.1,1314.34 1006.11,1314.34 1006.12,1314.34 1006.13,1314.34 1006.14,1314.34 1006.14,1314.34 1006.15,1314.34 1006.16,1314.34 1006.17,1314.34 1006.18,1314.35 1006.19,1314.35 1006.2,1314.35 1006.21,1314.35 1006.22,1314.35 1006.23,1314.35 1006.24,1314.35 1006.25,1314.35 1006.26,1314.35 1006.26,1314.35 1006.27,1314.35 1006.28,1314.35 1006.29,1314.35 1006.3,1314.35 1006.31,1314.35 1006.32,1314.35 1006.33,1314.36 1006.34,1314.36 1006.35,1314.36 1006.36,1314.36 1006.37,1314.36 1006.37,1314.36 1006.38,1314.36 1006.39,1314.36 1006.4,1314.36 1006.41,1314.36 1006.42,1314.36 1006.43,1314.36 1006.44,1314.36 1006.45,1314.36 1006.46,1314.36 1006.47,1314.36 1006.48,1314.37 1006.48,1314.37 1006.49,1314.37 1006.5,1314.37 1006.51,1314.37 1006.52,1314.37 1006.53,1314.37 1006.54,1314.37 1006.55,1314.37 1006.56,1314.37 1006.57,1314.37 1006.58,1314.37 1006.59,1314.37 1006.6,1314.37 1006.6,1314.37 1006.61,1314.37 1006.62,1314.38 1006.63,1314.38 1006.64,1314.38 1006.65,1314.38 1006.66,1314.38 1006.67,1314.38 1006.68,1314.38 1006.69,1314.38 1006.7,1314.38 1006.71,1314.38 1006.71,1314.38 1006.72,1314.38 1006.73,1314.38 1006.74,1314.38 1006.75,1314.38 1006.76,1314.38 1006.77,1314.39 1006.78,1314.39 1006.79,1314.39 1006.8,1314.39 1006.81,1314.39 1006.82,1314.39 1006.82,1314.39 1006.83,1314.39 1006.84,1314.39 1006.85,1314.39 1006.86,1314.39 1006.87,1314.39 1006.88,1314.39 1006.89,1314.39 1006.9,1314.39 1006.91,1314.39 1006.92,1314.39 1006.93,1314.4 1006.94,1314.4 1006.94,1314.4 1006.95,1314.4 1006.96,1314.4 1006.97,1314.4 1006.98,1314.4 1006.99,1314.4 1007,1314.4 1007.01,1314.4 1007.02,1314.4 1007.03,1314.4 1007.04,1314.4 1007.05,1314.4 1007.05,1314.4 1007.06,1314.4 1007.07,1314.41 1007.08,1314.41 1007.09,1314.41 1007.1,1314.41 1007.11,1314.41 1007.12,1314.41 1007.13,1314.41 1007.14,1314.41 1007.15,1314.41 1007.16,1314.41 1007.16,1314.41 1007.17,1314.41 1007.18,1314.41 1007.19,1314.41 1007.2,1314.41 1007.21,1314.41 1007.22,1314.42 1007.23,1314.42 1007.24,1314.42 1007.25,1314.42 1007.26,1314.42 1007.27,1314.42 1007.28,1314.42 1007.28,1314.42 1007.29,1314.42 1007.3,1314.42 1007.31,1314.42 1007.32,1314.42 1007.33,1314.42 1007.34,1314.42 1007.35,1314.42 1007.36,1314.42 1007.37,1314.43 1007.38,1314.43 1007.39,1314.43 1007.39,1314.43 1007.4,1314.43 1007.41,1314.43 1007.42,1314.43 1007.43,1314.43 1007.44,1314.43 1007.45,1314.43 1007.46,1314.43 1007.47,1314.43 1007.48,1314.43 1007.49,1314.43 1007.5,1314.43 1007.5,1314.43 1007.51,1314.44 1007.52,1314.44 1007.53,1314.44 1007.54,1314.44 1007.55,1314.44 1007.56,1314.44 1007.57,1314.44 1007.58,1314.44 1007.59,1314.44 1007.6,1314.44 1007.61,1314.44 1007.62,1314.44 1007.62,1314.44 1007.63,1314.44 1007.64,1314.44 1007.65,1314.44 1007.66,1314.44 1007.67,1314.45 1007.68,1314.45 1007.69,1314.45 1007.7,1314.45 1007.71,1314.45 1007.72,1314.45 1007.73,1314.45 1007.73,1314.45 1007.74,1314.45 1007.75,1314.45 1007.76,1314.45 1007.77,1314.45 1007.78,1314.45 1007.79,1314.45 1007.8,1314.45 1007.81,1314.45 1007.82,1314.46 1007.83,1314.46 1007.84,1314.46 1007.84,1314.46 1007.85,1314.46 1007.86,1314.46 1007.87,1314.46 1007.88,1314.46 1007.89,1314.46 1007.9,1314.46 1007.91,1314.46 1007.92,1314.46 1007.93,1314.46 1007.94,1314.46 1007.95,1314.46 1007.96,1314.46 1007.96,1314.47 1007.97,1314.47 1007.98,1314.47 1007.99,1314.47 1008,1314.47 1008.01,1314.47 1008.02,1314.47 1008.03,1314.47 1008.04,1314.47 1008.05,1314.47 1008.06,1314.47 1008.07,1314.47 1008.07,1314.47 1008.08,1314.47 1008.09,1314.47 1008.1,1314.47 1008.11,1314.48 1008.12,1314.48 1008.13,1314.48 1008.14,1314.48 1008.15,1314.48 1008.16,1314.48 1008.17,1314.48 1008.18,1314.48 1008.18,1314.48 1008.19,1314.48 1008.2,1314.48 1008.21,1314.48 1008.22,1314.48 1008.23,1314.48 1008.24,1314.48 1008.25,1314.48 1008.26,1314.49 1008.27,1314.49 1008.28,1314.49 1008.29,1314.49 1008.3,1314.49 1008.3,1314.49 1008.31,1314.49 1008.32,1314.49 1008.33,1314.49 1008.34,1314.49 1008.35,1314.49 1008.36,1314.49 1008.37,1314.49 1008.38,1314.49 1008.39,1314.49 1008.4,1314.49 1008.41,1314.49 1008.41,1314.5 1008.42,1314.5 1008.43,1314.5 1008.44,1314.5 1008.45,1314.5 1008.46,1314.5 1008.47,1314.5 1008.48,1314.5 1008.49,1314.5 1008.5,1314.5 1008.51,1314.5 1008.52,1314.5 1008.52,1314.5 1008.53,1314.5 1008.54,1314.5 1008.55,1314.5 1008.56,1314.51 1008.57,1314.51 1008.58,1314.51 1008.59,1314.51 1008.6,1314.51 1008.61,1314.51 1008.62,1314.51 1008.63,1314.51 1008.64,1314.51 1008.64,1314.51 1008.65,1314.51 1008.66,1314.51 1008.67,1314.51 1008.68,1314.51 1008.69,1314.51 1008.7,1314.51 1008.71,1314.52 1008.72,1314.52 1008.73,1314.52 1008.74,1314.52 1008.75,1314.52 1008.75,1314.52 1008.76,1314.52 1008.77,1314.52 1008.78,1314.52 1008.79,1314.52 1008.8,1314.52 1008.81,1314.52 1008.82,1314.52 1008.83,1314.52 1008.84,1314.52 1008.85,1314.52 1008.86,1314.53 1008.86,1314.53 1008.87,1314.53 1008.88,1314.53 1008.89,1314.53 1008.9,1314.53 1008.91,1314.53 1008.92,1314.53 1008.93,1314.53 1008.94,1314.53 1008.95,1314.53 1008.96,1314.53 1008.97,1314.53 1008.98,1314.53 1008.98,1314.53 1008.99,1314.53 1009,1314.54 1009.01,1314.54 1009.02,1314.54 1009.03,1314.54 1009.04,1314.54 1009.05,1314.54 1009.06,1314.54 1009.07,1314.54 1009.08,1314.54 1009.09,1314.54 1009.09,1314.54 1009.1,1314.54 1009.11,1314.54 1009.12,1314.54 1009.13,1314.54 1009.14,1314.54 1009.15,1314.54 1009.16,1314.55 1009.17,1314.55 1009.18,1314.55 1009.19,1314.55 1009.2,1314.55 1009.2,1314.55 1009.21,1314.55 1009.22,1314.55 1009.23,1314.55 1009.24,1314.55 1009.25,1314.55 1009.26,1314.55 1009.27,1314.55 1009.28,1314.55 1009.29,1314.55 1009.3,1314.55 1009.31,1314.56 1009.32,1314.56 1009.32,1314.56 1009.33,1314.56 1009.34,1314.56 1009.35,1314.56 1009.36,1314.56 1009.37,1314.56 1009.38,1314.56 1009.39,1314.56 1009.4,1314.56 1009.41,1314.56 1009.42,1314.56 1009.43,1314.56 1009.43,1314.56 1009.44,1314.56 1009.45,1314.57 1009.46,1314.57 1009.47,1314.57 1009.48,1314.57 1009.49,1314.57 1009.5,1314.57 1009.51,1314.57 1009.52,1314.57 1009.53,1314.57 1009.54,1314.57 1009.54,1314.57 1009.55,1314.57 1009.56,1314.57 1009.57,1314.57 1009.58,1314.57 1009.59,1314.57 1009.6,1314.58 1009.61,1314.58 1009.62,1314.58 1009.63,1314.58 1009.64,1314.58 1009.65,1314.58 1009.66,1314.58 1009.66,1314.58 1009.67,1314.58 1009.68,1314.58 1009.69,1314.58 1009.7,1314.58 1009.71,1314.58 1009.72,1314.58 1009.73,1314.58 1009.74,1314.58 1009.75,1314.59 1009.76,1314.59 1009.77,1314.59 1009.77,1314.59 1009.78,1314.59 1009.79,1314.59 1009.8,1314.59 1009.81,1314.59 1009.82,1314.59 1009.83,1314.59 1009.84,1314.59 1009.85,1314.59 1009.86,1314.59 1009.87,1314.59 1009.88,1314.59 1009.88,1314.59 1009.89,1314.59 1009.9,1314.6 1009.91,1314.6 1009.92,1314.6 1009.93,1314.6 1009.94,1314.6 1009.95,1314.6 1009.96,1314.6 1009.97,1314.6 1009.98,1314.6 1009.99,1314.6 1010,1314.6 1010,1314.6 1010.01,1314.6 1010.02,1314.6 1010.03,1314.6 1010.04,1314.6 1010.05,1314.61 1010.06,1314.61 1010.07,1314.61 1010.08,1314.61 1010.09,1314.61 1010.1,1314.61 1010.11,1314.61 1010.11,1314.61 1010.12,1314.61 1010.13,1314.61 1010.14,1314.61 1010.15,1314.61 1010.16,1314.61 1010.17,1314.61 1010.18,1314.61 1010.19,1314.61 1010.2,1314.62 1010.21,1314.62 1010.22,1314.62 1010.22,1314.62 1010.23,1314.62 1010.24,1314.62 1010.25,1314.62 1010.26,1314.62 1010.27,1314.62 1010.28,1314.62 1010.29,1314.62 1010.3,1314.62 1010.31,1314.62 1010.32,1314.62 1010.33,1314.62 1010.34,1314.62 1010.34,1314.63 1010.35,1314.63 1010.36,1314.63 1010.37,1314.63 1010.38,1314.63 1010.39,1314.63 1010.4,1314.63 1010.41,1314.63 1010.42,1314.63 1010.43,1314.63 1010.44,1314.63 1010.45,1314.63 1010.45,1314.63 1010.46,1314.63 1010.47,1314.63 1010.48,1314.63 1010.49,1314.64 1010.5,1314.64 1010.51,1314.64 1010.52,1314.64 1010.53,1314.64 1010.54,1314.64 1010.55,1314.64 1010.56,1314.64 1010.56,1314.64 1010.57,1314.64 1010.58,1314.64 1010.59,1314.64 1010.6,1314.64 1010.61,1314.64 1010.62,1314.64 1010.63,1314.64 1010.64,1314.64 1010.65,1314.65 1010.66,1314.65 1010.67,1314.65 1010.68,1314.65 1010.68,1314.65 1010.69,1314.65 1010.7,1314.65 1010.71,1314.65 1010.72,1314.65 1010.73,1314.65 1010.74,1314.65 1010.75,1314.65 1010.76,1314.65 1010.77,1314.65 1010.78,1314.65 1010.79,1314.65 1010.79,1314.66 1010.8,1314.66 1010.81,1314.66 1010.82,1314.66 1010.83,1314.66 1010.84,1314.66 1010.85,1314.66 1010.86,1314.66 1010.87,1314.66 1010.88,1314.66 1010.89,1314.66 1010.9,1314.66 1010.9,1314.66 1010.91,1314.66 1010.92,1314.66 1010.93,1314.66 1010.94,1314.67 1010.95,1314.67 1010.96,1314.67 1010.97,1314.67 1010.98,1314.67 1010.99,1314.67 1011,1314.67 1011.01,1314.67 1011.02,1314.67 1011.02,1314.67 1011.03,1314.67 1011.04,1314.67 1011.05,1314.67 1011.06,1314.67 1011.07,1314.67 1011.08,1314.67 1011.09,1314.68 1011.1,1314.68 1011.11,1314.68 1011.12,1314.68 1011.13,1314.68 1011.13,1314.68 1011.14,1314.68 1011.15,1314.68 1011.16,1314.68 1011.17,1314.68 1011.18,1314.68 1011.19,1314.68 1011.2,1314.68 1011.21,1314.68 1011.22,1314.68 1011.23,1314.68 1011.24,1314.69 1011.24,1314.69 1011.25,1314.69 1011.26,1314.69 1011.27,1314.69 1011.28,1314.69 1011.29,1314.69 1011.3,1314.69 1011.31,1314.69 1011.32,1314.69 1011.33,1314.69 1011.34,1314.69 1011.35,1314.69 1011.36,1314.69 1011.36,1314.69 1011.37,1314.69 1011.38,1314.69 1011.39,1314.7 1011.4,1314.7 1011.41,1314.7 1011.42,1314.7 1011.43,1314.7 1011.44,1314.7 1011.45,1314.7 1011.46,1314.7 1011.47,1314.7 1011.47,1314.7 1011.48,1314.7 1011.49,1314.7 1011.5,1314.7 1011.51,1314.7 1011.52,1314.7 1011.53,1314.7 1011.54,1314.71 1011.55,1314.71 1011.56,1314.71 1011.57,1314.71 1011.58,1314.71 1011.58,1314.71 1011.59,1314.71 1011.6,1314.71 1011.61,1314.71 1011.62,1314.71 1011.63,1314.71 1011.64,1314.71 1011.65,1314.71 1011.66,1314.71 1011.67,1314.71 1011.68,1314.71 1011.69,1314.72 1011.7,1314.72 1011.7,1314.72 1011.71,1314.72 1011.72,1314.72 1011.73,1314.72 1011.74,1314.72 1011.75,1314.72 1011.76,1314.72 1011.77,1314.72 1011.78,1314.72 1011.79,1314.72 1011.8,1314.72 1011.81,1314.72 1011.81,1314.72 1011.82,1314.72 1011.83,1314.73 1011.84,1314.73 1011.85,1314.73 1011.86,1314.73 1011.87,1314.73 1011.88,1314.73 1011.89,1314.73 1011.9,1314.73 1011.91,1314.73 1011.92,1314.73 1011.92,1314.73 1011.93,1314.73 1011.94,1314.73 1011.95,1314.73 1011.96,1314.73 1011.97,1314.73 1011.98,1314.74 1011.99,1314.74 1012,1314.74 1012.01,1314.74 1012.02,1314.74 1012.03,1314.74 1012.04,1314.74 1012.04,1314.74 1012.05,1314.74 1012.06,1314.74 1012.07,1314.74 1012.08,1314.74 1012.09,1314.74 1012.1,1314.74 1012.11,1314.74 1012.12,1314.74 1012.13,1314.74 1012.14,1314.75 1012.15,1314.75 1012.15,1314.75 1012.16,1314.75 1012.17,1314.75 1012.18,1314.75 1012.19,1314.75 1012.2,1314.75 1012.21,1314.75 1012.22,1314.75 1012.23,1314.75 1012.24,1314.75 1012.25,1314.75 1012.26,1314.75 1012.26,1314.75 1012.27,1314.75 1012.28,1314.76 1012.29,1314.76 1012.3,1314.76 1012.31,1314.76 1012.32,1314.76 1012.33,1314.76 1012.34,1314.76 1012.35,1314.76 1012.36,1314.76 1012.37,1314.76 1012.38,1314.76 1012.38,1314.76 1012.39,1314.76 1012.4,1314.76 1012.41,1314.76 1012.42,1314.76 1012.43,1314.77 1012.44,1314.77 1012.45,1314.77 1012.46,1314.77 1012.47,1314.77 1012.48,1314.77 1012.49,1314.77 1012.49,1314.77 1012.5,1314.77 1012.51,1314.77 1012.52,1314.77 1012.53,1314.77 1012.54,1314.77 1012.55,1314.77 1012.56,1314.77 1012.57,1314.77 1012.58,1314.78 1012.59,1314.78 1012.6,1314.78 1012.6,1314.78 1012.61,1314.78 1012.62,1314.78 1012.63,1314.78 1012.64,1314.78 1012.65,1314.78 1012.66,1314.78 1012.67,1314.78 1012.68,1314.78 1012.69,1314.78 1012.7,1314.78 1012.71,1314.78 1012.72,1314.78 1012.72,1314.78 1012.73,1314.79 1012.74,1314.79 1012.75,1314.79 1012.76,1314.79 1012.77,1314.79 1012.78,1314.79 1012.79,1314.79 1012.8,1314.79 1012.81,1314.79 1012.82,1314.79 1012.83,1314.79 1012.83,1314.79 1012.84,1314.79 1012.85,1314.79 1012.86,1314.79 1012.87,1314.79 1012.88,1314.8 1012.89,1314.8 1012.9,1314.8 1012.91,1314.8 1012.92,1314.8 1012.93,1314.8 1012.94,1314.8 1012.94,1314.8 1012.95,1314.8 1012.96,1314.8 1012.97,1314.8 1012.98,1314.8 1012.99,1314.8 1013,1314.8 1013.01,1314.8 1013.02,1314.8 1013.03,1314.81 1013.04,1314.81 1013.05,1314.81 1013.06,1314.81 1013.06,1314.81 1013.07,1314.81 1013.08,1314.81 1013.09,1314.81 1013.1,1314.81 1013.11,1314.81 1013.12,1314.81 1013.13,1314.81 1013.14,1314.81 1013.15,1314.81 1013.16,1314.81 1013.17,1314.81 1013.17,1314.82 1013.18,1314.82 1013.19,1314.82 1013.2,1314.82 1013.21,1314.82 1013.22,1314.82 1013.23,1314.82 1013.24,1314.82 1013.25,1314.82 1013.26,1314.82 1013.27,1314.82 1013.28,1314.82 1013.28,1314.82 1013.29,1314.82 1013.3,1314.82 1013.31,1314.82 1013.32,1314.83 1013.33,1314.83 1013.34,1314.83 1013.35,1314.83 1013.36,1314.83 1013.37,1314.83 1013.38,1314.83 1013.39,1314.83 1013.4,1314.83 1013.4,1314.83 1013.41,1314.83 1013.42,1314.83 1013.43,1314.83 1013.44,1314.83 1013.45,1314.83 1013.46,1314.83 1013.47,1314.83 1013.48,1314.84 1013.49,1314.84 1013.5,1314.84 1013.51,1314.84 1013.51,1314.84 1013.52,1314.84 1013.53,1314.84 1013.54,1314.84 1013.55,1314.84 1013.56,1314.84 1013.57,1314.84 1013.58,1314.84 1013.59,1314.84 1013.6,1314.84 1013.61,1314.84 1013.62,1314.84 1013.62,1314.85 1013.63,1314.85 1013.64,1314.85 1013.65,1314.85 1013.66,1314.85 1013.67,1314.85 1013.68,1314.85 1013.69,1314.85 1013.7,1314.85 1013.71,1314.85 1013.72,1314.85 1013.73,1314.85 1013.74,1314.85 1013.74,1314.85 1013.75,1314.85 1013.76,1314.85 1013.77,1314.86 1013.78,1314.86 1013.79,1314.86 1013.8,1314.86 1013.81,1314.86 1013.82,1314.86 1013.83,1314.86 1013.84,1314.86 1013.85,1314.86 1013.85,1314.86 1013.86,1314.86 1013.87,1314.86 1013.88,1314.86 1013.89,1314.86 1013.9,1314.86 1013.91,1314.86 1013.92,1314.87 1013.93,1314.87 1013.94,1314.87 1013.95,1314.87 1013.96,1314.87 1013.96,1314.87 1013.97,1314.87 1013.98,1314.87 1013.99,1314.87 1014,1314.87 1014.01,1314.87 1014.02,1314.87 1014.03,1314.87 1014.04,1314.87 1014.05,1314.87 1014.06,1314.87 1014.07,1314.88 1014.08,1314.88 1014.08,1314.88 1014.09,1314.88 1014.1,1314.88 1014.11,1314.88 1014.12,1314.88 1014.13,1314.88 1014.14,1314.88 1014.15,1314.88 1014.16,1314.88 1014.17,1314.88 1014.18,1314.88 1014.19,1314.88 1014.19,1314.88 1014.2,1314.88 1014.21,1314.88 1014.22,1314.89 1014.23,1314.89 1014.24,1314.89 1014.25,1314.89 1014.26,1314.89 1014.27,1314.89 1014.28,1314.89 1014.29,1314.89 1014.3,1314.89 1014.3,1314.89 1014.31,1314.89 1014.32,1314.89 1014.33,1314.89 1014.34,1314.89 1014.35,1314.89 1014.36,1314.89 1014.37,1314.9 1014.38,1314.9 1014.39,1314.9 1014.4,1314.9 1014.41,1314.9 1014.42,1314.9 1014.42,1314.9 1014.43,1314.9 1014.44,1314.9 1014.45,1314.9 1014.46,1314.9 1014.47,1314.9 1014.48,1314.9 1014.49,1314.9 1014.5,1314.9 1014.51,1314.9 1014.52,1314.91 1014.53,1314.91 1014.53,1314.91 1014.54,1314.91 1014.55,1314.91 1014.56,1314.91 1014.57,1314.91 1014.58,1314.91 1014.59,1314.91 1014.6,1314.91 1014.61,1314.91 1014.62,1314.91 1014.63,1314.91 1014.64,1314.91 1014.64,1314.91 1014.65,1314.91 1014.66,1314.92 1014.67,1314.92 1014.68,1314.92 1014.69,1314.92 1014.7,1314.92 1014.71,1314.92 1014.72,1314.92 1014.73,1314.92 1014.74,1314.92 1014.75,1314.92 1014.76,1314.92 1014.76,1314.92 1014.77,1314.92 1014.78,1314.92 1014.79,1314.92 1014.8,1314.92 1014.81,1314.93 1014.82,1314.93 1014.83,1314.93 1014.84,1314.93 1014.85,1314.93 1014.86,1314.93 1014.87,1314.93 1014.87,1314.93 1014.88,1314.93 1014.89,1314.93 1014.9,1314.93 1014.91,1314.93 1014.92,1314.93 1014.93,1314.93 1014.94,1314.93 1014.95,1314.93 1014.96,1314.93 1014.97,1314.94 1014.98,1314.94 1014.98,1314.94 1014.99,1314.94 1015,1314.94 1015.01,1314.94 1015.02,1314.94 1015.03,1314.94 1015.04,1314.94 1015.05,1314.94 1015.06,1314.94 1015.07,1314.94 1015.08,1314.94 1015.09,1314.94 1015.1,1314.94 1015.1,1314.94 1015.11,1314.95 1015.12,1314.95 1015.13,1314.95 1015.14,1314.95 1015.15,1314.95 1015.16,1314.95 1015.17,1314.95 1015.18,1314.95 1015.19,1314.95 1015.2,1314.95 1015.21,1314.95 1015.21,1314.95 1015.22,1314.95 1015.23,1314.95 1015.24,1314.95 1015.25,1314.95 1015.26,1314.96 1015.27,1314.96 1015.28,1314.96 1015.29,1314.96 1015.3,1314.96 1015.31,1314.96 1015.32,1314.96 1015.32,1314.96 1015.33,1314.96 1015.34,1314.96 1015.35,1314.96 1015.36,1314.96 1015.37,1314.96 1015.38,1314.96 1015.39,1314.96 1015.4,1314.96 1015.41,1314.97 1015.42,1314.97 1015.43,1314.97 1015.44,1314.97 1015.44,1314.97 1015.45,1314.97 1015.46,1314.97 1015.47,1314.97 1015.48,1314.97 1015.49,1314.97 1015.5,1314.97 1015.51,1314.97 1015.52,1314.97 1015.53,1314.97 1015.54,1314.97 1015.55,1314.97 1015.55,1314.97 1015.56,1314.98 1015.57,1314.98 1015.58,1314.98 1015.59,1314.98 1015.6,1314.98 1015.61,1314.98 1015.62,1314.98 1015.63,1314.98 1015.64,1314.98 1015.65,1314.98 1015.66,1314.98 1015.66,1314.98 1015.67,1314.98 1015.68,1314.98 1015.69,1314.98 1015.7,1314.98 1015.71,1314.99 1015.72,1314.99 1015.73,1314.99 1015.74,1314.99 1015.75,1314.99 1015.76,1314.99 1015.77,1314.99 1015.78,1314.99 1015.78,1314.99 1015.79,1314.99 1015.8,1314.99 1015.81,1314.99 1015.82,1314.99 1015.83,1314.99 1015.84,1314.99 1015.85,1314.99 1015.86,1315 1015.87,1315 1015.88,1315 1015.89,1315 1015.89,1315 1015.9,1315 1015.91,1315 1015.92,1315 1015.93,1315 1015.94,1315 1015.95,1315 1015.96,1315 1015.97,1315 1015.98,1315 1015.99,1315 1016,1315 1016,1315.01 1016.01,1315.01 1016.02,1315.01 1016.03,1315.01 1016.04,1315.01 1016.05,1315.01 1016.06,1315.01 1016.07,1315.01 1016.08,1315.01 1016.09,1315.01 1016.1,1315.01 1016.11,1315.01 1016.12,1315.01 1016.12,1315.01 1016.13,1315.01 1016.14,1315.01 1016.15,1315.02 1016.16,1315.02 1016.17,1315.02 1016.18,1315.02 1016.19,1315.02 1016.2,1315.02 1016.21,1315.02 1016.22,1315.02 1016.23,1315.02 1016.23,1315.02 1016.24,1315.02 1016.25,1315.02 1016.26,1315.02 1016.27,1315.02 1016.28,1315.02 1016.29,1315.02 1016.3,1315.02 1016.31,1315.03 1016.32,1315.03 1016.33,1315.03 1016.34,1315.03 1016.34,1315.03 1016.35,1315.03 1016.36,1315.03 1016.37,1315.03 1016.38,1315.03 1016.39,1315.03 1016.4,1315.03 1016.41,1315.03 1016.42,1315.03 1016.43,1315.03 1016.44,1315.03 1016.45,1315.03 1016.46,1315.04 1016.46,1315.04 1016.47,1315.04 1016.48,1315.04 1016.49,1315.04 1016.5,1315.04 1016.51,1315.04 1016.52,1315.04 1016.53,1315.04 1016.54,1315.04 1016.55,1315.04 1016.56,1315.04 1016.57,1315.04 1016.57,1315.04 1016.58,1315.04 1016.59,1315.04 1016.6,1315.05 1016.61,1315.05 1016.62,1315.05 1016.63,1315.05 1016.64,1315.05 1016.65,1315.05 1016.66,1315.05 1016.67,1315.05 1016.68,1315.05 1016.68,1315.05 1016.69,1315.05 1016.7,1315.05 1016.71,1315.05 1016.72,1315.05 1016.73,1315.05 1016.74,1315.05 1016.75,1315.06 1016.76,1315.06 1016.77,1315.06 1016.78,1315.06 1016.79,1315.06 1016.8,1315.06 1016.8,1315.06 1016.81,1315.06 1016.82,1315.06 1016.83,1315.06 1016.84,1315.06 1016.85,1315.06 1016.86,1315.06 1016.87,1315.06 1016.88,1315.06 1016.89,1315.06 1016.9,1315.07 1016.91,1315.07 1016.91,1315.07 1016.92,1315.07 1016.93,1315.07 1016.94,1315.07 1016.95,1315.07 1016.96,1315.07 1016.97,1315.07 1016.98,1315.07 1016.99,1315.07 1017,1315.07 1017.01,1315.07 1017.02,1315.07 1017.02,1315.07 1017.03,1315.07 1017.04,1315.07 1017.05,1315.08 1017.06,1315.08 1017.07,1315.08 1017.08,1315.08 1017.09,1315.08 1017.1,1315.08 1017.11,1315.08 1017.12,1315.08 1017.13,1315.08 1017.14,1315.08 1017.14,1315.08 1017.15,1315.08 1017.16,1315.08 1017.17,1315.08 1017.18,1315.08 1017.19,1315.08 1017.2,1315.09 1017.21,1315.09 1017.22,1315.09 1017.23,1315.09 1017.24,1315.09 1017.25,1315.09 1017.25,1315.09 1017.26,1315.09 1017.27,1315.09 1017.28,1315.09 1017.29,1315.09 1017.3,1315.09 1017.31,1315.09 1017.32,1315.09 1017.33,1315.09 1017.34,1315.09 1017.35,1315.1 1017.36,1315.1 1017.36,1315.1 1017.37,1315.1 1017.38,1315.1 1017.39,1315.1 1017.4,1315.1 1017.41,1315.1 1017.42,1315.1 1017.43,1315.1 1017.44,1315.1 1017.45,1315.1 1017.46,1315.1 1017.47,1315.1 1017.48,1315.1 1017.48,1315.1 1017.49,1315.11 1017.5,1315.11 1017.51,1315.11 1017.52,1315.11 1017.53,1315.11 1017.54,1315.11 1017.55,1315.11 1017.56,1315.11 1017.57,1315.11 1017.58,1315.11 1017.59,1315.11 1017.59,1315.11 1017.6,1315.11 1017.61,1315.11 1017.62,1315.11 1017.63,1315.11 1017.64,1315.11 1017.65,1315.12 1017.66,1315.12 1017.67,1315.12 1017.68,1315.12 1017.69,1315.12 1017.7,1315.12 1017.7,1315.12 1017.71,1315.12 1017.72,1315.12 1017.73,1315.12 1017.74,1315.12 1017.75,1315.12 1017.76,1315.12 1017.77,1315.12 1017.78,1315.12 1017.79,1315.12 1017.8,1315.13 1017.81,1315.13 1017.82,1315.13 1017.82,1315.13 1017.83,1315.13 1017.84,1315.13 1017.85,1315.13 1017.86,1315.13 1017.87,1315.13 1017.88,1315.13 1017.89,1315.13 1017.9,1315.13 1017.91,1315.13 1017.92,1315.13 1017.93,1315.13 1017.93,1315.13 1017.94,1315.14 1017.95,1315.14 1017.96,1315.14 1017.97,1315.14 1017.98,1315.14 1017.99,1315.14 1018,1315.14 1018.01,1315.14 1018.02,1315.14 1018.03,1315.14 1018.04,1315.14 1018.04,1315.14 1018.05,1315.14 1018.06,1315.14 1018.07,1315.14 1018.08,1315.14 1018.09,1315.15 1018.1,1315.15 1018.11,1315.15 1018.12,1315.15 1018.13,1315.15 1018.14,1315.15 1018.15,1315.15 1018.16,1315.15 1018.16,1315.15 1018.17,1315.15 1018.18,1315.15 1018.19,1315.15 1018.2,1315.15 1018.21,1315.15 1018.22,1315.15 1018.23,1315.15 1018.24,1315.16 1018.25,1315.16 1018.26,1315.16 1018.27,1315.16 1018.27,1315.16 1018.28,1315.16 1018.29,1315.16 1018.3,1315.16 1018.31,1315.16 1018.32,1315.16 1018.33,1315.16 1018.34,1315.16 1018.35,1315.16 1018.36,1315.16 1018.37,1315.16 1018.38,1315.16 1018.38,1315.16 1018.39,1315.17 1018.4,1315.17 1018.41,1315.17 1018.42,1315.17 1018.43,1315.17 1018.44,1315.17 1018.45,1315.17 1018.46,1315.17 1018.47,1315.17 1018.48,1315.17 1018.49,1315.17 1018.5,1315.17 1018.5,1315.17 1018.51,1315.17 1018.52,1315.17 1018.53,1315.17 1018.54,1315.18 1018.55,1315.18 1018.56,1315.18 1018.57,1315.18 1018.58,1315.18 1018.59,1315.18 1018.6,1315.18 1018.61,1315.18 1018.61,1315.18 1018.62,1315.18 1018.63,1315.18 1018.64,1315.18 1018.65,1315.18 1018.66,1315.18 1018.67,1315.18 1018.68,1315.18 1018.69,1315.19 1018.7,1315.19 1018.71,1315.19 1018.72,1315.19 1018.72,1315.19 1018.73,1315.19 1018.74,1315.19 1018.75,1315.19 1018.76,1315.19 1018.77,1315.19 1018.78,1315.19 1018.79,1315.19 1018.8,1315.19 1018.81,1315.19 1018.82,1315.19 1018.83,1315.19 1018.84,1315.2 1018.84,1315.2 1018.85,1315.2 1018.86,1315.2 1018.87,1315.2 1018.88,1315.2 1018.89,1315.2 1018.9,1315.2 1018.91,1315.2 1018.92,1315.2 1018.93,1315.2 1018.94,1315.2 1018.95,1315.2 1018.95,1315.2 1018.96,1315.2 1018.97,1315.2 1018.98,1315.2 1018.99,1315.21 1019,1315.21 1019.01,1315.21 1019.02,1315.21 1019.03,1315.21 1019.04,1315.21 1019.05,1315.21 1019.06,1315.21 1019.06,1315.21 1019.07,1315.21 1019.08,1315.21 1019.09,1315.21 1019.1,1315.21 1019.11,1315.21 1019.12,1315.21 1019.13,1315.21 1019.14,1315.22 1019.15,1315.22 1019.16,1315.22 1019.17,1315.22 1019.18,1315.22 1019.18,1315.22 1019.19,1315.22 1019.2,1315.22 1019.21,1315.22 1019.22,1315.22 1019.23,1315.22 1019.24,1315.22 1019.25,1315.22 1019.26,1315.22 1019.27,1315.22 1019.28,1315.22 1019.29,1315.23 1019.29,1315.23 1019.3,1315.23 1019.31,1315.23 1019.32,1315.23 1019.33,1315.23 1019.34,1315.23 1019.35,1315.23 1019.36,1315.23 1019.37,1315.23 1019.38,1315.23 1019.39,1315.23 1019.4,1315.23 1019.4,1315.23 1019.41,1315.23 1019.42,1315.23 1019.43,1315.24 1019.44,1315.24 1019.45,1315.24 1019.46,1315.24 1019.47,1315.24 1019.48,1315.24 1019.49,1315.24 1019.5,1315.24 1019.51,1315.24 1019.52,1315.24 1019.52,1315.24 1019.53,1315.24 1019.54,1315.24 1019.55,1315.24 1019.56,1315.24 1019.57,1315.24 1019.58,1315.24 1019.59,1315.25 1019.6,1315.25 1019.61,1315.25 1019.62,1315.25 1019.63,1315.25 1019.63,1315.25 1019.64,1315.25 1019.65,1315.25 1019.66,1315.25 1019.67,1315.25 1019.68,1315.25 1019.69,1315.25 1019.7,1315.25 1019.71,1315.25 1019.72,1315.25 1019.73,1315.25 1019.74,1315.26 1019.74,1315.26 1019.75,1315.26 1019.76,1315.26 1019.77,1315.26 1019.78,1315.26 1019.79,1315.26 1019.8,1315.26 1019.81,1315.26 1019.82,1315.26 1019.83,1315.26 1019.84,1315.26 1019.85,1315.26 1019.86,1315.26 1019.86,1315.26 1019.87,1315.26 1019.88,1315.27 1019.89,1315.27 1019.9,1315.27 1019.91,1315.27 1019.92,1315.27 1019.93,1315.27 1019.94,1315.27 1019.95,1315.27 1019.96,1315.27 1019.97,1315.27 1019.97,1315.27 1019.98,1315.27 1019.99,1315.27 1020,1315.27 1020.01,1315.27 1020.02,1315.27 1020.03,1315.28 1020.04,1315.28 1020.05,1315.28 1020.06,1315.28 1020.07,1315.28 1020.08,1315.28 1020.08,1315.28 1020.09,1315.28 1020.1,1315.28 1020.11,1315.28 1020.12,1315.28 1020.13,1315.28 1020.14,1315.28 1020.15,1315.28 1020.16,1315.28 1020.17,1315.28 1020.18,1315.29 1020.19,1315.29 1020.2,1315.29 1020.2,1315.29 1020.21,1315.29 1020.22,1315.29 1020.23,1315.29 1020.24,1315.29 1020.25,1315.29 1020.26,1315.29 1020.27,1315.29 1020.28,1315.29 1020.29,1315.29 1020.3,1315.29 1020.31,1315.29 1020.31,1315.29 1020.32,1315.29 1020.33,1315.3 1020.34,1315.3 1020.35,1315.3 1020.36,1315.3 1020.37,1315.3 1020.38,1315.3 1020.39,1315.3 1020.4,1315.3 1020.41,1315.3 1020.42,1315.3 1020.42,1315.3 1020.43,1315.3 1020.44,1315.3 1020.45,1315.3 1020.46,1315.3 1020.47,1315.3 1020.48,1315.31 1020.49,1315.31 1020.5,1315.31 1020.51,1315.31 1020.52,1315.31 1020.53,1315.31 1020.54,1315.31 1020.54,1315.31 1020.55,1315.31 1020.56,1315.31 1020.57,1315.31 1020.58,1315.31 1020.59,1315.31 1020.6,1315.31 1020.61,1315.31 1020.62,1315.31 1020.63,1315.32 1020.64,1315.32 1020.65,1315.32 1020.65,1315.32 1020.66,1315.32 1020.67,1315.32 1020.68,1315.32 1020.69,1315.32 1020.7,1315.32 1020.71,1315.32 1020.72,1315.32 1020.73,1315.32 1020.74,1315.32 1020.75,1315.32 1020.76,1315.32 1020.76,1315.32 1020.77,1315.33 1020.78,1315.33 1020.79,1315.33 1020.8,1315.33 1020.81,1315.33 1020.82,1315.33 1020.83,1315.33 1020.84,1315.33 1020.85,1315.33 1020.86,1315.33 1020.87,1315.33 1020.88,1315.33 1020.88,1315.33 1020.89,1315.33 1020.9,1315.33 1020.91,1315.33 1020.92,1315.33 1020.93,1315.34 1020.94,1315.34 1020.95,1315.34 1020.96,1315.34 1020.97,1315.34 1020.98,1315.34 1020.99,1315.34 1020.99,1315.34 1021,1315.34 1021.01,1315.34 1021.02,1315.34 1021.03,1315.34 1021.04,1315.34 1021.05,1315.34 1021.06,1315.34 1021.07,1315.34 1021.08,1315.35 1021.09,1315.35 1021.1,1315.35 1021.1,1315.35 1021.11,1315.35 1021.12,1315.35 1021.13,1315.35 1021.14,1315.35 1021.15,1315.35 1021.16,1315.35 1021.17,1315.35 1021.18,1315.35 1021.19,1315.35 1021.2,1315.35 1021.21,1315.35 1021.22,1315.35 1021.22,1315.36 1021.23,1315.36 1021.24,1315.36 1021.25,1315.36 1021.26,1315.36 1021.27,1315.36 1021.28,1315.36 1021.29,1315.36 1021.3,1315.36 1021.31,1315.36 1021.32,1315.36 1021.33,1315.36 1021.33,1315.36 1021.34,1315.36 1021.35,1315.36 1021.36,1315.36 1021.37,1315.37 1021.38,1315.37 1021.39,1315.37 1021.4,1315.37 1021.41,1315.37 1021.42,1315.37 1021.43,1315.37 1021.44,1315.37 1021.44,1315.37 1021.45,1315.37 1021.46,1315.37 1021.47,1315.37 1021.48,1315.37 1021.49,1315.37 1021.5,1315.37 1021.51,1315.37 1021.52,1315.37 1021.53,1315.38 1021.54,1315.38 1021.55,1315.38 1021.56,1315.38 1021.56,1315.38 1021.57,1315.38 1021.58,1315.38 1021.59,1315.38 1021.6,1315.38 1021.61,1315.38 1021.62,1315.38 1021.63,1315.38 1021.64,1315.38 1021.65,1315.38 1021.66,1315.38 1021.67,1315.38 1021.67,1315.39 1021.68,1315.39 1021.69,1315.39 1021.7,1315.39 1021.71,1315.39 1021.72,1315.39 1021.73,1315.39 1021.74,1315.39 1021.75,1315.39 1021.76,1315.39 1021.77,1315.39 1021.78,1315.39 1021.78,1315.39 1021.79,1315.39 1021.8,1315.39 1021.81,1315.39 1021.82,1315.4 1021.83,1315.4 1021.84,1315.4 1021.85,1315.4 1021.86,1315.4 1021.87,1315.4 1021.88,1315.4 1021.89,1315.4 1021.9,1315.4 1021.9,1315.4 1021.91,1315.4 1021.92,1315.4 1021.93,1315.4 1021.94,1315.4 1021.95,1315.4 1021.96,1315.4 1021.97,1315.41 1021.98,1315.41 1021.99,1315.41 1022,1315.41 1022.01,1315.41 1022.01,1315.41 1022.02,1315.41 1022.03,1315.41 1022.04,1315.41 1022.05,1315.41 1022.06,1315.41 1022.07,1315.41 1022.08,1315.41 1022.09,1315.41 1022.1,1315.41 1022.11,1315.41 1022.12,1315.42 1022.12,1315.42 1022.13,1315.42 1022.14,1315.42 1022.15,1315.42 1022.16,1315.42 1022.17,1315.42 1022.18,1315.42 1022.19,1315.42 1022.2,1315.42 1022.21,1315.42 1022.22,1315.42 1022.23,1315.42 1022.24,1315.42 1022.24,1315.42 1022.25,1315.42 1022.26,1315.42 1022.27,1315.43 1022.28,1315.43 1022.29,1315.43 1022.3,1315.43 1022.31,1315.43 1022.32,1315.43 1022.33,1315.43 1022.34,1315.43 1022.35,1315.43 1022.35,1315.43 1022.36,1315.43 1022.37,1315.43 1022.38,1315.43 1022.39,1315.43 1022.4,1315.43 1022.41,1315.43 1022.42,1315.44 1022.43,1315.44 1022.44,1315.44 1022.45,1315.44 1022.46,1315.44 1022.46,1315.44 1022.47,1315.44 1022.48,1315.44 1022.49,1315.44 1022.5,1315.44 1022.51,1315.44 1022.52,1315.44 1022.53,1315.44 1022.54,1315.44 1022.55,1315.44 1022.56,1315.44 1022.57,1315.45 1022.58,1315.45 1022.58,1315.45 1022.59,1315.45 1022.6,1315.45 1022.61,1315.45 1022.62,1315.45 1022.63,1315.45 1022.64,1315.45 1022.65,1315.45 1022.66,1315.45 1022.67,1315.45 1022.68,1315.45 1022.69,1315.45 1022.69,1315.45 1022.7,1315.45 1022.71,1315.46 1022.72,1315.46 1022.73,1315.46 1022.74,1315.46 1022.75,1315.46 1022.76,1315.46 1022.77,1315.46 1022.78,1315.46 1022.79,1315.46 1022.8,1315.46 1022.8,1315.46 1022.81,1315.46 1022.82,1315.46 1022.83,1315.46 1022.84,1315.46 1022.85,1315.46 1022.86,1315.46 1022.87,1315.47 1022.88,1315.47 1022.89,1315.47 1022.9,1315.47 1022.91,1315.47 1022.92,1315.47 1022.92,1315.47 1022.93,1315.47 1022.94,1315.47 1022.95,1315.47 1022.96,1315.47 1022.97,1315.47 1022.98,1315.47 1022.99,1315.47 1023,1315.47 1023.01,1315.47 1023.02,1315.48 1023.03,1315.48 1023.03,1315.48 1023.04,1315.48 1023.05,1315.48 1023.06,1315.48 1023.07,1315.48 1023.08,1315.48 1023.09,1315.48 1023.1,1315.48 1023.11,1315.48 1023.12,1315.48 1023.13,1315.48 1023.14,1315.48 1023.15,1315.48 1023.15,1315.48 1023.16,1315.49 1023.17,1315.49 1023.18,1315.49 1023.19,1315.49 1023.2,1315.49 1023.21,1315.49 1023.22,1315.49 1023.23,1315.49 1023.24,1315.49 1023.25,1315.49 1023.26,1315.49 1023.26,1315.49 1023.27,1315.49 1023.28,1315.49 1023.29,1315.49 1023.3,1315.49 1023.31,1315.5 1023.32,1315.5 1023.33,1315.5 1023.34,1315.5 1023.35,1315.5 1023.36,1315.5 1023.37,1315.5 1023.37,1315.5 1023.38,1315.5 1023.39,1315.5 1023.4,1315.5 1023.41,1315.5 1023.42,1315.5 1023.43,1315.5 1023.44,1315.5 1023.45,1315.5 1023.46,1315.5 1023.47,1315.51 1023.48,1315.51 1023.49,1315.51 1023.49,1315.51 1023.5,1315.51 1023.51,1315.51 1023.52,1315.51 1023.53,1315.51 1023.54,1315.51 1023.55,1315.51 1023.56,1315.51 1023.57,1315.51 1023.58,1315.51 1023.59,1315.51 1023.6,1315.51 1023.6,1315.51 1023.61,1315.52 1023.62,1315.52 1023.63,1315.52 1023.64,1315.52 1023.65,1315.52 1023.66,1315.52 1023.67,1315.52 1023.68,1315.52 1023.69,1315.52 1023.7,1315.52 1023.71,1315.52 1023.71,1315.52 1023.72,1315.52 1023.73,1315.52 1023.74,1315.52 1023.75,1315.52 1023.76,1315.53 1023.77,1315.53 1023.78,1315.53 1023.79,1315.53 1023.8,1315.53 1023.81,1315.53 1023.82,1315.53 1023.83,1315.53 1023.83,1315.53 1023.84,1315.53 1023.85,1315.53 1023.86,1315.53 1023.87,1315.53 1023.88,1315.53 1023.89,1315.53 1023.9,1315.53 1023.91,1315.54 1023.92,1315.54 1023.93,1315.54 1023.94,1315.54 1023.94,1315.54 1023.95,1315.54 1023.96,1315.54 1023.97,1315.54 1023.98,1315.54 1023.99,1315.54 1024,1315.54 1024.01,1315.54 1024.02,1315.54 1024.03,1315.54 1024.04,1315.54 1024.05,1315.54 1024.05,1315.54 1024.06,1315.55 1024.07,1315.55 1024.08,1315.55 1024.09,1315.55 1024.1,1315.55 1024.11,1315.55 1024.12,1315.55 1024.13,1315.55 1024.14,1315.55 1024.15,1315.55 1024.16,1315.55 1024.17,1315.55 1024.17,1315.55 1024.18,1315.55 1024.19,1315.55 1024.2,1315.55 1024.21,1315.56 1024.22,1315.56 1024.23,1315.56 1024.24,1315.56 1024.25,1315.56 1024.26,1315.56 1024.27,1315.56 1024.28,1315.56 1024.28,1315.56 1024.29,1315.56 1024.3,1315.56 1024.31,1315.56 1024.32,1315.56 1024.33,1315.56 1024.34,1315.56 1024.35,1315.56 1024.36,1315.57 1024.37,1315.57 1024.38,1315.57 1024.39,1315.57 1024.39,1315.57 1024.4,1315.57 1024.41,1315.57 1024.42,1315.57 1024.43,1315.57 1024.44,1315.57 1024.45,1315.57 1024.46,1315.57 1024.47,1315.57 1024.48,1315.57 1024.49,1315.57 1024.5,1315.57 1024.51,1315.58 1024.51,1315.58 1024.52,1315.58 1024.53,1315.58 1024.54,1315.58 1024.55,1315.58 1024.56,1315.58 1024.57,1315.58 1024.58,1315.58 1024.59,1315.58 1024.6,1315.58 1024.61,1315.58 1024.62,1315.58 1024.62,1315.58 1024.63,1315.58 1024.64,1315.58 1024.65,1315.58 1024.66,1315.59 1024.67,1315.59 1024.68,1315.59 1024.69,1315.59 1024.7,1315.59 1024.71,1315.59 1024.72,1315.59 1024.73,1315.59 1024.73,1315.59 1024.74,1315.59 1024.75,1315.59 1024.76,1315.59 1024.77,1315.59 1024.78,1315.59 1024.79,1315.59 1024.8,1315.59 1024.81,1315.6 1024.82,1315.6 1024.83,1315.6 1024.84,1315.6 1024.85,1315.6 1024.85,1315.6 1024.86,1315.6 1024.87,1315.6 1024.88,1315.6 1024.89,1315.6 1024.9,1315.6 1024.91,1315.6 1024.92,1315.6 1024.93,1315.6 1024.94,1315.6 1024.95,1315.6 1024.96,1315.61 1024.96,1315.61 1024.97,1315.61 1024.98,1315.61 1024.99,1315.61 1025,1315.61 1025.01,1315.61 1025.02,1315.61 1025.03,1315.61 1025.04,1315.61 1025.05,1315.61 1025.06,1315.61 1025.07,1315.61 1025.07,1315.61 1025.08,1315.61 1025.09,1315.61 1025.1,1315.62 1025.11,1315.62 1025.12,1315.62 1025.13,1315.62 1025.14,1315.62 1025.15,1315.62 1025.16,1315.62 1025.17,1315.62 1025.18,1315.62 1025.19,1315.62 1025.19,1315.62 1025.2,1315.62 1025.21,1315.62 1025.22,1315.62 1025.23,1315.62 1025.24,1315.62 1025.25,1315.62 1025.26,1315.63 1025.27,1315.63 1025.28,1315.63 1025.29,1315.63 1025.3,1315.63 1025.3,1315.63 1025.31,1315.63 1025.32,1315.63 1025.33,1315.63 1025.34,1315.63 1025.35,1315.63 1025.36,1315.63 1025.37,1315.63 1025.38,1315.63 1025.39,1315.63 1025.4,1315.63 1025.41,1315.64 1025.41,1315.64 1025.42,1315.64 1025.43,1315.64 1025.44,1315.64 1025.45,1315.64 1025.46,1315.64 1025.47,1315.64 1025.48,1315.64 1025.49,1315.64 1025.5,1315.64 1025.51,1315.64 1025.52,1315.64 1025.53,1315.64 1025.53,1315.64 1025.54,1315.64 1025.55,1315.65 1025.56,1315.65 1025.57,1315.65 1025.58,1315.65 1025.59,1315.65 1025.6,1315.65 1025.61,1315.65 1025.62,1315.65 1025.63,1315.65 1025.64,1315.65 1025.64,1315.65 1025.65,1315.65 1025.66,1315.65 1025.67,1315.65 1025.68,1315.65 1025.69,1315.65 1025.7,1315.66 1025.71,1315.66 1025.72,1315.66 1025.73,1315.66 1025.74,1315.66 1025.75,1315.66 1025.75,1315.66 1025.76,1315.66 1025.77,1315.66 1025.78,1315.66 1025.79,1315.66 1025.8,1315.66 1025.81,1315.66 1025.82,1315.66 1025.83,1315.66 1025.84,1315.66 1025.85,1315.66 1025.86,1315.67 1025.87,1315.67 1025.87,1315.67 1025.88,1315.67 1025.89,1315.67 1025.9,1315.67 1025.91,1315.67 1025.92,1315.67 1025.93,1315.67 1025.94,1315.67 1025.95,1315.67 1025.96,1315.67 1025.97,1315.67 1025.98,1315.67 1025.98,1315.67 1025.99,1315.67 1026,1315.68 1026.01,1315.68 1026.02,1315.68 1026.03,1315.68 1026.04,1315.68 1026.05,1315.68 1026.06,1315.68 1026.07,1315.68 1026.08,1315.68 1026.09,1315.68 1026.09,1315.68 1026.1,1315.68 1026.11,1315.68 1026.12,1315.68 1026.13,1315.68 1026.14,1315.68 1026.15,1315.69 1026.16,1315.69 1026.17,1315.69 1026.18,1315.69 1026.19,1315.69 1026.2,1315.69 1026.21,1315.69 1026.21,1315.69 1026.22,1315.69 1026.23,1315.69 1026.24,1315.69 1026.25,1315.69 1026.26,1315.69 1026.27,1315.69 1026.28,1315.69 1026.29,1315.69 1026.3,1315.7 1026.31,1315.7 1026.32,1315.7 1026.32,1315.7 1026.33,1315.7 1026.34,1315.7 1026.35,1315.7 1026.36,1315.7 1026.37,1315.7 1026.38,1315.7 1026.39,1315.7 1026.4,1315.7 1026.41,1315.7 1026.42,1315.7 1026.43,1315.7 1026.43,1315.7 1026.44,1315.7 1026.45,1315.71 1026.46,1315.71 1026.47,1315.71 1026.48,1315.71 1026.49,1315.71 1026.5,1315.71 1026.51,1315.71 1026.52,1315.71 1026.53,1315.71 1026.54,1315.71 1026.55,1315.71 1026.55,1315.71 1026.56,1315.71 1026.57,1315.71 1026.58,1315.71 1026.59,1315.71 1026.6,1315.72 1026.61,1315.72 1026.62,1315.72 1026.63,1315.72 1026.64,1315.72 1026.65,1315.72 1026.66,1315.72 1026.66,1315.72 1026.67,1315.72 1026.68,1315.72 1026.69,1315.72 1026.7,1315.72 1026.71,1315.72 1026.72,1315.72 1026.73,1315.72 1026.74,1315.72 1026.75,1315.73 1026.76,1315.73 1026.77,1315.73 1026.77,1315.73 1026.78,1315.73 1026.79,1315.73 1026.8,1315.73 1026.81,1315.73 1026.82,1315.73 1026.83,1315.73 1026.84,1315.73 1026.85,1315.73 1026.86,1315.73 1026.87,1315.73 1026.88,1315.73 1026.89,1315.73 1026.89,1315.74 1026.9,1315.74 1026.91,1315.74 1026.92,1315.74 1026.93,1315.74 1026.94,1315.74 1026.95,1315.74 1026.96,1315.74 1026.97,1315.74 1026.98,1315.74 1026.99,1315.74 1027,1315.74 1027,1315.74 1027.01,1315.74 1027.02,1315.74 1027.03,1315.74 1027.04,1315.74 1027.05,1315.75 1027.06,1315.75 1027.07,1315.75 1027.08,1315.75 1027.09,1315.75 1027.1,1315.75 1027.11,1315.75 1027.11,1315.75 1027.12,1315.75 1027.13,1315.75 1027.14,1315.75 1027.15,1315.75 1027.16,1315.75 1027.17,1315.75 1027.18,1315.75 1027.19,1315.75 1027.2,1315.76 1027.21,1315.76 1027.22,1315.76 1027.23,1315.76 1027.23,1315.76 1027.24,1315.76 1027.25,1315.76 1027.26,1315.76 1027.27,1315.76 1027.28,1315.76 1027.29,1315.76 1027.3,1315.76 1027.31,1315.76 1027.32,1315.76 1027.33,1315.76 1027.34,1315.76 1027.34,1315.77 1027.35,1315.77 1027.36,1315.77 1027.37,1315.77 1027.38,1315.77 1027.39,1315.77 1027.4,1315.77 1027.41,1315.77 1027.42,1315.77 1027.43,1315.77 1027.44,1315.77 1027.45,1315.77 1027.45,1315.77 1027.46,1315.77 1027.47,1315.77 1027.48,1315.77 1027.49,1315.78 1027.5,1315.78 1027.51,1315.78 1027.52,1315.78 1027.53,1315.78 1027.54,1315.78 1027.55,1315.78 1027.56,1315.78 1027.57,1315.78 1027.57,1315.78 1027.58,1315.78 1027.59,1315.78 1027.6,1315.78 1027.61,1315.78 1027.62,1315.78 1027.63,1315.78 1027.64,1315.78 1027.65,1315.79 1027.66,1315.79 1027.67,1315.79 1027.68,1315.79 1027.68,1315.79 1027.69,1315.79 1027.7,1315.79 1027.71,1315.79 1027.72,1315.79 1027.73,1315.79 1027.74,1315.79 1027.75,1315.79 1027.76,1315.79 1027.77,1315.79 1027.78,1315.79 1027.79,1315.79 1027.79,1315.8 1027.8,1315.8 1027.81,1315.8 1027.82,1315.8 1027.83,1315.8 1027.84,1315.8 1027.85,1315.8 1027.86,1315.8 1027.87,1315.8 1027.88,1315.8 1027.89,1315.8 1027.9,1315.8 1027.91,1315.8 1027.91,1315.8 1027.92,1315.8 1027.93,1315.8 1027.94,1315.81 1027.95,1315.81 1027.96,1315.81 1027.97,1315.81 1027.98,1315.81 1027.99,1315.81 1028,1315.81 1028.01,1315.81 1028.02,1315.81 1028.02,1315.81 1028.03,1315.81 1028.04,1315.81 1028.05,1315.81 1028.06,1315.81 1028.07,1315.81 1028.08,1315.81 1028.09,1315.82 1028.1,1315.82 1028.11,1315.82 1028.12,1315.82 1028.13,1315.82 1028.13,1315.82 1028.14,1315.82 1028.15,1315.82 1028.16,1315.82 1028.17,1315.82 1028.18,1315.82 1028.19,1315.82 1028.2,1315.82 1028.21,1315.82 1028.22,1315.82 1028.23,1315.82 1028.24,1315.82 1028.25,1315.83 1028.25,1315.83 1028.26,1315.83 1028.27,1315.83 1028.28,1315.83 1028.29,1315.83 1028.3,1315.83 1028.31,1315.83 1028.32,1315.83 1028.33,1315.83 1028.34,1315.83 1028.35,1315.83 1028.36,1315.83 1028.36,1315.83 1028.37,1315.83 1028.38,1315.83 1028.39,1315.84 1028.4,1315.84 1028.41,1315.84 1028.42,1315.84 1028.43,1315.84 1028.44,1315.84 1028.45,1315.84 1028.46,1315.84 1028.47,1315.84 1028.47,1315.84 1028.48,1315.84 1028.49,1315.84 1028.5,1315.84 1028.51,1315.84 1028.52,1315.84 1028.53,1315.84 1028.54,1315.85 1028.55,1315.85 1028.56,1315.85 1028.57,1315.85 1028.58,1315.85 1028.59,1315.85 1028.59,1315.85 1028.6,1315.85 1028.61,1315.85 1028.62,1315.85 1028.63,1315.85 1028.64,1315.85 1028.65,1315.85 1028.66,1315.85 1028.67,1315.85 1028.68,1315.85 1028.69,1315.86 1028.7,1315.86 1028.7,1315.86 1028.71,1315.86 1028.72,1315.86 1028.73,1315.86 1028.74,1315.86 1028.75,1315.86 1028.76,1315.86 1028.77,1315.86 1028.78,1315.86 1028.79,1315.86 1028.8,1315.86 1028.81,1315.86 1028.81,1315.86 1028.82,1315.86 1028.83,1315.86 1028.84,1315.87 1028.85,1315.87 1028.86,1315.87 1028.87,1315.87 1028.88,1315.87 1028.89,1315.87 1028.9,1315.87 1028.91,1315.87 1028.92,1315.87 1028.93,1315.87 1028.93,1315.87 1028.94,1315.87 1028.95,1315.87 1028.96,1315.87 1028.97,1315.87 1028.98,1315.87 1028.99,1315.88 1029,1315.88 1029.01,1315.88 1029.02,1315.88 1029.03,1315.88 1029.04,1315.88 1029.04,1315.88 1029.05,1315.88 1029.06,1315.88 1029.07,1315.88 1029.08,1315.88 1029.09,1315.88 1029.1,1315.88 1029.11,1315.88 1029.12,1315.88 1029.13,1315.88 1029.14,1315.89 1029.15,1315.89 1029.15,1315.89 1029.16,1315.89 1029.17,1315.89 1029.18,1315.89 1029.19,1315.89 1029.2,1315.89 1029.21,1315.89 1029.22,1315.89 1029.23,1315.89 1029.24,1315.89 1029.25,1315.89 1029.26,1315.89 1029.27,1315.89 1029.27,1315.89 1029.28,1315.89 1029.29,1315.9 1029.3,1315.9 1029.31,1315.9 1029.32,1315.9 1029.33,1315.9 1029.34,1315.9 1029.35,1315.9 1029.36,1315.9 1029.37,1315.9 1029.38,1315.9 1029.38,1315.9 1029.39,1315.9 1029.4,1315.9 1029.41,1315.9 1029.42,1315.9 1029.43,1315.9 1029.44,1315.91 1029.45,1315.91 1029.46,1315.91 1029.47,1315.91 1029.48,1315.91 1029.49,1315.91 1029.49,1315.91 1029.5,1315.91 1029.51,1315.91 1029.52,1315.91 1029.53,1315.91 1029.54,1315.91 1029.55,1315.91 1029.56,1315.91 1029.57,1315.91 1029.58,1315.91 1029.59,1315.92 1029.6,1315.92 1029.61,1315.92 1029.61,1315.92 1029.62,1315.92 1029.63,1315.92 1029.64,1315.92 1029.65,1315.92 1029.66,1315.92 1029.67,1315.92 1029.68,1315.92 1029.69,1315.92 1029.7,1315.92 1029.71,1315.92 1029.72,1315.92 1029.72,1315.92 1029.73,1315.93 1029.74,1315.93 1029.75,1315.93 1029.76,1315.93 1029.77,1315.93 1029.78,1315.93 1029.79,1315.93 1029.8,1315.93 1029.81,1315.93 1029.82,1315.93 1029.83,1315.93 1029.83,1315.93 1029.84,1315.93 1029.85,1315.93 1029.86,1315.93 1029.87,1315.93 1029.88,1315.93 1029.89,1315.94 1029.9,1315.94 1029.91,1315.94 1029.92,1315.94 1029.93,1315.94 1029.94,1315.94 1029.95,1315.94 1029.95,1315.94 1029.96,1315.94 1029.97,1315.94 1029.98,1315.94 1029.99,1315.94 1030,1315.94 1030.01,1315.94 1030.02,1315.94 1030.03,1315.94 1030.04,1315.95 1030.05,1315.95 1030.06,1315.95 1030.06,1315.95 1030.07,1315.95 1030.08,1315.95 1030.09,1315.95 1030.1,1315.95 1030.11,1315.95 1030.12,1315.95 1030.13,1315.95 1030.14,1315.95 1030.15,1315.95 1030.16,1315.95 1030.17,1315.95 1030.17,1315.95 1030.18,1315.96 1030.19,1315.96 1030.2,1315.96 1030.21,1315.96 1030.22,1315.96 1030.23,1315.96 1030.24,1315.96 1030.25,1315.96 1030.26,1315.96 1030.27,1315.96 1030.28,1315.96 1030.29,1315.96 1030.29,1315.96 1030.3,1315.96 1030.31,1315.96 1030.32,1315.96 1030.33,1315.97 1030.34,1315.97 1030.35,1315.97 1030.36,1315.97 1030.37,1315.97 1030.38,1315.97 1030.39,1315.97 1030.4,1315.97 1030.4,1315.97 1030.41,1315.97 1030.42,1315.97 1030.43,1315.97 1030.44,1315.97 1030.45,1315.97 1030.46,1315.97 1030.47,1315.97 1030.48,1315.97 1030.49,1315.98 1030.5,1315.98 1030.51,1315.98 1030.51,1315.98 1030.52,1315.98 1030.53,1315.98 1030.54,1315.98 1030.55,1315.98 1030.56,1315.98 1030.57,1315.98 1030.58,1315.98 1030.59,1315.98 1030.6,1315.98 1030.61,1315.98 1030.62,1315.98 1030.63,1315.98 1030.63,1315.99 1030.64,1315.99 1030.65,1315.99 1030.66,1315.99 1030.67,1315.99 1030.68,1315.99 1030.69,1315.99 1030.7,1315.99 1030.71,1315.99 1030.72,1315.99 1030.73,1315.99 1030.74,1315.99 1030.74,1315.99 1030.75,1315.99 1030.76,1315.99 1030.77,1315.99 1030.78,1316 1030.79,1316 1030.8,1316 1030.81,1316 1030.82,1316 1030.83,1316 1030.84,1316 1030.85,1316 1030.85,1316 1030.86,1316 1030.87,1316 1030.88,1316 1030.89,1316 1030.9,1316 1030.91,1316 1030.92,1316 1030.93,1316 1030.94,1316.01 1030.95,1316.01 1030.96,1316.01 1030.97,1316.01 1030.97,1316.01 1030.98,1316.01 1030.99,1316.01 1031,1316.01 1031.01,1316.01 1031.02,1316.01 1031.03,1316.01 1031.04,1316.01 1031.05,1316.01 1031.06,1316.01 1031.07,1316.01 1031.08,1316.01 1031.08,1316.02 1031.09,1316.02 1031.1,1316.02 1031.11,1316.02 1031.12,1316.02 1031.13,1316.02 1031.14,1316.02 1031.15,1316.02 1031.16,1316.02 1031.17,1316.02 1031.18,1316.02 1031.19,1316.02 1031.19,1316.02 1031.2,1316.02 1031.21,1316.02 1031.22,1316.02 1031.23,1316.03 1031.24,1316.03 1031.25,1316.03 1031.26,1316.03 1031.27,1316.03 1031.28,1316.03 1031.29,1316.03 1031.3,1316.03 1031.31,1316.03 1031.31,1316.03 1031.32,1316.03 1031.33,1316.03 1031.34,1316.03 1031.35,1316.03 1031.36,1316.03 1031.37,1316.03 1031.38,1316.04 1031.39,1316.04 1031.4,1316.04 1031.41,1316.04 1031.42,1316.04 1031.42,1316.04 1031.43,1316.04 1031.44,1316.04 1031.45,1316.04 1031.46,1316.04 1031.47,1316.04 1031.48,1316.04 1031.49,1316.04 1031.5,1316.04 1031.51,1316.04 1031.52,1316.04 1031.53,1316.04 1031.53,1316.05 1031.54,1316.05 1031.55,1316.05 1031.56,1316.05 1031.57,1316.05 1031.58,1316.05 1031.59,1316.05 1031.6,1316.05 1031.61,1316.05 1031.62,1316.05 1031.63,1316.05 1031.64,1316.05 1031.65,1316.05 1031.65,1316.05 1031.66,1316.05 1031.67,1316.05 1031.68,1316.06 1031.69,1316.06 1031.7,1316.06 1031.71,1316.06 1031.72,1316.06 1031.73,1316.06 1031.74,1316.06 1031.75,1316.06 1031.76,1316.06 1031.76,1316.06 1031.77,1316.06 1031.78,1316.06 1031.79,1316.06 1031.8,1316.06 1031.81,1316.06 1031.82,1316.06 1031.83,1316.07 1031.84,1316.07 1031.85,1316.07 1031.86,1316.07 1031.87,1316.07 1031.87,1316.07 1031.88,1316.07 1031.89,1316.07 1031.9,1316.07 1031.91,1316.07 1031.92,1316.07 1031.93,1316.07 1031.94,1316.07 1031.95,1316.07 1031.96,1316.07 1031.97,1316.07 1031.98,1316.07 1031.99,1316.08 1031.99,1316.08 1032,1316.08 1032.01,1316.08 1032.02,1316.08 1032.03,1316.08 1032.04,1316.08 1032.05,1316.08 1032.06,1316.08 1032.07,1316.08 1032.08,1316.08 1032.09,1316.08 1032.1,1316.08 1032.1,1316.08 1032.11,1316.08 1032.12,1316.08 1032.13,1316.09 1032.14,1316.09 1032.15,1316.09 1032.16,1316.09 1032.17,1316.09 1032.18,1316.09 1032.19,1316.09 1032.2,1316.09 1032.21,1316.09 1032.21,1316.09 1032.22,1316.09 1032.23,1316.09 1032.24,1316.09 1032.25,1316.09 1032.26,1316.09 1032.27,1316.09 1032.28,1316.1 1032.29,1316.1 1032.3,1316.1 1032.31,1316.1 1032.32,1316.1 1032.33,1316.1 1032.33,1316.1 1032.34,1316.1 1032.35,1316.1 1032.36,1316.1 1032.37,1316.1 1032.38,1316.1 1032.39,1316.1 1032.4,1316.1 1032.41,1316.1 1032.42,1316.1 1032.43,1316.11 1032.44,1316.11 1032.44,1316.11 1032.45,1316.11 1032.46,1316.11 1032.47,1316.11 1032.48,1316.11 1032.49,1316.11 1032.5,1316.11 1032.51,1316.11 1032.52,1316.11 1032.53,1316.11 1032.54,1316.11 1032.55,1316.11 1032.55,1316.11 1032.56,1316.11 1032.57,1316.11 1032.58,1316.12 1032.59,1316.12 1032.6,1316.12 1032.61,1316.12 1032.62,1316.12 1032.63,1316.12 1032.64,1316.12 1032.65,1316.12 1032.66,1316.12 1032.67,1316.12 1032.67,1316.12 1032.68,1316.12 1032.69,1316.12 1032.7,1316.12 1032.71,1316.12 1032.72,1316.12 1032.73,1316.13 1032.74,1316.13 1032.75,1316.13 1032.76,1316.13 1032.77,1316.13 1032.78,1316.13 1032.78,1316.13 1032.79,1316.13 1032.8,1316.13 1032.81,1316.13 1032.82,1316.13 1032.83,1316.13 1032.84,1316.13 1032.85,1316.13 1032.86,1316.13 1032.87,1316.13 1032.88,1316.14 1032.89,1316.14 1032.89,1316.14 1032.9,1316.14 1032.91,1316.14 1032.92,1316.14 1032.93,1316.14 1032.94,1316.14 1032.95,1316.14 1032.96,1316.14 1032.97,1316.14 1032.98,1316.14 1032.99,1316.14 1033,1316.14 1033.01,1316.14 1033.01,1316.14 1033.02,1316.15 1033.03,1316.15 1033.04,1316.15 1033.05,1316.15 1033.06,1316.15 1033.07,1316.15 1033.08,1316.15 1033.09,1316.15 1033.1,1316.15 1033.11,1316.15 1033.12,1316.15 1033.12,1316.15 1033.13,1316.15 1033.14,1316.15 1033.15,1316.15 1033.16,1316.15 1033.17,1316.15 1033.18,1316.16 1033.19,1316.16 1033.2,1316.16 1033.21,1316.16 1033.22,1316.16 1033.23,1316.16 1033.23,1316.16 1033.24,1316.16 1033.25,1316.16 1033.26,1316.16 1033.27,1316.16 1033.28,1316.16 1033.29,1316.16 1033.3,1316.16 1033.31,1316.16 1033.32,1316.16 1033.33,1316.17 1033.34,1316.17 1033.35,1316.17 1033.35,1316.17 1033.36,1316.17 1033.37,1316.17 1033.38,1316.17 1033.39,1316.17 1033.4,1316.17 1033.41,1316.17 1033.42,1316.17 1033.43,1316.17 1033.44,1316.17 1033.45,1316.17 1033.46,1316.17 1033.46,1316.17 1033.47,1316.18 1033.48,1316.18 1033.49,1316.18 1033.5,1316.18 1033.51,1316.18 1033.52,1316.18 1033.53,1316.18 1033.54,1316.18 1033.55,1316.18 1033.56,1316.18 1033.57,1316.18 1033.57,1316.18 1033.58,1316.18 1033.59,1316.18 1033.6,1316.18 1033.61,1316.18 1033.62,1316.18 1033.63,1316.19 1033.64,1316.19 1033.65,1316.19 1033.66,1316.19 1033.67,1316.19 1033.68,1316.19 1033.69,1316.19 1033.69,1316.19 1033.7,1316.19 1033.71,1316.19 1033.72,1316.19 1033.73,1316.19 1033.74,1316.19 1033.75,1316.19 1033.76,1316.19 1033.77,1316.19 1033.78,1316.2 1033.79,1316.2 1033.8,1316.2 1033.8,1316.2 1033.81,1316.2 1033.82,1316.2 1033.83,1316.2 1033.84,1316.2 1033.85,1316.2 1033.86,1316.2 1033.87,1316.2 1033.88,1316.2 1033.89,1316.2 1033.9,1316.2 1033.91,1316.2 1033.91,1316.2 1033.92,1316.21 1033.93,1316.21 1033.94,1316.21 1033.95,1316.21 1033.96,1316.21 1033.97,1316.21 1033.98,1316.21 1033.99,1316.21 1034,1316.21 1034.01,1316.21 1034.02,1316.21 1034.03,1316.21 1034.03,1316.21 1034.04,1316.21 1034.05,1316.21 1034.06,1316.21 1034.07,1316.21 1034.08,1316.22 1034.09,1316.22 1034.1,1316.22 1034.11,1316.22 1034.12,1316.22 1034.13,1316.22 1034.14,1316.22 1034.14,1316.22 1034.15,1316.22 1034.16,1316.22 1034.17,1316.22 1034.18,1316.22 1034.19,1316.22 1034.2,1316.22 1034.21,1316.22 1034.22,1316.22 1034.23,1316.23 1034.24,1316.23 1034.25,1316.23 1034.25,1316.23 1034.26,1316.23 1034.27,1316.23 1034.28,1316.23 1034.29,1316.23 1034.3,1316.23 1034.31,1316.23 1034.32,1316.23 1034.33,1316.23 1034.34,1316.23 1034.35,1316.23 1034.36,1316.23 1034.37,1316.23 1034.37,1316.24 1034.38,1316.24 1034.39,1316.24 1034.4,1316.24 1034.41,1316.24 1034.42,1316.24 1034.43,1316.24 1034.44,1316.24 1034.45,1316.24 1034.46,1316.24 1034.47,1316.24 1034.48,1316.24 1034.48,1316.24 1034.49,1316.24 1034.5,1316.24 1034.51,1316.24 1034.52,1316.25 1034.53,1316.25 1034.54,1316.25 1034.55,1316.25 1034.56,1316.25 1034.57,1316.25 1034.58,1316.25 1034.59,1316.25 1034.59,1316.25 1034.6,1316.25 1034.61,1316.25 1034.62,1316.25 1034.63,1316.25 1034.64,1316.25 1034.65,1316.25 1034.66,1316.25 1034.67,1316.25 1034.68,1316.26 1034.69,1316.26 1034.7,1316.26 1034.71,1316.26 1034.71,1316.26 1034.72,1316.26 1034.73,1316.26 1034.74,1316.26 1034.75,1316.26 1034.76,1316.26 1034.77,1316.26 1034.78,1316.26 1034.79,1316.26 1034.8,1316.26 1034.81,1316.26 1034.82,1316.26 1034.82,1316.27 1034.83,1316.27 1034.84,1316.27 1034.85,1316.27 1034.86,1316.27 1034.87,1316.27 1034.88,1316.27 1034.89,1316.27 1034.9,1316.27 1034.91,1316.27 1034.92,1316.27 1034.93,1316.27 1034.93,1316.27 1034.94,1316.27 1034.95,1316.27 1034.96,1316.27 1034.97,1316.28 1034.98,1316.28 1034.99,1316.28 1035,1316.28 1035.01,1316.28 1035.02,1316.28 1035.03,1316.28 1035.04,1316.28 1035.05,1316.28 1035.05,1316.28 1035.06,1316.28 1035.07,1316.28 1035.08,1316.28 1035.09,1316.28 1035.1,1316.28 1035.11,1316.28 1035.12,1316.28 1035.13,1316.29 1035.14,1316.29 1035.15,1316.29 1035.16,1316.29 1035.16,1316.29 1035.17,1316.29 1035.18,1316.29 1035.19,1316.29 1035.2,1316.29 1035.21,1316.29 1035.22,1316.29 1035.23,1316.29 1035.24,1316.29 1035.25,1316.29 1035.26,1316.29 1035.27,1316.29 1035.27,1316.3 1035.28,1316.3 1035.29,1316.3 1035.3,1316.3 1035.31,1316.3 1035.32,1316.3 1035.33,1316.3 1035.34,1316.3 1035.35,1316.3 1035.36,1316.3 1035.37,1316.3 1035.38,1316.3 1035.39,1316.3 1035.39,1316.3 1035.4,1316.3 1035.41,1316.3 1035.42,1316.31 1035.43,1316.31 1035.44,1316.31 1035.45,1316.31 1035.46,1316.31 1035.47,1316.31 1035.48,1316.31 1035.49,1316.31 1035.5,1316.31 1035.5,1316.31 1035.51,1316.31 1035.52,1316.31 1035.53,1316.31 1035.54,1316.31 1035.55,1316.31 1035.56,1316.31 1035.57,1316.32 1035.58,1316.32 1035.59,1316.32 1035.6,1316.32 1035.61,1316.32 1035.61,1316.32 1035.62,1316.32 1035.63,1316.32 1035.64,1316.32 1035.65,1316.32 1035.66,1316.32 1035.67,1316.32 1035.68,1316.32 1035.69,1316.32 1035.7,1316.32 1035.71,1316.32 1035.72,1316.32 1035.73,1316.33 1035.73,1316.33 1035.74,1316.33 1035.75,1316.33 1035.76,1316.33 1035.77,1316.33 1035.78,1316.33 1035.79,1316.33 1035.8,1316.33 1035.81,1316.33 1035.82,1316.33 1035.83,1316.33 1035.84,1316.33 1035.84,1316.33 1035.85,1316.33 1035.86,1316.33 1035.87,1316.34 1035.88,1316.34 1035.89,1316.34 1035.9,1316.34 1035.91,1316.34 1035.92,1316.34 1035.93,1316.34 1035.94,1316.34 1035.95,1316.34 1035.95,1316.34 1035.96,1316.34 1035.97,1316.34 1035.98,1316.34 1035.99,1316.34 1036,1316.34 1036.01,1316.34 1036.02,1316.35 1036.03,1316.35 1036.04,1316.35 1036.05,1316.35 1036.06,1316.35 1036.07,1316.35 1036.07,1316.35 1036.08,1316.35 1036.09,1316.35 1036.1,1316.35 1036.11,1316.35 1036.12,1316.35 1036.13,1316.35 1036.14,1316.35 1036.15,1316.35 1036.16,1316.35 1036.17,1316.35 1036.18,1316.36 1036.18,1316.36 1036.19,1316.36 1036.2,1316.36 1036.21,1316.36 1036.22,1316.36 1036.23,1316.36 1036.24,1316.36 1036.25,1316.36 1036.26,1316.36 1036.27,1316.36 1036.28,1316.36 1036.29,1316.36 1036.29,1316.36 1036.3,1316.36 1036.31,1316.36 1036.32,1316.37 1036.33,1316.37 1036.34,1316.37 1036.35,1316.37 1036.36,1316.37 1036.37,1316.37 1036.38,1316.37 1036.39,1316.37 1036.4,1316.37 1036.41,1316.37 1036.41,1316.37 1036.42,1316.37 1036.43,1316.37 1036.44,1316.37 1036.45,1316.37 1036.46,1316.37 1036.47,1316.38 1036.48,1316.38 1036.49,1316.38 1036.5,1316.38 1036.51,1316.38 1036.52,1316.38 1036.52,1316.38 1036.53,1316.38 1036.54,1316.38 1036.55,1316.38 1036.56,1316.38 1036.57,1316.38 1036.58,1316.38 1036.59,1316.38 1036.6,1316.38 1036.61,1316.38 1036.62,1316.38 1036.63,1316.39 1036.63,1316.39 1036.64,1316.39 1036.65,1316.39 1036.66,1316.39 1036.67,1316.39 1036.68,1316.39 1036.69,1316.39 1036.7,1316.39 1036.71,1316.39 1036.72,1316.39 1036.73,1316.39 1036.74,1316.39 1036.75,1316.39 1036.75,1316.39 1036.76,1316.39 1036.77,1316.4 1036.78,1316.4 1036.79,1316.4 1036.8,1316.4 1036.81,1316.4 1036.82,1316.4 1036.83,1316.4 1036.84,1316.4 1036.85,1316.4 1036.86,1316.4 1036.86,1316.4 1036.87,1316.4 1036.88,1316.4 1036.89,1316.4 1036.9,1316.4 1036.91,1316.4 1036.92,1316.41 1036.93,1316.41 1036.94,1316.41 1036.95,1316.41 1036.96,1316.41 1036.97,1316.41 1036.97,1316.41 1036.98,1316.41 1036.99,1316.41 1037,1316.41 1037.01,1316.41 1037.02,1316.41 1037.03,1316.41 1037.04,1316.41 1037.05,1316.41 1037.06,1316.41 1037.07,1316.41 1037.08,1316.42 1037.09,1316.42 1037.09,1316.42 1037.1,1316.42 1037.11,1316.42 1037.12,1316.42 1037.13,1316.42 1037.14,1316.42 1037.15,1316.42 1037.16,1316.42 1037.17,1316.42 1037.18,1316.42 1037.19,1316.42 1037.2,1316.42 1037.2,1316.42 1037.21,1316.42 1037.22,1316.43 1037.23,1316.43 1037.24,1316.43 1037.25,1316.43 1037.26,1316.43 1037.27,1316.43 1037.28,1316.43 1037.29,1316.43 1037.3,1316.43 1037.31,1316.43 1037.31,1316.43 1037.32,1316.43 1037.33,1316.43 1037.34,1316.43 1037.35,1316.43 1037.36,1316.43 1037.37,1316.44 1037.38,1316.44 1037.39,1316.44 1037.4,1316.44 1037.41,1316.44 1037.42,1316.44 1037.43,1316.44 1037.43,1316.44 1037.44,1316.44 1037.45,1316.44 1037.46,1316.44 1037.47,1316.44 1037.48,1316.44 1037.49,1316.44 1037.5,1316.44 1037.51,1316.44 1037.52,1316.45 1037.53,1316.45 1037.54,1316.45 1037.54,1316.45 1037.55,1316.45 1037.56,1316.45 1037.57,1316.45 1037.58,1316.45 1037.59,1316.45 1037.6,1316.45 1037.61,1316.45 1037.62,1316.45 1037.63,1316.45 1037.64,1316.45 1037.65,1316.45 1037.65,1316.45 1037.66,1316.45 1037.67,1316.46 1037.68,1316.46 1037.69,1316.46 1037.7,1316.46 1037.71,1316.46 1037.72,1316.46 1037.73,1316.46 1037.74,1316.46 1037.75,1316.46 1037.76,1316.46 1037.77,1316.46 1037.77,1316.46 1037.78,1316.46 1037.79,1316.46 1037.8,1316.46 1037.81,1316.46 1037.82,1316.47 1037.83,1316.47 1037.84,1316.47 1037.85,1316.47 1037.86,1316.47 1037.87,1316.47 1037.88,1316.47 1037.88,1316.47 1037.89,1316.47 1037.9,1316.47 1037.91,1316.47 1037.92,1316.47 1037.93,1316.47 1037.94,1316.47 1037.95,1316.47 1037.96,1316.47 1037.97,1316.48 1037.98,1316.48 1037.99,1316.48 1037.99,1316.48 1038,1316.48 1038.01,1316.48 1038.02,1316.48 1038.03,1316.48 1038.04,1316.48 1038.05,1316.48 1038.06,1316.48 1038.07,1316.48 1038.08,1316.48 1038.09,1316.48 1038.1,1316.48 1038.11,1316.48 1038.11,1316.48 1038.12,1316.49 1038.13,1316.49 1038.14,1316.49 1038.15,1316.49 1038.16,1316.49 1038.17,1316.49 1038.18,1316.49 1038.19,1316.49 1038.2,1316.49 1038.21,1316.49 1038.22,1316.49 1038.22,1316.49 1038.23,1316.49 1038.24,1316.49 1038.25,1316.49 1038.26,1316.49 1038.27,1316.5 1038.28,1316.5 1038.29,1316.5 1038.3,1316.5 1038.31,1316.5 1038.32,1316.5 1038.33,1316.5 1038.33,1316.5 1038.34,1316.5 1038.35,1316.5 1038.36,1316.5 1038.37,1316.5 1038.38,1316.5 1038.39,1316.5 1038.4,1316.5 1038.41,1316.5 1038.42,1316.51 1038.43,1316.51 1038.44,1316.51 1038.45,1316.51 1038.45,1316.51 1038.46,1316.51 1038.47,1316.51 1038.48,1316.51 1038.49,1316.51 1038.5,1316.51 1038.51,1316.51 1038.52,1316.51 1038.53,1316.51 1038.54,1316.51 1038.55,1316.51 1038.56,1316.51 1038.56,1316.51 1038.57,1316.52 1038.58,1316.52 1038.59,1316.52 1038.6,1316.52 1038.61,1316.52 1038.62,1316.52 1038.63,1316.52 1038.64,1316.52 1038.65,1316.52 1038.66,1316.52 1038.67,1316.52 1038.67,1316.52 1038.68,1316.52 1038.69,1316.52 1038.7,1316.52 1038.71,1316.52 1038.72,1316.53 1038.73,1316.53 1038.74,1316.53 1038.75,1316.53 1038.76,1316.53 1038.77,1316.53 1038.78,1316.53 1038.79,1316.53 1038.79,1316.53 1038.8,1316.53 1038.81,1316.53 1038.82,1316.53 1038.83,1316.53 1038.84,1316.53 1038.85,1316.53 1038.86,1316.53 1038.87,1316.54 1038.88,1316.54 1038.89,1316.54 1038.9,1316.54 1038.9,1316.54 1038.91,1316.54 1038.92,1316.54 1038.93,1316.54 1038.94,1316.54 1038.95,1316.54 1038.96,1316.54 1038.97,1316.54 1038.98,1316.54 1038.99,1316.54 1039,1316.54 1039.01,1316.54 1039.01,1316.54 1039.02,1316.55 1039.03,1316.55 1039.04,1316.55 1039.05,1316.55 1039.06,1316.55 1039.07,1316.55 1039.08,1316.55 1039.09,1316.55 1039.1,1316.55 1039.11,1316.55 1039.12,1316.55 1039.13,1316.55 1039.13,1316.55 1039.14,1316.55 1039.15,1316.55 1039.16,1316.55 1039.17,1316.56 1039.18,1316.56 1039.19,1316.56 1039.2,1316.56 1039.21,1316.56 1039.22,1316.56 1039.23,1316.56 1039.24,1316.56 1039.24,1316.56 1039.25,1316.56 1039.26,1316.56 1039.27,1316.56 1039.28,1316.56 1039.29,1316.56 1039.3,1316.56 1039.31,1316.56 1039.32,1316.57 1039.33,1316.57 1039.34,1316.57 1039.35,1316.57 1039.35,1316.57 1039.36,1316.57 1039.37,1316.57 1039.38,1316.57 1039.39,1316.57 1039.4,1316.57 1039.41,1316.57 1039.42,1316.57 1039.43,1316.57 1039.44,1316.57 1039.45,1316.57 1039.46,1316.57 1039.47,1316.57 1039.47,1316.58 1039.48,1316.58 1039.49,1316.58 1039.5,1316.58 1039.51,1316.58 1039.52,1316.58 1039.53,1316.58 1039.54,1316.58 1039.55,1316.58 1039.56,1316.58 1039.57,1316.58 1039.58,1316.58 1039.58,1316.58 1039.59,1316.58 1039.6,1316.58 1039.61,1316.58 1039.62,1316.59 1039.63,1316.59 1039.64,1316.59 1039.65,1316.59 1039.66,1316.59 1039.67,1316.59 1039.68,1316.59 1039.69,1316.59 1039.69,1316.59 1039.7,1316.59 1039.71,1316.59 1039.72,1316.59 1039.73,1316.59 1039.74,1316.59 1039.75,1316.59 1039.76,1316.59 1039.77,1316.6 1039.78,1316.6 1039.79,1316.6 1039.8,1316.6 1039.81,1316.6 1039.81,1316.6 1039.82,1316.6 1039.83,1316.6 1039.84,1316.6 1039.85,1316.6 1039.86,1316.6 1039.87,1316.6 1039.88,1316.6 1039.89,1316.6 1039.9,1316.6 1039.91,1316.6 1039.92,1316.6 1039.92,1316.61 1039.93,1316.61 1039.94,1316.61 1039.95,1316.61 1039.96,1316.61 1039.97,1316.61 1039.98,1316.61 1039.99,1316.61 1040,1316.61 1040.01,1316.61 1040.02,1316.61 1040.03,1316.61 1040.03,1316.61 1040.04,1316.61 1040.05,1316.61 1040.06,1316.61 1040.07,1316.62 1040.08,1316.62 1040.09,1316.62 1040.1,1316.62 1040.11,1316.62 1040.12,1316.62 1040.13,1316.62 1040.14,1316.62 1040.15,1316.62 1040.15,1316.62 1040.16,1316.62 1040.17,1316.62 1040.18,1316.62 1040.19,1316.62 1040.2,1316.62 1040.21,1316.62 1040.22,1316.63 1040.23,1316.63 1040.24,1316.63 1040.25,1316.63 1040.26,1316.63 1040.26,1316.63 1040.27,1316.63 1040.28,1316.63 1040.29,1316.63 1040.3,1316.63 1040.31,1316.63 1040.32,1316.63 1040.33,1316.63 1040.34,1316.63 1040.35,1316.63 1040.36,1316.63 1040.37,1316.63 1040.37,1316.64 1040.38,1316.64 1040.39,1316.64 1040.4,1316.64 1040.41,1316.64 1040.42,1316.64 1040.43,1316.64 1040.44,1316.64 1040.45,1316.64 1040.46,1316.64 1040.47,1316.64 1040.48,1316.64 1040.49,1316.64 1040.49,1316.64 1040.5,1316.64 1040.51,1316.64 1040.52,1316.65 1040.53,1316.65 1040.54,1316.65 1040.55,1316.65 1040.56,1316.65 1040.57,1316.65 1040.58,1316.65 1040.59,1316.65 1040.6,1316.65 1040.6,1316.65 1040.61,1316.65 1040.62,1316.65 1040.63,1316.65 1040.64,1316.65 1040.65,1316.65 1040.66,1316.65 1040.67,1316.66 1040.68,1316.66 1040.69,1316.66 1040.7,1316.66 1040.71,1316.66 1040.71,1316.66 1040.72,1316.66 1040.73,1316.66 1040.74,1316.66 1040.75,1316.66 1040.76,1316.66 1040.77,1316.66 1040.78,1316.66 1040.79,1316.66 1040.8,1316.66 1040.81,1316.66 1040.82,1316.66 1040.83,1316.67 1040.83,1316.67 1040.84,1316.67 1040.85,1316.67 1040.86,1316.67 1040.87,1316.67 1040.88,1316.67 1040.89,1316.67 1040.9,1316.67 1040.91,1316.67 1040.92,1316.67 1040.93,1316.67 1040.94,1316.67 1040.94,1316.67 1040.95,1316.67 1040.96,1316.67 1040.97,1316.68 1040.98,1316.68 1040.99,1316.68 1041,1316.68 1041.01,1316.68 1041.02,1316.68 1041.03,1316.68 1041.04,1316.68 1041.05,1316.68 1041.05,1316.68 1041.06,1316.68 1041.07,1316.68 1041.08,1316.68 1041.09,1316.68 1041.1,1316.68 1041.11,1316.68 1041.12,1316.69 1041.13,1316.69 1041.14,1316.69 1041.15,1316.69 1041.16,1316.69 1041.17,1316.69 1041.17,1316.69 1041.18,1316.69 1041.19,1316.69 1041.2,1316.69 1041.21,1316.69 1041.22,1316.69 1041.23,1316.69 1041.24,1316.69 1041.25,1316.69 1041.26,1316.69 1041.27,1316.69 1041.28,1316.7 1041.28,1316.7 1041.29,1316.7 1041.3,1316.7 1041.31,1316.7 1041.32,1316.7 1041.33,1316.7 1041.34,1316.7 1041.35,1316.7 1041.36,1316.7 1041.37,1316.7 1041.38,1316.7 1041.39,1316.7 1041.39,1316.7 1041.4,1316.7 1041.41,1316.7 1041.42,1316.71 1041.43,1316.71 1041.44,1316.71 1041.45,1316.71 1041.46,1316.71 1041.47,1316.71 1041.48,1316.71 1041.49,1316.71 1041.5,1316.71 1041.51,1316.71 1041.51,1316.71 1041.52,1316.71 1041.53,1316.71 1041.54,1316.71 1041.55,1316.71 1041.56,1316.71 1041.57,1316.72 1041.58,1316.72 1041.59,1316.72 1041.6,1316.72 1041.61,1316.72 1041.62,1316.72 1041.62,1316.72 1041.63,1316.72 1041.64,1316.72 1041.65,1316.72 1041.66,1316.72 1041.67,1316.72 1041.68,1316.72 1041.69,1316.72 1041.7,1316.72 1041.71,1316.72 1041.72,1316.72 1041.73,1316.73 1041.73,1316.73 1041.74,1316.73 1041.75,1316.73 1041.76,1316.73 1041.77,1316.73 1041.78,1316.73 1041.79,1316.73 1041.8,1316.73 1041.81,1316.73 1041.82,1316.73 1041.83,1316.73 1041.84,1316.73 1041.85,1316.73 1041.85,1316.73 1041.86,1316.73 1041.87,1316.74 1041.88,1316.74 1041.89,1316.74 1041.9,1316.74 1041.91,1316.74 1041.92,1316.74 1041.93,1316.74 1041.94,1316.74 1041.95,1316.74 1041.96,1316.74 1041.96,1316.74 1041.97,1316.74 1041.98,1316.74 1041.99,1316.74 1042,1316.74 1042.01,1316.74 1042.02,1316.75 1042.03,1316.75 1042.04,1316.75 1042.05,1316.75 1042.06,1316.75 1042.07,1316.75 1042.07,1316.75 1042.08,1316.75 1042.09,1316.75 1042.1,1316.75 1042.11,1316.75 1042.12,1316.75 1042.13,1316.75 1042.14,1316.75 1042.15,1316.75 1042.16,1316.75 1042.17,1316.75 1042.18,1316.76 1042.19,1316.76 1042.19,1316.76 1042.2,1316.76 1042.21,1316.76 1042.22,1316.76 1042.23,1316.76 1042.24,1316.76 1042.25,1316.76 1042.26,1316.76 1042.27,1316.76 1042.28,1316.76 1042.29,1316.76 1042.3,1316.76 1042.3,1316.76 1042.31,1316.76 1042.32,1316.77 1042.33,1316.77 1042.34,1316.77 1042.35,1316.77 1042.36,1316.77 1042.37,1316.77 1042.38,1316.77 1042.39,1316.77 1042.4,1316.77 1042.41,1316.77 1042.41,1316.77 1042.42,1316.77 1042.43,1316.77 1042.44,1316.77 1042.45,1316.77 1042.46,1316.77 1042.47,1316.78 1042.48,1316.78 1042.49,1316.78 1042.5,1316.78 1042.51,1316.78 1042.52,1316.78 1042.53,1316.78 1042.53,1316.78 1042.54,1316.78 1042.55,1316.78 1042.56,1316.78 1042.57,1316.78 1042.58,1316.78 1042.59,1316.78 1042.6,1316.78 1042.61,1316.78 1042.62,1316.78 1042.63,1316.79 1042.64,1316.79 1042.64,1316.79 1042.65,1316.79 1042.66,1316.79 1042.67,1316.79 1042.68,1316.79 1042.69,1316.79 1042.7,1316.79 1042.71,1316.79 1042.72,1316.79 1042.73,1316.79 1042.74,1316.79 1042.75,1316.79 1042.75,1316.79 1042.76,1316.79 1042.77,1316.8 1042.78,1316.8 1042.79,1316.8 1042.8,1316.8 1042.81,1316.8 1042.82,1316.8 1042.83,1316.8 1042.84,1316.8 1042.85,1316.8 1042.86,1316.8 1042.87,1316.8 1042.87,1316.8 1042.88,1316.8 1042.89,1316.8 1042.9,1316.8 1042.91,1316.8 1042.92,1316.81 1042.93,1316.81 1042.94,1316.81 1042.95,1316.81 1042.96,1316.81 1042.97,1316.81 1042.98,1316.81 1042.98,1316.81 1042.99,1316.81 1043,1316.81 1043.01,1316.81 1043.02,1316.81 1043.03,1316.81 1043.04,1316.81 1043.05,1316.81 1043.06,1316.81 1043.07,1316.81 1043.08,1316.82 1043.09,1316.82 1043.09,1316.82 1043.1,1316.82 1043.11,1316.82 1043.12,1316.82 1043.13,1316.82 1043.14,1316.82 1043.15,1316.82 1043.16,1316.82 1043.17,1316.82 1043.18,1316.82 1043.19,1316.82 1043.2,1316.82 1043.21,1316.82 1043.21,1316.82 1043.22,1316.83 1043.23,1316.83 1043.24,1316.83 1043.25,1316.83 1043.26,1316.83 1043.27,1316.83 1043.28,1316.83 1043.29,1316.83 1043.3,1316.83 1043.31,1316.83 1043.32,1316.83 1043.32,1316.83 1043.33,1316.83 1043.34,1316.83 1043.35,1316.83 1043.36,1316.83 1043.37,1316.84 1043.38,1316.84 1043.39,1316.84 1043.4,1316.84 1043.41,1316.84 1043.42,1316.84 1043.43,1316.84 1043.43,1316.84 1043.44,1316.84 1043.45,1316.84 1043.46,1316.84 1043.47,1316.84 1043.48,1316.84 1043.49,1316.84 1043.5,1316.84 1043.51,1316.84 1043.52,1316.84 1043.53,1316.85 1043.54,1316.85 1043.55,1316.85 1043.55,1316.85 1043.56,1316.85 1043.57,1316.85 1043.58,1316.85 1043.59,1316.85 1043.6,1316.85 1043.61,1316.85 1043.62,1316.85 1043.63,1316.85 1043.64,1316.85 1043.65,1316.85 1043.66,1316.85 1043.66,1316.85 1043.67,1316.86 1043.68,1316.86 1043.69,1316.86 1043.7,1316.86 1043.71,1316.86 1043.72,1316.86 1043.73,1316.86 1043.74,1316.86 1043.75,1316.86 1043.76,1316.86 1043.77,1316.86 1043.77,1316.86 1043.78,1316.86 1043.79,1316.86 1043.8,1316.86 1043.81,1316.86 1043.82,1316.87 1043.83,1316.87 1043.84,1316.87 1043.85,1316.87 1043.86,1316.87 1043.87,1316.87 1043.88,1316.87 1043.89,1316.87 1043.89,1316.87 1043.9,1316.87 1043.91,1316.87 1043.92,1316.87 1043.93,1316.87 1043.94,1316.87 1043.95,1316.87 1043.96,1316.87 1043.97,1316.87 1043.98,1316.88 1043.99,1316.88 1044,1316.88 1044,1316.88 1044.01,1316.88 1044.02,1316.88 1044.03,1316.88 1044.04,1316.88 1044.05,1316.88 1044.06,1316.88 1044.07,1316.88 1044.08,1316.88 1044.09,1316.88 1044.1,1316.88 1044.11,1316.88 1044.11,1316.88 1044.12,1316.89 1044.13,1316.89 1044.14,1316.89 1044.15,1316.89 1044.16,1316.89 1044.17,1316.89 1044.18,1316.89 1044.19,1316.89 1044.2,1316.89 1044.21,1316.89 1044.22,1316.89 1044.23,1316.89 1044.23,1316.89 1044.24,1316.89 1044.25,1316.89 1044.26,1316.89 1044.27,1316.9 1044.28,1316.9 1044.29,1316.9 1044.3,1316.9 1044.31,1316.9 1044.32,1316.9 1044.33,1316.9 1044.34,1316.9 1044.34,1316.9 1044.35,1316.9 1044.36,1316.9 1044.37,1316.9 1044.38,1316.9 1044.39,1316.9 1044.4,1316.9 1044.41,1316.9 1044.42,1316.9 1044.43,1316.91 1044.44,1316.91 1044.45,1316.91 1044.45,1316.91 1044.46,1316.91 1044.47,1316.91 1044.48,1316.91 1044.49,1316.91 1044.5,1316.91 1044.51,1316.91 1044.52,1316.91 1044.53,1316.91 1044.54,1316.91 1044.55,1316.91 1044.56,1316.91 1044.57,1316.91 1044.57,1316.92 1044.58,1316.92 1044.59,1316.92 1044.6,1316.92 1044.61,1316.92 1044.62,1316.92 1044.63,1316.92 1044.64,1316.92 1044.65,1316.92 1044.66,1316.92 1044.67,1316.92 1044.68,1316.92 1044.68,1316.92 1044.69,1316.92 1044.7,1316.92 1044.71,1316.92 1044.72,1316.93 1044.73,1316.93 1044.74,1316.93 1044.75,1316.93 1044.76,1316.93 1044.77,1316.93 1044.78,1316.93 1044.79,1316.93 1044.79,1316.93 1044.8,1316.93 1044.81,1316.93 1044.82,1316.93 1044.83,1316.93 1044.84,1316.93 1044.85,1316.93 1044.86,1316.93 1044.87,1316.93 1044.88,1316.94 1044.89,1316.94 1044.9,1316.94 1044.91,1316.94 1044.91,1316.94 1044.92,1316.94 1044.93,1316.94 1044.94,1316.94 1044.95,1316.94 1044.96,1316.94 1044.97,1316.94 1044.98,1316.94 1044.99,1316.94 1045,1316.94 1045.01,1316.94 1045.02,1316.94 1045.02,1316.95 1045.03,1316.95 1045.04,1316.95 1045.05,1316.95 1045.06,1316.95 1045.07,1316.95 1045.08,1316.95 1045.09,1316.95 1045.1,1316.95 1045.11,1316.95 1045.12,1316.95 1045.13,1316.95 1045.13,1316.95 1045.14,1316.95 1045.15,1316.95 1045.16,1316.95 1045.17,1316.95 1045.18,1316.96 1045.19,1316.96 1045.2,1316.96 1045.21,1316.96 1045.22,1316.96 1045.23,1316.96 1045.24,1316.96 1045.25,1316.96 1045.25,1316.96 1045.26,1316.96 1045.27,1316.96 1045.28,1316.96 1045.29,1316.96 1045.3,1316.96 1045.31,1316.96 1045.32,1316.96 1045.33,1316.97 1045.34,1316.97 1045.35,1316.97 1045.36,1316.97 1045.36,1316.97 1045.37,1316.97 1045.38,1316.97 1045.39,1316.97 1045.4,1316.97 1045.41,1316.97 1045.42,1316.97 1045.43,1316.97 1045.44,1316.97 1045.45,1316.97 1045.46,1316.97 1045.47,1316.97 1045.47,1316.98 1045.48,1316.98 1045.49,1316.98 1045.5,1316.98 1045.51,1316.98 1045.52,1316.98 1045.53,1316.98 1045.54,1316.98 1045.55,1316.98 1045.56,1316.98 1045.57,1316.98 1045.58,1316.98 1045.59,1316.98 1045.59,1316.98 1045.6,1316.98 1045.61,1316.98 1045.62,1316.98 1045.63,1316.99 1045.64,1316.99 1045.65,1316.99 1045.66,1316.99 1045.67,1316.99 1045.68,1316.99 1045.69,1316.99 1045.7,1316.99 1045.7,1316.99 1045.71,1316.99 1045.72,1316.99 1045.73,1316.99 1045.74,1316.99 1045.75,1316.99 1045.76,1316.99 1045.77,1316.99 1045.78,1317 1045.79,1317 1045.8,1317 1045.81,1317 1045.81,1317 1045.82,1317 1045.83,1317 1045.84,1317 1045.85,1317 1045.86,1317 1045.87,1317 1045.88,1317 1045.89,1317 1045.9,1317 1045.91,1317 1045.92,1317 1045.93,1317.01 1045.93,1317.01 1045.94,1317.01 1045.95,1317.01 1045.96,1317.01 1045.97,1317.01 1045.98,1317.01 1045.99,1317.01 1046,1317.01 1046.01,1317.01 1046.02,1317.01 1046.03,1317.01 1046.04,1317.01 1046.04,1317.01 1046.05,1317.01 1046.06,1317.01 1046.07,1317.01 1046.08,1317.02 1046.09,1317.02 1046.1,1317.02 1046.11,1317.02 1046.12,1317.02 1046.13,1317.02 1046.14,1317.02 1046.15,1317.02 1046.15,1317.02 1046.16,1317.02 1046.17,1317.02 1046.18,1317.02 1046.19,1317.02 1046.2,1317.02 1046.21,1317.02 1046.22,1317.02 1046.23,1317.03 1046.24,1317.03 1046.25,1317.03 1046.26,1317.03 1046.27,1317.03 1046.27,1317.03 1046.28,1317.03 1046.29,1317.03 1046.3,1317.03 1046.31,1317.03 1046.32,1317.03 1046.33,1317.03 1046.34,1317.03 1046.35,1317.03 1046.36,1317.03 1046.37,1317.03 1046.38,1317.04 1046.38,1317.04 1046.39,1317.04 1046.4,1317.04 1046.41,1317.04 1046.42,1317.04 1046.43,1317.04 1046.44,1317.04 1046.45,1317.04 1046.46,1317.04 1046.47,1317.04 1046.48,1317.04 1046.49,1317.04 1046.49,1317.04 1046.5,1317.04 1046.51,1317.04 1046.52,1317.04 1046.53,1317.05 1046.54,1317.05 1046.55,1317.05 1046.56,1317.05 1046.57,1317.05 1046.58,1317.05 1046.59,1317.05 1046.6,1317.05 1046.61,1317.05 1046.61,1317.05 1046.62,1317.05 1046.63,1317.05 1046.64,1317.05 1046.65,1317.05 1046.66,1317.05 1046.67,1317.05 1046.68,1317.06 1046.69,1317.06 1046.7,1317.06 1046.71,1317.06 1046.72,1317.06 1046.72,1317.06 1046.73,1317.06 1046.74,1317.06 1046.75,1317.06 1046.76,1317.06 1046.77,1317.06 1046.78,1317.06 1046.79,1317.06 1046.8,1317.06 1046.81,1317.06 1046.82,1317.06 1046.83,1317.06 1046.83,1317.07 1046.84,1317.07 1046.85,1317.07 1046.86,1317.07 1046.87,1317.07 1046.88,1317.07 1046.89,1317.07 1046.9,1317.07 1046.91,1317.07 1046.92,1317.07 1046.93,1317.07 1046.94,1317.07 1046.95,1317.07 1046.95,1317.07 1046.96,1317.07 1046.97,1317.07 1046.98,1317.08 1046.99,1317.08 1047,1317.08 1047.01,1317.08 1047.02,1317.08 1047.03,1317.08 1047.04,1317.08 1047.05,1317.08 1047.06,1317.08 1047.06,1317.08 1047.07,1317.08 1047.08,1317.08 1047.09,1317.08 1047.1,1317.08 1047.11,1317.08 1047.12,1317.08 1047.13,1317.09 1047.14,1317.09 1047.15,1317.09 1047.16,1317.09 1047.17,1317.09 1047.17,1317.09 1047.18,1317.09 1047.19,1317.09 1047.2,1317.09 1047.21,1317.09 1047.22,1317.09 1047.23,1317.09 1047.24,1317.09 1047.25,1317.09 1047.26,1317.09 1047.27,1317.09 1047.28,1317.09 1047.29,1317.1 1047.29,1317.1 1047.3,1317.1 1047.31,1317.1 1047.32,1317.1 1047.33,1317.1 1047.34,1317.1 1047.35,1317.1 1047.36,1317.1 1047.37,1317.1 1047.38,1317.1 1047.39,1317.1 1047.4,1317.1 1047.4,1317.1 1047.41,1317.1 1047.42,1317.1 1047.43,1317.11 1047.44,1317.11 1047.45,1317.11 1047.46,1317.11 1047.47,1317.11 1047.48,1317.11 1047.49,1317.11 1047.5,1317.11 1047.51,1317.11 1047.52,1317.11 1047.52,1317.11 1047.53,1317.11 1047.54,1317.11 1047.55,1317.11 1047.56,1317.11 1047.57,1317.11 1047.58,1317.12 1047.59,1317.12 1047.6,1317.12 1047.61,1317.12 1047.62,1317.12 1047.63,1317.12 1047.63,1317.12 1047.64,1317.12 1047.65,1317.12 1047.66,1317.12 1047.67,1317.12 1047.68,1317.12 1047.69,1317.12 1047.7,1317.12 1047.71,1317.12 1047.72,1317.12 1047.73,1317.12 1047.74,1317.13 1047.74,1317.13 1047.75,1317.13 1047.76,1317.13 1047.77,1317.13 1047.78,1317.13 1047.79,1317.13 1047.8,1317.13 1047.81,1317.13 1047.82,1317.13 1047.83,1317.13 1047.84,1317.13 1047.85,1317.13 1047.86,1317.13 1047.86,1317.13 1047.87,1317.13 1047.88,1317.14 1047.89,1317.14 1047.9,1317.14 1047.91,1317.14 1047.92,1317.14 1047.93,1317.14 1047.94,1317.14 1047.95,1317.14 1047.96,1317.14 1047.97,1317.14 1047.97,1317.14 1047.98,1317.14 1047.99,1317.14 1048,1317.14 1048.01,1317.14 1048.02,1317.14 1048.03,1317.14 1048.04,1317.15 1048.05,1317.15 1048.06,1317.15 1048.07,1317.15 1048.08,1317.15 1048.08,1317.15 1048.09,1317.15 1048.1,1317.15 1048.11,1317.15 1048.12,1317.15 1048.13,1317.15 1048.14,1317.15 1048.15,1317.15 1048.16,1317.15 1048.17,1317.15 1048.18,1317.15 1048.19,1317.16 1048.2,1317.16 1048.2,1317.16 1048.21,1317.16 1048.22,1317.16 1048.23,1317.16 1048.24,1317.16 1048.25,1317.16 1048.26,1317.16 1048.27,1317.16 1048.28,1317.16 1048.29,1317.16 1048.3,1317.16 1048.31,1317.16 1048.31,1317.16 1048.32,1317.16 1048.33,1317.17 1048.34,1317.17 1048.35,1317.17 1048.36,1317.17 1048.37,1317.17 1048.38,1317.17 1048.39,1317.17 1048.4,1317.17 1048.41,1317.17 1048.42,1317.17 1048.42,1317.17 1048.43,1317.17 1048.44,1317.17 1048.45,1317.17 1048.46,1317.17 1048.47,1317.17 1048.48,1317.17 1048.49,1317.18 1048.5,1317.18 1048.51,1317.18 1048.52,1317.18 1048.53,1317.18 1048.54,1317.18 1048.54,1317.18 1048.55,1317.18 1048.56,1317.18 1048.57,1317.18 1048.58,1317.18 1048.59,1317.18 1048.6,1317.18 1048.61,1317.18 1048.62,1317.18 1048.63,1317.18 1048.64,1317.19 1048.65,1317.19 1048.65,1317.19 1048.66,1317.19 1048.67,1317.19 1048.68,1317.19 1048.69,1317.19 1048.7,1317.19 1048.71,1317.19 1048.72,1317.19 1048.73,1317.19 1048.74,1317.19 1048.75,1317.19 1048.76,1317.19 1048.76,1317.19 1048.77,1317.19 1048.78,1317.2 1048.79,1317.2 1048.8,1317.2 1048.81,1317.2 1048.82,1317.2 1048.83,1317.2 1048.84,1317.2 1048.85,1317.2 1048.86,1317.2 1048.87,1317.2 1048.88,1317.2 1048.88,1317.2 1048.89,1317.2 1048.9,1317.2 1048.91,1317.2 1048.92,1317.2 1048.93,1317.2 1048.94,1317.21 1048.95,1317.21 1048.96,1317.21 1048.97,1317.21 1048.98,1317.21 1048.99,1317.21 1048.99,1317.21 1049,1317.21 1049.01,1317.21 1049.02,1317.21 1049.03,1317.21 1049.04,1317.21 1049.05,1317.21 1049.06,1317.21 1049.07,1317.21 1049.08,1317.21 1049.09,1317.22 1049.1,1317.22 1049.1,1317.22 1049.11,1317.22 1049.12,1317.22 1049.13,1317.22 1049.14,1317.22 1049.15,1317.22 1049.16,1317.22 1049.17,1317.22 1049.18,1317.22 1049.19,1317.22 1049.2,1317.22 1049.21,1317.22 1049.22,1317.22 1049.22,1317.22 1049.23,1317.22 1049.24,1317.23 1049.25,1317.23 1049.26,1317.23 1049.27,1317.23 1049.28,1317.23 1049.29,1317.23 1049.3,1317.23 1049.31,1317.23 1049.32,1317.23 1049.33,1317.23 1049.33,1317.23 1049.34,1317.23 1049.35,1317.23 1049.36,1317.23 1049.37,1317.23 1049.38,1317.23 1049.39,1317.24 1049.4,1317.24 1049.41,1317.24 1049.42,1317.24 1049.43,1317.24 1049.44,1317.24 1049.44,1317.24 1049.45,1317.24 1049.46,1317.24 1049.47,1317.24 1049.48,1317.24 1049.49,1317.24 1049.5,1317.24 1049.51,1317.24 1049.52,1317.24 1049.53,1317.24 1049.54,1317.25 1049.55,1317.25 1049.56,1317.25 1049.56,1317.25 1049.57,1317.25 1049.58,1317.25 1049.59,1317.25 1049.6,1317.25 1049.61,1317.25 1049.62,1317.25 1049.63,1317.25 1049.64,1317.25 1049.65,1317.25 1049.66,1317.25 1049.67,1317.25 1049.67,1317.25 1049.68,1317.25 1049.69,1317.26 1049.7,1317.26 1049.71,1317.26 1049.72,1317.26 1049.73,1317.26 1049.74,1317.26 1049.75,1317.26 1049.76,1317.26 1049.77,1317.26 1049.78,1317.26 1049.78,1317.26 1049.79,1317.26 1049.8,1317.26 1049.81,1317.26 1049.82,1317.26 1049.83,1317.26 1049.84,1317.27 1049.85,1317.27 1049.86,1317.27 1049.87,1317.27 1049.88,1317.27 1049.89,1317.27 1049.9,1317.27 1049.9,1317.27 1049.91,1317.27 1049.92,1317.27 1049.93,1317.27 1049.94,1317.27 1049.95,1317.27 1049.96,1317.27 1049.97,1317.27 1049.98,1317.27 1049.99,1317.27 1050,1317.28 1050.01,1317.28 1050.01,1317.28 1050.02,1317.28 1050.03,1317.28 1050.04,1317.28 1050.05,1317.28 1050.06,1317.28 1050.07,1317.28 1050.08,1317.28 1050.09,1317.28 1050.1,1317.28 1050.11,1317.28 1050.12,1317.28 1050.12,1317.28 1050.13,1317.28 1050.14,1317.29 1050.15,1317.29 1050.16,1317.29 1050.17,1317.29 1050.18,1317.29 1050.19,1317.29 1050.2,1317.29 1050.21,1317.29 1050.22,1317.29 1050.23,1317.29 1050.24,1317.29 1050.24,1317.29 1050.25,1317.29 1050.26,1317.29 1050.27,1317.29 1050.28,1317.29 1050.29,1317.3 1050.3,1317.3 1050.31,1317.3 1050.32,1317.3 1050.33,1317.3 1050.34,1317.3 1050.35,1317.3 1050.35,1317.3 1050.36,1317.3 1050.37,1317.3 1050.38,1317.3 1050.39,1317.3 1050.4,1317.3 1050.41,1317.3 1050.42,1317.3 1050.43,1317.3 1050.44,1317.3 1050.45,1317.31 1050.46,1317.31 1050.46,1317.31 1050.47,1317.31 1050.48,1317.31 1050.49,1317.31 1050.5,1317.31 1050.51,1317.31 1050.52,1317.31 1050.53,1317.31 1050.54,1317.31 1050.55,1317.31 1050.56,1317.31 1050.57,1317.31 1050.58,1317.31 1050.58,1317.31 1050.59,1317.32 1050.6,1317.32 1050.61,1317.32 1050.62,1317.32 1050.63,1317.32 1050.64,1317.32 1050.65,1317.32 1050.66,1317.32 1050.67,1317.32 1050.68,1317.32 1050.69,1317.32 1050.69,1317.32 1050.7,1317.32 1050.71,1317.32 1050.72,1317.32 1050.73,1317.32 1050.74,1317.32 1050.75,1317.33 1050.76,1317.33 1050.77,1317.33 1050.78,1317.33 1050.79,1317.33 1050.8,1317.33 1050.8,1317.33 1050.81,1317.33 1050.82,1317.33 1050.83,1317.33 1050.84,1317.33 1050.85,1317.33 1050.86,1317.33 1050.87,1317.33 1050.88,1317.33 1050.89,1317.33 1050.9,1317.34 1050.91,1317.34 1050.92,1317.34 1050.92,1317.34 1050.93,1317.34 1050.94,1317.34 1050.95,1317.34 1050.96,1317.34 1050.97,1317.34 1050.98,1317.34 1050.99,1317.34 1051,1317.34 1051.01,1317.34 1051.02,1317.34 1051.03,1317.34 1051.03,1317.34 1051.04,1317.35 1051.05,1317.35 1051.06,1317.35 1051.07,1317.35 1051.08,1317.35 1051.09,1317.35 1051.1,1317.35 1051.11,1317.35 1051.12,1317.35 1051.13,1317.35 1051.14,1317.35 1051.14,1317.35 1051.15,1317.35 1051.16,1317.35 1051.17,1317.35 1051.18,1317.35 1051.19,1317.35 1051.2,1317.36 1051.21,1317.36 1051.22,1317.36 1051.23,1317.36 1051.24,1317.36 1051.25,1317.36 1051.26,1317.36 1051.26,1317.36 1051.27,1317.36 1051.28,1317.36 1051.29,1317.36 1051.3,1317.36 1051.31,1317.36 1051.32,1317.36 1051.33,1317.36 1051.34,1317.36 1051.35,1317.37 1051.36,1317.37 1051.37,1317.37 1051.37,1317.37 1051.38,1317.37 1051.39,1317.37 1051.4,1317.37 1051.41,1317.37 1051.42,1317.37 1051.43,1317.37 1051.44,1317.37 1051.45,1317.37 1051.46,1317.37 1051.47,1317.37 1051.48,1317.37 1051.48,1317.37 1051.49,1317.37 1051.5,1317.38 1051.51,1317.38 1051.52,1317.38 1051.53,1317.38 1051.54,1317.38 1051.55,1317.38 1051.56,1317.38 1051.57,1317.38 1051.58,1317.38 1051.59,1317.38 1051.6,1317.38 1051.6,1317.38 1051.61,1317.38 1051.62,1317.38 1051.63,1317.38 1051.64,1317.38 1051.65,1317.39 1051.66,1317.39 1051.67,1317.39 1051.68,1317.39 1051.69,1317.39 1051.7,1317.39 1051.71,1317.39 1051.71,1317.39 1051.72,1317.39 1051.73,1317.39 1051.74,1317.39 1051.75,1317.39 1051.76,1317.39 1051.77,1317.39 1051.78,1317.39 1051.79,1317.39 1051.8,1317.4 1051.81,1317.4 1051.82,1317.4 1051.82,1317.4 1051.83,1317.4 1051.84,1317.4 1051.85,1317.4 1051.86,1317.4 1051.87,1317.4 1051.88,1317.4 1051.89,1317.4 1051.9,1317.4 1051.91,1317.4 1051.92,1317.4 1051.93,1317.4 1051.94,1317.4 1051.94,1317.4 1051.95,1317.41 1051.96,1317.41 1051.97,1317.41 1051.98,1317.41 1051.99,1317.41 1052,1317.41 1052.01,1317.41 1052.02,1317.41 1052.03,1317.41 1052.04,1317.41 1052.05,1317.41 1052.05,1317.41 1052.06,1317.41 1052.07,1317.41 1052.08,1317.41 1052.09,1317.41 1052.1,1317.42 1052.11,1317.42 1052.12,1317.42 1052.13,1317.42 1052.14,1317.42 1052.15,1317.42 1052.16,1317.42 1052.16,1317.42 1052.17,1317.42 1052.18,1317.42 1052.19,1317.42 1052.2,1317.42 1052.21,1317.42 1052.22,1317.42 1052.23,1317.42 1052.24,1317.42 1052.25,1317.42 1052.26,1317.43 1052.27,1317.43 1052.28,1317.43 1052.28,1317.43 1052.29,1317.43 1052.3,1317.43 1052.31,1317.43 1052.32,1317.43 1052.33,1317.43 1052.34,1317.43 1052.35,1317.43 1052.36,1317.43 1052.37,1317.43 1052.38,1317.43 1052.39,1317.43 1052.39,1317.43 1052.4,1317.44 1052.41,1317.44 1052.42,1317.44 1052.43,1317.44 1052.44,1317.44 1052.45,1317.44 1052.46,1317.44 1052.47,1317.44 1052.48,1317.44 1052.49,1317.44 1052.5,1317.44 1052.5,1317.44 1052.51,1317.44 1052.52,1317.44 1052.53,1317.44 1052.54,1317.44 1052.55,1317.45 1052.56,1317.45 1052.57,1317.45 1052.58,1317.45 1052.59,1317.45 1052.6,1317.45 1052.61,1317.45 1052.62,1317.45 1052.62,1317.45 1052.63,1317.45 1052.64,1317.45 1052.65,1317.45 1052.66,1317.45 1052.67,1317.45 1052.68,1317.45 1052.69,1317.45 1052.7,1317.45 1052.71,1317.46 1052.72,1317.46 1052.73,1317.46 1052.73,1317.46 1052.74,1317.46 1052.75,1317.46 1052.76,1317.46 1052.77,1317.46 1052.78,1317.46 1052.79,1317.46 1052.8,1317.46 1052.81,1317.46 1052.82,1317.46 1052.83,1317.46 1052.84,1317.46 1052.84,1317.46 1052.85,1317.47 1052.86,1317.47 1052.87,1317.47 1052.88,1317.47 1052.89,1317.47 1052.9,1317.47 1052.91,1317.47 1052.92,1317.47 1052.93,1317.47 1052.94,1317.47 1052.95,1317.47 1052.96,1317.47 1052.96,1317.47 1052.97,1317.47 1052.98,1317.47 1052.99,1317.47 1053,1317.47 1053.01,1317.48 1053.02,1317.48 1053.03,1317.48 1053.04,1317.48 1053.05,1317.48 1053.06,1317.48 1053.07,1317.48 1053.07,1317.48 1053.08,1317.48 1053.09,1317.48 1053.1,1317.48 1053.11,1317.48 1053.12,1317.48 1053.13,1317.48 1053.14,1317.48 1053.15,1317.48 1053.16,1317.49 1053.17,1317.49 1053.18,1317.49 1053.18,1317.49 1053.19,1317.49 1053.2,1317.49 1053.21,1317.49 1053.22,1317.49 1053.23,1317.49 1053.24,1317.49 1053.25,1317.49 1053.26,1317.49 1053.27,1317.49 1053.28,1317.49 1053.29,1317.49 1053.3,1317.49 1053.3,1317.5 1053.31,1317.5 1053.32,1317.5 1053.33,1317.5 1053.34,1317.5 1053.35,1317.5 1053.36,1317.5 1053.37,1317.5 1053.38,1317.5 1053.39,1317.5 1053.4,1317.5 1053.41,1317.5 1053.41,1317.5 1053.42,1317.5 1053.43,1317.5 1053.44,1317.5 1053.45,1317.5 1053.46,1317.51 1053.47,1317.51 1053.48,1317.51 1053.49,1317.51 1053.5,1317.51 1053.51,1317.51 1053.52,1317.51 1053.52,1317.51 1053.53,1317.51 1053.54,1317.51 1053.55,1317.51 1053.56,1317.51 1053.57,1317.51 1053.58,1317.51 1053.59,1317.51 1053.6,1317.51 1053.61,1317.52 1053.62,1317.52 1053.63,1317.52 1053.64,1317.52 1053.64,1317.52 1053.65,1317.52 1053.66,1317.52 1053.67,1317.52 1053.68,1317.52 1053.69,1317.52 1053.7,1317.52 1053.71,1317.52 1053.72,1317.52 1053.73,1317.52 1053.74,1317.52 1053.75,1317.52 1053.75,1317.52 1053.76,1317.53 1053.77,1317.53 1053.78,1317.53 1053.79,1317.53 1053.8,1317.53 1053.81,1317.53 1053.82,1317.53 1053.83,1317.53 1053.84,1317.53 1053.85,1317.53 1053.86,1317.53 1053.86,1317.53 1053.87,1317.53 1053.88,1317.53 1053.89,1317.53 1053.9,1317.53 1053.91,1317.54 1053.92,1317.54 1053.93,1317.54 1053.94,1317.54 1053.95,1317.54 1053.96,1317.54 1053.97,1317.54 1053.98,1317.54 1053.98,1317.54 1053.99,1317.54 1054,1317.54 1054.01,1317.54 1054.02,1317.54 1054.03,1317.54 1054.04,1317.54 1054.05,1317.54 1054.06,1317.54 1054.07,1317.55 1054.08,1317.55 1054.09,1317.55 1054.09,1317.55 1054.1,1317.55 1054.11,1317.55 1054.12,1317.55 1054.13,1317.55 1054.14,1317.55 1054.15,1317.55 1054.16,1317.55 1054.17,1317.55 1054.18,1317.55 1054.19,1317.55 1054.2,1317.55 1054.2,1317.55 1054.21,1317.56 1054.22,1317.56 1054.23,1317.56 1054.24,1317.56 1054.25,1317.56 1054.26,1317.56 1054.27,1317.56 1054.28,1317.56 1054.29,1317.56 1054.3,1317.56 1054.31,1317.56 1054.32,1317.56 1054.32,1317.56 1054.33,1317.56 1054.34,1317.56 1054.35,1317.56 1054.36,1317.57 1054.37,1317.57 1054.38,1317.57 1054.39,1317.57 1054.4,1317.57 1054.41,1317.57 1054.42,1317.57 1054.43,1317.57 1054.43,1317.57 1054.44,1317.57 1054.45,1317.57 1054.46,1317.57 1054.47,1317.57 1054.48,1317.57 1054.49,1317.57 1054.5,1317.57 1054.51,1317.57 1054.52,1317.58 1054.53,1317.58 1054.54,1317.58 1054.54,1317.58 1054.55,1317.58 1054.56,1317.58 1054.57,1317.58 1054.58,1317.58 1054.59,1317.58 1054.6,1317.58 1054.61,1317.58 1054.62,1317.58 1054.63,1317.58 1054.64,1317.58 1054.65,1317.58 1054.66,1317.58 1054.66,1317.59 1054.67,1317.59 1054.68,1317.59 1054.69,1317.59 1054.7,1317.59 1054.71,1317.59 1054.72,1317.59 1054.73,1317.59 1054.74,1317.59 1054.75,1317.59 1054.76,1317.59 1054.77,1317.59 1054.77,1317.59 1054.78,1317.59 1054.79,1317.59 1054.8,1317.59 1054.81,1317.59 1054.82,1317.6 1054.83,1317.6 1054.84,1317.6 1054.85,1317.6 1054.86,1317.6 1054.87,1317.6 1054.88,1317.6 1054.88,1317.6 1054.89,1317.6 1054.9,1317.6 1054.91,1317.6 1054.92,1317.6 1054.93,1317.6 1054.94,1317.6 1054.95,1317.6 1054.96,1317.6 1054.97,1317.61 1054.98,1317.61 1054.99,1317.61 1055,1317.61 1055,1317.61 1055.01,1317.61 1055.02,1317.61 1055.03,1317.61 1055.04,1317.61 1055.05,1317.61 1055.06,1317.61 1055.07,1317.61 1055.08,1317.61 1055.09,1317.61 1055.1,1317.61 1055.11,1317.61 1055.11,1317.61 1055.12,1317.62 1055.13,1317.62 1055.14,1317.62 1055.15,1317.62 1055.16,1317.62 1055.17,1317.62 1055.18,1317.62 1055.19,1317.62 1055.2,1317.62 1055.21,1317.62 1055.22,1317.62 1055.22,1317.62 1055.23,1317.62 1055.24,1317.62 1055.25,1317.62 1055.26,1317.62 1055.27,1317.63 1055.28,1317.63 1055.29,1317.63 1055.3,1317.63 1055.31,1317.63 1055.32,1317.63 1055.33,1317.63 1055.34,1317.63 1055.34,1317.63 1055.35,1317.63 1055.36,1317.63 1055.37,1317.63 1055.38,1317.63 1055.39,1317.63 1055.4,1317.63 1055.41,1317.63 1055.42,1317.64 1055.43,1317.64 1055.44,1317.64 1055.45,1317.64 1055.45,1317.64 1055.46,1317.64 1055.47,1317.64 1055.48,1317.64 1055.49,1317.64 1055.5,1317.64 1055.51,1317.64 1055.52,1317.64 1055.53,1317.64 1055.54,1317.64 1055.55,1317.64 1055.56,1317.64 1055.56,1317.64 1055.57,1317.65 1055.58,1317.65 1055.59,1317.65 1055.6,1317.65 1055.61,1317.65 1055.62,1317.65 1055.63,1317.65 1055.64,1317.65 1055.65,1317.65 1055.66,1317.65 1055.67,1317.65 1055.68,1317.65 1055.68,1317.65 1055.69,1317.65 1055.7,1317.65 1055.71,1317.65 1055.72,1317.66 1055.73,1317.66 1055.74,1317.66 1055.75,1317.66 1055.76,1317.66 1055.77,1317.66 1055.78,1317.66 1055.79,1317.66 1055.79,1317.66 1055.8,1317.66 1055.81,1317.66 1055.82,1317.66 1055.83,1317.66 1055.84,1317.66 1055.85,1317.66 1055.86,1317.66 1055.87,1317.66 1055.88,1317.67 1055.89,1317.67 1055.9,1317.67 1055.9,1317.67 1055.91,1317.67 1055.92,1317.67 1055.93,1317.67 1055.94,1317.67 1055.95,1317.67 1055.96,1317.67 1055.97,1317.67 1055.98,1317.67 1055.99,1317.67 1056,1317.67 1056.01,1317.67 1056.02,1317.67 1056.02,1317.68 1056.03,1317.68 1056.04,1317.68 1056.05,1317.68 1056.06,1317.68 1056.07,1317.68 1056.08,1317.68 1056.09,1317.68 1056.1,1317.68 1056.11,1317.68 1056.12,1317.68 1056.13,1317.68 1056.13,1317.68 1056.14,1317.68 1056.15,1317.68 1056.16,1317.68 1056.17,1317.68 1056.18,1317.69 1056.19,1317.69 1056.2,1317.69 1056.21,1317.69 1056.22,1317.69 1056.23,1317.69 1056.24,1317.69 1056.24,1317.69 1056.25,1317.69 1056.26,1317.69 1056.27,1317.69 1056.28,1317.69 1056.29,1317.69 1056.3,1317.69 1056.31,1317.69 1056.32,1317.69 1056.33,1317.7 1056.34,1317.7 1056.35,1317.7 1056.36,1317.7 1056.36,1317.7 1056.37,1317.7 1056.38,1317.7 1056.39,1317.7 1056.4,1317.7 1056.41,1317.7 1056.42,1317.7 1056.43,1317.7 1056.44,1317.7 1056.45,1317.7 1056.46,1317.7 1056.47,1317.7 1056.47,1317.71 1056.48,1317.71 1056.49,1317.71 1056.5,1317.71 1056.51,1317.71 1056.52,1317.71 1056.53,1317.71 1056.54,1317.71 1056.55,1317.71 1056.56,1317.71 1056.57,1317.71 1056.58,1317.71 1056.58,1317.71 1056.59,1317.71 1056.6,1317.71 1056.61,1317.71 1056.62,1317.71 1056.63,1317.72 1056.64,1317.72 1056.65,1317.72 1056.66,1317.72 1056.67,1317.72 1056.68,1317.72 1056.69,1317.72 1056.7,1317.72 1056.7,1317.72 1056.71,1317.72 1056.72,1317.72 1056.73,1317.72 1056.74,1317.72 1056.75,1317.72 1056.76,1317.72 1056.77,1317.72 1056.78,1317.73 1056.79,1317.73 1056.8,1317.73 1056.81,1317.73 1056.81,1317.73 1056.82,1317.73 1056.83,1317.73 1056.84,1317.73 1056.85,1317.73 1056.86,1317.73 1056.87,1317.73 1056.88,1317.73 1056.89,1317.73 1056.9,1317.73 1056.91,1317.73 1056.92,1317.73 1056.92,1317.73 1056.93,1317.74 1056.94,1317.74 1056.95,1317.74 1056.96,1317.74 1056.97,1317.74 1056.98,1317.74 1056.99,1317.74 1057,1317.74 1057.01,1317.74 1057.02,1317.74 1057.03,1317.74 1057.04,1317.74 1057.04,1317.74 1057.05,1317.74 1057.06,1317.74 1057.07,1317.74 1057.08,1317.75 1057.09,1317.75 1057.1,1317.75 1057.11,1317.75 1057.12,1317.75 1057.13,1317.75 1057.14,1317.75 1057.15,1317.75 1057.15,1317.75 1057.16,1317.75 1057.17,1317.75 1057.18,1317.75 1057.19,1317.75 1057.2,1317.75 1057.21,1317.75 1057.22,1317.75 1057.23,1317.75 1057.24,1317.76 1057.25,1317.76 1057.26,1317.76 1057.26,1317.76 1057.27,1317.76 1057.28,1317.76 1057.29,1317.76 1057.3,1317.76 1057.31,1317.76 1057.32,1317.76 1057.33,1317.76 1057.34,1317.76 1057.35,1317.76 1057.36,1317.76 1057.37,1317.76 1057.38,1317.76 1057.38,1317.77 1057.39,1317.77 1057.4,1317.77 1057.41,1317.77 1057.42,1317.77 1057.43,1317.77 1057.44,1317.77 1057.45,1317.77 1057.46,1317.77 1057.47,1317.77 1057.48,1317.77 1057.49,1317.77 1057.49,1317.77 1057.5,1317.77 1057.51,1317.77 1057.52,1317.77 1057.53,1317.77 1057.54,1317.78 1057.55,1317.78 1057.56,1317.78 1057.57,1317.78 1057.58,1317.78 1057.59,1317.78 1057.6,1317.78 1057.6,1317.78 1057.61,1317.78 1057.62,1317.78 1057.63,1317.78 1057.64,1317.78 1057.65,1317.78 1057.66,1317.78 1057.67,1317.78 1057.68,1317.78 1057.69,1317.79 1057.7,1317.79 1057.71,1317.79 1057.72,1317.79 1057.72,1317.79 1057.73,1317.79 1057.74,1317.79 1057.75,1317.79 1057.76,1317.79 1057.77,1317.79 1057.78,1317.79 1057.79,1317.79 1057.8,1317.79 1057.81,1317.79 1057.82,1317.79 1057.83,1317.79 1057.83,1317.8 1057.84,1317.8 1057.85,1317.8 1057.86,1317.8 1057.87,1317.8 1057.88,1317.8 1057.89,1317.8 1057.9,1317.8 1057.91,1317.8 1057.92,1317.8 1057.93,1317.8 1057.94,1317.8 1057.94,1317.8 1057.95,1317.8 1057.96,1317.8 1057.97,1317.8 1057.98,1317.8 1057.99,1317.81 1058,1317.81 1058.01,1317.81 1058.02,1317.81 1058.03,1317.81 1058.04,1317.81 1058.05,1317.81 1058.06,1317.81 1058.06,1317.81 1058.07,1317.81 1058.08,1317.81 1058.09,1317.81 1058.1,1317.81 1058.11,1317.81 1058.12,1317.81 1058.13,1317.81 1058.14,1317.82 1058.15,1317.82 1058.16,1317.82 1058.17,1317.82 1058.17,1317.82 1058.18,1317.82 1058.19,1317.82 1058.2,1317.82 1058.21,1317.82 1058.22,1317.82 1058.23,1317.82 1058.24,1317.82 1058.25,1317.82 1058.26,1317.82 1058.27,1317.82 1058.28,1317.82 1058.28,1317.82 1058.29,1317.83 1058.3,1317.83 1058.31,1317.83 1058.32,1317.83 1058.33,1317.83 1058.34,1317.83 1058.35,1317.83 1058.36,1317.83 1058.37,1317.83 1058.38,1317.83 1058.39,1317.83 1058.4,1317.83 1058.4,1317.83 1058.41,1317.83 1058.42,1317.83 1058.43,1317.83 1058.44,1317.84 1058.45,1317.84 1058.46,1317.84 1058.47,1317.84 1058.48,1317.84 1058.49,1317.84 1058.5,1317.84 1058.51,1317.84 1058.51,1317.84 1058.52,1317.84 1058.53,1317.84 1058.54,1317.84 1058.55,1317.84 1058.56,1317.84 1058.57,1317.84 1058.58,1317.84 1058.59,1317.84 1058.6,1317.85 1058.61,1317.85 1058.62,1317.85 1058.62,1317.85 1058.63,1317.85 1058.64,1317.85 1058.65,1317.85 1058.66,1317.85 1058.67,1317.85 1058.68,1317.85 1058.69,1317.85 1058.7,1317.85 1058.71,1317.85 1058.72,1317.85 1058.73,1317.85 1058.74,1317.85 1058.74,1317.86 1058.75,1317.86 1058.76,1317.86 1058.77,1317.86 1058.78,1317.86 1058.79,1317.86 1058.8,1317.86 1058.81,1317.86 1058.82,1317.86 1058.83,1317.86 1058.84,1317.86 1058.85,1317.86 1058.85,1317.86 1058.86,1317.86 1058.87,1317.86 1058.88,1317.86 1058.89,1317.86 1058.9,1317.87 1058.91,1317.87 1058.92,1317.87 1058.93,1317.87 1058.94,1317.87 1058.95,1317.87 1058.96,1317.87 1058.96,1317.87 1058.97,1317.87 1058.98,1317.87 1058.99,1317.87 1059,1317.87 1059.01,1317.87 1059.02,1317.87 1059.03,1317.87 1059.04,1317.87 1059.05,1317.88 1059.06,1317.88 1059.07,1317.88 1059.08,1317.88 1059.08,1317.88 1059.09,1317.88 1059.1,1317.88 1059.11,1317.88 1059.12,1317.88 1059.13,1317.88 1059.14,1317.88 1059.15,1317.88 1059.16,1317.88 1059.17,1317.88 1059.18,1317.88 1059.19,1317.88 1059.19,1317.88 1059.2,1317.89 1059.21,1317.89 1059.22,1317.89 1059.23,1317.89 1059.24,1317.89 1059.25,1317.89 1059.26,1317.89 1059.27,1317.89 1059.28,1317.89 1059.29,1317.89 1059.3,1317.89 1059.3,1317.89 1059.31,1317.89 1059.32,1317.89 1059.33,1317.89 1059.34,1317.89 1059.35,1317.9 1059.36,1317.9 1059.37,1317.9 1059.38,1317.9 1059.39,1317.9 1059.4,1317.9 1059.41,1317.9 1059.42,1317.9 1059.42,1317.9 1059.43,1317.9 1059.44,1317.9 1059.45,1317.9 1059.46,1317.9 1059.47,1317.9 1059.48,1317.9 1059.49,1317.9 1059.5,1317.9 1059.51,1317.91 1059.52,1317.91 1059.53,1317.91 1059.53,1317.91 1059.54,1317.91 1059.55,1317.91 1059.56,1317.91 1059.57,1317.91 1059.58,1317.91 1059.59,1317.91 1059.6,1317.91 1059.61,1317.91 1059.62,1317.91 1059.63,1317.91 1059.64,1317.91 1059.64,1317.91 1059.65,1317.92 1059.66,1317.92 1059.67,1317.92 1059.68,1317.92 1059.69,1317.92 1059.7,1317.92 1059.71,1317.92 1059.72,1317.92 1059.73,1317.92 1059.74,1317.92 1059.75,1317.92 1059.76,1317.92 1059.76,1317.92 1059.77,1317.92 1059.78,1317.92 1059.79,1317.92 1059.8,1317.93 1059.81,1317.93 1059.82,1317.93 1059.83,1317.93 1059.84,1317.93 1059.85,1317.93 1059.86,1317.93 1059.87,1317.93 1059.87,1317.93 1059.88,1317.93 1059.89,1317.93 1059.9,1317.93 1059.91,1317.93 1059.92,1317.93 1059.93,1317.93 1059.94,1317.93 1059.95,1317.93 1059.96,1317.94 1059.97,1317.94 1059.98,1317.94 1059.98,1317.94 1059.99,1317.94 1060,1317.94 1060.01,1317.94 1060.02,1317.94 1060.03,1317.94 1060.04,1317.94 1060.05,1317.94 1060.06,1317.94 1060.07,1317.94 1060.08,1317.94 1060.09,1317.94 1060.1,1317.94 1060.1,1317.95 1060.11,1317.95 1060.12,1317.95 1060.13,1317.95 1060.14,1317.95 1060.15,1317.95 1060.16,1317.95 1060.17,1317.95 1060.18,1317.95 1060.19,1317.95 1060.2,1317.95 1060.21,1317.95 1060.21,1317.95 1060.22,1317.95 1060.23,1317.95 1060.24,1317.95 1060.25,1317.95 1060.26,1317.96 1060.27,1317.96 1060.28,1317.96 1060.29,1317.96 1060.3,1317.96 1060.31,1317.96 1060.32,1317.96 1060.32,1317.96 1060.33,1317.96 1060.34,1317.96 1060.35,1317.96 1060.36,1317.96 1060.37,1317.96 1060.38,1317.96 1060.39,1317.96 1060.4,1317.96 1060.41,1317.97 1060.42,1317.97 1060.43,1317.97 1060.44,1317.97 1060.44,1317.97 1060.45,1317.97 1060.46,1317.97 1060.47,1317.97 1060.48,1317.97 1060.49,1317.97 1060.5,1317.97 1060.51,1317.97 1060.52,1317.97 1060.53,1317.97 1060.54,1317.97 1060.55,1317.97 1060.55,1317.97 1060.56,1317.98 1060.57,1317.98 1060.58,1317.98 1060.59,1317.98 1060.6,1317.98 1060.61,1317.98 1060.62,1317.98 1060.63,1317.98 1060.64,1317.98 1060.65,1317.98 1060.66,1317.98 1060.66,1317.98 1060.67,1317.98 1060.68,1317.98 1060.69,1317.98 1060.7,1317.98 1060.71,1317.99 1060.72,1317.99 1060.73,1317.99 1060.74,1317.99 1060.75,1317.99 1060.76,1317.99 1060.77,1317.99 1060.78,1317.99 1060.78,1317.99 1060.79,1317.99 1060.8,1317.99 1060.81,1317.99 1060.82,1317.99 1060.83,1317.99 1060.84,1317.99 1060.85,1317.99 1060.86,1317.99 1060.87,1318 1060.88,1318 1060.89,1318 1060.89,1318 1060.9,1318 1060.91,1318 1060.92,1318 1060.93,1318 1060.94,1318 1060.95,1318 1060.96,1318 1060.97,1318 1060.98,1318 1060.99,1318 1061,1318 1061,1318 1061.01,1318.01 1061.02,1318.01 1061.03,1318.01 1061.04,1318.01 1061.05,1318.01 1061.06,1318.01 1061.07,1318.01 1061.08,1318.01 1061.09,1318.01 1061.1,1318.01 1061.11,1318.01 1061.12,1318.01 1061.12,1318.01 1061.13,1318.01 1061.14,1318.01 1061.15,1318.01 1061.16,1318.01 1061.17,1318.02 1061.18,1318.02 1061.19,1318.02 1061.2,1318.02 1061.21,1318.02 1061.22,1318.02 1061.23,1318.02 1061.23,1318.02 1061.24,1318.02 1061.25,1318.02 1061.26,1318.02 1061.27,1318.02 1061.28,1318.02 1061.29,1318.02 1061.3,1318.02 1061.31,1318.02 1061.32,1318.03 1061.33,1318.03 1061.34,1318.03 1061.34,1318.03 1061.35,1318.03 1061.36,1318.03 1061.37,1318.03 1061.38,1318.03 1061.39,1318.03 1061.4,1318.03 1061.41,1318.03 1061.42,1318.03 1061.43,1318.03 1061.44,1318.03 1061.45,1318.03 1061.46,1318.03 1061.46,1318.03 1061.47,1318.04 1061.48,1318.04 1061.49,1318.04 1061.5,1318.04 1061.51,1318.04 1061.52,1318.04 1061.53,1318.04 1061.54,1318.04 1061.55,1318.04 1061.56,1318.04 1061.57,1318.04 1061.57,1318.04 1061.58,1318.04 1061.59,1318.04 1061.6,1318.04 1061.61,1318.04 1061.62,1318.05 1061.63,1318.05 1061.64,1318.05 1061.65,1318.05 1061.66,1318.05 1061.67,1318.05 1061.68,1318.05 1061.68,1318.05 1061.69,1318.05 1061.7,1318.05 1061.71,1318.05 1061.72,1318.05 1061.73,1318.05 1061.74,1318.05 1061.75,1318.05 1061.76,1318.05 1061.77,1318.05 1061.78,1318.06 1061.79,1318.06 1061.8,1318.06 1061.8,1318.06 1061.81,1318.06 1061.82,1318.06 1061.83,1318.06 1061.84,1318.06 1061.85,1318.06 1061.86,1318.06 1061.87,1318.06 1061.88,1318.06 1061.89,1318.06 1061.9,1318.06 1061.91,1318.06 1061.91,1318.06 1061.92,1318.07 1061.93,1318.07 1061.94,1318.07 1061.95,1318.07 1061.96,1318.07 1061.97,1318.07 1061.98,1318.07 1061.99,1318.07 1062,1318.07 1062.01,1318.07 1062.02,1318.07 1062.02,1318.07 1062.03,1318.07 1062.04,1318.07 1062.05,1318.07 1062.06,1318.07 1062.07,1318.07 1062.08,1318.08 1062.09,1318.08 1062.1,1318.08 1062.11,1318.08 1062.12,1318.08 1062.13,1318.08 1062.14,1318.08 1062.14,1318.08 1062.15,1318.08 1062.16,1318.08 1062.17,1318.08 1062.18,1318.08 1062.19,1318.08 1062.2,1318.08 1062.21,1318.08 1062.22,1318.08 1062.23,1318.09 1062.24,1318.09 1062.25,1318.09 1062.25,1318.09 1062.26,1318.09 1062.27,1318.09 1062.28,1318.09 1062.29,1318.09 1062.3,1318.09 1062.31,1318.09 1062.32,1318.09 1062.33,1318.09 1062.34,1318.09 1062.35,1318.09 1062.36,1318.09 1062.36,1318.09 1062.37,1318.09 1062.38,1318.1 1062.39,1318.1 1062.4,1318.1 1062.41,1318.1 1062.42,1318.1 1062.43,1318.1 1062.44,1318.1 1062.45,1318.1 1062.46,1318.1 1062.47,1318.1 1062.48,1318.1 1062.48,1318.1 1062.49,1318.1 1062.5,1318.1 1062.51,1318.1 1062.52,1318.1 1062.53,1318.11 1062.54,1318.11 1062.55,1318.11 1062.56,1318.11 1062.57,1318.11 1062.58,1318.11 1062.59,1318.11 1062.59,1318.11 1062.6,1318.11 1062.61,1318.11 1062.62,1318.11 1062.63,1318.11 1062.64,1318.11 1062.65,1318.11 1062.66,1318.11 1062.67,1318.11 1062.68,1318.11 1062.69,1318.12 1062.7,1318.12 1062.7,1318.12 1062.71,1318.12 1062.72,1318.12 1062.73,1318.12 1062.74,1318.12 1062.75,1318.12 1062.76,1318.12 1062.77,1318.12 1062.78,1318.12 1062.79,1318.12 1062.8,1318.12 1062.81,1318.12 1062.82,1318.12 1062.82,1318.12 1062.83,1318.13 1062.84,1318.13 1062.85,1318.13 1062.86,1318.13 1062.87,1318.13 1062.88,1318.13 1062.89,1318.13 1062.9,1318.13 1062.91,1318.13 1062.92,1318.13 1062.93,1318.13 1062.93,1318.13 1062.94,1318.13 1062.95,1318.13 1062.96,1318.13 1062.97,1318.13 1062.98,1318.13 1062.99,1318.14 1063,1318.14 1063.01,1318.14 1063.02,1318.14 1063.03,1318.14 1063.04,1318.14 1063.04,1318.14 1063.05,1318.14 1063.06,1318.14 1063.07,1318.14 1063.08,1318.14 1063.09,1318.14 1063.1,1318.14 1063.11,1318.14 1063.12,1318.14 1063.13,1318.14 1063.14,1318.15 1063.15,1318.15 1063.16,1318.15 1063.16,1318.15 1063.17,1318.15 1063.18,1318.15 1063.19,1318.15 1063.2,1318.15 1063.21,1318.15 1063.22,1318.15 1063.23,1318.15 1063.24,1318.15 1063.25,1318.15 1063.26,1318.15 1063.27,1318.15 1063.27,1318.15 1063.28,1318.15 1063.29,1318.16 1063.3,1318.16 1063.31,1318.16 1063.32,1318.16 1063.33,1318.16 1063.34,1318.16 1063.35,1318.16 1063.36,1318.16 1063.37,1318.16 1063.38,1318.16 1063.38,1318.16 1063.39,1318.16 1063.4,1318.16 1063.41,1318.16 1063.42,1318.16 1063.43,1318.16 1063.44,1318.17 1063.45,1318.17 1063.46,1318.17 1063.47,1318.17 1063.48,1318.17 1063.49,1318.17 1063.5,1318.17 1063.5,1318.17 1063.51,1318.17 1063.52,1318.17 1063.53,1318.17 1063.54,1318.17 1063.55,1318.17 1063.56,1318.17 1063.57,1318.17 1063.58,1318.17 1063.59,1318.17 1063.6,1318.18 1063.61,1318.18 1063.61,1318.18 1063.62,1318.18 1063.63,1318.18 1063.64,1318.18 1063.65,1318.18 1063.66,1318.18 1063.67,1318.18 1063.68,1318.18 1063.69,1318.18 1063.7,1318.18 1063.71,1318.18 1063.72,1318.18 1063.72,1318.18 1063.73,1318.18 1063.74,1318.19 1063.75,1318.19 1063.76,1318.19 1063.77,1318.19 1063.78,1318.19 1063.79,1318.19 1063.8,1318.19 1063.81,1318.19 1063.82,1318.19 1063.83,1318.19 1063.84,1318.19 1063.84,1318.19 1063.85,1318.19 1063.86,1318.19 1063.87,1318.19 1063.88,1318.19 1063.89,1318.19 1063.9,1318.2 1063.91,1318.2 1063.92,1318.2 1063.93,1318.2 1063.94,1318.2 1063.95,1318.2 1063.95,1318.2 1063.96,1318.2 1063.97,1318.2 1063.98,1318.2 1063.99,1318.2 1064,1318.2 1064.01,1318.2 1064.02,1318.2 1064.03,1318.2 1064.04,1318.2 1064.05,1318.21 1064.06,1318.21 1064.06,1318.21 1064.07,1318.21 1064.08,1318.21 1064.09,1318.21 1064.1,1318.21 1064.11,1318.21 1064.12,1318.21 1064.13,1318.21 1064.14,1318.21 1064.15,1318.21 1064.16,1318.21 1064.17,1318.21 1064.18,1318.21 1064.18,1318.21 1064.19,1318.21 1064.2,1318.22 1064.21,1318.22 1064.22,1318.22 1064.23,1318.22 1064.24,1318.22 1064.25,1318.22 1064.26,1318.22 1064.27,1318.22 1064.28,1318.22 1064.29,1318.22 1064.29,1318.22 1064.3,1318.22 1064.31,1318.22 1064.32,1318.22 1064.33,1318.22 1064.34,1318.22 1064.35,1318.23 1064.36,1318.23 1064.37,1318.23 1064.38,1318.23 1064.39,1318.23 1064.4,1318.23 1064.4,1318.23 1064.41,1318.23 1064.42,1318.23 1064.43,1318.23 1064.44,1318.23 1064.45,1318.23 1064.46,1318.23 1064.47,1318.23 1064.48,1318.23 1064.49,1318.23 1064.5,1318.23 1064.51,1318.24 1064.52,1318.24 1064.52,1318.24 1064.53,1318.24 1064.54,1318.24 1064.55,1318.24 1064.56,1318.24 1064.57,1318.24 1064.58,1318.24 1064.59,1318.24 1064.6,1318.24 1064.61,1318.24 1064.62,1318.24 1064.63,1318.24 1064.63,1318.24 1064.64,1318.24 1064.65,1318.25 1064.66,1318.25 1064.67,1318.25 1064.68,1318.25 1064.69,1318.25 1064.7,1318.25 1064.71,1318.25 1064.72,1318.25 1064.73,1318.25 1064.74,1318.25 1064.74,1318.25 1064.75,1318.25 1064.76,1318.25 1064.77,1318.25 1064.78,1318.25 1064.79,1318.25 1064.8,1318.25 1064.81,1318.26 1064.82,1318.26 1064.83,1318.26 1064.84,1318.26 1064.85,1318.26 1064.86,1318.26 1064.86,1318.26 1064.87,1318.26 1064.88,1318.26 1064.89,1318.26 1064.9,1318.26 1064.91,1318.26 1064.92,1318.26 1064.93,1318.26 1064.94,1318.26 1064.95,1318.26 1064.96,1318.27 1064.97,1318.27 1064.97,1318.27 1064.98,1318.27 1064.99,1318.27 1065,1318.27 1065.01,1318.27 1065.02,1318.27 1065.03,1318.27 1065.04,1318.27 1065.05,1318.27 1065.06,1318.27 1065.07,1318.27 1065.08,1318.27 1065.08,1318.27 1065.09,1318.27 1065.1,1318.27 1065.11,1318.28 1065.12,1318.28 1065.13,1318.28 1065.14,1318.28 1065.15,1318.28 1065.16,1318.28 1065.17,1318.28 1065.18,1318.28 1065.19,1318.28 1065.2,1318.28 1065.2,1318.28 1065.21,1318.28 1065.22,1318.28 1065.23,1318.28 1065.24,1318.28 1065.25,1318.28 1065.26,1318.29 1065.27,1318.29 1065.28,1318.29 1065.29,1318.29 1065.3,1318.29 1065.31,1318.29 1065.31,1318.29 1065.32,1318.29 1065.33,1318.29 1065.34,1318.29 1065.35,1318.29 1065.36,1318.29 1065.37,1318.29 1065.38,1318.29 1065.39,1318.29 1065.4,1318.29 1065.41,1318.29 1065.42,1318.3 1065.42,1318.3 1065.43,1318.3 1065.44,1318.3 1065.45,1318.3 1065.46,1318.3 1065.47,1318.3 1065.48,1318.3 1065.49,1318.3 1065.5,1318.3 1065.51,1318.3 1065.52,1318.3 1065.53,1318.3 1065.54,1318.3 1065.54,1318.3 1065.55,1318.3 1065.56,1318.31 1065.57,1318.31 1065.58,1318.31 1065.59,1318.31 1065.6,1318.31 1065.61,1318.31 1065.62,1318.31 1065.63,1318.31 1065.64,1318.31 1065.65,1318.31 1065.65,1318.31 1065.66,1318.31 1065.67,1318.31 1065.68,1318.31 1065.69,1318.31 1065.7,1318.31 1065.71,1318.31 1065.72,1318.32 1065.73,1318.32 1065.74,1318.32 1065.75,1318.32 1065.76,1318.32 1065.76,1318.32 1065.77,1318.32 1065.78,1318.32 1065.79,1318.32 1065.8,1318.32 1065.81,1318.32 1065.82,1318.32 1065.83,1318.32 1065.84,1318.32 1065.85,1318.32 1065.86,1318.32 1065.87,1318.33 1065.88,1318.33 1065.88,1318.33 1065.89,1318.33 1065.9,1318.33 1065.91,1318.33 1065.92,1318.33 1065.93,1318.33 1065.94,1318.33 1065.95,1318.33 1065.96,1318.33 1065.97,1318.33 1065.98,1318.33 1065.99,1318.33 1065.99,1318.33 1066,1318.33 1066.01,1318.33 1066.02,1318.34 1066.03,1318.34 1066.04,1318.34 1066.05,1318.34 1066.06,1318.34 1066.07,1318.34 1066.08,1318.34 1066.09,1318.34 1066.1,1318.34 1066.1,1318.34 1066.11,1318.34 1066.12,1318.34 1066.13,1318.34 1066.14,1318.34 1066.15,1318.34 1066.16,1318.34 1066.17,1318.35 1066.18,1318.35 1066.19,1318.35 1066.2,1318.35 1066.21,1318.35 1066.22,1318.35 1066.22,1318.35 1066.23,1318.35 1066.24,1318.35 1066.25,1318.35 1066.26,1318.35 1066.27,1318.35 1066.28,1318.35 1066.29,1318.35 1066.3,1318.35 1066.31,1318.35 1066.32,1318.35 1066.33,1318.36 1066.33,1318.36 1066.34,1318.36 1066.35,1318.36 1066.36,1318.36 1066.37,1318.36 1066.38,1318.36 1066.39,1318.36 1066.4,1318.36 1066.41,1318.36 1066.42,1318.36 1066.43,1318.36 1066.44,1318.36 1066.44,1318.36 1066.45,1318.36 1066.46,1318.36 1066.47,1318.37 1066.48,1318.37 1066.49,1318.37 1066.5,1318.37 1066.51,1318.37 1066.52,1318.37 1066.53,1318.37 1066.54,1318.37 1066.55,1318.37 1066.56,1318.37 1066.56,1318.37 1066.57,1318.37 1066.58,1318.37 1066.59,1318.37 1066.6,1318.37 1066.61,1318.37 1066.62,1318.37 1066.63,1318.38 1066.64,1318.38 1066.65,1318.38 1066.66,1318.38 1066.67,1318.38 1066.67,1318.38 1066.68,1318.38 1066.69,1318.38 1066.7,1318.38 1066.71,1318.38 1066.72,1318.38 1066.73,1318.38 1066.74,1318.38 1066.75,1318.38 1066.76,1318.38 1066.77,1318.38 1066.78,1318.39 1066.78,1318.39 1066.79,1318.39 1066.8,1318.39 1066.81,1318.39 1066.82,1318.39 1066.83,1318.39 1066.84,1318.39 1066.85,1318.39 1066.86,1318.39 1066.87,1318.39 1066.88,1318.39 1066.89,1318.39 1066.9,1318.39 1066.9,1318.39 1066.91,1318.39 1066.92,1318.39 1066.93,1318.4 1066.94,1318.4 1066.95,1318.4 1066.96,1318.4 1066.97,1318.4 1066.98,1318.4 1066.99,1318.4 1067,1318.4 1067.01,1318.4 1067.01,1318.4 1067.02,1318.4 1067.03,1318.4 1067.04,1318.4 1067.05,1318.4 1067.06,1318.4 1067.07,1318.4 1067.08,1318.41 1067.09,1318.41 1067.1,1318.41 1067.11,1318.41 1067.12,1318.41 1067.12,1318.41 1067.13,1318.41 1067.14,1318.41 1067.15,1318.41 1067.16,1318.41 1067.17,1318.41 1067.18,1318.41 1067.19,1318.41 1067.2,1318.41 1067.21,1318.41 1067.22,1318.41 1067.23,1318.41 1067.24,1318.42 1067.24,1318.42 1067.25,1318.42 1067.26,1318.42 1067.27,1318.42 1067.28,1318.42 1067.29,1318.42 1067.3,1318.42 1067.31,1318.42 1067.32,1318.42 1067.33,1318.42 1067.34,1318.42 1067.35,1318.42 1067.35,1318.42 1067.36,1318.42 1067.37,1318.42 1067.38,1318.43 1067.39,1318.43 1067.4,1318.43 1067.41,1318.43 1067.42,1318.43 1067.43,1318.43 1067.44,1318.43 1067.45,1318.43 1067.46,1318.43 1067.46,1318.43 1067.47,1318.43 1067.48,1318.43 1067.49,1318.43 1067.5,1318.43 1067.51,1318.43 1067.52,1318.43 1067.53,1318.43 1067.54,1318.44 1067.55,1318.44 1067.56,1318.44 1067.57,1318.44 1067.58,1318.44 1067.58,1318.44 1067.59,1318.44 1067.6,1318.44 1067.61,1318.44 1067.62,1318.44 1067.63,1318.44 1067.64,1318.44 1067.65,1318.44 1067.66,1318.44 1067.67,1318.44 1067.68,1318.44 1067.69,1318.45 1067.69,1318.45 1067.7,1318.45 1067.71,1318.45 1067.72,1318.45 1067.73,1318.45 1067.74,1318.45 1067.75,1318.45 1067.76,1318.45 1067.77,1318.45 1067.78,1318.45 1067.79,1318.45 1067.8,1318.45 1067.8,1318.45 1067.81,1318.45 1067.82,1318.45 1067.83,1318.45 1067.84,1318.46 1067.85,1318.46 1067.86,1318.46 1067.87,1318.46 1067.88,1318.46 1067.89,1318.46 1067.9,1318.46 1067.91,1318.46 1067.92,1318.46 1067.92,1318.46 1067.93,1318.46 1067.94,1318.46 1067.95,1318.46 1067.96,1318.46 1067.97,1318.46 1067.98,1318.46 1067.99,1318.47 1068,1318.47 1068.01,1318.47 1068.02,1318.47 1068.03,1318.47 1068.03,1318.47 1068.04,1318.47 1068.05,1318.47 1068.06,1318.47 1068.07,1318.47 1068.08,1318.47 1068.09,1318.47 1068.1,1318.47 1068.11,1318.47 1068.12,1318.47 1068.13,1318.47 1068.14,1318.47 1068.14,1318.48 1068.15,1318.48 1068.16,1318.48 1068.17,1318.48 1068.18,1318.48 1068.19,1318.48 1068.2,1318.48 1068.21,1318.48 1068.22,1318.48 1068.23,1318.48 1068.24,1318.48 1068.25,1318.48 1068.26,1318.48 1068.26,1318.48 1068.27,1318.48 1068.28,1318.48 1068.29,1318.48 1068.3,1318.49 1068.31,1318.49 1068.32,1318.49 1068.33,1318.49 1068.34,1318.49 1068.35,1318.49 1068.36,1318.49 1068.37,1318.49 1068.37,1318.49 1068.38,1318.49 1068.39,1318.49 1068.4,1318.49 1068.41,1318.49 1068.42,1318.49 1068.43,1318.49 1068.44,1318.49 1068.45,1318.5 1068.46,1318.5 1068.47,1318.5 1068.48,1318.5 1068.48,1318.5 1068.49,1318.5 1068.5,1318.5 1068.51,1318.5 1068.52,1318.5 1068.53,1318.5 1068.54,1318.5 1068.55,1318.5 1068.56,1318.5 1068.57,1318.5 1068.58,1318.5 1068.59,1318.5 1068.6,1318.5 1068.6,1318.51 1068.61,1318.51 1068.62,1318.51 1068.63,1318.51 1068.64,1318.51 1068.65,1318.51 1068.66,1318.51 1068.67,1318.51 1068.68,1318.51 1068.69,1318.51 1068.7,1318.51 1068.71,1318.51 1068.71,1318.51 1068.72,1318.51 1068.73,1318.51 1068.74,1318.51 1068.75,1318.52 1068.76,1318.52 1068.77,1318.52 1068.78,1318.52 1068.79,1318.52 1068.8,1318.52 1068.81,1318.52 1068.82,1318.52 1068.82,1318.52 1068.83,1318.52 1068.84,1318.52 1068.85,1318.52 1068.86,1318.52 1068.87,1318.52 1068.88,1318.52 1068.89,1318.52 1068.9,1318.52 1068.91,1318.53 1068.92,1318.53 1068.93,1318.53 1068.94,1318.53 1068.94,1318.53 1068.95,1318.53 1068.96,1318.53 1068.97,1318.53 1068.98,1318.53 1068.99,1318.53 1069,1318.53 1069.01,1318.53 1069.02,1318.53 1069.03,1318.53 1069.04,1318.53 1069.05,1318.53 1069.05,1318.54 1069.06,1318.54 1069.07,1318.54 1069.08,1318.54 1069.09,1318.54 1069.1,1318.54 1069.11,1318.54 1069.12,1318.54 1069.13,1318.54 1069.14,1318.54 1069.15,1318.54 1069.16,1318.54 1069.16,1318.54 1069.17,1318.54 1069.18,1318.54 1069.19,1318.54 1069.2,1318.54 1069.21,1318.55 1069.22,1318.55 1069.23,1318.55 1069.24,1318.55 1069.25,1318.55 1069.26,1318.55 1069.27,1318.55 1069.28,1318.55 1069.28,1318.55 1069.29,1318.55 1069.3,1318.55 1069.31,1318.55 1069.32,1318.55 1069.33,1318.55 1069.34,1318.55 1069.35,1318.55 1069.36,1318.56 1069.37,1318.56 1069.38,1318.56 1069.39,1318.56 1069.39,1318.56 1069.4,1318.56 1069.41,1318.56 1069.42,1318.56 1069.43,1318.56 1069.44,1318.56 1069.45,1318.56 1069.46,1318.56 1069.47,1318.56 1069.48,1318.56 1069.49,1318.56 1069.5,1318.56 1069.5,1318.56 1069.51,1318.57 1069.52,1318.57 1069.53,1318.57 1069.54,1318.57 1069.55,1318.57 1069.56,1318.57 1069.57,1318.57 1069.58,1318.57 1069.59,1318.57 1069.6,1318.57 1069.61,1318.57 1069.62,1318.57 1069.62,1318.57 1069.63,1318.57 1069.64,1318.57 1069.65,1318.57 1069.66,1318.58 1069.67,1318.58 1069.68,1318.58 1069.69,1318.58 1069.7,1318.58 1069.71,1318.58 1069.72,1318.58 1069.73,1318.58 1069.73,1318.58 1069.74,1318.58 1069.75,1318.58 1069.76,1318.58 1069.77,1318.58 1069.78,1318.58 1069.79,1318.58 1069.8,1318.58 1069.81,1318.58 1069.82,1318.59 1069.83,1318.59 1069.84,1318.59 1069.84,1318.59 1069.85,1318.59 1069.86,1318.59 1069.87,1318.59 1069.88,1318.59 1069.89,1318.59 1069.9,1318.59 1069.91,1318.59 1069.92,1318.59 1069.93,1318.59 1069.94,1318.59 1069.95,1318.59 1069.96,1318.59 1069.96,1318.59 1069.97,1318.6 1069.98,1318.6 1069.99,1318.6 1070,1318.6 1070.01,1318.6 1070.02,1318.6 1070.03,1318.6 1070.04,1318.6 1070.05,1318.6 1070.06,1318.6 1070.07,1318.6 1070.07,1318.6 1070.08,1318.6 1070.09,1318.6 1070.1,1318.6 1070.11,1318.6 1070.12,1318.61 1070.13,1318.61 1070.14,1318.61 1070.15,1318.61 1070.16,1318.61 1070.17,1318.61 1070.18,1318.61 1070.18,1318.61 1070.19,1318.61 1070.2,1318.61 1070.21,1318.61 1070.22,1318.61 1070.23,1318.61 1070.24,1318.61 1070.25,1318.61 1070.26,1318.61 1070.27,1318.61 1070.28,1318.62 1070.29,1318.62 1070.3,1318.62 1070.3,1318.62 1070.31,1318.62 1070.32,1318.62 1070.33,1318.62 1070.34,1318.62 1070.35,1318.62 1070.36,1318.62 1070.37,1318.62 1070.38,1318.62 1070.39,1318.62 1070.4,1318.62 1070.41,1318.62 1070.41,1318.62 1070.42,1318.63 1070.43,1318.63 1070.44,1318.63 1070.45,1318.63 1070.46,1318.63 1070.47,1318.63 1070.48,1318.63 1070.49,1318.63 1070.5,1318.63 1070.51,1318.63 1070.52,1318.63 1070.52,1318.63 1070.53,1318.63 1070.54,1318.63 1070.55,1318.63 1070.56,1318.63 1070.57,1318.63 1070.58,1318.64 1070.59,1318.64 1070.6,1318.64 1070.61,1318.64 1070.62,1318.64 1070.63,1318.64 1070.64,1318.64 1070.64,1318.64 1070.65,1318.64 1070.66,1318.64 1070.67,1318.64 1070.68,1318.64 1070.69,1318.64 1070.7,1318.64 1070.71,1318.64 1070.72,1318.64 1070.73,1318.65 1070.74,1318.65 1070.75,1318.65 1070.75,1318.65 1070.76,1318.65 1070.77,1318.65 1070.78,1318.65 1070.79,1318.65 1070.8,1318.65 1070.81,1318.65 1070.82,1318.65 1070.83,1318.65 1070.84,1318.65 1070.85,1318.65 1070.86,1318.65 1070.86,1318.65 1070.87,1318.65 1070.88,1318.66 1070.89,1318.66 1070.9,1318.66 1070.91,1318.66 1070.92,1318.66 1070.93,1318.66 1070.94,1318.66 1070.95,1318.66 1070.96,1318.66 1070.97,1318.66 1070.98,1318.66 1070.98,1318.66 1070.99,1318.66 1071,1318.66 1071.01,1318.66 1071.02,1318.66 1071.03,1318.67 1071.04,1318.67 1071.05,1318.67 1071.06,1318.67 1071.07,1318.67 1071.08,1318.67 1071.09,1318.67 1071.09,1318.67 1071.1,1318.67 1071.11,1318.67 1071.12,1318.67 1071.13,1318.67 1071.14,1318.67 1071.15,1318.67 1071.16,1318.67 1071.17,1318.67 1071.18,1318.67 1071.19,1318.68 1071.2,1318.68 1071.2,1318.68 1071.21,1318.68 1071.22,1318.68 1071.23,1318.68 1071.24,1318.68 1071.25,1318.68 1071.26,1318.68 1071.27,1318.68 1071.28,1318.68 1071.29,1318.68 1071.3,1318.68 1071.31,1318.68 1071.32,1318.68 1071.32,1318.68 1071.33,1318.68 1071.34,1318.69 1071.35,1318.69 1071.36,1318.69 1071.37,1318.69 1071.38,1318.69 1071.39,1318.69 1071.4,1318.69 1071.41,1318.69 1071.42,1318.69 1071.43,1318.69 1071.43,1318.69 1071.44,1318.69 1071.45,1318.69 1071.46,1318.69 1071.47,1318.69 1071.48,1318.69 1071.49,1318.7 1071.5,1318.7 1071.51,1318.7 1071.52,1318.7 1071.53,1318.7 1071.54,1318.7 1071.54,1318.7 1071.55,1318.7 1071.56,1318.7 1071.57,1318.7 1071.58,1318.7 1071.59,1318.7 1071.6,1318.7 1071.61,1318.7 1071.62,1318.7 1071.63,1318.7 1071.64,1318.7 1071.65,1318.71 1071.66,1318.71 1071.66,1318.71 1071.67,1318.71 1071.68,1318.71 1071.69,1318.71 1071.7,1318.71 1071.71,1318.71 1071.72,1318.71 1071.73,1318.71 1071.74,1318.71 1071.75,1318.71 1071.76,1318.71 1071.77,1318.71 1071.77,1318.71 1071.78,1318.71 1071.79,1318.72 1071.8,1318.72 1071.81,1318.72 1071.82,1318.72 1071.83,1318.72 1071.84,1318.72 1071.85,1318.72 1071.86,1318.72 1071.87,1318.72 1071.88,1318.72 1071.88,1318.72 1071.89,1318.72 1071.9,1318.72 1071.91,1318.72 1071.92,1318.72 1071.93,1318.72 1071.94,1318.72 1071.95,1318.73 1071.96,1318.73 1071.97,1318.73 1071.98,1318.73 1071.99,1318.73 1072,1318.73 1072,1318.73 1072.01,1318.73 1072.02,1318.73 1072.03,1318.73 1072.04,1318.73 1072.05,1318.73 1072.06,1318.73 1072.07,1318.73 1072.08,1318.73 1072.09,1318.73 1072.1,1318.74 1072.11,1318.74 1072.11,1318.74 1072.12,1318.74 1072.13,1318.74 1072.14,1318.74 1072.15,1318.74 1072.16,1318.74 1072.17,1318.74 1072.18,1318.74 1072.19,1318.74 1072.2,1318.74 1072.21,1318.74 1072.22,1318.74 1072.23,1318.74 1072.23,1318.74 1072.24,1318.74 1072.25,1318.75 1072.26,1318.75 1072.27,1318.75 1072.28,1318.75 1072.29,1318.75 1072.3,1318.75 1072.31,1318.75 1072.32,1318.75 1072.33,1318.75 1072.34,1318.75 1072.34,1318.75 1072.35,1318.75 1072.36,1318.75 1072.37,1318.75 1072.38,1318.75 1072.39,1318.75 1072.4,1318.75 1072.41,1318.76 1072.42,1318.76 1072.43,1318.76 1072.44,1318.76 1072.45,1318.76 1072.45,1318.76 1072.46,1318.76 1072.47,1318.76 1072.48,1318.76 1072.49,1318.76 1072.5,1318.76 1072.51,1318.76 1072.52,1318.76 1072.53,1318.76 1072.54,1318.76 1072.55,1318.76 1072.56,1318.77 1072.57,1318.77 1072.57,1318.77 1072.58,1318.77 1072.59,1318.77 1072.6,1318.77 1072.61,1318.77 1072.62,1318.77 1072.63,1318.77 1072.64,1318.77 1072.65,1318.77 1072.66,1318.77 1072.67,1318.77 1072.68,1318.77 1072.68,1318.77 1072.69,1318.77 1072.7,1318.77 1072.71,1318.78 1072.72,1318.78 1072.73,1318.78 1072.74,1318.78 1072.75,1318.78 1072.76,1318.78 1072.77,1318.78 1072.78,1318.78 1072.79,1318.78 1072.79,1318.78 1072.8,1318.78 1072.81,1318.78 1072.82,1318.78 1072.83,1318.78 1072.84,1318.78 1072.85,1318.78 1072.86,1318.79 1072.87,1318.79 1072.88,1318.79 1072.89,1318.79 1072.9,1318.79 1072.91,1318.79 1072.91,1318.79 1072.92,1318.79 1072.93,1318.79 1072.94,1318.79 1072.95,1318.79 1072.96,1318.79 1072.97,1318.79 1072.98,1318.79 1072.99,1318.79 1073,1318.79 1073.01,1318.79 1073.02,1318.8 1073.02,1318.8 1073.03,1318.8 1073.04,1318.8 1073.05,1318.8 1073.06,1318.8 1073.07,1318.8 1073.08,1318.8 1073.09,1318.8 1073.1,1318.8 1073.11,1318.8 1073.12,1318.8 1073.13,1318.8 1073.13,1318.8 1073.14,1318.8 1073.15,1318.8 1073.16,1318.81 1073.17,1318.81 1073.18,1318.81 1073.19,1318.81 1073.2,1318.81 1073.21,1318.81 1073.22,1318.81 1073.23,1318.81 1073.24,1318.81 1073.25,1318.81 1073.25,1318.81 1073.26,1318.81 1073.27,1318.81 1073.28,1318.81 1073.29,1318.81 1073.3,1318.81 1073.31,1318.81 1073.32,1318.82 1073.33,1318.82 1073.34,1318.82 1073.35,1318.82 1073.36,1318.82 1073.36,1318.82 1073.37,1318.82 1073.38,1318.82 1073.39,1318.82 1073.4,1318.82 1073.41,1318.82 1073.42,1318.82 1073.43,1318.82 1073.44,1318.82 1073.45,1318.82 1073.46,1318.82 1073.47,1318.82 1073.47,1318.83 1073.48,1318.83 1073.49,1318.83 1073.5,1318.83 1073.51,1318.83 1073.52,1318.83 1073.53,1318.83 1073.54,1318.83 1073.55,1318.83 1073.56,1318.83 1073.57,1318.83 1073.58,1318.83 1073.59,1318.83 1073.59,1318.83 1073.6,1318.83 1073.61,1318.83 1073.62,1318.84 1073.63,1318.84 1073.64,1318.84 1073.65,1318.84 1073.66,1318.84 1073.67,1318.84 1073.68,1318.84 1073.69,1318.84 1073.7,1318.84 1073.7,1318.84 1073.71,1318.84 1073.72,1318.84 1073.73,1318.84 1073.74,1318.84 1073.75,1318.84 1073.76,1318.84 1073.77,1318.84 1073.78,1318.85 1073.79,1318.85 1073.8,1318.85 1073.81,1318.85 1073.81,1318.85 1073.82,1318.85 1073.83,1318.85 1073.84,1318.85 1073.85,1318.85 1073.86,1318.85 1073.87,1318.85 1073.88,1318.85 1073.89,1318.85 1073.9,1318.85 1073.91,1318.85 1073.92,1318.85 1073.93,1318.86 1073.93,1318.86 1073.94,1318.86 1073.95,1318.86 1073.96,1318.86 1073.97,1318.86 1073.98,1318.86 1073.99,1318.86 1074,1318.86 1074.01,1318.86 1074.02,1318.86 1074.03,1318.86 1074.04,1318.86 1074.04,1318.86 1074.05,1318.86 1074.06,1318.86 1074.07,1318.86 1074.08,1318.87 1074.09,1318.87 1074.1,1318.87 1074.11,1318.87 1074.12,1318.87 1074.13,1318.87 1074.14,1318.87 1074.15,1318.87 1074.15,1318.87 1074.16,1318.87 1074.17,1318.87 1074.18,1318.87 1074.19,1318.87 1074.2,1318.87 1074.21,1318.87 1074.22,1318.87 1074.23,1318.87 1074.24,1318.88 1074.25,1318.88 1074.26,1318.88 1074.27,1318.88 1074.27,1318.88 1074.28,1318.88 1074.29,1318.88 1074.3,1318.88 1074.31,1318.88 1074.32,1318.88 1074.33,1318.88 1074.34,1318.88 1074.35,1318.88 1074.36,1318.88 1074.37,1318.88 1074.38,1318.88 1074.38,1318.89 1074.39,1318.89 1074.4,1318.89 1074.41,1318.89 1074.42,1318.89 1074.43,1318.89 1074.44,1318.89 1074.45,1318.89 1074.46,1318.89 1074.47,1318.89 1074.48,1318.89 1074.49,1318.89 1074.49,1318.89 1074.5,1318.89 1074.51,1318.89 1074.52,1318.89 1074.53,1318.89 1074.54,1318.9 1074.55,1318.9 1074.56,1318.9 1074.57,1318.9 1074.58,1318.9 1074.59,1318.9 1074.6,1318.9 1074.61,1318.9 1074.61,1318.9 1074.62,1318.9 1074.63,1318.9 1074.64,1318.9 1074.65,1318.9 1074.66,1318.9 1074.67,1318.9 1074.68,1318.9 1074.69,1318.91 1074.7,1318.91 1074.71,1318.91 1074.72,1318.91 1074.72,1318.91 1074.73,1318.91 1074.74,1318.91 1074.75,1318.91 1074.76,1318.91 1074.77,1318.91 1074.78,1318.91 1074.79,1318.91 1074.8,1318.91 1074.81,1318.91 1074.82,1318.91 1074.83,1318.91 1074.83,1318.91 1074.84,1318.92 1074.85,1318.92 1074.86,1318.92 1074.87,1318.92 1074.88,1318.92 1074.89,1318.92 1074.9,1318.92 1074.91,1318.92 1074.92,1318.92 1074.93,1318.92 1074.94,1318.92 1074.95,1318.92 1074.95,1318.92 1074.96,1318.92 1074.97,1318.92 1074.98,1318.92 1074.99,1318.92 1075,1318.93 1075.01,1318.93 1075.02,1318.93 1075.03,1318.93 1075.04,1318.93 1075.05,1318.93 1075.06,1318.93 1075.06,1318.93 1075.07,1318.93 1075.08,1318.93 1075.09,1318.93 1075.1,1318.93 1075.11,1318.93 1075.12,1318.93 1075.13,1318.93 1075.14,1318.93 1075.15,1318.94 1075.16,1318.94 1075.17,1318.94 1075.17,1318.94 1075.18,1318.94 1075.19,1318.94 1075.2,1318.94 1075.21,1318.94 1075.22,1318.94 1075.23,1318.94 1075.24,1318.94 1075.25,1318.94 1075.26,1318.94 1075.27,1318.94 1075.28,1318.94 1075.29,1318.94 1075.29,1318.94 1075.3,1318.95 1075.31,1318.95 1075.32,1318.95 1075.33,1318.95 1075.34,1318.95 1075.35,1318.95 1075.36,1318.95 1075.37,1318.95 1075.38,1318.95 1075.39,1318.95 1075.4,1318.95 1075.4,1318.95 1075.41,1318.95 1075.42,1318.95 1075.43,1318.95 1075.44,1318.95 1075.45,1318.96 1075.46,1318.96 1075.47,1318.96 1075.48,1318.96 1075.49,1318.96 1075.5,1318.96 1075.51,1318.96 1075.51,1318.96 1075.52,1318.96 1075.53,1318.96 1075.54,1318.96 1075.55,1318.96 1075.56,1318.96 1075.57,1318.96 1075.58,1318.96 1075.59,1318.96 1075.6,1318.96 1075.61,1318.97 1075.62,1318.97 1075.63,1318.97 1075.63,1318.97 1075.64,1318.97 1075.65,1318.97 1075.66,1318.97 1075.67,1318.97 1075.68,1318.97 1075.69,1318.97 1075.7,1318.97 1075.71,1318.97 1075.72,1318.97 1075.73,1318.97 1075.74,1318.97 1075.74,1318.97 1075.75,1318.97 1075.76,1318.98 1075.77,1318.98 1075.78,1318.98 1075.79,1318.98 1075.8,1318.98 1075.81,1318.98 1075.82,1318.98 1075.83,1318.98 1075.84,1318.98 1075.85,1318.98 1075.85,1318.98 1075.86,1318.98 1075.87,1318.98 1075.88,1318.98 1075.89,1318.98 1075.9,1318.98 1075.91,1318.99 1075.92,1318.99 1075.93,1318.99 1075.94,1318.99 1075.95,1318.99 1075.96,1318.99 1075.97,1318.99 1075.97,1318.99 1075.98,1318.99 1075.99,1318.99 1076,1318.99 1076.01,1318.99 1076.02,1318.99 1076.03,1318.99 1076.04,1318.99 1076.05,1318.99 1076.06,1318.99 1076.07,1319 1076.08,1319 1076.08,1319 1076.09,1319 1076.1,1319 1076.11,1319 1076.12,1319 1076.13,1319 1076.14,1319 1076.15,1319 1076.16,1319 1076.17,1319 1076.18,1319 1076.19,1319 1076.19,1319 1076.2,1319 1076.21,1319.01 1076.22,1319.01 1076.23,1319.01 1076.24,1319.01 1076.25,1319.01 1076.26,1319.01 1076.27,1319.01 1076.28,1319.01 1076.29,1319.01 1076.3,1319.01 1076.31,1319.01 1076.31,1319.01 1076.32,1319.01 1076.33,1319.01 1076.34,1319.01 1076.35,1319.01 1076.36,1319.01 1076.37,1319.02 1076.38,1319.02 1076.39,1319.02 1076.4,1319.02 1076.41,1319.02 1076.42,1319.02 1076.42,1319.02 1076.43,1319.02 1076.44,1319.02 1076.45,1319.02 1076.46,1319.02 1076.47,1319.02 1076.48,1319.02 1076.49,1319.02 1076.5,1319.02 1076.51,1319.02 1076.52,1319.02 1076.53,1319.03 1076.53,1319.03 1076.54,1319.03 1076.55,1319.03 1076.56,1319.03 1076.57,1319.03 1076.58,1319.03 1076.59,1319.03 1076.6,1319.03 1076.61,1319.03 1076.62,1319.03 1076.63,1319.03 1076.64,1319.03 1076.65,1319.03 1076.65,1319.03 1076.66,1319.03 1076.67,1319.04 1076.68,1319.04 1076.69,1319.04 1076.7,1319.04 1076.71,1319.04 1076.72,1319.04 1076.73,1319.04 1076.74,1319.04 1076.75,1319.04 1076.76,1319.04 1076.76,1319.04 1076.77,1319.04 1076.78,1319.04 1076.79,1319.04 1076.8,1319.04 1076.81,1319.04 1076.82,1319.04 1076.83,1319.05 1076.84,1319.05 1076.85,1319.05 1076.86,1319.05 1076.87,1319.05 1076.87,1319.05 1076.88,1319.05 1076.89,1319.05 1076.9,1319.05 1076.91,1319.05 1076.92,1319.05 1076.93,1319.05 1076.94,1319.05 1076.95,1319.05 1076.96,1319.05 1076.97,1319.05 1076.98,1319.06 1076.99,1319.06 1076.99,1319.06 1077,1319.06 1077.01,1319.06 1077.02,1319.06 1077.03,1319.06 1077.04,1319.06 1077.05,1319.06 1077.06,1319.06 1077.07,1319.06 1077.08,1319.06 1077.09,1319.06 1077.1,1319.06 1077.1,1319.06 1077.11,1319.06 1077.12,1319.06 1077.13,1319.07 1077.14,1319.07 1077.15,1319.07 1077.16,1319.07 1077.17,1319.07 1077.18,1319.07 1077.19,1319.07 1077.2,1319.07 1077.21,1319.07 1077.21,1319.07 1077.22,1319.07 1077.23,1319.07 1077.24,1319.07 1077.25,1319.07 1077.26,1319.07 1077.27,1319.07 1077.28,1319.07 1077.29,1319.08 1077.3,1319.08 1077.31,1319.08 1077.32,1319.08 1077.33,1319.08 1077.33,1319.08 1077.34,1319.08 1077.35,1319.08 1077.36,1319.08 1077.37,1319.08 1077.38,1319.08 1077.39,1319.08 1077.4,1319.08 1077.41,1319.08 1077.42,1319.08 1077.43,1319.08 1077.44,1319.09 1077.44,1319.09 1077.45,1319.09 1077.46,1319.09 1077.47,1319.09 1077.48,1319.09 1077.49,1319.09 1077.5,1319.09 1077.51,1319.09 1077.52,1319.09 1077.53,1319.09 1077.54,1319.09 1077.55,1319.09 1077.55,1319.09 1077.56,1319.09 1077.57,1319.09 1077.58,1319.09 1077.59,1319.1 1077.6,1319.1 1077.61,1319.1 1077.62,1319.1 1077.63,1319.1 1077.64,1319.1 1077.65,1319.1 1077.66,1319.1 1077.67,1319.1 1077.67,1319.1 1077.68,1319.1 1077.69,1319.1 1077.7,1319.1 1077.71,1319.1 1077.72,1319.1 1077.73,1319.1 1077.74,1319.11 1077.75,1319.11 1077.76,1319.11 1077.77,1319.11 1077.78,1319.11 1077.78,1319.11 1077.79,1319.11 1077.8,1319.11 1077.81,1319.11 1077.82,1319.11 1077.83,1319.11 1077.84,1319.11 1077.85,1319.11 1077.86,1319.11 1077.87,1319.11 1077.88,1319.11 1077.89,1319.11 1077.89,1319.12 1077.9,1319.12 1077.91,1319.12 1077.92,1319.12 1077.93,1319.12 1077.94,1319.12 1077.95,1319.12 1077.96,1319.12 1077.97,1319.12 1077.98,1319.12 1077.99,1319.12 1078,1319.12 1078.01,1319.12 1078.01,1319.12 1078.02,1319.12 1078.03,1319.12 1078.04,1319.12 1078.05,1319.13 1078.06,1319.13 1078.07,1319.13 1078.08,1319.13 1078.09,1319.13 1078.1,1319.13 1078.11,1319.13 1078.12,1319.13 1078.12,1319.13 1078.13,1319.13 1078.14,1319.13 1078.15,1319.13 1078.16,1319.13 1078.17,1319.13 1078.18,1319.13 1078.19,1319.13 1078.2,1319.14 1078.21,1319.14 1078.22,1319.14 1078.23,1319.14 1078.23,1319.14 1078.24,1319.14 1078.25,1319.14 1078.26,1319.14 1078.27,1319.14 1078.28,1319.14 1078.29,1319.14 1078.3,1319.14 1078.31,1319.14 1078.32,1319.14 1078.33,1319.14 1078.34,1319.14 1078.35,1319.14 1078.35,1319.15 1078.36,1319.15 1078.37,1319.15 1078.38,1319.15 1078.39,1319.15 1078.4,1319.15 1078.41,1319.15 1078.42,1319.15 1078.43,1319.15 1078.44,1319.15 1078.45,1319.15 1078.46,1319.15 1078.46,1319.15 1078.47,1319.15 1078.48,1319.15 1078.49,1319.15 1078.5,1319.15 1078.51,1319.16 1078.52,1319.16 1078.53,1319.16 1078.54,1319.16 1078.55,1319.16 1078.56,1319.16 1078.57,1319.16 1078.57,1319.16 1078.58,1319.16 1078.59,1319.16 1078.6,1319.16 1078.61,1319.16 1078.62,1319.16 1078.63,1319.16 1078.64,1319.16 1078.65,1319.16 1078.66,1319.17 1078.67,1319.17 1078.68,1319.17 1078.69,1319.17 1078.69,1319.17 1078.7,1319.17 1078.71,1319.17 1078.72,1319.17 1078.73,1319.17 1078.74,1319.17 1078.75,1319.17 1078.76,1319.17 1078.77,1319.17 1078.78,1319.17 1078.79,1319.17 1078.8,1319.17 1078.8,1319.17 1078.81,1319.18 1078.82,1319.18 1078.83,1319.18 1078.84,1319.18 1078.85,1319.18 1078.86,1319.18 1078.87,1319.18 1078.88,1319.18 1078.89,1319.18 1078.9,1319.18 1078.91,1319.18 1078.91,1319.18 1078.92,1319.18 1078.93,1319.18 1078.94,1319.18 1078.95,1319.18 1078.96,1319.19 1078.97,1319.19 1078.98,1319.19 1078.99,1319.19 1079,1319.19 1079.01,1319.19 1079.02,1319.19 1079.03,1319.19 1079.03,1319.19 1079.04,1319.19 1079.05,1319.19 1079.06,1319.19 1079.07,1319.19 1079.08,1319.19 1079.09,1319.19 1079.1,1319.19 1079.11,1319.19 1079.12,1319.2 1079.13,1319.2 1079.14,1319.2 1079.14,1319.2 1079.15,1319.2 1079.16,1319.2 1079.17,1319.2 1079.18,1319.2 1079.19,1319.2 1079.2,1319.2 1079.21,1319.2 1079.22,1319.2 1079.23,1319.2 1079.24,1319.2 1079.25,1319.2 1079.25,1319.2 1079.26,1319.2 1079.27,1319.21 1079.28,1319.21 1079.29,1319.21 1079.3,1319.21 1079.31,1319.21 1079.32,1319.21 1079.33,1319.21 1079.34,1319.21 1079.35,1319.21 1079.36,1319.21 1079.37,1319.21 1079.37,1319.21 1079.38,1319.21 1079.39,1319.21 1079.4,1319.21 1079.41,1319.21 1079.42,1319.22 1079.43,1319.22 1079.44,1319.22 1079.45,1319.22 1079.46,1319.22 1079.47,1319.22 1079.48,1319.22 1079.48,1319.22 1079.49,1319.22 1079.5,1319.22 1079.51,1319.22 1079.52,1319.22 1079.53,1319.22 1079.54,1319.22 1079.55,1319.22 1079.56,1319.22 1079.57,1319.22 1079.58,1319.23 1079.59,1319.23 1079.59,1319.23 1079.6,1319.23 1079.61,1319.23 1079.62,1319.23 1079.63,1319.23 1079.64,1319.23 1079.65,1319.23 1079.66,1319.23 1079.67,1319.23 1079.68,1319.23 1079.69,1319.23 1079.7,1319.23 1079.71,1319.23 1079.71,1319.23 1079.72,1319.23 1079.73,1319.24 1079.74,1319.24 1079.75,1319.24 1079.76,1319.24 1079.77,1319.24 1079.78,1319.24 1079.79,1319.24 1079.8,1319.24 1079.81,1319.24 1079.82,1319.24 1079.82,1319.24 1079.83,1319.24 1079.84,1319.24 1079.85,1319.24 1079.86,1319.24 1079.87,1319.24 1079.88,1319.25 1079.89,1319.25 1079.9,1319.25 1079.91,1319.25 1079.92,1319.25 1079.93,1319.25 1079.93,1319.25 1079.94,1319.25 1079.95,1319.25 1079.96,1319.25 1079.97,1319.25 1079.98,1319.25 1079.99,1319.25 1080,1319.25 1080.01,1319.25 1080.02,1319.25 1080.03,1319.25 1080.04,1319.26 1080.05,1319.26 1080.05,1319.26 1080.06,1319.26 1080.07,1319.26 1080.08,1319.26 1080.09,1319.26 1080.1,1319.26 1080.11,1319.26 1080.12,1319.26 1080.13,1319.26 1080.14,1319.26 1080.15,1319.26 1080.16,1319.26 1080.16,1319.26 1080.17,1319.26 1080.18,1319.26 1080.19,1319.27 1080.2,1319.27 1080.21,1319.27 1080.22,1319.27 1080.23,1319.27 1080.24,1319.27 1080.25,1319.27 1080.26,1319.27 1080.27,1319.27 1080.27,1319.27 1080.28,1319.27 1080.29,1319.27 1080.3,1319.27 1080.31,1319.27 1080.32,1319.27 1080.33,1319.27 1080.34,1319.28 1080.35,1319.28 1080.36,1319.28 1080.37,1319.28 1080.38,1319.28 1080.39,1319.28 1080.39,1319.28 1080.4,1319.28 1080.41,1319.28 1080.42,1319.28 1080.43,1319.28 1080.44,1319.28 1080.45,1319.28 1080.46,1319.28 1080.47,1319.28 1080.48,1319.28 1080.49,1319.28 1080.5,1319.29 1080.5,1319.29 1080.51,1319.29 1080.52,1319.29 1080.53,1319.29 1080.54,1319.29 1080.55,1319.29 1080.56,1319.29 1080.57,1319.29 1080.58,1319.29 1080.59,1319.29 1080.6,1319.29 1080.61,1319.29 1080.61,1319.29 1080.62,1319.29 1080.63,1319.29 1080.64,1319.29 1080.65,1319.3 1080.66,1319.3 1080.67,1319.3 1080.68,1319.3 1080.69,1319.3 1080.7,1319.3 1080.71,1319.3 1080.72,1319.3 1080.73,1319.3 1080.73,1319.3 1080.74,1319.3 1080.75,1319.3 1080.76,1319.3 1080.77,1319.3 1080.78,1319.3 1080.79,1319.3 1080.8,1319.31 1080.81,1319.31 1080.82,1319.31 1080.83,1319.31 1080.84,1319.31 1080.84,1319.31 1080.85,1319.31 1080.86,1319.31 1080.87,1319.31 1080.88,1319.31 1080.89,1319.31 1080.9,1319.31 1080.91,1319.31 1080.92,1319.31 1080.93,1319.31 1080.94,1319.31 1080.95,1319.31 1080.95,1319.32 1080.96,1319.32 1080.97,1319.32 1080.98,1319.32 1080.99,1319.32 1081,1319.32 1081.01,1319.32 1081.02,1319.32 1081.03,1319.32 1081.04,1319.32 1081.05,1319.32 1081.06,1319.32 1081.07,1319.32 1081.07,1319.32 1081.08,1319.32 1081.09,1319.32 1081.1,1319.32 1081.11,1319.33 1081.12,1319.33 1081.13,1319.33 1081.14,1319.33 1081.15,1319.33 1081.16,1319.33 1081.17,1319.33 1081.18,1319.33 1081.18,1319.33 1081.19,1319.33 1081.2,1319.33 1081.21,1319.33 1081.22,1319.33 1081.23,1319.33 1081.24,1319.33 1081.25,1319.33 1081.26,1319.34 1081.27,1319.34 1081.28,1319.34 1081.29,1319.34 1081.29,1319.34 1081.3,1319.34 1081.31,1319.34 1081.32,1319.34 1081.33,1319.34 1081.34,1319.34 1081.35,1319.34 1081.36,1319.34 1081.37,1319.34 1081.38,1319.34 1081.39,1319.34 1081.4,1319.34 1081.41,1319.34 1081.41,1319.35 1081.42,1319.35 1081.43,1319.35 1081.44,1319.35 1081.45,1319.35 1081.46,1319.35 1081.47,1319.35 1081.48,1319.35 1081.49,1319.35 1081.5,1319.35 1081.51,1319.35 1081.52,1319.35 1081.52,1319.35 1081.53,1319.35 1081.54,1319.35 1081.55,1319.35 1081.56,1319.36 1081.57,1319.36 1081.58,1319.36 1081.59,1319.36 1081.6,1319.36 1081.61,1319.36 1081.62,1319.36 1081.63,1319.36 1081.63,1319.36 1081.64,1319.36 1081.65,1319.36 1081.66,1319.36 1081.67,1319.36 1081.68,1319.36 1081.69,1319.36 1081.7,1319.36 1081.71,1319.36 1081.72,1319.37 1081.73,1319.37 1081.74,1319.37 1081.75,1319.37 1081.75,1319.37 1081.76,1319.37 1081.77,1319.37 1081.78,1319.37 1081.79,1319.37 1081.8,1319.37 1081.81,1319.37 1081.82,1319.37 1081.83,1319.37 1081.84,1319.37 1081.85,1319.37 1081.86,1319.37 1081.86,1319.37 1081.87,1319.38 1081.88,1319.38 1081.89,1319.38 1081.9,1319.38 1081.91,1319.38 1081.92,1319.38 1081.93,1319.38 1081.94,1319.38 1081.95,1319.38 1081.96,1319.38 1081.97,1319.38 1081.97,1319.38 1081.98,1319.38 1081.99,1319.38 1082,1319.38 1082.01,1319.38 1082.02,1319.39 1082.03,1319.39 1082.04,1319.39 1082.05,1319.39 1082.06,1319.39 1082.07,1319.39 1082.08,1319.39 1082.09,1319.39 1082.09,1319.39 1082.1,1319.39 1082.11,1319.39 1082.12,1319.39 1082.13,1319.39 1082.14,1319.39 1082.15,1319.39 1082.16,1319.39 1082.17,1319.39 1082.18,1319.4 1082.19,1319.4 1082.2,1319.4 1082.2,1319.4 1082.21,1319.4 1082.22,1319.4 1082.23,1319.4 1082.24,1319.4 1082.25,1319.4 1082.26,1319.4 1082.27,1319.4 1082.28,1319.4 1082.29,1319.4 1082.3,1319.4 1082.31,1319.4 1082.31,1319.4 1082.32,1319.4 1082.33,1319.41 1082.34,1319.41 1082.35,1319.41 1082.36,1319.41 1082.37,1319.41 1082.38,1319.41 1082.39,1319.41 1082.4,1319.41 1082.41,1319.41 1082.42,1319.41 1082.43,1319.41 1082.43,1319.41 1082.44,1319.41 1082.45,1319.41 1082.46,1319.41 1082.47,1319.41 1082.48,1319.42 1082.49,1319.42 1082.5,1319.42 1082.51,1319.42 1082.52,1319.42 1082.53,1319.42 1082.54,1319.42 1082.54,1319.42 1082.55,1319.42 1082.56,1319.42 1082.57,1319.42 1082.58,1319.42 1082.59,1319.42 1082.6,1319.42 1082.61,1319.42 1082.62,1319.42 1082.63,1319.42 1082.64,1319.43 1082.65,1319.43 1082.65,1319.43 1082.66,1319.43 1082.67,1319.43 1082.68,1319.43 1082.69,1319.43 1082.7,1319.43 1082.71,1319.43 1082.72,1319.43 1082.73,1319.43 1082.74,1319.43 1082.75,1319.43 1082.76,1319.43 1082.77,1319.43 1082.77,1319.43 1082.78,1319.43 1082.79,1319.44 1082.8,1319.44 1082.81,1319.44 1082.82,1319.44 1082.83,1319.44 1082.84,1319.44 1082.85,1319.44 1082.86,1319.44 1082.87,1319.44 1082.88,1319.44 1082.88,1319.44 1082.89,1319.44 1082.9,1319.44 1082.91,1319.44 1082.92,1319.44 1082.93,1319.44 1082.94,1319.45 1082.95,1319.45 1082.96,1319.45 1082.97,1319.45 1082.98,1319.45 1082.99,1319.45 1082.99,1319.45 1083,1319.45 1083.01,1319.45 1083.02,1319.45 1083.03,1319.45 1083.04,1319.45 1083.05,1319.45 1083.06,1319.45 1083.07,1319.45 1083.08,1319.45 1083.09,1319.45 1083.1,1319.46 1083.11,1319.46 1083.11,1319.46 1083.12,1319.46 1083.13,1319.46 1083.14,1319.46 1083.15,1319.46 1083.16,1319.46 1083.17,1319.46 1083.18,1319.46 1083.19,1319.46 1083.2,1319.46 1083.21,1319.46 1083.22,1319.46 1083.22,1319.46 1083.23,1319.46 1083.24,1319.46 1083.25,1319.47 1083.26,1319.47 1083.27,1319.47 1083.28,1319.47 1083.29,1319.47 1083.3,1319.47 1083.31,1319.47 1083.32,1319.47 1083.33,1319.47 1083.33,1319.47 1083.34,1319.47 1083.35,1319.47 1083.36,1319.47 1083.37,1319.47 1083.38,1319.47 1083.39,1319.47 1083.4,1319.48 1083.41,1319.48 1083.42,1319.48 1083.43,1319.48 1083.44,1319.48 1083.45,1319.48 1083.45,1319.48 1083.46,1319.48 1083.47,1319.48 1083.48,1319.48 1083.49,1319.48 1083.5,1319.48 1083.51,1319.48 1083.52,1319.48 1083.53,1319.48 1083.54,1319.48 1083.55,1319.48 1083.56,1319.49 1083.56,1319.49 1083.57,1319.49 1083.58,1319.49 1083.59,1319.49 1083.6,1319.49 1083.61,1319.49 1083.62,1319.49 1083.63,1319.49 1083.64,1319.49 1083.65,1319.49 1083.66,1319.49 1083.67,1319.49 1083.67,1319.49 1083.68,1319.49 1083.69,1319.49 1083.7,1319.49 1083.71,1319.5 1083.72,1319.5 1083.73,1319.5 1083.74,1319.5 1083.75,1319.5 1083.76,1319.5 1083.77,1319.5 1083.78,1319.5 1083.79,1319.5 1083.79,1319.5 1083.8,1319.5 1083.81,1319.5 1083.82,1319.5 1083.83,1319.5 1083.84,1319.5 1083.85,1319.5 1083.86,1319.5 1083.87,1319.51 1083.88,1319.51 1083.89,1319.51 1083.9,1319.51 1083.9,1319.51 1083.91,1319.51 1083.92,1319.51 1083.93,1319.51 1083.94,1319.51 1083.95,1319.51 1083.96,1319.51 1083.97,1319.51 1083.98,1319.51 1083.99,1319.51 1084,1319.51 1084.01,1319.51 1084.01,1319.52 1084.02,1319.52 1084.03,1319.52 1084.04,1319.52 1084.05,1319.52 1084.06,1319.52 1084.07,1319.52 1084.08,1319.52 1084.09,1319.52 1084.1,1319.52 1084.11,1319.52 1084.12,1319.52 1084.13,1319.52 1084.13,1319.52 1084.14,1319.52 1084.15,1319.52 1084.16,1319.52 1084.17,1319.53 1084.18,1319.53 1084.19,1319.53 1084.2,1319.53 1084.21,1319.53 1084.22,1319.53 1084.23,1319.53 1084.24,1319.53 1084.24,1319.53 1084.25,1319.53 1084.26,1319.53 1084.27,1319.53 1084.28,1319.53 1084.29,1319.53 1084.3,1319.53 1084.31,1319.53 1084.32,1319.53 1084.33,1319.54 1084.34,1319.54 1084.35,1319.54 1084.35,1319.54 1084.36,1319.54 1084.37,1319.54 1084.38,1319.54 1084.39,1319.54 1084.4,1319.54 1084.41,1319.54 1084.42,1319.54 1084.43,1319.54 1084.44,1319.54 1084.45,1319.54 1084.46,1319.54 1084.47,1319.54 1084.47,1319.55 1084.48,1319.55 1084.49,1319.55 1084.5,1319.55 1084.51,1319.55 1084.52,1319.55 1084.53,1319.55 1084.54,1319.55 1084.55,1319.55 1084.56,1319.55 1084.57,1319.55 1084.58,1319.55 1084.58,1319.55 1084.59,1319.55 1084.6,1319.55 1084.61,1319.55 1084.62,1319.55 1084.63,1319.56 1084.64,1319.56 1084.65,1319.56 1084.66,1319.56 1084.67,1319.56 1084.68,1319.56 1084.69,1319.56 1084.69,1319.56 1084.7,1319.56 1084.71,1319.56 1084.72,1319.56 1084.73,1319.56 1084.74,1319.56 1084.75,1319.56 1084.76,1319.56 1084.77,1319.56 1084.78,1319.56 1084.79,1319.57 1084.8,1319.57 1084.81,1319.57 1084.81,1319.57 1084.82,1319.57 1084.83,1319.57 1084.84,1319.57 1084.85,1319.57 1084.86,1319.57 1084.87,1319.57 1084.88,1319.57 1084.89,1319.57 1084.9,1319.57 1084.91,1319.57 1084.92,1319.57 1084.92,1319.57 1084.93,1319.58 1084.94,1319.58 1084.95,1319.58 1084.96,1319.58 1084.97,1319.58 1084.98,1319.58 1084.99,1319.58 1085,1319.58 1085.01,1319.58 1085.02,1319.58 1085.03,1319.58 1085.03,1319.58 1085.04,1319.58 1085.05,1319.58 1085.06,1319.58 1085.07,1319.58 1085.08,1319.58 1085.09,1319.59 1085.1,1319.59 1085.11,1319.59 1085.12,1319.59 1085.13,1319.59 1085.14,1319.59 1085.15,1319.59 1085.15,1319.59 1085.16,1319.59 1085.17,1319.59 1085.18,1319.59 1085.19,1319.59 1085.2,1319.59 1085.21,1319.59 1085.22,1319.59 1085.23,1319.59 1085.24,1319.59 1085.25,1319.6 1085.26,1319.6 1085.26,1319.6 1085.27,1319.6 1085.28,1319.6 1085.29,1319.6 1085.3,1319.6 1085.31,1319.6 1085.32,1319.6 1085.33,1319.6 1085.34,1319.6 1085.35,1319.6 1085.36,1319.6 1085.37,1319.6 1085.37,1319.6 1085.38,1319.6 1085.39,1319.61 1085.4,1319.61 1085.41,1319.61 1085.42,1319.61 1085.43,1319.61 1085.44,1319.61 1085.45,1319.61 1085.46,1319.61 1085.47,1319.61 1085.48,1319.61 1085.49,1319.61 1085.49,1319.61 1085.5,1319.61 1085.51,1319.61 1085.52,1319.61 1085.53,1319.61 1085.54,1319.61 1085.55,1319.62 1085.56,1319.62 1085.57,1319.62 1085.58,1319.62 1085.59,1319.62 1085.6,1319.62 1085.6,1319.62 1085.61,1319.62 1085.62,1319.62 1085.63,1319.62 1085.64,1319.62 1085.65,1319.62 1085.66,1319.62 1085.67,1319.62 1085.68,1319.62 1085.69,1319.62 1085.7,1319.62 1085.71,1319.63 1085.71,1319.63 1085.72,1319.63 1085.73,1319.63 1085.74,1319.63 1085.75,1319.63 1085.76,1319.63 1085.77,1319.63 1085.78,1319.63 1085.79,1319.63 1085.8,1319.63 1085.81,1319.63 1085.82,1319.63 1085.83,1319.63 1085.83,1319.63 1085.84,1319.63 1085.85,1319.64 1085.86,1319.64 1085.87,1319.64 1085.88,1319.64 1085.89,1319.64 1085.9,1319.64 1085.91,1319.64 1085.92,1319.64 1085.93,1319.64 1085.94,1319.64 1085.94,1319.64 1085.95,1319.64 1085.96,1319.64 1085.97,1319.64 1085.98,1319.64 1085.99,1319.64 1086,1319.64 1086.01,1319.65 1086.02,1319.65 1086.03,1319.65 1086.04,1319.65 1086.05,1319.65 1086.05,1319.65 1086.06,1319.65 1086.07,1319.65 1086.08,1319.65 1086.09,1319.65 1086.1,1319.65 1086.11,1319.65 1086.12,1319.65 1086.13,1319.65 1086.14,1319.65 1086.15,1319.65 1086.16,1319.65 1086.17,1319.66 1086.17,1319.66 1086.18,1319.66 1086.19,1319.66 1086.2,1319.66 1086.21,1319.66 1086.22,1319.66 1086.23,1319.66 1086.24,1319.66 1086.25,1319.66 1086.26,1319.66 1086.27,1319.66 1086.28,1319.66 1086.28,1319.66 1086.29,1319.66 1086.3,1319.66 1086.31,1319.66 1086.32,1319.67 1086.33,1319.67 1086.34,1319.67 1086.35,1319.67 1086.36,1319.67 1086.37,1319.67 1086.38,1319.67 1086.39,1319.67 1086.39,1319.67 1086.4,1319.67 1086.41,1319.67 1086.42,1319.67 1086.43,1319.67 1086.44,1319.67 1086.45,1319.67 1086.46,1319.67 1086.47,1319.68 1086.48,1319.68 1086.49,1319.68 1086.5,1319.68 1086.51,1319.68 1086.51,1319.68 1086.52,1319.68 1086.53,1319.68 1086.54,1319.68 1086.55,1319.68 1086.56,1319.68 1086.57,1319.68 1086.58,1319.68 1086.59,1319.68 1086.6,1319.68 1086.61,1319.68 1086.62,1319.68 1086.62,1319.69 1086.63,1319.69 1086.64,1319.69 1086.65,1319.69 1086.66,1319.69 1086.67,1319.69 1086.68,1319.69 1086.69,1319.69 1086.7,1319.69 1086.71,1319.69 1086.72,1319.69 1086.73,1319.69 1086.73,1319.69 1086.74,1319.69 1086.75,1319.69 1086.76,1319.69 1086.77,1319.69 1086.78,1319.7 1086.79,1319.7 1086.8,1319.7 1086.81,1319.7 1086.82,1319.7 1086.83,1319.7 1086.84,1319.7 1086.85,1319.7 1086.85,1319.7 1086.86,1319.7 1086.87,1319.7 1086.88,1319.7 1086.89,1319.7 1086.9,1319.7 1086.91,1319.7 1086.92,1319.7 1086.93,1319.71 1086.94,1319.71 1086.95,1319.71 1086.96,1319.71 1086.96,1319.71 1086.97,1319.71 1086.98,1319.71 1086.99,1319.71 1087,1319.71 1087.01,1319.71 1087.02,1319.71 1087.03,1319.71 1087.04,1319.71 1087.05,1319.71 1087.06,1319.71 1087.07,1319.71 1087.07,1319.71 1087.08,1319.72 1087.09,1319.72 1087.1,1319.72 1087.11,1319.72 1087.12,1319.72 1087.13,1319.72 1087.14,1319.72 1087.15,1319.72 1087.16,1319.72 1087.17,1319.72 1087.18,1319.72 1087.19,1319.72 1087.19,1319.72 1087.2,1319.72 1087.21,1319.72 1087.22,1319.72 1087.23,1319.72 1087.24,1319.73 1087.25,1319.73 1087.26,1319.73 1087.27,1319.73 1087.28,1319.73 1087.29,1319.73 1087.3,1319.73 1087.3,1319.73 1087.31,1319.73 1087.32,1319.73 1087.33,1319.73 1087.34,1319.73 1087.35,1319.73 1087.36,1319.73 1087.37,1319.73 1087.38,1319.73 1087.39,1319.73 1087.4,1319.74 1087.41,1319.74 1087.41,1319.74 1087.42,1319.74 1087.43,1319.74 1087.44,1319.74 1087.45,1319.74 1087.46,1319.74 1087.47,1319.74 1087.48,1319.74 1087.49,1319.74 1087.5,1319.74 1087.51,1319.74 1087.52,1319.74 1087.53,1319.74 1087.53,1319.74 1087.54,1319.75 1087.55,1319.75 1087.56,1319.75 1087.57,1319.75 1087.58,1319.75 1087.59,1319.75 1087.6,1319.75 1087.61,1319.75 1087.62,1319.75 1087.63,1319.75 1087.64,1319.75 1087.64,1319.75 1087.65,1319.75 1087.66,1319.75 1087.67,1319.75 1087.68,1319.75 1087.69,1319.75 1087.7,1319.76 1087.71,1319.76 1087.72,1319.76 1087.73,1319.76 1087.74,1319.76 1087.75,1319.76 1087.75,1319.76 1087.76,1319.76 1087.77,1319.76 1087.78,1319.76 1087.79,1319.76 1087.8,1319.76 1087.81,1319.76 1087.82,1319.76 1087.83,1319.76 1087.84,1319.76 1087.85,1319.76 1087.86,1319.77 1087.87,1319.77 1087.87,1319.77 1087.88,1319.77 1087.89,1319.77 1087.9,1319.77 1087.91,1319.77 1087.92,1319.77 1087.93,1319.77 1087.94,1319.77 1087.95,1319.77 1087.96,1319.77 1087.97,1319.77 1087.98,1319.77 1087.98,1319.77 1087.99,1319.77 1088,1319.78 1088.01,1319.78 1088.02,1319.78 1088.03,1319.78 1088.04,1319.78 1088.05,1319.78 1088.06,1319.78 1088.07,1319.78 1088.08,1319.78 1088.09,1319.78 1088.09,1319.78 1088.1,1319.78 1088.11,1319.78 1088.12,1319.78 1088.13,1319.78 1088.14,1319.78 1088.15,1319.78 1088.16,1319.79 1088.17,1319.79 1088.18,1319.79 1088.19,1319.79 1088.2,1319.79 1088.21,1319.79 1088.21,1319.79 1088.22,1319.79 1088.23,1319.79 1088.24,1319.79 1088.25,1319.79 1088.26,1319.79 1088.27,1319.79 1088.28,1319.79 1088.29,1319.79 1088.3,1319.79 1088.31,1319.79 1088.32,1319.8 1088.32,1319.8 1088.33,1319.8 1088.34,1319.8 1088.35,1319.8 1088.36,1319.8 1088.37,1319.8 1088.38,1319.8 1088.39,1319.8 1088.4,1319.8 1088.41,1319.8 1088.42,1319.8 1088.43,1319.8 1088.43,1319.8 1088.44,1319.8 1088.45,1319.8 1088.46,1319.8 1088.47,1319.81 1088.48,1319.81 1088.49,1319.81 1088.5,1319.81 1088.51,1319.81 1088.52,1319.81 1088.53,1319.81 1088.54,1319.81 1088.55,1319.81 1088.55,1319.81 1088.56,1319.81 1088.57,1319.81 1088.58,1319.81 1088.59,1319.81 1088.6,1319.81 1088.61,1319.81 1088.62,1319.82 1088.63,1319.82 1088.64,1319.82 1088.65,1319.82 1088.66,1319.82 1088.66,1319.82 1088.67,1319.82 1088.68,1319.82 1088.69,1319.82 1088.7,1319.82 1088.71,1319.82 1088.72,1319.82 1088.73,1319.82 1088.74,1319.82 1088.75,1319.82 1088.76,1319.82 1088.77,1319.82 1088.77,1319.83 1088.78,1319.83 1088.79,1319.83 1088.8,1319.83 1088.81,1319.83 1088.82,1319.83 1088.83,1319.83 1088.84,1319.83 1088.85,1319.83 1088.86,1319.83 1088.87,1319.83 1088.88,1319.83 1088.89,1319.83 1088.89,1319.83 1088.9,1319.83 1088.91,1319.83 1088.92,1319.83 1088.93,1319.84 1088.94,1319.84 1088.95,1319.84 1088.96,1319.84 1088.97,1319.84 1088.98,1319.84 1088.99,1319.84 1089,1319.84 1089,1319.84 1089.01,1319.84 1089.02,1319.84 1089.03,1319.84 1089.04,1319.84 1089.05,1319.84 1089.06,1319.84 1089.07,1319.84 1089.08,1319.85 1089.09,1319.85 1089.1,1319.85 1089.11,1319.85 1089.11,1319.85 1089.12,1319.85 1089.13,1319.85 1089.14,1319.85 1089.15,1319.85 1089.16,1319.85 1089.17,1319.85 1089.18,1319.85 1089.19,1319.85 1089.2,1319.85 1089.21,1319.85 1089.22,1319.85 1089.23,1319.85 1089.23,1319.86 1089.24,1319.86 1089.25,1319.86 1089.26,1319.86 1089.27,1319.86 1089.28,1319.86 1089.29,1319.86 1089.3,1319.86 1089.31,1319.86 1089.32,1319.86 1089.33,1319.86 1089.34,1319.86 1089.34,1319.86 1089.35,1319.86 1089.36,1319.86 1089.37,1319.86 1089.38,1319.86 1089.39,1319.87 1089.4,1319.87 1089.41,1319.87 1089.42,1319.87 1089.43,1319.87 1089.44,1319.87 1089.45,1319.87 1089.45,1319.87 1089.46,1319.87 1089.47,1319.87 1089.48,1319.87 1089.49,1319.87 1089.5,1319.87 1089.51,1319.87 1089.52,1319.87 1089.53,1319.87 1089.54,1319.87 1089.55,1319.88 1089.56,1319.88 1089.57,1319.88 1089.57,1319.88 1089.58,1319.88 1089.59,1319.88 1089.6,1319.88 1089.61,1319.88 1089.62,1319.88 1089.63,1319.88 1089.64,1319.88 1089.65,1319.88 1089.66,1319.88 1089.67,1319.88 1089.68,1319.88 1089.68,1319.88 1089.69,1319.89 1089.7,1319.89 1089.71,1319.89 1089.72,1319.89 1089.73,1319.89 1089.74,1319.89 1089.75,1319.89 1089.76,1319.89 1089.77,1319.89 1089.78,1319.89 1089.79,1319.89 1089.79,1319.89 1089.8,1319.89 1089.81,1319.89 1089.82,1319.89 1089.83,1319.89 1089.84,1319.89 1089.85,1319.9 1089.86,1319.9 1089.87,1319.9 1089.88,1319.9 1089.89,1319.9 1089.9,1319.9 1089.91,1319.9 1089.91,1319.9 1089.92,1319.9 1089.93,1319.9 1089.94,1319.9 1089.95,1319.9 1089.96,1319.9 1089.97,1319.9 1089.98,1319.9 1089.99,1319.9 1090,1319.9 1090.01,1319.91 1090.02,1319.91 1090.02,1319.91 1090.03,1319.91 1090.04,1319.91 1090.05,1319.91 1090.06,1319.91 1090.07,1319.91 1090.08,1319.91 1090.09,1319.91 1090.1,1319.91 1090.11,1319.91 1090.12,1319.91 1090.13,1319.91 1090.13,1319.91 1090.14,1319.91 1090.15,1319.91 1090.16,1319.92 1090.17,1319.92 1090.18,1319.92 1090.19,1319.92 1090.2,1319.92 1090.21,1319.92 1090.22,1319.92 1090.23,1319.92 1090.24,1319.92 1090.25,1319.92 1090.25,1319.92 1090.26,1319.92 1090.27,1319.92 1090.28,1319.92 1090.29,1319.92 1090.3,1319.92 1090.31,1319.93 1090.32,1319.93 1090.33,1319.93 1090.34,1319.93 1090.35,1319.93 1090.36,1319.93 1090.36,1319.93 1090.37,1319.93 1090.38,1319.93 1090.39,1319.93 1090.4,1319.93 1090.41,1319.93 1090.42,1319.93 1090.43,1319.93 1090.44,1319.93 1090.45,1319.93 1090.46,1319.93 1090.47,1319.94 1090.47,1319.94 1090.48,1319.94 1090.49,1319.94 1090.5,1319.94 1090.51,1319.94 1090.52,1319.94 1090.53,1319.94 1090.54,1319.94 1090.55,1319.94 1090.56,1319.94 1090.57,1319.94 1090.58,1319.94 1090.59,1319.94 1090.59,1319.94 1090.6,1319.94 1090.61,1319.94 1090.62,1319.95 1090.63,1319.95 1090.64,1319.95 1090.65,1319.95 1090.66,1319.95 1090.67,1319.95 1090.68,1319.95 1090.69,1319.95 1090.7,1319.95 1090.7,1319.95 1090.71,1319.95 1090.72,1319.95 1090.73,1319.95 1090.74,1319.95 1090.75,1319.95 1090.76,1319.95 1090.77,1319.95 1090.78,1319.96 1090.79,1319.96 1090.8,1319.96 1090.81,1319.96 1090.81,1319.96 1090.82,1319.96 1090.83,1319.96 1090.84,1319.96 1090.85,1319.96 1090.86,1319.96 1090.87,1319.96 1090.88,1319.96 1090.89,1319.96 1090.9,1319.96 1090.91,1319.96 1090.92,1319.96 1090.93,1319.97 1090.93,1319.97 1090.94,1319.97 1090.95,1319.97 1090.96,1319.97 1090.97,1319.97 1090.98,1319.97 1090.99,1319.97 1091,1319.97 1091.01,1319.97 1091.02,1319.97 1091.03,1319.97 1091.04,1319.97 1091.04,1319.97 1091.05,1319.97 1091.06,1319.97 1091.07,1319.97 1091.08,1319.98 1091.09,1319.98 1091.1,1319.98 1091.11,1319.98 1091.12,1319.98 1091.13,1319.98 1091.14,1319.98 1091.15,1319.98 1091.15,1319.98 1091.16,1319.98 1091.17,1319.98 1091.18,1319.98 1091.19,1319.98 1091.2,1319.98 1091.21,1319.98 1091.22,1319.98 1091.23,1319.98 1091.24,1319.99 1091.25,1319.99 1091.26,1319.99 1091.27,1319.99 1091.27,1319.99 1091.28,1319.99 1091.29,1319.99 1091.3,1319.99 1091.31,1319.99 1091.32,1319.99 1091.33,1319.99 1091.34,1319.99 1091.35,1319.99 1091.36,1319.99 1091.37,1319.99 1091.38,1319.99 1091.38,1319.99 1091.39,1320 1091.4,1320 1091.41,1320 1091.42,1320 1091.43,1320 1091.44,1320 1091.45,1320 1091.46,1320 1091.47,1320 1091.48,1320 1091.49,1320 1091.49,1320 1091.5,1320 1091.51,1320 1091.52,1320 1091.53,1320 1091.54,1320.01 1091.55,1320.01 1091.56,1320.01 1091.57,1320.01 1091.58,1320.01 1091.59,1320.01 1091.6,1320.01 1091.61,1320.01 1091.61,1320.01 1091.62,1320.01 1091.63,1320.01 1091.64,1320.01 1091.65,1320.01 1091.66,1320.01 1091.67,1320.01 1091.68,1320.01 1091.69,1320.01 1091.7,1320.02 1091.71,1320.02 1091.72,1320.02 1091.72,1320.02 1091.73,1320.02 1091.74,1320.02 1091.75,1320.02 1091.76,1320.02 1091.77,1320.02 1091.78,1320.02 1091.79,1320.02 1091.8,1320.02 1091.81,1320.02 1091.82,1320.02 1091.83,1320.02 1091.83,1320.02 1091.84,1320.02 1091.85,1320.03 1091.86,1320.03 1091.87,1320.03 1091.88,1320.03 1091.89,1320.03 1091.9,1320.03 1091.91,1320.03 1091.92,1320.03 1091.93,1320.03 1091.94,1320.03 1091.95,1320.03 1091.95,1320.03 1091.96,1320.03 1091.97,1320.03 1091.98,1320.03 1091.99,1320.03 1092,1320.03 1092.01,1320.04 1092.02,1320.04 1092.03,1320.04 1092.04,1320.04 1092.05,1320.04 1092.06,1320.04 1092.06,1320.04 1092.07,1320.04 1092.08,1320.04 1092.09,1320.04 1092.1,1320.04 1092.11,1320.04 1092.12,1320.04 1092.13,1320.04 1092.14,1320.04 1092.15,1320.04 1092.16,1320.05 1092.17,1320.05 1092.17,1320.05 1092.18,1320.05 1092.19,1320.05 1092.2,1320.05 1092.21,1320.05 1092.22,1320.05 1092.23,1320.05 1092.24,1320.05 1092.25,1320.05 1092.26,1320.05 1092.27,1320.05 1092.28,1320.05 1092.29,1320.05 1092.29,1320.05 1092.3,1320.05 1092.31,1320.06 1092.32,1320.06 1092.33,1320.06 1092.34,1320.06 1092.35,1320.06 1092.36,1320.06 1092.37,1320.06 1092.38,1320.06 1092.39,1320.06 1092.4,1320.06 1092.4,1320.06 1092.41,1320.06 1092.42,1320.06 1092.43,1320.06 1092.44,1320.06 1092.45,1320.06 1092.46,1320.06 1092.47,1320.07 1092.48,1320.07 1092.49,1320.07 1092.5,1320.07 1092.51,1320.07 1092.51,1320.07 1092.52,1320.07 1092.53,1320.07 1092.54,1320.07 1092.55,1320.07 1092.56,1320.07 1092.57,1320.07 1092.58,1320.07 1092.59,1320.07 1092.6,1320.07 1092.61,1320.07 1092.62,1320.07 1092.63,1320.08 1092.63,1320.08 1092.64,1320.08 1092.65,1320.08 1092.66,1320.08 1092.67,1320.08 1092.68,1320.08 1092.69,1320.08 1092.7,1320.08 1092.71,1320.08 1092.72,1320.08 1092.73,1320.08 1092.74,1320.08 1092.74,1320.08 1092.75,1320.08 1092.76,1320.08 1092.77,1320.09 1092.78,1320.09 1092.79,1320.09 1092.8,1320.09 1092.81,1320.09 1092.82,1320.09 1092.83,1320.09 1092.84,1320.09 1092.85,1320.09 1092.85,1320.09 1092.86,1320.09 1092.87,1320.09 1092.88,1320.09 1092.89,1320.09 1092.9,1320.09 1092.91,1320.09 1092.92,1320.09 1092.93,1320.1 1092.94,1320.1 1092.95,1320.1 1092.96,1320.1 1092.97,1320.1 1092.97,1320.1 1092.98,1320.1 1092.99,1320.1 1093,1320.1 1093.01,1320.1 1093.02,1320.1 1093.03,1320.1 1093.04,1320.1 1093.05,1320.1 1093.06,1320.1 1093.07,1320.1 1093.08,1320.1 1093.08,1320.11 1093.09,1320.11 1093.1,1320.11 1093.11,1320.11 1093.12,1320.11 1093.13,1320.11 1093.14,1320.11 1093.15,1320.11 1093.16,1320.11 1093.17,1320.11 1093.18,1320.11 1093.19,1320.11 1093.19,1320.11 1093.2,1320.11 1093.21,1320.11 1093.22,1320.11 1093.23,1320.11 1093.24,1320.12 1093.25,1320.12 1093.26,1320.12 1093.27,1320.12 1093.28,1320.12 1093.29,1320.12 1093.3,1320.12 1093.31,1320.12 1093.31,1320.12 1093.32,1320.12 1093.33,1320.12 1093.34,1320.12 1093.35,1320.12 1093.36,1320.12 1093.37,1320.12 1093.38,1320.12 1093.39,1320.12 1093.4,1320.13 1093.41,1320.13 1093.42,1320.13 1093.42,1320.13 1093.43,1320.13 1093.44,1320.13 1093.45,1320.13 1093.46,1320.13 1093.47,1320.13 1093.48,1320.13 1093.49,1320.13 1093.5,1320.13 1093.51,1320.13 1093.52,1320.13 1093.53,1320.13 1093.53,1320.13 1093.54,1320.14 1093.55,1320.14 1093.56,1320.14 1093.57,1320.14 1093.58,1320.14 1093.59,1320.14 1093.6,1320.14 1093.61,1320.14 1093.62,1320.14 1093.63,1320.14 1093.64,1320.14 1093.65,1320.14 1093.65,1320.14 1093.66,1320.14 1093.67,1320.14 1093.68,1320.14 1093.69,1320.14 1093.7,1320.15 1093.71,1320.15 1093.72,1320.15 1093.73,1320.15 1093.74,1320.15 1093.75,1320.15 1093.76,1320.15 1093.76,1320.15 1093.77,1320.15 1093.78,1320.15 1093.79,1320.15 1093.8,1320.15 1093.81,1320.15 1093.82,1320.15 1093.83,1320.15 1093.84,1320.15 1093.85,1320.15 1093.86,1320.16 1093.87,1320.16 1093.87,1320.16 1093.88,1320.16 1093.89,1320.16 1093.9,1320.16 1093.91,1320.16 1093.92,1320.16 1093.93,1320.16 1093.94,1320.16 1093.95,1320.16 1093.96,1320.16 1093.97,1320.16 1093.98,1320.16 1093.99,1320.16 1093.99,1320.16 1094,1320.16 1094.01,1320.17 1094.02,1320.17 1094.03,1320.17 1094.04,1320.17 1094.05,1320.17 1094.06,1320.17 1094.07,1320.17 1094.08,1320.17 1094.09,1320.17 1094.1,1320.17 1094.1,1320.17 1094.11,1320.17 1094.12,1320.17 1094.13,1320.17 1094.14,1320.17 1094.15,1320.17 1094.16,1320.18 1094.17,1320.18 1094.18,1320.18 1094.19,1320.18 1094.2,1320.18 1094.21,1320.18 1094.21,1320.18 1094.22,1320.18 1094.23,1320.18 1094.24,1320.18 1094.25,1320.18 1094.26,1320.18 1094.27,1320.18 1094.28,1320.18 1094.29,1320.18 1094.3,1320.18 1094.31,1320.18 1094.32,1320.19 1094.33,1320.19 1094.33,1320.19 1094.34,1320.19 1094.35,1320.19 1094.36,1320.19 1094.37,1320.19 1094.38,1320.19 1094.39,1320.19 1094.4,1320.19 1094.41,1320.19 1094.42,1320.19 1094.43,1320.19 1094.44,1320.19 1094.44,1320.19 1094.45,1320.19 1094.46,1320.19 1094.47,1320.2 1094.48,1320.2 1094.49,1320.2 1094.5,1320.2 1094.51,1320.2 1094.52,1320.2 1094.53,1320.2 1094.54,1320.2 1094.55,1320.2 1094.55,1320.2 1094.56,1320.2 1094.57,1320.2 1094.58,1320.2 1094.59,1320.2 1094.6,1320.2 1094.61,1320.2 1094.62,1320.2 1094.63,1320.21 1094.64,1320.21 1094.65,1320.21 1094.66,1320.21 1094.67,1320.21 1094.67,1320.21 1094.68,1320.21 1094.69,1320.21 1094.7,1320.21 1094.71,1320.21 1094.72,1320.21 1094.73,1320.21 1094.74,1320.21 1094.75,1320.21 1094.76,1320.21 1094.77,1320.21 1094.78,1320.21 1094.78,1320.22 1094.79,1320.22 1094.8,1320.22 1094.81,1320.22 1094.82,1320.22 1094.83,1320.22 1094.84,1320.22 1094.85,1320.22 1094.86,1320.22 1094.87,1320.22 1094.88,1320.22 1094.89,1320.22 1094.89,1320.22 1094.9,1320.22 1094.91,1320.22 1094.92,1320.22 1094.93,1320.23 1094.94,1320.23 1094.95,1320.23 1094.96,1320.23 1094.97,1320.23 1094.98,1320.23 1094.99,1320.23 1095,1320.23 1095.01,1320.23 1095.01,1320.23 1095.02,1320.23 1095.03,1320.23 1095.04,1320.23 1095.05,1320.23 1095.06,1320.23 1095.07,1320.23 1095.08,1320.23 1095.09,1320.24 1095.1,1320.24 1095.11,1320.24 1095.12,1320.24 1095.12,1320.24 1095.13,1320.24 1095.14,1320.24 1095.15,1320.24 1095.16,1320.24 1095.17,1320.24 1095.18,1320.24 1095.19,1320.24 1095.2,1320.24 1095.21,1320.24 1095.22,1320.24 1095.23,1320.24 1095.23,1320.24 1095.24,1320.25 1095.25,1320.25 1095.26,1320.25 1095.27,1320.25 1095.28,1320.25 1095.29,1320.25 1095.3,1320.25 1095.31,1320.25 1095.32,1320.25 1095.33,1320.25 1095.34,1320.25 1095.35,1320.25 1095.35,1320.25 1095.36,1320.25 1095.37,1320.25 1095.38,1320.25 1095.39,1320.25 1095.4,1320.26 1095.41,1320.26 1095.42,1320.26 1095.43,1320.26 1095.44,1320.26 1095.45,1320.26 1095.46,1320.26 1095.46,1320.26 1095.47,1320.26 1095.48,1320.26 1095.49,1320.26 1095.5,1320.26 1095.51,1320.26 1095.52,1320.26 1095.53,1320.26 1095.54,1320.26 1095.55,1320.26 1095.56,1320.27 1095.57,1320.27 1095.57,1320.27 1095.58,1320.27 1095.59,1320.27 1095.6,1320.27 1095.61,1320.27 1095.62,1320.27 1095.63,1320.27 1095.64,1320.27 1095.65,1320.27 1095.66,1320.27 1095.67,1320.27 1095.68,1320.27 1095.69,1320.27 1095.69,1320.27 1095.7,1320.28 1095.71,1320.28 1095.72,1320.28 1095.73,1320.28 1095.74,1320.28 1095.75,1320.28 1095.76,1320.28 1095.77,1320.28 1095.78,1320.28 1095.79,1320.28 1095.8,1320.28 1095.8,1320.28 1095.81,1320.28 1095.82,1320.28 1095.83,1320.28 1095.84,1320.28 1095.85,1320.28 1095.86,1320.29 1095.87,1320.29 1095.88,1320.29 1095.89,1320.29 1095.9,1320.29 1095.91,1320.29 1095.91,1320.29 1095.92,1320.29 1095.93,1320.29 1095.94,1320.29 1095.95,1320.29 1095.96,1320.29 1095.97,1320.29 1095.98,1320.29 1095.99,1320.29 1096,1320.29 1096.01,1320.29 1096.02,1320.3 1096.03,1320.3 1096.03,1320.3 1096.04,1320.3 1096.05,1320.3 1096.06,1320.3 1096.07,1320.3 1096.08,1320.3 1096.09,1320.3 1096.1,1320.3 1096.11,1320.3 1096.12,1320.3 1096.13,1320.3 1096.14,1320.3 1096.14,1320.3 1096.15,1320.3 1096.16,1320.3 1096.17,1320.31 1096.18,1320.31 1096.19,1320.31 1096.2,1320.31 1096.21,1320.31 1096.22,1320.31 1096.23,1320.31 1096.24,1320.31 1096.25,1320.31 1096.25,1320.31 1096.26,1320.31 1096.27,1320.31 1096.28,1320.31 1096.29,1320.31 1096.3,1320.31 1096.31,1320.31 1096.32,1320.31 1096.33,1320.32 1096.34,1320.32 1096.35,1320.32 1096.36,1320.32 1096.37,1320.32 1096.37,1320.32 1096.38,1320.32 1096.39,1320.32 1096.4,1320.32 1096.41,1320.32 1096.42,1320.32 1096.43,1320.32 1096.44,1320.32 1096.45,1320.32 1096.46,1320.32 1096.47,1320.32 1096.48,1320.33 1096.48,1320.33 1096.49,1320.33 1096.5,1320.33 1096.51,1320.33 1096.52,1320.33 1096.53,1320.33 1096.54,1320.33 1096.55,1320.33 1096.56,1320.33 1096.57,1320.33 1096.58,1320.33 1096.59,1320.33 1096.59,1320.33 1096.6,1320.33 1096.61,1320.33 1096.62,1320.33 1096.63,1320.34 1096.64,1320.34 1096.65,1320.34 1096.66,1320.34 1096.67,1320.34 1096.68,1320.34 1096.69,1320.34 1096.7,1320.34 1096.71,1320.34 1096.71,1320.34 1096.72,1320.34 1096.73,1320.34 1096.74,1320.34 1096.75,1320.34 1096.76,1320.34 1096.77,1320.34 1096.78,1320.34 1096.79,1320.35 1096.8,1320.35 1096.81,1320.35 1096.82,1320.35 1096.82,1320.35 1096.83,1320.35 1096.84,1320.35 1096.85,1320.35 1096.86,1320.35 1096.87,1320.35 1096.88,1320.35 1096.89,1320.35 1096.9,1320.35 1096.91,1320.35 1096.92,1320.35 1096.93,1320.35 1096.94,1320.35 1096.94,1320.36 1096.95,1320.36 1096.96,1320.36 1096.97,1320.36 1096.98,1320.36 1096.99,1320.36 1097,1320.36 1097.01,1320.36 1097.02,1320.36 1097.03,1320.36 1097.04,1320.36 1097.05,1320.36 1097.05,1320.36 1097.06,1320.36 1097.07,1320.36 1097.08,1320.36 1097.09,1320.36 1097.1,1320.37 1097.11,1320.37 1097.12,1320.37 1097.13,1320.37 1097.14,1320.37 1097.15,1320.37 1097.16,1320.37 1097.16,1320.37 1097.17,1320.37 1097.18,1320.37 1097.19,1320.37 1097.2,1320.37 1097.21,1320.37 1097.22,1320.37 1097.23,1320.37 1097.24,1320.37 1097.25,1320.38 1097.26,1320.38 1097.27,1320.38 1097.28,1320.38 1097.28,1320.38 1097.29,1320.38 1097.3,1320.38 1097.31,1320.38 1097.32,1320.38 1097.33,1320.38 1097.34,1320.38 1097.35,1320.38 1097.36,1320.38 1097.37,1320.38 1097.38,1320.38 1097.39,1320.38 1097.39,1320.38 1097.4,1320.39 1097.41,1320.39 1097.42,1320.39 1097.43,1320.39 1097.44,1320.39 1097.45,1320.39 1097.46,1320.39 1097.47,1320.39 1097.48,1320.39 1097.49,1320.39 1097.5,1320.39 1097.5,1320.39 1097.51,1320.39 1097.52,1320.39 1097.53,1320.39 1097.54,1320.39 1097.55,1320.39 1097.56,1320.4 1097.57,1320.4 1097.58,1320.4 1097.59,1320.4 1097.6,1320.4 1097.61,1320.4 1097.62,1320.4 1097.62,1320.4 1097.63,1320.4 1097.64,1320.4 1097.65,1320.4 1097.66,1320.4 1097.67,1320.4 1097.68,1320.4 1097.69,1320.4 1097.7,1320.4 1097.71,1320.4 1097.72,1320.41 1097.73,1320.41 1097.73,1320.41 1097.74,1320.41 1097.75,1320.41 1097.76,1320.41 1097.77,1320.41 1097.78,1320.41 1097.79,1320.41 1097.8,1320.41 1097.81,1320.41 1097.82,1320.41 1097.83,1320.41 1097.84,1320.41 1097.84,1320.41 1097.85,1320.41 1097.86,1320.41 1097.87,1320.42 1097.88,1320.42 1097.89,1320.42 1097.9,1320.42 1097.91,1320.42 1097.92,1320.42 1097.93,1320.42 1097.94,1320.42 1097.95,1320.42 1097.96,1320.42 1097.96,1320.42 1097.97,1320.42 1097.98,1320.42 1097.99,1320.42 1098,1320.42 1098.01,1320.42 1098.02,1320.43 1098.03,1320.43 1098.04,1320.43 1098.05,1320.43 1098.06,1320.43 1098.07,1320.43 1098.07,1320.43 1098.08,1320.43 1098.09,1320.43 1098.1,1320.43 1098.11,1320.43 1098.12,1320.43 1098.13,1320.43 1098.14,1320.43 1098.15,1320.43 1098.16,1320.43 1098.17,1320.43 1098.18,1320.44 1098.18,1320.44 1098.19,1320.44 1098.2,1320.44 1098.21,1320.44 1098.22,1320.44 1098.23,1320.44 1098.24,1320.44 1098.25,1320.44 1098.26,1320.44 1098.27,1320.44 1098.28,1320.44 1098.29,1320.44 1098.3,1320.44 1098.3,1320.44 1098.31,1320.44 1098.32,1320.44 1098.33,1320.45 1098.34,1320.45 1098.35,1320.45 1098.36,1320.45 1098.37,1320.45 1098.38,1320.45 1098.39,1320.45 1098.4,1320.45 1098.41,1320.45 1098.41,1320.45 1098.42,1320.45 1098.43,1320.45 1098.44,1320.45 1098.45,1320.45 1098.46,1320.45 1098.47,1320.45 1098.48,1320.45 1098.49,1320.46 1098.5,1320.46 1098.51,1320.46 1098.52,1320.46 1098.52,1320.46 1098.53,1320.46 1098.54,1320.46 1098.55,1320.46 1098.56,1320.46 1098.57,1320.46 1098.58,1320.46 1098.59,1320.46 1098.6,1320.46 1098.61,1320.46 1098.62,1320.46 1098.63,1320.46 1098.64,1320.46 1098.64,1320.47 1098.65,1320.47 1098.66,1320.47 1098.67,1320.47 1098.68,1320.47 1098.69,1320.47 1098.7,1320.47 1098.71,1320.47 1098.72,1320.47 1098.73,1320.47 1098.74,1320.47 1098.75,1320.47 1098.75,1320.47 1098.76,1320.47 1098.77,1320.47 1098.78,1320.47 1098.79,1320.47 1098.8,1320.48 1098.81,1320.48 1098.82,1320.48 1098.83,1320.48 1098.84,1320.48 1098.85,1320.48 1098.86,1320.48 1098.86,1320.48 1098.87,1320.48 1098.88,1320.48 1098.89,1320.48 1098.9,1320.48 1098.91,1320.48 1098.92,1320.48 1098.93,1320.48 1098.94,1320.48 1098.95,1320.49 1098.96,1320.49 1098.97,1320.49 1098.98,1320.49 1098.98,1320.49 1098.99,1320.49 1099,1320.49 1099.01,1320.49 1099.02,1320.49 1099.03,1320.49 1099.04,1320.49 1099.05,1320.49 1099.06,1320.49 1099.07,1320.49 1099.08,1320.49 1099.09,1320.49 1099.09,1320.49 1099.1,1320.5 1099.11,1320.5 1099.12,1320.5 1099.13,1320.5 1099.14,1320.5 1099.15,1320.5 1099.16,1320.5 1099.17,1320.5 1099.18,1320.5 1099.19,1320.5 1099.2,1320.5 1099.2,1320.5 1099.21,1320.5 1099.22,1320.5 1099.23,1320.5 1099.24,1320.5 1099.25,1320.5 1099.26,1320.51 1099.27,1320.51 1099.28,1320.51 1099.29,1320.51 1099.3,1320.51 1099.31,1320.51 1099.32,1320.51 1099.32,1320.51 1099.33,1320.51 1099.34,1320.51 1099.35,1320.51 1099.36,1320.51 1099.37,1320.51 1099.38,1320.51 1099.39,1320.51 1099.4,1320.51 1099.41,1320.51 1099.42,1320.52 1099.43,1320.52 1099.43,1320.52 1099.44,1320.52 1099.45,1320.52 1099.46,1320.52 1099.47,1320.52 1099.48,1320.52 1099.49,1320.52 1099.5,1320.52 1099.51,1320.52 1099.52,1320.52 1099.53,1320.52 1099.54,1320.52 1099.54,1320.52 1099.55,1320.52 1099.56,1320.52 1099.57,1320.53 1099.58,1320.53 1099.59,1320.53 1099.6,1320.53 1099.61,1320.53 1099.62,1320.53 1099.63,1320.53 1099.64,1320.53 1099.65,1320.53 1099.66,1320.53 1099.66,1320.53 1099.67,1320.53 1099.68,1320.53 1099.69,1320.53 1099.7,1320.53 1099.71,1320.53 1099.72,1320.53 1099.73,1320.54 1099.74,1320.54 1099.75,1320.54 1099.76,1320.54 1099.77,1320.54 1099.77,1320.54 1099.78,1320.54 1099.79,1320.54 1099.8,1320.54 1099.81,1320.54 1099.82,1320.54 1099.83,1320.54 1099.84,1320.54 1099.85,1320.54 1099.86,1320.54 1099.87,1320.54 1099.88,1320.55 1099.88,1320.55 1099.89,1320.55 1099.9,1320.55 1099.91,1320.55 1099.92,1320.55 1099.93,1320.55 1099.94,1320.55 1099.95,1320.55 1099.96,1320.55 1099.97,1320.55 1099.98,1320.55 1099.99,1320.55 1100,1320.55 1100,1320.55 1100.01,1320.55 1100.02,1320.55 1100.03,1320.56 1100.04,1320.56 1100.05,1320.56 1100.06,1320.56 1100.07,1320.56 1100.08,1320.56 1100.09,1320.56 1100.1,1320.56 1100.11,1320.56 1100.11,1320.56 1100.12,1320.56 1100.13,1320.56 1100.14,1320.56 1100.15,1320.56 1100.16,1320.56 1100.17,1320.56 1100.18,1320.56 1100.19,1320.57 1100.2,1320.57 1100.21,1320.57 1100.22,1320.57 1100.22,1320.57 1100.23,1320.57 1100.24,1320.57 1100.25,1320.57 1100.26,1320.57 1100.27,1320.57 1100.28,1320.57 1100.29,1320.57 1100.3,1320.57 1100.31,1320.57 1100.32,1320.57 1100.33,1320.57 1100.34,1320.57 1100.34,1320.58 1100.35,1320.58 1100.36,1320.58 1100.37,1320.58 1100.38,1320.58 1100.39,1320.58 1100.4,1320.58 1100.41,1320.58 1100.42,1320.58 1100.43,1320.58 1100.44,1320.58 1100.45,1320.58 1100.45,1320.58 1100.46,1320.58 1100.47,1320.58 1100.48,1320.58 1100.49,1320.58 1100.5,1320.59 1100.51,1320.59 1100.52,1320.59 1100.53,1320.59 1100.54,1320.59 1100.55,1320.59 1100.56,1320.59 1100.56,1320.59 1100.57,1320.59 1100.58,1320.59 1100.59,1320.59 1100.6,1320.59 1100.61,1320.59 1100.62,1320.59 1100.63,1320.59 1100.64,1320.59 1100.65,1320.59 1100.66,1320.6 1100.67,1320.6 1100.68,1320.6 1100.68,1320.6 1100.69,1320.6 1100.7,1320.6 1100.71,1320.6 1100.72,1320.6 1100.73,1320.6 1100.74,1320.6 1100.75,1320.6 1100.76,1320.6 1100.77,1320.6 1100.78,1320.6 1100.79,1320.6 1100.79,1320.6 1100.8,1320.6 1100.81,1320.61 1100.82,1320.61 1100.83,1320.61 1100.84,1320.61 1100.85,1320.61 1100.86,1320.61 1100.87,1320.61 1100.88,1320.61 1100.89,1320.61 1100.9,1320.61 1100.9,1320.61 1100.91,1320.61 1100.92,1320.61 1100.93,1320.61 1100.94,1320.61 1100.95,1320.61 1100.96,1320.62 1100.97,1320.62 1100.98,1320.62 1100.99,1320.62 1101,1320.62 1101.01,1320.62 1101.02,1320.62 1101.02,1320.62 1101.03,1320.62 1101.04,1320.62 1101.05,1320.62 1101.06,1320.62 1101.07,1320.62 1101.08,1320.62 1101.09,1320.62 1101.1,1320.62 1101.11,1320.62 1101.12,1320.63 1101.13,1320.63 1101.13,1320.63 1101.14,1320.63 1101.15,1320.63 1101.16,1320.63 1101.17,1320.63 1101.18,1320.63 1101.19,1320.63 1101.2,1320.63 1101.21,1320.63 1101.22,1320.63 1101.23,1320.63 1101.24,1320.63 1101.24,1320.63 1101.25,1320.63 1101.26,1320.63 1101.27,1320.64 1101.28,1320.64 1101.29,1320.64 1101.3,1320.64 1101.31,1320.64 1101.32,1320.64 1101.33,1320.64 1101.34,1320.64 1101.35,1320.64 1101.36,1320.64 1101.36,1320.64 1101.37,1320.64 1101.38,1320.64 1101.39,1320.64 1101.4,1320.64 1101.41,1320.64 1101.42,1320.64 1101.43,1320.65 1101.44,1320.65 1101.45,1320.65 1101.46,1320.65 1101.47,1320.65 1101.47,1320.65 1101.48,1320.65 1101.49,1320.65 1101.5,1320.65 1101.51,1320.65 1101.52,1320.65 1101.53,1320.65 1101.54,1320.65 1101.55,1320.65 1101.56,1320.65 1101.57,1320.65 1101.58,1320.65 1101.58,1320.66 1101.59,1320.66 1101.6,1320.66 1101.61,1320.66 1101.62,1320.66 1101.63,1320.66 1101.64,1320.66 1101.65,1320.66 1101.66,1320.66 1101.67,1320.66 1101.68,1320.66 1101.69,1320.66 1101.7,1320.66 1101.7,1320.66 1101.71,1320.66 1101.72,1320.66 1101.73,1320.66 1101.74,1320.67 1101.75,1320.67 1101.76,1320.67 1101.77,1320.67 1101.78,1320.67 1101.79,1320.67 1101.8,1320.67 1101.81,1320.67 1101.81,1320.67 1101.82,1320.67 1101.83,1320.67 1101.84,1320.67 1101.85,1320.67 1101.86,1320.67 1101.87,1320.67 1101.88,1320.67 1101.89,1320.67 1101.9,1320.68 1101.91,1320.68 1101.92,1320.68 1101.92,1320.68 1101.93,1320.68 1101.94,1320.68 1101.95,1320.68 1101.96,1320.68 1101.97,1320.68 1101.98,1320.68 1101.99,1320.68 1102,1320.68 1102.01,1320.68 1102.02,1320.68 1102.03,1320.68 1102.04,1320.68 1102.04,1320.69 1102.05,1320.69 1102.06,1320.69 1102.07,1320.69 1102.08,1320.69 1102.09,1320.69 1102.1,1320.69 1102.11,1320.69 1102.12,1320.69 1102.13,1320.69 1102.14,1320.69 1102.15,1320.69 1102.15,1320.69 1102.16,1320.69 1102.17,1320.69 1102.18,1320.69 1102.19,1320.69 1102.2,1320.7 1102.21,1320.7 1102.22,1320.7 1102.23,1320.7 1102.24,1320.7 1102.25,1320.7 1102.26,1320.7 1102.26,1320.7 1102.27,1320.7 1102.28,1320.7 1102.29,1320.7 1102.3,1320.7 1102.31,1320.7 1102.32,1320.7 1102.33,1320.7 1102.34,1320.7 1102.35,1320.7 1102.36,1320.71 1102.37,1320.71 1102.38,1320.71 1102.38,1320.71 1102.39,1320.71 1102.4,1320.71 1102.41,1320.71 1102.42,1320.71 1102.43,1320.71 1102.44,1320.71 1102.45,1320.71 1102.46,1320.71 1102.47,1320.71 1102.48,1320.71 1102.49,1320.71 1102.49,1320.71 1102.5,1320.71 1102.51,1320.72 1102.52,1320.72 1102.53,1320.72 1102.54,1320.72 1102.55,1320.72 1102.56,1320.72 1102.57,1320.72 1102.58,1320.72 1102.59,1320.72 1102.6,1320.72 1102.6,1320.72 1102.61,1320.72 1102.62,1320.72 1102.63,1320.72 1102.64,1320.72 1102.65,1320.72 1102.66,1320.72 1102.67,1320.73 1102.68,1320.73 1102.69,1320.73 1102.7,1320.73 1102.71,1320.73 1102.72,1320.73 1102.72,1320.73 1102.73,1320.73 1102.74,1320.73 1102.75,1320.73 1102.76,1320.73 1102.77,1320.73 1102.78,1320.73 1102.79,1320.73 1102.8,1320.73 1102.81,1320.73 1102.82,1320.73 1102.83,1320.74 1102.83,1320.74 1102.84,1320.74 1102.85,1320.74 1102.86,1320.74 1102.87,1320.74 1102.88,1320.74 1102.89,1320.74 1102.9,1320.74 1102.91,1320.74 1102.92,1320.74 1102.93,1320.74 1102.94,1320.74 1102.94,1320.74 1102.95,1320.74 1102.96,1320.74 1102.97,1320.74 1102.98,1320.75 1102.99,1320.75 1103,1320.75 1103.01,1320.75 1103.02,1320.75 1103.03,1320.75 1103.04,1320.75 1103.05,1320.75 1103.06,1320.75 1103.06,1320.75 1103.07,1320.75 1103.08,1320.75 1103.09,1320.75 1103.1,1320.75 1103.11,1320.75 1103.12,1320.75 1103.13,1320.76 1103.14,1320.76 1103.15,1320.76 1103.16,1320.76 1103.17,1320.76 1103.17,1320.76 1103.18,1320.76 1103.19,1320.76 1103.2,1320.76 1103.21,1320.76 1103.22,1320.76 1103.23,1320.76 1103.24,1320.76 1103.25,1320.76 1103.26,1320.76 1103.27,1320.76 1103.28,1320.76 1103.28,1320.77 1103.29,1320.77 1103.3,1320.77 1103.31,1320.77 1103.32,1320.77 1103.33,1320.77 1103.34,1320.77 1103.35,1320.77 1103.36,1320.77 1103.37,1320.77 1103.38,1320.77 1103.39,1320.77 1103.4,1320.77 1103.4,1320.77 1103.41,1320.77 1103.42,1320.77 1103.43,1320.77 1103.44,1320.78 1103.45,1320.78 1103.46,1320.78 1103.47,1320.78 1103.48,1320.78 1103.49,1320.78 1103.5,1320.78 1103.51,1320.78 1103.51,1320.78 1103.52,1320.78 1103.53,1320.78 1103.54,1320.78 1103.55,1320.78 1103.56,1320.78 1103.57,1320.78 1103.58,1320.78 1103.59,1320.78 1103.6,1320.79 1103.61,1320.79 1103.62,1320.79 1103.62,1320.79 1103.63,1320.79 1103.64,1320.79 1103.65,1320.79 1103.66,1320.79 1103.67,1320.79 1103.68,1320.79 1103.69,1320.79 1103.7,1320.79 1103.71,1320.79 1103.72,1320.79 1103.73,1320.79 1103.74,1320.79 1103.74,1320.79 1103.75,1320.8 1103.76,1320.8 1103.77,1320.8 1103.78,1320.8 1103.79,1320.8 1103.8,1320.8 1103.81,1320.8 1103.82,1320.8 1103.83,1320.8 1103.84,1320.8 1103.85,1320.8 1103.85,1320.8 1103.86,1320.8 1103.87,1320.8 1103.88,1320.8 1103.89,1320.8 1103.9,1320.8 1103.91,1320.81 1103.92,1320.81 1103.93,1320.81 1103.94,1320.81 1103.95,1320.81 1103.96,1320.81 1103.96,1320.81 1103.97,1320.81 1103.98,1320.81 1103.99,1320.81 1104,1320.81 1104.01,1320.81 1104.02,1320.81 1104.03,1320.81 1104.04,1320.81 1104.05,1320.81 1104.06,1320.81 1104.07,1320.82 1104.08,1320.82 1104.08,1320.82 1104.09,1320.82 1104.1,1320.82 1104.11,1320.82 1104.12,1320.82 1104.13,1320.82 1104.14,1320.82 1104.15,1320.82 1104.16,1320.82 1104.17,1320.82 1104.18,1320.82 1104.19,1320.82 1104.19,1320.82 1104.2,1320.82 1104.21,1320.82 1104.22,1320.83 1104.23,1320.83 1104.24,1320.83 1104.25,1320.83 1104.26,1320.83 1104.27,1320.83 1104.28,1320.83 1104.29,1320.83 1104.3,1320.83 1104.3,1320.83 1104.31,1320.83 1104.32,1320.83 1104.33,1320.83 1104.34,1320.83 1104.35,1320.83 1104.36,1320.83 1104.37,1320.83 1104.38,1320.84 1104.39,1320.84 1104.4,1320.84 1104.41,1320.84 1104.42,1320.84 1104.42,1320.84 1104.43,1320.84 1104.44,1320.84 1104.45,1320.84 1104.46,1320.84 1104.47,1320.84 1104.48,1320.84 1104.49,1320.84 1104.5,1320.84 1104.51,1320.84 1104.52,1320.84 1104.53,1320.85 1104.53,1320.85 1104.54,1320.85 1104.55,1320.85 1104.56,1320.85 1104.57,1320.85 1104.58,1320.85 1104.59,1320.85 1104.6,1320.85 1104.61,1320.85 1104.62,1320.85 1104.63,1320.85 1104.64,1320.85 1104.64,1320.85 1104.65,1320.85 1104.66,1320.85 1104.67,1320.85 1104.68,1320.86 1104.69,1320.86 1104.7,1320.86 1104.71,1320.86 1104.72,1320.86 1104.73,1320.86 1104.74,1320.86 1104.75,1320.86 1104.76,1320.86 1104.76,1320.86 1104.77,1320.86 1104.78,1320.86 1104.79,1320.86 1104.8,1320.86 1104.81,1320.86 1104.82,1320.86 1104.83,1320.86 1104.84,1320.87 1104.85,1320.87 1104.86,1320.87 1104.87,1320.87 1104.87,1320.87 1104.88,1320.87 1104.89,1320.87 1104.9,1320.87 1104.91,1320.87 1104.92,1320.87 1104.93,1320.87 1104.94,1320.87 1104.95,1320.87 1104.96,1320.87 1104.97,1320.87 1104.98,1320.87 1104.98,1320.87 1104.99,1320.88 1105,1320.88 1105.01,1320.88 1105.02,1320.88 1105.03,1320.88 1105.04,1320.88 1105.05,1320.88 1105.06,1320.88 1105.07,1320.88 1105.08,1320.88 1105.09,1320.88 1105.1,1320.88 1105.1,1320.88 1105.11,1320.88 1105.12,1320.88 1105.13,1320.88 1105.14,1320.88 1105.15,1320.89 1105.16,1320.89 1105.17,1320.89 1105.18,1320.89 1105.19,1320.89 1105.2,1320.89 1105.21,1320.89 1105.21,1320.89 1105.22,1320.89 1105.23,1320.89 1105.24,1320.89 1105.25,1320.89 1105.26,1320.89 1105.27,1320.89 1105.28,1320.89 1105.29,1320.89 1105.3,1320.89 1105.31,1320.9 1105.32,1320.9 1105.32,1320.9 1105.33,1320.9 1105.34,1320.9 1105.35,1320.9 1105.36,1320.9 1105.37,1320.9 1105.38,1320.9 1105.39,1320.9 1105.4,1320.9 1105.41,1320.9 1105.42,1320.9 1105.43,1320.9 1105.44,1320.9 1105.44,1320.9 1105.45,1320.9 1105.46,1320.91 1105.47,1320.91 1105.48,1320.91 1105.49,1320.91 1105.5,1320.91 1105.51,1320.91 1105.52,1320.91 1105.53,1320.91 1105.54,1320.91 1105.55,1320.91 1105.55,1320.91 1105.56,1320.91 1105.57,1320.91 1105.58,1320.91 1105.59,1320.91 1105.6,1320.91 1105.61,1320.91 1105.62,1320.92 1105.63,1320.92 1105.64,1320.92 1105.65,1320.92 1105.66,1320.92 1105.66,1320.92 1105.67,1320.92 1105.68,1320.92 1105.69,1320.92 1105.7,1320.92 1105.71,1320.92 1105.72,1320.92 1105.73,1320.92 1105.74,1320.92 1105.75,1320.92 1105.76,1320.92 1105.77,1320.92 1105.78,1320.93 1105.78,1320.93 1105.79,1320.93 1105.8,1320.93 1105.81,1320.93 1105.82,1320.93 1105.83,1320.93 1105.84,1320.93 1105.85,1320.93 1105.86,1320.93 1105.87,1320.93 1105.88,1320.93 1105.89,1320.93 1105.89,1320.93 1105.9,1320.93 1105.91,1320.93 1105.92,1320.93 1105.93,1320.94 1105.94,1320.94 1105.95,1320.94 1105.96,1320.94 1105.97,1320.94 1105.98,1320.94 1105.99,1320.94 1106,1320.94 1106,1320.94 1106.01,1320.94 1106.02,1320.94 1106.03,1320.94 1106.04,1320.94 1106.05,1320.94 1106.06,1320.94 1106.07,1320.94 1106.08,1320.95 1106.09,1320.95 1106.1,1320.95 1106.11,1320.95 1106.12,1320.95 1106.12,1320.95 1106.13,1320.95 1106.14,1320.95 1106.15,1320.95 1106.16,1320.95 1106.17,1320.95 1106.18,1320.95 1106.19,1320.95 1106.2,1320.95 1106.21,1320.95 1106.22,1320.95 1106.23,1320.95 1106.23,1320.96 1106.24,1320.96 1106.25,1320.96 1106.26,1320.96 1106.27,1320.96 1106.28,1320.96 1106.29,1320.96 1106.3,1320.96 1106.31,1320.96 1106.32,1320.96 1106.33,1320.96 1106.34,1320.96 1106.34,1320.96 1106.35,1320.96 1106.36,1320.96 1106.37,1320.96 1106.38,1320.96 1106.39,1320.97 1106.4,1320.97 1106.41,1320.97 1106.42,1320.97 1106.43,1320.97 1106.44,1320.97 1106.45,1320.97 1106.46,1320.97 1106.46,1320.97 1106.47,1320.97 1106.48,1320.97 1106.49,1320.97 1106.5,1320.97 1106.51,1320.97 1106.52,1320.97 1106.53,1320.97 1106.54,1320.97 1106.55,1320.98 1106.56,1320.98 1106.57,1320.98 1106.57,1320.98 1106.58,1320.98 1106.59,1320.98 1106.6,1320.98 1106.61,1320.98 1106.62,1320.98 1106.63,1320.98 1106.64,1320.98 1106.65,1320.98 1106.66,1320.98 1106.67,1320.98 1106.68,1320.98 1106.68,1320.98 1106.69,1320.98 1106.7,1320.99 1106.71,1320.99 1106.72,1320.99 1106.73,1320.99 1106.74,1320.99 1106.75,1320.99 1106.76,1320.99 1106.77,1320.99 1106.78,1320.99 1106.79,1320.99 1106.8,1320.99 1106.8,1320.99 1106.81,1320.99 1106.82,1320.99 1106.83,1320.99 1106.84,1320.99 1106.85,1320.99 1106.86,1321 1106.87,1321 1106.88,1321 1106.89,1321 1106.9,1321 1106.91,1321 1106.91,1321 1106.92,1321 1106.93,1321 1106.94,1321 1106.95,1321 1106.96,1321 1106.97,1321 1106.98,1321 1106.99,1321 1107,1321 1107.01,1321 1107.02,1321.01 1107.02,1321.01 1107.03,1321.01 1107.04,1321.01 1107.05,1321.01 1107.06,1321.01 1107.07,1321.01 1107.08,1321.01 1107.09,1321.01 1107.1,1321.01 1107.11,1321.01 1107.12,1321.01 1107.13,1321.01 1107.14,1321.01 1107.14,1321.01 1107.15,1321.01 1107.16,1321.01 1107.17,1321.02 1107.18,1321.02 1107.19,1321.02 1107.2,1321.02 1107.21,1321.02 1107.22,1321.02 1107.23,1321.02 1107.24,1321.02 1107.25,1321.02 1107.25,1321.02 1107.26,1321.02 1107.27,1321.02 1107.28,1321.02 1107.29,1321.02 1107.3,1321.02 1107.31,1321.02 1107.32,1321.02 1107.33,1321.03 1107.34,1321.03 1107.35,1321.03 1107.36,1321.03 1107.36,1321.03 1107.37,1321.03 1107.38,1321.03 1107.39,1321.03 1107.4,1321.03 1107.41,1321.03 1107.42,1321.03 1107.43,1321.03 1107.44,1321.03 1107.45,1321.03 1107.46,1321.03 1107.47,1321.03 1107.48,1321.03 1107.48,1321.04 1107.49,1321.04 1107.5,1321.04 1107.51,1321.04 1107.52,1321.04 1107.53,1321.04 1107.54,1321.04 1107.55,1321.04 1107.56,1321.04 1107.57,1321.04 1107.58,1321.04 1107.59,1321.04 1107.59,1321.04 1107.6,1321.04 1107.61,1321.04 1107.62,1321.04 1107.63,1321.04 1107.64,1321.05 1107.65,1321.05 1107.66,1321.05 1107.67,1321.05 1107.68,1321.05 1107.69,1321.05 1107.7,1321.05 1107.7,1321.05 1107.71,1321.05 1107.72,1321.05 1107.73,1321.05 1107.74,1321.05 1107.75,1321.05 1107.76,1321.05 1107.77,1321.05 1107.78,1321.05 1107.79,1321.05 1107.8,1321.06 1107.81,1321.06 1107.82,1321.06 1107.82,1321.06 1107.83,1321.06 1107.84,1321.06 1107.85,1321.06 1107.86,1321.06 1107.87,1321.06 1107.88,1321.06 1107.89,1321.06 1107.9,1321.06 1107.91,1321.06 1107.92,1321.06 1107.93,1321.06 1107.93,1321.06 1107.94,1321.07 1107.95,1321.07 1107.96,1321.07 1107.97,1321.07 1107.98,1321.07 1107.99,1321.07 1108,1321.07 1108.01,1321.07 1108.02,1321.07 1108.03,1321.07 1108.04,1321.07 1108.04,1321.07 1108.05,1321.07 1108.06,1321.07 1108.07,1321.07 1108.08,1321.07 1108.09,1321.07 1108.1,1321.08 1108.11,1321.08 1108.12,1321.08 1108.13,1321.08 1108.14,1321.08 1108.15,1321.08 1108.16,1321.08 1108.16,1321.08 1108.17,1321.08 1108.18,1321.08 1108.19,1321.08 1108.2,1321.08 1108.21,1321.08 1108.22,1321.08 1108.23,1321.08 1108.24,1321.08 1108.25,1321.08 1108.26,1321.09 1108.27,1321.09 1108.27,1321.09 1108.28,1321.09 1108.29,1321.09 1108.3,1321.09 1108.31,1321.09 1108.32,1321.09 1108.33,1321.09 1108.34,1321.09 1108.35,1321.09 1108.36,1321.09 1108.37,1321.09 1108.38,1321.09 1108.38,1321.09 1108.39,1321.09 1108.4,1321.09 1108.41,1321.1 1108.42,1321.1 1108.43,1321.1 1108.44,1321.1 1108.45,1321.1 1108.46,1321.1 1108.47,1321.1 1108.48,1321.1 1108.49,1321.1 1108.5,1321.1 1108.5,1321.1 1108.51,1321.1 1108.52,1321.1 1108.53,1321.1 1108.54,1321.1 1108.55,1321.1 1108.56,1321.1 1108.57,1321.11 1108.58,1321.11 1108.59,1321.11 1108.6,1321.11 1108.61,1321.11 1108.61,1321.11 1108.62,1321.11 1108.63,1321.11 1108.64,1321.11 1108.65,1321.11 1108.66,1321.11 1108.67,1321.11 1108.68,1321.11 1108.69,1321.11 1108.7,1321.11 1108.71,1321.11 1108.72,1321.11 1108.72,1321.12 1108.73,1321.12 1108.74,1321.12 1108.75,1321.12 1108.76,1321.12 1108.77,1321.12 1108.78,1321.12 1108.79,1321.12 1108.8,1321.12 1108.81,1321.12 1108.82,1321.12 1108.83,1321.12 1108.84,1321.12 1108.84,1321.12 1108.85,1321.12 1108.86,1321.12 1108.87,1321.12 1108.88,1321.13 1108.89,1321.13 1108.9,1321.13 1108.91,1321.13 1108.92,1321.13 1108.93,1321.13 1108.94,1321.13 1108.95,1321.13 1108.95,1321.13 1108.96,1321.13 1108.97,1321.13 1108.98,1321.13 1108.99,1321.13 1109,1321.13 1109.01,1321.13 1109.02,1321.13 1109.03,1321.13 1109.04,1321.14 1109.05,1321.14 1109.06,1321.14 1109.06,1321.14 1109.07,1321.14 1109.08,1321.14 1109.09,1321.14 1109.1,1321.14 1109.11,1321.14 1109.12,1321.14 1109.13,1321.14 1109.14,1321.14 1109.15,1321.14 1109.16,1321.14 1109.17,1321.14 1109.18,1321.14 1109.18,1321.14 1109.19,1321.15 1109.2,1321.15 1109.21,1321.15 1109.22,1321.15 1109.23,1321.15 1109.24,1321.15 1109.25,1321.15 1109.26,1321.15 1109.27,1321.15 1109.28,1321.15 1109.29,1321.15 1109.29,1321.15 1109.3,1321.15 1109.31,1321.15 1109.32,1321.15 1109.33,1321.15 1109.34,1321.15 1109.35,1321.16 1109.36,1321.16 1109.37,1321.16 1109.38,1321.16 1109.39,1321.16 1109.4,1321.16 1109.4,1321.16 1109.41,1321.16 1109.42,1321.16 1109.43,1321.16 1109.44,1321.16 1109.45,1321.16 1109.46,1321.16 1109.47,1321.16 1109.48,1321.16 1109.49,1321.16 1109.5,1321.16 1109.51,1321.17 1109.52,1321.17 1109.52,1321.17 1109.53,1321.17 1109.54,1321.17 1109.55,1321.17 1109.56,1321.17 1109.57,1321.17 1109.58,1321.17 1109.59,1321.17 1109.6,1321.17 1109.61,1321.17 1109.62,1321.17 1109.63,1321.17 1109.63,1321.17 1109.64,1321.17 1109.65,1321.17 1109.66,1321.18 1109.67,1321.18 1109.68,1321.18 1109.69,1321.18 1109.7,1321.18 1109.71,1321.18 1109.72,1321.18 1109.73,1321.18 1109.74,1321.18 1109.74,1321.18 1109.75,1321.18 1109.76,1321.18 1109.77,1321.18 1109.78,1321.18 1109.79,1321.18 1109.8,1321.18 1109.81,1321.18 1109.82,1321.19 1109.83,1321.19 1109.84,1321.19 1109.85,1321.19 1109.86,1321.19 1109.86,1321.19 1109.87,1321.19 1109.88,1321.19 1109.89,1321.19 1109.9,1321.19 1109.91,1321.19 1109.92,1321.19 1109.93,1321.19 1109.94,1321.19 1109.95,1321.19 1109.96,1321.19 1109.97,1321.19 1109.97,1321.2 1109.98,1321.2 1109.99,1321.2 1110,1321.2 1110.01,1321.2 1110.02,1321.2 1110.03,1321.2 1110.04,1321.2 1110.05,1321.2 1110.06,1321.2 1110.07,1321.2 1110.08,1321.2 1110.08,1321.2 1110.09,1321.2 1110.1,1321.2 1110.11,1321.2 1110.12,1321.2 1110.13,1321.21 1110.14,1321.21 1110.15,1321.21 1110.16,1321.21 1110.17,1321.21 1110.18,1321.21 1110.19,1321.21 1110.2,1321.21 1110.2,1321.21 1110.21,1321.21 1110.22,1321.21 1110.23,1321.21 1110.24,1321.21 1110.25,1321.21 1110.26,1321.21 1110.27,1321.21 1110.28,1321.21 1110.29,1321.22 1110.3,1321.22 1110.31,1321.22 1110.31,1321.22 1110.32,1321.22 1110.33,1321.22 1110.34,1321.22 1110.35,1321.22 1110.36,1321.22 1110.37,1321.22 1110.38,1321.22 1110.39,1321.22 1110.4,1321.22 1110.41,1321.22 1110.42,1321.22 1110.42,1321.22 1110.43,1321.23 1110.44,1321.23 1110.45,1321.23 1110.46,1321.23 1110.47,1321.23 1110.48,1321.23 1110.49,1321.23 1110.5,1321.23 1110.51,1321.23 1110.52,1321.23 1110.53,1321.23 1110.54,1321.23 1110.54,1321.23 1110.55,1321.23 1110.56,1321.23 1110.57,1321.23 1110.58,1321.23 1110.59,1321.24 1110.6,1321.24 1110.61,1321.24 1110.62,1321.24 1110.63,1321.24 1110.64,1321.24 1110.65,1321.24 1110.65,1321.24 1110.66,1321.24 1110.67,1321.24 1110.68,1321.24 1110.69,1321.24 1110.7,1321.24 1110.71,1321.24 1110.72,1321.24 1110.73,1321.24 1110.74,1321.24 1110.75,1321.25 1110.76,1321.25 1110.76,1321.25 1110.77,1321.25 1110.78,1321.25 1110.79,1321.25 1110.8,1321.25 1110.81,1321.25 1110.82,1321.25 1110.83,1321.25 1110.84,1321.25 1110.85,1321.25 1110.86,1321.25 1110.87,1321.25 1110.88,1321.25 1110.88,1321.25 1110.89,1321.25 1110.9,1321.26 1110.91,1321.26 1110.92,1321.26 1110.93,1321.26 1110.94,1321.26 1110.95,1321.26 1110.96,1321.26 1110.97,1321.26 1110.98,1321.26 1110.99,1321.26 1110.99,1321.26 1111,1321.26 1111.01,1321.26 1111.02,1321.26 1111.03,1321.26 1111.04,1321.26 1111.05,1321.26 1111.06,1321.27 1111.07,1321.27 1111.08,1321.27 1111.09,1321.27 1111.1,1321.27 1111.1,1321.27 1111.11,1321.27 1111.12,1321.27 1111.13,1321.27 1111.14,1321.27 1111.15,1321.27 1111.16,1321.27 1111.17,1321.27 1111.18,1321.27 1111.19,1321.27 1111.2,1321.27 1111.21,1321.27 1111.22,1321.28 1111.22,1321.28 1111.23,1321.28 1111.24,1321.28 1111.25,1321.28 1111.26,1321.28 1111.27,1321.28 1111.28,1321.28 1111.29,1321.28 1111.3,1321.28 1111.31,1321.28 1111.32,1321.28 1111.33,1321.28 1111.33,1321.28 1111.34,1321.28 1111.35,1321.28 1111.36,1321.28 1111.37,1321.29 1111.38,1321.29 1111.39,1321.29 1111.4,1321.29 1111.41,1321.29 1111.42,1321.29 1111.43,1321.29 1111.44,1321.29 1111.44,1321.29 1111.45,1321.29 1111.46,1321.29 1111.47,1321.29 1111.48,1321.29 1111.49,1321.29 1111.5,1321.29 1111.51,1321.29 1111.52,1321.29 1111.53,1321.3 1111.54,1321.3 1111.55,1321.3 1111.56,1321.3 1111.56,1321.3 1111.57,1321.3 1111.58,1321.3 1111.59,1321.3 1111.6,1321.3 1111.61,1321.3 1111.62,1321.3 1111.63,1321.3 1111.64,1321.3 1111.65,1321.3 1111.66,1321.3 1111.67,1321.3 1111.67,1321.3 1111.68,1321.31 1111.69,1321.31 1111.7,1321.31 1111.71,1321.31 1111.72,1321.31 1111.73,1321.31 1111.74,1321.31 1111.75,1321.31 1111.76,1321.31 1111.77,1321.31 1111.78,1321.31 1111.78,1321.31 1111.79,1321.31 1111.8,1321.31 1111.81,1321.31 1111.82,1321.31 1111.83,1321.31 1111.84,1321.32 1111.85,1321.32 1111.86,1321.32 1111.87,1321.32 1111.88,1321.32 1111.89,1321.32 1111.9,1321.32 1111.9,1321.32 1111.91,1321.32 1111.92,1321.32 1111.93,1321.32 1111.94,1321.32 1111.95,1321.32 1111.96,1321.32 1111.97,1321.32 1111.98,1321.32 1111.99,1321.32 1112,1321.33 1112.01,1321.33 1112.01,1321.33 1112.02,1321.33 1112.03,1321.33 1112.04,1321.33 1112.05,1321.33 1112.06,1321.33 1112.07,1321.33 1112.08,1321.33 1112.09,1321.33 1112.1,1321.33 1112.11,1321.33 1112.12,1321.33 1112.12,1321.33 1112.13,1321.33 1112.14,1321.33 1112.15,1321.34 1112.16,1321.34 1112.17,1321.34 1112.18,1321.34 1112.19,1321.34 1112.2,1321.34 1112.21,1321.34 1112.22,1321.34 1112.23,1321.34 1112.24,1321.34 1112.24,1321.34 1112.25,1321.34 1112.26,1321.34 1112.27,1321.34 1112.28,1321.34 1112.29,1321.34 1112.3,1321.34 1112.31,1321.35 1112.32,1321.35 1112.33,1321.35 1112.34,1321.35 1112.35,1321.35 1112.35,1321.35 1112.36,1321.35 1112.37,1321.35 1112.38,1321.35 1112.39,1321.35 1112.4,1321.35 1112.41,1321.35 1112.42,1321.35 1112.43,1321.35 1112.44,1321.35 1112.45,1321.35 1112.46,1321.35 1112.46,1321.36 1112.47,1321.36 1112.48,1321.36 1112.49,1321.36 1112.5,1321.36 1112.51,1321.36 1112.52,1321.36 1112.53,1321.36 1112.54,1321.36 1112.55,1321.36 1112.56,1321.36 1112.57,1321.36 1112.58,1321.36 1112.58,1321.36 1112.59,1321.36 1112.6,1321.36 1112.61,1321.36 1112.62,1321.37 1112.63,1321.37 1112.64,1321.37 1112.65,1321.37 1112.66,1321.37 1112.67,1321.37 1112.68,1321.37 1112.69,1321.37 1112.69,1321.37 1112.7,1321.37 1112.71,1321.37 1112.72,1321.37 1112.73,1321.37 1112.74,1321.37 1112.75,1321.37 1112.76,1321.37 1112.77,1321.37 1112.78,1321.38 1112.79,1321.38 1112.8,1321.38 1112.8,1321.38 1112.81,1321.38 1112.82,1321.38 1112.83,1321.38 1112.84,1321.38 1112.85,1321.38 1112.86,1321.38 1112.87,1321.38 1112.88,1321.38 1112.89,1321.38 1112.9,1321.38 1112.91,1321.38 1112.92,1321.38 1112.92,1321.38 1112.93,1321.39 1112.94,1321.39 1112.95,1321.39 1112.96,1321.39 1112.97,1321.39 1112.98,1321.39 1112.99,1321.39 1113,1321.39 1113.01,1321.39 1113.02,1321.39 1113.03,1321.39 1113.03,1321.39 1113.04,1321.39 1113.05,1321.39 1113.06,1321.39 1113.07,1321.39 1113.08,1321.39 1113.09,1321.4 1113.1,1321.4 1113.11,1321.4 1113.12,1321.4 1113.13,1321.4 1113.14,1321.4 1113.14,1321.4 1113.15,1321.4 1113.16,1321.4 1113.17,1321.4 1113.18,1321.4 1113.19,1321.4 1113.2,1321.4 1113.21,1321.4 1113.22,1321.4 1113.23,1321.4 1113.24,1321.4 1113.25,1321.41 1113.26,1321.41 1113.26,1321.41 1113.27,1321.41 1113.28,1321.41 1113.29,1321.41 1113.3,1321.41 1113.31,1321.41 1113.32,1321.41 1113.33,1321.41 1113.34,1321.41 1113.35,1321.41 1113.36,1321.41 1113.37,1321.41 1113.37,1321.41 1113.38,1321.41 1113.39,1321.41 1113.4,1321.42 1113.41,1321.42 1113.42,1321.42 1113.43,1321.42 1113.44,1321.42 1113.45,1321.42 1113.46,1321.42 1113.47,1321.42 1113.48,1321.42 1113.48,1321.42 1113.49,1321.42 1113.5,1321.42 1113.51,1321.42 1113.52,1321.42 1113.53,1321.42 1113.54,1321.42 1113.55,1321.42 1113.56,1321.43 1113.57,1321.43 1113.58,1321.43 1113.59,1321.43 1113.6,1321.43 1113.6,1321.43 1113.61,1321.43 1113.62,1321.43 1113.63,1321.43 1113.64,1321.43 1113.65,1321.43 1113.66,1321.43 1113.67,1321.43 1113.68,1321.43 1113.69,1321.43 1113.7,1321.43 1113.71,1321.43 1113.71,1321.44 1113.72,1321.44 1113.73,1321.44 1113.74,1321.44 1113.75,1321.44 1113.76,1321.44 1113.77,1321.44 1113.78,1321.44 1113.79,1321.44 1113.8,1321.44 1113.81,1321.44 1113.82,1321.44 1113.82,1321.44 1113.83,1321.44 1113.84,1321.44 1113.85,1321.44 1113.86,1321.44 1113.87,1321.45 1113.88,1321.45 1113.89,1321.45 1113.9,1321.45 1113.91,1321.45 1113.92,1321.45 1113.93,1321.45 1113.94,1321.45 1113.94,1321.45 1113.95,1321.45 1113.96,1321.45 1113.97,1321.45 1113.98,1321.45 1113.99,1321.45 1114,1321.45 1114.01,1321.45 1114.02,1321.45 1114.03,1321.46 1114.04,1321.46 1114.05,1321.46 1114.05,1321.46 1114.06,1321.46 1114.07,1321.46 1114.08,1321.46 1114.09,1321.46 1114.1,1321.46 1114.11,1321.46 1114.12,1321.46 1114.13,1321.46 1114.14,1321.46 1114.15,1321.46 1114.16,1321.46 1114.16,1321.46 1114.17,1321.46 1114.18,1321.47 1114.19,1321.47 1114.2,1321.47 1114.21,1321.47 1114.22,1321.47 1114.23,1321.47 1114.24,1321.47 1114.25,1321.47 1114.26,1321.47 1114.27,1321.47 1114.28,1321.47 1114.28,1321.47 1114.29,1321.47 1114.3,1321.47 1114.31,1321.47 1114.32,1321.47 1114.33,1321.47 1114.34,1321.48 1114.35,1321.48 1114.36,1321.48 1114.37,1321.48 1114.38,1321.48 1114.39,1321.48 1114.39,1321.48 1114.4,1321.48 1114.41,1321.48 1114.42,1321.48 1114.43,1321.48 1114.44,1321.48 1114.45,1321.48 1114.46,1321.48 1114.47,1321.48 1114.48,1321.48 1114.49,1321.48 1114.5,1321.49 1114.5,1321.49 1114.51,1321.49 1114.52,1321.49 1114.53,1321.49 1114.54,1321.49 1114.55,1321.49 1114.56,1321.49 1114.57,1321.49 1114.58,1321.49 1114.59,1321.49 1114.6,1321.49 1114.61,1321.49 1114.62,1321.49 1114.62,1321.49 1114.63,1321.49 1114.64,1321.49 1114.65,1321.5 1114.66,1321.5 1114.67,1321.5 1114.68,1321.5 1114.69,1321.5 1114.7,1321.5 1114.71,1321.5 1114.72,1321.5 1114.73,1321.5 1114.73,1321.5 1114.74,1321.5 1114.75,1321.5 1114.76,1321.5 1114.77,1321.5 1114.78,1321.5 1114.79,1321.5 1114.8,1321.5 1114.81,1321.51 1114.82,1321.51 1114.83,1321.51 1114.84,1321.51 1114.84,1321.51 1114.85,1321.51 1114.86,1321.51 1114.87,1321.51 1114.88,1321.51 1114.89,1321.51 1114.9,1321.51 1114.91,1321.51 1114.92,1321.51 1114.93,1321.51 1114.94,1321.51 1114.95,1321.51 1114.96,1321.51 1114.96,1321.52 1114.97,1321.52 1114.98,1321.52 1114.99,1321.52 1115,1321.52 1115.01,1321.52 1115.02,1321.52 1115.03,1321.52 1115.04,1321.52 1115.05,1321.52 1115.06,1321.52 1115.07,1321.52 1115.07,1321.52 1115.08,1321.52 1115.09,1321.52 1115.1,1321.52 1115.11,1321.52 1115.12,1321.53 1115.13,1321.53 1115.14,1321.53 1115.15,1321.53 1115.16,1321.53 1115.17,1321.53 1115.18,1321.53 1115.18,1321.53 1115.19,1321.53 1115.2,1321.53 1115.21,1321.53 1115.22,1321.53 1115.23,1321.53 1115.24,1321.53 1115.25,1321.53 1115.26,1321.53 1115.27,1321.53 1115.28,1321.54 1115.29,1321.54 1115.3,1321.54 1115.3,1321.54 1115.31,1321.54 1115.32,1321.54 1115.33,1321.54 1115.34,1321.54 1115.35,1321.54 1115.36,1321.54 1115.37,1321.54 1115.38,1321.54 1115.39,1321.54 1115.4,1321.54 1115.41,1321.54 1115.41,1321.54 1115.42,1321.54 1115.43,1321.55 1115.44,1321.55 1115.45,1321.55 1115.46,1321.55 1115.47,1321.55 1115.48,1321.55 1115.49,1321.55 1115.5,1321.55 1115.51,1321.55 1115.52,1321.55 1115.52,1321.55 1115.53,1321.55 1115.54,1321.55 1115.55,1321.55 1115.56,1321.55 1115.57,1321.55 1115.58,1321.55 1115.59,1321.56 1115.6,1321.56 1115.61,1321.56 1115.62,1321.56 1115.63,1321.56 1115.64,1321.56 1115.64,1321.56 1115.65,1321.56 1115.66,1321.56 1115.67,1321.56 1115.68,1321.56 1115.69,1321.56 1115.7,1321.56 1115.71,1321.56 1115.72,1321.56 1115.73,1321.56 1115.74,1321.56 1115.75,1321.57 1115.75,1321.57 1115.76,1321.57 1115.77,1321.57 1115.78,1321.57 1115.79,1321.57 1115.8,1321.57 1115.81,1321.57 1115.82,1321.57 1115.83,1321.57 1115.84,1321.57 1115.85,1321.57 1115.86,1321.57 1115.86,1321.57 1115.87,1321.57 1115.88,1321.57 1115.89,1321.57 1115.9,1321.58 1115.91,1321.58 1115.92,1321.58 1115.93,1321.58 1115.94,1321.58 1115.95,1321.58 1115.96,1321.58 1115.97,1321.58 1115.98,1321.58 1115.98,1321.58 1115.99,1321.58 1116,1321.58 1116.01,1321.58 1116.02,1321.58 1116.03,1321.58 1116.04,1321.58 1116.05,1321.58 1116.06,1321.59 1116.07,1321.59 1116.08,1321.59 1116.09,1321.59 1116.09,1321.59 1116.1,1321.59 1116.11,1321.59 1116.12,1321.59 1116.13,1321.59 1116.14,1321.59 1116.15,1321.59 1116.16,1321.59 1116.17,1321.59 1116.18,1321.59 1116.19,1321.59 1116.2,1321.59 1116.2,1321.59 1116.21,1321.6 1116.22,1321.6 1116.23,1321.6 1116.24,1321.6 1116.25,1321.6 1116.26,1321.6 1116.27,1321.6 1116.28,1321.6 1116.29,1321.6 1116.3,1321.6 1116.31,1321.6 1116.32,1321.6 1116.32,1321.6 1116.33,1321.6 1116.34,1321.6 1116.35,1321.6 1116.36,1321.6 1116.37,1321.61 1116.38,1321.61 1116.39,1321.61 1116.4,1321.61 1116.41,1321.61 1116.42,1321.61 1116.43,1321.61 1116.43,1321.61 1116.44,1321.61 1116.45,1321.61 1116.46,1321.61 1116.47,1321.61 1116.48,1321.61 1116.49,1321.61 1116.5,1321.61 1116.51,1321.61 1116.52,1321.61 1116.53,1321.62 1116.54,1321.62 1116.54,1321.62 1116.55,1321.62 1116.56,1321.62 1116.57,1321.62 1116.58,1321.62 1116.59,1321.62 1116.6,1321.62 1116.61,1321.62 1116.62,1321.62 1116.63,1321.62 1116.64,1321.62 1116.65,1321.62 1116.66,1321.62 1116.66,1321.62 1116.67,1321.62 1116.68,1321.63 1116.69,1321.63 1116.7,1321.63 1116.71,1321.63 1116.72,1321.63 1116.73,1321.63 1116.74,1321.63 1116.75,1321.63 1116.76,1321.63 1116.77,1321.63 1116.77,1321.63 1116.78,1321.63 1116.79,1321.63 1116.8,1321.63 1116.81,1321.63 1116.82,1321.63 1116.83,1321.63 1116.84,1321.64 1116.85,1321.64 1116.86,1321.64 1116.87,1321.64 1116.88,1321.64 1116.88,1321.64 1116.89,1321.64 1116.9,1321.64 1116.91,1321.64 1116.92,1321.64 1116.93,1321.64 1116.94,1321.64 1116.95,1321.64 1116.96,1321.64 1116.97,1321.64 1116.98,1321.64 1116.99,1321.64 1117,1321.65 1117,1321.65 1117.01,1321.65 1117.02,1321.65 1117.03,1321.65 1117.04,1321.65 1117.05,1321.65 1117.06,1321.65 1117.07,1321.65 1117.08,1321.65 1117.09,1321.65 1117.1,1321.65 1117.11,1321.65 1117.11,1321.65 1117.12,1321.65 1117.13,1321.65 1117.14,1321.65 1117.15,1321.66 1117.16,1321.66 1117.17,1321.66 1117.18,1321.66 1117.19,1321.66 1117.2,1321.66 1117.21,1321.66 1117.22,1321.66 1117.22,1321.66 1117.23,1321.66 1117.24,1321.66 1117.25,1321.66 1117.26,1321.66 1117.27,1321.66 1117.28,1321.66 1117.29,1321.66 1117.3,1321.66 1117.31,1321.67 1117.32,1321.67 1117.33,1321.67 1117.34,1321.67 1117.34,1321.67 1117.35,1321.67 1117.36,1321.67 1117.37,1321.67 1117.38,1321.67 1117.39,1321.67 1117.4,1321.67 1117.41,1321.67 1117.42,1321.67 1117.43,1321.67 1117.44,1321.67 1117.45,1321.67 1117.45,1321.67 1117.46,1321.68 1117.47,1321.68 1117.48,1321.68 1117.49,1321.68 1117.5,1321.68 1117.51,1321.68 1117.52,1321.68 1117.53,1321.68 1117.54,1321.68 1117.55,1321.68 1117.56,1321.68 1117.56,1321.68 1117.57,1321.68 1117.58,1321.68 1117.59,1321.68 1117.6,1321.68 1117.61,1321.68 1117.62,1321.69 1117.63,1321.69 1117.64,1321.69 1117.65,1321.69 1117.66,1321.69 1117.67,1321.69 1117.68,1321.69 1117.68,1321.69 1117.69,1321.69 1117.7,1321.69 1117.71,1321.69 1117.72,1321.69 1117.73,1321.69 1117.74,1321.69 1117.75,1321.69 1117.76,1321.69 1117.77,1321.69 1117.78,1321.7 1117.79,1321.7 1117.79,1321.7 1117.8,1321.7 1117.81,1321.7 1117.82,1321.7 1117.83,1321.7 1117.84,1321.7 1117.85,1321.7 1117.86,1321.7 1117.87,1321.7 1117.88,1321.7 1117.89,1321.7 1117.9,1321.7 1117.9,1321.7 1117.91,1321.7 1117.92,1321.7 1117.93,1321.71 1117.94,1321.71 1117.95,1321.71 1117.96,1321.71 1117.97,1321.71 1117.98,1321.71 1117.99,1321.71 1118,1321.71 1118.01,1321.71 1118.02,1321.71 1118.02,1321.71 1118.03,1321.71 1118.04,1321.71 1118.05,1321.71 1118.06,1321.71 1118.07,1321.71 1118.08,1321.71 1118.09,1321.72 1118.1,1321.72 1118.11,1321.72 1118.12,1321.72 1118.13,1321.72 1118.13,1321.72 1118.14,1321.72 1118.15,1321.72 1118.16,1321.72 1118.17,1321.72 1118.18,1321.72 1118.19,1321.72 1118.2,1321.72 1118.21,1321.72 1118.22,1321.72 1118.23,1321.72 1118.24,1321.72 1118.24,1321.73 1118.25,1321.73 1118.26,1321.73 1118.27,1321.73 1118.28,1321.73 1118.29,1321.73 1118.3,1321.73 1118.31,1321.73 1118.32,1321.73 1118.33,1321.73 1118.34,1321.73 1118.35,1321.73 1118.36,1321.73 1118.36,1321.73 1118.37,1321.73 1118.38,1321.73 1118.39,1321.73 1118.4,1321.74 1118.41,1321.74 1118.42,1321.74 1118.43,1321.74 1118.44,1321.74 1118.45,1321.74 1118.46,1321.74 1118.47,1321.74 1118.47,1321.74 1118.48,1321.74 1118.49,1321.74 1118.5,1321.74 1118.51,1321.74 1118.52,1321.74 1118.53,1321.74 1118.54,1321.74 1118.55,1321.74 1118.56,1321.75 1118.57,1321.75 1118.58,1321.75 1118.58,1321.75 1118.59,1321.75 1118.6,1321.75 1118.61,1321.75 1118.62,1321.75 1118.63,1321.75 1118.64,1321.75 1118.65,1321.75 1118.66,1321.75 1118.67,1321.75 1118.68,1321.75 1118.69,1321.75 1118.7,1321.75 1118.7,1321.75 1118.71,1321.76 1118.72,1321.76 1118.73,1321.76 1118.74,1321.76 1118.75,1321.76 1118.76,1321.76 1118.77,1321.76 1118.78,1321.76 1118.79,1321.76 1118.8,1321.76 1118.81,1321.76 1118.81,1321.76 1118.82,1321.76 1118.83,1321.76 1118.84,1321.76 1118.85,1321.76 1118.86,1321.76 1118.87,1321.76 1118.88,1321.77 1118.89,1321.77 1118.9,1321.77 1118.91,1321.77 1118.92,1321.77 1118.92,1321.77 1118.93,1321.77 1118.94,1321.77 1118.95,1321.77 1118.96,1321.77 1118.97,1321.77 1118.98,1321.77 1118.99,1321.77 1119,1321.77 1119.01,1321.77 1119.02,1321.77 1119.03,1321.77 1119.04,1321.78 1119.04,1321.78 1119.05,1321.78 1119.06,1321.78 1119.07,1321.78 1119.08,1321.78 1119.09,1321.78 1119.1,1321.78 1119.11,1321.78 1119.12,1321.78 1119.13,1321.78 1119.14,1321.78 1119.15,1321.78 1119.15,1321.78 1119.16,1321.78 1119.17,1321.78 1119.18,1321.78 1119.19,1321.79 1119.2,1321.79 1119.21,1321.79 1119.22,1321.79 1119.23,1321.79 1119.24,1321.79 1119.25,1321.79 1119.26,1321.79 1119.26,1321.79 1119.27,1321.79 1119.28,1321.79 1119.29,1321.79 1119.3,1321.79 1119.31,1321.79 1119.32,1321.79 1119.33,1321.79 1119.34,1321.79 1119.35,1321.8 1119.36,1321.8 1119.37,1321.8 1119.38,1321.8 1119.38,1321.8 1119.39,1321.8 1119.4,1321.8 1119.41,1321.8 1119.42,1321.8 1119.43,1321.8 1119.44,1321.8 1119.45,1321.8 1119.46,1321.8 1119.47,1321.8 1119.48,1321.8 1119.49,1321.8 1119.49,1321.8 1119.5,1321.81 1119.51,1321.81 1119.52,1321.81 1119.53,1321.81 1119.54,1321.81 1119.55,1321.81 1119.56,1321.81 1119.57,1321.81 1119.58,1321.81 1119.59,1321.81 1119.6,1321.81 1119.6,1321.81 1119.61,1321.81 1119.62,1321.81 1119.63,1321.81 1119.64,1321.81 1119.65,1321.81 1119.66,1321.82 1119.67,1321.82 1119.68,1321.82 1119.69,1321.82 1119.7,1321.82 1119.71,1321.82 1119.72,1321.82 1119.72,1321.82 1119.73,1321.82 1119.74,1321.82 1119.75,1321.82 1119.76,1321.82 1119.77,1321.82 1119.78,1321.82 1119.79,1321.82 1119.8,1321.82 1119.81,1321.82 1119.82,1321.83 1119.83,1321.83 1119.83,1321.83 1119.84,1321.83 1119.85,1321.83 1119.86,1321.83 1119.87,1321.83 1119.88,1321.83 1119.89,1321.83 1119.9,1321.83 1119.91,1321.83 1119.92,1321.83 1119.93,1321.83 1119.94,1321.83 1119.94,1321.83 1119.95,1321.83 1119.96,1321.83 1119.97,1321.84 1119.98,1321.84 1119.99,1321.84 1120,1321.84 1120.01,1321.84 1120.02,1321.84 1120.03,1321.84 1120.04,1321.84 1120.05,1321.84 1120.06,1321.84 1120.06,1321.84 1120.07,1321.84 1120.08,1321.84 1120.09,1321.84 1120.1,1321.84 1120.11,1321.84 1120.12,1321.84 1120.13,1321.85 1120.14,1321.85 1120.15,1321.85 1120.16,1321.85 1120.17,1321.85 1120.17,1321.85 1120.18,1321.85 1120.19,1321.85 1120.2,1321.85 1120.21,1321.85 1120.22,1321.85 1120.23,1321.85 1120.24,1321.85 1120.25,1321.85 1120.26,1321.85 1120.27,1321.85 1120.28,1321.85 1120.28,1321.86 1120.29,1321.86 1120.3,1321.86 1120.31,1321.86 1120.32,1321.86 1120.33,1321.86 1120.34,1321.86 1120.35,1321.86 1120.36,1321.86 1120.37,1321.86 1120.38,1321.86 1120.39,1321.86 1120.4,1321.86 1120.4,1321.86 1120.41,1321.86 1120.42,1321.86 1120.43,1321.86 1120.44,1321.87 1120.45,1321.87 1120.46,1321.87 1120.47,1321.87 1120.48,1321.87 1120.49,1321.87 1120.5,1321.87 1120.51,1321.87 1120.51,1321.87 1120.52,1321.87 1120.53,1321.87 1120.54,1321.87 1120.55,1321.87 1120.56,1321.87 1120.57,1321.87 1120.58,1321.87 1120.59,1321.87 1120.6,1321.88 1120.61,1321.88 1120.62,1321.88 1120.62,1321.88 1120.63,1321.88 1120.64,1321.88 1120.65,1321.88 1120.66,1321.88 1120.67,1321.88 1120.68,1321.88 1120.69,1321.88 1120.7,1321.88 1120.71,1321.88 1120.72,1321.88 1120.73,1321.88 1120.74,1321.88 1120.74,1321.88 1120.75,1321.89 1120.76,1321.89 1120.77,1321.89 1120.78,1321.89 1120.79,1321.89 1120.8,1321.89 1120.81,1321.89 1120.82,1321.89 1120.83,1321.89 1120.84,1321.89 1120.85,1321.89 1120.85,1321.89 1120.86,1321.89 1120.87,1321.89 1120.88,1321.89 1120.89,1321.89 1120.9,1321.89 1120.91,1321.9 1120.92,1321.9 1120.93,1321.9 1120.94,1321.9 1120.95,1321.9 1120.96,1321.9 1120.96,1321.9 1120.97,1321.9 1120.98,1321.9 1120.99,1321.9 1121,1321.9 1121.01,1321.9 1121.02,1321.9 1121.03,1321.9 1121.04,1321.9 1121.05,1321.9 1121.06,1321.9 1121.07,1321.91 1121.08,1321.91 1121.08,1321.91 1121.09,1321.91 1121.1,1321.91 1121.11,1321.91 1121.12,1321.91 1121.13,1321.91 1121.14,1321.91 1121.15,1321.91 1121.16,1321.91 1121.17,1321.91 1121.18,1321.91 1121.19,1321.91 1121.19,1321.91 1121.2,1321.91 1121.21,1321.91 1121.22,1321.92 1121.23,1321.92 1121.24,1321.92 1121.25,1321.92 1121.26,1321.92 1121.27,1321.92 1121.28,1321.92 1121.29,1321.92 1121.3,1321.92 1121.3,1321.92 1121.31,1321.92 1121.32,1321.92 1121.33,1321.92 1121.34,1321.92 1121.35,1321.92 1121.36,1321.92 1121.37,1321.92 1121.38,1321.93 1121.39,1321.93 1121.4,1321.93 1121.41,1321.93 1121.42,1321.93 1121.42,1321.93 1121.43,1321.93 1121.44,1321.93 1121.45,1321.93 1121.46,1321.93 1121.47,1321.93 1121.48,1321.93 1121.49,1321.93 1121.5,1321.93 1121.51,1321.93 1121.52,1321.93 1121.53,1321.93 1121.53,1321.93 1121.54,1321.94 1121.55,1321.94 1121.56,1321.94 1121.57,1321.94 1121.58,1321.94 1121.59,1321.94 1121.6,1321.94 1121.61,1321.94 1121.62,1321.94 1121.63,1321.94 1121.64,1321.94 1121.65,1321.94 1121.65,1321.94 1121.66,1321.94 1121.67,1321.94 1121.68,1321.94 1121.69,1321.94 1121.7,1321.95 1121.71,1321.95 1121.72,1321.95 1121.73,1321.95 1121.74,1321.95 1121.75,1321.95 1121.76,1321.95 1121.76,1321.95 1121.77,1321.95 1121.78,1321.95 1121.79,1321.95 1121.8,1321.95 1121.81,1321.95 1121.82,1321.95 1121.83,1321.95 1121.84,1321.95 1121.85,1321.95 1121.86,1321.96 1121.87,1321.96 1121.87,1321.96 1121.88,1321.96 1121.89,1321.96 1121.9,1321.96 1121.91,1321.96 1121.92,1321.96 1121.93,1321.96 1121.94,1321.96 1121.95,1321.96 1121.96,1321.96 1121.97,1321.96 1121.98,1321.96 1121.99,1321.96 1121.99,1321.96 1122,1321.96 1122.01,1321.97 1122.02,1321.97 1122.03,1321.97 1122.04,1321.97 1122.05,1321.97 1122.06,1321.97 1122.07,1321.97 1122.08,1321.97 1122.09,1321.97 1122.1,1321.97 1122.1,1321.97 1122.11,1321.97 1122.12,1321.97 1122.13,1321.97 1122.14,1321.97 1122.15,1321.97 1122.16,1321.97 1122.17,1321.98 1122.18,1321.98 1122.19,1321.98 1122.2,1321.98 1122.21,1321.98 1122.21,1321.98 1122.22,1321.98 1122.23,1321.98 1122.24,1321.98 1122.25,1321.98 1122.26,1321.98 1122.27,1321.98 1122.28,1321.98 1122.29,1321.98 1122.3,1321.98 1122.31,1321.98 1122.32,1321.98 1122.33,1321.99 1122.33,1321.99 1122.34,1321.99 1122.35,1321.99 1122.36,1321.99 1122.37,1321.99 1122.38,1321.99 1122.39,1321.99 1122.4,1321.99 1122.41,1321.99 1122.42,1321.99 1122.43,1321.99 1122.44,1321.99 1122.44,1321.99 1122.45,1321.99 1122.46,1321.99 1122.47,1321.99 1122.48,1322 1122.49,1322 1122.5,1322 1122.51,1322 1122.52,1322 1122.53,1322 1122.54,1322 1122.55,1322 1122.55,1322 1122.56,1322 1122.57,1322 1122.58,1322 1122.59,1322 1122.6,1322 1122.61,1322 1122.62,1322 1122.63,1322 1122.64,1322.01 1122.65,1322.01 1122.66,1322.01 1122.67,1322.01 1122.67,1322.01 1122.68,1322.01 1122.69,1322.01 1122.7,1322.01 1122.71,1322.01 1122.72,1322.01 1122.73,1322.01 1122.74,1322.01 1122.75,1322.01 1122.76,1322.01 1122.77,1322.01 1122.78,1322.01 1122.78,1322.01 1122.79,1322.02 1122.8,1322.02 1122.81,1322.02 1122.82,1322.02 1122.83,1322.02 1122.84,1322.02 1122.85,1322.02 1122.86,1322.02 1122.87,1322.02 1122.88,1322.02 1122.89,1322.02 1122.89,1322.02 1122.9,1322.02 1122.91,1322.02 1122.92,1322.02 1122.93,1322.02 1122.94,1322.02 1122.95,1322.03 1122.96,1322.03 1122.97,1322.03 1122.98,1322.03 1122.99,1322.03 1123,1322.03 1123.01,1322.03 1123.01,1322.03 1123.02,1322.03 1123.03,1322.03 1123.04,1322.03 1123.05,1322.03 1123.06,1322.03 1123.07,1322.03 1123.08,1322.03 1123.09,1322.03 1123.1,1322.03 1123.11,1322.04 1123.12,1322.04 1123.12,1322.04 1123.13,1322.04 1123.14,1322.04 1123.15,1322.04 1123.16,1322.04 1123.17,1322.04 1123.18,1322.04 1123.19,1322.04 1123.2,1322.04 1123.21,1322.04 1123.22,1322.04 1123.23,1322.04 1123.23,1322.04 1123.24,1322.04 1123.25,1322.04 1123.26,1322.04 1123.27,1322.05 1123.28,1322.05 1123.29,1322.05 1123.3,1322.05 1123.31,1322.05 1123.32,1322.05 1123.33,1322.05 1123.34,1322.05 1123.35,1322.05 1123.35,1322.05 1123.36,1322.05 1123.37,1322.05 1123.38,1322.05 1123.39,1322.05 1123.4,1322.05 1123.41,1322.05 1123.42,1322.05 1123.43,1322.06 1123.44,1322.06 1123.45,1322.06 1123.46,1322.06 1123.46,1322.06 1123.47,1322.06 1123.48,1322.06 1123.49,1322.06 1123.5,1322.06 1123.51,1322.06 1123.52,1322.06 1123.53,1322.06 1123.54,1322.06 1123.55,1322.06 1123.56,1322.06 1123.57,1322.06 1123.57,1322.06 1123.58,1322.07 1123.59,1322.07 1123.6,1322.07 1123.61,1322.07 1123.62,1322.07 1123.63,1322.07 1123.64,1322.07 1123.65,1322.07 1123.66,1322.07 1123.67,1322.07 1123.68,1322.07 1123.69,1322.07 1123.69,1322.07 1123.7,1322.07 1123.71,1322.07 1123.72,1322.07 1123.73,1322.07 1123.74,1322.08 1123.75,1322.08 1123.76,1322.08 1123.77,1322.08 1123.78,1322.08 1123.79,1322.08 1123.8,1322.08 1123.8,1322.08 1123.81,1322.08 1123.82,1322.08 1123.83,1322.08 1123.84,1322.08 1123.85,1322.08 1123.86,1322.08 1123.87,1322.08 1123.88,1322.08 1123.89,1322.08 1123.9,1322.09 1123.91,1322.09 1123.91,1322.09 1123.92,1322.09 1123.93,1322.09 1123.94,1322.09 1123.95,1322.09 1123.96,1322.09 1123.97,1322.09 1123.98,1322.09 1123.99,1322.09 1124,1322.09 1124.01,1322.09 1124.02,1322.09 1124.03,1322.09 1124.03,1322.09 1124.04,1322.09 1124.05,1322.1 1124.06,1322.1 1124.07,1322.1 1124.08,1322.1 1124.09,1322.1 1124.1,1322.1 1124.11,1322.1 1124.12,1322.1 1124.13,1322.1 1124.14,1322.1 1124.14,1322.1 1124.15,1322.1 1124.16,1322.1 1124.17,1322.1 1124.18,1322.1 1124.19,1322.1 1124.2,1322.1 1124.21,1322.11 1124.22,1322.11 1124.23,1322.11 1124.24,1322.11 1124.25,1322.11 1124.25,1322.11 1124.26,1322.11 1124.27,1322.11 1124.28,1322.11 1124.29,1322.11 1124.3,1322.11 1124.31,1322.11 1124.32,1322.11 1124.33,1322.11 1124.34,1322.11 1124.35,1322.11 1124.36,1322.11 1124.37,1322.12 1124.37,1322.12 1124.38,1322.12 1124.39,1322.12 1124.4,1322.12 1124.41,1322.12 1124.42,1322.12 1124.43,1322.12 1124.44,1322.12 1124.45,1322.12 1124.46,1322.12 1124.47,1322.12 1124.48,1322.12 1124.48,1322.12 1124.49,1322.12 1124.5,1322.12 1124.51,1322.12 1124.52,1322.13 1124.53,1322.13 1124.54,1322.13 1124.55,1322.13 1124.56,1322.13 1124.57,1322.13 1124.58,1322.13 1124.59,1322.13 1124.59,1322.13 1124.6,1322.13 1124.61,1322.13 1124.62,1322.13 1124.63,1322.13 1124.64,1322.13 1124.65,1322.13 1124.66,1322.13 1124.67,1322.13 1124.68,1322.14 1124.69,1322.14 1124.7,1322.14 1124.71,1322.14 1124.71,1322.14 1124.72,1322.14 1124.73,1322.14 1124.74,1322.14 1124.75,1322.14 1124.76,1322.14 1124.77,1322.14 1124.78,1322.14 1124.79,1322.14 1124.8,1322.14 1124.81,1322.14 1124.82,1322.14 1124.82,1322.14 1124.83,1322.14 1124.84,1322.15 1124.85,1322.15 1124.86,1322.15 1124.87,1322.15 1124.88,1322.15 1124.89,1322.15 1124.9,1322.15 1124.91,1322.15 1124.92,1322.15 1124.93,1322.15 1124.93,1322.15 1124.94,1322.15 1124.95,1322.15 1124.96,1322.15 1124.97,1322.15 1124.98,1322.15 1124.99,1322.15 1125,1322.16 1125.01,1322.16 1125.02,1322.16 1125.03,1322.16 1125.04,1322.16 1125.05,1322.16 1125.05,1322.16 1125.06,1322.16 1125.07,1322.16 1125.08,1322.16 1125.09,1322.16 1125.1,1322.16 1125.11,1322.16 1125.12,1322.16 1125.13,1322.16 1125.14,1322.16 1125.15,1322.16 1125.16,1322.17 1125.16,1322.17 1125.17,1322.17 1125.18,1322.17 1125.19,1322.17 1125.2,1322.17 1125.21,1322.17 1125.22,1322.17 1125.23,1322.17 1125.24,1322.17 1125.25,1322.17 1125.26,1322.17 1125.27,1322.17 1125.27,1322.17 1125.28,1322.17 1125.29,1322.17 1125.3,1322.17 1125.31,1322.18 1125.32,1322.18 1125.33,1322.18 1125.34,1322.18 1125.35,1322.18 1125.36,1322.18 1125.37,1322.18 1125.38,1322.18 1125.39,1322.18 1125.39,1322.18 1125.4,1322.18 1125.41,1322.18 1125.42,1322.18 1125.43,1322.18 1125.44,1322.18 1125.45,1322.18 1125.46,1322.18 1125.47,1322.19 1125.48,1322.19 1125.49,1322.19 1125.5,1322.19 1125.5,1322.19 1125.51,1322.19 1125.52,1322.19 1125.53,1322.19 1125.54,1322.19 1125.55,1322.19 1125.56,1322.19 1125.57,1322.19 1125.58,1322.19 1125.59,1322.19 1125.6,1322.19 1125.61,1322.19 1125.61,1322.19 1125.62,1322.2 1125.63,1322.2 1125.64,1322.2 1125.65,1322.2 1125.66,1322.2 1125.67,1322.2 1125.68,1322.2 1125.69,1322.2 1125.7,1322.2 1125.71,1322.2 1125.72,1322.2 1125.73,1322.2 1125.73,1322.2 1125.74,1322.2 1125.75,1322.2 1125.76,1322.2 1125.77,1322.2 1125.78,1322.21 1125.79,1322.21 1125.8,1322.21 1125.81,1322.21 1125.82,1322.21 1125.83,1322.21 1125.84,1322.21 1125.84,1322.21 1125.85,1322.21 1125.86,1322.21 1125.87,1322.21 1125.88,1322.21 1125.89,1322.21 1125.9,1322.21 1125.91,1322.21 1125.92,1322.21 1125.93,1322.21 1125.94,1322.22 1125.95,1322.22 1125.95,1322.22 1125.96,1322.22 1125.97,1322.22 1125.98,1322.22 1125.99,1322.22 1126,1322.22 1126.01,1322.22 1126.02,1322.22 1126.03,1322.22 1126.04,1322.22 1126.05,1322.22 1126.06,1322.22 1126.07,1322.22 1126.07,1322.22 1126.08,1322.22 1126.09,1322.22 1126.1,1322.23 1126.11,1322.23 1126.12,1322.23 1126.13,1322.23 1126.14,1322.23 1126.15,1322.23 1126.16,1322.23 1126.17,1322.23 1126.18,1322.23 1126.18,1322.23 1126.19,1322.23 1126.2,1322.23 1126.21,1322.23 1126.22,1322.23 1126.23,1322.23 1126.24,1322.23 1126.25,1322.23 1126.26,1322.24 1126.27,1322.24 1126.28,1322.24 1126.29,1322.24 1126.29,1322.24 1126.3,1322.24 1126.31,1322.24 1126.32,1322.24 1126.33,1322.24 1126.34,1322.24 1126.35,1322.24 1126.36,1322.24 1126.37,1322.24 1126.38,1322.24 1126.39,1322.24 1126.4,1322.24 1126.41,1322.24 1126.41,1322.25 1126.42,1322.25 1126.43,1322.25 1126.44,1322.25 1126.45,1322.25 1126.46,1322.25 1126.47,1322.25 1126.48,1322.25 1126.49,1322.25 1126.5,1322.25 1126.51,1322.25 1126.52,1322.25 1126.52,1322.25 1126.53,1322.25 1126.54,1322.25 1126.55,1322.25 1126.56,1322.25 1126.57,1322.26 1126.58,1322.26 1126.59,1322.26 1126.6,1322.26 1126.61,1322.26 1126.62,1322.26 1126.63,1322.26 1126.63,1322.26 1126.64,1322.26 1126.65,1322.26 1126.66,1322.26 1126.67,1322.26 1126.68,1322.26 1126.69,1322.26 1126.7,1322.26 1126.71,1322.26 1126.72,1322.26 1126.73,1322.27 1126.74,1322.27 1126.75,1322.27 1126.75,1322.27 1126.76,1322.27 1126.77,1322.27 1126.78,1322.27 1126.79,1322.27 1126.8,1322.27 1126.81,1322.27 1126.82,1322.27 1126.83,1322.27 1126.84,1322.27 1126.85,1322.27 1126.86,1322.27 1126.86,1322.27 1126.87,1322.27 1126.88,1322.28 1126.89,1322.28 1126.9,1322.28 1126.91,1322.28 1126.92,1322.28 1126.93,1322.28 1126.94,1322.28 1126.95,1322.28 1126.96,1322.28 1126.97,1322.28 1126.97,1322.28 1126.98,1322.28 1126.99,1322.28 1127,1322.28 1127.01,1322.28 1127.02,1322.28 1127.03,1322.28 1127.04,1322.29 1127.05,1322.29 1127.06,1322.29 1127.07,1322.29 1127.08,1322.29 1127.09,1322.29 1127.09,1322.29 1127.1,1322.29 1127.11,1322.29 1127.12,1322.29 1127.13,1322.29 1127.14,1322.29 1127.15,1322.29 1127.16,1322.29 1127.17,1322.29 1127.18,1322.29 1127.19,1322.29 1127.2,1322.29 1127.2,1322.3 1127.21,1322.3 1127.22,1322.3 1127.23,1322.3 1127.24,1322.3 1127.25,1322.3 1127.26,1322.3 1127.27,1322.3 1127.28,1322.3 1127.29,1322.3 1127.3,1322.3 1127.31,1322.3 1127.31,1322.3 1127.32,1322.3 1127.33,1322.3 1127.34,1322.3 1127.35,1322.3 1127.36,1322.31 1127.37,1322.31 1127.38,1322.31 1127.39,1322.31 1127.4,1322.31 1127.41,1322.31 1127.42,1322.31 1127.43,1322.31 1127.43,1322.31 1127.44,1322.31 1127.45,1322.31 1127.46,1322.31 1127.47,1322.31 1127.48,1322.31 1127.49,1322.31 1127.5,1322.31 1127.51,1322.31 1127.52,1322.32 1127.53,1322.32 1127.54,1322.32 1127.54,1322.32 1127.55,1322.32 1127.56,1322.32 1127.57,1322.32 1127.58,1322.32 1127.59,1322.32 1127.6,1322.32 1127.61,1322.32 1127.62,1322.32 1127.63,1322.32 1127.64,1322.32 1127.65,1322.32 1127.65,1322.32 1127.66,1322.32 1127.67,1322.33 1127.68,1322.33 1127.69,1322.33 1127.7,1322.33 1127.71,1322.33 1127.72,1322.33 1127.73,1322.33 1127.74,1322.33 1127.75,1322.33 1127.76,1322.33 1127.77,1322.33 1127.77,1322.33 1127.78,1322.33 1127.79,1322.33 1127.8,1322.33 1127.81,1322.33 1127.82,1322.33 1127.83,1322.34 1127.84,1322.34 1127.85,1322.34 1127.86,1322.34 1127.87,1322.34 1127.88,1322.34 1127.88,1322.34 1127.89,1322.34 1127.9,1322.34 1127.91,1322.34 1127.92,1322.34 1127.93,1322.34 1127.94,1322.34 1127.95,1322.34 1127.96,1322.34 1127.97,1322.34 1127.98,1322.34 1127.99,1322.35 1127.99,1322.35 1128,1322.35 1128.01,1322.35 1128.02,1322.35 1128.03,1322.35 1128.04,1322.35 1128.05,1322.35 1128.06,1322.35 1128.07,1322.35 1128.08,1322.35 1128.09,1322.35 1128.1,1322.35 1128.11,1322.35 1128.11,1322.35 1128.12,1322.35 1128.13,1322.35 1128.14,1322.36 1128.15,1322.36 1128.16,1322.36 1128.17,1322.36 1128.18,1322.36 1128.19,1322.36 1128.2,1322.36 1128.21,1322.36 1128.22,1322.36 1128.22,1322.36 1128.23,1322.36 1128.24,1322.36 1128.25,1322.36 1128.26,1322.36 1128.27,1322.36 1128.28,1322.36 1128.29,1322.36 1128.3,1322.36 1128.31,1322.37 1128.32,1322.37 1128.33,1322.37 1128.33,1322.37 1128.34,1322.37 1128.35,1322.37 1128.36,1322.37 1128.37,1322.37 1128.38,1322.37 1128.39,1322.37 1128.4,1322.37 1128.41,1322.37 1128.42,1322.37 1128.43,1322.37 1128.44,1322.37 1128.45,1322.37 1128.45,1322.37 1128.46,1322.38 1128.47,1322.38 1128.48,1322.38 1128.49,1322.38 1128.5,1322.38 1128.51,1322.38 1128.52,1322.38 1128.53,1322.38 1128.54,1322.38 1128.55,1322.38 1128.56,1322.38 1128.56,1322.38 1128.57,1322.38 1128.58,1322.38 1128.59,1322.38 1128.6,1322.38 1128.61,1322.38 1128.62,1322.39 1128.63,1322.39 1128.64,1322.39 1128.65,1322.39 1128.66,1322.39 1128.67,1322.39 1128.67,1322.39 1128.68,1322.39 1128.69,1322.39 1128.7,1322.39 1128.71,1322.39 1128.72,1322.39 1128.73,1322.39 1128.74,1322.39 1128.75,1322.39 1128.76,1322.39 1128.77,1322.39 1128.78,1322.4 1128.79,1322.4 1128.79,1322.4 1128.8,1322.4 1128.81,1322.4 1128.82,1322.4 1128.83,1322.4 1128.84,1322.4 1128.85,1322.4 1128.86,1322.4 1128.87,1322.4 1128.88,1322.4 1128.89,1322.4 1128.9,1322.4 1128.9,1322.4 1128.91,1322.4 1128.92,1322.4 1128.93,1322.41 1128.94,1322.41 1128.95,1322.41 1128.96,1322.41 1128.97,1322.41 1128.98,1322.41 1128.99,1322.41 1129,1322.41 1129.01,1322.41 1129.01,1322.41 1129.02,1322.41 1129.03,1322.41 1129.04,1322.41 1129.05,1322.41 1129.06,1322.41 1129.07,1322.41 1129.08,1322.41 1129.09,1322.42 1129.1,1322.42 1129.11,1322.42 1129.12,1322.42 1129.13,1322.42 1129.13,1322.42 1129.14,1322.42 1129.15,1322.42 1129.16,1322.42 1129.17,1322.42 1129.18,1322.42 1129.19,1322.42 1129.2,1322.42 1129.21,1322.42 1129.22,1322.42 1129.23,1322.42 1129.24,1322.42 1129.24,1322.42 1129.25,1322.43 1129.26,1322.43 1129.27,1322.43 1129.28,1322.43 1129.29,1322.43 1129.3,1322.43 1129.31,1322.43 1129.32,1322.43 1129.33,1322.43 1129.34,1322.43 1129.35,1322.43 1129.35,1322.43 1129.36,1322.43 1129.37,1322.43 1129.38,1322.43 1129.39,1322.43 1129.4,1322.43 1129.41,1322.44 1129.42,1322.44 1129.43,1322.44 1129.44,1322.44 1129.45,1322.44 1129.46,1322.44 1129.47,1322.44 1129.47,1322.44 1129.48,1322.44 1129.49,1322.44 1129.5,1322.44 1129.51,1322.44 1129.52,1322.44 1129.53,1322.44 1129.54,1322.44 1129.55,1322.44 1129.56,1322.44 1129.57,1322.45 1129.58,1322.45 1129.58,1322.45 1129.59,1322.45 1129.6,1322.45 1129.61,1322.45 1129.62,1322.45 1129.63,1322.45 1129.64,1322.45 1129.65,1322.45 1129.66,1322.45 1129.67,1322.45 1129.68,1322.45 1129.69,1322.45 1129.69,1322.45 1129.7,1322.45 1129.71,1322.45 1129.72,1322.46 1129.73,1322.46 1129.74,1322.46 1129.75,1322.46 1129.76,1322.46 1129.77,1322.46 1129.78,1322.46 1129.79,1322.46 1129.8,1322.46 1129.81,1322.46 1129.81,1322.46 1129.82,1322.46 1129.83,1322.46 1129.84,1322.46 1129.85,1322.46 1129.86,1322.46 1129.87,1322.46 1129.88,1322.47 1129.89,1322.47 1129.9,1322.47 1129.91,1322.47 1129.92,1322.47 1129.92,1322.47 1129.93,1322.47 1129.94,1322.47 1129.95,1322.47 1129.96,1322.47 1129.97,1322.47 1129.98,1322.47 1129.99,1322.47 1130,1322.47 1130.01,1322.47 1130.02,1322.47 1130.03,1322.47 1130.03,1322.48 1130.04,1322.48 1130.05,1322.48 1130.06,1322.48 1130.07,1322.48 1130.08,1322.48 1130.09,1322.48 1130.1,1322.48 1130.11,1322.48 1130.12,1322.48 1130.13,1322.48 1130.14,1322.48 1130.15,1322.48 1130.15,1322.48 1130.16,1322.48 1130.17,1322.48 1130.18,1322.48 1130.19,1322.48 1130.2,1322.49 1130.21,1322.49 1130.22,1322.49 1130.23,1322.49 1130.24,1322.49 1130.25,1322.49 1130.26,1322.49 1130.26,1322.49 1130.27,1322.49 1130.28,1322.49 1130.29,1322.49 1130.3,1322.49 1130.31,1322.49 1130.32,1322.49 1130.33,1322.49 1130.34,1322.49 1130.35,1322.49 1130.36,1322.5 1130.37,1322.5 1130.37,1322.5 1130.38,1322.5 1130.39,1322.5 1130.4,1322.5 1130.41,1322.5 1130.42,1322.5 1130.43,1322.5 1130.44,1322.5 1130.45,1322.5 1130.46,1322.5 1130.47,1322.5 1130.48,1322.5 1130.49,1322.5 1130.49,1322.5 1130.5,1322.5 1130.51,1322.51 1130.52,1322.51 1130.53,1322.51 1130.54,1322.51 1130.55,1322.51 1130.56,1322.51 1130.57,1322.51 1130.58,1322.51 1130.59,1322.51 1130.6,1322.51 1130.6,1322.51 1130.61,1322.51 1130.62,1322.51 1130.63,1322.51 1130.64,1322.51 1130.65,1322.51 1130.66,1322.51 1130.67,1322.52 1130.68,1322.52 1130.69,1322.52 1130.7,1322.52 1130.71,1322.52 1130.71,1322.52 1130.72,1322.52 1130.73,1322.52 1130.74,1322.52 1130.75,1322.52 1130.76,1322.52 1130.77,1322.52 1130.78,1322.52 1130.79,1322.52 1130.8,1322.52 1130.81,1322.52 1130.82,1322.52 1130.83,1322.53 1130.83,1322.53 1130.84,1322.53 1130.85,1322.53 1130.86,1322.53 1130.87,1322.53 1130.88,1322.53 1130.89,1322.53 1130.9,1322.53 1130.91,1322.53 1130.92,1322.53 1130.93,1322.53 1130.94,1322.53 1130.94,1322.53 1130.95,1322.53 1130.96,1322.53 1130.97,1322.53 1130.98,1322.54 1130.99,1322.54 1131,1322.54 1131.01,1322.54 1131.02,1322.54 1131.03,1322.54 1131.04,1322.54 1131.05,1322.54 1131.05,1322.54 1131.06,1322.54 1131.07,1322.54 1131.08,1322.54 1131.09,1322.54 1131.1,1322.54 1131.11,1322.54 1131.12,1322.54 1131.13,1322.54 1131.14,1322.54 1131.15,1322.55 1131.16,1322.55 1131.17,1322.55 1131.17,1322.55 1131.18,1322.55 1131.19,1322.55 1131.2,1322.55 1131.21,1322.55 1131.22,1322.55 1131.23,1322.55 1131.24,1322.55 1131.25,1322.55 1131.26,1322.55 1131.27,1322.55 1131.28,1322.55 1131.28,1322.55 1131.29,1322.55 1131.3,1322.56 1131.31,1322.56 1131.32,1322.56 1131.33,1322.56 1131.34,1322.56 1131.35,1322.56 1131.36,1322.56 1131.37,1322.56 1131.38,1322.56 1131.39,1322.56 1131.39,1322.56 1131.4,1322.56 1131.41,1322.56 1131.42,1322.56 1131.43,1322.56 1131.44,1322.56 1131.45,1322.56 1131.46,1322.57 1131.47,1322.57 1131.48,1322.57 1131.49,1322.57 1131.5,1322.57 1131.51,1322.57 1131.51,1322.57 1131.52,1322.57 1131.53,1322.57 1131.54,1322.57 1131.55,1322.57 1131.56,1322.57 1131.57,1322.57 1131.58,1322.57 1131.59,1322.57 1131.6,1322.57 1131.61,1322.57 1131.62,1322.58 1131.62,1322.58 1131.63,1322.58 1131.64,1322.58 1131.65,1322.58 1131.66,1322.58 1131.67,1322.58 1131.68,1322.58 1131.69,1322.58 1131.7,1322.58 1131.71,1322.58 1131.72,1322.58 1131.73,1322.58 1131.73,1322.58 1131.74,1322.58 1131.75,1322.58 1131.76,1322.58 1131.77,1322.59 1131.78,1322.59 1131.79,1322.59 1131.8,1322.59 1131.81,1322.59 1131.82,1322.59 1131.83,1322.59 1131.84,1322.59 1131.85,1322.59 1131.85,1322.59 1131.86,1322.59 1131.87,1322.59 1131.88,1322.59 1131.89,1322.59 1131.9,1322.59 1131.91,1322.59 1131.92,1322.59 1131.93,1322.59 1131.94,1322.6 1131.95,1322.6 1131.96,1322.6 1131.96,1322.6 1131.97,1322.6 1131.98,1322.6 1131.99,1322.6 1132,1322.6 1132.01,1322.6 1132.02,1322.6 1132.03,1322.6 1132.04,1322.6 1132.05,1322.6 1132.06,1322.6 1132.07,1322.6 1132.07,1322.6 1132.08,1322.6 1132.09,1322.61 1132.1,1322.61 1132.11,1322.61 1132.12,1322.61 1132.13,1322.61 1132.14,1322.61 1132.15,1322.61 1132.16,1322.61 1132.17,1322.61 1132.18,1322.61 1132.19,1322.61 1132.19,1322.61 1132.2,1322.61 1132.21,1322.61 1132.22,1322.61 1132.23,1322.61 1132.24,1322.61 1132.25,1322.62 1132.26,1322.62 1132.27,1322.62 1132.28,1322.62 1132.29,1322.62 1132.3,1322.62 1132.3,1322.62 1132.31,1322.62 1132.32,1322.62 1132.33,1322.62 1132.34,1322.62 1132.35,1322.62 1132.36,1322.62 1132.37,1322.62 1132.38,1322.62 1132.39,1322.62 1132.4,1322.62 1132.41,1322.63 1132.41,1322.63 1132.42,1322.63 1132.43,1322.63 1132.44,1322.63 1132.45,1322.63 1132.46,1322.63 1132.47,1322.63 1132.48,1322.63 1132.49,1322.63 1132.5,1322.63 1132.51,1322.63 1132.52,1322.63 1132.53,1322.63 1132.53,1322.63 1132.54,1322.63 1132.55,1322.63 1132.56,1322.64 1132.57,1322.64 1132.58,1322.64 1132.59,1322.64 1132.6,1322.64 1132.61,1322.64 1132.62,1322.64 1132.63,1322.64 1132.64,1322.64 1132.64,1322.64 1132.65,1322.64 1132.66,1322.64 1132.67,1322.64 1132.68,1322.64 1132.69,1322.64 1132.7,1322.64 1132.71,1322.64 1132.72,1322.64 1132.73,1322.65 1132.74,1322.65 1132.75,1322.65 1132.75,1322.65 1132.76,1322.65 1132.77,1322.65 1132.78,1322.65 1132.79,1322.65 1132.8,1322.65 1132.81,1322.65 1132.82,1322.65 1132.83,1322.65 1132.84,1322.65 1132.85,1322.65 1132.86,1322.65 1132.87,1322.65 1132.87,1322.65 1132.88,1322.66 1132.89,1322.66 1132.9,1322.66 1132.91,1322.66 1132.92,1322.66 1132.93,1322.66 1132.94,1322.66 1132.95,1322.66 1132.96,1322.66 1132.97,1322.66 1132.98,1322.66 1132.98,1322.66 1132.99,1322.66 1133,1322.66 1133.01,1322.66 1133.02,1322.66 1133.03,1322.66 1133.04,1322.67 1133.05,1322.67 1133.06,1322.67 1133.07,1322.67 1133.08,1322.67 1133.09,1322.67 1133.09,1322.67 1133.1,1322.67 1133.11,1322.67 1133.12,1322.67 1133.13,1322.67 1133.14,1322.67 1133.15,1322.67 1133.16,1322.67 1133.17,1322.67 1133.18,1322.67 1133.19,1322.67 1133.2,1322.68 1133.21,1322.68 1133.21,1322.68 1133.22,1322.68 1133.23,1322.68 1133.24,1322.68 1133.25,1322.68 1133.26,1322.68 1133.27,1322.68 1133.28,1322.68 1133.29,1322.68 1133.3,1322.68 1133.31,1322.68 1133.32,1322.68 1133.32,1322.68 1133.33,1322.68 1133.34,1322.68 1133.35,1322.69 1133.36,1322.69 1133.37,1322.69 1133.38,1322.69 1133.39,1322.69 1133.4,1322.69 1133.41,1322.69 1133.42,1322.69 1133.43,1322.69 1133.43,1322.69 1133.44,1322.69 1133.45,1322.69 1133.46,1322.69 1133.47,1322.69 1133.48,1322.69 1133.49,1322.69 1133.5,1322.69 1133.51,1322.69 1133.52,1322.7 1133.53,1322.7 1133.54,1322.7 1133.55,1322.7 1133.55,1322.7 1133.56,1322.7 1133.57,1322.7 1133.58,1322.7 1133.59,1322.7 1133.6,1322.7 1133.61,1322.7 1133.62,1322.7 1133.63,1322.7 1133.64,1322.7 1133.65,1322.7 1133.66,1322.7 1133.66,1322.7 1133.67,1322.71 1133.68,1322.71 1133.69,1322.71 1133.7,1322.71 1133.71,1322.71 1133.72,1322.71 1133.73,1322.71 1133.74,1322.71 1133.75,1322.71 1133.76,1322.71 1133.77,1322.71 1133.77,1322.71 1133.78,1322.71 1133.79,1322.71 1133.8,1322.71 1133.81,1322.71 1133.82,1322.71 1133.83,1322.72 1133.84,1322.72 1133.85,1322.72 1133.86,1322.72 1133.87,1322.72 1133.88,1322.72 1133.89,1322.72 1133.89,1322.72 1133.9,1322.72 1133.91,1322.72 1133.92,1322.72 1133.93,1322.72 1133.94,1322.72 1133.95,1322.72 1133.96,1322.72 1133.97,1322.72 1133.98,1322.72 1133.99,1322.73 1134,1322.73 1134,1322.73 1134.01,1322.73 1134.02,1322.73 1134.03,1322.73 1134.04,1322.73 1134.05,1322.73 1134.06,1322.73 1134.07,1322.73 1134.08,1322.73 1134.09,1322.73 1134.1,1322.73 1134.11,1322.73 1134.11,1322.73 1134.12,1322.73 1134.13,1322.73 1134.14,1322.73 1134.15,1322.74 1134.16,1322.74 1134.17,1322.74 1134.18,1322.74 1134.19,1322.74 1134.2,1322.74 1134.21,1322.74 1134.22,1322.74 1134.23,1322.74 1134.23,1322.74 1134.24,1322.74 1134.25,1322.74 1134.26,1322.74 1134.27,1322.74 1134.28,1322.74 1134.29,1322.74 1134.3,1322.74 1134.31,1322.75 1134.32,1322.75 1134.33,1322.75 1134.34,1322.75 1134.34,1322.75 1134.35,1322.75 1134.36,1322.75 1134.37,1322.75 1134.38,1322.75 1134.39,1322.75 1134.4,1322.75 1134.41,1322.75 1134.42,1322.75 1134.43,1322.75 1134.44,1322.75 1134.45,1322.75 1134.45,1322.75 1134.46,1322.76 1134.47,1322.76 1134.48,1322.76 1134.49,1322.76 1134.5,1322.76 1134.51,1322.76 1134.52,1322.76 1134.53,1322.76 1134.54,1322.76 1134.55,1322.76 1134.56,1322.76 1134.57,1322.76 1134.57,1322.76 1134.58,1322.76 1134.59,1322.76 1134.6,1322.76 1134.61,1322.76 1134.62,1322.77 1134.63,1322.77 1134.64,1322.77 1134.65,1322.77 1134.66,1322.77 1134.67,1322.77 1134.68,1322.77 1134.68,1322.77 1134.69,1322.77 1134.7,1322.77 1134.71,1322.77 1134.72,1322.77 1134.73,1322.77 1134.74,1322.77 1134.75,1322.77 1134.76,1322.77 1134.77,1322.77 1134.78,1322.78 1134.79,1322.78 1134.79,1322.78 1134.8,1322.78 1134.81,1322.78 1134.82,1322.78 1134.83,1322.78 1134.84,1322.78 1134.85,1322.78 1134.86,1322.78 1134.87,1322.78 1134.88,1322.78 1134.89,1322.78 1134.9,1322.78 1134.91,1322.78 1134.91,1322.78 1134.92,1322.78 1134.93,1322.78 1134.94,1322.79 1134.95,1322.79 1134.96,1322.79 1134.97,1322.79 1134.98,1322.79 1134.99,1322.79 1135,1322.79 1135.01,1322.79 1135.02,1322.79 1135.02,1322.79 1135.03,1322.79 1135.04,1322.79 1135.05,1322.79 1135.06,1322.79 1135.07,1322.79 1135.08,1322.79 1135.09,1322.79 1135.1,1322.8 1135.11,1322.8 1135.12,1322.8 1135.13,1322.8 1135.13,1322.8 1135.14,1322.8 1135.15,1322.8 1135.16,1322.8 1135.17,1322.8 1135.18,1322.8 1135.19,1322.8 1135.2,1322.8 1135.21,1322.8 1135.22,1322.8 1135.23,1322.8 1135.24,1322.8 1135.25,1322.8 1135.25,1322.81 1135.26,1322.81 1135.27,1322.81 1135.28,1322.81 1135.29,1322.81 1135.3,1322.81 1135.31,1322.81 1135.32,1322.81 1135.33,1322.81 1135.34,1322.81 1135.35,1322.81 1135.36,1322.81 1135.36,1322.81 1135.37,1322.81 1135.38,1322.81 1135.39,1322.81 1135.4,1322.81 1135.41,1322.82 1135.42,1322.82 1135.43,1322.82 1135.44,1322.82 1135.45,1322.82 1135.46,1322.82 1135.47,1322.82 1135.47,1322.82 1135.48,1322.82 1135.49,1322.82 1135.5,1322.82 1135.51,1322.82 1135.52,1322.82 1135.53,1322.82 1135.54,1322.82 1135.55,1322.82 1135.56,1322.82 1135.57,1322.82 1135.58,1322.83 1135.59,1322.83 1135.59,1322.83 1135.6,1322.83 1135.61,1322.83 1135.62,1322.83 1135.63,1322.83 1135.64,1322.83 1135.65,1322.83 1135.66,1322.83 1135.67,1322.83 1135.68,1322.83 1135.69,1322.83 1135.7,1322.83 1135.7,1322.83 1135.71,1322.83 1135.72,1322.83 1135.73,1322.84 1135.74,1322.84 1135.75,1322.84 1135.76,1322.84 1135.77,1322.84 1135.78,1322.84 1135.79,1322.84 1135.8,1322.84 1135.81,1322.84 1135.81,1322.84 1135.82,1322.84 1135.83,1322.84 1135.84,1322.84 1135.85,1322.84 1135.86,1322.84 1135.87,1322.84 1135.88,1322.84 1135.89,1322.85 1135.9,1322.85 1135.91,1322.85 1135.92,1322.85 1135.93,1322.85 1135.93,1322.85 1135.94,1322.85 1135.95,1322.85 1135.96,1322.85 1135.97,1322.85 1135.98,1322.85 1135.99,1322.85 1136,1322.85 1136.01,1322.85 1136.02,1322.85 1136.03,1322.85 1136.04,1322.85 1136.04,1322.86 1136.05,1322.86 1136.06,1322.86 1136.07,1322.86 1136.08,1322.86 1136.09,1322.86 1136.1,1322.86 1136.11,1322.86 1136.12,1322.86 1136.13,1322.86 1136.14,1322.86 1136.15,1322.86 1136.15,1322.86 1136.16,1322.86 1136.17,1322.86 1136.18,1322.86 1136.19,1322.86 1136.2,1322.86 1136.21,1322.87 1136.22,1322.87 1136.23,1322.87 1136.24,1322.87 1136.25,1322.87 1136.26,1322.87 1136.27,1322.87 1136.27,1322.87 1136.28,1322.87 1136.29,1322.87 1136.3,1322.87 1136.31,1322.87 1136.32,1322.87 1136.33,1322.87 1136.34,1322.87 1136.35,1322.87 1136.36,1322.87 1136.37,1322.88 1136.38,1322.88 1136.38,1322.88 1136.39,1322.88 1136.4,1322.88 1136.41,1322.88 1136.42,1322.88 1136.43,1322.88 1136.44,1322.88 1136.45,1322.88 1136.46,1322.88 1136.47,1322.88 1136.48,1322.88 1136.49,1322.88 1136.49,1322.88 1136.5,1322.88 1136.51,1322.88 1136.52,1322.89 1136.53,1322.89 1136.54,1322.89 1136.55,1322.89 1136.56,1322.89 1136.57,1322.89 1136.58,1322.89 1136.59,1322.89 1136.6,1322.89 1136.61,1322.89 1136.61,1322.89 1136.62,1322.89 1136.63,1322.89 1136.64,1322.89 1136.65,1322.89 1136.66,1322.89 1136.67,1322.89 1136.68,1322.9 1136.69,1322.9 1136.7,1322.9 1136.71,1322.9 1136.72,1322.9 1136.72,1322.9 1136.73,1322.9 1136.74,1322.9 1136.75,1322.9 1136.76,1322.9 1136.77,1322.9 1136.78,1322.9 1136.79,1322.9 1136.8,1322.9 1136.81,1322.9 1136.82,1322.9 1136.83,1322.9 1136.83,1322.9 1136.84,1322.91 1136.85,1322.91 1136.86,1322.91 1136.87,1322.91 1136.88,1322.91 1136.89,1322.91 1136.9,1322.91 1136.91,1322.91 1136.92,1322.91 1136.93,1322.91 1136.94,1322.91 1136.95,1322.91 1136.95,1322.91 1136.96,1322.91 1136.97,1322.91 1136.98,1322.91 1136.99,1322.91 1137,1322.92 1137.01,1322.92 1137.02,1322.92 1137.03,1322.92 1137.04,1322.92 1137.05,1322.92 1137.06,1322.92 1137.06,1322.92 1137.07,1322.92 1137.08,1322.92 1137.09,1322.92 1137.1,1322.92 1137.11,1322.92 1137.12,1322.92 1137.13,1322.92 1137.14,1322.92 1137.15,1322.92 1137.16,1322.93 1137.17,1322.93 1137.17,1322.93 1137.18,1322.93 1137.19,1322.93 1137.2,1322.93 1137.21,1322.93 1137.22,1322.93 1137.23,1322.93 1137.24,1322.93 1137.25,1322.93 1137.26,1322.93 1137.27,1322.93 1137.28,1322.93 1137.29,1322.93 1137.29,1322.93 1137.3,1322.93 1137.31,1322.94 1137.32,1322.94 1137.33,1322.94 1137.34,1322.94 1137.35,1322.94 1137.36,1322.94 1137.37,1322.94 1137.38,1322.94 1137.39,1322.94 1137.4,1322.94 1137.4,1322.94 1137.41,1322.94 1137.42,1322.94 1137.43,1322.94 1137.44,1322.94 1137.45,1322.94 1137.46,1322.94 1137.47,1322.94 1137.48,1322.95 1137.49,1322.95 1137.5,1322.95 1137.51,1322.95 1137.51,1322.95 1137.52,1322.95 1137.53,1322.95 1137.54,1322.95 1137.55,1322.95 1137.56,1322.95 1137.57,1322.95 1137.58,1322.95 1137.59,1322.95 1137.6,1322.95 1137.61,1322.95 1137.62,1322.95 1137.63,1322.95 1137.63,1322.96 1137.64,1322.96 1137.65,1322.96 1137.66,1322.96 1137.67,1322.96 1137.68,1322.96 1137.69,1322.96 1137.7,1322.96 1137.71,1322.96 1137.72,1322.96 1137.73,1322.96 1137.74,1322.96 1137.74,1322.96 1137.75,1322.96 1137.76,1322.96 1137.77,1322.96 1137.78,1322.96 1137.79,1322.97 1137.8,1322.97 1137.81,1322.97 1137.82,1322.97 1137.83,1322.97 1137.84,1322.97 1137.85,1322.97 1137.85,1322.97 1137.86,1322.97 1137.87,1322.97 1137.88,1322.97 1137.89,1322.97 1137.9,1322.97 1137.91,1322.97 1137.92,1322.97 1137.93,1322.97 1137.94,1322.97 1137.95,1322.98 1137.96,1322.98 1137.97,1322.98 1137.97,1322.98 1137.98,1322.98 1137.99,1322.98 1138,1322.98 1138.01,1322.98 1138.02,1322.98 1138.03,1322.98 1138.04,1322.98 1138.05,1322.98 1138.06,1322.98 1138.07,1322.98 1138.08,1322.98 1138.08,1322.98 1138.09,1322.98 1138.1,1322.98 1138.11,1322.99 1138.12,1322.99 1138.13,1322.99 1138.14,1322.99 1138.15,1322.99 1138.16,1322.99 1138.17,1322.99 1138.18,1322.99 1138.19,1322.99 1138.19,1322.99 1138.2,1322.99 1138.21,1322.99 1138.22,1322.99 1138.23,1322.99 1138.24,1322.99 1138.25,1322.99 1138.26,1322.99 1138.27,1323 1138.28,1323 1138.29,1323 1138.3,1323 1138.31,1323 1138.31,1323 1138.32,1323 1138.33,1323 1138.34,1323 1138.35,1323 1138.36,1323 1138.37,1323 1138.38,1323 1138.39,1323 1138.4,1323 1138.41,1323 1138.42,1323 1138.42,1323.01 1138.43,1323.01 1138.44,1323.01 1138.45,1323.01 1138.46,1323.01 1138.47,1323.01 1138.48,1323.01 1138.49,1323.01 1138.5,1323.01 1138.51,1323.01 1138.52,1323.01 1138.53,1323.01 1138.53,1323.01 1138.54,1323.01 1138.55,1323.01 1138.56,1323.01 1138.57,1323.01 1138.58,1323.01 1138.59,1323.02 1138.6,1323.02 1138.61,1323.02 1138.62,1323.02 1138.63,1323.02 1138.64,1323.02 1138.65,1323.02 1138.65,1323.02 1138.66,1323.02 1138.67,1323.02 1138.68,1323.02 1138.69,1323.02 1138.7,1323.02 1138.71,1323.02 1138.72,1323.02 1138.73,1323.02 1138.74,1323.02 1138.75,1323.03 1138.76,1323.03 1138.76,1323.03 1138.77,1323.03 1138.78,1323.03 1138.79,1323.03 1138.8,1323.03 1138.81,1323.03 1138.82,1323.03 1138.83,1323.03 1138.84,1323.03 1138.85,1323.03 1138.86,1323.03 1138.87,1323.03 1138.87,1323.03 1138.88,1323.03 1138.89,1323.03 1138.9,1323.04 1138.91,1323.04 1138.92,1323.04 1138.93,1323.04 1138.94,1323.04 1138.95,1323.04 1138.96,1323.04 1138.97,1323.04 1138.98,1323.04 1138.99,1323.04 1138.99,1323.04 1139,1323.04 1139.01,1323.04 1139.02,1323.04 1139.03,1323.04 1139.04,1323.04 1139.05,1323.04 1139.06,1323.05 1139.07,1323.05 1139.08,1323.05 1139.09,1323.05 1139.1,1323.05 1139.1,1323.05 1139.11,1323.05 1139.12,1323.05 1139.13,1323.05 1139.14,1323.05 1139.15,1323.05 1139.16,1323.05 1139.17,1323.05 1139.18,1323.05 1139.19,1323.05 1139.2,1323.05 1139.21,1323.05 1139.21,1323.05 1139.22,1323.06 1139.23,1323.06 1139.24,1323.06 1139.25,1323.06 1139.26,1323.06 1139.27,1323.06 1139.28,1323.06 1139.29,1323.06 1139.3,1323.06 1139.31,1323.06 1139.32,1323.06 1139.33,1323.06 1139.33,1323.06 1139.34,1323.06 1139.35,1323.06 1139.36,1323.06 1139.37,1323.06 1139.38,1323.07 1139.39,1323.07 1139.4,1323.07 1139.41,1323.07 1139.42,1323.07 1139.43,1323.07 1139.44,1323.07 1139.44,1323.07 1139.45,1323.07 1139.46,1323.07 1139.47,1323.07 1139.48,1323.07 1139.49,1323.07 1139.5,1323.07 1139.51,1323.07 1139.52,1323.07 1139.53,1323.07 1139.54,1323.08 1139.55,1323.08 1139.55,1323.08 1139.56,1323.08 1139.57,1323.08 1139.58,1323.08 1139.59,1323.08 1139.6,1323.08 1139.61,1323.08 1139.62,1323.08 1139.63,1323.08 1139.64,1323.08 1139.65,1323.08 1139.66,1323.08 1139.67,1323.08 1139.67,1323.08 1139.68,1323.08 1139.69,1323.09 1139.7,1323.09 1139.71,1323.09 1139.72,1323.09 1139.73,1323.09 1139.74,1323.09 1139.75,1323.09 1139.76,1323.09 1139.77,1323.09 1139.78,1323.09 1139.78,1323.09 1139.79,1323.09 1139.8,1323.09 1139.81,1323.09 1139.82,1323.09 1139.83,1323.09 1139.84,1323.09 1139.85,1323.09 1139.86,1323.1 1139.87,1323.1 1139.88,1323.1 1139.89,1323.1 1139.89,1323.1 1139.9,1323.1 1139.91,1323.1 1139.92,1323.1 1139.93,1323.1 1139.94,1323.1 1139.95,1323.1 1139.96,1323.1 1139.97,1323.1 1139.98,1323.1 1139.99,1323.1 1140,1323.1 1140.01,1323.1 1140.01,1323.11 1140.02,1323.11 1140.03,1323.11 1140.04,1323.11 1140.05,1323.11 1140.06,1323.11 1140.07,1323.11 1140.08,1323.11 1140.09,1323.11 1140.1,1323.11 1140.11,1323.11 1140.12,1323.11 1140.12,1323.11 1140.13,1323.11 1140.14,1323.11 1140.15,1323.11 1140.16,1323.11 1140.17,1323.12 1140.18,1323.12 1140.19,1323.12 1140.2,1323.12 1140.21,1323.12 1140.22,1323.12 1140.23,1323.12 1140.23,1323.12 1140.24,1323.12 1140.25,1323.12 1140.26,1323.12 1140.27,1323.12 1140.28,1323.12 1140.29,1323.12 1140.3,1323.12 1140.31,1323.12 1140.32,1323.12 1140.33,1323.12 1140.34,1323.13 1140.35,1323.13 1140.35,1323.13 1140.36,1323.13 1140.37,1323.13 1140.38,1323.13 1140.39,1323.13 1140.4,1323.13 1140.41,1323.13 1140.42,1323.13 1140.43,1323.13 1140.44,1323.13 1140.45,1323.13 1140.46,1323.13 1140.46,1323.13 1140.47,1323.13 1140.48,1323.13 1140.49,1323.14 1140.5,1323.14 1140.51,1323.14 1140.52,1323.14 1140.53,1323.14 1140.54,1323.14 1140.55,1323.14 1140.56,1323.14 1140.57,1323.14 1140.57,1323.14 1140.58,1323.14 1140.59,1323.14 1140.6,1323.14 1140.61,1323.14 1140.62,1323.14 1140.63,1323.14 1140.64,1323.14 1140.65,1323.15 1140.66,1323.15 1140.67,1323.15 1140.68,1323.15 1140.69,1323.15 1140.69,1323.15 1140.7,1323.15 1140.71,1323.15 1140.72,1323.15 1140.73,1323.15 1140.74,1323.15 1140.75,1323.15 1140.76,1323.15 1140.77,1323.15 1140.78,1323.15 1140.79,1323.15 1140.8,1323.15 1140.8,1323.15 1140.81,1323.16 1140.82,1323.16 1140.83,1323.16 1140.84,1323.16 1140.85,1323.16 1140.86,1323.16 1140.87,1323.16 1140.88,1323.16 1140.89,1323.16 1140.9,1323.16 1140.91,1323.16 1140.91,1323.16 1140.92,1323.16 1140.93,1323.16 1140.94,1323.16 1140.95,1323.16 1140.96,1323.16 1140.97,1323.17 1140.98,1323.17 1140.99,1323.17 1141,1323.17 1141.01,1323.17 1141.02,1323.17 1141.03,1323.17 1141.03,1323.17 1141.04,1323.17 1141.05,1323.17 1141.06,1323.17 1141.07,1323.17 1141.08,1323.17 1141.09,1323.17 1141.1,1323.17 1141.11,1323.17 1141.12,1323.17 1141.13,1323.18 1141.14,1323.18 1141.14,1323.18 1141.15,1323.18 1141.16,1323.18 1141.17,1323.18 1141.18,1323.18 1141.19,1323.18 1141.2,1323.18 1141.21,1323.18 1141.22,1323.18 1141.23,1323.18 1141.24,1323.18 1141.25,1323.18 1141.25,1323.18 1141.26,1323.18 1141.27,1323.18 1141.28,1323.19 1141.29,1323.19 1141.3,1323.19 1141.31,1323.19 1141.32,1323.19 1141.33,1323.19 1141.34,1323.19 1141.35,1323.19 1141.36,1323.19 1141.37,1323.19 1141.37,1323.19 1141.38,1323.19 1141.39,1323.19 1141.4,1323.19 1141.41,1323.19 1141.42,1323.19 1141.43,1323.19 1141.44,1323.19 1141.45,1323.2 1141.46,1323.2 1141.47,1323.2 1141.48,1323.2 1141.48,1323.2 1141.49,1323.2 1141.5,1323.2 1141.51,1323.2 1141.52,1323.2 1141.53,1323.2 1141.54,1323.2 1141.55,1323.2 1141.56,1323.2 1141.57,1323.2 1141.58,1323.2 1141.59,1323.2 1141.59,1323.2 1141.6,1323.21 1141.61,1323.21 1141.62,1323.21 1141.63,1323.21 1141.64,1323.21 1141.65,1323.21 1141.66,1323.21 1141.67,1323.21 1141.68,1323.21 1141.69,1323.21 1141.7,1323.21 1141.71,1323.21 1141.71,1323.21 1141.72,1323.21 1141.73,1323.21 1141.74,1323.21 1141.75,1323.21 1141.76,1323.22 1141.77,1323.22 1141.78,1323.22 1141.79,1323.22 1141.8,1323.22 1141.81,1323.22 1141.82,1323.22 1141.82,1323.22 1141.83,1323.22 1141.84,1323.22 1141.85,1323.22 1141.86,1323.22 1141.87,1323.22 1141.88,1323.22 1141.89,1323.22 1141.9,1323.22 1141.91,1323.22 1141.92,1323.22 1141.93,1323.23 1141.93,1323.23 1141.94,1323.23 1141.95,1323.23 1141.96,1323.23 1141.97,1323.23 1141.98,1323.23 1141.99,1323.23 1142,1323.23 1142.01,1323.23 1142.02,1323.23 1142.03,1323.23 1142.04,1323.23 1142.05,1323.23 1142.05,1323.23 1142.06,1323.23 1142.07,1323.23 1142.08,1323.24 1142.09,1323.24 1142.1,1323.24 1142.11,1323.24 1142.12,1323.24 1142.13,1323.24 1142.14,1323.24 1142.15,1323.24 1142.16,1323.24 1142.16,1323.24 1142.17,1323.24 1142.18,1323.24 1142.19,1323.24 1142.2,1323.24 1142.21,1323.24 1142.22,1323.24 1142.23,1323.24 1142.24,1323.25 1142.25,1323.25 1142.26,1323.25 1142.27,1323.25 1142.27,1323.25 1142.28,1323.25 1142.29,1323.25 1142.3,1323.25 1142.31,1323.25 1142.32,1323.25 1142.33,1323.25 1142.34,1323.25 1142.35,1323.25 1142.36,1323.25 1142.37,1323.25 1142.38,1323.25 1142.39,1323.25 1142.39,1323.25 1142.4,1323.26 1142.41,1323.26 1142.42,1323.26 1142.43,1323.26 1142.44,1323.26 1142.45,1323.26 1142.46,1323.26 1142.47,1323.26 1142.48,1323.26 1142.49,1323.26 1142.5,1323.26 1142.5,1323.26 1142.51,1323.26 1142.52,1323.26 1142.53,1323.26 1142.54,1323.26 1142.55,1323.26 1142.56,1323.27 1142.57,1323.27 1142.58,1323.27 1142.59,1323.27 1142.6,1323.27 1142.61,1323.27 1142.61,1323.27 1142.62,1323.27 1142.63,1323.27 1142.64,1323.27 1142.65,1323.27 1142.66,1323.27 1142.67,1323.27 1142.68,1323.27 1142.69,1323.27 1142.7,1323.27 1142.71,1323.27 1142.72,1323.28 1142.73,1323.28 1142.73,1323.28 1142.74,1323.28 1142.75,1323.28 1142.76,1323.28 1142.77,1323.28 1142.78,1323.28 1142.79,1323.28 1142.8,1323.28 1142.81,1323.28 1142.82,1323.28 1142.83,1323.28 1142.84,1323.28 1142.84,1323.28 1142.85,1323.28 1142.86,1323.28 1142.87,1323.28 1142.88,1323.29 1142.89,1323.29 1142.9,1323.29 1142.91,1323.29 1142.92,1323.29 1142.93,1323.29 1142.94,1323.29 1142.95,1323.29 1142.95,1323.29 1142.96,1323.29 1142.97,1323.29 1142.98,1323.29 1142.99,1323.29 1143,1323.29 1143.01,1323.29 1143.02,1323.29 1143.03,1323.29 1143.04,1323.3 1143.05,1323.3 1143.06,1323.3 1143.07,1323.3 1143.07,1323.3 1143.08,1323.3 1143.09,1323.3 1143.1,1323.3 1143.11,1323.3 1143.12,1323.3 1143.13,1323.3 1143.14,1323.3 1143.15,1323.3 1143.16,1323.3 1143.17,1323.3 1143.18,1323.3 1143.18,1323.3 1143.19,1323.31 1143.2,1323.31 1143.21,1323.31 1143.22,1323.31 1143.23,1323.31 1143.24,1323.31 1143.25,1323.31 1143.26,1323.31 1143.27,1323.31 1143.28,1323.31 1143.29,1323.31 1143.29,1323.31 1143.3,1323.31 1143.31,1323.31 1143.32,1323.31 1143.33,1323.31 1143.34,1323.31 1143.35,1323.31 1143.36,1323.32 1143.37,1323.32 1143.38,1323.32 1143.39,1323.32 1143.4,1323.32 1143.41,1323.32 1143.41,1323.32 1143.42,1323.32 1143.43,1323.32 1143.44,1323.32 1143.45,1323.32 1143.46,1323.32 1143.47,1323.32 1143.48,1323.32 1143.49,1323.32 1143.5,1323.32 1143.51,1323.32 1143.52,1323.33 1143.52,1323.33 1143.53,1323.33 1143.54,1323.33 1143.55,1323.33 1143.56,1323.33 1143.57,1323.33 1143.58,1323.33 1143.59,1323.33 1143.6,1323.33 1143.61,1323.33 1143.62,1323.33 1143.63,1323.33 1143.63,1323.33 1143.64,1323.33 1143.65,1323.33 1143.66,1323.33 1143.67,1323.34 1143.68,1323.34 1143.69,1323.34 1143.7,1323.34 1143.71,1323.34 1143.72,1323.34 1143.73,1323.34 1143.74,1323.34 1143.75,1323.34 1143.75,1323.34 1143.76,1323.34 1143.77,1323.34 1143.78,1323.34 1143.79,1323.34 1143.8,1323.34 1143.81,1323.34 1143.82,1323.34 1143.83,1323.34 1143.84,1323.35 1143.85,1323.35 1143.86,1323.35 1143.86,1323.35 1143.87,1323.35 1143.88,1323.35 1143.89,1323.35 1143.9,1323.35 1143.91,1323.35 1143.92,1323.35 1143.93,1323.35 1143.94,1323.35 1143.95,1323.35 1143.96,1323.35 1143.97,1323.35 1143.97,1323.35 1143.98,1323.35 1143.99,1323.36 1144,1323.36 1144.01,1323.36 1144.02,1323.36 1144.03,1323.36 1144.04,1323.36 1144.05,1323.36 1144.06,1323.36 1144.07,1323.36 1144.08,1323.36 1144.09,1323.36 1144.09,1323.36 1144.1,1323.36 1144.11,1323.36 1144.12,1323.36 1144.13,1323.36 1144.14,1323.36 1144.15,1323.37 1144.16,1323.37 1144.17,1323.37 1144.18,1323.37 1144.19,1323.37 1144.2,1323.37 1144.2,1323.37 1144.21,1323.37 1144.22,1323.37 1144.23,1323.37 1144.24,1323.37 1144.25,1323.37 1144.26,1323.37 1144.27,1323.37 1144.28,1323.37 1144.29,1323.37 1144.3,1323.37 1144.31,1323.37 1144.31,1323.38 1144.32,1323.38 1144.33,1323.38 1144.34,1323.38 1144.35,1323.38 1144.36,1323.38 1144.37,1323.38 1144.38,1323.38 1144.39,1323.38 1144.4,1323.38 1144.41,1323.38 1144.42,1323.38 1144.43,1323.38 1144.43,1323.38 1144.44,1323.38 1144.45,1323.38 1144.46,1323.38 1144.47,1323.39 1144.48,1323.39 1144.49,1323.39 1144.5,1323.39 1144.51,1323.39 1144.52,1323.39 1144.53,1323.39 1144.54,1323.39 1144.54,1323.39 1144.55,1323.39 1144.56,1323.39 1144.57,1323.39 1144.58,1323.39 1144.59,1323.39 1144.6,1323.39 1144.61,1323.39 1144.62,1323.39 1144.63,1323.4 1144.64,1323.4 1144.65,1323.4 1144.65,1323.4 1144.66,1323.4 1144.67,1323.4 1144.68,1323.4 1144.69,1323.4 1144.7,1323.4 1144.71,1323.4 1144.72,1323.4 1144.73,1323.4 1144.74,1323.4 1144.75,1323.4 1144.76,1323.4 1144.77,1323.4 1144.77,1323.4 1144.78,1323.4 1144.79,1323.41 1144.8,1323.41 1144.81,1323.41 1144.82,1323.41 1144.83,1323.41 1144.84,1323.41 1144.85,1323.41 1144.86,1323.41 1144.87,1323.41 1144.88,1323.41 1144.88,1323.41 1144.89,1323.41 1144.9,1323.41 1144.91,1323.41 1144.92,1323.41 1144.93,1323.41 1144.94,1323.41 1144.95,1323.42 1144.96,1323.42 1144.97,1323.42 1144.98,1323.42 1144.99,1323.42 1144.99,1323.42 1145,1323.42 1145.01,1323.42 1145.02,1323.42 1145.03,1323.42 1145.04,1323.42 1145.05,1323.42 1145.06,1323.42 1145.07,1323.42 1145.08,1323.42 1145.09,1323.42 1145.1,1323.42 1145.11,1323.43 1145.11,1323.43 1145.12,1323.43 1145.13,1323.43 1145.14,1323.43 1145.15,1323.43 1145.16,1323.43 1145.17,1323.43 1145.18,1323.43 1145.19,1323.43 1145.2,1323.43 1145.21,1323.43 1145.22,1323.43 1145.22,1323.43 1145.23,1323.43 1145.24,1323.43 1145.25,1323.43 1145.26,1323.43 1145.27,1323.44 1145.28,1323.44 1145.29,1323.44 1145.3,1323.44 1145.31,1323.44 1145.32,1323.44 1145.33,1323.44 1145.33,1323.44 1145.34,1323.44 1145.35,1323.44 1145.36,1323.44 1145.37,1323.44 1145.38,1323.44 1145.39,1323.44 1145.4,1323.44 1145.41,1323.44 1145.42,1323.44 1145.43,1323.45 1145.44,1323.45 1145.45,1323.45 1145.45,1323.45 1145.46,1323.45 1145.47,1323.45 1145.48,1323.45 1145.49,1323.45 1145.5,1323.45 1145.51,1323.45 1145.52,1323.45 1145.53,1323.45 1145.54,1323.45 1145.55,1323.45 1145.56,1323.45 1145.56,1323.45 1145.57,1323.45 1145.58,1323.46 1145.59,1323.46 1145.6,1323.46 1145.61,1323.46 1145.62,1323.46 1145.63,1323.46 1145.64,1323.46 1145.65,1323.46 1145.66,1323.46 1145.67,1323.46 1145.67,1323.46 1145.68,1323.46 1145.69,1323.46 1145.7,1323.46 1145.71,1323.46 1145.72,1323.46 1145.73,1323.46 1145.74,1323.46 1145.75,1323.47 1145.76,1323.47 1145.77,1323.47 1145.78,1323.47 1145.79,1323.47 1145.79,1323.47 1145.8,1323.47 1145.81,1323.47 1145.82,1323.47 1145.83,1323.47 1145.84,1323.47 1145.85,1323.47 1145.86,1323.47 1145.87,1323.47 1145.88,1323.47 1145.89,1323.47 1145.9,1323.47 1145.9,1323.48 1145.91,1323.48 1145.92,1323.48 1145.93,1323.48 1145.94,1323.48 1145.95,1323.48 1145.96,1323.48 1145.97,1323.48 1145.98,1323.48 1145.99,1323.48 1146,1323.48 1146.01,1323.48 1146.01,1323.48 1146.02,1323.48 1146.03,1323.48 1146.04,1323.48 1146.05,1323.48 1146.06,1323.48 1146.07,1323.49 1146.08,1323.49 1146.09,1323.49 1146.1,1323.49 1146.11,1323.49 1146.12,1323.49 1146.13,1323.49 1146.13,1323.49 1146.14,1323.49 1146.15,1323.49 1146.16,1323.49 1146.17,1323.49 1146.18,1323.49 1146.19,1323.49 1146.2,1323.49 1146.21,1323.49 1146.22,1323.49 1146.23,1323.5 1146.24,1323.5 1146.24,1323.5 1146.25,1323.5 1146.26,1323.5 1146.27,1323.5 1146.28,1323.5 1146.29,1323.5 1146.3,1323.5 1146.31,1323.5 1146.32,1323.5 1146.33,1323.5 1146.34,1323.5 1146.35,1323.5 1146.36,1323.5 1146.36,1323.5 1146.37,1323.5 1146.38,1323.51 1146.39,1323.51 1146.4,1323.51 1146.41,1323.51 1146.42,1323.51 1146.43,1323.51 1146.44,1323.51 1146.45,1323.51 1146.46,1323.51 1146.47,1323.51 1146.47,1323.51 1146.48,1323.51 1146.49,1323.51 1146.5,1323.51 1146.51,1323.51 1146.52,1323.51 1146.53,1323.51 1146.54,1323.51 1146.55,1323.52 1146.56,1323.52 1146.57,1323.52 1146.58,1323.52 1146.58,1323.52 1146.59,1323.52 1146.6,1323.52 1146.61,1323.52 1146.62,1323.52 1146.63,1323.52 1146.64,1323.52 1146.65,1323.52 1146.66,1323.52 1146.67,1323.52 1146.68,1323.52 1146.69,1323.52 1146.7,1323.52 1146.7,1323.53 1146.71,1323.53 1146.72,1323.53 1146.73,1323.53 1146.74,1323.53 1146.75,1323.53 1146.76,1323.53 1146.77,1323.53 1146.78,1323.53 1146.79,1323.53 1146.8,1323.53 1146.81,1323.53 1146.81,1323.53 1146.82,1323.53 1146.83,1323.53 1146.84,1323.53 1146.85,1323.53 1146.86,1323.54 1146.87,1323.54 1146.88,1323.54 1146.89,1323.54 1146.9,1323.54 1146.91,1323.54 1146.92,1323.54 1146.92,1323.54 1146.93,1323.54 1146.94,1323.54 1146.95,1323.54 1146.96,1323.54 1146.97,1323.54 1146.98,1323.54 1146.99,1323.54 1147,1323.54 1147.01,1323.54 1147.02,1323.54 1147.03,1323.55 1147.04,1323.55 1147.04,1323.55 1147.05,1323.55 1147.06,1323.55 1147.07,1323.55 1147.08,1323.55 1147.09,1323.55 1147.1,1323.55 1147.11,1323.55 1147.12,1323.55 1147.13,1323.55 1147.14,1323.55 1147.15,1323.55 1147.15,1323.55 1147.16,1323.55 1147.17,1323.55 1147.18,1323.56 1147.19,1323.56 1147.2,1323.56 1147.21,1323.56 1147.22,1323.56 1147.23,1323.56 1147.24,1323.56 1147.25,1323.56 1147.26,1323.56 1147.26,1323.56 1147.27,1323.56 1147.28,1323.56 1147.29,1323.56 1147.3,1323.56 1147.31,1323.56 1147.32,1323.56 1147.33,1323.56 1147.34,1323.56 1147.35,1323.57 1147.36,1323.57 1147.37,1323.57 1147.38,1323.57 1147.38,1323.57 1147.39,1323.57 1147.4,1323.57 1147.41,1323.57 1147.42,1323.57 1147.43,1323.57 1147.44,1323.57 1147.45,1323.57 1147.46,1323.57 1147.47,1323.57 1147.48,1323.57 1147.49,1323.57 1147.49,1323.57 1147.5,1323.58 1147.51,1323.58 1147.52,1323.58 1147.53,1323.58 1147.54,1323.58 1147.55,1323.58 1147.56,1323.58 1147.57,1323.58 1147.58,1323.58 1147.59,1323.58 1147.6,1323.58 1147.6,1323.58 1147.61,1323.58 1147.62,1323.58 1147.63,1323.58 1147.64,1323.58 1147.65,1323.58 1147.66,1323.59 1147.67,1323.59 1147.68,1323.59 1147.69,1323.59 1147.7,1323.59 1147.71,1323.59 1147.72,1323.59 1147.72,1323.59 1147.73,1323.59 1147.74,1323.59 1147.75,1323.59 1147.76,1323.59 1147.77,1323.59 1147.78,1323.59 1147.79,1323.59 1147.8,1323.59 1147.81,1323.59 1147.82,1323.59 1147.83,1323.6 1147.83,1323.6 1147.84,1323.6 1147.85,1323.6 1147.86,1323.6 1147.87,1323.6 1147.88,1323.6 1147.89,1323.6 1147.9,1323.6 1147.91,1323.6 1147.92,1323.6 1147.93,1323.6 1147.94,1323.6 1147.94,1323.6 1147.95,1323.6 1147.96,1323.6 1147.97,1323.6 1147.98,1323.61 1147.99,1323.61 1148,1323.61 1148.01,1323.61 1148.02,1323.61 1148.03,1323.61 1148.04,1323.61 1148.05,1323.61 1148.06,1323.61 1148.06,1323.61 1148.07,1323.61 1148.08,1323.61 1148.09,1323.61 1148.1,1323.61 1148.11,1323.61 1148.12,1323.61 1148.13,1323.61 1148.14,1323.62 1148.15,1323.62 1148.16,1323.62 1148.17,1323.62 1148.17,1323.62 1148.18,1323.62 1148.19,1323.62 1148.2,1323.62 1148.21,1323.62 1148.22,1323.62 1148.23,1323.62 1148.24,1323.62 1148.25,1323.62 1148.26,1323.62 1148.27,1323.62 1148.28,1323.62 1148.28,1323.62 1148.29,1323.62 1148.3,1323.63 1148.31,1323.63 1148.32,1323.63 1148.33,1323.63 1148.34,1323.63 1148.35,1323.63 1148.36,1323.63 1148.37,1323.63 1148.38,1323.63 1148.39,1323.63 1148.4,1323.63 1148.4,1323.63 1148.41,1323.63 1148.42,1323.63 1148.43,1323.63 1148.44,1323.63 1148.45,1323.63 1148.46,1323.64 1148.47,1323.64 1148.48,1323.64 1148.49,1323.64 1148.5,1323.64 1148.51,1323.64 1148.51,1323.64 1148.52,1323.64 1148.53,1323.64 1148.54,1323.64 1148.55,1323.64 1148.56,1323.64 1148.57,1323.64 1148.58,1323.64 1148.59,1323.64 1148.6,1323.64 1148.61,1323.64 1148.62,1323.64 1148.62,1323.65 1148.63,1323.65 1148.64,1323.65 1148.65,1323.65 1148.66,1323.65 1148.67,1323.65 1148.68,1323.65 1148.69,1323.65 1148.7,1323.65 1148.71,1323.65 1148.72,1323.65 1148.73,1323.65 1148.74,1323.65 1148.74,1323.65 1148.75,1323.65 1148.76,1323.65 1148.77,1323.65 1148.78,1323.66 1148.79,1323.66 1148.8,1323.66 1148.81,1323.66 1148.82,1323.66 1148.83,1323.66 1148.84,1323.66 1148.85,1323.66 1148.85,1323.66 1148.86,1323.66 1148.87,1323.66 1148.88,1323.66 1148.89,1323.66 1148.9,1323.66 1148.91,1323.66 1148.92,1323.66 1148.93,1323.66 1148.94,1323.67 1148.95,1323.67 1148.96,1323.67 1148.96,1323.67 1148.97,1323.67 1148.98,1323.67 1148.99,1323.67 1149,1323.67 1149.01,1323.67 1149.02,1323.67 1149.03,1323.67 1149.04,1323.67 1149.05,1323.67 1149.06,1323.67 1149.07,1323.67 1149.08,1323.67 1149.08,1323.67 1149.09,1323.67 1149.1,1323.68 1149.11,1323.68 1149.12,1323.68 1149.13,1323.68 1149.14,1323.68 1149.15,1323.68 1149.16,1323.68 1149.17,1323.68 1149.18,1323.68 1149.19,1323.68 1149.19,1323.68 1149.2,1323.68 1149.21,1323.68 1149.22,1323.68 1149.23,1323.68 1149.24,1323.68 1149.25,1323.68 1149.26,1323.69 1149.27,1323.69 1149.28,1323.69 1149.29,1323.69 1149.3,1323.69 1149.3,1323.69 1149.31,1323.69 1149.32,1323.69 1149.33,1323.69 1149.34,1323.69 1149.35,1323.69 1149.36,1323.69 1149.37,1323.69 1149.38,1323.69 1149.39,1323.69 1149.4,1323.69 1149.41,1323.69 1149.42,1323.69 1149.42,1323.7 1149.43,1323.7 1149.44,1323.7 1149.45,1323.7 1149.46,1323.7 1149.47,1323.7 1149.48,1323.7 1149.49,1323.7 1149.5,1323.7 1149.51,1323.7 1149.52,1323.7 1149.53,1323.7 1149.53,1323.7 1149.54,1323.7 1149.55,1323.7 1149.56,1323.7 1149.57,1323.7 1149.58,1323.71 1149.59,1323.71 1149.6,1323.71 1149.61,1323.71 1149.62,1323.71 1149.63,1323.71 1149.64,1323.71 1149.64,1323.71 1149.65,1323.71 1149.66,1323.71 1149.67,1323.71 1149.68,1323.71 1149.69,1323.71 1149.7,1323.71 1149.71,1323.71 1149.72,1323.71 1149.73,1323.71 1149.74,1323.72 1149.75,1323.72 1149.76,1323.72 1149.76,1323.72 1149.77,1323.72 1149.78,1323.72 1149.79,1323.72 1149.8,1323.72 1149.81,1323.72 1149.82,1323.72 1149.83,1323.72 1149.84,1323.72 1149.85,1323.72 1149.86,1323.72 1149.87,1323.72 1149.87,1323.72 1149.88,1323.72 1149.89,1323.72 1149.9,1323.73 1149.91,1323.73 1149.92,1323.73 1149.93,1323.73 1149.94,1323.73 1149.95,1323.73 1149.96,1323.73 1149.97,1323.73 1149.98,1323.73 1149.98,1323.73 1149.99,1323.73 1150,1323.73 1150.01,1323.73 1150.02,1323.73 1150.03,1323.73 1150.04,1323.73 1150.05,1323.73 1150.06,1323.74 1150.07,1323.74 1150.08,1323.74 1150.09,1323.74 1150.1,1323.74 1150.1,1323.74 1150.11,1323.74 1150.12,1323.74 1150.13,1323.74 1150.14,1323.74 1150.15,1323.74 1150.16,1323.74 1150.17,1323.74 1150.18,1323.74 1150.19,1323.74 1150.2,1323.74 1150.21,1323.74 1150.21,1323.74 1150.22,1323.75 1150.23,1323.75 1150.24,1323.75 1150.25,1323.75 1150.26,1323.75 1150.27,1323.75 1150.28,1323.75 1150.29,1323.75 1150.3,1323.75 1150.31,1323.75 1150.32,1323.75 1150.32,1323.75 1150.33,1323.75 1150.34,1323.75 1150.35,1323.75 1150.36,1323.75 1150.37,1323.75 1150.38,1323.76 1150.39,1323.76 1150.4,1323.76 1150.41,1323.76 1150.42,1323.76 1150.43,1323.76 1150.44,1323.76 1150.44,1323.76 1150.45,1323.76 1150.46,1323.76 1150.47,1323.76 1150.48,1323.76 1150.49,1323.76 1150.5,1323.76 1150.51,1323.76 1150.52,1323.76 1150.53,1323.76 1150.54,1323.76 1150.55,1323.77 1150.55,1323.77 1150.56,1323.77 1150.57,1323.77 1150.58,1323.77 1150.59,1323.77 1150.6,1323.77 1150.61,1323.77 1150.62,1323.77 1150.63,1323.77 1150.64,1323.77 1150.65,1323.77 1150.66,1323.77 1150.66,1323.77 1150.67,1323.77 1150.68,1323.77 1150.69,1323.77 1150.7,1323.78 1150.71,1323.78 1150.72,1323.78 1150.73,1323.78 1150.74,1323.78 1150.75,1323.78 1150.76,1323.78 1150.77,1323.78 1150.78,1323.78 1150.78,1323.78 1150.79,1323.78 1150.8,1323.78 1150.81,1323.78 1150.82,1323.78 1150.83,1323.78 1150.84,1323.78 1150.85,1323.78 1150.86,1323.79 1150.87,1323.79 1150.88,1323.79 1150.89,1323.79 1150.89,1323.79 1150.9,1323.79 1150.91,1323.79 1150.92,1323.79 1150.93,1323.79 1150.94,1323.79 1150.95,1323.79 1150.96,1323.79 1150.97,1323.79 1150.98,1323.79 1150.99,1323.79 1151,1323.79 1151,1323.79 1151.01,1323.79 1151.02,1323.8 1151.03,1323.8 1151.04,1323.8 1151.05,1323.8 1151.06,1323.8 1151.07,1323.8 1151.08,1323.8 1151.09,1323.8 1151.1,1323.8 1151.11,1323.8 1151.12,1323.8 1151.12,1323.8 1151.13,1323.8 1151.14,1323.8 1151.15,1323.8 1151.16,1323.8 1151.17,1323.8 1151.18,1323.81 1151.19,1323.81 1151.2,1323.81 1151.21,1323.81 1151.22,1323.81 1151.23,1323.81 1151.23,1323.81 1151.24,1323.81 1151.25,1323.81 1151.26,1323.81 1151.27,1323.81 1151.28,1323.81 1151.29,1323.81 1151.3,1323.81 1151.31,1323.81 1151.32,1323.81 1151.33,1323.81 1151.34,1323.81 1151.34,1323.82 1151.35,1323.82 1151.36,1323.82 1151.37,1323.82 1151.38,1323.82 1151.39,1323.82 1151.4,1323.82 1151.41,1323.82 1151.42,1323.82 1151.43,1323.82 1151.44,1323.82 1151.45,1323.82 1151.46,1323.82 1151.46,1323.82 1151.47,1323.82 1151.48,1323.82 1151.49,1323.82 1151.5,1323.83 1151.51,1323.83 1151.52,1323.83 1151.53,1323.83 1151.54,1323.83 1151.55,1323.83 1151.56,1323.83 1151.57,1323.83 1151.57,1323.83 1151.58,1323.83 1151.59,1323.83 1151.6,1323.83 1151.61,1323.83 1151.62,1323.83 1151.63,1323.83 1151.64,1323.83 1151.65,1323.83 1151.66,1323.84 1151.67,1323.84 1151.68,1323.84 1151.68,1323.84 1151.69,1323.84 1151.7,1323.84 1151.71,1323.84 1151.72,1323.84 1151.73,1323.84 1151.74,1323.84 1151.75,1323.84 1151.76,1323.84 1151.77,1323.84 1151.78,1323.84 1151.79,1323.84 1151.8,1323.84 1151.8,1323.84 1151.81,1323.84 1151.82,1323.85 1151.83,1323.85 1151.84,1323.85 1151.85,1323.85 1151.86,1323.85 1151.87,1323.85 1151.88,1323.85 1151.89,1323.85 1151.9,1323.85 1151.91,1323.85 1151.91,1323.85 1151.92,1323.85 1151.93,1323.85 1151.94,1323.85 1151.95,1323.85 1151.96,1323.85 1151.97,1323.85 1151.98,1323.86 1151.99,1323.86 1152,1323.86 1152.01,1323.86 1152.02,1323.86 1152.02,1323.86 1152.03,1323.86 1152.04,1323.86 1152.05,1323.86 1152.06,1323.86 1152.07,1323.86 1152.08,1323.86 1152.09,1323.86 1152.1,1323.86 1152.11,1323.86 1152.12,1323.86 1152.13,1323.86 1152.14,1323.86 1152.14,1323.87 1152.15,1323.87 1152.16,1323.87 1152.17,1323.87 1152.18,1323.87 1152.19,1323.87 1152.2,1323.87 1152.21,1323.87 1152.22,1323.87 1152.23,1323.87 1152.24,1323.87 1152.25,1323.87 1152.25,1323.87 1152.26,1323.87 1152.27,1323.87 1152.28,1323.87 1152.29,1323.87 1152.3,1323.88 1152.31,1323.88 1152.32,1323.88 1152.33,1323.88 1152.34,1323.88 1152.35,1323.88 1152.36,1323.88 1152.36,1323.88 1152.37,1323.88 1152.38,1323.88 1152.39,1323.88 1152.4,1323.88 1152.41,1323.88 1152.42,1323.88 1152.43,1323.88 1152.44,1323.88 1152.45,1323.88 1152.46,1323.88 1152.47,1323.89 1152.48,1323.89 1152.48,1323.89 1152.49,1323.89 1152.5,1323.89 1152.51,1323.89 1152.52,1323.89 1152.53,1323.89 1152.54,1323.89 1152.55,1323.89 1152.56,1323.89 1152.57,1323.89 1152.58,1323.89 1152.59,1323.89 1152.59,1323.89 1152.6,1323.89 1152.61,1323.89 1152.62,1323.9 1152.63,1323.9 1152.64,1323.9 1152.65,1323.9 1152.66,1323.9 1152.67,1323.9 1152.68,1323.9 1152.69,1323.9 1152.7,1323.9 1152.7,1323.9 1152.71,1323.9 1152.72,1323.9 1152.73,1323.9 1152.74,1323.9 1152.75,1323.9 1152.76,1323.9 1152.77,1323.9 1152.78,1323.9 1152.79,1323.91 1152.8,1323.91 1152.81,1323.91 1152.82,1323.91 1152.82,1323.91 1152.83,1323.91 1152.84,1323.91 1152.85,1323.91 1152.86,1323.91 1152.87,1323.91 1152.88,1323.91 1152.89,1323.91 1152.9,1323.91 1152.91,1323.91 1152.92,1323.91 1152.93,1323.91 1152.93,1323.91 1152.94,1323.92 1152.95,1323.92 1152.96,1323.92 1152.97,1323.92 1152.98,1323.92 1152.99,1323.92 1153,1323.92 1153.01,1323.92 1153.02,1323.92 1153.03,1323.92 1153.04,1323.92 1153.04,1323.92 1153.05,1323.92 1153.06,1323.92 1153.07,1323.92 1153.08,1323.92 1153.09,1323.92 1153.1,1323.93 1153.11,1323.93 1153.12,1323.93 1153.13,1323.93 1153.14,1323.93 1153.15,1323.93 1153.16,1323.93 1153.16,1323.93 1153.17,1323.93 1153.18,1323.93 1153.19,1323.93 1153.2,1323.93 1153.21,1323.93 1153.22,1323.93 1153.23,1323.93 1153.24,1323.93 1153.25,1323.93 1153.26,1323.93 1153.27,1323.94 1153.27,1323.94 1153.28,1323.94 1153.29,1323.94 1153.3,1323.94 1153.31,1323.94 1153.32,1323.94 1153.33,1323.94 1153.34,1323.94 1153.35,1323.94 1153.36,1323.94 1153.37,1323.94 1153.38,1323.94 1153.38,1323.94 1153.39,1323.94 1153.4,1323.94 1153.41,1323.94 1153.42,1323.95 1153.43,1323.95 1153.44,1323.95 1153.45,1323.95 1153.46,1323.95 1153.47,1323.95 1153.48,1323.95 1153.49,1323.95 1153.5,1323.95 1153.5,1323.95 1153.51,1323.95 1153.52,1323.95 1153.53,1323.95 1153.54,1323.95 1153.55,1323.95 1153.56,1323.95 1153.57,1323.95 1153.58,1323.95 1153.59,1323.96 1153.6,1323.96 1153.61,1323.96 1153.61,1323.96 1153.62,1323.96 1153.63,1323.96 1153.64,1323.96 1153.65,1323.96 1153.66,1323.96 1153.67,1323.96 1153.68,1323.96 1153.69,1323.96 1153.7,1323.96 1153.71,1323.96 1153.72,1323.96 1153.72,1323.96 1153.73,1323.96 1153.74,1323.97 1153.75,1323.97 1153.76,1323.97 1153.77,1323.97 1153.78,1323.97 1153.79,1323.97 1153.8,1323.97 1153.81,1323.97 1153.82,1323.97 1153.83,1323.97 1153.84,1323.97 1153.84,1323.97 1153.85,1323.97 1153.86,1323.97 1153.87,1323.97 1153.88,1323.97 1153.89,1323.97 1153.9,1323.97 1153.91,1323.98 1153.92,1323.98 1153.93,1323.98 1153.94,1323.98 1153.95,1323.98 1153.95,1323.98 1153.96,1323.98 1153.97,1323.98 1153.98,1323.98 1153.99,1323.98 1154,1323.98 1154.01,1323.98 1154.02,1323.98 1154.03,1323.98 1154.04,1323.98 1154.05,1323.98 1154.06,1323.98 1154.06,1323.99 1154.07,1323.99 1154.08,1323.99 1154.09,1323.99 1154.1,1323.99 1154.11,1323.99 1154.12,1323.99 1154.13,1323.99 1154.14,1323.99 1154.15,1323.99 1154.16,1323.99 1154.17,1323.99 1154.18,1323.99 1154.18,1323.99 1154.19,1323.99 1154.2,1323.99 "/>
<path clip-path="url(#clip400)" d="M772.63 1021.96 L1123.57 1021.96 L1123.57 866.442 L772.63 866.442  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="772.63,1021.96 1123.57,1021.96 1123.57,866.442 772.63,866.442 772.63,1021.96 "/>
<polyline clip-path="url(#clip400)" style="stroke:#009af9; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="782.841,918.282 844.102,918.282 "/>
<path clip-path="url(#clip400)" d="M882.182 903.664 L882.182 908.595 Q879.821 906.395 877.136 905.307 Q874.474 904.22 871.465 904.22 Q865.539 904.22 862.391 907.854 Q859.243 911.465 859.243 918.317 Q859.243 925.145 862.391 928.78 Q865.539 932.391 871.465 932.391 Q874.474 932.391 877.136 931.303 Q879.821 930.215 882.182 928.016 L882.182 932.9 Q879.729 934.567 876.974 935.4 Q874.243 936.233 871.187 936.233 Q863.34 936.233 858.826 931.442 Q854.312 926.627 854.312 918.317 Q854.312 909.983 858.826 905.192 Q863.34 900.377 871.187 900.377 Q874.289 900.377 877.02 901.21 Q879.775 902.02 882.182 903.664 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M905.747 910.4 L905.747 914.428 Q903.942 913.502 901.997 913.039 Q900.053 912.576 897.969 912.576 Q894.798 912.576 893.201 913.548 Q891.627 914.52 891.627 916.465 Q891.627 917.946 892.761 918.803 Q893.895 919.636 897.321 920.4 L898.78 920.724 Q903.317 921.696 905.215 923.479 Q907.136 925.238 907.136 928.409 Q907.136 932.02 904.266 934.127 Q901.418 936.233 896.418 936.233 Q894.335 936.233 892.067 935.817 Q889.821 935.423 887.321 934.613 L887.321 930.215 Q889.682 931.442 891.974 932.067 Q894.266 932.668 896.511 932.668 Q899.52 932.668 901.141 931.65 Q902.761 930.608 902.761 928.733 Q902.761 926.997 901.581 926.071 Q900.423 925.145 896.465 924.289 L894.983 923.942 Q891.025 923.108 889.266 921.395 Q887.507 919.659 887.507 916.65 Q887.507 912.993 890.099 911.002 Q892.692 909.011 897.46 909.011 Q899.821 909.011 901.905 909.358 Q903.988 909.706 905.747 910.4 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M925.701 922.53 Q920.539 922.53 918.548 923.71 Q916.557 924.891 916.557 927.738 Q916.557 930.006 918.039 931.349 Q919.543 932.668 922.113 932.668 Q925.654 932.668 927.784 930.168 Q929.937 927.645 929.937 923.479 L929.937 922.53 L925.701 922.53 M934.196 920.77 L934.196 935.562 L929.937 935.562 L929.937 931.627 Q928.479 933.988 926.303 935.122 Q924.127 936.233 920.979 936.233 Q916.997 936.233 914.636 934.011 Q912.298 931.766 912.298 928.016 Q912.298 923.641 915.215 921.419 Q918.154 919.196 923.965 919.196 L929.937 919.196 L929.937 918.78 Q929.937 915.84 927.992 914.243 Q926.071 912.622 922.576 912.622 Q920.354 912.622 918.247 913.155 Q916.141 913.687 914.196 914.752 L914.196 910.817 Q916.534 909.914 918.733 909.474 Q920.932 909.011 923.016 909.011 Q928.641 909.011 931.418 911.928 Q934.196 914.844 934.196 920.77 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M952.228 918.919 L952.228 926.141 L960.353 926.141 L960.353 928.34 L952.228 928.34 L952.228 935.562 L949.798 935.562 L949.798 928.34 L941.673 928.34 L941.673 926.141 L949.798 926.141 L949.798 918.919 L952.228 918.919 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M967.992 909.636 L972.251 909.636 L972.251 935.562 L967.992 935.562 L967.992 909.636 M967.992 899.544 L972.251 899.544 L972.251 904.937 L967.992 904.937 L967.992 899.544 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1002.71 919.914 L1002.71 935.562 L998.455 935.562 L998.455 920.053 Q998.455 916.372 997.02 914.544 Q995.585 912.715 992.714 912.715 Q989.265 912.715 987.274 914.914 Q985.284 917.113 985.284 920.909 L985.284 935.562 L981.001 935.562 L981.001 909.636 L985.284 909.636 L985.284 913.664 Q986.812 911.326 988.872 910.169 Q990.955 909.011 993.663 909.011 Q998.131 909.011 1000.42 911.789 Q1002.71 914.544 1002.71 919.914 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1020.47 918.919 L1020.47 926.141 L1028.59 926.141 L1028.59 928.34 L1020.47 928.34 L1020.47 935.562 L1018.04 935.562 L1018.04 928.34 L1009.91 928.34 L1009.91 926.141 L1018.04 926.141 L1018.04 918.919 L1020.47 918.919 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1038.78 922.622 Q1038.78 927.321 1040.7 930.006 Q1042.64 932.668 1046.02 932.668 Q1049.4 932.668 1051.35 930.006 Q1053.29 927.321 1053.29 922.622 Q1053.29 917.923 1051.35 915.261 Q1049.4 912.576 1046.02 912.576 Q1042.64 912.576 1040.7 915.261 Q1038.78 917.923 1038.78 922.622 M1053.29 931.673 Q1051.95 933.988 1049.89 935.122 Q1047.85 936.233 1044.98 936.233 Q1040.28 936.233 1037.32 932.483 Q1034.38 928.733 1034.38 922.622 Q1034.38 916.511 1037.32 912.761 Q1040.28 909.011 1044.98 909.011 Q1047.85 909.011 1049.89 910.145 Q1051.95 911.257 1053.29 913.571 L1053.29 909.636 L1057.55 909.636 L1057.55 945.423 L1053.29 945.423 L1053.29 931.673 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1076.56 899.59 Q1073.45 904.914 1071.95 910.122 Q1070.45 915.331 1070.45 920.678 Q1070.45 926.025 1071.95 931.28 Q1073.48 936.511 1076.56 941.812 L1072.85 941.812 Q1069.38 936.372 1067.64 931.118 Q1065.93 925.863 1065.93 920.678 Q1065.93 915.516 1067.64 910.284 Q1069.36 905.053 1072.85 899.59 L1076.56 899.59 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1089.03 902.275 L1089.03 909.636 L1097.81 909.636 L1097.81 912.946 L1089.03 912.946 L1089.03 927.02 Q1089.03 930.192 1089.89 931.094 Q1090.77 931.997 1093.43 931.997 L1097.81 931.997 L1097.81 935.562 L1093.43 935.562 Q1088.5 935.562 1086.63 933.733 Q1084.75 931.881 1084.75 927.02 L1084.75 912.946 L1081.63 912.946 L1081.63 909.636 L1084.75 909.636 L1084.75 902.275 L1089.03 902.275 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1102.74 899.59 L1106.44 899.59 Q1109.91 905.053 1111.63 910.284 Q1113.36 915.516 1113.36 920.678 Q1113.36 925.863 1111.63 931.118 Q1109.91 936.372 1106.44 941.812 L1102.74 941.812 Q1105.82 936.511 1107.32 931.28 Q1108.85 926.025 1108.85 920.678 Q1108.85 915.331 1107.32 910.122 Q1105.82 904.914 1102.74 899.59 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip400)" style="stroke:#e26f46; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="782.841,970.122 844.102,970.122 "/>
<path clip-path="url(#clip400)" d="M882.182 955.504 L882.182 960.435 Q879.821 958.235 877.136 957.147 Q874.474 956.06 871.465 956.06 Q865.539 956.06 862.391 959.694 Q859.243 963.305 859.243 970.157 Q859.243 976.985 862.391 980.62 Q865.539 984.231 871.465 984.231 Q874.474 984.231 877.136 983.143 Q879.821 982.055 882.182 979.856 L882.182 984.74 Q879.729 986.407 876.974 987.24 Q874.243 988.073 871.187 988.073 Q863.34 988.073 858.826 983.282 Q854.312 978.467 854.312 970.157 Q854.312 961.823 858.826 957.032 Q863.34 952.217 871.187 952.217 Q874.289 952.217 877.02 953.05 Q879.775 953.86 882.182 955.504 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M905.747 962.24 L905.747 966.268 Q903.942 965.342 901.997 964.879 Q900.053 964.416 897.969 964.416 Q894.798 964.416 893.201 965.388 Q891.627 966.36 891.627 968.305 Q891.627 969.786 892.761 970.643 Q893.895 971.476 897.321 972.24 L898.78 972.564 Q903.317 973.536 905.215 975.319 Q907.136 977.078 907.136 980.249 Q907.136 983.86 904.266 985.967 Q901.418 988.073 896.418 988.073 Q894.335 988.073 892.067 987.657 Q889.821 987.263 887.321 986.453 L887.321 982.055 Q889.682 983.282 891.974 983.907 Q894.266 984.508 896.511 984.508 Q899.52 984.508 901.141 983.49 Q902.761 982.448 902.761 980.573 Q902.761 978.837 901.581 977.911 Q900.423 976.985 896.465 976.129 L894.983 975.782 Q891.025 974.948 889.266 973.235 Q887.507 971.499 887.507 968.49 Q887.507 964.833 890.099 962.842 Q892.692 960.851 897.46 960.851 Q899.821 960.851 901.905 961.198 Q903.988 961.546 905.747 962.24 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M910.863 961.476 L915.377 961.476 L923.479 983.235 L931.58 961.476 L936.094 961.476 L926.372 987.402 L920.585 987.402 L910.863 961.476 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M951.233 970.759 L951.233 977.981 L959.358 977.981 L959.358 980.18 L951.233 980.18 L951.233 987.402 L948.802 987.402 L948.802 980.18 L940.678 980.18 L940.678 977.981 L948.802 977.981 L948.802 970.759 L951.233 970.759 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M966.997 961.476 L971.256 961.476 L971.256 987.402 L966.997 987.402 L966.997 961.476 M966.997 951.384 L971.256 951.384 L971.256 956.777 L966.997 956.777 L966.997 951.384 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1001.72 971.754 L1001.72 987.402 L997.46 987.402 L997.46 971.893 Q997.46 968.212 996.024 966.384 Q994.589 964.555 991.719 964.555 Q988.27 964.555 986.279 966.754 Q984.288 968.953 984.288 972.749 L984.288 987.402 L980.006 987.402 L980.006 961.476 L984.288 961.476 L984.288 965.504 Q985.816 963.166 987.876 962.009 Q989.96 960.851 992.668 960.851 Q997.136 960.851 999.427 963.629 Q1001.72 966.384 1001.72 971.754 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1019.47 970.759 L1019.47 977.981 L1027.6 977.981 L1027.6 980.18 L1019.47 980.18 L1019.47 987.402 L1017.04 987.402 L1017.04 980.18 L1008.92 980.18 L1008.92 977.981 L1017.04 977.981 L1017.04 970.759 L1019.47 970.759 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1037.78 974.462 Q1037.78 979.161 1039.7 981.846 Q1041.65 984.508 1045.03 984.508 Q1048.41 984.508 1050.35 981.846 Q1052.3 979.161 1052.3 974.462 Q1052.3 969.763 1050.35 967.101 Q1048.41 964.416 1045.03 964.416 Q1041.65 964.416 1039.7 967.101 Q1037.78 969.763 1037.78 974.462 M1052.3 983.513 Q1050.95 985.828 1048.89 986.962 Q1046.86 988.073 1043.99 988.073 Q1039.29 988.073 1036.33 984.323 Q1033.39 980.573 1033.39 974.462 Q1033.39 968.351 1036.33 964.601 Q1039.29 960.851 1043.99 960.851 Q1046.86 960.851 1048.89 961.985 Q1050.95 963.097 1052.3 965.411 L1052.3 961.476 L1056.56 961.476 L1056.56 997.263 L1052.3 997.263 L1052.3 983.513 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1075.56 951.43 Q1072.46 956.754 1070.95 961.962 Q1069.45 967.171 1069.45 972.518 Q1069.45 977.865 1070.95 983.12 Q1072.48 988.351 1075.56 993.652 L1071.86 993.652 Q1068.39 988.212 1066.65 982.958 Q1064.94 977.703 1064.94 972.518 Q1064.94 967.356 1066.65 962.124 Q1068.36 956.893 1071.86 951.43 L1075.56 951.43 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1088.04 954.115 L1088.04 961.476 L1096.81 961.476 L1096.81 964.786 L1088.04 964.786 L1088.04 978.86 Q1088.04 982.032 1088.89 982.934 Q1089.77 983.837 1092.44 983.837 L1096.81 983.837 L1096.81 987.402 L1092.44 987.402 Q1087.51 987.402 1085.63 985.573 Q1083.76 983.721 1083.76 978.86 L1083.76 964.786 L1080.63 964.786 L1080.63 961.476 L1083.76 961.476 L1083.76 954.115 L1088.04 954.115 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1101.74 951.43 L1105.45 951.43 Q1108.92 956.893 1110.63 962.124 Q1112.37 967.356 1112.37 972.518 Q1112.37 977.703 1110.63 982.958 Q1108.92 988.212 1105.45 993.652 L1101.74 993.652 Q1104.82 988.351 1106.32 983.12 Q1107.85 977.865 1107.85 972.518 Q1107.85 967.171 1106.32 961.962 Q1104.82 956.754 1101.74 951.43 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1433.84 1423.18 L2352.76 1423.18 L2352.76 847.244 L1433.84 847.244  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip405">
    <rect x="1433" y="847" width="920" height="577"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip405)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1572.05,1423.18 1572.05,847.244 "/>
<polyline clip-path="url(#clip405)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1821.21,1423.18 1821.21,847.244 "/>
<polyline clip-path="url(#clip405)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2070.37,1423.18 2070.37,847.244 "/>
<polyline clip-path="url(#clip405)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2319.53,1423.18 2319.53,847.244 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1433.84,1423.18 2352.76,1423.18 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1572.05,1423.18 1572.05,1404.28 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1821.21,1423.18 1821.21,1404.28 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2070.37,1423.18 2070.37,1404.28 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2319.53,1423.18 2319.53,1404.28 "/>
<path clip-path="url(#clip400)" d="M1531.65 1481.64 L1539.29 1481.64 L1539.29 1455.28 L1530.98 1456.95 L1530.98 1452.69 L1539.25 1451.02 L1543.92 1451.02 L1543.92 1481.64 L1551.56 1481.64 L1551.56 1485.58 L1531.65 1485.58 L1531.65 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1571.01 1454.1 Q1567.39 1454.1 1565.57 1457.66 Q1563.76 1461.2 1563.76 1468.33 Q1563.76 1475.44 1565.57 1479.01 Q1567.39 1482.55 1571.01 1482.55 Q1574.64 1482.55 1576.45 1479.01 Q1578.27 1475.44 1578.27 1468.33 Q1578.27 1461.2 1576.45 1457.66 Q1574.64 1454.1 1571.01 1454.1 M1571.01 1450.39 Q1576.82 1450.39 1579.87 1455 Q1582.95 1459.58 1582.95 1468.33 Q1582.95 1477.06 1579.87 1481.67 Q1576.82 1486.25 1571.01 1486.25 Q1565.2 1486.25 1562.12 1481.67 Q1559.06 1477.06 1559.06 1468.33 Q1559.06 1459.58 1562.12 1455 Q1565.2 1450.39 1571.01 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1601.17 1454.1 Q1597.56 1454.1 1595.73 1457.66 Q1593.92 1461.2 1593.92 1468.33 Q1593.92 1475.44 1595.73 1479.01 Q1597.56 1482.55 1601.17 1482.55 Q1604.8 1482.55 1606.61 1479.01 Q1608.44 1475.44 1608.44 1468.33 Q1608.44 1461.2 1606.61 1457.66 Q1604.8 1454.1 1601.17 1454.1 M1601.17 1450.39 Q1606.98 1450.39 1610.03 1455 Q1613.11 1459.58 1613.11 1468.33 Q1613.11 1477.06 1610.03 1481.67 Q1606.98 1486.25 1601.17 1486.25 Q1595.36 1486.25 1592.28 1481.67 Q1589.22 1477.06 1589.22 1468.33 Q1589.22 1459.58 1592.28 1455 Q1595.36 1450.39 1601.17 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1780.82 1481.64 L1788.46 1481.64 L1788.46 1455.28 L1780.15 1456.95 L1780.15 1452.69 L1788.41 1451.02 L1793.08 1451.02 L1793.08 1481.64 L1800.72 1481.64 L1800.72 1485.58 L1780.82 1485.58 L1780.82 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1810.21 1451.02 L1828.57 1451.02 L1828.57 1454.96 L1814.5 1454.96 L1814.5 1463.43 Q1815.52 1463.08 1816.53 1462.92 Q1817.55 1462.73 1818.57 1462.73 Q1824.36 1462.73 1827.74 1465.9 Q1831.12 1469.08 1831.12 1474.49 Q1831.12 1480.07 1827.64 1483.17 Q1824.17 1486.25 1817.85 1486.25 Q1815.68 1486.25 1813.41 1485.88 Q1811.16 1485.51 1808.76 1484.77 L1808.76 1480.07 Q1810.84 1481.2 1813.06 1481.76 Q1815.28 1482.32 1817.76 1482.32 Q1821.77 1482.32 1824.1 1480.21 Q1826.44 1478.1 1826.44 1474.49 Q1826.44 1470.88 1824.1 1468.77 Q1821.77 1466.67 1817.76 1466.67 Q1815.89 1466.67 1814.01 1467.08 Q1812.16 1467.5 1810.21 1468.38 L1810.21 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1850.33 1454.1 Q1846.72 1454.1 1844.89 1457.66 Q1843.08 1461.2 1843.08 1468.33 Q1843.08 1475.44 1844.89 1479.01 Q1846.72 1482.55 1850.33 1482.55 Q1853.96 1482.55 1855.77 1479.01 Q1857.6 1475.44 1857.6 1468.33 Q1857.6 1461.2 1855.77 1457.66 Q1853.96 1454.1 1850.33 1454.1 M1850.33 1450.39 Q1856.14 1450.39 1859.2 1455 Q1862.27 1459.58 1862.27 1468.33 Q1862.27 1477.06 1859.2 1481.67 Q1856.14 1486.25 1850.33 1486.25 Q1844.52 1486.25 1841.44 1481.67 Q1838.39 1477.06 1838.39 1468.33 Q1838.39 1459.58 1841.44 1455 Q1844.52 1450.39 1850.33 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2034.06 1481.64 L2050.38 1481.64 L2050.38 1485.58 L2028.44 1485.58 L2028.44 1481.64 Q2031.1 1478.89 2035.68 1474.26 Q2040.29 1469.61 2041.47 1468.27 Q2043.72 1465.74 2044.6 1464.01 Q2045.5 1462.25 2045.5 1460.56 Q2045.5 1457.8 2043.56 1456.07 Q2041.63 1454.33 2038.53 1454.33 Q2036.33 1454.33 2033.88 1455.09 Q2031.45 1455.86 2028.67 1457.41 L2028.67 1452.69 Q2031.49 1451.55 2033.95 1450.97 Q2036.4 1450.39 2038.44 1450.39 Q2043.81 1450.39 2047 1453.08 Q2050.2 1455.77 2050.2 1460.26 Q2050.2 1462.39 2049.39 1464.31 Q2048.6 1466.2 2046.49 1468.8 Q2045.92 1469.47 2042.81 1472.69 Q2039.71 1475.88 2034.06 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2070.2 1454.1 Q2066.59 1454.1 2064.76 1457.66 Q2062.95 1461.2 2062.95 1468.33 Q2062.95 1475.44 2064.76 1479.01 Q2066.59 1482.55 2070.2 1482.55 Q2073.83 1482.55 2075.64 1479.01 Q2077.47 1475.44 2077.47 1468.33 Q2077.47 1461.2 2075.64 1457.66 Q2073.83 1454.1 2070.2 1454.1 M2070.2 1450.39 Q2076.01 1450.39 2079.06 1455 Q2082.14 1459.58 2082.14 1468.33 Q2082.14 1477.06 2079.06 1481.67 Q2076.01 1486.25 2070.2 1486.25 Q2064.39 1486.25 2061.31 1481.67 Q2058.25 1477.06 2058.25 1468.33 Q2058.25 1459.58 2061.31 1455 Q2064.39 1450.39 2070.2 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2100.36 1454.1 Q2096.75 1454.1 2094.92 1457.66 Q2093.11 1461.2 2093.11 1468.33 Q2093.11 1475.44 2094.92 1479.01 Q2096.75 1482.55 2100.36 1482.55 Q2103.99 1482.55 2105.8 1479.01 Q2107.63 1475.44 2107.63 1468.33 Q2107.63 1461.2 2105.8 1457.66 Q2103.99 1454.1 2100.36 1454.1 M2100.36 1450.39 Q2106.17 1450.39 2109.23 1455 Q2112.3 1459.58 2112.3 1468.33 Q2112.3 1477.06 2109.23 1481.67 Q2106.17 1486.25 2100.36 1486.25 Q2094.55 1486.25 2091.47 1481.67 Q2088.42 1477.06 2088.42 1468.33 Q2088.42 1459.58 2091.47 1455 Q2094.55 1450.39 2100.36 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2283.23 1481.64 L2299.55 1481.64 L2299.55 1485.58 L2277.6 1485.58 L2277.6 1481.64 Q2280.26 1478.89 2284.85 1474.26 Q2289.45 1469.61 2290.63 1468.27 Q2292.88 1465.74 2293.76 1464.01 Q2294.66 1462.25 2294.66 1460.56 Q2294.66 1457.8 2292.72 1456.07 Q2290.8 1454.33 2287.69 1454.33 Q2285.5 1454.33 2283.04 1455.09 Q2280.61 1455.86 2277.83 1457.41 L2277.83 1452.69 Q2280.66 1451.55 2283.11 1450.97 Q2285.56 1450.39 2287.6 1450.39 Q2292.97 1450.39 2296.17 1453.08 Q2299.36 1455.77 2299.36 1460.26 Q2299.36 1462.39 2298.55 1464.31 Q2297.76 1466.2 2295.66 1468.8 Q2295.08 1469.47 2291.98 1472.69 Q2288.87 1475.88 2283.23 1481.64 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2309.41 1451.02 L2327.76 1451.02 L2327.76 1454.96 L2313.69 1454.96 L2313.69 1463.43 Q2314.71 1463.08 2315.73 1462.92 Q2316.74 1462.73 2317.76 1462.73 Q2323.55 1462.73 2326.93 1465.9 Q2330.31 1469.08 2330.31 1474.49 Q2330.31 1480.07 2326.84 1483.17 Q2323.37 1486.25 2317.05 1486.25 Q2314.87 1486.25 2312.6 1485.88 Q2310.36 1485.51 2307.95 1484.77 L2307.95 1480.07 Q2310.03 1481.2 2312.25 1481.76 Q2314.48 1482.32 2316.95 1482.32 Q2320.96 1482.32 2323.3 1480.21 Q2325.63 1478.1 2325.63 1474.49 Q2325.63 1470.88 2323.3 1468.77 Q2320.96 1466.67 2316.95 1466.67 Q2315.08 1466.67 2313.2 1467.08 Q2311.35 1467.5 2309.41 1468.38 L2309.41 1451.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2349.52 1454.1 Q2345.91 1454.1 2344.08 1457.66 Q2342.28 1461.2 2342.28 1468.33 Q2342.28 1475.44 2344.08 1479.01 Q2345.91 1482.55 2349.52 1482.55 Q2353.16 1482.55 2354.96 1479.01 Q2356.79 1475.44 2356.79 1468.33 Q2356.79 1461.2 2354.96 1457.66 Q2353.16 1454.1 2349.52 1454.1 M2349.52 1450.39 Q2355.33 1450.39 2358.39 1455 Q2361.47 1459.58 2361.47 1468.33 Q2361.47 1477.06 2358.39 1481.67 Q2355.33 1486.25 2349.52 1486.25 Q2343.71 1486.25 2340.63 1481.67 Q2337.58 1477.06 2337.58 1468.33 Q2337.58 1459.58 2340.63 1455 Q2343.71 1450.39 2349.52 1450.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1716.68 1568.04 L1698.54 1520.52 L1705.25 1520.52 L1720.31 1560.53 L1735.39 1520.52 L1742.08 1520.52 L1723.97 1568.04 L1716.68 1568.04 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1757.52 1536.5 Q1752.8 1536.5 1750.07 1540.19 Q1747.33 1543.85 1747.33 1550.25 Q1747.33 1556.65 1750.04 1560.34 Q1752.77 1564 1757.52 1564 Q1762.19 1564 1764.93 1560.31 Q1767.67 1556.62 1767.67 1550.25 Q1767.67 1543.92 1764.93 1540.23 Q1762.19 1536.5 1757.52 1536.5 M1757.52 1531.54 Q1765.15 1531.54 1769.51 1536.5 Q1773.88 1541.47 1773.88 1550.25 Q1773.88 1559 1769.51 1564 Q1765.15 1568.97 1757.52 1568.97 Q1749.84 1568.97 1745.48 1564 Q1741.16 1559 1741.16 1550.25 Q1741.16 1541.47 1745.48 1536.5 Q1749.84 1531.54 1757.52 1531.54 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1783.58 1518.52 L1789.44 1518.52 L1789.44 1568.04 L1783.58 1568.04 L1783.58 1518.52 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1801.09 1553.98 L1801.09 1532.4 L1806.95 1532.4 L1806.95 1553.75 Q1806.95 1558.81 1808.92 1561.36 Q1810.89 1563.87 1814.84 1563.87 Q1819.58 1563.87 1822.32 1560.85 Q1825.09 1557.83 1825.09 1552.61 L1825.09 1532.4 L1830.94 1532.4 L1830.94 1568.04 L1825.09 1568.04 L1825.09 1562.57 Q1822.95 1565.82 1820.12 1567.41 Q1817.32 1568.97 1813.6 1568.97 Q1807.45 1568.97 1804.27 1565.15 Q1801.09 1561.33 1801.09 1553.98 M1815.83 1531.54 L1815.83 1531.54 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1870.76 1539.24 Q1872.96 1535.29 1876.01 1533.41 Q1879.07 1531.54 1883.21 1531.54 Q1888.78 1531.54 1891.8 1535.45 Q1894.82 1539.33 1894.82 1546.53 L1894.82 1568.04 L1888.94 1568.04 L1888.94 1546.72 Q1888.94 1541.59 1887.12 1539.11 Q1885.31 1536.63 1881.58 1536.63 Q1877.03 1536.63 1874.39 1539.65 Q1871.75 1542.68 1871.75 1547.9 L1871.75 1568.04 L1865.86 1568.04 L1865.86 1546.72 Q1865.86 1541.56 1864.05 1539.11 Q1862.23 1536.63 1858.44 1536.63 Q1853.96 1536.63 1851.31 1539.68 Q1848.67 1542.71 1848.67 1547.9 L1848.67 1568.04 L1842.78 1568.04 L1842.78 1532.4 L1848.67 1532.4 L1848.67 1537.93 Q1850.68 1534.66 1853.48 1533.1 Q1856.28 1531.54 1860.13 1531.54 Q1864.01 1531.54 1866.72 1533.51 Q1869.46 1535.48 1870.76 1539.24 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1937 1548.76 L1937 1551.62 L1910.07 1551.62 Q1910.45 1557.67 1913.7 1560.85 Q1916.98 1564 1922.8 1564 Q1926.17 1564 1929.33 1563.17 Q1932.51 1562.35 1935.63 1560.69 L1935.63 1566.23 Q1932.48 1567.57 1929.17 1568.27 Q1925.86 1568.97 1922.45 1568.97 Q1913.92 1568.97 1908.92 1564 Q1903.96 1559.04 1903.96 1550.57 Q1903.96 1541.82 1908.67 1536.69 Q1913.41 1531.54 1921.43 1531.54 Q1928.63 1531.54 1932.8 1536.18 Q1937 1540.8 1937 1548.76 M1931.14 1547.04 Q1931.08 1542.23 1928.43 1539.37 Q1925.82 1536.5 1921.5 1536.5 Q1916.59 1536.5 1913.63 1539.27 Q1910.71 1542.04 1910.26 1547.07 L1931.14 1547.04 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1966.79 1518.52 L1980.28 1518.52 L1980.28 1523.07 L1972.64 1523.07 L1972.64 1572.09 L1980.28 1572.09 L1980.28 1576.64 L1966.79 1576.64 L1966.79 1518.52 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2020.51 1539.24 Q2022.71 1535.29 2025.77 1533.41 Q2028.82 1531.54 2032.96 1531.54 Q2038.53 1531.54 2041.55 1535.45 Q2044.58 1539.33 2044.58 1546.53 L2044.58 1568.04 L2038.69 1568.04 L2038.69 1546.72 Q2038.69 1541.59 2036.87 1539.11 Q2035.06 1536.63 2031.34 1536.63 Q2026.78 1536.63 2024.14 1539.65 Q2021.5 1542.68 2021.5 1547.9 L2021.5 1568.04 L2015.61 1568.04 L2015.61 1546.72 Q2015.61 1541.56 2013.8 1539.11 Q2011.98 1536.63 2008.2 1536.63 Q2003.71 1536.63 2001.07 1539.68 Q1998.43 1542.71 1998.43 1547.9 L1998.43 1568.04 L1992.54 1568.04 L1992.54 1532.4 L1998.43 1532.4 L1998.43 1537.93 Q2000.43 1534.66 2003.23 1533.1 Q2006.03 1531.54 2009.88 1531.54 Q2013.77 1531.54 2016.47 1533.51 Q2019.21 1535.48 2020.51 1539.24 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2056.26 1518.52 L2062.11 1518.52 L2062.11 1568.04 L2056.26 1568.04 L2056.26 1518.52 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2088.05 1518.52 L2088.05 1576.64 L2074.56 1576.64 L2074.56 1572.09 L2082.17 1572.09 L2082.17 1523.07 L2074.56 1523.07 L2074.56 1518.52 L2088.05 1518.52 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip405)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1433.84,1317.07 2352.76,1317.07 "/>
<polyline clip-path="url(#clip405)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1433.84,1209.67 2352.76,1209.67 "/>
<polyline clip-path="url(#clip405)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1433.84,1102.28 2352.76,1102.28 "/>
<polyline clip-path="url(#clip405)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1433.84,994.881 2352.76,994.881 "/>
<polyline clip-path="url(#clip405)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1433.84,887.486 2352.76,887.486 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1433.84,1423.18 1433.84,847.244 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1433.84,1317.07 1452.73,1317.07 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1433.84,1209.67 1452.73,1209.67 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1433.84,1102.28 1452.73,1102.28 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1433.84,994.881 1452.73,994.881 "/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1433.84,887.486 1452.73,887.486 "/>
<path clip-path="url(#clip400)" d="M1350.75 1330.41 L1367.07 1330.41 L1367.07 1334.35 L1345.13 1334.35 L1345.13 1330.41 Q1347.79 1327.66 1352.37 1323.03 Q1356.98 1318.38 1358.16 1317.03 Q1360.41 1314.51 1361.29 1312.77 Q1362.19 1311.01 1362.19 1309.32 Q1362.19 1306.57 1360.24 1304.83 Q1358.32 1303.1 1355.22 1303.1 Q1353.02 1303.1 1350.57 1303.86 Q1348.14 1304.63 1345.36 1306.18 L1345.36 1301.45 Q1348.18 1300.32 1350.64 1299.74 Q1353.09 1299.16 1355.13 1299.16 Q1360.5 1299.16 1363.69 1301.85 Q1366.89 1304.53 1366.89 1309.02 Q1366.89 1311.15 1366.08 1313.07 Q1365.29 1314.97 1363.18 1317.57 Q1362.6 1318.24 1359.5 1321.45 Q1356.4 1324.65 1350.75 1330.41 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1376.93 1299.79 L1395.29 1299.79 L1395.29 1303.72 L1381.22 1303.72 L1381.22 1312.19 Q1382.23 1311.85 1383.25 1311.69 Q1384.27 1311.5 1385.29 1311.5 Q1391.08 1311.5 1394.46 1314.67 Q1397.84 1317.84 1397.84 1323.26 Q1397.84 1328.84 1394.36 1331.94 Q1390.89 1335.02 1384.57 1335.02 Q1382.4 1335.02 1380.13 1334.65 Q1377.88 1334.28 1375.48 1333.54 L1375.48 1328.84 Q1377.56 1329.97 1379.78 1330.53 Q1382 1331.08 1384.48 1331.08 Q1388.48 1331.08 1390.82 1328.98 Q1393.16 1326.87 1393.16 1323.26 Q1393.16 1319.65 1390.82 1317.54 Q1388.48 1315.44 1384.48 1315.44 Q1382.6 1315.44 1380.73 1315.85 Q1378.88 1316.27 1376.93 1317.15 L1376.93 1299.79 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1345.78 1192.39 L1364.13 1192.39 L1364.13 1196.33 L1350.06 1196.33 L1350.06 1204.8 Q1351.08 1204.45 1352.1 1204.29 Q1353.11 1204.1 1354.13 1204.1 Q1359.92 1204.1 1363.3 1207.28 Q1366.68 1210.45 1366.68 1215.86 Q1366.68 1221.44 1363.21 1224.54 Q1359.73 1227.62 1353.42 1227.62 Q1351.24 1227.62 1348.97 1227.25 Q1346.73 1226.88 1344.32 1226.14 L1344.32 1221.44 Q1346.4 1222.58 1348.62 1223.13 Q1350.85 1223.69 1353.32 1223.69 Q1357.33 1223.69 1359.67 1221.58 Q1362 1219.48 1362 1215.86 Q1362 1212.25 1359.67 1210.15 Q1357.33 1208.04 1353.32 1208.04 Q1351.45 1208.04 1349.57 1208.46 Q1347.72 1208.87 1345.78 1209.75 L1345.78 1192.39 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1385.89 1195.47 Q1382.28 1195.47 1380.45 1199.04 Q1378.65 1202.58 1378.65 1209.71 Q1378.65 1216.81 1380.45 1220.38 Q1382.28 1223.92 1385.89 1223.92 Q1389.53 1223.92 1391.33 1220.38 Q1393.16 1216.81 1393.16 1209.71 Q1393.16 1202.58 1391.33 1199.04 Q1389.53 1195.47 1385.89 1195.47 M1385.89 1191.77 Q1391.7 1191.77 1394.76 1196.37 Q1397.84 1200.96 1397.84 1209.71 Q1397.84 1218.43 1394.76 1223.04 Q1391.7 1227.62 1385.89 1227.62 Q1380.08 1227.62 1377 1223.04 Q1373.95 1218.43 1373.95 1209.71 Q1373.95 1200.96 1377 1196.37 Q1380.08 1191.77 1385.89 1191.77 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1345.54 1085 L1367.77 1085 L1367.77 1086.99 L1355.22 1119.56 L1350.34 1119.56 L1362.14 1088.93 L1345.54 1088.93 L1345.54 1085 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1376.93 1085 L1395.29 1085 L1395.29 1088.93 L1381.22 1088.93 L1381.22 1097.4 Q1382.23 1097.06 1383.25 1096.89 Q1384.27 1096.71 1385.29 1096.71 Q1391.08 1096.71 1394.46 1099.88 Q1397.84 1103.05 1397.84 1108.47 Q1397.84 1114.05 1394.36 1117.15 Q1390.89 1120.23 1384.57 1120.23 Q1382.4 1120.23 1380.13 1119.86 Q1377.88 1119.49 1375.48 1118.75 L1375.48 1114.05 Q1377.56 1115.18 1379.78 1115.74 Q1382 1116.29 1384.48 1116.29 Q1388.48 1116.29 1390.82 1114.19 Q1393.16 1112.08 1393.16 1108.47 Q1393.16 1104.86 1390.82 1102.75 Q1388.48 1100.64 1384.48 1100.64 Q1382.6 1100.64 1380.73 1101.06 Q1378.88 1101.48 1376.93 1102.36 L1376.93 1085 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1316.38 1008.23 L1324.02 1008.23 L1324.02 981.86 L1315.71 983.527 L1315.71 979.268 L1323.97 977.601 L1328.65 977.601 L1328.65 1008.23 L1336.29 1008.23 L1336.29 1012.16 L1316.38 1012.16 L1316.38 1008.23 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1355.73 980.68 Q1352.12 980.68 1350.29 984.245 Q1348.48 987.786 1348.48 994.916 Q1348.48 1002.02 1350.29 1005.59 Q1352.12 1009.13 1355.73 1009.13 Q1359.36 1009.13 1361.17 1005.59 Q1363 1002.02 1363 994.916 Q1363 987.786 1361.17 984.245 Q1359.36 980.68 1355.73 980.68 M1355.73 976.976 Q1361.54 976.976 1364.6 981.583 Q1367.67 986.166 1367.67 994.916 Q1367.67 1003.64 1364.6 1008.25 Q1361.54 1012.83 1355.73 1012.83 Q1349.92 1012.83 1346.84 1008.25 Q1343.79 1003.64 1343.79 994.916 Q1343.79 986.166 1346.84 981.583 Q1349.92 976.976 1355.73 976.976 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1385.89 980.68 Q1382.28 980.68 1380.45 984.245 Q1378.65 987.786 1378.65 994.916 Q1378.65 1002.02 1380.45 1005.59 Q1382.28 1009.13 1385.89 1009.13 Q1389.53 1009.13 1391.33 1005.59 Q1393.16 1002.02 1393.16 994.916 Q1393.16 987.786 1391.33 984.245 Q1389.53 980.68 1385.89 980.68 M1385.89 976.976 Q1391.7 976.976 1394.76 981.583 Q1397.84 986.166 1397.84 994.916 Q1397.84 1003.64 1394.76 1008.25 Q1391.7 1012.83 1385.89 1012.83 Q1380.08 1012.83 1377 1008.25 Q1373.95 1003.64 1373.95 994.916 Q1373.95 986.166 1377 981.583 Q1380.08 976.976 1385.89 976.976 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1317.37 900.831 L1325.01 900.831 L1325.01 874.465 L1316.7 876.132 L1316.7 871.872 L1324.97 870.206 L1329.64 870.206 L1329.64 900.831 L1337.28 900.831 L1337.28 904.766 L1317.37 904.766 L1317.37 900.831 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1350.75 900.831 L1367.07 900.831 L1367.07 904.766 L1345.13 904.766 L1345.13 900.831 Q1347.79 898.076 1352.37 893.446 Q1356.98 888.794 1358.16 887.451 Q1360.41 884.928 1361.29 883.192 Q1362.19 881.433 1362.19 879.743 Q1362.19 876.988 1360.24 875.252 Q1358.32 873.516 1355.22 873.516 Q1353.02 873.516 1350.57 874.28 Q1348.14 875.044 1345.36 876.595 L1345.36 871.872 Q1348.18 870.738 1350.64 870.159 Q1353.09 869.581 1355.13 869.581 Q1360.5 869.581 1363.69 872.266 Q1366.89 874.951 1366.89 879.442 Q1366.89 881.571 1366.08 883.493 Q1365.29 885.391 1363.18 887.983 Q1362.6 888.655 1359.5 891.872 Q1356.4 895.067 1350.75 900.831 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1376.93 870.206 L1395.29 870.206 L1395.29 874.141 L1381.22 874.141 L1381.22 882.613 Q1382.23 882.266 1383.25 882.104 Q1384.27 881.919 1385.29 881.919 Q1391.08 881.919 1394.46 885.09 Q1397.84 888.261 1397.84 893.678 Q1397.84 899.257 1394.36 902.358 Q1390.89 905.437 1384.57 905.437 Q1382.4 905.437 1380.13 905.067 Q1377.88 904.696 1375.48 903.956 L1375.48 899.257 Q1377.56 900.391 1379.78 900.946 Q1382 901.502 1384.48 901.502 Q1388.48 901.502 1390.82 899.395 Q1393.16 897.289 1393.16 893.678 Q1393.16 890.067 1390.82 887.96 Q1388.48 885.854 1384.48 885.854 Q1382.6 885.854 1380.73 886.27 Q1378.88 886.687 1376.93 887.567 L1376.93 870.206 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1223.21 1406.44 L1241.07 1406.44 L1241.07 1398.35 Q1241.07 1393.87 1238.75 1391.42 Q1236.42 1388.96 1232.13 1388.96 Q1227.86 1388.96 1225.54 1391.42 Q1223.21 1393.87 1223.21 1398.35 L1223.21 1406.44 M1217.93 1412.87 L1217.93 1398.35 Q1217.93 1390.37 1221.56 1386.29 Q1225.16 1382.19 1232.13 1382.19 Q1239.16 1382.19 1242.76 1386.29 Q1246.35 1390.37 1246.35 1398.35 L1246.35 1406.44 L1265.45 1406.44 L1265.45 1412.87 L1217.93 1412.87 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1235.28 1354.3 Q1234.7 1355.29 1234.45 1356.47 Q1234.16 1357.61 1234.16 1359.01 Q1234.16 1363.98 1237.41 1366.65 Q1240.62 1369.29 1246.67 1369.29 L1265.45 1369.29 L1265.45 1375.18 L1229.8 1375.18 L1229.8 1369.29 L1235.34 1369.29 Q1232.09 1367.45 1230.54 1364.49 Q1228.94 1361.53 1228.94 1357.3 Q1228.94 1356.69 1229.04 1355.96 Q1229.1 1355.23 1229.26 1354.34 L1235.28 1354.3 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1246.16 1319.1 L1249.03 1319.1 L1249.03 1346.03 Q1255.07 1345.65 1258.26 1342.4 Q1261.41 1339.12 1261.41 1333.3 Q1261.41 1329.92 1260.58 1326.77 Q1259.75 1323.59 1258.1 1320.47 L1263.64 1320.47 Q1264.97 1323.62 1265.67 1326.93 Q1266.37 1330.24 1266.37 1333.65 Q1266.37 1342.18 1261.41 1347.17 Q1256.44 1352.14 1247.98 1352.14 Q1239.22 1352.14 1234.1 1347.43 Q1228.94 1342.69 1228.94 1334.67 Q1228.94 1327.47 1233.59 1323.3 Q1238.21 1319.1 1246.16 1319.1 M1244.44 1324.96 Q1239.64 1325.02 1236.77 1327.66 Q1233.91 1330.27 1233.91 1334.6 Q1233.91 1339.5 1236.68 1342.46 Q1239.45 1345.39 1244.48 1345.84 L1244.44 1324.96 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1230.85 1286.76 L1236.39 1286.76 Q1235.12 1289.25 1234.48 1291.92 Q1233.85 1294.59 1233.85 1297.46 Q1233.85 1301.82 1235.18 1304.01 Q1236.52 1306.18 1239.19 1306.18 Q1241.23 1306.18 1242.41 1304.62 Q1243.55 1303.06 1244.6 1298.35 L1245.05 1296.34 Q1246.39 1290.11 1248.84 1287.5 Q1251.26 1284.85 1255.62 1284.85 Q1260.58 1284.85 1263.48 1288.8 Q1266.37 1292.72 1266.37 1299.59 Q1266.37 1302.45 1265.8 1305.57 Q1265.26 1308.66 1264.15 1312.1 L1258.1 1312.1 Q1259.79 1308.85 1260.64 1305.7 Q1261.47 1302.55 1261.47 1299.46 Q1261.47 1295.33 1260.07 1293.1 Q1258.64 1290.87 1256.06 1290.87 Q1253.67 1290.87 1252.4 1292.49 Q1251.13 1294.08 1249.95 1299.53 L1249.47 1301.56 Q1248.33 1307.01 1245.97 1309.43 Q1243.58 1311.84 1239.45 1311.84 Q1234.42 1311.84 1231.68 1308.28 Q1228.94 1304.71 1228.94 1298.16 Q1228.94 1294.91 1229.42 1292.05 Q1229.9 1289.18 1230.85 1286.76 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1230.85 1252.8 L1236.39 1252.8 Q1235.12 1255.29 1234.48 1257.96 Q1233.85 1260.63 1233.85 1263.5 Q1233.85 1267.86 1235.18 1270.05 Q1236.52 1272.22 1239.19 1272.22 Q1241.23 1272.22 1242.41 1270.66 Q1243.55 1269.1 1244.6 1264.39 L1245.05 1262.38 Q1246.39 1256.14 1248.84 1253.53 Q1251.26 1250.89 1255.62 1250.89 Q1260.58 1250.89 1263.48 1254.84 Q1266.37 1258.75 1266.37 1265.63 Q1266.37 1268.49 1265.8 1271.61 Q1265.26 1274.7 1264.15 1278.14 L1258.1 1278.14 Q1259.79 1274.89 1260.64 1271.74 Q1261.47 1268.59 1261.47 1265.5 Q1261.47 1261.36 1260.07 1259.14 Q1258.64 1256.91 1256.06 1256.91 Q1253.67 1256.91 1252.4 1258.53 Q1251.13 1260.12 1249.95 1265.57 L1249.47 1267.6 Q1248.33 1273.05 1245.97 1275.46 Q1243.58 1277.88 1239.45 1277.88 Q1234.42 1277.88 1231.68 1274.32 Q1228.94 1270.75 1228.94 1264.2 Q1228.94 1260.95 1229.42 1258.09 Q1229.9 1255.22 1230.85 1252.8 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1251.38 1242.17 L1229.8 1242.17 L1229.8 1236.32 L1251.16 1236.32 Q1256.22 1236.32 1258.77 1234.34 Q1261.28 1232.37 1261.28 1228.42 Q1261.28 1223.68 1258.26 1220.94 Q1255.23 1218.17 1250.01 1218.17 L1229.8 1218.17 L1229.8 1212.32 L1265.45 1212.32 L1265.45 1218.17 L1259.98 1218.17 Q1263.22 1220.31 1264.81 1223.14 Q1266.37 1225.94 1266.37 1229.66 Q1266.37 1235.81 1262.55 1238.99 Q1258.74 1242.17 1251.38 1242.17 M1228.94 1227.44 L1228.94 1227.44 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1235.28 1179.6 Q1234.7 1180.58 1234.45 1181.76 Q1234.16 1182.91 1234.16 1184.31 Q1234.16 1189.27 1237.41 1191.95 Q1240.62 1194.59 1246.67 1194.59 L1265.45 1194.59 L1265.45 1200.48 L1229.8 1200.48 L1229.8 1194.59 L1235.34 1194.59 Q1232.09 1192.74 1230.54 1189.78 Q1228.94 1186.82 1228.94 1182.59 Q1228.94 1181.98 1229.04 1181.25 Q1229.1 1180.52 1229.26 1179.63 L1235.28 1179.6 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1246.16 1144.39 L1249.03 1144.39 L1249.03 1171.32 Q1255.07 1170.94 1258.26 1167.69 Q1261.41 1164.41 1261.41 1158.59 Q1261.41 1155.22 1260.58 1152.07 Q1259.75 1148.88 1258.1 1145.76 L1263.64 1145.76 Q1264.97 1148.91 1265.67 1152.22 Q1266.37 1155.53 1266.37 1158.94 Q1266.37 1167.47 1261.41 1172.47 Q1256.44 1177.43 1247.98 1177.43 Q1239.22 1177.43 1234.1 1172.72 Q1228.94 1167.98 1228.94 1159.96 Q1228.94 1152.77 1233.59 1148.6 Q1238.21 1144.39 1246.16 1144.39 M1244.44 1150.25 Q1239.64 1150.31 1236.77 1152.96 Q1233.91 1155.57 1233.91 1159.89 Q1233.91 1164.8 1236.68 1167.76 Q1239.45 1170.68 1244.48 1171.13 L1244.44 1150.25 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1215.93 1114.6 L1215.93 1101.11 L1220.48 1101.11 L1220.48 1108.75 L1269.49 1108.75 L1269.49 1101.11 L1274.04 1101.11 L1274.04 1114.6 L1215.93 1114.6 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1236.65 1060.88 Q1232.7 1058.68 1230.82 1055.62 Q1228.94 1052.57 1228.94 1048.43 Q1228.94 1042.86 1232.86 1039.84 Q1236.74 1036.81 1243.93 1036.81 L1265.45 1036.81 L1265.45 1042.7 L1244.13 1042.7 Q1239 1042.7 1236.52 1044.52 Q1234.04 1046.33 1234.04 1050.05 Q1234.04 1054.61 1237.06 1057.25 Q1240.08 1059.89 1245.3 1059.89 L1265.45 1059.89 L1265.45 1065.78 L1244.13 1065.78 Q1238.97 1065.78 1236.52 1067.59 Q1234.04 1069.41 1234.04 1073.19 Q1234.04 1077.68 1237.09 1080.32 Q1240.12 1082.97 1245.3 1082.97 L1265.45 1082.97 L1265.45 1088.85 L1229.8 1088.85 L1229.8 1082.97 L1235.34 1082.97 Q1232.06 1080.96 1230.5 1078.16 Q1228.94 1075.36 1228.94 1071.51 Q1228.94 1067.62 1230.92 1064.92 Q1232.89 1062.18 1236.65 1060.88 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1236.65 997.379 Q1232.7 995.182 1230.82 992.127 Q1228.94 989.071 1228.94 984.934 Q1228.94 979.364 1232.86 976.34 Q1236.74 973.316 1243.93 973.316 L1265.45 973.316 L1265.45 979.204 L1244.13 979.204 Q1239 979.204 1236.52 981.019 Q1234.04 982.833 1234.04 986.557 Q1234.04 991.108 1237.06 993.75 Q1240.08 996.392 1245.3 996.392 L1265.45 996.392 L1265.45 1002.28 L1244.13 1002.28 Q1238.97 1002.28 1236.52 1004.09 Q1234.04 1005.91 1234.04 1009.7 Q1234.04 1014.18 1237.09 1016.83 Q1240.12 1019.47 1245.3 1019.47 L1265.45 1019.47 L1265.45 1025.36 L1229.8 1025.36 L1229.8 1019.47 L1235.34 1019.47 Q1232.06 1017.46 1230.5 1014.66 Q1228.94 1011.86 1228.94 1008.01 Q1228.94 1004.13 1230.92 1001.42 Q1232.89 998.683 1236.65 997.379 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1217.93 961.38 L1217.93 954.951 L1237.41 954.951 L1237.41 931.589 L1217.93 931.589 L1217.93 925.16 L1265.45 925.16 L1265.45 931.589 L1242.82 931.589 L1242.82 954.951 L1265.45 954.951 L1265.45 961.38 L1217.93 961.38 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1247.21 889.161 Q1240.85 889.161 1237.35 891.803 Q1233.85 894.413 1233.85 899.156 Q1233.85 903.866 1237.35 906.508 Q1240.85 909.118 1247.21 909.118 Q1253.55 909.118 1257.05 906.508 Q1260.55 903.866 1260.55 899.156 Q1260.55 894.413 1257.05 891.803 Q1253.55 889.161 1247.21 889.161 M1261.03 883.305 Q1270.13 883.305 1274.55 887.347 Q1279.01 891.389 1279.01 899.729 Q1279.01 902.816 1278.53 905.553 Q1278.09 908.29 1277.13 910.869 L1271.43 910.869 Q1272.84 908.29 1273.5 905.776 Q1274.17 903.262 1274.17 900.652 Q1274.17 894.891 1271.15 892.026 Q1268.16 889.161 1262.08 889.161 L1259.18 889.161 Q1262.33 890.976 1263.89 893.808 Q1265.45 896.641 1265.45 900.588 Q1265.45 907.145 1260.45 911.155 Q1255.46 915.165 1247.21 915.165 Q1238.94 915.165 1233.94 911.155 Q1228.94 907.145 1228.94 900.588 Q1228.94 896.641 1230.5 893.808 Q1232.06 890.976 1235.21 889.161 L1229.8 889.161 L1229.8 883.305 L1261.03 883.305 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1215.93 857.556 L1274.04 857.556 L1274.04 871.051 L1269.49 871.051 L1269.49 863.444 L1220.48 863.444 L1220.48 871.051 L1215.93 871.051 L1215.93 857.556 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip405)" style="stroke:#009af9; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1877.49,1403.68 1877.51,1403.67 1877.51,1403.67 1877.51,1403.67 1877.52,1403.66 1877.52,1403.66 1877.52,1403.65 1877.52,1403.65 1877.53,1403.64 1877.53,1403.64 1877.53,1403.63 1877.53,1403.63 1877.54,1403.62 1877.54,1403.61 1877.54,1403.61 1877.54,1403.6 1877.55,1403.59 1877.55,1403.59 1877.55,1403.58 1877.55,1403.57 1877.56,1403.57 1877.56,1403.56 1877.56,1403.55 1877.56,1403.54 1877.57,1403.54 1877.57,1403.53 1877.57,1403.52 1877.57,1403.51 1877.58,1403.51 1877.58,1403.5 1877.58,1403.49 1877.58,1403.48 1877.58,1403.47 1877.59,1403.46 1877.59,1403.46 1877.59,1403.45 1877.59,1403.44 1877.6,1403.43 1877.6,1403.42 1877.6,1403.41 1877.6,1403.4 1877.6,1403.39 1877.61,1403.39 1877.61,1403.38 1877.61,1403.37 1877.61,1403.36 1877.61,1403.35 1877.62,1403.34 1877.62,1403.33 1877.62,1403.32 1877.62,1403.31 1877.62,1403.3 1877.63,1403.29 1877.63,1403.28 1877.63,1403.27 1877.63,1403.26 1877.63,1403.25 1877.64,1403.24 1877.64,1403.23 1877.64,1403.22 1877.64,1403.21 1877.64,1403.2 1877.64,1403.19 1877.65,1403.18 1877.65,1403.17 1877.65,1403.16 1877.65,1403.15 1877.65,1403.14 1877.66,1403.13 1877.66,1403.12 1877.66,1403.11 1877.66,1403.1 1877.66,1403.09 1877.66,1403.08 1877.66,1403.06 1877.67,1403.05 1877.67,1403.04 1877.67,1403.03 1877.67,1403.02 1877.67,1403.01 1877.67,1403 1877.68,1402.99 1877.68,1402.98 1877.68,1402.97 1877.68,1402.95 1877.68,1402.94 1877.68,1402.93 1877.68,1402.92 1877.69,1402.91 1877.69,1402.9 1877.69,1402.89 1877.69,1402.87 1877.69,1402.86 1877.69,1402.85 1877.69,1402.84 1877.69,1402.83 1877.7,1402.82 1877.7,1402.8 1877.7,1402.79 1877.7,1402.78 1877.7,1402.77 1877.7,1402.76 1877.7,1402.74 1877.7,1402.73 1877.7,1402.72 1877.7,1402.71 1877.71,1402.7 1877.71,1402.68 1877.71,1402.67 1877.71,1402.66 1877.71,1402.65 1877.71,1402.63 1877.71,1402.62 1877.71,1402.61 1877.71,1402.6 1877.71,1402.58 1877.71,1402.57 1877.72,1402.56 1877.72,1402.55 1877.72,1402.53 1877.72,1402.52 1877.72,1402.51 1877.72,1402.5 1877.72,1402.48 1877.72,1402.47 1877.72,1402.46 1877.72,1402.45 1877.72,1402.43 1877.72,1402.42 1877.72,1402.41 1877.72,1402.39 1877.72,1402.38 1877.72,1402.37 1877.72,1402.35 1877.73,1402.34 1877.73,1402.33 1877.73,1402.32 1877.73,1402.3 1877.73,1402.29 1877.73,1402.28 1877.73,1402.26 1877.73,1402.25 1877.73,1402.24 1877.73,1402.22 1877.73,1402.21 1877.73,1402.2 1877.73,1402.18 1877.73,1402.17 1877.73,1402.16 1877.73,1402.14 1877.73,1402.13 1877.73,1402.11 1877.73,1402.1 1877.73,1402.09 1877.73,1402.07 1877.73,1402.06 1877.73,1402.05 1877.73,1402.03 1877.73,1402.02 1877.73,1402.01 1877.73,1401.99 1877.73,1401.98 1877.73,1401.96 1877.73,1401.95 1877.73,1401.94 1877.73,1401.92 1877.73,1401.91 1877.73,1401.89 1877.73,1401.88 1877.73,1401.87 1877.73,1401.85 1877.73,1401.84 1877.73,1401.82 1877.73,1401.81 1877.73,1401.8 1877.73,1401.78 1877.73,1401.77 1877.73,1401.75 1877.73,1401.74 1877.73,1401.72 1877.73,1401.71 1877.73,1401.7 1877.73,1401.68 1877.73,1401.67 1877.73,1401.65 1877.73,1401.64 1877.73,1401.62 1877.73,1401.61 1877.73,1401.59 1877.73,1401.58 1877.73,1401.56 1877.73,1401.55 1877.73,1401.54 1877.73,1401.52 1877.73,1401.51 1877.73,1401.49 1877.73,1401.48 1877.73,1401.46 1877.73,1401.45 1877.73,1401.43 1877.73,1401.42 1877.73,1401.4 1877.73,1401.39 1877.73,1401.37 1877.73,1401.36 1877.73,1401.34 1877.73,1401.33 1877.73,1401.31 1877.73,1401.3 1877.73,1401.28 1877.73,1401.27 1877.73,1401.25 1877.73,1401.24 1877.73,1401.22 1877.73,1401.21 1877.73,1401.19 1877.73,1401.18 1877.73,1401.16 1877.73,1401.15 1877.73,1401.13 1877.73,1401.12 1877.73,1401.1 1877.73,1401.09 1877.73,1401.07 1877.73,1401.05 1877.73,1401.04 1877.73,1401.02 1877.73,1401.01 1877.73,1400.99 1877.73,1400.98 1877.73,1400.96 1877.73,1400.95 1877.73,1400.93 1877.73,1400.92 1877.73,1400.9 1877.73,1400.88 1877.73,1400.87 1877.73,1400.85 1877.73,1400.84 1877.73,1400.82 1877.73,1400.81 1877.73,1400.79 1877.73,1400.77 1877.73,1400.76 1877.73,1400.74 1877.73,1400.73 1877.73,1400.71 1877.73,1400.69 1877.73,1400.68 1877.73,1400.66 1877.73,1400.65 1877.73,1400.63 1877.73,1400.62 1877.73,1400.6 1877.73,1400.58 1877.73,1400.57 1877.73,1400.55 1877.73,1400.54 1877.73,1400.52 1877.73,1400.5 1877.73,1400.49 1877.73,1400.47 1877.73,1400.45 1877.73,1400.44 1877.73,1400.42 1877.73,1400.41 1877.73,1400.39 1877.73,1400.37 1877.73,1400.36 1877.73,1400.34 1877.73,1400.32 1877.73,1400.31 1877.73,1400.29 1877.73,1400.28 1877.73,1400.26 1877.73,1400.24 1877.73,1400.23 1877.73,1400.21 1877.73,1400.19 1877.73,1400.18 1877.73,1400.16 1877.73,1400.14 1877.73,1400.13 1877.73,1400.11 1877.73,1400.09 1877.73,1400.08 1877.73,1400.06 1877.73,1400.04 1877.73,1400.03 1877.73,1400.01 1877.73,1399.99 1877.73,1399.98 1877.73,1399.96 1877.73,1399.94 1877.73,1399.93 1877.73,1399.91 1877.73,1399.89 1877.73,1399.88 1877.73,1399.86 1877.73,1399.84 1877.73,1399.83 1877.73,1399.81 1877.73,1399.79 1877.73,1399.78 1877.73,1399.76 1877.73,1399.74 1877.73,1399.73 1877.73,1399.71 1877.73,1399.69 1877.73,1399.67 1877.73,1399.66 1877.73,1399.64 1877.73,1399.62 1877.73,1399.61 1877.73,1399.59 1877.73,1399.57 1877.73,1399.55 1877.73,1399.54 1877.73,1399.52 1877.73,1399.5 1877.73,1399.49 1877.73,1399.47 1877.73,1399.45 1877.73,1399.43 1877.73,1399.42 1877.73,1399.4 1877.73,1399.38 1877.73,1399.36 1877.73,1399.35 1877.73,1399.33 1877.73,1399.31 1877.73,1399.3 1877.73,1399.28 1877.73,1399.26 1877.73,1399.24 1877.73,1399.23 1877.73,1399.21 1877.73,1399.19 1877.73,1399.17 1877.73,1399.16 1877.73,1399.14 1877.73,1399.12 1877.73,1399.1 1877.73,1399.09 1877.73,1399.07 1877.73,1399.05 1877.73,1399.03 1877.73,1399.01 1877.73,1399 1877.73,1398.98 1877.73,1398.96 1877.73,1398.94 1877.73,1398.93 1877.73,1398.91 1877.73,1398.89 1877.73,1398.87 1877.73,1398.86 1877.73,1398.84 1877.73,1398.82 1877.73,1398.8 1877.73,1398.78 1877.73,1398.77 1877.73,1398.75 1877.73,1398.73 1877.73,1398.71 1877.73,1398.69 1877.73,1398.68 1877.73,1398.66 1877.73,1398.64 1877.73,1398.62 1877.73,1398.6 1877.73,1398.59 1877.73,1398.57 1877.73,1398.55 1877.73,1398.53 1877.73,1398.51 1877.73,1398.5 1877.73,1398.48 1877.73,1398.46 1877.73,1398.44 1877.73,1398.42 1877.73,1398.41 1877.73,1398.39 1877.73,1398.37 1877.73,1398.35 1877.73,1398.33 1877.73,1398.31 1877.73,1398.3 1877.73,1398.28 1877.73,1398.26 1877.73,1398.24 1877.73,1398.22 1877.73,1398.2 1877.73,1398.19 1877.73,1398.17 1877.73,1398.15 1877.73,1398.13 1877.73,1398.11 1877.73,1398.09 1877.73,1398.08 1877.73,1398.06 1877.73,1398.04 1877.73,1398.02 1877.73,1398 1877.73,1397.98 1877.73,1397.96 1877.73,1397.95 1877.73,1397.93 1877.73,1397.91 1877.73,1397.89 1877.73,1397.87 1877.73,1397.85 1877.73,1397.83 1877.73,1397.82 1877.73,1397.8 1877.73,1397.78 1877.73,1397.76 1877.73,1397.74 1877.73,1397.72 1877.73,1397.7 1877.73,1397.69 1877.73,1397.67 1877.73,1397.65 1877.73,1397.63 1877.73,1397.61 1877.73,1397.59 1877.73,1397.57 1877.73,1397.55 1877.73,1397.53 1877.73,1397.52 1877.73,1397.5 1877.73,1397.48 1877.73,1397.46 1877.73,1397.44 1877.73,1397.42 1877.73,1397.4 1877.73,1397.38 1877.73,1397.36 1877.73,1397.35 1877.73,1397.33 1877.73,1397.31 1877.73,1397.29 1877.73,1397.27 1877.73,1397.25 1877.73,1397.23 1877.73,1397.21 1877.73,1397.19 1877.73,1397.17 1877.73,1397.15 1877.73,1397.14 1877.73,1397.12 1877.73,1397.1 1877.73,1397.08 1877.73,1397.06 1877.73,1397.04 1877.73,1397.02 1877.73,1397 1877.73,1396.98 1877.73,1396.96 1877.73,1396.94 1877.73,1396.92 1877.73,1396.91 1877.73,1396.89 1877.73,1396.87 1877.73,1396.85 1877.73,1396.83 1877.73,1396.81 1877.73,1396.79 1877.73,1396.77 1877.73,1396.75 1877.73,1396.73 1877.73,1396.71 1877.73,1396.69 1877.73,1396.67 1877.73,1396.65 1877.73,1396.63 1877.73,1396.61 1877.73,1396.59 1877.73,1396.58 1877.73,1396.56 1877.73,1396.54 1877.73,1396.52 1877.73,1396.5 1877.73,1396.48 1877.73,1396.46 1877.73,1396.44 1877.73,1396.42 1877.73,1396.4 1877.73,1396.38 1877.73,1396.36 1877.73,1396.34 1877.73,1396.32 1877.73,1396.3 1877.73,1396.28 1877.73,1396.26 1877.73,1396.24 1877.73,1396.22 1877.73,1396.2 1877.73,1396.18 1877.73,1396.16 1877.73,1396.14 1877.73,1396.12 1877.73,1396.1 1877.73,1396.08 1877.73,1396.06 1877.73,1396.04 1877.73,1396.02 1877.73,1396 1877.73,1395.98 1877.73,1395.96 1877.73,1395.94 1877.73,1395.92 1877.73,1395.9 1877.73,1395.88 1877.73,1395.86 1877.73,1395.85 1877.73,1395.83 1877.73,1395.81 1877.73,1395.79 1877.73,1395.77 1877.73,1395.75 1877.73,1395.73 1877.73,1395.71 1877.73,1395.68 1877.73,1395.66 1877.73,1395.64 1877.73,1395.62 1877.73,1395.6 1877.73,1395.58 1877.73,1395.56 1877.73,1395.54 1877.73,1395.52 1877.73,1395.5 1877.73,1395.48 1877.73,1395.46 1877.73,1395.44 1877.73,1395.42 1877.73,1395.4 1877.73,1395.38 1877.73,1395.36 1877.73,1395.34 1877.73,1395.32 1877.73,1395.3 1877.73,1395.28 1877.73,1395.26 1877.73,1395.24 1877.73,1395.22 1877.73,1395.2 1877.73,1395.18 1877.73,1395.16 1877.73,1395.14 1877.73,1395.12 1877.73,1395.1 1877.73,1395.08 1877.73,1395.06 1877.73,1395.04 1877.73,1395.02 1877.73,1395 1877.73,1394.98 1877.73,1394.96 1877.73,1394.93 1877.73,1394.91 1877.73,1394.89 1877.73,1394.87 1877.73,1394.85 1877.73,1394.83 1877.73,1394.81 1877.73,1394.79 1877.73,1394.77 1877.73,1394.75 1877.73,1394.73 1877.73,1394.71 1877.73,1394.69 1877.73,1394.67 1877.73,1394.65 1877.73,1394.63 1877.73,1394.61 1877.73,1394.58 1877.73,1394.56 1877.73,1394.54 1877.73,1394.52 1877.73,1394.5 1877.73,1394.48 1877.73,1394.46 1877.73,1394.44 1877.73,1394.42 1877.73,1394.4 1877.73,1394.38 1877.73,1394.36 1877.73,1394.34 1877.73,1394.32 1877.73,1394.29 1877.73,1394.27 1877.73,1394.25 1877.73,1394.23 1877.73,1394.21 1877.73,1394.19 1877.73,1394.17 1877.73,1394.15 1877.73,1394.13 1877.73,1394.11 1877.73,1394.09 1877.73,1394.06 1877.73,1394.04 1877.73,1394.02 1877.73,1394 1877.73,1393.98 1877.73,1393.96 1877.73,1393.94 1877.73,1393.92 1877.73,1393.9 1877.73,1393.88 1877.73,1393.85 1877.73,1393.83 1877.73,1393.81 1877.73,1393.79 1877.73,1393.77 1877.73,1393.75 1877.73,1393.73 1877.73,1393.71 1877.73,1393.69 1877.73,1393.66 1877.73,1393.64 1877.73,1393.62 1877.73,1393.6 1877.73,1393.58 1877.73,1393.56 1877.73,1393.54 1877.73,1393.52 1877.73,1393.5 1877.73,1393.47 1877.73,1393.45 1877.73,1393.43 1877.73,1393.41 1877.73,1393.39 1877.73,1393.37 1877.73,1393.35 1877.73,1393.33 1877.73,1393.3 1877.73,1393.28 1877.73,1393.26 1877.73,1393.24 1877.73,1393.22 1877.73,1393.2 1877.73,1393.18 1877.73,1393.15 1877.73,1393.13 1877.73,1393.11 1877.73,1393.09 1877.73,1393.07 1877.73,1393.05 1877.73,1393.03 1877.73,1393 1877.73,1392.98 1877.73,1392.96 1877.73,1392.94 1877.73,1392.92 1877.73,1392.9 1877.73,1392.88 1877.73,1392.85 1877.73,1392.83 1877.73,1392.81 1877.73,1392.79 1877.73,1392.77 1877.73,1392.75 1877.73,1392.72 1877.73,1392.7 1877.73,1392.68 1877.73,1392.66 1877.73,1392.64 1877.73,1392.62 1877.73,1392.6 1877.73,1392.57 1877.73,1392.55 1877.73,1392.53 1877.73,1392.51 1877.73,1392.49 1877.73,1392.47 1877.73,1392.44 1877.73,1392.42 1877.73,1392.4 1877.73,1392.38 1877.73,1392.36 1877.73,1392.33 1877.73,1392.31 1877.73,1392.29 1877.73,1392.27 1877.73,1392.25 1877.73,1392.23 1877.73,1392.2 1877.73,1392.18 1877.73,1392.16 1877.73,1392.14 1877.73,1392.12 1877.73,1392.09 1877.73,1392.07 1877.73,1392.05 1877.73,1392.03 1877.73,1392.01 1877.73,1391.99 1877.73,1391.96 1877.73,1391.94 1877.73,1391.92 1877.73,1391.9 1877.73,1391.88 1877.73,1391.85 1877.73,1391.83 1877.73,1391.81 1877.73,1391.79 1877.73,1391.77 1877.73,1391.74 1877.73,1391.72 1877.73,1391.7 1877.73,1391.68 1877.73,1391.66 1877.73,1391.63 1877.73,1391.61 1877.73,1391.59 1877.73,1391.57 1877.73,1391.55 1877.73,1391.52 1877.73,1391.5 1877.73,1391.48 1877.73,1391.46 1877.73,1391.43 1877.73,1391.41 1877.73,1391.39 1877.73,1391.37 1877.73,1391.35 1877.73,1391.32 1877.73,1391.3 1877.73,1391.28 1877.73,1391.26 1877.73,1391.23 1877.73,1391.21 1877.73,1391.19 1877.73,1391.17 1877.73,1391.15 1877.73,1391.12 1877.73,1391.1 1877.73,1391.08 1877.73,1391.06 1877.73,1391.03 1877.73,1391.01 1877.73,1390.99 1877.73,1390.97 1877.73,1390.95 1877.73,1390.92 1877.73,1390.9 1877.73,1390.88 1877.73,1390.86 1877.73,1390.83 1877.73,1390.81 1877.73,1390.79 1877.73,1390.77 1877.73,1390.74 1877.73,1390.72 1877.73,1390.7 1877.73,1390.68 1877.73,1390.65 1877.73,1390.63 1877.73,1390.61 1877.73,1390.59 1877.73,1390.56 1877.73,1390.54 1877.73,1390.52 1877.73,1390.5 1877.73,1390.47 1877.73,1390.45 1877.73,1390.43 1877.73,1390.41 1877.73,1390.38 1877.73,1390.36 1877.73,1390.34 1877.73,1390.32 1877.73,1390.29 1877.73,1390.27 1877.73,1390.25 1877.73,1390.23 1877.73,1390.2 1877.73,1390.18 1877.73,1390.16 1877.73,1390.13 1877.73,1390.11 1877.73,1390.09 1877.73,1390.07 1877.73,1390.04 1877.73,1390.02 1877.73,1390 1877.73,1389.98 1877.73,1389.95 1877.73,1389.93 1877.73,1389.91 1877.73,1389.88 1877.73,1389.86 1877.73,1389.84 1877.73,1389.82 1877.73,1389.79 1877.73,1389.77 1877.73,1389.75 1877.73,1389.73 1877.73,1389.7 1877.73,1389.68 1877.73,1389.66 1877.73,1389.63 1877.73,1389.61 1877.73,1389.59 1877.73,1389.57 1877.73,1389.54 1877.73,1389.52 1877.73,1389.5 1877.73,1389.47 1877.73,1389.45 1877.73,1389.43 1877.73,1389.41 1877.73,1389.38 1877.73,1389.36 1877.73,1389.34 1877.73,1389.31 1877.73,1389.29 1877.73,1389.27 1877.73,1389.24 1877.73,1389.22 1877.73,1389.2 1877.73,1389.18 1877.73,1389.15 1877.73,1389.13 1877.73,1389.11 1877.73,1389.08 1877.73,1389.06 1877.73,1389.04 1877.73,1389.01 1877.73,1388.99 1877.73,1388.97 1877.73,1388.94 1877.73,1388.92 1877.73,1388.9 1877.73,1388.88 1877.73,1388.85 1877.73,1388.83 1877.73,1388.81 1877.73,1388.78 1877.73,1388.76 1877.73,1388.74 1877.73,1388.71 1877.73,1388.69 1877.73,1388.67 1877.73,1388.64 1877.73,1388.62 1877.73,1388.6 1877.73,1388.57 1877.73,1388.55 1877.73,1388.53 1877.73,1388.5 1877.73,1388.48 1877.73,1388.46 1877.73,1388.43 1877.73,1388.41 1877.73,1388.39 1877.73,1388.36 1877.73,1388.34 1877.73,1388.32 1877.73,1388.29 1877.73,1388.27 1877.73,1388.25 1877.73,1388.22 1877.73,1388.2 1877.73,1388.18 1877.73,1388.15 1877.73,1388.13 1877.73,1388.11 1877.73,1388.08 1877.73,1388.06 1877.73,1388.04 1877.73,1388.01 1877.73,1387.99 1877.73,1387.97 1877.73,1387.94 1877.73,1387.92 1877.73,1387.9 1877.73,1387.87 1877.73,1387.85 1877.73,1387.83 1877.73,1387.8 1877.73,1387.78 1877.73,1387.76 1877.73,1387.73 1877.73,1387.71 1877.73,1387.69 1877.73,1387.66 1877.73,1387.64 1877.73,1387.61 1877.73,1387.59 1877.73,1387.57 1877.73,1387.54 1877.73,1387.52 1877.73,1387.5 1877.73,1387.47 1877.73,1387.45 1877.73,1387.43 1877.73,1387.4 1877.73,1387.38 1877.73,1387.35 1877.73,1387.33 1877.73,1387.31 1877.73,1387.28 1877.73,1387.26 1877.73,1387.24 1877.73,1387.21 1877.73,1387.19 1877.73,1387.17 1877.73,1387.14 1877.73,1387.12 1877.73,1387.09 1877.73,1387.07 1877.73,1387.05 1877.73,1387.02 1877.73,1387 1877.73,1386.98 1877.73,1386.95 1877.73,1386.93 1877.73,1386.9 1877.73,1386.88 1877.73,1386.86 1877.73,1386.83 1877.73,1386.81 1877.73,1386.79 1877.73,1386.76 1877.73,1386.74 1877.73,1386.71 1877.73,1386.69 1877.73,1386.67 1877.73,1386.64 1877.73,1386.62 1877.73,1386.59 1877.73,1386.57 1877.73,1386.55 1877.73,1386.52 1877.73,1386.5 1877.73,1386.47 1877.73,1386.45 1877.73,1386.43 1877.73,1386.4 1877.73,1386.38 1877.73,1386.36 1877.73,1386.33 1877.73,1386.31 1877.73,1386.28 1877.73,1386.26 1877.73,1386.24 1877.73,1386.21 1877.73,1386.19 1877.73,1386.16 1877.73,1386.14 1877.73,1386.12 1877.73,1386.09 1877.73,1386.07 1877.73,1386.04 1877.73,1386.02 1877.73,1385.99 1877.73,1385.97 1877.73,1385.95 1877.73,1385.92 1877.73,1385.9 1877.73,1385.87 1877.73,1385.85 1877.73,1385.83 1877.73,1385.8 1877.73,1385.78 1877.73,1385.75 1877.73,1385.73 1877.73,1385.71 1877.73,1385.68 1877.73,1385.66 1877.73,1385.63 1877.73,1385.61 1877.73,1385.58 1877.73,1385.56 1877.73,1385.54 1877.73,1385.51 1877.73,1385.49 1877.73,1385.46 1877.73,1385.44 1877.73,1385.41 1877.73,1385.39 1877.73,1385.37 1877.73,1385.34 1877.73,1385.32 1877.73,1385.29 1877.73,1385.27 1877.73,1385.24 1877.73,1385.22 1877.73,1385.2 1877.73,1385.17 1877.73,1385.15 1877.73,1385.12 1877.73,1385.1 1877.73,1385.07 1877.73,1385.05 1877.73,1385.03 1877.73,1385 1877.73,1384.98 1877.73,1384.95 1877.73,1384.93 1877.73,1384.9 1877.73,1384.88 1877.73,1384.86 1877.73,1384.83 1877.73,1384.81 1877.73,1384.78 1877.73,1384.76 1877.73,1384.73 1877.73,1384.71 1877.73,1384.68 1877.73,1384.66 1877.73,1384.64 1877.73,1384.61 1877.73,1384.59 1877.73,1384.56 1877.73,1384.54 1877.73,1384.51 1877.73,1384.49 1877.73,1384.46 1877.73,1384.44 1877.73,1384.41 1877.73,1384.39 1877.73,1384.37 1877.73,1384.34 1877.73,1384.32 1877.73,1384.29 1877.73,1384.27 1877.73,1384.24 1877.73,1384.22 1877.73,1384.19 1877.73,1384.17 1877.73,1384.14 1877.73,1384.12 1877.73,1384.09 1877.73,1384.07 1877.73,1384.05 1877.73,1384.02 1877.73,1384 1877.73,1383.97 1877.73,1383.95 1877.73,1383.92 1877.73,1383.9 1877.73,1383.87 1877.73,1383.85 1877.73,1383.82 1877.73,1383.8 1877.73,1383.77 1877.73,1383.75 1877.73,1383.72 1877.73,1383.7 1877.73,1383.68 1877.73,1383.65 1877.73,1383.63 1877.73,1383.6 1877.73,1383.58 1877.73,1383.55 1877.73,1383.53 1877.73,1383.5 1877.73,1383.48 1877.73,1383.45 1877.73,1383.43 1877.73,1383.4 1877.73,1383.38 1877.73,1383.35 1877.73,1383.33 1877.73,1383.3 1877.73,1383.28 1877.73,1383.25 1877.73,1383.23 1877.73,1383.2 1877.73,1383.18 1877.73,1383.15 1877.73,1383.13 1877.73,1383.1 1877.73,1383.08 1877.73,1383.05 1877.73,1383.03 1877.73,1383 1877.73,1382.98 1877.73,1382.95 1877.73,1382.93 1877.73,1382.9 1877.73,1382.88 1877.73,1382.85 1877.73,1382.83 1877.73,1382.8 1877.73,1382.78 1877.73,1382.75 1877.73,1382.73 1877.73,1382.7 1877.73,1382.68 1877.73,1382.65 1877.73,1382.63 1877.73,1382.6 1877.73,1382.58 1877.73,1382.55 1877.73,1382.53 1877.73,1382.5 1877.73,1382.48 1877.73,1382.45 1877.73,1382.43 1877.73,1382.4 1877.73,1382.38 1877.73,1382.35 1877.73,1382.33 1877.73,1382.3 1877.73,1382.28 1877.73,1382.25 1877.73,1382.23 1877.73,1382.2 1877.73,1382.18 1877.73,1382.15 1877.73,1382.13 1877.73,1382.1 1877.73,1382.08 1877.73,1382.05 1877.73,1382.03 1877.73,1382 1877.73,1381.98 1877.73,1381.95 1877.73,1381.93 1877.73,1381.9 1877.73,1381.88 1877.73,1381.85 1877.73,1381.83 1877.73,1381.8 1877.73,1381.78 1877.73,1381.75 1877.73,1381.72 1877.73,1381.7 1877.73,1381.67 1877.73,1381.65 1877.73,1381.62 1877.73,1381.6 1877.73,1381.57 1877.73,1381.55 1877.73,1381.52 1877.73,1381.5 1877.73,1381.47 1877.73,1381.45 1877.73,1381.42 1877.73,1381.4 1877.73,1381.37 1877.73,1381.35 1877.73,1381.32 1877.73,1381.29 1877.73,1381.27 1877.73,1381.24 1877.73,1381.22 1877.73,1381.19 1877.73,1381.17 1877.73,1381.14 1877.73,1381.12 1877.73,1381.09 1877.73,1381.07 1877.73,1381.04 1877.73,1381.01 1877.73,1380.99 1877.73,1380.96 1877.73,1380.94 1877.73,1380.91 1877.73,1380.89 1877.73,1380.86 1877.73,1380.84 1877.73,1380.81 1877.73,1380.79 1877.73,1380.76 1877.73,1380.73 1877.73,1380.71 1877.73,1380.68 1877.73,1380.66 1877.73,1380.63 1877.73,1380.61 1877.73,1380.58 1877.73,1380.56 1877.73,1380.53 1877.73,1380.5 1877.73,1380.48 1877.73,1380.45 1877.73,1380.43 1877.73,1380.4 1877.73,1380.38 1877.73,1380.35 1877.73,1380.33 1877.73,1380.3 1877.73,1380.27 1877.73,1380.25 1877.73,1380.22 1877.73,1380.2 1877.73,1380.17 1877.73,1380.15 1877.73,1380.12 1877.73,1380.1 1877.73,1380.07 1877.73,1380.04 1877.73,1380.02 1877.73,1379.99 1877.73,1379.97 1877.73,1379.94 1877.73,1379.92 1877.73,1379.89 1877.73,1379.86 1877.73,1379.84 1877.73,1379.81 1877.73,1379.79 1877.73,1379.76 1877.73,1379.74 1877.73,1379.71 1877.73,1379.68 1877.73,1379.66 1877.73,1379.63 1877.73,1379.61 1877.73,1379.58 1877.73,1379.55 1877.73,1379.53 1877.73,1379.5 1877.73,1379.48 1877.73,1379.45 1877.73,1379.43 1877.73,1379.4 1877.73,1379.37 1877.73,1379.35 1877.73,1379.32 1877.73,1379.3 1877.73,1379.27 1877.73,1379.25 1877.73,1379.22 1877.73,1379.19 1877.73,1379.17 1877.73,1379.14 1877.73,1379.12 1877.73,1379.09 1877.73,1379.06 1877.73,1379.04 1877.73,1379.01 1877.73,1378.99 1877.73,1378.96 1877.73,1378.93 1877.73,1378.91 1877.73,1378.88 1877.73,1378.86 1877.73,1378.83 1877.73,1378.8 1877.73,1378.78 1877.73,1378.75 1877.73,1378.73 1877.73,1378.7 1877.73,1378.67 1877.73,1378.65 1877.73,1378.62 1877.73,1378.6 1877.73,1378.57 1877.73,1378.54 1877.73,1378.52 1877.73,1378.49 1877.73,1378.47 1877.73,1378.44 1877.73,1378.41 1877.73,1378.39 1877.73,1378.36 1877.73,1378.34 1877.73,1378.31 1877.73,1378.28 1877.73,1378.26 1877.73,1378.23 1877.73,1378.21 1877.73,1378.18 1877.73,1378.15 1877.73,1378.13 1877.73,1378.1 1877.73,1378.08 1877.73,1378.05 1877.73,1378.02 1877.73,1378 1877.73,1377.97 1877.73,1377.94 1877.73,1377.92 1877.73,1377.89 1877.73,1377.87 1877.73,1377.84 1877.73,1377.81 1877.73,1377.79 1877.73,1377.76 1877.73,1377.74 1877.73,1377.71 1877.73,1377.68 1877.73,1377.66 1877.73,1377.63 1877.73,1377.6 1877.73,1377.58 1877.73,1377.55 1877.73,1377.53 1877.73,1377.5 1877.73,1377.47 1877.73,1377.45 1877.73,1377.42 1877.73,1377.39 1877.73,1377.37 1877.73,1377.34 1877.73,1377.32 1877.73,1377.29 1877.73,1377.26 1877.73,1377.24 1877.73,1377.21 1877.73,1377.18 1877.73,1377.16 1877.73,1377.13 1877.73,1377.11 1877.73,1377.08 1877.73,1377.05 1877.73,1377.03 1877.73,1377 1877.73,1376.97 1877.73,1376.95 1877.73,1376.92 1877.73,1376.89 1877.73,1376.87 1877.73,1376.84 1877.73,1376.82 1877.73,1376.79 1877.73,1376.76 1877.73,1376.74 1877.73,1376.71 1877.73,1376.68 1877.73,1376.66 1877.73,1376.63 1877.73,1376.6 1877.73,1376.58 1877.73,1376.55 1877.73,1376.52 1877.73,1376.5 1877.73,1376.47 1877.73,1376.45 1877.73,1376.42 1877.73,1376.39 1877.73,1376.37 1877.73,1376.34 1877.73,1376.31 1877.73,1376.29 1877.73,1376.26 1877.73,1376.23 1877.73,1376.21 1877.73,1376.18 1877.73,1376.15 1877.73,1376.13 1877.73,1376.1 1877.73,1376.07 1877.73,1376.05 1877.73,1376.02 1877.73,1375.99 1877.73,1375.97 1877.73,1375.94 1877.73,1375.91 1877.73,1375.89 1877.73,1375.86 1877.73,1375.84 1877.73,1375.81 1877.73,1375.78 1877.73,1375.76 1877.73,1375.73 1877.73,1375.7 1877.73,1375.68 1877.73,1375.65 1877.73,1375.62 1877.73,1375.6 1877.73,1375.57 1877.73,1375.54 1877.73,1375.52 1877.73,1375.49 1877.73,1375.46 1877.73,1375.44 1877.73,1375.41 1877.73,1375.38 1877.73,1375.36 1877.73,1375.33 1877.73,1375.3 1877.73,1375.28 1877.73,1375.25 1877.73,1375.22 1877.73,1375.2 1877.73,1375.17 1877.73,1375.14 1877.73,1375.12 1877.73,1375.09 1877.73,1375.06 1877.73,1375.03 1877.73,1375.01 1877.73,1374.98 1877.73,1374.95 1877.73,1374.93 1877.73,1374.9 1877.73,1374.87 1877.73,1374.85 1877.73,1374.82 1877.73,1374.79 1877.73,1374.77 1877.73,1374.74 1877.73,1374.71 1877.73,1374.69 1877.73,1374.66 1877.73,1374.63 1877.73,1374.61 1877.73,1374.58 1877.73,1374.55 1877.73,1374.53 1877.73,1374.5 1877.73,1374.47 1877.73,1374.44 1877.73,1374.42 1877.73,1374.39 1877.73,1374.36 1877.73,1374.34 1877.73,1374.31 1877.73,1374.28 1877.73,1374.26 1877.73,1374.23 1877.73,1374.2 1877.73,1374.18 1877.73,1374.15 1877.73,1374.12 1877.73,1374.1 1877.73,1374.07 1877.73,1374.04 1877.73,1374.01 1877.73,1373.99 1877.73,1373.96 1877.73,1373.93 1877.73,1373.91 1877.73,1373.88 1877.73,1373.85 1877.73,1373.83 1877.73,1373.8 1877.73,1373.77 1877.73,1373.74 1877.73,1373.72 1877.73,1373.69 1877.73,1373.66 1877.73,1373.64 1877.73,1373.61 1877.73,1373.58 1877.73,1373.56 1877.73,1373.53 1877.73,1373.5 1877.73,1373.47 1877.73,1373.45 1877.73,1373.42 1877.73,1373.39 1877.73,1373.37 1877.73,1373.34 1877.73,1373.31 1877.73,1373.28 1877.73,1373.26 1877.73,1373.23 1877.73,1373.2 1877.73,1373.18 1877.73,1373.15 1877.73,1373.12 1877.73,1373.09 1877.73,1373.07 1877.73,1373.04 1877.73,1373.01 1877.73,1372.99 1877.73,1372.96 1877.73,1372.93 1877.73,1372.9 1877.73,1372.88 1877.73,1372.85 1877.73,1372.82 1877.73,1372.8 1877.73,1372.77 1877.73,1372.74 1877.73,1372.71 1877.73,1372.69 1877.73,1372.66 1877.73,1372.63 1877.73,1372.61 1877.73,1372.58 1877.73,1372.55 1877.73,1372.52 1877.73,1372.5 1877.73,1372.47 1877.73,1372.44 1877.73,1372.42 1877.73,1372.39 1877.73,1372.36 1877.73,1372.33 1877.73,1372.31 1877.73,1372.28 1877.73,1372.25 1877.73,1372.22 1877.73,1372.2 1877.73,1372.17 1877.73,1372.14 1877.73,1372.11 1877.73,1372.09 1877.73,1372.06 1877.73,1372.03 1877.73,1372.01 1877.73,1371.98 1877.73,1371.95 1877.73,1371.92 1877.73,1371.9 1877.73,1371.87 1877.73,1371.84 1877.73,1371.81 1877.73,1371.79 1877.73,1371.76 1877.73,1371.73 1877.73,1371.7 1877.73,1371.68 1877.73,1371.65 1877.73,1371.62 1877.73,1371.6 1877.73,1371.57 1877.73,1371.54 1877.73,1371.51 1877.73,1371.49 1877.73,1371.46 1877.73,1371.43 1877.73,1371.4 1877.73,1371.38 1877.73,1371.35 1877.73,1371.32 1877.73,1371.29 1877.73,1371.27 1877.73,1371.24 1877.73,1371.21 1877.73,1371.18 1877.73,1371.16 1877.73,1371.13 1877.73,1371.1 1877.73,1371.07 1877.73,1371.05 1877.73,1371.02 1877.73,1370.99 1877.73,1370.96 1877.73,1370.94 1877.73,1370.91 1877.73,1370.88 1877.73,1370.85 1877.73,1370.83 1877.73,1370.8 1877.73,1370.77 1877.73,1370.74 1877.73,1370.72 1877.73,1370.69 1877.73,1370.66 1877.73,1370.63 1877.73,1370.61 1877.73,1370.58 1877.73,1370.55 1877.73,1370.52 1877.73,1370.5 1877.73,1370.47 1877.73,1370.44 1877.73,1370.41 1877.73,1370.38 1877.73,1370.36 1877.73,1370.33 1877.73,1370.3 1877.73,1370.27 1877.73,1370.25 1877.73,1370.22 1877.73,1370.19 1877.73,1370.16 1877.73,1370.14 1877.73,1370.11 1877.73,1370.08 1877.73,1370.05 1877.73,1370.03 1877.73,1370 1877.73,1369.97 1877.73,1369.94 1877.73,1369.91 1877.73,1369.89 1877.73,1369.86 1877.73,1369.83 1877.73,1369.8 1877.73,1369.78 1877.73,1369.75 1877.73,1369.72 1877.73,1369.69 1877.73,1369.67 1877.73,1369.64 1877.73,1369.61 1877.73,1369.58 1877.73,1369.55 1877.73,1369.53 1877.73,1369.5 1877.73,1369.47 1877.73,1369.44 1877.73,1369.42 1877.73,1369.39 1877.73,1369.36 1877.73,1369.33 1877.73,1369.3 1877.73,1369.28 1877.73,1369.25 1877.73,1369.22 1877.73,1369.19 1877.73,1369.17 1877.73,1369.14 1877.73,1369.11 1877.73,1369.08 1877.73,1369.05 1877.73,1369.03 1877.73,1369 1877.73,1368.97 1877.73,1368.94 1877.73,1368.91 1877.73,1368.89 1877.73,1368.86 1877.73,1368.83 1877.73,1368.8 1877.73,1368.78 1877.73,1368.75 1877.73,1368.72 1877.73,1368.69 1877.73,1368.66 1877.73,1368.64 1877.73,1368.61 1877.73,1368.58 1877.73,1368.55 1877.73,1368.52 1877.73,1368.5 1877.73,1368.47 1877.73,1368.44 1877.73,1368.41 1877.73,1368.38 1877.73,1368.36 1877.73,1368.33 1877.73,1368.3 1877.73,1368.27 1877.73,1368.24 1877.73,1368.22 1877.73,1368.19 1877.73,1368.16 1877.73,1368.13 1877.73,1368.1 1877.73,1368.08 1877.73,1368.05 1877.73,1368.02 1877.73,1367.99 1877.73,1367.96 1877.73,1367.94 1877.73,1367.91 1877.73,1367.88 1877.73,1367.85 1877.73,1367.82 1877.73,1367.8 1877.73,1367.77 1877.73,1367.74 1877.73,1367.71 1877.73,1367.68 1877.73,1367.66 1877.73,1367.63 1877.73,1367.6 1877.73,1367.57 1877.73,1367.54 1877.73,1367.52 1877.73,1367.49 1877.73,1367.46 1877.73,1367.43 1877.73,1367.4 1877.73,1367.38 1877.73,1367.35 1877.73,1367.32 1877.73,1367.29 1877.73,1367.26 1877.73,1367.23 1877.73,1367.21 1877.73,1367.18 1877.73,1367.15 1877.73,1367.12 1877.73,1367.09 1877.73,1367.07 1877.73,1367.04 1877.73,1367.01 1877.73,1366.98 1877.73,1366.95 1877.73,1366.93 1877.73,1366.9 1877.73,1366.87 1877.73,1366.84 1877.73,1366.81 1877.73,1366.78 1877.73,1366.76 1877.73,1366.73 1877.73,1366.7 1877.73,1366.67 1877.73,1366.64 1877.73,1366.61 1877.73,1366.59 1877.73,1366.56 1877.73,1366.53 1877.73,1366.5 1877.73,1366.47 1877.73,1366.45 1877.73,1366.42 1877.73,1366.39 1877.73,1366.36 1877.73,1366.33 1877.73,1366.3 1877.73,1366.28 1877.73,1366.25 1877.73,1366.22 1877.73,1366.19 1877.73,1366.16 1877.73,1366.13 1877.73,1366.11 1877.73,1366.08 1877.73,1366.05 1877.73,1366.02 1877.73,1365.99 1877.73,1365.96 1877.73,1365.94 1877.73,1365.91 1877.73,1365.88 1877.73,1365.85 1877.73,1365.82 1877.73,1365.79 1877.73,1365.77 1877.73,1365.74 1877.73,1365.71 1877.73,1365.68 1877.73,1365.65 1877.73,1365.62 1877.73,1365.6 1877.73,1365.57 1877.73,1365.54 1877.73,1365.51 1877.73,1365.48 1877.73,1365.45 1877.73,1365.43 1877.73,1365.4 1877.73,1365.37 1877.73,1365.34 1877.73,1365.31 1877.73,1365.28 1877.73,1365.25 1877.73,1365.23 1877.73,1365.2 1877.73,1365.17 1877.73,1365.14 1877.73,1365.11 1877.73,1365.08 1877.73,1365.06 1877.73,1365.03 1877.73,1365 1877.73,1364.97 1877.73,1364.94 1877.73,1364.91 1877.73,1364.88 1877.73,1364.86 1877.73,1364.83 1877.73,1364.8 1877.73,1364.77 1877.73,1364.74 1877.73,1364.71 1877.73,1364.69 1877.73,1364.66 1877.73,1364.63 1877.73,1364.6 1877.73,1364.57 1877.73,1364.54 1877.73,1364.51 1877.73,1364.49 1877.73,1364.46 1877.73,1364.43 1877.73,1364.4 1877.73,1364.37 1877.73,1364.34 1877.73,1364.31 1877.73,1364.29 1877.73,1364.26 1877.73,1364.23 1877.73,1364.2 1877.73,1364.17 1877.73,1364.14 1877.73,1364.11 1877.73,1364.09 1877.73,1364.06 1877.73,1364.03 1877.73,1364 1877.73,1363.97 1877.73,1363.94 1877.73,1363.91 1877.73,1363.89 1877.73,1363.86 1877.73,1363.83 1877.73,1363.8 1877.73,1363.77 1877.73,1363.74 1877.73,1363.71 1877.73,1363.68 1877.73,1363.66 1877.73,1363.63 1877.73,1363.6 1877.73,1363.57 1877.73,1363.54 1877.73,1363.51 1877.73,1363.48 1877.73,1363.46 1877.73,1363.43 1877.73,1363.4 1877.73,1363.37 1877.73,1363.34 1877.73,1363.31 1877.73,1363.28 1877.73,1363.25 1877.73,1363.23 1877.73,1363.2 1877.73,1363.17 1877.73,1363.14 1877.73,1363.11 1877.73,1363.08 1877.73,1363.05 1877.73,1363.02 1877.73,1363 1877.73,1362.97 1877.73,1362.94 1877.73,1362.91 1877.73,1362.88 1877.73,1362.85 1877.73,1362.82 1877.73,1362.79 1877.73,1362.77 1877.73,1362.74 1877.73,1362.71 1877.73,1362.68 1877.73,1362.65 1877.73,1362.62 1877.73,1362.59 1877.73,1362.56 1877.73,1362.53 1877.73,1362.51 1877.73,1362.48 1877.73,1362.45 1877.73,1362.42 1877.73,1362.39 1877.73,1362.36 1877.73,1362.33 1877.73,1362.3 1877.73,1362.27 1877.73,1362.25 1877.73,1362.22 1877.73,1362.19 1877.73,1362.16 1877.73,1362.13 1877.73,1362.1 1877.73,1362.07 1877.73,1362.04 1877.73,1362.01 1877.73,1361.99 1877.73,1361.96 1877.73,1361.93 1877.73,1361.9 1877.73,1361.87 1877.73,1361.84 1877.73,1361.81 1877.73,1361.78 1877.73,1361.75 1877.73,1361.73 1877.73,1361.7 1877.73,1361.67 1877.73,1361.64 1877.73,1361.61 1877.73,1361.58 1877.73,1361.55 1877.73,1361.52 1877.73,1361.49 1877.73,1361.47 1877.73,1361.44 1877.73,1361.41 1877.73,1361.38 1877.73,1361.35 1877.73,1361.32 1877.73,1361.29 1877.73,1361.26 1877.73,1361.23 1877.73,1361.2 1877.73,1361.18 1877.73,1361.15 1877.73,1361.12 1877.73,1361.09 1877.73,1361.06 1877.73,1361.03 1877.73,1361 1877.73,1360.97 1877.73,1360.94 1877.73,1360.91 1877.73,1360.88 1877.73,1360.86 1877.73,1360.83 1877.73,1360.8 1877.73,1360.77 1877.73,1360.74 1877.73,1360.71 1877.73,1360.68 1877.73,1360.65 1877.73,1360.62 1877.73,1360.59 1877.73,1360.57 1877.73,1360.54 1877.73,1360.51 1877.73,1360.48 1877.73,1360.45 1877.73,1360.42 1877.73,1360.39 1877.73,1360.36 1877.73,1360.33 1877.73,1360.3 1877.73,1360.27 1877.73,1360.24 1877.73,1360.22 1877.73,1360.19 1877.73,1360.16 1877.73,1360.13 1877.73,1360.1 1877.73,1360.07 1877.73,1360.04 1877.73,1360.01 1877.73,1359.98 1877.73,1359.95 1877.73,1359.92 1877.73,1359.89 1877.73,1359.87 1877.73,1359.84 1877.73,1359.81 1877.73,1359.78 1877.73,1359.75 1877.73,1359.72 1877.73,1359.69 1877.73,1359.66 1877.73,1359.63 1877.73,1359.6 1877.73,1359.57 1877.73,1359.54 1877.73,1359.52 1877.73,1359.49 1877.73,1359.46 1877.73,1359.43 1877.73,1359.4 1877.73,1359.37 1877.73,1359.34 1877.73,1359.31 1877.73,1359.28 1877.73,1359.25 1877.73,1359.22 1877.73,1359.19 1877.73,1359.16 1877.73,1359.13 1877.73,1359.11 1877.73,1359.08 1877.73,1359.05 1877.73,1359.02 1877.73,1358.99 1877.73,1358.96 1877.73,1358.93 1877.73,1358.9 1877.73,1358.87 1877.73,1358.84 1877.73,1358.81 1877.73,1358.78 1877.73,1358.75 1877.73,1358.72 1877.73,1358.69 1877.73,1358.67 1877.73,1358.64 1877.73,1358.61 1877.73,1358.58 1877.73,1358.55 1877.73,1358.52 1877.73,1358.49 1877.73,1358.46 1877.73,1358.43 1877.73,1358.4 1877.73,1358.37 1877.73,1358.34 1877.73,1358.31 1877.73,1358.28 1877.73,1358.25 1877.73,1358.23 1877.73,1358.2 1877.73,1358.17 1877.73,1358.14 1877.73,1358.11 1877.73,1358.08 1877.73,1358.05 1877.73,1358.02 1877.73,1357.99 1877.73,1357.96 1877.73,1357.93 1877.73,1357.9 1877.73,1357.87 1877.73,1357.84 1877.73,1357.81 1877.73,1357.78 1877.73,1357.75 1877.73,1357.72 1877.73,1357.7 1877.73,1357.67 1877.73,1357.64 1877.73,1357.61 1877.73,1357.58 1877.73,1357.55 1877.73,1357.52 1877.73,1357.49 1877.73,1357.46 1877.73,1357.43 1877.73,1357.4 1877.73,1357.37 1877.73,1357.34 1877.73,1357.31 1877.73,1357.28 1877.73,1357.25 1877.73,1357.22 1877.73,1357.19 1877.73,1357.16 1877.73,1357.13 1877.73,1357.11 1877.73,1357.08 1877.73,1357.05 1877.73,1357.02 1877.73,1356.99 1877.73,1356.96 1877.73,1356.93 1877.73,1356.9 1877.73,1356.87 1877.73,1356.84 1877.73,1356.81 1877.73,1356.78 1877.73,1356.75 1877.73,1356.72 1877.73,1356.69 1877.73,1356.66 1877.73,1356.63 1877.73,1356.6 1877.73,1356.57 1877.73,1356.54 1877.73,1356.51 1877.73,1356.48 1877.73,1356.45 1877.73,1356.42 1877.73,1356.4 1877.73,1356.37 1877.73,1356.34 1877.73,1356.31 1877.73,1356.28 1877.73,1356.25 1877.73,1356.22 1877.73,1356.19 1877.73,1356.16 1877.73,1356.13 1877.73,1356.1 1877.73,1356.07 1877.73,1356.04 1877.73,1356.01 1877.73,1355.98 1877.73,1355.95 1877.73,1355.92 1877.73,1355.89 1877.73,1355.86 1877.73,1355.83 1877.73,1355.8 1877.73,1355.77 1877.73,1355.74 1877.73,1355.71 1877.73,1355.68 1877.73,1355.65 1877.73,1355.62 1877.73,1355.59 1877.73,1355.56 1877.73,1355.53 1877.73,1355.5 1877.73,1355.48 1877.73,1355.45 1877.73,1355.42 1877.73,1355.39 1877.73,1355.36 1877.73,1355.33 1877.73,1355.3 1877.73,1355.27 1877.73,1355.24 1877.73,1355.21 1877.73,1355.18 1877.73,1355.15 1877.73,1355.12 1877.73,1355.09 1877.73,1355.06 1877.73,1355.03 1877.73,1355 1877.73,1354.97 1877.73,1354.94 1877.73,1354.91 1877.73,1354.88 1877.73,1354.85 1877.73,1354.82 1877.73,1354.79 1877.73,1354.76 1877.73,1354.73 1877.73,1354.7 1877.73,1354.67 1877.73,1354.64 1877.73,1354.61 1877.73,1354.58 1877.73,1354.55 1877.73,1354.52 1877.73,1354.49 1877.73,1354.46 1877.73,1354.43 1877.73,1354.4 1877.73,1354.37 1877.73,1354.34 1877.73,1354.31 1877.73,1354.28 1877.73,1354.25 1877.73,1354.22 1877.73,1354.19 1877.73,1354.16 1877.73,1354.13 1877.73,1354.1 1877.73,1354.07 1877.73,1354.04 1877.73,1354.01 1877.73,1353.98 1877.73,1353.95 1877.73,1353.92 1877.73,1353.89 1877.73,1353.86 1877.73,1353.83 1877.73,1353.8 1877.73,1353.77 1877.73,1353.74 1877.73,1353.71 1877.73,1353.68 1877.73,1353.65 1877.73,1353.63 1877.73,1353.6 1877.73,1353.57 1877.73,1353.54 1877.73,1353.51 1877.73,1353.48 1877.73,1353.45 1877.73,1353.42 1877.73,1353.39 1877.73,1353.36 1877.73,1353.33 1877.73,1353.3 1877.73,1353.27 1877.73,1353.24 1877.73,1353.21 1877.73,1353.18 1877.73,1353.15 1877.73,1353.12 1877.73,1353.09 1877.73,1353.06 1877.73,1353.03 1877.73,1353 1877.73,1352.97 1877.73,1352.94 1877.73,1352.91 1877.73,1352.88 1877.73,1352.85 1877.73,1352.82 1877.73,1352.79 1877.73,1352.76 1877.73,1352.73 1877.73,1352.7 1877.73,1352.66 1877.73,1352.63 1877.73,1352.6 1877.73,1352.57 1877.73,1352.54 1877.73,1352.51 1877.73,1352.48 1877.73,1352.45 1877.73,1352.42 1877.73,1352.39 1877.73,1352.36 1877.73,1352.33 1877.73,1352.3 1877.73,1352.27 1877.73,1352.24 1877.73,1352.21 1877.73,1352.18 1877.73,1352.15 1877.73,1352.12 1877.73,1352.09 1877.73,1352.06 1877.73,1352.03 1877.73,1352 1877.73,1351.97 1877.73,1351.94 1877.73,1351.91 1877.73,1351.88 1877.73,1351.85 1877.73,1351.82 1877.73,1351.79 1877.73,1351.76 1877.73,1351.73 1877.73,1351.7 1877.73,1351.67 1877.73,1351.64 1877.73,1351.61 1877.73,1351.58 1877.73,1351.55 1877.73,1351.52 1877.73,1351.49 1877.73,1351.46 1877.73,1351.43 1877.73,1351.4 1877.73,1351.37 1877.73,1351.34 1877.73,1351.31 1877.73,1351.28 1877.73,1351.25 1877.73,1351.22 1877.73,1351.19 1877.73,1351.16 1877.73,1351.13 1877.73,1351.1 1877.73,1351.07 1877.73,1351.04 1877.73,1351.01 1877.73,1350.98 1877.73,1350.95 1877.73,1350.92 1877.73,1350.89 1877.73,1350.86 1877.73,1350.83 1877.73,1350.8 1877.73,1350.76 1877.73,1350.73 1877.73,1350.7 1877.73,1350.67 1877.73,1350.64 1877.73,1350.61 1877.73,1350.58 1877.73,1350.55 1877.73,1350.52 1877.73,1350.49 1877.73,1350.46 1877.73,1350.43 1877.73,1350.4 1877.73,1350.37 1877.73,1350.34 1877.73,1350.31 1877.73,1350.28 1877.73,1350.25 1877.73,1350.22 1877.73,1350.19 1877.73,1350.16 1877.73,1350.13 1877.73,1350.1 1877.73,1350.07 1877.73,1350.04 1877.73,1350.01 1877.73,1349.98 1877.73,1349.95 1877.73,1349.92 1877.73,1349.89 1877.73,1349.86 1877.73,1349.83 1877.73,1349.79 1877.73,1349.76 1877.73,1349.73 1877.73,1349.7 1877.73,1349.67 1877.73,1349.64 1877.73,1349.61 1877.73,1349.58 1877.73,1349.55 1877.73,1349.52 1877.73,1349.49 1877.73,1349.46 1877.73,1349.43 1877.73,1349.4 1877.73,1349.37 1877.73,1349.34 1877.73,1349.31 1877.73,1349.28 1877.73,1349.25 1877.73,1349.22 1877.73,1349.19 1877.73,1349.16 1877.73,1349.13 1877.73,1349.1 1877.73,1349.07 1877.73,1349.03 1877.73,1349 1877.73,1348.97 1877.73,1348.94 1877.73,1348.91 1877.73,1348.88 1877.73,1348.85 1877.73,1348.82 1877.73,1348.79 1877.73,1348.76 1877.73,1348.73 1877.73,1348.7 1877.73,1348.67 1877.73,1348.64 1877.73,1348.61 1877.73,1348.58 1877.73,1348.55 1877.73,1348.52 1877.73,1348.49 1877.73,1348.46 1877.73,1348.43 1877.73,1348.39 1877.73,1348.36 1877.73,1348.33 1877.73,1348.3 1877.73,1348.27 1877.73,1348.24 1877.73,1348.21 1877.73,1348.18 1877.73,1348.15 1877.73,1348.12 1877.73,1348.09 1877.73,1348.06 1877.73,1348.03 1877.73,1348 1877.73,1347.97 1877.73,1347.94 1877.73,1347.91 1877.73,1347.88 1877.73,1347.85 1877.73,1347.81 1877.73,1347.78 1877.73,1347.75 1877.73,1347.72 1877.73,1347.69 1877.73,1347.66 1877.73,1347.63 1877.73,1347.6 1877.73,1347.57 1877.73,1347.54 1877.73,1347.51 1877.73,1347.48 1877.73,1347.45 1877.73,1347.42 1877.73,1347.39 1877.73,1347.36 1877.73,1347.33 1877.73,1347.29 1877.73,1347.26 1877.73,1347.23 1877.73,1347.2 1877.73,1347.17 1877.73,1347.14 1877.73,1347.11 1877.73,1347.08 1877.73,1347.05 1877.73,1347.02 1877.73,1346.99 1877.73,1346.96 1877.73,1346.93 1877.73,1346.9 1877.73,1346.87 1877.73,1346.83 1877.73,1346.8 1877.73,1346.77 1877.73,1346.74 1877.73,1346.71 1877.73,1346.68 1877.73,1346.65 1877.73,1346.62 1877.73,1346.59 1877.73,1346.56 1877.73,1346.53 1877.73,1346.5 1877.73,1346.47 1877.73,1346.44 1877.73,1346.41 1877.73,1346.37 1877.73,1346.34 1877.73,1346.31 1877.73,1346.28 1877.73,1346.25 1877.73,1346.22 1877.73,1346.19 1877.73,1346.16 1877.73,1346.13 1877.73,1346.1 1877.73,1346.07 1877.73,1346.04 1877.73,1346.01 1877.73,1345.98 1877.73,1345.94 1877.73,1345.91 1877.73,1345.88 1877.73,1345.85 1877.73,1345.82 1877.73,1345.79 1877.73,1345.76 1877.73,1345.73 1877.73,1345.7 1877.73,1345.67 1877.73,1345.64 1877.73,1345.61 1877.73,1345.58 1877.73,1345.54 1877.73,1345.51 1877.73,1345.48 1877.73,1345.45 1877.73,1345.42 1877.73,1345.39 1877.73,1345.36 1877.73,1345.33 1877.73,1345.3 1877.73,1345.27 1877.73,1345.24 1877.73,1345.21 1877.73,1345.17 1877.73,1345.14 1877.73,1345.11 1877.73,1345.08 1877.73,1345.05 1877.73,1345.02 1877.73,1344.99 1877.73,1344.96 1877.73,1344.93 1877.73,1344.9 1877.73,1344.87 1877.73,1344.84 1877.73,1344.8 1877.73,1344.77 1877.73,1344.74 1877.73,1344.71 1877.73,1344.68 1877.73,1344.65 1877.73,1344.62 1877.73,1344.59 1877.73,1344.56 1877.73,1344.53 1877.73,1344.5 1877.73,1344.46 1877.73,1344.43 1877.73,1344.4 1877.73,1344.37 1877.73,1344.34 1877.73,1344.31 1877.73,1344.28 1877.73,1344.25 1877.73,1344.22 1877.73,1344.19 1877.73,1344.16 1877.73,1344.13 1877.73,1344.09 1877.73,1344.06 1877.73,1344.03 1877.73,1344 1877.73,1343.97 1877.73,1343.94 1877.73,1343.91 1877.73,1343.88 1877.73,1343.85 1877.73,1343.82 1877.73,1343.78 1877.73,1343.75 1877.73,1343.72 1877.73,1343.69 1877.73,1343.66 1877.73,1343.63 1877.73,1343.6 1877.73,1343.57 1877.73,1343.54 1877.73,1343.51 1877.73,1343.48 1877.73,1343.44 1877.73,1343.41 1877.73,1343.38 1877.73,1343.35 1877.73,1343.32 1877.73,1343.29 1877.73,1343.26 1877.73,1343.23 1877.73,1343.2 1877.73,1343.17 1877.73,1343.13 1877.73,1343.1 1877.73,1343.07 1877.73,1343.04 1877.73,1343.01 1877.73,1342.98 1877.73,1342.95 1877.73,1342.92 1877.73,1342.89 1877.73,1342.85 1877.73,1342.82 1877.73,1342.79 1877.73,1342.76 1877.73,1342.73 1877.73,1342.7 1877.73,1342.67 1877.73,1342.64 1877.73,1342.61 1877.73,1342.58 1877.73,1342.54 1877.73,1342.51 1877.73,1342.48 1877.73,1342.45 1877.73,1342.42 1877.73,1342.39 1877.73,1342.36 1877.73,1342.33 1877.73,1342.3 1877.73,1342.26 1877.73,1342.23 1877.73,1342.2 1877.73,1342.17 1877.73,1342.14 1877.73,1342.11 1877.73,1342.08 1877.73,1342.05 1877.73,1342.02 1877.73,1341.98 1877.73,1341.95 1877.73,1341.92 1877.73,1341.89 1877.73,1341.86 1877.73,1341.83 1877.73,1341.8 1877.73,1341.77 1877.73,1341.74 1877.73,1341.7 1877.73,1341.67 1877.73,1341.64 1877.73,1341.61 1877.73,1341.58 1877.73,1341.55 1877.73,1341.52 1877.73,1341.49 1877.73,1341.46 1877.73,1341.42 1877.73,1341.39 1877.73,1341.36 1877.73,1341.33 1877.73,1341.3 1877.73,1341.27 1877.73,1341.24 1877.73,1341.21 1877.73,1341.17 1877.73,1341.14 1877.73,1341.11 1877.73,1341.08 1877.73,1341.05 1877.73,1341.02 1877.73,1340.99 1877.73,1340.96 1877.73,1340.93 1877.73,1340.89 1877.73,1340.86 1877.73,1340.83 1877.73,1340.8 1877.73,1340.77 1877.73,1340.74 1877.73,1340.71 1877.73,1340.68 1877.73,1340.64 1877.73,1340.61 1877.73,1340.58 1877.73,1340.55 1877.73,1340.52 1877.73,1340.49 1877.73,1340.46 1877.73,1340.43 1877.73,1340.39 1877.73,1340.36 1877.73,1340.33 1877.73,1340.3 1877.73,1340.27 1877.73,1340.24 1877.73,1340.21 1877.73,1340.18 1877.73,1340.14 1877.73,1340.11 1877.73,1340.08 1877.73,1340.05 1877.73,1340.02 1877.73,1339.99 1877.73,1339.96 1877.73,1339.92 1877.73,1339.89 1877.73,1339.86 1877.73,1339.83 1877.73,1339.8 1877.73,1339.77 1877.73,1339.74 1877.73,1339.71 1877.73,1339.67 1877.73,1339.64 1877.73,1339.61 1877.73,1339.58 1877.73,1339.55 1877.73,1339.52 1877.73,1339.49 1877.73,1339.46 1877.73,1339.42 1877.73,1339.39 1877.73,1339.36 1877.73,1339.33 1877.73,1339.3 1877.73,1339.27 1877.73,1339.24 1877.73,1339.2 1877.73,1339.17 1877.73,1339.14 1877.73,1339.11 1877.73,1339.08 1877.73,1339.05 1877.73,1339.02 1877.73,1338.98 1877.73,1338.95 1877.73,1338.92 1877.73,1338.89 1877.73,1338.86 1877.73,1338.83 1877.73,1338.8 1877.73,1338.77 1877.73,1338.73 1877.73,1338.7 1877.73,1338.67 1877.73,1338.64 1877.73,1338.61 1877.73,1338.58 1877.73,1338.55 1877.73,1338.51 1877.73,1338.48 1877.73,1338.45 1877.73,1338.42 1877.73,1338.39 1877.73,1338.36 1877.73,1338.33 1877.73,1338.29 1877.73,1338.26 1877.73,1338.23 1877.73,1338.2 1877.73,1338.17 1877.73,1338.14 1877.73,1338.11 1877.73,1338.07 1877.73,1338.04 1877.73,1338.01 1877.73,1337.98 1877.73,1337.95 1877.73,1337.92 1877.73,1337.89 1877.73,1337.85 1877.73,1337.82 1877.73,1337.79 1877.73,1337.76 1877.73,1337.73 1877.73,1337.7 1877.73,1337.66 1877.73,1337.63 1877.73,1337.6 1877.73,1337.57 1877.73,1337.54 1877.73,1337.51 1877.73,1337.48 1877.73,1337.44 1877.73,1337.41 1877.73,1337.38 1877.73,1337.35 1877.73,1337.32 1877.73,1337.29 1877.73,1337.26 1877.73,1337.22 1877.73,1337.19 1877.73,1337.16 1877.73,1337.13 1877.73,1337.1 1877.73,1337.07 1877.73,1337.03 1877.73,1337 1877.73,1336.97 1877.73,1336.94 1877.73,1336.91 1877.73,1336.88 1877.73,1336.85 1877.73,1336.81 1877.73,1336.78 1877.73,1336.75 1877.73,1336.72 1877.73,1336.69 1877.73,1336.66 1877.73,1336.62 1877.73,1336.59 1877.73,1336.56 1877.73,1336.53 1877.73,1336.5 1877.73,1336.47 1877.73,1336.43 1877.73,1336.4 1877.73,1336.37 1877.73,1336.34 1877.73,1336.31 1877.73,1336.28 1877.73,1336.25 1877.73,1336.21 1877.73,1336.18 1877.73,1336.15 1877.73,1336.12 1877.73,1336.09 1877.73,1336.06 1877.73,1336.02 1877.73,1335.99 1877.73,1335.96 1877.73,1335.93 1877.73,1335.9 1877.73,1335.87 1877.73,1335.83 1877.73,1335.8 1877.73,1335.77 1877.73,1335.74 1877.73,1335.71 1877.73,1335.68 1877.73,1335.64 1877.73,1335.61 1877.73,1335.58 1877.73,1335.55 1877.73,1335.52 1877.73,1335.49 1877.73,1335.45 1877.73,1335.42 1877.73,1335.39 1877.73,1335.36 1877.73,1335.33 1877.73,1335.3 1877.73,1335.26 1877.73,1335.23 1877.73,1335.2 1877.73,1335.17 1877.73,1335.14 1877.73,1335.11 1877.73,1335.07 1877.73,1335.04 1877.73,1335.01 1877.73,1334.98 1877.73,1334.95 1877.73,1334.92 1877.73,1334.88 1877.73,1334.85 1877.73,1334.82 1877.73,1334.79 1877.73,1334.76 1877.73,1334.73 1877.73,1334.69 1877.73,1334.66 1877.73,1334.63 1877.73,1334.6 1877.73,1334.57 1877.73,1334.54 1877.73,1334.5 1877.73,1334.47 1877.73,1334.44 1877.73,1334.41 1877.73,1334.38 1877.73,1334.34 1877.73,1334.31 1877.73,1334.28 1877.73,1334.25 1877.73,1334.22 1877.73,1334.19 1877.73,1334.15 1877.73,1334.12 1877.73,1334.09 1877.73,1334.06 1877.73,1334.03 1877.73,1334 1877.73,1333.96 1877.73,1333.93 1877.73,1333.9 1877.73,1333.87 1877.73,1333.84 1877.73,1333.8 1877.73,1333.77 1877.73,1333.74 1877.73,1333.71 1877.73,1333.68 1877.73,1333.65 1877.73,1333.61 1877.73,1333.58 1877.73,1333.55 1877.73,1333.52 1877.73,1333.49 1877.73,1333.45 1877.73,1333.42 1877.73,1333.39 1877.73,1333.36 1877.73,1333.33 1877.73,1333.3 1877.73,1333.26 1877.73,1333.23 1877.73,1333.2 1877.73,1333.17 1877.73,1333.14 1877.73,1333.1 1877.73,1333.07 1877.73,1333.04 1877.73,1333.01 1877.73,1332.98 1877.73,1332.95 1877.73,1332.91 1877.73,1332.88 1877.73,1332.85 1877.73,1332.82 1877.73,1332.79 1877.73,1332.75 1877.73,1332.72 1877.73,1332.69 1877.73,1332.66 1877.73,1332.63 1877.73,1332.6 1877.73,1332.56 1877.73,1332.53 1877.73,1332.5 1877.73,1332.47 1877.73,1332.44 1877.73,1332.4 1877.73,1332.37 1877.73,1332.34 1877.73,1332.31 1877.73,1332.28 1877.73,1332.24 1877.73,1332.21 1877.73,1332.18 1877.73,1332.15 1877.73,1332.12 1877.73,1332.08 1877.73,1332.05 1877.73,1332.02 1877.73,1331.99 1877.73,1331.96 1877.73,1331.92 1877.73,1331.89 1877.73,1331.86 1877.73,1331.83 1877.73,1331.8 1877.73,1331.77 1877.73,1331.73 1877.73,1331.7 1877.73,1331.67 1877.73,1331.64 1877.73,1331.61 1877.73,1331.57 1877.73,1331.54 1877.73,1331.51 1877.73,1331.48 1877.73,1331.45 1877.73,1331.41 1877.73,1331.38 1877.73,1331.35 1877.73,1331.32 1877.73,1331.29 1877.73,1331.25 1877.73,1331.22 1877.73,1331.19 1877.73,1331.16 1877.73,1331.13 1877.73,1331.09 1877.73,1331.06 1877.73,1331.03 1877.73,1331 1877.73,1330.97 1877.73,1330.93 1877.73,1330.9 1877.73,1330.87 1877.73,1330.84 1877.73,1330.81 1877.73,1330.77 1877.73,1330.74 1877.73,1330.71 1877.73,1330.68 1877.73,1330.65 1877.73,1330.61 1877.73,1330.58 1877.73,1330.55 1877.73,1330.52 1877.73,1330.49 1877.73,1330.45 1877.73,1330.42 1877.73,1330.39 1877.73,1330.36 1877.73,1330.33 1877.73,1330.29 1877.73,1330.26 1877.73,1330.23 1877.73,1330.2 1877.73,1330.17 1877.73,1330.13 1877.73,1330.1 1877.73,1330.07 1877.73,1330.04 1877.73,1330 1877.73,1329.97 1877.73,1329.94 1877.73,1329.91 1877.73,1329.88 1877.73,1329.84 1877.73,1329.81 1877.73,1329.78 1877.73,1329.75 1877.73,1329.72 1877.73,1329.68 1877.73,1329.65 1877.73,1329.62 1877.73,1329.59 1877.73,1329.56 1877.73,1329.52 1877.73,1329.49 1877.73,1329.46 1877.73,1329.43 1877.73,1329.4 1877.73,1329.36 1877.73,1329.33 1877.73,1329.3 1877.73,1329.27 1877.73,1329.23 1877.73,1329.2 1877.73,1329.17 1877.73,1329.14 1877.73,1329.11 1877.73,1329.07 1877.73,1329.04 1877.73,1329.01 1877.73,1328.98 1877.73,1328.95 1877.73,1328.91 1877.73,1328.88 1877.73,1328.85 1877.73,1328.82 1877.73,1328.78 1877.73,1328.75 1877.73,1328.72 1877.73,1328.69 1877.73,1328.66 1877.73,1328.62 1877.73,1328.59 1877.73,1328.56 1877.73,1328.53 1877.73,1328.5 1877.73,1328.46 1877.73,1328.43 1877.73,1328.4 1877.73,1328.37 1877.73,1328.33 1877.73,1328.3 1877.73,1328.27 1877.73,1328.24 1877.73,1328.21 1877.73,1328.17 1877.73,1328.14 1877.73,1328.11 1877.73,1328.08 1877.73,1328.04 1877.73,1328.01 1877.73,1327.98 1877.73,1327.95 1877.73,1327.92 1877.73,1327.88 1877.73,1327.85 1877.73,1327.82 1877.73,1327.79 1877.73,1327.75 1877.73,1327.72 1877.73,1327.69 1877.73,1327.66 1877.73,1327.63 1877.73,1327.59 1877.73,1327.56 1877.73,1327.53 1877.73,1327.5 1877.73,1327.46 1877.73,1327.43 1877.73,1327.4 1877.73,1327.37 1877.73,1327.34 1877.73,1327.3 1877.73,1327.27 1877.73,1327.24 1877.73,1327.21 1877.73,1327.17 1877.73,1327.14 1877.73,1327.11 1877.73,1327.08 1877.73,1327.05 1877.73,1327.01 1877.73,1326.98 1877.73,1326.95 1877.73,1326.92 1877.73,1326.88 1877.73,1326.85 1877.73,1326.82 1877.73,1326.79 1877.73,1326.75 1877.73,1326.72 1877.73,1326.69 1877.73,1326.66 1877.73,1326.63 1877.73,1326.59 1877.73,1326.56 1877.73,1326.53 1877.73,1326.5 1877.73,1326.46 1877.73,1326.43 1877.73,1326.4 1877.73,1326.37 1877.73,1326.33 1877.73,1326.3 1877.73,1326.27 1877.73,1326.24 1877.73,1326.21 1877.73,1326.17 1877.73,1326.14 1877.73,1326.11 1877.73,1326.08 1877.73,1326.04 1877.73,1326.01 1877.73,1325.98 1877.73,1325.95 1877.73,1325.91 1877.73,1325.88 1877.73,1325.85 1877.73,1325.82 1877.73,1325.78 1877.73,1325.75 1877.73,1325.72 1877.73,1325.69 1877.73,1325.66 1877.73,1325.62 1877.73,1325.59 1877.73,1325.56 1877.73,1325.53 1877.73,1325.49 1877.73,1325.46 1877.73,1325.43 1877.73,1325.4 1877.73,1325.36 1877.73,1325.33 1877.73,1325.3 1877.73,1325.27 1877.73,1325.23 1877.73,1325.2 1877.73,1325.17 1877.73,1325.14 1877.73,1325.1 1877.73,1325.07 1877.73,1325.04 1877.73,1325.01 1877.73,1324.98 1877.73,1324.94 1877.73,1324.91 1877.73,1324.88 1877.73,1324.85 1877.73,1324.81 1877.73,1324.78 1877.73,1324.75 1877.73,1324.72 1877.73,1324.68 1877.73,1324.65 1877.73,1324.62 1877.73,1324.59 1877.73,1324.55 1877.73,1324.52 1877.73,1324.49 1877.73,1324.46 1877.73,1324.42 1877.73,1324.39 1877.73,1324.36 1877.73,1324.33 1877.73,1324.29 1877.73,1324.26 1877.73,1324.23 1877.73,1324.2 1877.73,1324.16 1877.73,1324.13 1877.73,1324.1 1877.73,1324.07 1877.73,1324.03 1877.73,1324 1877.73,1323.97 1877.73,1323.94 1877.73,1323.9 1877.73,1323.87 1877.73,1323.84 1877.73,1323.81 1877.73,1323.77 1877.73,1323.74 1877.73,1323.71 1877.73,1323.68 1877.73,1323.64 1877.73,1323.61 1877.73,1323.58 1877.73,1323.55 1877.73,1323.51 1877.73,1323.48 1877.73,1323.45 1877.73,1323.42 1877.73,1323.38 1877.73,1323.35 1877.73,1323.32 1877.73,1323.29 1877.73,1323.25 1877.73,1323.22 1877.73,1323.19 1877.73,1323.16 1877.73,1323.12 1877.73,1323.09 1877.73,1323.06 1877.73,1323.03 1877.73,1322.99 1877.73,1322.96 1877.73,1322.93 1877.73,1322.9 1877.73,1322.86 1877.73,1322.83 1877.73,1322.8 1877.73,1322.77 1877.73,1322.73 1877.73,1322.7 1877.73,1322.67 1877.73,1322.64 1877.73,1322.6 1877.73,1322.57 1877.73,1322.54 1877.73,1322.51 1877.73,1322.47 1877.73,1322.44 1877.73,1322.41 1877.73,1322.38 1877.73,1322.34 1877.73,1322.31 1877.73,1322.28 1877.73,1322.25 1877.73,1322.21 1877.73,1322.18 1877.73,1322.15 1877.73,1322.12 1877.73,1322.08 1877.73,1322.05 1877.73,1322.02 1877.73,1321.98 1877.73,1321.95 1877.73,1321.92 1877.73,1321.89 1877.73,1321.85 1877.73,1321.82 1877.73,1321.79 1877.73,1321.76 1877.73,1321.72 1877.73,1321.69 1877.73,1321.66 1877.73,1321.63 1877.73,1321.59 1877.73,1321.56 1877.73,1321.53 1877.73,1321.5 1877.73,1321.46 1877.73,1321.43 1877.73,1321.4 1877.73,1321.36 1877.73,1321.33 1877.73,1321.3 1877.73,1321.27 1877.73,1321.23 1877.73,1321.2 1877.73,1321.17 1877.73,1321.14 1877.73,1321.1 1877.73,1321.07 1877.73,1321.04 1877.73,1321.01 1877.73,1320.97 1877.73,1320.94 1877.73,1320.91 1877.73,1320.88 1877.73,1320.84 1877.73,1320.81 1877.73,1320.78 1877.73,1320.74 1877.73,1320.71 1877.73,1320.68 1877.73,1320.65 1877.73,1320.61 1877.73,1320.58 1877.73,1320.55 1877.73,1320.52 1877.73,1320.48 1877.73,1320.45 1877.73,1320.42 1877.73,1320.38 1877.73,1320.35 1877.73,1320.32 1877.73,1320.29 1877.73,1320.25 1877.73,1320.22 1877.73,1320.19 1877.73,1320.16 1877.73,1320.12 1877.73,1320.09 1877.73,1320.06 1877.73,1320.03 1877.73,1319.99 1877.73,1319.96 1877.73,1319.93 1877.73,1319.89 1877.73,1319.86 1877.73,1319.83 1877.73,1319.8 1877.73,1319.76 1877.73,1319.73 1877.73,1319.7 1877.73,1319.67 1877.73,1319.63 1877.73,1319.6 1877.73,1319.57 1877.73,1319.53 1877.73,1319.5 1877.73,1319.47 1877.73,1319.44 1877.73,1319.4 1877.73,1319.37 1877.73,1319.34 1877.73,1319.3 1877.73,1319.27 1877.73,1319.24 1877.73,1319.21 1877.73,1319.17 1877.73,1319.14 1877.73,1319.11 1877.73,1319.08 1877.73,1319.04 1877.73,1319.01 1877.73,1318.98 1877.73,1318.94 1877.73,1318.91 1877.73,1318.88 1877.73,1318.85 1877.73,1318.81 1877.73,1318.78 1877.73,1318.75 1877.73,1318.71 1877.73,1318.68 1877.73,1318.65 1877.73,1318.62 1877.73,1318.58 1877.73,1318.55 1877.73,1318.52 1877.73,1318.49 1877.73,1318.45 1877.73,1318.42 1877.73,1318.39 1877.73,1318.35 1877.73,1318.32 1877.73,1318.29 1877.73,1318.26 1877.73,1318.22 1877.73,1318.19 1877.73,1318.16 1877.73,1318.12 1877.73,1318.09 1877.73,1318.06 1877.73,1318.03 1877.73,1317.99 1877.73,1317.96 1877.73,1317.93 1877.73,1317.89 1877.73,1317.86 1877.73,1317.83 1877.73,1317.8 1877.73,1317.76 1877.73,1317.73 1877.73,1317.7 1877.73,1317.66 1877.73,1317.63 1877.73,1317.6 1877.73,1317.57 1877.73,1317.53 1877.73,1317.5 1877.73,1317.47 1877.73,1317.43 1877.73,1317.4 1877.73,1317.37 1877.73,1317.34 1877.73,1317.3 1877.73,1317.27 1877.73,1317.24 1877.73,1317.2 1877.73,1317.17 1877.73,1317.14 1877.73,1317.11 1877.73,1317.07 1877.73,1317.04 1877.73,1317.01 1877.73,1316.97 1877.73,1316.94 1877.73,1316.91 1877.73,1316.88 1877.73,1316.84 1877.73,1316.81 1877.73,1316.78 1877.73,1316.74 1877.73,1316.71 1877.73,1316.68 1877.73,1316.65 1877.73,1316.61 1877.73,1316.58 1877.73,1316.55 1877.73,1316.51 1877.73,1316.48 1877.73,1316.45 1877.73,1316.41 1877.73,1316.38 1877.73,1316.35 1877.73,1316.32 1877.73,1316.28 1877.73,1316.25 1877.73,1316.22 1877.73,1316.18 1877.73,1316.15 1877.73,1316.12 1877.73,1316.09 1877.73,1316.05 1877.73,1316.02 1877.73,1315.99 1877.73,1315.95 1877.73,1315.92 1877.73,1315.89 1877.73,1315.85 1877.73,1315.82 1877.73,1315.79 1877.73,1315.76 1877.73,1315.72 1877.73,1315.69 1877.73,1315.66 1877.73,1315.62 1877.73,1315.59 1877.73,1315.56 1877.73,1315.53 1877.73,1315.49 1877.73,1315.46 1877.73,1315.43 1877.73,1315.39 1877.73,1315.36 1877.73,1315.33 1877.73,1315.29 1877.73,1315.26 1877.73,1315.23 1877.73,1315.2 1877.73,1315.16 1877.73,1315.13 1877.73,1315.1 1877.73,1315.06 1877.73,1315.03 1877.73,1315 1877.73,1314.96 1877.73,1314.93 1877.73,1314.9 1877.73,1314.87 1877.73,1314.83 1877.73,1314.8 1877.73,1314.77 1877.73,1314.73 1877.73,1314.7 1877.73,1314.67 1877.73,1314.63 1877.73,1314.6 1877.73,1314.57 1877.73,1314.54 1877.73,1314.5 1877.73,1314.47 1877.73,1314.44 1877.73,1314.4 1877.73,1314.37 1877.73,1314.34 1877.73,1314.3 1877.73,1314.27 1877.73,1314.24 1877.73,1314.2 1877.73,1314.17 1877.73,1314.14 1877.73,1314.11 1877.73,1314.07 1877.73,1314.04 1877.73,1314.01 1877.73,1313.97 1877.73,1313.94 1877.73,1313.91 1877.73,1313.87 1877.73,1313.84 1877.73,1313.81 1877.73,1313.77 1877.73,1313.74 1877.73,1313.71 1877.73,1313.68 1877.73,1313.64 1877.73,1313.61 1877.73,1313.58 1877.73,1313.54 1877.73,1313.51 1877.73,1313.48 1877.73,1313.44 1877.73,1313.41 1877.73,1313.38 1877.73,1313.34 1877.73,1313.31 1877.73,1313.28 1877.73,1313.25 1877.73,1313.21 1877.73,1313.18 1877.73,1313.15 1877.73,1313.11 1877.73,1313.08 1877.73,1313.05 1877.73,1313.01 1877.73,1312.98 1877.73,1312.95 1877.73,1312.91 1877.73,1312.88 1877.73,1312.85 1877.73,1312.82 1877.73,1312.78 1877.73,1312.75 1877.73,1312.72 1877.73,1312.68 1877.73,1312.65 1877.73,1312.62 1877.73,1312.58 1877.73,1312.55 1877.73,1312.52 1877.73,1312.48 1877.73,1312.45 1877.73,1312.42 1877.73,1312.38 1877.73,1312.35 1877.73,1312.32 1877.73,1312.29 1877.73,1312.25 1877.73,1312.22 1877.73,1312.19 1877.73,1312.15 1877.73,1312.12 1877.73,1312.09 1877.73,1312.05 1877.73,1312.02 1877.73,1311.99 1877.73,1311.95 1877.73,1311.92 1877.73,1311.89 1877.73,1311.85 1877.73,1311.82 1877.73,1311.79 1877.73,1311.75 1877.73,1311.72 1877.73,1311.69 1877.73,1311.65 1877.73,1311.62 1877.73,1311.59 1877.73,1311.56 1877.73,1311.52 1877.73,1311.49 1877.73,1311.46 1877.73,1311.42 1877.73,1311.39 1877.73,1311.36 1877.73,1311.32 1877.73,1311.29 1877.73,1311.26 1877.73,1311.22 1877.73,1311.19 1877.73,1311.16 1877.73,1311.12 1877.73,1311.09 1877.73,1311.06 1877.73,1311.02 1877.73,1310.99 1877.73,1310.96 1877.73,1310.92 1877.73,1310.89 1877.73,1310.86 1877.73,1310.82 1877.73,1310.79 1877.73,1310.76 1877.73,1310.73 1877.73,1310.69 1877.73,1310.66 1877.73,1310.63 1877.73,1310.59 1877.73,1310.56 1877.73,1310.53 1877.73,1310.49 1877.73,1310.46 1877.73,1310.43 1877.73,1310.39 1877.73,1310.36 1877.73,1310.33 1877.73,1310.29 1877.73,1310.26 1877.73,1310.23 1877.73,1310.19 1877.73,1310.16 1877.73,1310.13 1877.73,1310.09 1877.73,1310.06 1877.73,1310.03 1877.73,1309.99 1877.73,1309.96 1877.73,1309.93 1877.73,1309.89 1877.73,1309.86 1877.73,1309.83 1877.73,1309.79 1877.73,1309.76 1877.73,1309.73 1877.73,1309.69 1877.73,1309.66 1877.73,1309.63 1877.73,1309.59 1877.73,1309.56 1877.73,1309.53 1877.73,1309.49 1877.73,1309.46 1877.73,1309.43 1877.73,1309.39 1877.73,1309.36 1877.73,1309.33 1877.73,1309.29 1877.73,1309.26 1877.73,1309.23 1877.73,1309.2 1877.73,1309.16 1877.73,1309.13 1877.73,1309.1 1877.73,1309.06 1877.73,1309.03 1877.73,1309 1877.73,1308.96 1877.73,1308.93 1877.73,1308.9 1877.73,1308.86 1877.73,1308.83 1877.73,1308.8 1877.73,1308.76 1877.73,1308.73 1877.73,1308.7 1877.73,1308.66 1877.73,1308.63 1877.73,1308.6 1877.73,1308.56 1877.73,1308.53 1877.73,1308.5 1877.73,1308.46 1877.73,1308.43 1877.73,1308.4 1877.73,1308.36 1877.73,1308.33 1877.73,1308.3 1877.73,1308.26 1877.73,1308.23 1877.73,1308.2 1877.73,1308.16 1877.73,1308.13 1877.73,1308.1 1877.73,1308.06 1877.73,1308.03 1877.73,1308 1877.73,1307.96 1877.73,1307.93 1877.73,1307.9 1877.73,1307.86 1877.73,1307.83 1877.73,1307.79 1877.73,1307.76 1877.73,1307.73 1877.73,1307.69 1877.73,1307.66 1877.73,1307.63 1877.73,1307.59 1877.73,1307.56 1877.73,1307.53 1877.73,1307.49 1877.73,1307.46 1877.73,1307.43 1877.73,1307.39 1877.73,1307.36 1877.73,1307.33 1877.73,1307.29 1877.73,1307.26 1877.73,1307.23 1877.73,1307.19 1877.73,1307.16 1877.73,1307.13 1877.73,1307.09 1877.73,1307.06 1877.73,1307.03 1877.73,1306.99 1877.73,1306.96 1877.73,1306.93 1877.73,1306.89 1877.73,1306.86 1877.73,1306.83 1877.73,1306.79 1877.73,1306.76 1877.73,1306.73 1877.73,1306.69 1877.73,1306.66 1877.73,1306.63 1877.73,1306.59 1877.73,1306.56 1877.73,1306.53 1877.73,1306.49 1877.73,1306.46 1877.73,1306.43 1877.73,1306.39 1877.73,1306.36 1877.73,1306.33 1877.73,1306.29 1877.73,1306.26 1877.73,1306.22 1877.73,1306.19 1877.73,1306.16 1877.73,1306.12 1877.73,1306.09 1877.73,1306.06 1877.73,1306.02 1877.73,1305.99 1877.73,1305.96 1877.73,1305.92 1877.73,1305.89 1877.73,1305.86 1877.73,1305.82 1877.73,1305.79 1877.73,1305.76 1877.73,1305.72 1877.73,1305.69 1877.73,1305.66 1877.73,1305.62 1877.73,1305.59 1877.73,1305.56 1877.73,1305.52 1877.73,1305.49 1877.73,1305.46 1877.73,1305.42 1877.73,1305.39 1877.73,1305.35 1877.73,1305.32 1877.73,1305.29 1877.73,1305.25 1877.73,1305.22 1877.73,1305.19 1877.73,1305.15 1877.73,1305.12 1877.73,1305.09 1877.73,1305.05 1877.73,1305.02 1877.73,1304.99 1877.73,1304.95 1877.73,1304.92 1877.73,1304.89 1877.73,1304.85 1877.73,1304.82 1877.73,1304.79 1877.73,1304.75 1877.73,1304.72 1877.73,1304.68 1877.73,1304.65 1877.73,1304.62 1877.73,1304.58 1877.73,1304.55 1877.73,1304.52 1877.73,1304.48 1877.73,1304.45 1877.73,1304.42 1877.73,1304.38 1877.73,1304.35 1877.73,1304.32 1877.73,1304.28 1877.73,1304.25 1877.73,1304.22 1877.73,1304.18 1877.73,1304.15 1877.73,1304.11 1877.73,1304.08 1877.73,1304.05 1877.73,1304.01 1877.73,1303.98 1877.73,1303.95 1877.73,1303.91 1877.73,1303.88 1877.73,1303.85 1877.73,1303.81 1877.73,1303.78 1877.73,1303.75 1877.73,1303.71 1877.73,1303.68 1877.73,1303.64 1877.73,1303.61 1877.73,1303.58 1877.73,1303.54 1877.73,1303.51 1877.73,1303.48 1877.73,1303.44 1877.73,1303.41 1877.73,1303.38 1877.73,1303.34 1877.73,1303.31 1877.73,1303.28 1877.73,1303.24 1877.73,1303.21 1877.73,1303.17 1877.73,1303.14 1877.73,1303.11 1877.73,1303.07 1877.73,1303.04 1877.73,1303.01 1877.73,1302.97 1877.73,1302.94 1877.73,1302.91 1877.73,1302.87 1877.73,1302.84 1877.73,1302.81 1877.73,1302.77 1877.73,1302.74 1877.73,1302.7 1877.73,1302.67 1877.73,1302.64 1877.73,1302.6 1877.73,1302.57 1877.73,1302.54 1877.73,1302.5 1877.73,1302.47 1877.73,1302.44 1877.73,1302.4 1877.73,1302.37 1877.73,1302.33 1877.73,1302.3 1877.73,1302.27 1877.73,1302.23 1877.73,1302.2 1877.73,1302.17 1877.73,1302.13 1877.73,1302.1 1877.73,1302.07 1877.73,1302.03 1877.73,1302 1877.73,1301.96 1877.73,1301.93 1877.73,1301.9 1877.73,1301.86 1877.73,1301.83 1877.73,1301.8 1877.73,1301.76 1877.73,1301.73 1877.73,1301.7 1877.73,1301.66 1877.73,1301.63 1877.73,1301.59 1877.73,1301.56 1877.73,1301.53 1877.73,1301.49 1877.73,1301.46 1877.73,1301.43 1877.73,1301.39 1877.73,1301.36 1877.73,1301.33 1877.73,1301.29 1877.73,1301.26 1877.73,1301.22 1877.73,1301.19 1877.73,1301.16 1877.73,1301.12 1877.73,1301.09 1877.73,1301.06 1877.73,1301.02 1877.73,1300.99 1877.73,1300.96 1877.73,1300.92 1877.73,1300.89 1877.73,1300.85 1877.73,1300.82 1877.73,1300.79 1877.73,1300.75 1877.73,1300.72 1877.73,1300.69 1877.73,1300.65 1877.73,1300.62 1877.73,1300.58 1877.73,1300.55 1877.73,1300.52 1877.73,1300.48 1877.73,1300.45 1877.73,1300.42 1877.73,1300.38 1877.73,1300.35 1877.73,1300.32 1877.73,1300.28 1877.73,1300.25 1877.73,1300.21 1877.73,1300.18 1877.73,1300.15 1877.73,1300.11 1877.73,1300.08 1877.73,1300.05 1877.73,1300.01 1877.73,1299.98 1877.73,1299.94 1877.73,1299.91 1877.73,1299.88 1877.73,1299.84 1877.73,1299.81 1877.73,1299.78 1877.73,1299.74 1877.73,1299.71 1877.73,1299.67 1877.73,1299.64 1877.73,1299.61 1877.73,1299.57 1877.73,1299.54 1877.73,1299.51 1877.73,1299.47 1877.73,1299.44 1877.73,1299.4 1877.73,1299.37 1877.73,1299.34 1877.73,1299.3 1877.73,1299.27 1877.73,1299.24 1877.73,1299.2 1877.73,1299.17 1877.73,1299.13 1877.73,1299.1 1877.73,1299.07 1877.73,1299.03 1877.73,1299 1877.73,1298.97 1877.73,1298.93 1877.73,1298.9 1877.73,1298.86 1877.73,1298.83 1877.73,1298.8 1877.73,1298.76 1877.73,1298.73 1877.73,1298.7 1877.73,1298.66 1877.73,1298.63 1877.73,1298.59 1877.73,1298.56 1877.73,1298.53 1877.73,1298.49 1877.73,1298.46 1877.73,1298.43 1877.73,1298.39 1877.73,1298.36 1877.73,1298.32 1877.73,1298.29 1877.73,1298.26 1877.73,1298.22 1877.73,1298.19 1877.73,1298.16 1877.73,1298.12 1877.73,1298.09 1877.73,1298.05 1877.73,1298.02 1877.73,1297.99 1877.73,1297.95 1877.73,1297.92 1877.73,1297.88 1877.73,1297.85 1877.73,1297.82 1877.73,1297.78 1877.73,1297.75 1877.73,1297.72 1877.73,1297.68 1877.73,1297.65 1877.73,1297.61 1877.73,1297.58 1877.73,1297.55 1877.73,1297.51 1877.73,1297.48 1877.73,1297.44 1877.73,1297.41 1877.73,1297.38 1877.73,1297.34 1877.73,1297.31 1877.73,1297.28 1877.73,1297.24 1877.73,1297.21 1877.73,1297.17 1877.73,1297.14 1877.73,1297.11 1877.73,1297.07 1877.73,1297.04 1877.73,1297.01 1877.73,1296.97 1877.73,1296.94 1877.73,1296.9 1877.73,1296.87 1877.73,1296.84 1877.73,1296.8 1877.73,1296.77 1877.73,1296.73 1877.73,1296.7 1877.73,1296.67 1877.73,1296.63 1877.73,1296.6 1877.73,1296.57 1877.73,1296.53 1877.73,1296.5 1877.73,1296.46 1877.73,1296.43 1877.73,1296.4 1877.73,1296.36 1877.73,1296.33 1877.73,1296.29 1877.73,1296.26 1877.73,1296.23 1877.73,1296.19 1877.73,1296.16 1877.73,1296.12 1877.73,1296.09 1877.73,1296.06 1877.73,1296.02 1877.73,1295.99 1877.73,1295.96 1877.73,1295.92 1877.73,1295.89 1877.73,1295.85 1877.73,1295.82 1877.73,1295.79 1877.73,1295.75 1877.73,1295.72 1877.73,1295.68 1877.73,1295.65 1877.73,1295.62 1877.73,1295.58 1877.73,1295.55 1877.73,1295.51 1877.73,1295.48 1877.73,1295.45 1877.73,1295.41 1877.73,1295.38 1877.73,1295.35 1877.73,1295.31 1877.73,1295.28 1877.73,1295.24 1877.73,1295.21 1877.73,1295.18 1877.73,1295.14 1877.73,1295.11 1877.73,1295.07 1877.73,1295.04 1877.73,1295.01 1877.73,1294.97 1877.73,1294.94 1877.73,1294.9 1877.73,1294.87 1877.73,1294.84 1877.73,1294.8 1877.73,1294.77 1877.73,1294.73 1877.73,1294.7 1877.73,1294.67 1877.73,1294.63 1877.73,1294.6 1877.73,1294.57 1877.73,1294.53 1877.73,1294.5 1877.73,1294.46 1877.73,1294.43 1877.73,1294.4 1877.73,1294.36 1877.73,1294.33 1877.73,1294.29 1877.73,1294.26 1877.73,1294.23 1877.73,1294.19 1877.73,1294.16 1877.73,1294.12 1877.73,1294.09 1877.73,1294.06 1877.73,1294.02 1877.73,1293.99 1877.73,1293.95 1877.73,1293.92 1877.73,1293.89 1877.73,1293.85 1877.73,1293.82 1877.73,1293.78 1877.73,1293.75 1877.73,1293.72 1877.73,1293.68 1877.73,1293.65 1877.73,1293.61 1877.73,1293.58 1877.73,1293.55 1877.73,1293.51 1877.73,1293.48 1877.73,1293.44 1877.73,1293.41 1877.73,1293.38 1877.73,1293.34 1877.73,1293.31 1877.73,1293.27 1877.73,1293.24 1877.73,1293.21 1877.73,1293.17 1877.73,1293.14 1877.73,1293.1 1877.73,1293.07 1877.73,1293.04 1877.73,1293 1877.73,1292.97 1877.73,1292.93 1877.73,1292.9 1877.73,1292.87 1877.73,1292.83 1877.73,1292.8 1877.73,1292.76 1877.73,1292.73 1877.73,1292.7 1877.73,1292.66 1877.73,1292.63 1877.73,1292.59 1877.73,1292.56 1877.73,1292.53 1877.73,1292.49 1877.73,1292.46 1877.73,1292.42 1877.73,1292.39 1877.73,1292.36 1877.73,1292.32 1877.73,1292.29 1877.73,1292.25 1877.73,1292.22 1877.73,1292.19 1877.73,1292.15 1877.73,1292.12 1877.73,1292.08 1877.73,1292.05 1877.73,1292.02 1877.73,1291.98 1877.73,1291.95 1877.73,1291.91 1877.73,1291.88 1877.73,1291.85 1877.73,1291.81 1877.73,1291.78 1877.73,1291.74 1877.73,1291.71 1877.73,1291.68 1877.73,1291.64 1877.73,1291.61 1877.73,1291.57 1877.73,1291.54 1877.73,1291.51 1877.73,1291.47 1877.73,1291.44 1877.73,1291.4 1877.73,1291.37 1877.73,1291.34 1877.73,1291.3 1877.73,1291.27 1877.73,1291.23 1877.73,1291.2 1877.73,1291.17 1877.73,1291.13 1877.73,1291.1 1877.73,1291.06 1877.73,1291.03 1877.73,1290.99 1877.73,1290.96 1877.73,1290.93 1877.73,1290.89 1877.73,1290.86 1877.73,1290.82 1877.73,1290.79 1877.73,1290.76 1877.73,1290.72 1877.73,1290.69 1877.73,1290.65 1877.73,1290.62 1877.73,1290.59 1877.73,1290.55 1877.73,1290.52 1877.73,1290.48 1877.73,1290.45 1877.73,1290.42 1877.73,1290.38 1877.73,1290.35 1877.73,1290.31 1877.73,1290.28 1877.73,1290.25 1877.73,1290.21 1877.73,1290.18 1877.73,1290.14 1877.73,1290.11 1877.73,1290.07 1877.73,1290.04 1877.73,1290.01 1877.73,1289.97 1877.73,1289.94 1877.73,1289.9 1877.73,1289.87 1877.73,1289.84 1877.73,1289.8 1877.73,1289.77 1877.73,1289.73 1877.73,1289.7 1877.73,1289.67 1877.73,1289.63 1877.73,1289.6 1877.73,1289.56 1877.73,1289.53 1877.73,1289.49 1877.73,1289.46 1877.73,1289.43 1877.73,1289.39 1877.73,1289.36 1877.73,1289.32 1877.73,1289.29 1877.73,1289.26 1877.73,1289.22 1877.73,1289.19 1877.73,1289.15 1877.73,1289.12 1877.73,1289.09 1877.73,1289.05 1877.73,1289.02 1877.73,1288.98 1877.73,1288.95 1877.73,1288.91 1877.73,1288.88 1877.73,1288.85 1877.73,1288.81 1877.73,1288.78 1877.73,1288.74 1877.73,1288.71 1877.73,1288.68 1877.73,1288.64 1877.73,1288.61 1877.73,1288.57 1877.73,1288.54 1877.73,1288.5 1877.73,1288.47 1877.73,1288.44 1877.73,1288.4 1877.73,1288.37 1877.73,1288.33 1877.73,1288.3 1877.73,1288.27 1877.73,1288.23 1877.73,1288.2 1877.73,1288.16 1877.73,1288.13 1877.73,1288.09 1877.73,1288.06 1877.73,1288.03 1877.73,1287.99 1877.73,1287.96 1877.73,1287.92 1877.73,1287.89 1877.73,1287.86 1877.73,1287.82 1877.73,1287.79 1877.73,1287.75 1877.73,1287.72 1877.73,1287.68 1877.73,1287.65 1877.73,1287.62 1877.73,1287.58 1877.73,1287.55 1877.73,1287.51 1877.73,1287.48 1877.73,1287.45 1877.73,1287.41 1877.73,1287.38 1877.73,1287.34 1877.73,1287.31 1877.73,1287.27 1877.73,1287.24 1877.73,1287.21 1877.73,1287.17 1877.73,1287.14 1877.73,1287.1 1877.73,1287.07 1877.73,1287.03 1877.73,1287 1877.73,1286.97 1877.73,1286.93 1877.73,1286.9 1877.73,1286.86 1877.73,1286.83 1877.73,1286.8 1877.73,1286.76 1877.73,1286.73 1877.73,1286.69 1877.73,1286.66 1877.73,1286.62 1877.73,1286.59 1877.73,1286.56 1877.73,1286.52 1877.73,1286.49 1877.73,1286.45 1877.73,1286.42 1877.73,1286.38 1877.73,1286.35 1877.73,1286.32 1877.73,1286.28 1877.73,1286.25 1877.73,1286.21 1877.73,1286.18 1877.73,1286.15 1877.73,1286.11 1877.73,1286.08 1877.73,1286.04 1877.73,1286.01 1877.73,1285.97 1877.73,1285.94 1877.73,1285.91 1877.73,1285.87 1877.73,1285.84 1877.73,1285.8 1877.73,1285.77 1877.73,1285.73 1877.73,1285.7 1877.73,1285.67 1877.73,1285.63 1877.73,1285.6 1877.73,1285.56 1877.73,1285.53 1877.73,1285.49 1877.73,1285.46 1877.73,1285.43 1877.73,1285.39 1877.73,1285.36 1877.73,1285.32 1877.73,1285.29 1877.73,1285.25 1877.73,1285.22 1877.73,1285.19 1877.73,1285.15 1877.73,1285.12 1877.73,1285.08 1877.73,1285.05 1877.73,1285.01 1877.73,1284.98 1877.73,1284.95 1877.73,1284.91 1877.73,1284.88 1877.73,1284.84 1877.73,1284.81 1877.73,1284.78 1877.73,1284.74 1877.73,1284.71 1877.73,1284.67 1877.73,1284.64 1877.73,1284.6 1877.73,1284.57 1877.73,1284.54 1877.73,1284.5 1877.73,1284.47 1877.73,1284.43 1877.73,1284.4 1877.73,1284.36 1877.73,1284.33 1877.73,1284.3 1877.73,1284.26 1877.73,1284.23 1877.73,1284.19 1877.73,1284.16 1877.73,1284.12 1877.73,1284.09 1877.73,1284.05 1877.73,1284.02 1877.73,1283.99 1877.73,1283.95 1877.73,1283.92 1877.73,1283.88 1877.73,1283.85 1877.73,1283.81 1877.73,1283.78 1877.73,1283.75 1877.73,1283.71 1877.73,1283.68 1877.73,1283.64 1877.73,1283.61 1877.73,1283.57 1877.73,1283.54 1877.73,1283.51 1877.73,1283.47 1877.73,1283.44 1877.73,1283.4 1877.73,1283.37 1877.73,1283.33 1877.73,1283.3 1877.73,1283.27 1877.73,1283.23 1877.73,1283.2 1877.73,1283.16 1877.73,1283.13 1877.73,1283.09 1877.73,1283.06 1877.73,1283.03 1877.73,1282.99 1877.73,1282.96 1877.73,1282.92 1877.73,1282.89 1877.73,1282.85 1877.73,1282.82 1877.73,1282.79 1877.73,1282.75 1877.73,1282.72 1877.73,1282.68 1877.73,1282.65 1877.73,1282.61 1877.73,1282.58 1877.73,1282.54 1877.73,1282.51 1877.73,1282.48 1877.73,1282.44 1877.73,1282.41 1877.73,1282.37 1877.73,1282.34 1877.73,1282.3 1877.73,1282.27 1877.73,1282.24 1877.73,1282.2 1877.73,1282.17 1877.73,1282.13 1877.73,1282.1 1877.73,1282.06 1877.73,1282.03 1877.73,1282 1877.73,1281.96 1877.73,1281.93 1877.73,1281.89 1877.73,1281.86 1877.73,1281.82 1877.73,1281.79 1877.73,1281.75 1877.73,1281.72 1877.73,1281.69 1877.73,1281.65 1877.73,1281.62 1877.73,1281.58 1877.73,1281.55 1877.73,1281.51 1877.73,1281.48 1877.73,1281.45 1877.73,1281.41 1877.73,1281.38 1877.73,1281.34 1877.73,1281.31 1877.73,1281.27 1877.73,1281.24 1877.73,1281.2 1877.73,1281.17 1877.73,1281.14 1877.73,1281.1 1877.73,1281.07 1877.73,1281.03 1877.73,1281 1877.73,1280.96 1877.73,1280.93 1877.73,1280.89 1877.73,1280.86 1877.73,1280.83 1877.73,1280.79 1877.73,1280.76 1877.73,1280.72 1877.73,1280.69 1877.73,1280.65 1877.73,1280.62 1877.73,1280.59 1877.73,1280.55 1877.73,1280.52 1877.73,1280.48 1877.73,1280.45 1877.73,1280.41 1877.73,1280.38 1877.73,1280.34 1877.73,1280.31 1877.73,1280.28 1877.73,1280.24 1877.73,1280.21 1877.73,1280.17 1877.73,1280.14 1877.73,1280.1 1877.73,1280.07 1877.73,1280.03 1877.73,1280 1877.73,1279.97 1877.73,1279.93 1877.73,1279.9 1877.73,1279.86 1877.73,1279.83 1877.73,1279.79 1877.73,1279.76 1877.73,1279.72 1877.73,1279.69 1877.73,1279.66 1877.73,1279.62 1877.73,1279.59 1877.73,1279.55 1877.73,1279.52 1877.73,1279.48 1877.73,1279.45 1877.73,1279.41 1877.73,1279.38 1877.73,1279.35 1877.73,1279.31 1877.73,1279.28 1877.73,1279.24 1877.73,1279.21 1877.73,1279.17 1877.73,1279.14 1877.73,1279.1 1877.73,1279.07 1877.73,1279.04 1877.73,1279 1877.73,1278.97 1877.73,1278.93 1877.73,1278.9 1877.73,1278.86 1877.73,1278.83 1877.73,1278.79 1877.73,1278.76 1877.73,1278.73 1877.73,1278.69 1877.73,1278.66 1877.73,1278.62 1877.73,1278.59 1877.73,1278.55 1877.73,1278.52 1877.73,1278.48 1877.73,1278.45 1877.73,1278.42 1877.73,1278.38 1877.73,1278.35 1877.73,1278.31 1877.73,1278.28 1877.73,1278.24 1877.73,1278.21 1877.73,1278.17 1877.73,1278.14 1877.73,1278.11 1877.73,1278.07 1877.73,1278.04 1877.73,1278 1877.73,1277.97 1877.73,1277.93 1877.73,1277.9 1877.73,1277.86 1877.73,1277.83 1877.73,1277.8 1877.73,1277.76 1877.73,1277.73 1877.73,1277.69 1877.73,1277.66 1877.73,1277.62 1877.73,1277.59 1877.73,1277.55 1877.73,1277.52 1877.73,1277.48 1877.73,1277.45 1877.73,1277.42 1877.73,1277.38 1877.73,1277.35 1877.73,1277.31 1877.73,1277.28 1877.73,1277.24 1877.73,1277.21 1877.73,1277.17 1877.73,1277.14 1877.73,1277.11 1877.73,1277.07 1877.73,1277.04 1877.73,1277 1877.73,1276.97 1877.73,1276.93 1877.73,1276.9 1877.73,1276.86 1877.73,1276.83 1877.73,1276.79 1877.73,1276.76 1877.73,1276.73 1877.73,1276.69 1877.73,1276.66 1877.73,1276.62 1877.73,1276.59 1877.73,1276.55 1877.73,1276.52 1877.73,1276.48 1877.73,1276.45 1877.73,1276.41 1877.73,1276.38 1877.73,1276.35 1877.73,1276.31 1877.73,1276.28 1877.73,1276.24 1877.73,1276.21 1877.73,1276.17 1877.73,1276.14 1877.73,1276.1 1877.73,1276.07 1877.73,1276.03 1877.73,1276 1877.73,1275.97 1877.73,1275.93 1877.73,1275.9 1877.73,1275.86 1877.73,1275.83 1877.73,1275.79 1877.73,1275.76 1877.73,1275.72 1877.73,1275.69 1877.73,1275.66 1877.73,1275.62 1877.73,1275.59 1877.73,1275.55 1877.73,1275.52 1877.73,1275.48 1877.73,1275.45 1877.73,1275.41 1877.73,1275.38 1877.73,1275.34 1877.73,1275.31 1877.73,1275.27 1877.73,1275.24 1877.73,1275.21 1877.73,1275.17 1877.73,1275.14 1877.73,1275.1 1877.73,1275.07 1877.73,1275.03 1877.73,1275 1877.73,1274.96 1877.73,1274.93 1877.73,1274.89 1877.73,1274.86 1877.73,1274.83 1877.73,1274.79 1877.73,1274.76 1877.73,1274.72 1877.73,1274.69 1877.73,1274.65 1877.73,1274.62 1877.73,1274.58 1877.73,1274.55 1877.73,1274.51 1877.73,1274.48 1877.73,1274.45 1877.73,1274.41 1877.73,1274.38 1877.73,1274.34 1877.73,1274.31 1877.73,1274.27 1877.73,1274.24 1877.73,1274.2 1877.73,1274.17 1877.73,1274.13 1877.73,1274.1 1877.73,1274.06 1877.73,1274.03 1877.73,1274 1877.73,1273.96 1877.73,1273.93 1877.73,1273.89 1877.73,1273.86 1877.73,1273.82 1877.73,1273.79 1877.73,1273.75 1877.73,1273.72 1877.73,1273.68 1877.73,1273.65 1877.73,1273.62 1877.73,1273.58 1877.73,1273.55 1877.73,1273.51 1877.73,1273.48 1877.73,1273.44 1877.73,1273.41 1877.73,1273.37 1877.73,1273.34 1877.73,1273.3 1877.73,1273.27 1877.73,1273.23 1877.73,1273.2 1877.73,1273.17 1877.73,1273.13 1877.73,1273.1 1877.73,1273.06 1877.73,1273.03 1877.73,1272.99 1877.73,1272.96 1877.73,1272.92 1877.73,1272.89 1877.73,1272.85 1877.73,1272.82 1877.73,1272.78 1877.73,1272.75 1877.73,1272.72 1877.73,1272.68 1877.73,1272.65 1877.73,1272.61 1877.73,1272.58 1877.73,1272.54 1877.73,1272.51 1877.73,1272.47 1877.73,1272.44 1877.73,1272.4 1877.73,1272.37 1877.73,1272.33 1877.73,1272.3 1877.73,1272.27 1877.73,1272.23 1877.73,1272.2 1877.73,1272.16 1877.73,1272.13 1877.73,1272.09 1877.73,1272.06 1877.73,1272.02 1877.73,1271.99 1877.73,1271.95 1877.73,1271.92 1877.73,1271.88 1877.73,1271.85 1877.73,1271.81 1877.73,1271.78 1877.73,1271.75 1877.73,1271.71 1877.73,1271.68 1877.73,1271.64 1877.73,1271.61 1877.73,1271.57 1877.73,1271.54 1877.73,1271.5 1877.73,1271.47 1877.73,1271.43 1877.73,1271.4 1877.73,1271.36 1877.73,1271.33 1877.73,1271.3 1877.73,1271.26 1877.73,1271.23 1877.73,1271.19 1877.73,1271.16 1877.73,1271.12 1877.73,1271.09 1877.73,1271.05 1877.73,1271.02 1877.73,1270.98 1877.73,1270.95 1877.73,1270.91 1877.73,1270.88 1877.73,1270.84 1877.73,1270.81 1877.73,1270.78 1877.73,1270.74 1877.73,1270.71 1877.73,1270.67 1877.73,1270.64 1877.73,1270.6 1877.73,1270.57 1877.73,1270.53 1877.73,1270.5 1877.73,1270.46 1877.73,1270.43 1877.73,1270.39 1877.73,1270.36 1877.73,1270.32 1877.73,1270.29 1877.73,1270.26 1877.73,1270.22 1877.73,1270.19 1877.73,1270.15 1877.73,1270.12 1877.73,1270.08 1877.73,1270.05 1877.73,1270.01 1877.73,1269.98 1877.73,1269.94 1877.73,1269.91 1877.73,1269.87 1877.73,1269.84 1877.73,1269.8 1877.73,1269.77 1877.73,1269.73 1877.73,1269.7 1877.73,1269.67 1877.73,1269.63 1877.73,1269.6 1877.73,1269.56 1877.73,1269.53 1877.73,1269.49 1877.73,1269.46 1877.73,1269.42 1877.73,1269.39 1877.73,1269.35 1877.73,1269.32 1877.73,1269.28 1877.73,1269.25 1877.73,1269.21 1877.73,1269.18 1877.73,1269.14 1877.73,1269.11 1877.73,1269.08 1877.73,1269.04 1877.73,1269.01 1877.73,1268.97 1877.73,1268.94 1877.73,1268.9 1877.73,1268.87 1877.73,1268.83 1877.73,1268.8 1877.73,1268.76 1877.73,1268.73 1877.73,1268.69 1877.73,1268.66 1877.73,1268.62 1877.73,1268.59 1877.73,1268.55 1877.73,1268.52 1877.73,1268.49 1877.73,1268.45 1877.73,1268.42 1877.73,1268.38 1877.73,1268.35 1877.73,1268.31 1877.73,1268.28 1877.73,1268.24 1877.73,1268.21 1877.73,1268.17 1877.73,1268.14 1877.73,1268.1 1877.73,1268.07 1877.73,1268.03 1877.73,1268 1877.73,1267.96 1877.73,1267.93 1877.73,1267.89 1877.73,1267.86 1877.73,1267.83 1877.73,1267.79 1877.73,1267.76 1877.73,1267.72 1877.73,1267.69 1877.73,1267.65 1877.73,1267.62 1877.73,1267.58 1877.73,1267.55 1877.73,1267.51 1877.73,1267.48 1877.73,1267.44 1877.73,1267.41 1877.73,1267.37 1877.73,1267.34 1877.73,1267.3 1877.73,1267.27 1877.73,1267.23 1877.73,1267.2 1877.73,1267.16 1877.73,1267.13 1877.73,1267.1 1877.73,1267.06 1877.73,1267.03 1877.73,1266.99 1877.73,1266.96 1877.73,1266.92 1877.73,1266.89 1877.73,1266.85 1877.73,1266.82 1877.73,1266.78 1877.73,1266.75 1877.73,1266.71 1877.73,1266.68 1877.73,1266.64 1877.73,1266.61 1877.73,1266.57 1877.73,1266.54 1877.73,1266.5 1877.73,1266.47 1877.73,1266.43 1877.73,1266.4 1877.73,1266.37 1877.73,1266.33 1877.73,1266.3 1877.73,1266.26 1877.73,1266.23 1877.73,1266.19 1877.73,1266.16 1877.73,1266.12 1877.73,1266.09 1877.73,1266.05 1877.73,1266.02 1877.73,1265.98 1877.73,1265.95 1877.73,1265.91 1877.73,1265.88 1877.73,1265.84 1877.73,1265.81 1877.73,1265.77 1877.73,1265.74 1877.73,1265.7 1877.73,1265.67 1877.73,1265.63 1877.73,1265.6 1877.73,1265.57 1877.73,1265.53 1877.73,1265.5 1877.73,1265.46 1877.73,1265.43 1877.73,1265.39 1877.73,1265.36 1877.73,1265.32 1877.73,1265.29 1877.73,1265.25 1877.73,1265.22 1877.73,1265.18 1877.73,1265.15 1877.73,1265.11 1877.73,1265.08 1877.73,1265.04 1877.73,1265.01 1877.73,1264.97 1877.73,1264.94 1877.73,1264.9 1877.73,1264.87 1877.73,1264.83 1877.73,1264.8 1877.73,1264.77 1877.73,1264.73 1877.73,1264.7 1877.73,1264.66 1877.73,1264.63 1877.73,1264.59 1877.73,1264.56 1877.73,1264.52 1877.73,1264.49 1877.73,1264.45 1877.73,1264.42 1877.73,1264.38 1877.73,1264.35 1877.73,1264.31 1877.73,1264.28 1877.73,1264.24 1877.73,1264.21 1877.73,1264.17 1877.73,1264.14 1877.73,1264.1 1877.73,1264.07 1877.73,1264.03 1877.73,1264 1877.73,1263.96 1877.73,1263.93 1877.73,1263.89 1877.73,1263.86 1877.73,1263.82 1877.73,1263.79 1877.73,1263.76 1877.73,1263.72 1877.73,1263.69 1877.73,1263.65 1877.73,1263.62 1877.73,1263.58 1877.73,1263.55 1877.73,1263.51 1877.73,1263.48 1877.73,1263.44 1877.73,1263.41 1877.73,1263.37 1877.73,1263.34 1877.73,1263.3 1877.73,1263.27 1877.73,1263.23 1877.73,1263.2 1877.73,1263.16 1877.73,1263.13 1877.73,1263.09 1877.73,1263.06 1877.73,1263.02 1877.73,1262.99 1877.73,1262.95 1877.73,1262.92 1877.73,1262.88 1877.73,1262.85 1877.73,1262.81 1877.73,1262.78 1877.73,1262.74 1877.73,1262.71 1877.73,1262.68 1877.73,1262.64 1877.73,1262.61 1877.73,1262.57 1877.73,1262.54 1877.73,1262.5 1877.73,1262.47 1877.73,1262.43 1877.73,1262.4 1877.73,1262.36 1877.73,1262.33 1877.73,1262.29 1877.73,1262.26 1877.73,1262.22 1877.73,1262.19 1877.73,1262.15 1877.73,1262.12 1877.73,1262.08 1877.73,1262.05 1877.73,1262.01 1877.73,1261.98 1877.73,1261.94 1877.73,1261.91 1877.73,1261.87 1877.73,1261.84 1877.73,1261.8 1877.73,1261.77 1877.73,1261.73 1877.73,1261.7 1877.73,1261.66 1877.73,1261.63 1877.73,1261.59 1877.73,1261.56 1877.73,1261.52 1877.73,1261.49 1877.73,1261.45 1877.73,1261.42 1877.73,1261.39 1877.73,1261.35 1877.73,1261.32 1877.73,1261.28 1877.73,1261.25 1877.73,1261.21 1877.73,1261.18 1877.73,1261.14 1877.73,1261.11 1877.73,1261.07 1877.73,1261.04 1877.73,1261 1877.73,1260.97 1877.73,1260.93 1877.73,1260.9 1877.73,1260.86 1877.73,1260.83 1877.73,1260.79 1877.73,1260.76 1877.73,1260.72 1877.73,1260.69 1877.73,1260.65 1877.73,1260.62 1877.73,1260.58 1877.73,1260.55 1877.73,1260.51 1877.73,1260.48 1877.73,1260.44 1877.73,1260.41 1877.73,1260.37 1877.73,1260.34 1877.73,1260.3 1877.73,1260.27 1877.73,1260.23 1877.73,1260.2 1877.73,1260.16 1877.73,1260.13 1877.73,1260.09 1877.73,1260.06 1877.73,1260.02 1877.73,1259.99 1877.73,1259.95 1877.73,1259.92 1877.73,1259.88 1877.73,1259.85 1877.73,1259.81 1877.73,1259.78 1877.73,1259.74 1877.73,1259.71 1877.73,1259.68 1877.73,1259.64 1877.73,1259.61 1877.73,1259.57 1877.73,1259.54 1877.73,1259.5 1877.73,1259.47 1877.73,1259.43 1877.73,1259.4 1877.73,1259.36 1877.73,1259.33 1877.73,1259.29 1877.73,1259.26 1877.73,1259.22 1877.73,1259.19 1877.73,1259.15 1877.73,1259.12 1877.73,1259.08 1877.73,1259.05 1877.73,1259.01 1877.73,1258.98 1877.73,1258.94 1877.73,1258.91 1877.73,1258.87 1877.73,1258.84 1877.73,1258.8 1877.73,1258.77 1877.73,1258.73 1877.73,1258.7 1877.73,1258.66 1877.73,1258.63 1877.73,1258.59 1877.73,1258.56 1877.73,1258.52 1877.73,1258.49 1877.73,1258.45 1877.73,1258.42 1877.73,1258.38 1877.73,1258.35 1877.73,1258.31 1877.73,1258.28 1877.73,1258.24 1877.73,1258.21 1877.73,1258.17 1877.73,1258.14 1877.73,1258.1 1877.73,1258.07 1877.73,1258.03 1877.73,1258 1877.73,1257.96 1877.73,1257.93 1877.73,1257.89 1877.73,1257.86 1877.73,1257.82 1877.73,1257.79 1877.73,1257.75 1877.73,1257.72 1877.73,1257.68 1877.73,1257.65 1877.73,1257.61 1877.73,1257.58 1877.73,1257.54 1877.73,1257.51 1877.73,1257.47 1877.73,1257.44 1877.73,1257.4 1877.73,1257.37 1877.73,1257.33 1877.73,1257.3 1877.73,1257.26 1877.73,1257.23 1877.73,1257.19 1877.73,1257.16 1877.73,1257.12 1877.73,1257.09 1877.73,1257.05 1877.73,1257.02 1877.73,1256.98 1877.73,1256.95 1877.73,1256.91 1877.73,1256.88 1877.73,1256.84 1877.73,1256.81 1877.73,1256.78 1877.73,1256.74 1877.73,1256.71 1877.73,1256.67 1877.73,1256.64 1877.73,1256.6 1877.73,1256.57 1877.73,1256.53 1877.73,1256.5 1877.73,1256.46 1877.73,1256.43 1877.73,1256.39 1877.73,1256.36 1877.73,1256.32 1877.73,1256.29 1877.73,1256.25 1877.73,1256.22 1877.73,1256.18 1877.73,1256.15 1877.73,1256.11 1877.73,1256.08 1877.73,1256.04 1877.73,1256.01 1877.73,1255.97 1877.73,1255.94 1877.73,1255.9 1877.73,1255.87 1877.73,1255.83 1877.73,1255.8 1877.73,1255.76 1877.73,1255.73 1877.73,1255.69 1877.73,1255.66 1877.73,1255.62 1877.73,1255.59 1877.73,1255.55 1877.73,1255.52 1877.73,1255.48 1877.73,1255.45 1877.73,1255.41 1877.73,1255.38 1877.73,1255.34 1877.73,1255.31 1877.73,1255.27 1877.73,1255.24 1877.73,1255.2 1877.73,1255.17 1877.73,1255.13 1877.73,1255.1 1877.73,1255.06 1877.73,1255.03 1877.73,1254.99 1877.73,1254.96 1877.73,1254.92 1877.73,1254.89 1877.73,1254.85 1877.73,1254.82 1877.73,1254.78 1877.73,1254.75 1877.73,1254.71 1877.73,1254.68 1877.73,1254.64 1877.73,1254.61 1877.73,1254.57 1877.73,1254.54 1877.73,1254.5 1877.73,1254.47 1877.73,1254.43 1877.73,1254.4 1877.73,1254.36 1877.73,1254.33 1877.73,1254.29 1877.73,1254.26 1877.73,1254.22 1877.73,1254.19 1877.73,1254.15 1877.73,1254.12 1877.73,1254.08 1877.73,1254.05 1877.73,1254.01 1877.73,1253.98 1877.73,1253.94 1877.73,1253.91 1877.73,1253.87 1877.73,1253.84 1877.73,1253.8 1877.73,1253.77 1877.73,1253.73 1877.73,1253.7 1877.73,1253.66 1877.73,1253.63 1877.73,1253.59 1877.73,1253.56 1877.73,1253.52 1877.73,1253.49 1877.73,1253.45 1877.73,1253.42 1877.73,1253.38 1877.73,1253.35 1877.73,1253.31 1877.73,1253.28 1877.73,1253.24 1877.73,1253.21 1877.73,1253.17 1877.73,1253.14 1877.73,1253.1 1877.73,1253.06 1877.73,1253.03 1877.73,1252.99 1877.73,1252.96 1877.73,1252.92 1877.73,1252.89 1877.73,1252.85 1877.73,1252.82 1877.73,1252.78 1877.73,1252.75 1877.73,1252.71 1877.73,1252.68 1877.73,1252.64 1877.73,1252.61 1877.73,1252.57 1877.73,1252.54 1877.73,1252.5 1877.73,1252.47 1877.73,1252.43 1877.73,1252.4 1877.73,1252.36 1877.73,1252.33 1877.73,1252.29 1877.73,1252.26 1877.73,1252.22 1877.73,1252.19 1877.73,1252.15 1877.73,1252.12 1877.73,1252.08 1877.73,1252.05 1877.73,1252.01 1877.73,1251.98 1877.73,1251.94 1877.73,1251.91 1877.73,1251.87 1877.73,1251.84 1877.73,1251.8 1877.73,1251.77 1877.73,1251.73 1877.73,1251.7 1877.73,1251.66 1877.73,1251.63 1877.73,1251.59 1877.73,1251.56 1877.73,1251.52 1877.73,1251.49 1877.73,1251.45 1877.73,1251.42 1877.73,1251.38 1877.73,1251.35 1877.73,1251.31 1877.73,1251.28 1877.73,1251.24 1877.73,1251.21 1877.73,1251.17 1877.73,1251.14 1877.73,1251.1 1877.73,1251.07 1877.73,1251.03 1877.73,1251 1877.73,1250.96 1877.73,1250.93 1877.73,1250.89 1877.73,1250.86 1877.73,1250.82 1877.73,1250.79 1877.73,1250.75 1877.73,1250.72 1877.73,1250.68 1877.73,1250.65 1877.73,1250.61 1877.73,1250.58 1877.73,1250.54 1877.73,1250.51 1877.73,1250.47 1877.73,1250.44 1877.73,1250.4 1877.73,1250.37 1877.73,1250.33 1877.73,1250.3 1877.73,1250.26 1877.73,1250.23 1877.73,1250.19 1877.73,1250.16 1877.73,1250.12 1877.73,1250.09 1877.73,1250.05 1877.73,1250.01 1877.73,1249.98 1877.73,1249.94 1877.73,1249.91 1877.73,1249.87 1877.73,1249.84 1877.73,1249.8 1877.73,1249.77 1877.73,1249.73 1877.73,1249.7 1877.73,1249.66 1877.73,1249.63 1877.73,1249.59 1877.73,1249.56 1877.73,1249.52 1877.73,1249.49 1877.73,1249.45 1877.73,1249.42 1877.73,1249.38 1877.73,1249.35 1877.73,1249.31 1877.73,1249.28 1877.73,1249.24 1877.73,1249.21 1877.73,1249.17 1877.73,1249.14 1877.73,1249.1 1877.73,1249.07 1877.73,1249.03 1877.73,1249 1877.73,1248.96 1877.73,1248.93 1877.73,1248.89 1877.73,1248.86 1877.73,1248.82 1877.73,1248.79 1877.73,1248.75 1877.73,1248.72 1877.73,1248.68 1877.73,1248.65 1877.73,1248.61 1877.73,1248.58 1877.73,1248.54 1877.73,1248.51 1877.73,1248.47 1877.73,1248.44 1877.73,1248.4 1877.73,1248.37 1877.73,1248.33 1877.73,1248.3 1877.73,1248.26 1877.73,1248.23 1877.73,1248.19 1877.73,1248.15 1877.73,1248.12 1877.73,1248.08 1877.73,1248.05 1877.73,1248.01 1877.73,1247.98 1877.73,1247.94 1877.73,1247.91 1877.73,1247.87 1877.73,1247.84 1877.73,1247.8 1877.73,1247.77 1877.73,1247.73 1877.73,1247.7 1877.73,1247.66 1877.73,1247.63 1877.73,1247.59 1877.73,1247.56 1877.73,1247.52 1877.73,1247.49 1877.73,1247.45 1877.73,1247.42 1877.73,1247.38 1877.73,1247.35 1877.73,1247.31 1877.73,1247.28 1877.73,1247.24 1877.73,1247.21 1877.73,1247.17 1877.73,1247.14 1877.73,1247.1 1877.73,1247.07 1877.73,1247.03 1877.73,1247 1877.73,1246.96 1877.73,1246.93 1877.73,1246.89 1877.73,1246.86 1877.73,1246.82 1877.73,1246.79 1877.73,1246.75 1877.73,1246.71 1877.73,1246.68 1877.73,1246.64 1877.73,1246.61 1877.73,1246.57 1877.73,1246.54 1877.73,1246.5 1877.73,1246.47 1877.73,1246.43 1877.73,1246.4 1877.73,1246.36 1877.73,1246.33 1877.73,1246.29 1877.73,1246.26 1877.73,1246.22 1877.73,1246.19 1877.73,1246.15 1877.73,1246.12 1877.73,1246.08 1877.73,1246.05 1877.73,1246.01 1877.73,1245.98 1877.73,1245.94 1877.73,1245.91 1877.73,1245.87 1877.73,1245.84 1877.73,1245.8 1877.73,1245.77 1877.73,1245.73 1877.73,1245.7 1877.73,1245.66 1877.73,1245.63 1877.73,1245.59 1877.73,1245.56 1877.73,1245.52 1877.73,1245.48 1877.73,1245.45 1877.73,1245.41 1877.73,1245.38 1877.73,1245.34 1877.73,1245.31 1877.73,1245.27 1877.73,1245.24 1877.73,1245.2 1877.73,1245.17 1877.73,1245.13 1877.73,1245.1 1877.73,1245.06 1877.73,1245.03 1877.73,1244.99 1877.73,1244.96 1877.73,1244.92 1877.73,1244.89 1877.73,1244.85 1877.73,1244.82 1877.73,1244.78 1877.73,1244.75 1877.73,1244.71 1877.73,1244.68 1877.73,1244.64 1877.73,1244.61 1877.73,1244.57 1877.73,1244.54 1877.73,1244.5 1877.73,1244.47 1877.73,1244.43 1877.73,1244.4 1877.73,1244.36 1877.73,1244.32 1877.73,1244.29 1877.73,1244.25 1877.73,1244.22 1877.73,1244.18 1877.73,1244.15 1877.73,1244.11 1877.73,1244.08 1877.73,1244.04 1877.73,1244.01 1877.73,1243.97 1877.73,1243.94 1877.73,1243.9 1877.73,1243.87 1877.73,1243.83 1877.73,1243.8 1877.73,1243.76 1877.73,1243.73 1877.73,1243.69 1877.73,1243.66 1877.73,1243.62 1877.73,1243.59 1877.73,1243.55 1877.73,1243.52 1877.73,1243.48 1877.73,1243.45 1877.73,1243.41 1877.73,1243.38 1877.73,1243.34 1877.73,1243.3 1877.73,1243.27 1877.73,1243.23 1877.73,1243.2 1877.73,1243.16 1877.73,1243.13 1877.73,1243.09 1877.73,1243.06 1877.73,1243.02 1877.73,1242.99 1877.73,1242.95 1877.73,1242.92 1877.73,1242.88 1877.73,1242.85 1877.73,1242.81 1877.73,1242.78 1877.73,1242.74 1877.73,1242.71 1877.73,1242.67 1877.73,1242.64 1877.73,1242.6 1877.73,1242.57 1877.73,1242.53 1877.73,1242.5 1877.73,1242.46 1877.73,1242.43 1877.73,1242.39 1877.73,1242.35 1877.73,1242.32 1877.73,1242.28 1877.73,1242.25 1877.73,1242.21 1877.73,1242.18 1877.73,1242.14 1877.73,1242.11 1877.73,1242.07 1877.73,1242.04 1877.73,1242 1877.73,1241.97 1877.73,1241.93 1877.73,1241.9 1877.73,1241.86 1877.73,1241.83 1877.73,1241.79 1877.73,1241.76 1877.73,1241.72 1877.73,1241.69 1877.73,1241.65 1877.73,1241.62 1877.73,1241.58 1877.73,1241.55 1877.73,1241.51 1877.73,1241.47 1877.73,1241.44 1877.73,1241.4 1877.73,1241.37 1877.73,1241.33 1877.73,1241.3 1877.73,1241.26 1877.73,1241.23 1877.73,1241.19 1877.73,1241.16 1877.73,1241.12 1877.73,1241.09 1877.73,1241.05 1877.73,1241.02 1877.73,1240.98 1877.73,1240.95 1877.73,1240.91 1877.73,1240.88 1877.73,1240.84 1877.73,1240.81 1877.73,1240.77 1877.73,1240.74 1877.73,1240.7 1877.73,1240.67 1877.73,1240.63 1877.73,1240.59 1877.73,1240.56 1877.73,1240.52 1877.73,1240.49 1877.73,1240.45 1877.73,1240.42 1877.73,1240.38 1877.73,1240.35 1877.73,1240.31 1877.73,1240.28 1877.73,1240.24 1877.73,1240.21 1877.73,1240.17 1877.73,1240.14 1877.73,1240.1 1877.73,1240.07 1877.73,1240.03 1877.73,1240 1877.73,1239.96 1877.73,1239.93 1877.73,1239.89 1877.73,1239.86 1877.73,1239.82 1877.73,1239.78 1877.73,1239.75 1877.73,1239.71 1877.73,1239.68 1877.73,1239.64 1877.73,1239.61 1877.73,1239.57 1877.73,1239.54 1877.73,1239.5 1877.73,1239.47 1877.73,1239.43 1877.73,1239.4 1877.73,1239.36 1877.73,1239.33 1877.73,1239.29 1877.73,1239.26 1877.73,1239.22 1877.73,1239.19 1877.73,1239.15 1877.73,1239.12 1877.73,1239.08 1877.73,1239.04 1877.73,1239.01 1877.73,1238.97 1877.73,1238.94 1877.73,1238.9 1877.73,1238.87 1877.73,1238.83 1877.73,1238.8 1877.73,1238.76 1877.73,1238.73 1877.73,1238.69 1877.73,1238.66 1877.73,1238.62 1877.73,1238.59 1877.73,1238.55 1877.73,1238.52 1877.73,1238.48 1877.73,1238.45 1877.73,1238.41 1877.73,1238.38 1877.73,1238.34 1877.73,1238.31 1877.73,1238.27 1877.73,1238.23 1877.73,1238.2 1877.73,1238.16 1877.73,1238.13 1877.73,1238.09 1877.73,1238.06 1877.73,1238.02 1877.73,1237.99 1877.73,1237.95 1877.73,1237.92 1877.73,1237.88 1877.73,1237.85 1877.73,1237.81 1877.73,1237.78 1877.73,1237.74 1877.73,1237.71 1877.73,1237.67 1877.73,1237.64 1877.73,1237.6 1877.73,1237.56 1877.73,1237.53 1877.73,1237.49 1877.73,1237.46 1877.73,1237.42 1877.73,1237.39 1877.73,1237.35 1877.73,1237.32 1877.73,1237.28 1877.73,1237.25 1877.73,1237.21 1877.73,1237.18 1877.73,1237.14 1877.73,1237.11 1877.73,1237.07 1877.73,1237.04 1877.73,1237 1877.73,1236.97 1877.73,1236.93 1877.73,1236.9 1877.73,1236.86 1877.73,1236.82 1877.73,1236.79 1877.73,1236.75 1877.73,1236.72 1877.73,1236.68 1877.73,1236.65 1877.73,1236.61 1877.73,1236.58 1877.73,1236.54 1877.73,1236.51 1877.73,1236.47 1877.73,1236.44 1877.73,1236.4 1877.73,1236.37 1877.73,1236.33 1877.73,1236.3 1877.73,1236.26 1877.73,1236.23 1877.73,1236.19 1877.73,1236.15 1877.73,1236.12 1877.73,1236.08 1877.73,1236.05 1877.73,1236.01 1877.73,1235.98 1877.73,1235.94 1877.73,1235.91 1877.73,1235.87 1877.73,1235.84 1877.73,1235.8 1877.73,1235.77 1877.73,1235.73 1877.73,1235.7 1877.73,1235.66 1877.73,1235.63 1877.73,1235.59 1877.73,1235.56 1877.73,1235.52 1877.73,1235.48 1877.73,1235.45 1877.73,1235.41 1877.73,1235.38 1877.73,1235.34 1877.73,1235.31 1877.73,1235.27 1877.73,1235.24 1877.73,1235.2 1877.73,1235.17 1877.73,1235.13 1877.73,1235.1 1877.73,1235.06 1877.73,1235.03 1877.73,1234.99 1877.73,1234.96 1877.73,1234.92 1877.73,1234.88 1877.73,1234.85 1877.73,1234.81 1877.73,1234.78 1877.73,1234.74 1877.73,1234.71 1877.73,1234.67 1877.73,1234.64 1877.73,1234.6 1877.73,1234.57 1877.73,1234.53 1877.73,1234.5 1877.73,1234.46 1877.73,1234.43 1877.73,1234.39 1877.73,1234.36 1877.73,1234.32 1877.73,1234.29 1877.73,1234.25 1877.73,1234.21 1877.73,1234.18 1877.73,1234.14 1877.73,1234.11 1877.73,1234.07 1877.73,1234.04 1877.73,1234 1877.73,1233.97 1877.73,1233.93 1877.73,1233.9 1877.73,1233.86 1877.73,1233.83 1877.73,1233.79 1877.73,1233.76 1877.73,1233.72 1877.73,1233.69 1877.73,1233.65 1877.73,1233.61 1877.73,1233.58 1877.73,1233.54 1877.73,1233.51 1877.73,1233.47 1877.73,1233.44 1877.73,1233.4 1877.73,1233.37 1877.73,1233.33 1877.73,1233.3 1877.73,1233.26 1877.73,1233.23 1877.73,1233.19 1877.73,1233.16 1877.73,1233.12 1877.73,1233.09 1877.73,1233.05 1877.73,1233.01 1877.73,1232.98 1877.73,1232.94 1877.73,1232.91 1877.73,1232.87 1877.73,1232.84 1877.73,1232.8 1877.73,1232.77 1877.73,1232.73 1877.73,1232.7 1877.73,1232.66 1877.73,1232.63 1877.73,1232.59 1877.73,1232.56 1877.73,1232.52 1877.73,1232.49 1877.73,1232.45 1877.73,1232.41 1877.73,1232.38 1877.73,1232.34 1877.73,1232.31 1877.73,1232.27 1877.73,1232.24 1877.73,1232.2 1877.73,1232.17 1877.73,1232.13 1877.73,1232.1 1877.73,1232.06 1877.73,1232.03 1877.73,1231.99 1877.73,1231.96 1877.73,1231.92 1877.73,1231.89 1877.73,1231.85 1877.73,1231.81 1877.73,1231.78 1877.73,1231.74 1877.73,1231.71 1877.73,1231.67 1877.73,1231.64 1877.73,1231.6 1877.73,1231.57 1877.73,1231.53 1877.73,1231.5 1877.73,1231.46 1877.73,1231.43 1877.73,1231.39 1877.73,1231.36 1877.73,1231.32 1877.73,1231.28 1877.73,1231.25 1877.73,1231.21 1877.73,1231.18 1877.73,1231.14 1877.73,1231.11 1877.73,1231.07 1877.73,1231.04 1877.73,1231 1877.73,1230.97 1877.73,1230.93 1877.73,1230.9 1877.73,1230.86 1877.73,1230.83 1877.73,1230.79 1877.73,1230.76 1877.73,1230.72 1877.73,1230.68 1877.73,1230.65 1877.73,1230.61 1877.73,1230.58 1877.73,1230.54 1877.73,1230.51 1877.73,1230.47 1877.73,1230.44 1877.73,1230.4 1877.73,1230.37 1877.73,1230.33 1877.73,1230.3 1877.73,1230.26 1877.73,1230.23 1877.73,1230.19 1877.73,1230.15 1877.73,1230.12 1877.73,1230.08 1877.73,1230.05 1877.73,1230.01 1877.73,1229.98 1877.73,1229.94 1877.73,1229.91 1877.73,1229.87 1877.73,1229.84 1877.73,1229.8 1877.73,1229.77 1877.73,1229.73 1877.73,1229.7 1877.73,1229.66 1877.73,1229.62 1877.73,1229.59 1877.73,1229.55 1877.73,1229.52 1877.73,1229.48 1877.73,1229.45 1877.73,1229.41 1877.73,1229.38 1877.73,1229.34 1877.73,1229.31 1877.73,1229.27 1877.73,1229.24 1877.73,1229.2 1877.73,1229.17 1877.73,1229.13 1877.73,1229.1 1877.73,1229.06 1877.73,1229.02 1877.73,1228.99 1877.73,1228.95 1877.73,1228.92 1877.73,1228.88 1877.73,1228.85 1877.73,1228.81 1877.73,1228.78 1877.73,1228.74 1877.73,1228.71 1877.73,1228.67 1877.73,1228.64 1877.73,1228.6 1877.73,1228.57 1877.73,1228.53 1877.73,1228.49 1877.73,1228.46 1877.73,1228.42 1877.73,1228.39 1877.73,1228.35 1877.73,1228.32 1877.73,1228.28 1877.73,1228.25 1877.73,1228.21 1877.73,1228.18 1877.73,1228.14 1877.73,1228.11 1877.73,1228.07 1877.73,1228.03 1877.73,1228 1877.73,1227.96 1877.73,1227.93 1877.73,1227.89 1877.73,1227.86 1877.73,1227.82 1877.73,1227.79 1877.73,1227.75 1877.73,1227.72 1877.73,1227.68 1877.73,1227.65 1877.73,1227.61 1877.73,1227.58 1877.73,1227.54 1877.73,1227.5 1877.73,1227.47 1877.73,1227.43 1877.73,1227.4 1877.73,1227.36 1877.73,1227.33 1877.73,1227.29 1877.73,1227.26 1877.73,1227.22 1877.73,1227.19 1877.73,1227.15 1877.73,1227.12 1877.73,1227.08 1877.73,1227.05 1877.73,1227.01 1877.73,1226.97 1877.73,1226.94 1877.73,1226.9 1877.73,1226.87 1877.73,1226.83 1877.73,1226.8 1877.73,1226.76 1877.73,1226.73 1877.73,1226.69 1877.73,1226.66 1877.73,1226.62 1877.73,1226.59 1877.73,1226.55 1877.73,1226.52 1877.73,1226.48 1877.73,1226.44 1877.73,1226.41 1877.73,1226.37 1877.73,1226.34 1877.73,1226.3 1877.73,1226.27 1877.73,1226.23 1877.73,1226.2 1877.73,1226.16 1877.73,1226.13 1877.73,1226.09 1877.73,1226.06 1877.73,1226.02 1877.73,1225.98 1877.73,1225.95 1877.73,1225.91 1877.73,1225.88 1877.73,1225.84 1877.73,1225.81 1877.73,1225.77 1877.73,1225.74 1877.73,1225.7 1877.73,1225.67 1877.73,1225.63 1877.73,1225.6 1877.73,1225.56 1877.73,1225.53 1877.73,1225.49 1877.73,1225.45 1877.73,1225.42 1877.73,1225.38 1877.73,1225.35 1877.73,1225.31 1877.73,1225.28 1877.73,1225.24 1877.73,1225.21 1877.73,1225.17 1877.73,1225.14 1877.73,1225.1 1877.73,1225.07 1877.73,1225.03 1877.73,1224.99 1877.73,1224.96 1877.73,1224.92 1877.73,1224.89 1877.73,1224.85 1877.73,1224.82 1877.73,1224.78 1877.73,1224.75 1877.73,1224.71 1877.73,1224.68 1877.73,1224.64 1877.73,1224.61 1877.73,1224.57 1877.73,1224.53 1877.73,1224.5 1877.73,1224.46 1877.73,1224.43 1877.73,1224.39 1877.73,1224.36 1877.73,1224.32 1877.73,1224.29 1877.73,1224.25 1877.73,1224.22 1877.73,1224.18 1877.73,1224.15 1877.73,1224.11 1877.73,1224.08 1877.73,1224.04 1877.73,1224 1877.73,1223.97 1877.73,1223.93 1877.73,1223.9 1877.73,1223.86 1877.73,1223.83 1877.73,1223.79 1877.73,1223.76 1877.73,1223.72 1877.73,1223.69 1877.73,1223.65 1877.73,1223.62 1877.73,1223.58 1877.73,1223.54 1877.73,1223.51 1877.73,1223.47 1877.73,1223.44 1877.73,1223.4 1877.73,1223.37 1877.73,1223.33 1877.73,1223.3 1877.73,1223.26 1877.73,1223.23 1877.73,1223.19 1877.73,1223.16 1877.73,1223.12 1877.73,1223.08 1877.73,1223.05 1877.73,1223.01 1877.73,1222.98 1877.73,1222.94 1877.73,1222.91 1877.73,1222.87 1877.73,1222.84 1877.73,1222.8 1877.73,1222.77 1877.73,1222.73 1877.73,1222.7 1877.73,1222.66 1877.73,1222.62 1877.73,1222.59 1877.73,1222.55 1877.73,1222.52 1877.73,1222.48 1877.73,1222.45 1877.73,1222.41 1877.73,1222.38 1877.73,1222.34 1877.73,1222.31 1877.73,1222.27 1877.73,1222.24 1877.73,1222.2 1877.73,1222.16 1877.73,1222.13 1877.73,1222.09 1877.73,1222.06 1877.73,1222.02 1877.73,1221.99 1877.73,1221.95 1877.73,1221.92 1877.73,1221.88 1877.73,1221.85 1877.73,1221.81 1877.73,1221.78 1877.73,1221.74 1877.73,1221.7 1877.73,1221.67 1877.73,1221.63 1877.73,1221.6 1877.73,1221.56 1877.73,1221.53 1877.73,1221.49 1877.73,1221.46 1877.73,1221.42 1877.73,1221.39 1877.73,1221.35 1877.73,1221.32 1877.73,1221.28 1877.73,1221.24 1877.73,1221.21 1877.73,1221.17 1877.73,1221.14 1877.73,1221.1 1877.73,1221.07 1877.73,1221.03 1877.73,1221 1877.73,1220.96 1877.73,1220.93 1877.73,1220.89 1877.73,1220.86 1877.73,1220.82 1877.73,1220.78 1877.73,1220.75 1877.73,1220.71 1877.73,1220.68 1877.73,1220.64 1877.73,1220.61 1877.73,1220.57 1877.73,1220.54 1877.73,1220.5 1877.73,1220.47 1877.73,1220.43 1877.73,1220.4 1877.73,1220.36 1877.73,1220.32 1877.73,1220.29 1877.73,1220.25 1877.73,1220.22 1877.73,1220.18 1877.73,1220.15 1877.73,1220.11 1877.73,1220.08 1877.73,1220.04 1877.73,1220.01 1877.73,1219.97 1877.73,1219.94 1877.73,1219.9 1877.73,1219.86 1877.73,1219.83 1877.73,1219.79 1877.73,1219.76 1877.73,1219.72 1877.73,1219.69 1877.73,1219.65 1877.73,1219.62 1877.73,1219.58 1877.73,1219.55 1877.73,1219.51 1877.73,1219.48 1877.73,1219.44 1877.73,1219.4 1877.73,1219.37 1877.73,1219.33 1877.73,1219.3 1877.73,1219.26 1877.73,1219.23 1877.73,1219.19 1877.73,1219.16 1877.73,1219.12 1877.73,1219.09 1877.73,1219.05 1877.73,1219.02 1877.73,1218.98 1877.73,1218.94 1877.73,1218.91 1877.73,1218.87 1877.73,1218.84 1877.73,1218.8 1877.73,1218.77 1877.73,1218.73 1877.73,1218.7 1877.73,1218.66 1877.73,1218.63 1877.73,1218.59 1877.73,1218.55 1877.73,1218.52 1877.73,1218.48 1877.73,1218.45 1877.73,1218.41 1877.73,1218.38 1877.73,1218.34 1877.73,1218.31 1877.73,1218.27 1877.73,1218.24 1877.73,1218.2 1877.73,1218.17 1877.73,1218.13 1877.73,1218.09 1877.73,1218.06 1877.73,1218.02 1877.73,1217.99 1877.73,1217.95 1877.73,1217.92 1877.73,1217.88 1877.73,1217.85 1877.73,1217.81 1877.73,1217.78 1877.73,1217.74 1877.73,1217.71 1877.73,1217.67 1877.73,1217.63 1877.73,1217.6 1877.73,1217.56 1877.73,1217.53 1877.73,1217.49 1877.73,1217.46 1877.73,1217.42 1877.73,1217.39 1877.73,1217.35 1877.73,1217.32 1877.73,1217.28 1877.73,1217.24 1877.73,1217.21 1877.73,1217.17 1877.73,1217.14 1877.73,1217.1 1877.73,1217.07 1877.73,1217.03 1877.73,1217 1877.73,1216.96 1877.73,1216.93 1877.73,1216.89 1877.73,1216.86 1877.73,1216.82 1877.73,1216.78 1877.73,1216.75 1877.73,1216.71 1877.73,1216.68 1877.73,1216.64 1877.73,1216.61 1877.73,1216.57 1877.73,1216.54 1877.73,1216.5 1877.73,1216.47 1877.73,1216.43 1877.73,1216.39 1877.73,1216.36 1877.73,1216.32 1877.73,1216.29 1877.73,1216.25 1877.73,1216.22 1877.73,1216.18 1877.73,1216.15 1877.73,1216.11 1877.73,1216.08 1877.73,1216.04 1877.73,1216.01 1877.73,1215.97 1877.73,1215.93 1877.73,1215.9 1877.73,1215.86 1877.73,1215.83 1877.73,1215.79 1877.73,1215.76 1877.73,1215.72 1877.73,1215.69 1877.73,1215.65 1877.73,1215.62 1877.73,1215.58 1877.73,1215.54 1877.73,1215.51 1877.73,1215.47 1877.73,1215.44 1877.73,1215.4 1877.73,1215.37 1877.73,1215.33 1877.73,1215.3 1877.73,1215.26 1877.73,1215.23 1877.73,1215.19 1877.73,1215.16 1877.73,1215.12 1877.73,1215.08 1877.73,1215.05 1877.73,1215.01 1877.73,1214.98 1877.73,1214.94 1877.73,1214.91 1877.73,1214.87 1877.73,1214.84 1877.73,1214.8 1877.73,1214.77 1877.73,1214.73 1877.73,1214.69 1877.73,1214.66 1877.73,1214.62 1877.73,1214.59 1877.73,1214.55 1877.73,1214.52 1877.73,1214.48 1877.73,1214.45 1877.73,1214.41 1877.73,1214.38 1877.73,1214.34 1877.73,1214.31 1877.73,1214.27 1877.73,1214.23 1877.73,1214.2 1877.73,1214.16 1877.73,1214.13 1877.73,1214.09 1877.73,1214.06 1877.73,1214.02 1877.73,1213.99 1877.73,1213.95 1877.73,1213.92 1877.73,1213.88 1877.73,1213.84 1877.73,1213.81 1877.73,1213.77 1877.73,1213.74 1877.73,1213.7 1877.73,1213.67 1877.73,1213.63 1877.73,1213.6 1877.73,1213.56 1877.73,1213.53 1877.73,1213.49 1877.73,1213.45 1877.73,1213.42 1877.73,1213.38 1877.73,1213.35 1877.73,1213.31 1877.73,1213.28 1877.73,1213.24 1877.73,1213.21 1877.73,1213.17 1877.73,1213.14 1877.73,1213.1 1877.73,1213.07 1877.73,1213.03 1877.73,1212.99 1877.73,1212.96 1877.73,1212.92 1877.73,1212.89 1877.73,1212.85 1877.73,1212.82 1877.73,1212.78 1877.73,1212.75 1877.73,1212.71 1877.73,1212.68 1877.73,1212.64 1877.73,1212.6 1877.73,1212.57 1877.73,1212.53 1877.73,1212.5 1877.73,1212.46 1877.73,1212.43 1877.73,1212.39 1877.73,1212.36 1877.73,1212.32 1877.73,1212.29 1877.73,1212.25 1877.73,1212.21 1877.73,1212.18 1877.73,1212.14 1877.73,1212.11 1877.73,1212.07 1877.73,1212.04 1877.73,1212 1877.73,1211.97 1877.73,1211.93 1877.73,1211.9 1877.73,1211.86 1877.73,1211.83 1877.73,1211.79 1877.73,1211.75 1877.73,1211.72 1877.73,1211.68 1877.73,1211.65 1877.73,1211.61 1877.73,1211.58 1877.73,1211.54 1877.73,1211.51 1877.73,1211.47 1877.73,1211.44 1877.73,1211.4 1877.73,1211.36 1877.73,1211.33 1877.73,1211.29 1877.73,1211.26 1877.73,1211.22 1877.73,1211.19 1877.73,1211.15 1877.73,1211.12 1877.73,1211.08 1877.73,1211.05 1877.73,1211.01 1877.73,1210.97 1877.73,1210.94 1877.73,1210.9 1877.73,1210.87 1877.73,1210.83 1877.73,1210.8 1877.73,1210.76 1877.73,1210.73 1877.73,1210.69 1877.73,1210.66 1877.73,1210.62 1877.73,1210.58 1877.73,1210.55 1877.73,1210.51 1877.73,1210.48 1877.73,1210.44 1877.73,1210.41 1877.73,1210.37 1877.73,1210.34 1877.73,1210.3 1877.73,1210.27 1877.73,1210.23 1877.73,1210.2 1877.73,1210.16 1877.73,1210.12 1877.73,1210.09 1877.73,1210.05 1877.73,1210.02 1877.73,1209.98 1877.73,1209.95 1877.73,1209.91 1877.73,1209.88 1877.73,1209.84 1877.73,1209.81 1877.73,1209.77 1877.73,1209.73 1877.73,1209.7 1877.73,1209.66 1877.73,1209.63 1877.73,1209.59 1877.73,1209.56 1877.73,1209.52 1877.73,1209.49 1877.73,1209.45 1877.73,1209.42 1877.73,1209.38 1877.73,1209.34 1877.73,1209.31 1877.73,1209.27 1877.73,1209.24 1877.73,1209.2 1877.73,1209.17 1877.73,1209.13 1877.73,1209.1 1877.73,1209.06 1877.73,1209.03 1877.73,1208.99 1877.73,1208.95 1877.73,1208.92 1877.73,1208.88 1877.73,1208.85 1877.73,1208.81 1877.73,1208.78 1877.73,1208.74 1877.73,1208.71 1877.73,1208.67 1877.73,1208.64 1877.73,1208.6 1877.73,1208.56 1877.73,1208.53 1877.73,1208.49 1877.73,1208.46 1877.73,1208.42 1877.73,1208.39 1877.73,1208.35 1877.73,1208.32 1877.73,1208.28 1877.73,1208.25 1877.73,1208.21 1877.73,1208.17 1877.73,1208.14 1877.73,1208.1 1877.73,1208.07 1877.73,1208.03 1877.73,1208 1877.73,1207.96 1877.73,1207.93 1877.73,1207.89 1877.73,1207.86 1877.73,1207.82 1877.73,1207.78 1877.73,1207.75 1877.73,1207.71 1877.73,1207.68 1877.73,1207.64 1877.73,1207.61 1877.73,1207.57 1877.73,1207.54 1877.73,1207.5 1877.73,1207.47 1877.73,1207.43 1877.73,1207.4 1877.73,1207.36 1877.73,1207.32 1877.73,1207.29 1877.73,1207.25 1877.73,1207.22 1877.73,1207.18 1877.73,1207.15 1877.73,1207.11 1877.73,1207.08 1877.73,1207.04 1877.73,1207.01 1877.73,1206.97 1877.73,1206.93 1877.73,1206.9 1877.73,1206.86 1877.73,1206.83 1877.73,1206.79 1877.73,1206.76 1877.73,1206.72 1877.73,1206.69 1877.73,1206.65 1877.73,1206.62 1877.73,1206.58 1877.73,1206.54 1877.73,1206.51 1877.73,1206.47 1877.73,1206.44 1877.73,1206.4 1877.73,1206.37 1877.73,1206.33 1877.73,1206.3 1877.73,1206.26 1877.73,1206.23 1877.73,1206.19 1877.73,1206.15 1877.73,1206.12 1877.73,1206.08 1877.73,1206.05 1877.73,1206.01 1877.73,1205.98 1877.73,1205.94 1877.73,1205.91 1877.73,1205.87 1877.73,1205.84 1877.73,1205.8 1877.73,1205.76 1877.73,1205.73 1877.73,1205.69 1877.73,1205.66 1877.73,1205.62 1877.73,1205.59 1877.73,1205.55 1877.73,1205.52 1877.73,1205.48 1877.73,1205.45 1877.73,1205.41 1877.73,1205.37 1877.73,1205.34 1877.73,1205.3 1877.73,1205.27 1877.73,1205.23 1877.73,1205.2 1877.73,1205.16 1877.73,1205.13 1877.73,1205.09 1877.73,1205.06 1877.73,1205.02 1877.73,1204.98 1877.73,1204.95 1877.73,1204.91 1877.73,1204.88 1877.73,1204.84 1877.73,1204.81 1877.73,1204.77 1877.73,1204.74 1877.73,1204.7 1877.73,1204.67 1877.73,1204.63 1877.73,1204.59 1877.73,1204.56 1877.73,1204.52 1877.73,1204.49 1877.73,1204.45 1877.73,1204.42 1877.73,1204.38 1877.73,1204.35 1877.73,1204.31 1877.73,1204.28 1877.73,1204.24 1877.73,1204.2 1877.73,1204.17 1877.73,1204.13 1877.73,1204.1 1877.73,1204.06 1877.73,1204.03 1877.73,1203.99 1877.73,1203.96 1877.73,1203.92 1877.73,1203.89 1877.73,1203.85 1877.73,1203.81 1877.73,1203.78 1877.73,1203.74 1877.73,1203.71 1877.73,1203.67 1877.73,1203.64 1877.73,1203.6 1877.73,1203.57 1877.73,1203.53 1877.73,1203.5 1877.73,1203.46 1877.73,1203.42 1877.73,1203.39 1877.73,1203.35 1877.73,1203.32 1877.73,1203.28 1877.73,1203.25 1877.73,1203.21 1877.73,1203.18 1877.73,1203.14 1877.73,1203.11 1877.73,1203.07 1877.73,1203.03 1877.73,1203 1877.73,1202.96 1877.73,1202.93 1877.73,1202.89 1877.73,1202.86 1877.73,1202.82 1877.73,1202.79 1877.73,1202.75 1877.73,1202.72 1877.73,1202.68 1877.73,1202.64 1877.73,1202.61 1877.73,1202.57 1877.73,1202.54 1877.73,1202.5 1877.73,1202.47 1877.73,1202.43 1877.73,1202.4 1877.73,1202.36 1877.73,1202.33 1877.73,1202.29 1877.73,1202.25 1877.73,1202.22 1877.73,1202.18 1877.73,1202.15 1877.73,1202.11 1877.73,1202.08 1877.73,1202.04 1877.73,1202.01 1877.73,1201.97 1877.73,1201.94 1877.73,1201.9 1877.73,1201.86 1877.73,1201.83 1877.73,1201.79 1877.73,1201.76 1877.73,1201.72 1877.73,1201.69 1877.73,1201.65 1877.73,1201.62 1877.73,1201.58 1877.73,1201.55 1877.73,1201.51 1877.73,1201.47 1877.73,1201.44 1877.73,1201.4 1877.73,1201.37 1877.73,1201.33 1877.73,1201.3 1877.73,1201.26 1877.73,1201.23 1877.73,1201.19 1877.73,1201.16 1877.73,1201.12 1877.73,1201.08 1877.73,1201.05 1877.73,1201.01 1877.73,1200.98 1877.73,1200.94 1877.73,1200.91 1877.73,1200.87 1877.73,1200.84 1877.73,1200.8 1877.73,1200.77 1877.73,1200.73 1877.73,1200.69 1877.73,1200.66 1877.73,1200.62 1877.73,1200.59 1877.73,1200.55 1877.73,1200.52 1877.73,1200.48 1877.73,1200.45 1877.73,1200.41 1877.73,1200.38 1877.73,1200.34 1877.73,1200.3 1877.73,1200.27 1877.73,1200.23 1877.73,1200.2 1877.73,1200.16 1877.73,1200.13 1877.73,1200.09 1877.73,1200.06 1877.73,1200.02 1877.73,1199.99 1877.73,1199.95 1877.73,1199.91 1877.73,1199.88 1877.73,1199.84 1877.73,1199.81 1877.73,1199.77 1877.73,1199.74 1877.73,1199.7 1877.73,1199.67 1877.73,1199.63 1877.73,1199.6 1877.73,1199.56 1877.73,1199.52 1877.73,1199.49 1877.73,1199.45 1877.73,1199.42 1877.73,1199.38 1877.73,1199.35 1877.73,1199.31 1877.73,1199.28 1877.73,1199.24 1877.73,1199.21 1877.73,1199.17 1877.73,1199.13 1877.73,1199.1 1877.73,1199.06 1877.73,1199.03 1877.73,1198.99 1877.73,1198.96 1877.73,1198.92 1877.73,1198.89 1877.73,1198.85 1877.73,1198.82 1877.73,1198.78 1877.73,1198.74 1877.73,1198.71 1877.73,1198.67 1877.73,1198.64 1877.73,1198.6 1877.73,1198.57 1877.73,1198.53 1877.73,1198.5 1877.73,1198.46 1877.73,1198.43 1877.73,1198.39 1877.73,1198.35 1877.73,1198.32 1877.73,1198.28 1877.73,1198.25 1877.73,1198.21 1877.73,1198.18 1877.73,1198.14 1877.73,1198.11 1877.73,1198.07 1877.73,1198.03 1877.73,1198 1877.73,1197.96 1877.73,1197.93 1877.73,1197.89 1877.73,1197.86 1877.73,1197.82 1877.73,1197.79 1877.73,1197.75 1877.73,1197.72 1877.73,1197.68 1877.73,1197.64 1877.73,1197.61 1877.73,1197.57 1877.73,1197.54 1877.73,1197.5 1877.73,1197.47 1877.73,1197.43 1877.73,1197.4 1877.73,1197.36 1877.73,1197.33 1877.73,1197.29 1877.73,1197.25 1877.73,1197.22 1877.73,1197.18 1877.73,1197.15 1877.73,1197.11 1877.73,1197.08 1877.73,1197.04 1877.73,1197.01 1877.73,1196.97 1877.73,1196.94 1877.73,1196.9 1877.73,1196.86 1877.73,1196.83 1877.73,1196.79 1877.73,1196.76 1877.73,1196.72 1877.73,1196.69 1877.73,1196.65 1877.73,1196.62 1877.73,1196.58 1877.73,1196.55 1877.73,1196.51 1877.73,1196.47 1877.73,1196.44 1877.73,1196.4 1877.73,1196.37 1877.73,1196.33 1877.73,1196.3 1877.73,1196.26 1877.73,1196.23 1877.73,1196.19 1877.73,1196.16 1877.73,1196.12 1877.73,1196.08 1877.73,1196.05 1877.73,1196.01 1877.73,1195.98 1877.73,1195.94 1877.73,1195.91 1877.73,1195.87 1877.73,1195.84 1877.73,1195.8 1877.73,1195.77 1877.73,1195.73 1877.73,1195.69 1877.73,1195.66 1877.73,1195.62 1877.73,1195.59 1877.73,1195.55 1877.73,1195.52 1877.73,1195.48 1877.73,1195.45 1877.73,1195.41 1877.73,1195.38 1877.73,1195.34 1877.73,1195.3 1877.73,1195.27 1877.73,1195.23 1877.73,1195.2 1877.73,1195.16 1877.73,1195.13 1877.73,1195.09 1877.73,1195.06 1877.73,1195.02 1877.73,1194.99 1877.73,1194.95 1877.73,1194.91 1877.73,1194.88 1877.73,1194.84 1877.73,1194.81 1877.73,1194.77 1877.73,1194.74 1877.73,1194.7 1877.73,1194.67 1877.73,1194.63 1877.73,1194.6 1877.73,1194.56 1877.73,1194.52 1877.73,1194.49 1877.73,1194.45 1877.73,1194.42 1877.73,1194.38 1877.73,1194.35 1877.73,1194.31 1877.73,1194.28 1877.73,1194.24 1877.73,1194.21 1877.73,1194.17 1877.73,1194.13 1877.73,1194.1 1877.73,1194.06 1877.73,1194.03 1877.73,1193.99 1877.73,1193.96 1877.73,1193.92 1877.73,1193.89 1877.73,1193.85 1877.73,1193.82 1877.73,1193.78 1877.73,1193.74 1877.73,1193.71 1877.73,1193.67 1877.73,1193.64 1877.73,1193.6 1877.73,1193.57 1877.73,1193.53 1877.73,1193.5 1877.73,1193.46 1877.73,1193.43 1877.73,1193.39 1877.73,1193.35 1877.73,1193.32 1877.73,1193.28 1877.73,1193.25 1877.73,1193.21 1877.73,1193.18 1877.73,1193.14 1877.73,1193.11 1877.73,1193.07 1877.73,1193.04 1877.73,1193 1877.73,1192.96 1877.73,1192.93 1877.73,1192.89 1877.73,1192.86 1877.73,1192.82 1877.73,1192.79 1877.73,1192.75 1877.73,1192.72 1877.73,1192.68 1877.73,1192.65 1877.73,1192.61 1877.73,1192.57 1877.73,1192.54 1877.73,1192.5 1877.73,1192.47 1877.73,1192.43 1877.73,1192.4 1877.73,1192.36 1877.73,1192.33 1877.73,1192.29 1877.73,1192.26 1877.73,1192.22 1877.73,1192.18 1877.73,1192.15 1877.73,1192.11 1877.73,1192.08 1877.73,1192.04 1877.73,1192.01 1877.73,1191.97 1877.73,1191.94 1877.73,1191.9 1877.73,1191.87 1877.73,1191.83 1877.73,1191.79 1877.73,1191.76 1877.73,1191.72 1877.73,1191.69 1877.73,1191.65 1877.73,1191.62 1877.73,1191.58 1877.73,1191.55 1877.73,1191.51 1877.73,1191.48 1877.73,1191.44 1877.73,1191.4 1877.73,1191.37 1877.73,1191.33 1877.73,1191.3 1877.73,1191.26 1877.73,1191.23 1877.73,1191.19 1877.73,1191.16 1877.73,1191.12 1877.73,1191.09 1877.73,1191.05 1877.73,1191.01 1877.73,1190.98 1877.73,1190.94 1877.73,1190.91 1877.73,1190.87 1877.73,1190.84 1877.73,1190.8 1877.73,1190.77 1877.73,1190.73 1877.73,1190.7 1877.73,1190.66 1877.73,1190.62 1877.73,1190.59 1877.73,1190.55 1877.73,1190.52 1877.73,1190.48 1877.73,1190.45 1877.73,1190.41 1877.73,1190.38 1877.73,1190.34 1877.73,1190.31 1877.73,1190.27 1877.73,1190.23 1877.73,1190.2 1877.73,1190.16 1877.73,1190.13 1877.73,1190.09 1877.73,1190.06 1877.73,1190.02 1877.73,1189.99 1877.73,1189.95 1877.73,1189.92 1877.73,1189.88 1877.73,1189.84 1877.73,1189.81 1877.73,1189.77 1877.73,1189.74 1877.73,1189.7 1877.73,1189.67 1877.73,1189.63 1877.73,1189.6 1877.73,1189.56 1877.73,1189.53 1877.73,1189.49 1877.73,1189.45 1877.73,1189.42 1877.73,1189.38 1877.73,1189.35 1877.73,1189.31 1877.73,1189.28 1877.73,1189.24 1877.73,1189.21 1877.73,1189.17 1877.73,1189.14 1877.73,1189.1 1877.73,1189.06 1877.73,1189.03 1877.73,1188.99 1877.73,1188.96 1877.73,1188.92 1877.73,1188.89 1877.73,1188.85 1877.73,1188.82 1877.73,1188.78 1877.73,1188.75 1877.73,1188.71 1877.73,1188.67 1877.73,1188.64 1877.73,1188.6 1877.73,1188.57 1877.73,1188.53 1877.73,1188.5 1877.73,1188.46 1877.73,1188.43 1877.73,1188.39 1877.73,1188.36 1877.73,1188.32 1877.73,1188.28 1877.73,1188.25 1877.73,1188.21 1877.73,1188.18 1877.73,1188.14 1877.73,1188.11 1877.73,1188.07 1877.73,1188.04 1877.73,1188 1877.73,1187.97 1877.73,1187.93 1877.73,1187.89 1877.73,1187.86 1877.73,1187.82 1877.73,1187.79 1877.73,1187.75 1877.73,1187.72 1877.73,1187.68 1877.73,1187.65 1877.73,1187.61 1877.73,1187.58 1877.73,1187.54 1877.73,1187.5 1877.73,1187.47 1877.73,1187.43 1877.73,1187.4 1877.73,1187.36 1877.73,1187.33 1877.73,1187.29 1877.73,1187.26 1877.73,1187.22 1877.73,1187.19 1877.73,1187.15 1877.73,1187.11 1877.73,1187.08 1877.73,1187.04 1877.73,1187.01 1877.73,1186.97 1877.73,1186.94 1877.73,1186.9 1877.73,1186.87 1877.73,1186.83 1877.73,1186.8 1877.73,1186.76 1877.73,1186.72 1877.73,1186.69 1877.73,1186.65 1877.73,1186.62 1877.73,1186.58 1877.73,1186.55 1877.73,1186.51 1877.73,1186.48 1877.73,1186.44 1877.73,1186.41 1877.73,1186.37 1877.73,1186.33 1877.73,1186.3 1877.73,1186.26 1877.73,1186.23 1877.73,1186.19 1877.73,1186.16 1877.73,1186.12 1877.73,1186.09 1877.73,1186.05 1877.73,1186.02 1877.73,1185.98 1877.73,1185.94 1877.73,1185.91 1877.73,1185.87 1877.73,1185.84 1877.73,1185.8 1877.73,1185.77 1877.73,1185.73 1877.73,1185.7 1877.73,1185.66 1877.73,1185.63 1877.73,1185.59 1877.73,1185.55 1877.73,1185.52 1877.73,1185.48 1877.73,1185.45 1877.73,1185.41 1877.73,1185.38 1877.73,1185.34 1877.73,1185.31 1877.73,1185.27 1877.73,1185.24 1877.73,1185.2 1877.73,1185.17 1877.73,1185.13 1877.73,1185.09 1877.73,1185.06 1877.73,1185.02 1877.73,1184.99 1877.73,1184.95 1877.73,1184.92 1877.73,1184.88 1877.73,1184.85 1877.73,1184.81 1877.73,1184.78 1877.73,1184.74 1877.73,1184.7 1877.73,1184.67 1877.73,1184.63 1877.73,1184.6 1877.73,1184.56 1877.73,1184.53 1877.73,1184.49 1877.73,1184.46 1877.73,1184.42 1877.73,1184.39 1877.73,1184.35 1877.73,1184.31 1877.73,1184.28 1877.73,1184.24 1877.73,1184.21 1877.73,1184.17 1877.73,1184.14 1877.73,1184.1 1877.73,1184.07 1877.73,1184.03 1877.73,1184 1877.73,1183.96 1877.73,1183.92 1877.73,1183.89 1877.73,1183.85 1877.73,1183.82 1877.73,1183.78 1877.73,1183.75 1877.73,1183.71 1877.73,1183.68 1877.73,1183.64 1877.73,1183.61 1877.73,1183.57 1877.73,1183.53 1877.73,1183.5 1877.73,1183.46 1877.73,1183.43 1877.73,1183.39 1877.73,1183.36 1877.73,1183.32 1877.73,1183.29 1877.73,1183.25 1877.73,1183.22 1877.73,1183.18 1877.73,1183.14 1877.73,1183.11 1877.73,1183.07 1877.73,1183.04 1877.73,1183 1877.73,1182.97 1877.73,1182.93 1877.73,1182.9 1877.73,1182.86 1877.73,1182.83 1877.73,1182.79 1877.73,1182.76 1877.73,1182.72 1877.73,1182.68 1877.73,1182.65 1877.73,1182.61 1877.73,1182.58 1877.73,1182.54 1877.73,1182.51 1877.73,1182.47 1877.73,1182.44 1877.73,1182.4 1877.73,1182.37 1877.73,1182.33 1877.73,1182.29 1877.73,1182.26 1877.73,1182.22 1877.73,1182.19 1877.73,1182.15 1877.73,1182.12 1877.73,1182.08 1877.73,1182.05 1877.73,1182.01 1877.73,1181.98 1877.73,1181.94 1877.73,1181.9 1877.73,1181.87 1877.73,1181.83 1877.73,1181.8 1877.73,1181.76 1877.73,1181.73 1877.73,1181.69 1877.73,1181.66 1877.73,1181.62 1877.73,1181.59 1877.73,1181.55 1877.73,1181.51 1877.73,1181.48 1877.73,1181.44 1877.73,1181.41 1877.73,1181.37 1877.73,1181.34 1877.73,1181.3 1877.73,1181.27 1877.73,1181.23 1877.73,1181.2 1877.73,1181.16 1877.73,1181.13 1877.73,1181.09 1877.73,1181.05 1877.73,1181.02 1877.73,1180.98 1877.73,1180.95 1877.73,1180.91 1877.73,1180.88 1877.73,1180.84 1877.73,1180.81 1877.73,1180.77 1877.73,1180.74 1877.73,1180.7 1877.73,1180.66 1877.73,1180.63 1877.73,1180.59 1877.73,1180.56 1877.73,1180.52 1877.73,1180.49 1877.73,1180.45 1877.73,1180.42 1877.73,1180.38 1877.73,1180.35 1877.73,1180.31 1877.73,1180.27 1877.73,1180.24 1877.73,1180.2 1877.73,1180.17 1877.73,1180.13 1877.73,1180.1 1877.73,1180.06 1877.73,1180.03 1877.73,1179.99 1877.73,1179.96 1877.73,1179.92 1877.73,1179.89 1877.73,1179.85 1877.73,1179.81 1877.73,1179.78 1877.73,1179.74 1877.73,1179.71 1877.73,1179.67 1877.73,1179.64 1877.73,1179.6 1877.73,1179.57 1877.73,1179.53 1877.73,1179.5 1877.73,1179.46 1877.73,1179.42 1877.73,1179.39 1877.73,1179.35 1877.73,1179.32 1877.73,1179.28 1877.73,1179.25 1877.73,1179.21 1877.73,1179.18 1877.73,1179.14 1877.73,1179.11 1877.73,1179.07 1877.73,1179.03 1877.73,1179 1877.73,1178.96 1877.73,1178.93 1877.73,1178.89 1877.73,1178.86 1877.73,1178.82 1877.73,1178.79 1877.73,1178.75 1877.73,1178.72 1877.73,1178.68 1877.73,1178.65 1877.73,1178.61 1877.73,1178.57 1877.73,1178.54 1877.73,1178.5 1877.73,1178.47 1877.73,1178.43 1877.73,1178.4 1877.73,1178.36 1877.73,1178.33 1877.73,1178.29 1877.73,1178.26 1877.73,1178.22 1877.73,1178.18 1877.73,1178.15 1877.73,1178.11 1877.73,1178.08 1877.73,1178.04 1877.73,1178.01 1877.73,1177.97 1877.73,1177.94 1877.73,1177.9 1877.73,1177.87 1877.73,1177.83 1877.73,1177.8 1877.73,1177.76 1877.73,1177.72 1877.73,1177.69 1877.73,1177.65 1877.73,1177.62 1877.73,1177.58 1877.73,1177.55 1877.73,1177.51 1877.73,1177.48 1877.73,1177.44 1877.73,1177.41 1877.73,1177.37 1877.73,1177.33 1877.73,1177.3 1877.73,1177.26 1877.73,1177.23 1877.73,1177.19 1877.73,1177.16 1877.73,1177.12 1877.73,1177.09 1877.73,1177.05 1877.73,1177.02 1877.73,1176.98 1877.73,1176.95 1877.73,1176.91 1877.73,1176.87 1877.73,1176.84 1877.73,1176.8 1877.73,1176.77 1877.73,1176.73 1877.73,1176.7 1877.73,1176.66 1877.73,1176.63 1877.73,1176.59 1877.73,1176.56 1877.73,1176.52 1877.73,1176.48 1877.73,1176.45 1877.73,1176.41 1877.73,1176.38 1877.73,1176.34 1877.73,1176.31 1877.73,1176.27 1877.73,1176.24 1877.73,1176.2 1877.73,1176.17 1877.73,1176.13 1877.73,1176.1 1877.73,1176.06 1877.73,1176.02 1877.73,1175.99 1877.73,1175.95 1877.73,1175.92 1877.73,1175.88 1877.73,1175.85 1877.73,1175.81 1877.73,1175.78 1877.73,1175.74 1877.73,1175.71 1877.73,1175.67 1877.73,1175.63 1877.73,1175.6 1877.73,1175.56 1877.73,1175.53 1877.73,1175.49 1877.73,1175.46 1877.73,1175.42 1877.73,1175.39 1877.73,1175.35 1877.73,1175.32 1877.73,1175.28 1877.73,1175.25 1877.73,1175.21 1877.73,1175.17 1877.73,1175.14 1877.73,1175.1 1877.73,1175.07 1877.73,1175.03 1877.73,1175 1877.73,1174.96 1877.73,1174.93 1877.73,1174.89 1877.73,1174.86 1877.73,1174.82 1877.73,1174.79 1877.73,1174.75 1877.73,1174.71 1877.73,1174.68 1877.73,1174.64 1877.73,1174.61 1877.73,1174.57 1877.73,1174.54 1877.73,1174.5 1877.73,1174.47 1877.73,1174.43 1877.73,1174.4 1877.73,1174.36 1877.73,1174.32 1877.73,1174.29 1877.73,1174.25 1877.73,1174.22 1877.73,1174.18 1877.73,1174.15 1877.73,1174.11 1877.73,1174.08 1877.73,1174.04 1877.73,1174.01 1877.73,1173.97 1877.73,1173.94 1877.73,1173.9 1877.73,1173.86 1877.73,1173.83 1877.73,1173.79 1877.73,1173.76 1877.73,1173.72 1877.73,1173.69 1877.73,1173.65 1877.73,1173.62 1877.73,1173.58 1877.73,1173.55 1877.73,1173.51 1877.73,1173.48 1877.73,1173.44 1877.73,1173.4 1877.73,1173.37 1877.73,1173.33 1877.73,1173.3 1877.73,1173.26 1877.73,1173.23 1877.73,1173.19 1877.73,1173.16 1877.73,1173.12 1877.73,1173.09 1877.73,1173.05 1877.73,1173.02 1877.73,1172.98 1877.73,1172.94 1877.73,1172.91 1877.73,1172.87 1877.73,1172.84 1877.73,1172.8 1877.73,1172.77 1877.73,1172.73 1877.73,1172.7 1877.73,1172.66 1877.73,1172.63 1877.73,1172.59 1877.73,1172.56 1877.73,1172.52 1877.73,1172.48 1877.73,1172.45 1877.73,1172.41 1877.73,1172.38 1877.73,1172.34 1877.73,1172.31 1877.73,1172.27 1877.73,1172.24 1877.73,1172.2 1877.73,1172.17 1877.73,1172.13 1877.73,1172.09 1877.73,1172.06 1877.73,1172.02 1877.73,1171.99 1877.73,1171.95 1877.73,1171.92 1877.73,1171.88 1877.73,1171.85 1877.73,1171.81 1877.73,1171.78 1877.73,1171.74 1877.73,1171.71 1877.73,1171.67 1877.73,1171.63 1877.73,1171.6 1877.73,1171.56 1877.73,1171.53 1877.73,1171.49 1877.73,1171.46 1877.73,1171.42 1877.73,1171.39 1877.73,1171.35 1877.73,1171.32 1877.73,1171.28 1877.73,1171.25 1877.73,1171.21 1877.73,1171.17 1877.73,1171.14 1877.73,1171.1 1877.73,1171.07 1877.73,1171.03 1877.73,1171 1877.73,1170.96 1877.73,1170.93 1877.73,1170.89 1877.73,1170.86 1877.73,1170.82 1877.73,1170.79 1877.73,1170.75 1877.73,1170.71 1877.73,1170.68 1877.73,1170.64 1877.73,1170.61 1877.73,1170.57 1877.73,1170.54 1877.73,1170.5 1877.73,1170.47 1877.73,1170.43 1877.73,1170.4 1877.73,1170.36 1877.73,1170.33 1877.73,1170.29 1877.73,1170.25 1877.73,1170.22 1877.73,1170.18 1877.73,1170.15 1877.73,1170.11 1877.73,1170.08 1877.73,1170.04 1877.73,1170.01 1877.73,1169.97 1877.73,1169.94 1877.73,1169.9 1877.73,1169.87 1877.73,1169.83 1877.73,1169.79 1877.73,1169.76 1877.73,1169.72 1877.73,1169.69 1877.73,1169.65 1877.73,1169.62 1877.73,1169.58 1877.73,1169.55 1877.73,1169.51 1877.73,1169.48 1877.73,1169.44 1877.73,1169.41 1877.73,1169.37 1877.73,1169.33 1877.73,1169.3 1877.73,1169.26 1877.73,1169.23 1877.73,1169.19 1877.73,1169.16 1877.73,1169.12 1877.73,1169.09 1877.73,1169.05 1877.73,1169.02 1877.73,1168.98 1877.73,1168.95 1877.73,1168.91 1877.73,1168.88 1877.73,1168.84 1877.73,1168.8 1877.73,1168.77 1877.73,1168.73 1877.73,1168.7 1877.73,1168.66 1877.73,1168.63 1877.73,1168.59 1877.73,1168.56 1877.73,1168.52 1877.73,1168.49 1877.73,1168.45 1877.73,1168.42 1877.73,1168.38 1877.73,1168.34 1877.73,1168.31 1877.73,1168.27 1877.73,1168.24 1877.73,1168.2 1877.73,1168.17 1877.73,1168.13 1877.73,1168.1 1877.73,1168.06 1877.73,1168.03 1877.73,1167.99 1877.73,1167.96 1877.73,1167.92 1877.73,1167.88 1877.73,1167.85 1877.73,1167.81 1877.73,1167.78 1877.73,1167.74 1877.73,1167.71 1877.73,1167.67 1877.73,1167.64 1877.73,1167.6 1877.73,1167.57 1877.73,1167.53 1877.73,1167.5 1877.73,1167.46 1877.73,1167.42 1877.73,1167.39 1877.73,1167.35 1877.73,1167.32 1877.73,1167.28 1877.73,1167.25 1877.73,1167.21 1877.73,1167.18 1877.73,1167.14 1877.73,1167.11 1877.73,1167.07 1877.73,1167.04 1877.73,1167 1877.73,1166.97 1877.73,1166.93 1877.73,1166.89 1877.73,1166.86 1877.73,1166.82 1877.73,1166.79 1877.73,1166.75 1877.73,1166.72 1877.73,1166.68 1877.73,1166.65 1877.73,1166.61 1877.73,1166.58 1877.73,1166.54 1877.73,1166.51 1877.73,1166.47 1877.73,1166.43 1877.73,1166.4 1877.73,1166.36 1877.73,1166.33 1877.73,1166.29 1877.73,1166.26 1877.73,1166.22 1877.73,1166.19 1877.73,1166.15 1877.73,1166.12 1877.73,1166.08 1877.73,1166.05 1877.73,1166.01 1877.73,1165.98 1877.73,1165.94 1877.73,1165.9 1877.73,1165.87 1877.73,1165.83 1877.73,1165.8 1877.73,1165.76 1877.73,1165.73 1877.73,1165.69 1877.73,1165.66 1877.73,1165.62 1877.73,1165.59 1877.73,1165.55 1877.73,1165.52 1877.73,1165.48 1877.73,1165.44 1877.73,1165.41 1877.73,1165.37 1877.73,1165.34 1877.73,1165.3 1877.73,1165.27 1877.73,1165.23 1877.73,1165.2 1877.73,1165.16 1877.73,1165.13 1877.73,1165.09 1877.73,1165.06 1877.73,1165.02 1877.73,1164.99 1877.73,1164.95 1877.73,1164.91 1877.73,1164.88 1877.73,1164.84 1877.73,1164.81 1877.73,1164.77 1877.73,1164.74 1877.73,1164.7 1877.73,1164.67 1877.73,1164.63 1877.73,1164.6 1877.73,1164.56 1877.73,1164.53 1877.73,1164.49 1877.73,1164.45 1877.73,1164.42 1877.73,1164.38 1877.73,1164.35 1877.73,1164.31 1877.73,1164.28 1877.73,1164.24 1877.73,1164.21 1877.73,1164.17 1877.73,1164.14 1877.73,1164.1 1877.73,1164.07 1877.73,1164.03 1877.73,1164 1877.73,1163.96 1877.73,1163.92 1877.73,1163.89 1877.73,1163.85 1877.73,1163.82 1877.73,1163.78 1877.73,1163.75 1877.73,1163.71 1877.73,1163.68 1877.73,1163.64 1877.73,1163.61 1877.73,1163.57 1877.73,1163.54 1877.73,1163.5 1877.73,1163.47 1877.73,1163.43 1877.73,1163.39 1877.73,1163.36 1877.73,1163.32 1877.73,1163.29 1877.73,1163.25 1877.73,1163.22 1877.73,1163.18 1877.73,1163.15 1877.73,1163.11 1877.73,1163.08 1877.73,1163.04 1877.73,1163.01 1877.73,1162.97 1877.73,1162.94 1877.73,1162.9 1877.73,1162.86 1877.73,1162.83 1877.73,1162.79 1877.73,1162.76 1877.73,1162.72 1877.73,1162.69 1877.73,1162.65 1877.73,1162.62 1877.73,1162.58 1877.73,1162.55 1877.73,1162.51 1877.73,1162.48 1877.73,1162.44 1877.73,1162.41 1877.73,1162.37 1877.73,1162.33 1877.73,1162.3 1877.73,1162.26 1877.73,1162.23 1877.73,1162.19 1877.73,1162.16 1877.73,1162.12 1877.73,1162.09 1877.73,1162.05 1877.73,1162.02 1877.73,1161.98 1877.73,1161.95 1877.73,1161.91 1877.73,1161.88 1877.73,1161.84 1877.73,1161.8 1877.73,1161.77 1877.73,1161.73 1877.73,1161.7 1877.73,1161.66 1877.73,1161.63 1877.73,1161.59 1877.73,1161.56 1877.73,1161.52 1877.73,1161.49 1877.73,1161.45 1877.73,1161.42 1877.73,1161.38 1877.73,1161.35 1877.73,1161.31 1877.73,1161.27 1877.73,1161.24 1877.73,1161.2 1877.73,1161.17 1877.73,1161.13 1877.73,1161.1 1877.73,1161.06 1877.73,1161.03 1877.73,1160.99 1877.73,1160.96 1877.73,1160.92 1877.73,1160.89 1877.73,1160.85 1877.73,1160.82 1877.73,1160.78 1877.73,1160.74 1877.73,1160.71 1877.73,1160.67 1877.73,1160.64 1877.73,1160.6 1877.73,1160.57 1877.73,1160.53 1877.73,1160.5 1877.73,1160.46 1877.73,1160.43 1877.73,1160.39 1877.73,1160.36 1877.73,1160.32 1877.73,1160.29 1877.73,1160.25 1877.73,1160.22 1877.73,1160.18 1877.73,1160.14 1877.73,1160.11 1877.73,1160.07 1877.73,1160.04 1877.73,1160 1877.73,1159.97 1877.73,1159.93 1877.73,1159.9 1877.73,1159.86 1877.73,1159.83 1877.73,1159.79 1877.73,1159.76 1877.73,1159.72 1877.73,1159.69 1877.73,1159.65 1877.73,1159.61 1877.73,1159.58 1877.73,1159.54 1877.73,1159.51 1877.73,1159.47 1877.73,1159.44 1877.73,1159.4 1877.73,1159.37 1877.73,1159.33 1877.73,1159.3 1877.73,1159.26 1877.73,1159.23 1877.73,1159.19 1877.73,1159.16 1877.73,1159.12 1877.73,1159.09 1877.73,1159.05 1877.73,1159.01 1877.73,1158.98 1877.73,1158.94 1877.73,1158.91 1877.73,1158.87 1877.73,1158.84 1877.73,1158.8 1877.73,1158.77 1877.73,1158.73 1877.73,1158.7 1877.73,1158.66 1877.73,1158.63 1877.73,1158.59 1877.73,1158.56 1877.73,1158.52 1877.73,1158.48 1877.73,1158.45 1877.73,1158.41 1877.73,1158.38 1877.73,1158.34 1877.73,1158.31 1877.73,1158.27 1877.73,1158.24 1877.73,1158.2 1877.73,1158.17 1877.73,1158.13 1877.73,1158.1 1877.73,1158.06 1877.73,1158.03 1877.73,1157.99 1877.73,1157.96 1877.73,1157.92 1877.73,1157.88 1877.73,1157.85 1877.73,1157.81 1877.73,1157.78 1877.73,1157.74 1877.73,1157.71 1877.73,1157.67 1877.73,1157.64 1877.73,1157.6 1877.73,1157.57 1877.73,1157.53 1877.73,1157.5 1877.73,1157.46 1877.73,1157.43 1877.73,1157.39 1877.73,1157.36 1877.73,1157.32 1877.73,1157.28 1877.73,1157.25 1877.73,1157.21 1877.73,1157.18 1877.73,1157.14 1877.73,1157.11 1877.73,1157.07 1877.73,1157.04 1877.73,1157 1877.73,1156.97 1877.73,1156.93 1877.73,1156.9 1877.73,1156.86 1877.73,1156.83 1877.73,1156.79 1877.73,1156.76 1877.73,1156.72 1877.73,1156.68 1877.73,1156.65 1877.73,1156.61 1877.73,1156.58 1877.73,1156.54 1877.73,1156.51 1877.73,1156.47 1877.73,1156.44 1877.73,1156.4 1877.73,1156.37 1877.73,1156.33 1877.73,1156.3 1877.73,1156.26 1877.73,1156.23 1877.73,1156.19 1877.73,1156.16 1877.73,1156.12 1877.73,1156.08 1877.73,1156.05 1877.73,1156.01 1877.73,1155.98 1877.73,1155.94 1877.73,1155.91 1877.73,1155.87 1877.73,1155.84 1877.73,1155.8 1877.73,1155.77 1877.73,1155.73 1877.73,1155.7 1877.73,1155.66 1877.73,1155.63 1877.73,1155.59 1877.73,1155.56 1877.73,1155.52 1877.73,1155.48 1877.73,1155.45 1877.73,1155.41 1877.73,1155.38 1877.73,1155.34 1877.73,1155.31 1877.73,1155.27 1877.73,1155.24 1877.73,1155.2 1877.73,1155.17 1877.73,1155.13 1877.73,1155.1 1877.73,1155.06 1877.73,1155.03 1877.73,1154.99 1877.73,1154.96 1877.73,1154.92 1877.73,1154.89 1877.73,1154.85 1877.73,1154.81 1877.73,1154.78 1877.73,1154.74 1877.73,1154.71 1877.73,1154.67 1877.73,1154.64 1877.73,1154.6 1877.73,1154.57 1877.73,1154.53 1877.73,1154.5 1877.73,1154.46 1877.73,1154.43 1877.73,1154.39 1877.73,1154.36 1877.73,1154.32 1877.73,1154.29 1877.73,1154.25 1877.73,1154.22 1877.73,1154.18 1877.73,1154.14 1877.73,1154.11 1877.73,1154.07 1877.73,1154.04 1877.73,1154 1877.73,1153.97 1877.73,1153.93 1877.73,1153.9 1877.73,1153.86 1877.73,1153.83 1877.73,1153.79 1877.73,1153.76 1877.73,1153.72 1877.73,1153.69 1877.73,1153.65 1877.73,1153.62 1877.73,1153.58 1877.73,1153.54 1877.73,1153.51 1877.73,1153.47 1877.73,1153.44 1877.73,1153.4 1877.73,1153.37 1877.73,1153.33 1877.73,1153.3 1877.73,1153.26 1877.73,1153.23 1877.73,1153.19 1877.73,1153.16 1877.73,1153.12 1877.73,1153.09 1877.73,1153.05 1877.73,1153.02 1877.73,1152.98 1877.73,1152.95 1877.73,1152.91 1877.73,1152.88 1877.73,1152.84 1877.73,1152.8 1877.73,1152.77 1877.73,1152.73 1877.73,1152.7 1877.73,1152.66 1877.73,1152.63 1877.73,1152.59 1877.73,1152.56 1877.73,1152.52 1877.73,1152.49 1877.73,1152.45 1877.73,1152.42 1877.73,1152.38 1877.73,1152.35 1877.73,1152.31 1877.73,1152.28 1877.73,1152.24 1877.73,1152.21 1877.73,1152.17 1877.73,1152.13 1877.73,1152.1 1877.73,1152.06 1877.73,1152.03 1877.73,1151.99 1877.73,1151.96 1877.73,1151.92 1877.73,1151.89 1877.73,1151.85 1877.73,1151.82 1877.73,1151.78 1877.73,1151.75 1877.73,1151.71 1877.73,1151.68 1877.73,1151.64 1877.73,1151.61 1877.73,1151.57 1877.73,1151.54 1877.73,1151.5 1877.73,1151.46 1877.73,1151.43 1877.73,1151.39 1877.73,1151.36 1877.73,1151.32 1877.73,1151.29 1877.73,1151.25 1877.73,1151.22 1877.73,1151.18 1877.73,1151.15 1877.73,1151.11 1877.73,1151.08 1877.73,1151.04 1877.73,1151.01 1877.73,1150.97 1877.73,1150.94 1877.73,1150.9 1877.73,1150.87 1877.73,1150.83 1877.73,1150.8 1877.73,1150.76 1877.73,1150.72 1877.73,1150.69 1877.73,1150.65 1877.73,1150.62 1877.73,1150.58 1877.73,1150.55 1877.73,1150.51 1877.73,1150.48 1877.73,1150.44 1877.73,1150.41 1877.73,1150.37 1877.73,1150.34 1877.73,1150.3 1877.73,1150.27 1877.73,1150.23 1877.73,1150.2 1877.73,1150.16 1877.73,1150.13 1877.73,1150.09 1877.73,1150.06 1877.73,1150.02 1877.73,1149.98 1877.73,1149.95 1877.73,1149.91 1877.73,1149.88 1877.73,1149.84 1877.73,1149.81 1877.73,1149.77 1877.73,1149.74 1877.73,1149.7 1877.73,1149.67 1877.73,1149.63 1877.73,1149.6 1877.73,1149.56 1877.73,1149.53 1877.73,1149.49 1877.73,1149.46 1877.73,1149.42 1877.73,1149.39 1877.73,1149.35 1877.73,1149.32 1877.73,1149.28 1877.73,1149.25 1877.73,1149.21 1877.73,1149.17 1877.73,1149.14 1877.73,1149.1 1877.73,1149.07 1877.73,1149.03 1877.73,1149 1877.73,1148.96 1877.73,1148.93 1877.73,1148.89 1877.73,1148.86 1877.73,1148.82 1877.73,1148.79 1877.73,1148.75 1877.73,1148.72 1877.73,1148.68 1877.73,1148.65 1877.73,1148.61 1877.73,1148.58 1877.73,1148.54 1877.73,1148.51 1877.73,1148.47 1877.73,1148.43 1877.73,1148.4 1877.73,1148.36 1877.73,1148.33 1877.73,1148.29 1877.73,1148.26 1877.73,1148.22 1877.73,1148.19 1877.73,1148.15 1877.73,1148.12 1877.73,1148.08 1877.73,1148.05 1877.73,1148.01 1877.73,1147.98 1877.73,1147.94 1877.73,1147.91 1877.73,1147.87 1877.73,1147.84 1877.73,1147.8 1877.73,1147.77 1877.73,1147.73 1877.73,1147.7 1877.73,1147.66 1877.73,1147.62 1877.73,1147.59 1877.73,1147.55 1877.73,1147.52 1877.73,1147.48 1877.73,1147.45 1877.73,1147.41 1877.73,1147.38 1877.73,1147.34 1877.73,1147.31 1877.73,1147.27 1877.73,1147.24 1877.73,1147.2 1877.73,1147.17 1877.73,1147.13 1877.73,1147.1 1877.73,1147.06 1877.73,1147.03 1877.73,1146.99 1877.73,1146.96 1877.73,1146.92 1877.73,1146.89 1877.73,1146.85 1877.73,1146.82 1877.73,1146.78 1877.73,1146.74 1877.73,1146.71 1877.73,1146.67 1877.73,1146.64 1877.73,1146.6 1877.73,1146.57 1877.73,1146.53 1877.73,1146.5 1877.73,1146.46 1877.73,1146.43 1877.73,1146.39 1877.73,1146.36 1877.73,1146.32 1877.73,1146.29 1877.73,1146.25 1877.73,1146.22 1877.73,1146.18 1877.73,1146.15 1877.73,1146.11 1877.73,1146.08 1877.73,1146.04 1877.73,1146.01 1877.73,1145.97 1877.73,1145.94 1877.73,1145.9 1877.73,1145.86 1877.73,1145.83 1877.73,1145.79 1877.73,1145.76 1877.73,1145.72 1877.73,1145.69 1877.73,1145.65 1877.73,1145.62 1877.73,1145.58 1877.73,1145.55 1877.73,1145.51 1877.73,1145.48 1877.73,1145.44 1877.73,1145.41 1877.73,1145.37 1877.73,1145.34 1877.73,1145.3 1877.73,1145.27 1877.73,1145.23 1877.73,1145.2 1877.73,1145.16 1877.73,1145.13 1877.73,1145.09 1877.73,1145.06 1877.73,1145.02 1877.73,1144.99 1877.73,1144.95 1877.73,1144.91 1877.73,1144.88 1877.73,1144.84 1877.73,1144.81 1877.73,1144.77 1877.73,1144.74 1877.73,1144.7 1877.73,1144.67 1877.73,1144.63 1877.73,1144.6 1877.73,1144.56 1877.73,1144.53 1877.73,1144.49 1877.73,1144.46 1877.73,1144.42 1877.73,1144.39 1877.73,1144.35 1877.73,1144.32 1877.73,1144.28 1877.73,1144.25 1877.73,1144.21 1877.73,1144.18 1877.73,1144.14 1877.73,1144.11 1877.73,1144.07 1877.73,1144.04 1877.73,1144 1877.73,1143.96 1877.73,1143.93 1877.73,1143.89 1877.73,1143.86 1877.73,1143.82 1877.73,1143.79 1877.73,1143.75 1877.73,1143.72 1877.73,1143.68 1877.73,1143.65 1877.73,1143.61 1877.73,1143.58 1877.73,1143.54 1877.73,1143.51 1877.73,1143.47 1877.73,1143.44 1877.73,1143.4 1877.73,1143.37 1877.73,1143.33 1877.73,1143.3 1877.73,1143.26 1877.73,1143.23 1877.73,1143.19 1877.73,1143.16 1877.73,1143.12 1877.73,1143.09 1877.73,1143.05 1877.73,1143.02 1877.73,1142.98 1877.73,1142.94 1877.73,1142.91 1877.73,1142.87 1877.73,1142.84 1877.73,1142.8 1877.73,1142.77 1877.73,1142.73 1877.73,1142.7 1877.73,1142.66 1877.73,1142.63 1877.73,1142.59 1877.73,1142.56 1877.73,1142.52 1877.73,1142.49 1877.73,1142.45 1877.73,1142.42 1877.73,1142.38 1877.73,1142.35 1877.73,1142.31 1877.73,1142.28 1877.73,1142.24 1877.73,1142.21 1877.73,1142.17 1877.73,1142.14 1877.73,1142.1 1877.73,1142.07 1877.73,1142.03 1877.73,1142 1877.73,1141.96 1877.73,1141.93 1877.73,1141.89 1877.73,1141.85 1877.73,1141.82 1877.73,1141.78 1877.73,1141.75 1877.73,1141.71 1877.73,1141.68 1877.73,1141.64 1877.73,1141.61 1877.73,1141.57 1877.73,1141.54 1877.73,1141.5 1877.73,1141.47 1877.73,1141.43 1877.73,1141.4 1877.73,1141.36 1877.73,1141.33 1877.73,1141.29 1877.73,1141.26 1877.73,1141.22 1877.73,1141.19 1877.73,1141.15 1877.73,1141.12 1877.73,1141.08 1877.73,1141.05 1877.73,1141.01 1877.73,1140.98 1877.73,1140.94 1877.73,1140.91 1877.73,1140.87 1877.73,1140.84 1877.73,1140.8 1877.73,1140.77 1877.73,1140.73 1877.73,1140.69 1877.73,1140.66 1877.73,1140.62 1877.73,1140.59 1877.73,1140.55 1877.73,1140.52 1877.73,1140.48 1877.73,1140.45 1877.73,1140.41 1877.73,1140.38 1877.73,1140.34 1877.73,1140.31 1877.73,1140.27 1877.73,1140.24 1877.73,1140.2 1877.73,1140.17 1877.73,1140.13 1877.73,1140.1 1877.73,1140.06 1877.73,1140.03 1877.73,1139.99 1877.73,1139.96 1877.73,1139.92 1877.73,1139.89 1877.73,1139.85 1877.73,1139.82 1877.73,1139.78 1877.73,1139.75 1877.73,1139.71 1877.73,1139.68 1877.73,1139.64 1877.73,1139.61 1877.73,1139.57 1877.73,1139.54 1877.73,1139.5 1877.73,1139.47 1877.73,1139.43 1877.73,1139.39 1877.73,1139.36 1877.73,1139.32 1877.73,1139.29 1877.73,1139.25 1877.73,1139.22 1877.73,1139.18 1877.73,1139.15 1877.73,1139.11 1877.73,1139.08 1877.73,1139.04 1877.73,1139.01 1877.73,1138.97 1877.73,1138.94 1877.73,1138.9 1877.73,1138.87 1877.73,1138.83 1877.73,1138.8 1877.73,1138.76 1877.73,1138.73 1877.73,1138.69 1877.73,1138.66 1877.73,1138.62 1877.73,1138.59 1877.73,1138.55 1877.73,1138.52 1877.73,1138.48 1877.73,1138.45 1877.73,1138.41 1877.73,1138.38 1877.73,1138.34 1877.73,1138.31 1877.73,1138.27 1877.73,1138.24 1877.73,1138.2 1877.73,1138.17 1877.73,1138.13 1877.73,1138.1 1877.73,1138.06 1877.73,1138.03 1877.73,1137.99 1877.73,1137.95 1877.73,1137.92 1877.73,1137.88 1877.73,1137.85 1877.73,1137.81 1877.73,1137.78 1877.73,1137.74 1877.73,1137.71 1877.73,1137.67 1877.73,1137.64 1877.73,1137.6 1877.73,1137.57 1877.73,1137.53 1877.73,1137.5 1877.73,1137.46 1877.73,1137.43 1877.73,1137.39 1877.73,1137.36 1877.73,1137.32 1877.73,1137.29 1877.73,1137.25 1877.73,1137.22 1877.73,1137.18 1877.73,1137.15 1877.73,1137.11 1877.73,1137.08 1877.73,1137.04 1877.73,1137.01 1877.73,1136.97 1877.73,1136.94 1877.73,1136.9 1877.73,1136.87 1877.73,1136.83 1877.73,1136.8 1877.73,1136.76 1877.73,1136.73 1877.73,1136.69 1877.73,1136.66 1877.73,1136.62 1877.73,1136.59 1877.73,1136.55 1877.73,1136.52 1877.73,1136.48 1877.73,1136.45 1877.73,1136.41 1877.73,1136.38 1877.73,1136.34 1877.73,1136.31 1877.73,1136.27 1877.73,1136.23 1877.73,1136.2 1877.73,1136.16 1877.73,1136.13 1877.73,1136.09 1877.73,1136.06 1877.73,1136.02 1877.73,1135.99 1877.73,1135.95 1877.73,1135.92 1877.73,1135.88 1877.73,1135.85 1877.73,1135.81 1877.73,1135.78 1877.73,1135.74 1877.73,1135.71 1877.73,1135.67 1877.73,1135.64 1877.73,1135.6 1877.73,1135.57 1877.73,1135.53 1877.73,1135.5 1877.73,1135.46 1877.73,1135.43 1877.73,1135.39 1877.73,1135.36 1877.73,1135.32 1877.73,1135.29 1877.73,1135.25 1877.73,1135.22 1877.73,1135.18 1877.73,1135.15 1877.73,1135.11 1877.73,1135.08 1877.73,1135.04 1877.73,1135.01 1877.73,1134.97 1877.73,1134.94 1877.73,1134.9 1877.73,1134.87 1877.73,1134.83 1877.73,1134.8 1877.73,1134.76 1877.73,1134.73 1877.73,1134.69 1877.73,1134.66 1877.73,1134.62 1877.73,1134.59 1877.73,1134.55 1877.73,1134.52 1877.73,1134.48 1877.73,1134.45 1877.73,1134.41 1877.73,1134.38 1877.73,1134.34 1877.73,1134.31 1877.73,1134.27 1877.73,1134.24 1877.73,1134.2 1877.73,1134.16 1877.73,1134.13 1877.73,1134.09 1877.73,1134.06 1877.73,1134.02 1877.73,1133.99 1877.73,1133.95 1877.73,1133.92 1877.73,1133.88 1877.73,1133.85 1877.73,1133.81 1877.73,1133.78 1877.73,1133.74 1877.73,1133.71 1877.73,1133.67 1877.73,1133.64 1877.73,1133.6 1877.73,1133.57 1877.73,1133.53 1877.73,1133.5 1877.73,1133.46 1877.73,1133.43 1877.73,1133.39 1877.73,1133.36 1877.73,1133.32 1877.73,1133.29 1877.73,1133.25 1877.73,1133.22 1877.73,1133.18 1877.73,1133.15 1877.73,1133.11 1877.73,1133.08 1877.73,1133.04 1877.73,1133.01 1877.73,1132.97 1877.73,1132.94 1877.73,1132.9 1877.73,1132.87 1877.73,1132.83 1877.73,1132.8 1877.73,1132.76 1877.73,1132.73 1877.73,1132.69 1877.73,1132.66 1877.73,1132.62 1877.73,1132.59 1877.73,1132.55 1877.73,1132.52 1877.73,1132.48 1877.73,1132.45 1877.73,1132.41 1877.73,1132.38 1877.73,1132.34 1877.73,1132.31 1877.73,1132.27 1877.73,1132.24 1877.73,1132.2 1877.73,1132.17 1877.73,1132.13 1877.73,1132.1 1877.73,1132.06 1877.73,1132.03 1877.73,1131.99 1877.73,1131.96 1877.73,1131.92 1877.73,1131.89 1877.73,1131.85 1877.73,1131.82 1877.73,1131.78 1877.73,1131.75 1877.73,1131.71 1877.73,1131.68 1877.73,1131.64 1877.73,1131.61 1877.73,1131.57 1877.73,1131.54 1877.73,1131.5 1877.73,1131.47 1877.73,1131.43 1877.73,1131.4 1877.73,1131.36 1877.73,1131.33 1877.73,1131.29 1877.73,1131.26 1877.73,1131.22 1877.73,1131.19 1877.73,1131.15 1877.73,1131.12 1877.73,1131.08 1877.73,1131.05 1877.73,1131.01 1877.73,1130.98 1877.73,1130.94 1877.73,1130.91 1877.73,1130.87 1877.73,1130.84 1877.73,1130.8 1877.73,1130.76 1877.73,1130.73 1877.73,1130.69 1877.73,1130.66 1877.73,1130.62 1877.73,1130.59 1877.73,1130.55 1877.73,1130.52 1877.73,1130.48 1877.73,1130.45 1877.73,1130.41 1877.73,1130.38 1877.73,1130.34 1877.73,1130.31 1877.73,1130.27 1877.73,1130.24 1877.73,1130.2 1877.73,1130.17 1877.73,1130.13 1877.73,1130.1 1877.73,1130.06 1877.73,1130.03 1877.73,1129.99 1877.73,1129.96 1877.73,1129.92 1877.73,1129.89 1877.73,1129.85 1877.73,1129.82 1877.73,1129.78 1877.73,1129.75 1877.73,1129.71 1877.73,1129.68 1877.73,1129.64 1877.73,1129.61 1877.73,1129.57 1877.73,1129.54 1877.73,1129.5 1877.73,1129.47 1877.73,1129.43 1877.73,1129.4 1877.73,1129.36 1877.73,1129.33 1877.73,1129.29 1877.73,1129.26 1877.73,1129.22 1877.73,1129.19 1877.73,1129.15 1877.73,1129.12 1877.73,1129.08 1877.73,1129.05 1877.73,1129.01 1877.73,1128.98 1877.73,1128.94 1877.73,1128.91 1877.73,1128.87 1877.73,1128.84 1877.73,1128.8 1877.73,1128.77 1877.73,1128.73 1877.73,1128.7 1877.73,1128.66 1877.73,1128.63 1877.73,1128.59 1877.73,1128.56 1877.73,1128.52 1877.73,1128.49 1877.73,1128.45 1877.73,1128.42 1877.73,1128.38 1877.73,1128.35 1877.73,1128.31 1877.73,1128.28 1877.73,1128.24 1877.73,1128.21 1877.73,1128.17 1877.73,1128.14 1877.73,1128.1 1877.73,1128.07 1877.73,1128.03 1877.73,1128 1877.73,1127.96 1877.73,1127.93 1877.73,1127.89 1877.73,1127.86 1877.73,1127.82 1877.73,1127.79 1877.73,1127.75 1877.73,1127.72 1877.73,1127.68 1877.73,1127.65 1877.73,1127.61 1877.73,1127.58 1877.73,1127.54 1877.73,1127.51 1877.73,1127.47 1877.73,1127.44 1877.73,1127.4 1877.73,1127.37 1877.73,1127.33 1877.73,1127.3 1877.73,1127.26 1877.73,1127.23 1877.73,1127.19 1877.73,1127.16 1877.73,1127.12 1877.73,1127.09 1877.73,1127.05 1877.73,1127.02 1877.73,1126.98 1877.73,1126.95 1877.73,1126.91 1877.73,1126.88 1877.73,1126.84 1877.73,1126.81 1877.73,1126.77 1877.73,1126.74 1877.73,1126.7 1877.73,1126.67 1877.73,1126.63 1877.73,1126.6 1877.73,1126.56 1877.73,1126.53 1877.73,1126.49 1877.73,1126.46 1877.73,1126.42 1877.73,1126.39 1877.73,1126.35 1877.73,1126.32 1877.73,1126.28 1877.73,1126.25 1877.73,1126.21 1877.73,1126.18 1877.73,1126.14 1877.73,1126.11 1877.73,1126.07 1877.73,1126.04 1877.73,1126 1877.73,1125.97 1877.73,1125.93 1877.73,1125.9 1877.73,1125.86 1877.73,1125.83 1877.73,1125.79 1877.73,1125.76 1877.73,1125.72 1877.73,1125.69 1877.73,1125.65 1877.73,1125.62 1877.73,1125.59 1877.73,1125.55 1877.73,1125.52 1877.73,1125.48 1877.73,1125.45 1877.73,1125.41 1877.73,1125.38 1877.73,1125.34 1877.73,1125.31 1877.73,1125.27 1877.73,1125.24 1877.73,1125.2 1877.73,1125.17 1877.73,1125.13 1877.73,1125.1 1877.73,1125.06 1877.73,1125.03 1877.73,1124.99 1877.73,1124.96 1877.73,1124.92 1877.73,1124.89 1877.73,1124.85 1877.73,1124.82 1877.73,1124.78 1877.73,1124.75 1877.73,1124.71 1877.73,1124.68 1877.73,1124.64 1877.73,1124.61 1877.73,1124.57 1877.73,1124.54 1877.73,1124.5 1877.73,1124.47 1877.73,1124.43 1877.73,1124.4 1877.73,1124.36 1877.73,1124.33 1877.73,1124.29 1877.73,1124.26 1877.73,1124.22 1877.73,1124.19 1877.73,1124.15 1877.73,1124.12 1877.73,1124.08 1877.73,1124.05 1877.73,1124.01 1877.73,1123.98 1877.73,1123.94 1877.73,1123.91 1877.73,1123.87 1877.73,1123.84 1877.73,1123.8 1877.73,1123.77 1877.73,1123.73 1877.73,1123.7 1877.73,1123.66 1877.73,1123.63 1877.73,1123.59 1877.73,1123.56 1877.73,1123.52 1877.73,1123.49 1877.73,1123.45 1877.73,1123.42 1877.73,1123.38 1877.73,1123.35 1877.73,1123.31 1877.73,1123.28 1877.73,1123.24 1877.73,1123.21 1877.73,1123.17 1877.73,1123.14 1877.73,1123.1 1877.73,1123.07 1877.73,1123.03 1877.73,1123 1877.73,1122.96 1877.73,1122.93 1877.73,1122.89 1877.73,1122.86 1877.73,1122.82 1877.73,1122.79 1877.73,1122.75 1877.73,1122.72 1877.73,1122.68 1877.73,1122.65 1877.73,1122.61 1877.73,1122.58 1877.73,1122.54 1877.73,1122.51 1877.73,1122.47 1877.73,1122.44 1877.73,1122.4 1877.73,1122.37 1877.73,1122.33 1877.73,1122.3 1877.73,1122.27 1877.73,1122.23 1877.73,1122.2 1877.73,1122.16 1877.73,1122.13 1877.73,1122.09 1877.73,1122.06 1877.73,1122.02 1877.73,1121.99 1877.73,1121.95 1877.73,1121.92 1877.73,1121.88 1877.73,1121.85 1877.73,1121.81 1877.73,1121.78 1877.73,1121.74 1877.73,1121.71 1877.73,1121.67 1877.73,1121.64 1877.73,1121.6 1877.73,1121.57 1877.73,1121.53 1877.73,1121.5 1877.73,1121.46 1877.73,1121.43 1877.73,1121.39 1877.73,1121.36 1877.73,1121.32 1877.73,1121.29 1877.73,1121.25 1877.73,1121.22 1877.73,1121.18 1877.73,1121.15 1877.73,1121.11 1877.73,1121.08 1877.73,1121.04 1877.73,1121.01 1877.73,1120.97 1877.73,1120.94 1877.73,1120.9 1877.73,1120.87 1877.73,1120.83 1877.73,1120.8 1877.73,1120.76 1877.73,1120.73 1877.73,1120.69 1877.73,1120.66 1877.73,1120.62 1877.73,1120.59 1877.73,1120.55 1877.73,1120.52 1877.73,1120.48 1877.73,1120.45 1877.73,1120.41 1877.73,1120.38 1877.73,1120.34 1877.73,1120.31 1877.73,1120.28 1877.73,1120.24 1877.73,1120.21 1877.73,1120.17 1877.73,1120.14 1877.73,1120.1 1877.73,1120.07 1877.73,1120.03 1877.73,1120 1877.73,1119.96 1877.73,1119.93 1877.73,1119.89 1877.73,1119.86 1877.73,1119.82 1877.73,1119.79 1877.73,1119.75 1877.73,1119.72 1877.73,1119.68 1877.73,1119.65 1877.73,1119.61 1877.73,1119.58 1877.73,1119.54 1877.73,1119.51 1877.73,1119.47 1877.73,1119.44 1877.73,1119.4 1877.73,1119.37 1877.73,1119.33 1877.73,1119.3 1877.73,1119.26 1877.73,1119.23 1877.73,1119.19 1877.73,1119.16 1877.73,1119.12 1877.73,1119.09 1877.73,1119.05 1877.73,1119.02 1877.73,1118.98 1877.73,1118.95 1877.73,1118.91 1877.73,1118.88 1877.73,1118.84 1877.73,1118.81 1877.73,1118.77 1877.73,1118.74 1877.73,1118.71 1877.73,1118.67 1877.73,1118.64 1877.73,1118.6 1877.73,1118.57 1877.73,1118.53 1877.73,1118.5 1877.73,1118.46 1877.73,1118.43 1877.73,1118.39 1877.73,1118.36 1877.73,1118.32 1877.73,1118.29 1877.73,1118.25 1877.73,1118.22 1877.73,1118.18 1877.73,1118.15 1877.73,1118.11 1877.73,1118.08 1877.73,1118.04 1877.73,1118.01 1877.73,1117.97 1877.73,1117.94 1877.73,1117.9 1877.73,1117.87 1877.73,1117.83 1877.73,1117.8 1877.73,1117.76 1877.73,1117.73 1877.73,1117.69 1877.73,1117.66 1877.73,1117.62 1877.73,1117.59 1877.73,1117.55 1877.73,1117.52 1877.73,1117.48 1877.73,1117.45 1877.73,1117.41 1877.73,1117.38 1877.73,1117.35 1877.73,1117.31 1877.73,1117.28 1877.73,1117.24 1877.73,1117.21 1877.73,1117.17 1877.73,1117.14 1877.73,1117.1 1877.73,1117.07 1877.73,1117.03 1877.73,1117 1877.73,1116.96 1877.73,1116.93 1877.73,1116.89 1877.73,1116.86 1877.73,1116.82 1877.73,1116.79 1877.73,1116.75 1877.73,1116.72 1877.73,1116.68 1877.73,1116.65 1877.73,1116.61 1877.73,1116.58 1877.73,1116.54 1877.73,1116.51 1877.73,1116.47 1877.73,1116.44 1877.73,1116.4 1877.73,1116.37 1877.73,1116.33 1877.73,1116.3 1877.73,1116.26 1877.73,1116.23 1877.73,1116.2 1877.73,1116.16 1877.73,1116.13 1877.73,1116.09 1877.73,1116.06 1877.73,1116.02 1877.73,1115.99 1877.73,1115.95 1877.73,1115.92 1877.73,1115.88 1877.73,1115.85 1877.73,1115.81 1877.73,1115.78 1877.73,1115.74 1877.73,1115.71 1877.73,1115.67 1877.73,1115.64 1877.73,1115.6 1877.73,1115.57 1877.73,1115.53 1877.73,1115.5 1877.73,1115.46 1877.73,1115.43 1877.73,1115.39 1877.73,1115.36 1877.73,1115.32 1877.73,1115.29 1877.73,1115.25 1877.73,1115.22 1877.73,1115.18 1877.73,1115.15 1877.73,1115.12 1877.73,1115.08 1877.73,1115.05 1877.73,1115.01 1877.73,1114.98 1877.73,1114.94 1877.73,1114.91 1877.73,1114.87 1877.73,1114.84 1877.73,1114.8 1877.73,1114.77 1877.73,1114.73 1877.73,1114.7 1877.73,1114.66 1877.73,1114.63 1877.73,1114.59 1877.73,1114.56 1877.73,1114.52 1877.73,1114.49 1877.73,1114.45 1877.73,1114.42 1877.73,1114.38 1877.73,1114.35 1877.73,1114.31 1877.73,1114.28 1877.73,1114.24 1877.73,1114.21 1877.73,1114.18 1877.73,1114.14 1877.73,1114.11 1877.73,1114.07 1877.73,1114.04 1877.73,1114 1877.73,1113.97 1877.73,1113.93 1877.73,1113.9 1877.73,1113.86 1877.73,1113.83 1877.73,1113.79 1877.73,1113.76 1877.73,1113.72 1877.73,1113.69 1877.73,1113.65 1877.73,1113.62 1877.73,1113.58 1877.73,1113.55 1877.73,1113.51 1877.73,1113.48 1877.73,1113.44 1877.73,1113.41 1877.73,1113.37 1877.73,1113.34 1877.73,1113.3 1877.73,1113.27 1877.73,1113.24 1877.73,1113.2 1877.73,1113.17 1877.73,1113.13 1877.73,1113.1 1877.73,1113.06 1877.73,1113.03 1877.73,1112.99 1877.73,1112.96 1877.73,1112.92 1877.73,1112.89 1877.73,1112.85 1877.73,1112.82 1877.73,1112.78 1877.73,1112.75 1877.73,1112.71 1877.73,1112.68 1877.73,1112.64 1877.73,1112.61 1877.73,1112.57 1877.73,1112.54 1877.73,1112.5 1877.73,1112.47 1877.73,1112.43 1877.73,1112.4 1877.73,1112.37 1877.73,1112.33 1877.73,1112.3 1877.73,1112.26 1877.73,1112.23 1877.73,1112.19 1877.73,1112.16 1877.73,1112.12 1877.73,1112.09 1877.73,1112.05 1877.73,1112.02 1877.73,1111.98 1877.73,1111.95 1877.73,1111.91 1877.73,1111.88 1877.73,1111.84 1877.73,1111.81 1877.73,1111.77 1877.73,1111.74 1877.73,1111.7 1877.73,1111.67 1877.73,1111.63 1877.73,1111.6 1877.73,1111.57 1877.73,1111.53 1877.73,1111.5 1877.73,1111.46 1877.73,1111.43 1877.73,1111.39 1877.73,1111.36 1877.73,1111.32 1877.73,1111.29 1877.73,1111.25 1877.73,1111.22 1877.73,1111.18 1877.73,1111.15 1877.73,1111.11 1877.73,1111.08 1877.73,1111.04 1877.73,1111.01 1877.73,1110.97 1877.73,1110.94 1877.73,1110.9 1877.73,1110.87 1877.73,1110.84 1877.73,1110.8 1877.73,1110.77 1877.73,1110.73 1877.73,1110.7 1877.73,1110.66 1877.73,1110.63 1877.73,1110.59 1877.73,1110.56 1877.73,1110.52 1877.73,1110.49 1877.73,1110.45 1877.73,1110.42 1877.73,1110.38 1877.73,1110.35 1877.73,1110.31 1877.73,1110.28 1877.73,1110.24 1877.73,1110.21 1877.73,1110.17 1877.73,1110.14 1877.73,1110.11 1877.73,1110.07 1877.73,1110.04 1877.73,1110 1877.73,1109.97 1877.73,1109.93 1877.73,1109.9 1877.73,1109.86 1877.73,1109.83 1877.73,1109.79 1877.73,1109.76 1877.73,1109.72 1877.73,1109.69 1877.73,1109.65 1877.73,1109.62 1877.73,1109.58 1877.73,1109.55 1877.73,1109.51 1877.73,1109.48 1877.73,1109.44 1877.73,1109.41 1877.73,1109.38 1877.73,1109.34 1877.73,1109.31 1877.73,1109.27 1877.73,1109.24 1877.73,1109.2 1877.73,1109.17 1877.73,1109.13 1877.73,1109.1 1877.73,1109.06 1877.73,1109.03 1877.73,1108.99 1877.73,1108.96 1877.73,1108.92 1877.73,1108.89 1877.73,1108.85 1877.73,1108.82 1877.73,1108.78 1877.73,1108.75 1877.73,1108.72 1877.73,1108.68 1877.73,1108.65 1877.73,1108.61 1877.73,1108.58 1877.73,1108.54 1877.73,1108.51 1877.73,1108.47 1877.73,1108.44 1877.73,1108.4 1877.73,1108.37 1877.73,1108.33 1877.73,1108.3 1877.73,1108.26 1877.73,1108.23 1877.73,1108.19 1877.73,1108.16 1877.73,1108.12 1877.73,1108.09 1877.73,1108.06 1877.73,1108.02 1877.73,1107.99 1877.73,1107.95 1877.73,1107.92 1877.73,1107.88 1877.73,1107.85 1877.73,1107.81 1877.73,1107.78 1877.73,1107.74 1877.73,1107.71 1877.73,1107.67 1877.73,1107.64 1877.73,1107.6 1877.73,1107.57 1877.73,1107.53 1877.73,1107.5 1877.73,1107.47 1877.73,1107.43 1877.73,1107.4 1877.73,1107.36 1877.73,1107.33 1877.73,1107.29 1877.73,1107.26 1877.73,1107.22 1877.73,1107.19 1877.73,1107.15 1877.73,1107.12 1877.73,1107.08 1877.73,1107.05 1877.73,1107.01 1877.73,1106.98 1877.73,1106.94 1877.73,1106.91 1877.73,1106.87 1877.73,1106.84 1877.73,1106.81 1877.73,1106.77 1877.73,1106.74 1877.73,1106.7 1877.73,1106.67 1877.73,1106.63 1877.73,1106.6 1877.73,1106.56 1877.73,1106.53 1877.73,1106.49 1877.73,1106.46 1877.73,1106.42 1877.73,1106.39 1877.73,1106.35 1877.73,1106.32 1877.73,1106.28 1877.73,1106.25 1877.73,1106.22 1877.73,1106.18 1877.73,1106.15 1877.73,1106.11 1877.73,1106.08 1877.73,1106.04 1877.73,1106.01 1877.73,1105.97 1877.73,1105.94 1877.73,1105.9 1877.73,1105.87 1877.73,1105.83 1877.73,1105.8 1877.73,1105.76 1877.73,1105.73 1877.73,1105.7 1877.73,1105.66 1877.73,1105.63 1877.73,1105.59 1877.73,1105.56 1877.73,1105.52 1877.73,1105.49 1877.73,1105.45 1877.73,1105.42 1877.73,1105.38 1877.73,1105.35 1877.73,1105.31 1877.73,1105.28 1877.73,1105.24 1877.73,1105.21 1877.73,1105.17 1877.73,1105.14 1877.73,1105.11 1877.73,1105.07 1877.73,1105.04 1877.73,1105 1877.73,1104.97 1877.73,1104.93 1877.73,1104.9 1877.73,1104.86 1877.73,1104.83 1877.73,1104.79 1877.73,1104.76 1877.73,1104.72 1877.73,1104.69 1877.73,1104.65 1877.73,1104.62 1877.73,1104.59 1877.73,1104.55 1877.73,1104.52 1877.73,1104.48 1877.73,1104.45 1877.73,1104.41 1877.73,1104.38 1877.73,1104.34 1877.73,1104.31 1877.73,1104.27 1877.73,1104.24 1877.73,1104.2 1877.73,1104.17 1877.73,1104.13 1877.73,1104.1 1877.73,1104.07 1877.73,1104.03 1877.73,1104 1877.73,1103.96 1877.73,1103.93 1877.73,1103.89 1877.73,1103.86 1877.73,1103.82 1877.73,1103.79 1877.73,1103.75 1877.73,1103.72 1877.73,1103.68 1877.73,1103.65 1877.73,1103.61 1877.73,1103.58 1877.73,1103.55 1877.73,1103.51 1877.73,1103.48 1877.73,1103.44 1877.73,1103.41 1877.73,1103.37 1877.73,1103.34 1877.73,1103.3 1877.73,1103.27 1877.73,1103.23 1877.73,1103.2 1877.73,1103.16 1877.73,1103.13 1877.73,1103.09 1877.73,1103.06 1877.73,1103.03 1877.73,1102.99 1877.73,1102.96 1877.73,1102.92 1877.73,1102.89 1877.73,1102.85 1877.73,1102.82 1877.73,1102.78 1877.73,1102.75 1877.73,1102.71 1877.73,1102.68 1877.73,1102.64 1877.73,1102.61 1877.73,1102.58 1877.73,1102.54 1877.73,1102.51 1877.73,1102.47 1877.73,1102.44 1877.73,1102.4 1877.73,1102.37 1877.73,1102.33 1877.73,1102.3 1877.73,1102.26 1877.73,1102.23 1877.73,1102.19 1877.73,1102.16 1877.73,1102.12 1877.73,1102.09 1877.73,1102.06 1877.73,1102.02 1877.73,1101.99 1877.73,1101.95 1877.73,1101.92 1877.73,1101.88 1877.73,1101.85 1877.73,1101.81 1877.73,1101.78 1877.73,1101.74 1877.73,1101.71 1877.73,1101.67 1877.73,1101.64 1877.73,1101.61 1877.73,1101.57 1877.73,1101.54 1877.73,1101.5 1877.73,1101.47 1877.73,1101.43 1877.73,1101.4 1877.73,1101.36 1877.73,1101.33 1877.73,1101.29 1877.73,1101.26 1877.73,1101.22 1877.73,1101.19 1877.73,1101.16 1877.73,1101.12 1877.73,1101.09 1877.73,1101.05 1877.73,1101.02 1877.73,1100.98 1877.73,1100.95 1877.73,1100.91 1877.73,1100.88 1877.73,1100.84 1877.73,1100.81 1877.73,1100.77 1877.73,1100.74 1877.73,1100.71 1877.73,1100.67 1877.73,1100.64 1877.73,1100.6 1877.73,1100.57 1877.73,1100.53 1877.73,1100.5 1877.73,1100.46 1877.73,1100.43 1877.73,1100.39 1877.73,1100.36 1877.73,1100.32 1877.73,1100.29 1877.73,1100.26 1877.73,1100.22 1877.73,1100.19 1877.73,1100.15 1877.73,1100.12 1877.73,1100.08 1877.73,1100.05 1877.73,1100.01 1877.73,1099.98 1877.73,1099.94 1877.73,1099.91 1877.73,1099.87 1877.73,1099.84 1877.73,1099.81 1877.73,1099.77 1877.73,1099.74 1877.73,1099.7 1877.73,1099.67 1877.73,1099.63 1877.73,1099.6 1877.73,1099.56 1877.73,1099.53 1877.73,1099.49 1877.73,1099.46 1877.73,1099.42 1877.73,1099.39 1877.73,1099.36 1877.73,1099.32 1877.73,1099.29 1877.73,1099.25 1877.73,1099.22 1877.73,1099.18 1877.73,1099.15 1877.73,1099.11 1877.73,1099.08 1877.73,1099.04 1877.73,1099.01 1877.73,1098.98 1877.73,1098.94 1877.73,1098.91 1877.73,1098.87 1877.73,1098.84 1877.73,1098.8 1877.73,1098.77 1877.73,1098.73 1877.73,1098.7 1877.73,1098.66 1877.73,1098.63 1877.73,1098.59 1877.73,1098.56 1877.73,1098.53 1877.73,1098.49 1877.73,1098.46 1877.73,1098.42 1877.73,1098.39 1877.73,1098.35 1877.73,1098.32 1877.73,1098.28 1877.73,1098.25 1877.73,1098.21 1877.73,1098.18 1877.73,1098.15 1877.73,1098.11 1877.73,1098.08 1877.73,1098.04 1877.73,1098.01 1877.73,1097.97 1877.73,1097.94 1877.73,1097.9 1877.73,1097.87 1877.73,1097.83 1877.73,1097.8 1877.73,1097.76 1877.73,1097.73 1877.73,1097.7 1877.73,1097.66 1877.73,1097.63 1877.73,1097.59 1877.73,1097.56 1877.73,1097.52 1877.73,1097.49 1877.73,1097.45 1877.73,1097.42 1877.73,1097.38 1877.73,1097.35 1877.73,1097.32 1877.73,1097.28 1877.73,1097.25 1877.73,1097.21 1877.73,1097.18 1877.73,1097.14 1877.73,1097.11 1877.73,1097.07 1877.73,1097.04 1877.73,1097 1877.73,1096.97 1877.73,1096.94 1877.73,1096.9 1877.73,1096.87 1877.73,1096.83 1877.73,1096.8 1877.73,1096.76 1877.73,1096.73 1877.73,1096.69 1877.73,1096.66 1877.73,1096.62 1877.73,1096.59 1877.73,1096.56 1877.73,1096.52 1877.73,1096.49 1877.73,1096.45 1877.73,1096.42 1877.73,1096.38 1877.73,1096.35 1877.73,1096.31 1877.73,1096.28 1877.73,1096.24 1877.73,1096.21 1877.73,1096.18 1877.73,1096.14 1877.73,1096.11 1877.73,1096.07 1877.73,1096.04 1877.73,1096 1877.73,1095.97 1877.73,1095.93 1877.73,1095.9 1877.73,1095.86 1877.73,1095.83 1877.73,1095.8 1877.73,1095.76 1877.73,1095.73 1877.73,1095.69 1877.73,1095.66 1877.73,1095.62 1877.73,1095.59 1877.73,1095.55 1877.73,1095.52 1877.73,1095.48 1877.73,1095.45 1877.73,1095.42 1877.73,1095.38 1877.73,1095.35 1877.73,1095.31 1877.73,1095.28 1877.73,1095.24 1877.73,1095.21 1877.73,1095.17 1877.73,1095.14 1877.73,1095.1 1877.73,1095.07 1877.73,1095.04 1877.73,1095 1877.73,1094.97 1877.73,1094.93 1877.73,1094.9 1877.73,1094.86 1877.73,1094.83 1877.73,1094.79 1877.73,1094.76 1877.73,1094.73 1877.73,1094.69 1877.73,1094.66 1877.73,1094.62 1877.73,1094.59 1877.73,1094.55 1877.73,1094.52 1877.73,1094.48 1877.73,1094.45 1877.73,1094.41 1877.73,1094.38 1877.73,1094.35 1877.73,1094.31 1877.73,1094.28 1877.73,1094.24 1877.73,1094.21 1877.73,1094.17 1877.73,1094.14 1877.73,1094.1 1877.73,1094.07 1877.73,1094.03 1877.73,1094 1877.73,1093.97 1877.73,1093.93 1877.73,1093.9 1877.73,1093.86 1877.73,1093.83 1877.73,1093.79 1877.73,1093.76 1877.73,1093.72 1877.73,1093.69 1877.73,1093.66 1877.73,1093.62 1877.73,1093.59 1877.73,1093.55 1877.73,1093.52 1877.73,1093.48 1877.73,1093.45 1877.73,1093.41 1877.73,1093.38 1877.73,1093.34 1877.73,1093.31 1877.73,1093.28 1877.73,1093.24 1877.73,1093.21 1877.73,1093.17 1877.73,1093.14 1877.73,1093.1 1877.73,1093.07 1877.73,1093.03 1877.73,1093 1877.73,1092.97 1877.73,1092.93 1877.73,1092.9 1877.73,1092.86 1877.73,1092.83 1877.73,1092.79 1877.73,1092.76 1877.73,1092.72 1877.73,1092.69 1877.73,1092.66 1877.73,1092.62 1877.73,1092.59 1877.73,1092.55 1877.73,1092.52 1877.73,1092.48 1877.73,1092.45 1877.73,1092.41 1877.73,1092.38 1877.73,1092.34 1877.73,1092.31 1877.73,1092.28 1877.73,1092.24 1877.73,1092.21 1877.73,1092.17 1877.73,1092.14 1877.73,1092.1 1877.73,1092.07 1877.73,1092.03 1877.73,1092 1877.73,1091.97 1877.73,1091.93 1877.73,1091.9 1877.73,1091.86 1877.73,1091.83 1877.73,1091.79 1877.73,1091.76 1877.73,1091.72 1877.73,1091.69 1877.73,1091.66 1877.73,1091.62 1877.73,1091.59 1877.73,1091.55 1877.73,1091.52 1877.73,1091.48 1877.73,1091.45 1877.73,1091.41 1877.73,1091.38 1877.73,1091.35 1877.73,1091.31 1877.73,1091.28 1877.73,1091.24 1877.73,1091.21 1877.73,1091.17 1877.73,1091.14 1877.73,1091.1 1877.73,1091.07 1877.73,1091.04 1877.73,1091 1877.73,1090.97 1877.73,1090.93 1877.73,1090.9 1877.73,1090.86 1877.73,1090.83 1877.73,1090.79 1877.73,1090.76 1877.73,1090.72 1877.73,1090.69 1877.73,1090.66 1877.73,1090.62 1877.73,1090.59 1877.73,1090.55 1877.73,1090.52 1877.73,1090.48 1877.73,1090.45 1877.73,1090.41 1877.73,1090.38 1877.73,1090.35 1877.73,1090.31 1877.73,1090.28 1877.73,1090.24 1877.73,1090.21 1877.73,1090.17 1877.73,1090.14 1877.73,1090.1 1877.73,1090.07 1877.73,1090.04 1877.73,1090 1877.73,1089.97 1877.73,1089.93 1877.73,1089.9 1877.73,1089.86 1877.73,1089.83 1877.73,1089.79 1877.73,1089.76 1877.73,1089.73 1877.73,1089.69 1877.73,1089.66 1877.73,1089.62 1877.73,1089.59 1877.73,1089.55 1877.73,1089.52 1877.73,1089.49 1877.73,1089.45 1877.73,1089.42 1877.73,1089.38 1877.73,1089.35 1877.73,1089.31 1877.73,1089.28 1877.73,1089.24 1877.73,1089.21 1877.73,1089.18 1877.73,1089.14 1877.73,1089.11 1877.73,1089.07 1877.73,1089.04 1877.73,1089 1877.73,1088.97 1877.73,1088.93 1877.73,1088.9 1877.73,1088.87 1877.73,1088.83 1877.73,1088.8 1877.73,1088.76 1877.73,1088.73 1877.73,1088.69 1877.73,1088.66 1877.73,1088.62 1877.73,1088.59 1877.73,1088.56 1877.73,1088.52 1877.73,1088.49 1877.73,1088.45 1877.73,1088.42 1877.73,1088.38 1877.73,1088.35 1877.73,1088.31 1877.73,1088.28 1877.73,1088.25 1877.73,1088.21 1877.73,1088.18 1877.73,1088.14 1877.73,1088.11 1877.73,1088.07 1877.73,1088.04 1877.73,1088.01 1877.73,1087.97 1877.73,1087.94 1877.73,1087.9 1877.73,1087.87 1877.73,1087.83 1877.73,1087.8 1877.73,1087.76 1877.73,1087.73 1877.73,1087.7 1877.73,1087.66 1877.73,1087.63 1877.73,1087.59 1877.73,1087.56 1877.73,1087.52 1877.73,1087.49 1877.73,1087.45 1877.73,1087.42 1877.73,1087.39 1877.73,1087.35 1877.73,1087.32 1877.73,1087.28 1877.73,1087.25 1877.73,1087.21 1877.73,1087.18 1877.73,1087.15 1877.73,1087.11 1877.73,1087.08 1877.73,1087.04 1877.73,1087.01 1877.73,1086.97 1877.73,1086.94 1877.73,1086.9 1877.73,1086.87 1877.73,1086.84 1877.73,1086.8 1877.73,1086.77 1877.73,1086.73 1877.73,1086.7 1877.73,1086.66 1877.73,1086.63 1877.73,1086.6 1877.73,1086.56 1877.73,1086.53 1877.73,1086.49 1877.73,1086.46 1877.73,1086.42 1877.73,1086.39 1877.73,1086.35 1877.73,1086.32 1877.73,1086.29 1877.73,1086.25 1877.73,1086.22 1877.73,1086.18 1877.73,1086.15 1877.73,1086.11 1877.73,1086.08 1877.73,1086.05 1877.73,1086.01 1877.73,1085.98 1877.73,1085.94 1877.73,1085.91 1877.73,1085.87 1877.73,1085.84 1877.73,1085.8 1877.73,1085.77 1877.73,1085.74 1877.73,1085.7 1877.73,1085.67 1877.73,1085.63 1877.73,1085.6 1877.73,1085.56 1877.73,1085.53 1877.73,1085.5 1877.73,1085.46 1877.73,1085.43 1877.73,1085.39 1877.73,1085.36 1877.73,1085.32 1877.73,1085.29 1877.73,1085.25 1877.73,1085.22 1877.73,1085.19 1877.73,1085.15 1877.73,1085.12 1877.73,1085.08 1877.73,1085.05 1877.73,1085.01 1877.73,1084.98 1877.73,1084.95 1877.73,1084.91 1877.73,1084.88 1877.73,1084.84 1877.73,1084.81 1877.73,1084.77 1877.73,1084.74 1877.73,1084.7 1877.73,1084.67 1877.73,1084.64 1877.73,1084.6 1877.73,1084.57 1877.73,1084.53 1877.73,1084.5 1877.73,1084.46 1877.73,1084.43 1877.73,1084.4 1877.73,1084.36 1877.73,1084.33 1877.73,1084.29 1877.73,1084.26 1877.73,1084.22 1877.73,1084.19 1877.73,1084.16 1877.73,1084.12 1877.73,1084.09 1877.73,1084.05 1877.73,1084.02 1877.73,1083.98 1877.73,1083.95 1877.73,1083.92 1877.73,1083.88 1877.73,1083.85 1877.73,1083.81 1877.73,1083.78 1877.73,1083.74 1877.73,1083.71 1877.73,1083.67 1877.73,1083.64 1877.73,1083.61 1877.73,1083.57 1877.73,1083.54 1877.73,1083.5 1877.73,1083.47 1877.73,1083.43 1877.73,1083.4 1877.73,1083.37 1877.73,1083.33 1877.73,1083.3 1877.73,1083.26 1877.73,1083.23 1877.73,1083.19 1877.73,1083.16 1877.73,1083.13 1877.73,1083.09 1877.73,1083.06 1877.73,1083.02 1877.73,1082.99 1877.73,1082.95 1877.73,1082.92 1877.73,1082.89 1877.73,1082.85 1877.73,1082.82 1877.73,1082.78 1877.73,1082.75 1877.73,1082.71 1877.73,1082.68 1877.73,1082.65 1877.73,1082.61 1877.73,1082.58 1877.73,1082.54 1877.73,1082.51 1877.73,1082.47 1877.73,1082.44 1877.73,1082.41 1877.73,1082.37 1877.73,1082.34 1877.73,1082.3 1877.73,1082.27 1877.73,1082.23 1877.73,1082.2 1877.73,1082.16 1877.73,1082.13 1877.73,1082.1 1877.73,1082.06 1877.73,1082.03 1877.73,1081.99 1877.73,1081.96 1877.73,1081.92 1877.73,1081.89 1877.73,1081.86 1877.73,1081.82 1877.73,1081.79 1877.73,1081.75 1877.73,1081.72 1877.73,1081.68 1877.73,1081.65 1877.73,1081.62 1877.73,1081.58 1877.73,1081.55 1877.73,1081.51 1877.73,1081.48 1877.73,1081.44 1877.73,1081.41 1877.73,1081.38 1877.73,1081.34 1877.73,1081.31 1877.73,1081.27 1877.73,1081.24 1877.73,1081.2 1877.73,1081.17 1877.73,1081.14 1877.73,1081.1 1877.73,1081.07 1877.73,1081.03 1877.73,1081 1877.73,1080.96 1877.73,1080.93 1877.73,1080.9 1877.73,1080.86 1877.73,1080.83 1877.73,1080.79 1877.73,1080.76 1877.73,1080.72 1877.73,1080.69 1877.73,1080.66 1877.73,1080.62 1877.73,1080.59 1877.73,1080.55 1877.73,1080.52 1877.73,1080.48 1877.73,1080.45 1877.73,1080.42 1877.73,1080.38 1877.73,1080.35 1877.73,1080.31 1877.73,1080.28 1877.73,1080.24 1877.73,1080.21 1877.73,1080.18 1877.73,1080.14 1877.73,1080.11 1877.73,1080.07 1877.73,1080.04 1877.73,1080.01 1877.73,1079.97 1877.73,1079.94 1877.73,1079.9 1877.73,1079.87 1877.73,1079.83 1877.73,1079.8 1877.73,1079.77 1877.73,1079.73 1877.73,1079.7 1877.73,1079.66 1877.73,1079.63 1877.73,1079.59 1877.73,1079.56 1877.73,1079.53 1877.73,1079.49 1877.73,1079.46 1877.73,1079.42 1877.73,1079.39 1877.73,1079.35 1877.73,1079.32 1877.73,1079.29 1877.73,1079.25 1877.73,1079.22 1877.73,1079.18 1877.73,1079.15 1877.73,1079.11 1877.73,1079.08 1877.73,1079.05 1877.73,1079.01 1877.73,1078.98 1877.73,1078.94 1877.73,1078.91 1877.73,1078.87 1877.73,1078.84 1877.73,1078.81 1877.73,1078.77 1877.73,1078.74 1877.73,1078.7 1877.73,1078.67 1877.73,1078.63 1877.73,1078.6 1877.73,1078.57 1877.73,1078.53 1877.73,1078.5 1877.73,1078.46 1877.73,1078.43 1877.73,1078.4 1877.73,1078.36 1877.73,1078.33 1877.73,1078.29 1877.73,1078.26 1877.73,1078.22 1877.73,1078.19 1877.73,1078.16 1877.73,1078.12 1877.73,1078.09 1877.73,1078.05 1877.73,1078.02 1877.73,1077.98 1877.73,1077.95 1877.73,1077.92 1877.73,1077.88 1877.73,1077.85 1877.73,1077.81 1877.73,1077.78 1877.73,1077.74 1877.73,1077.71 1877.73,1077.68 1877.73,1077.64 1877.73,1077.61 1877.73,1077.57 1877.73,1077.54 1877.73,1077.51 1877.73,1077.47 1877.73,1077.44 1877.73,1077.4 1877.73,1077.37 1877.73,1077.33 1877.73,1077.3 1877.73,1077.27 1877.73,1077.23 1877.73,1077.2 1877.73,1077.16 1877.73,1077.13 1877.73,1077.09 1877.73,1077.06 1877.73,1077.03 1877.73,1076.99 1877.73,1076.96 1877.73,1076.92 1877.73,1076.89 1877.73,1076.86 1877.73,1076.82 1877.73,1076.79 1877.73,1076.75 1877.73,1076.72 1877.73,1076.68 1877.73,1076.65 1877.73,1076.62 1877.73,1076.58 1877.73,1076.55 1877.73,1076.51 1877.73,1076.48 1877.73,1076.44 1877.73,1076.41 1877.73,1076.38 1877.73,1076.34 1877.73,1076.31 1877.73,1076.27 1877.73,1076.24 1877.73,1076.21 1877.73,1076.17 1877.73,1076.14 1877.73,1076.1 1877.73,1076.07 1877.73,1076.03 1877.73,1076 1877.73,1075.97 1877.73,1075.93 1877.73,1075.9 1877.73,1075.86 1877.73,1075.83 1877.73,1075.8 1877.73,1075.76 1877.73,1075.73 1877.73,1075.69 1877.73,1075.66 1877.73,1075.62 1877.73,1075.59 1877.73,1075.56 1877.73,1075.52 1877.73,1075.49 1877.73,1075.45 1877.73,1075.42 1877.73,1075.38 1877.73,1075.35 1877.73,1075.32 1877.73,1075.28 1877.73,1075.25 1877.73,1075.21 1877.73,1075.18 1877.73,1075.15 1877.73,1075.11 1877.73,1075.08 1877.73,1075.04 1877.73,1075.01 1877.73,1074.97 1877.73,1074.94 1877.73,1074.91 1877.73,1074.87 1877.73,1074.84 1877.73,1074.8 1877.73,1074.77 1877.73,1074.74 1877.73,1074.7 1877.73,1074.67 1877.73,1074.63 1877.73,1074.6 1877.73,1074.56 1877.73,1074.53 1877.73,1074.5 1877.73,1074.46 1877.73,1074.43 1877.73,1074.39 1877.73,1074.36 1877.73,1074.33 1877.73,1074.29 1877.73,1074.26 1877.73,1074.22 1877.73,1074.19 1877.73,1074.15 1877.73,1074.12 1877.73,1074.09 1877.73,1074.05 1877.73,1074.02 1877.73,1073.98 1877.73,1073.95 1877.73,1073.92 1877.73,1073.88 1877.73,1073.85 1877.73,1073.81 1877.73,1073.78 1877.73,1073.75 1877.73,1073.71 1877.73,1073.68 1877.73,1073.64 1877.73,1073.61 1877.73,1073.57 1877.73,1073.54 1877.73,1073.51 1877.73,1073.47 1877.73,1073.44 1877.73,1073.4 1877.73,1073.37 1877.73,1073.34 1877.73,1073.3 1877.73,1073.27 1877.73,1073.23 1877.73,1073.2 1877.73,1073.16 1877.73,1073.13 1877.73,1073.1 1877.73,1073.06 1877.73,1073.03 1877.73,1072.99 1877.73,1072.96 1877.73,1072.93 1877.73,1072.89 1877.73,1072.86 1877.73,1072.82 1877.73,1072.79 1877.73,1072.75 1877.73,1072.72 1877.73,1072.69 1877.73,1072.65 1877.73,1072.62 1877.73,1072.58 1877.73,1072.55 1877.73,1072.52 1877.73,1072.48 1877.73,1072.45 1877.73,1072.41 1877.73,1072.38 1877.73,1072.35 1877.73,1072.31 1877.73,1072.28 1877.73,1072.24 1877.73,1072.21 1877.73,1072.17 1877.73,1072.14 1877.73,1072.11 1877.73,1072.07 1877.73,1072.04 1877.73,1072 1877.73,1071.97 1877.73,1071.94 1877.73,1071.9 1877.73,1071.87 1877.73,1071.83 1877.73,1071.8 1877.73,1071.77 1877.73,1071.73 1877.73,1071.7 1877.73,1071.66 1877.73,1071.63 1877.73,1071.59 1877.73,1071.56 1877.73,1071.53 1877.73,1071.49 1877.73,1071.46 1877.73,1071.42 1877.73,1071.39 1877.73,1071.36 1877.73,1071.32 1877.73,1071.29 1877.73,1071.25 1877.73,1071.22 1877.73,1071.19 1877.73,1071.15 1877.73,1071.12 1877.73,1071.08 1877.73,1071.05 1877.73,1071.02 1877.73,1070.98 1877.73,1070.95 1877.73,1070.91 1877.73,1070.88 1877.73,1070.84 1877.73,1070.81 1877.73,1070.78 1877.73,1070.74 1877.73,1070.71 1877.73,1070.67 1877.73,1070.64 1877.73,1070.61 1877.73,1070.57 1877.73,1070.54 1877.73,1070.5 1877.73,1070.47 1877.73,1070.44 1877.73,1070.4 1877.73,1070.37 1877.73,1070.33 1877.73,1070.3 1877.73,1070.27 1877.73,1070.23 1877.73,1070.2 1877.73,1070.16 1877.73,1070.13 1877.73,1070.09 1877.73,1070.06 1877.73,1070.03 1877.73,1069.99 1877.73,1069.96 1877.73,1069.92 1877.73,1069.89 1877.73,1069.86 1877.73,1069.82 1877.73,1069.79 1877.73,1069.75 1877.73,1069.72 1877.73,1069.69 1877.73,1069.65 1877.73,1069.62 1877.73,1069.58 1877.73,1069.55 1877.73,1069.52 1877.73,1069.48 1877.73,1069.45 1877.73,1069.41 1877.73,1069.38 1877.73,1069.34 1877.73,1069.31 1877.73,1069.28 1877.73,1069.24 1877.73,1069.21 1877.73,1069.17 1877.73,1069.14 1877.73,1069.11 1877.73,1069.07 1877.73,1069.04 1877.73,1069 1877.73,1068.97 1877.73,1068.94 1877.73,1068.9 1877.73,1068.87 1877.73,1068.83 1877.73,1068.8 1877.73,1068.77 1877.73,1068.73 1877.73,1068.7 1877.73,1068.66 1877.73,1068.63 1877.73,1068.6 1877.73,1068.56 1877.73,1068.53 1877.73,1068.5 1877.73,1068.46 1877.72,1068.43 1877.72,1068.39 1877.72,1068.36 1877.72,1068.33 1877.72,1068.29 1877.72,1068.26 1877.72,1068.22 1877.72,1068.19 1877.72,1068.16 1877.72,1068.12 1877.72,1068.09 1877.72,1068.05 1877.72,1068.02 1877.72,1067.99 1877.72,1067.95 1877.72,1067.92 1877.72,1067.89 1877.72,1067.85 1877.72,1067.82 1877.72,1067.78 1877.72,1067.75 1877.72,1067.72 1877.72,1067.68 1877.72,1067.65 1877.71,1067.61 1877.71,1067.58 1877.71,1067.55 1877.71,1067.51 1877.71,1067.48 1877.71,1067.45 1877.71,1067.41 1877.71,1067.38 1877.71,1067.34 1877.71,1067.31 1877.71,1067.28 1877.71,1067.24 1877.71,1067.21 1877.71,1067.18 1877.71,1067.14 1877.7,1067.11 1877.7,1067.08 1877.7,1067.04 1877.7,1067.01 1877.7,1066.97 1877.7,1066.94 1877.7,1066.91 1877.7,1066.87 1877.7,1066.84 1877.7,1066.81 1877.7,1066.77 1877.7,1066.74 1877.7,1066.7 1877.69,1066.67 1877.69,1066.64 1877.69,1066.6 1877.69,1066.57 1877.69,1066.54 1877.69,1066.5 1877.69,1066.47 1877.69,1066.44 1877.69,1066.4 1877.69,1066.37 1877.69,1066.34 1877.68,1066.3 1877.68,1066.27 1877.68,1066.23 1877.68,1066.2 1877.68,1066.17 1877.68,1066.13 1877.68,1066.1 1877.68,1066.07 1877.68,1066.03 1877.68,1066 1877.67,1065.97 1877.67,1065.93 1877.67,1065.9 1877.67,1065.87 1877.67,1065.83 1877.67,1065.8 1877.67,1065.76 1877.67,1065.73 1877.67,1065.7 1877.66,1065.66 1877.66,1065.63 1877.66,1065.6 1877.66,1065.56 1877.66,1065.53 1877.66,1065.5 1877.66,1065.46 1877.66,1065.43 1877.65,1065.4 1877.65,1065.36 1877.65,1065.33 1877.65,1065.3 1877.65,1065.26 1877.65,1065.23 1877.65,1065.2 1877.65,1065.16 1877.64,1065.13 1877.64,1065.1 1877.64,1065.06 1877.64,1065.03 1877.64,1065 1877.64,1064.96 1877.64,1064.93 1877.63,1064.9 1877.63,1064.86 1877.63,1064.83 1877.63,1064.8 1877.63,1064.76 1877.63,1064.73 1877.63,1064.7 1877.62,1064.66 1877.62,1064.63 1877.62,1064.6 1877.62,1064.56 1877.62,1064.53 1877.62,1064.5 1877.62,1064.46 1877.61,1064.43 1877.61,1064.4 1877.61,1064.36 1877.61,1064.33 1877.61,1064.3 1877.61,1064.26 1877.6,1064.23 1877.6,1064.2 1877.6,1064.16 1877.6,1064.13 1877.6,1064.1 1877.6,1064.06 1877.59,1064.03 1877.59,1064 1877.59,1063.96 1877.59,1063.93 1877.59,1063.9 1877.59,1063.86 1877.58,1063.83 1877.58,1063.8 1877.58,1063.77 1877.58,1063.73 1877.58,1063.7 1877.58,1063.67 1877.57,1063.63 1877.57,1063.6 1877.57,1063.57 1877.57,1063.53 1877.57,1063.5 1877.56,1063.47 1877.56,1063.43 1877.56,1063.4 1877.56,1063.37 1877.56,1063.33 1877.56,1063.3 1877.55,1063.27 1877.55,1063.24 1877.55,1063.2 1877.55,1063.17 1877.55,1063.14 1877.54,1063.1 1877.54,1063.07 1877.54,1063.04 1877.54,1063 1877.54,1062.97 1877.53,1062.94 1877.53,1062.91 1877.53,1062.87 1877.53,1062.84 1877.53,1062.81 1877.52,1062.77 1877.52,1062.74 1877.52,1062.71 1877.52,1062.67 1877.52,1062.64 1877.51,1062.61 1877.51,1062.58 1877.51,1062.54 1877.51,1062.51 1877.5,1062.48 1877.5,1062.44 1877.5,1062.41 1877.5,1062.38 1877.5,1062.34 1877.49,1062.31 1877.49,1062.28 1877.49,1062.25 1877.49,1062.21 1877.48,1062.18 1877.48,1062.15 1877.48,1062.11 1877.48,1062.08 1877.48,1062.05 1877.47,1062.02 1877.47,1061.98 1877.47,1061.95 1877.47,1061.92 1877.46,1061.88 1877.46,1061.85 1877.46,1061.82 1877.46,1061.79 1877.45,1061.75 1877.45,1061.72 1877.45,1061.69 1877.45,1061.65 1877.45,1061.62 1877.44,1061.59 1877.44,1061.56 1877.44,1061.52 1877.44,1061.49 1877.43,1061.46 1877.43,1061.42 1877.43,1061.39 1877.43,1061.36 1877.42,1061.33 1877.42,1061.29 1877.42,1061.26 1877.42,1061.23 1877.41,1061.2 1877.41,1061.16 1877.41,1061.13 1877.41,1061.1 1877.4,1061.06 1877.4,1061.03 1877.4,1061 1877.39,1060.97 1877.39,1060.93 1877.39,1060.9 1877.39,1060.87 1877.38,1060.84 1877.38,1060.8 1877.38,1060.77 1877.38,1060.74 1877.37,1060.7 1877.37,1060.67 1877.37,1060.64 1877.37,1060.61 1877.36,1060.57 1877.36,1060.54 1877.36,1060.51 1877.35,1060.48 1877.35,1060.44 1877.35,1060.41 1877.35,1060.38 1877.34,1060.35 1877.34,1060.31 1877.34,1060.28 1877.34,1060.25 1877.33,1060.22 1877.33,1060.18 1877.33,1060.15 1877.32,1060.12 1877.32,1060.08 1877.32,1060.05 1877.32,1060.02 1877.31,1059.99 1877.31,1059.95 1877.31,1059.92 1877.3,1059.89 1877.3,1059.86 1877.3,1059.82 1877.29,1059.79 1877.29,1059.76 1877.29,1059.73 1877.29,1059.69 1877.28,1059.66 1877.28,1059.63 1877.28,1059.6 1877.27,1059.56 1877.27,1059.53 1877.27,1059.5 1877.26,1059.47 1877.26,1059.43 1877.26,1059.4 1877.26,1059.37 1877.25,1059.34 1877.25,1059.3 1877.25,1059.27 1877.24,1059.24 1877.24,1059.21 1877.24,1059.18 1877.23,1059.14 1877.23,1059.11 1877.23,1059.08 1877.22,1059.05 1877.22,1059.01 1877.22,1058.98 1877.21,1058.95 1877.21,1058.92 1877.21,1058.88 1877.2,1058.85 1877.2,1058.82 1877.2,1058.79 1877.2,1058.75 1877.19,1058.72 1877.19,1058.69 1877.19,1058.66 1877.18,1058.62 1877.18,1058.59 1877.18,1058.56 1877.17,1058.53 1877.17,1058.5 1877.17,1058.46 1877.16,1058.43 1877.16,1058.4 1877.16,1058.37 1877.15,1058.33 1877.15,1058.3 1877.14,1058.27 1877.14,1058.24 1877.14,1058.21 1877.13,1058.17 1877.13,1058.14 1877.13,1058.11 1877.12,1058.08 1877.12,1058.04 1877.12,1058.01 1877.11,1057.98 1877.11,1057.95 1877.11,1057.91 1877.1,1057.88 1877.1,1057.85 1877.1,1057.82 1877.09,1057.79 1877.09,1057.75 1877.09,1057.72 1877.08,1057.69 1877.08,1057.66 1877.07,1057.63 1877.07,1057.59 1877.07,1057.56 1877.06,1057.53 1877.06,1057.5 1877.06,1057.46 1877.05,1057.43 1877.05,1057.4 1877.05,1057.37 1877.04,1057.34 1877.04,1057.3 1877.03,1057.27 1877.03,1057.24 1877.03,1057.21 1877.02,1057.18 1877.02,1057.14 1877.02,1057.11 1877.01,1057.08 1877.01,1057.05 1877,1057.02 1877,1056.98 1877,1056.95 1876.99,1056.92 1876.99,1056.89 1876.99,1056.86 1876.98,1056.82 1876.98,1056.79 1876.97,1056.76 1876.97,1056.73 1876.97,1056.69 1876.96,1056.66 1876.96,1056.63 1876.95,1056.6 1876.95,1056.57 1876.95,1056.53 1876.94,1056.5 1876.94,1056.47 1876.94,1056.44 1876.93,1056.41 1876.93,1056.38 1876.92,1056.34 1876.92,1056.31 1876.92,1056.28 1876.91,1056.25 1876.91,1056.22 1876.9,1056.18 1876.9,1056.15 1876.9,1056.12 1876.89,1056.09 1876.89,1056.06 1876.88,1056.02 1876.88,1055.99 1876.87,1055.96 1876.87,1055.93 1876.87,1055.9 1876.86,1055.86 1876.86,1055.83 1876.85,1055.8 1876.85,1055.77 1876.85,1055.74 1876.84,1055.71 1876.84,1055.67 1876.83,1055.64 1876.83,1055.61 1876.82,1055.58 1876.82,1055.55 1876.82,1055.51 1876.81,1055.48 1876.81,1055.45 1876.8,1055.42 1876.8,1055.39 1876.8,1055.36 1876.79,1055.32 1876.79,1055.29 1876.78,1055.26 1876.78,1055.23 1876.77,1055.2 1876.77,1055.16 1876.77,1055.13 1876.76,1055.1 1876.76,1055.07 1876.75,1055.04 1876.75,1055.01 1876.74,1054.97 1876.74,1054.94 1876.73,1054.91 1876.73,1054.88 1876.73,1054.85 1876.72,1054.82 1876.72,1054.78 1876.71,1054.75 1876.71,1054.72 1876.7,1054.69 1876.7,1054.66 1876.69,1054.63 1876.69,1054.59 1876.69,1054.56 1876.68,1054.53 1876.68,1054.5 1876.67,1054.47 1876.67,1054.44 1876.66,1054.4 1876.66,1054.37 1876.65,1054.34 1876.65,1054.31 1876.65,1054.28 1876.64,1054.25 1876.64,1054.21 1876.63,1054.18 1876.63,1054.15 1876.62,1054.12 1876.62,1054.09 1876.61,1054.06 1876.61,1054.03 1876.6,1053.99 1876.6,1053.96 1876.59,1053.93 1876.59,1053.9 1876.58,1053.87 1876.58,1053.84 1876.58,1053.8 1876.57,1053.77 1876.57,1053.74 1876.56,1053.71 1876.56,1053.68 1876.55,1053.65 1876.55,1053.62 1876.54,1053.58 1876.54,1053.55 1876.53,1053.52 1876.53,1053.49 1876.52,1053.46 1876.52,1053.43 1876.51,1053.39 1876.51,1053.36 1876.5,1053.33 1876.5,1053.3 1876.49,1053.27 1876.49,1053.24 1876.48,1053.21 1876.48,1053.17 1876.47,1053.14 1876.47,1053.11 1876.46,1053.08 1876.46,1053.05 1876.45,1053.02 1876.45,1052.99 1876.44,1052.95 1876.44,1052.92 1876.44,1052.89 1876.43,1052.86 1876.43,1052.83 1876.42,1052.8 1876.42,1052.77 1876.41,1052.74 1876.41,1052.7 1876.4,1052.67 1876.4,1052.64 1876.39,1052.61 1876.38,1052.58 1876.38,1052.55 1876.37,1052.52 1876.37,1052.48 1876.36,1052.45 1876.36,1052.42 1876.35,1052.39 1876.35,1052.36 1876.34,1052.33 1876.34,1052.3 1876.33,1052.27 1876.33,1052.23 1876.32,1052.2 1876.32,1052.17 1876.31,1052.14 1876.31,1052.11 1876.3,1052.08 1876.3,1052.05 1876.29,1052.02 1876.29,1051.98 1876.28,1051.95 1876.28,1051.92 1876.27,1051.89 1876.27,1051.86 1876.26,1051.83 1876.26,1051.8 1876.25,1051.77 1876.25,1051.73 1876.24,1051.7 1876.23,1051.67 1876.23,1051.64 1876.22,1051.61 1876.22,1051.58 1876.21,1051.55 1876.21,1051.52 1876.2,1051.49 1876.2,1051.45 1876.19,1051.42 1876.19,1051.39 1876.18,1051.36 1876.18,1051.33 1876.17,1051.3 1876.16,1051.27 1876.16,1051.24 1876.15,1051.21 1876.15,1051.17 1876.14,1051.14 1876.14,1051.11 1876.13,1051.08 1876.13,1051.05 1876.12,1051.02 1876.12,1050.99 1876.11,1050.96 1876.1,1050.93 1876.1,1050.89 1876.09,1050.86 1876.09,1050.83 1876.08,1050.8 1876.08,1050.77 1876.07,1050.74 1876.07,1050.71 1876.06,1050.68 1876.05,1050.65 1876.05,1050.62 1876.04,1050.58 1876.04,1050.55 1876.03,1050.52 1876.03,1050.49 1876.02,1050.46 1876.01,1050.43 1876.01,1050.4 1876,1050.37 1876,1050.34 1875.99,1050.31 1875.99,1050.28 1875.98,1050.24 1875.98,1050.21 1875.97,1050.18 1875.96,1050.15 1875.96,1050.12 1875.95,1050.09 1875.95,1050.06 1875.94,1050.03 1875.93,1050 1875.93,1049.97 1875.92,1049.94 1875.92,1049.9 1875.91,1049.87 1875.91,1049.84 1875.9,1049.81 1875.89,1049.78 1875.89,1049.75 1875.88,1049.72 1875.88,1049.69 1875.87,1049.66 1875.86,1049.63 1875.86,1049.6 1875.85,1049.56 1875.85,1049.53 1875.84,1049.5 1875.84,1049.47 1875.83,1049.44 1875.82,1049.41 1875.82,1049.38 1875.81,1049.35 1875.81,1049.32 1875.8,1049.29 1875.79,1049.26 1875.79,1049.23 1875.78,1049.2 1875.78,1049.16 1875.77,1049.13 1875.76,1049.1 1875.76,1049.07 1875.75,1049.04 1875.75,1049.01 1875.74,1048.98 1875.73,1048.95 1875.73,1048.92 1875.72,1048.89 1875.71,1048.86 1875.71,1048.83 1875.7,1048.8 1875.7,1048.77 1875.69,1048.73 1875.68,1048.7 1875.68,1048.67 1875.67,1048.64 1875.67,1048.61 1875.66,1048.58 1875.65,1048.55 1875.65,1048.52 1875.64,1048.49 1875.63,1048.46 1875.63,1048.43 1875.62,1048.4 1875.62,1048.37 1875.61,1048.34 1875.6,1048.31 1875.6,1048.28 1875.59,1048.24 1875.58,1048.21 1875.58,1048.18 1875.57,1048.15 1875.57,1048.12 1875.56,1048.09 1875.55,1048.06 1875.55,1048.03 1875.54,1048 1875.53,1047.97 1875.53,1047.94 1875.52,1047.91 1875.52,1047.88 1875.51,1047.85 1875.5,1047.82 1875.5,1047.79 1875.49,1047.76 1875.48,1047.73 1875.48,1047.69 1875.47,1047.66 1875.46,1047.63 1875.46,1047.6 1875.45,1047.57 1875.44,1047.54 1875.44,1047.51 1875.43,1047.48 1875.43,1047.45 1875.42,1047.42 1875.41,1047.39 1875.41,1047.36 1875.4,1047.33 1875.39,1047.3 1875.39,1047.27 1875.38,1047.24 1875.37,1047.21 1875.37,1047.18 1875.36,1047.15 1875.35,1047.12 1875.35,1047.09 1875.34,1047.06 1875.33,1047.02 1875.33,1046.99 1875.32,1046.96 1875.31,1046.93 1875.31,1046.9 1875.3,1046.87 1875.29,1046.84 1875.29,1046.81 1875.28,1046.78 1875.27,1046.75 1875.27,1046.72 1875.26,1046.69 1875.25,1046.66 1875.25,1046.63 1875.24,1046.6 1875.23,1046.57 1875.23,1046.54 1875.22,1046.51 1875.21,1046.48 1875.21,1046.45 1875.2,1046.42 1875.19,1046.39 1875.19,1046.36 1875.18,1046.33 1875.17,1046.3 1875.17,1046.27 1875.16,1046.24 1875.15,1046.21 1875.15,1046.18 1875.14,1046.15 1875.13,1046.12 1875.13,1046.09 1875.12,1046.06 1875.11,1046.02 1875.1,1045.99 1875.1,1045.96 1875.09,1045.93 1875.08,1045.9 1875.08,1045.87 1875.07,1045.84 1875.06,1045.81 1875.06,1045.78 1875.05,1045.75 1875.04,1045.72 1875.04,1045.69 1875.03,1045.66 1875.02,1045.63 1875.01,1045.6 1875.01,1045.57 1875,1045.54 1874.99,1045.51 1874.99,1045.48 1874.98,1045.45 1874.97,1045.42 1874.97,1045.39 1874.96,1045.36 1874.95,1045.33 1874.94,1045.3 1874.94,1045.27 1874.93,1045.24 1874.92,1045.21 1874.92,1045.18 1874.91,1045.15 1874.9,1045.12 1874.89,1045.09 1874.89,1045.06 1874.88,1045.03 1874.87,1045 1874.87,1044.97 1874.86,1044.94 1874.85,1044.91 1874.84,1044.88 1874.84,1044.85 1874.83,1044.82 1874.82,1044.79 1874.82,1044.76 1874.81,1044.73 1874.8,1044.7 1874.79,1044.67 1874.79,1044.64 1874.78,1044.61 1874.77,1044.58 1874.77,1044.55 1874.76,1044.52 1874.75,1044.49 1874.74,1044.46 1874.74,1044.43 1874.73,1044.4 1874.72,1044.37 1874.71,1044.34 1874.71,1044.31 1874.7,1044.28 1874.69,1044.25 1874.68,1044.22 1874.68,1044.19 1874.67,1044.16 1874.66,1044.13 1874.66,1044.1 1874.65,1044.07 1874.64,1044.04 1874.63,1044.01 1874.63,1043.98 1874.62,1043.95 1874.61,1043.92 1874.6,1043.89 1874.6,1043.86 1874.59,1043.83 1874.58,1043.8 1874.57,1043.77 1874.57,1043.74 1874.56,1043.71 1874.55,1043.68 1874.54,1043.65 1874.54,1043.62 1874.53,1043.59 1874.52,1043.56 1874.51,1043.53 1874.51,1043.5 1874.5,1043.47 1874.49,1043.44 1874.48,1043.42 1874.48,1043.39 1874.47,1043.36 1874.46,1043.33 1874.45,1043.3 1874.45,1043.27 1874.44,1043.24 1874.43,1043.21 1874.42,1043.18 1874.42,1043.15 1874.41,1043.12 1874.4,1043.09 1874.39,1043.06 1874.38,1043.03 1874.38,1043 1874.37,1042.97 1874.36,1042.94 1874.35,1042.91 1874.35,1042.88 1874.34,1042.85 1874.33,1042.82 1874.32,1042.79 1874.32,1042.76 1874.31,1042.73 1874.3,1042.7 1874.29,1042.67 1874.28,1042.64 1874.28,1042.61 1874.27,1042.58 1874.26,1042.55 1874.25,1042.52 1874.25,1042.49 1874.24,1042.46 1874.23,1042.44 1874.22,1042.41 1874.21,1042.38 1874.21,1042.35 1874.2,1042.32 1874.19,1042.29 1874.18,1042.26 1874.17,1042.23 1874.17,1042.2 1874.16,1042.17 1874.15,1042.14 1874.14,1042.11 1874.14,1042.08 1874.13,1042.05 1874.12,1042.02 1874.11,1041.99 1874.1,1041.96 1874.1,1041.93 1874.09,1041.9 1874.08,1041.87 1874.07,1041.84 1874.06,1041.81 1874.06,1041.79 1874.05,1041.76 1874.04,1041.73 1874.03,1041.7 1874.02,1041.67 1874.02,1041.64 1874.01,1041.61 1874,1041.58 1873.99,1041.55 1873.98,1041.52 1873.98,1041.49 1873.97,1041.46 1873.96,1041.43 1873.95,1041.4 1873.94,1041.37 1873.94,1041.34 1873.93,1041.31 1873.92,1041.28 1873.91,1041.26 1873.9,1041.23 1873.89,1041.2 1873.89,1041.17 1873.88,1041.14 1873.87,1041.11 1873.86,1041.08 1873.85,1041.05 1873.85,1041.02 1873.84,1040.99 1873.83,1040.96 1873.82,1040.93 1873.81,1040.9 1873.8,1040.87 1873.8,1040.84 1873.79,1040.81 1873.78,1040.79 1873.77,1040.76 1873.76,1040.73 1873.75,1040.7 1873.75,1040.67 1873.74,1040.64 1873.73,1040.61 1873.72,1040.58 1873.71,1040.55 1873.71,1040.52 1873.7,1040.49 1873.69,1040.46 1873.68,1040.43 1873.67,1040.4 1873.66,1040.38 1873.66,1040.35 1873.65,1040.32 1873.64,1040.29 1873.63,1040.26 1873.62,1040.23 1873.61,1040.2 1873.6,1040.17 1873.6,1040.14 1873.59,1040.11 1873.58,1040.08 1873.57,1040.05 1873.56,1040.02 1873.55,1040 1873.55,1039.97 1873.54,1039.94 1873.53,1039.91 1873.52,1039.88 1873.51,1039.85 1873.5,1039.82 1873.49,1039.79 1873.49,1039.76 1873.48,1039.73 1873.47,1039.7 1873.46,1039.67 1873.45,1039.65 1873.44,1039.62 1873.44,1039.59 1873.43,1039.56 1873.42,1039.53 1873.41,1039.5 1873.4,1039.47 1873.39,1039.44 1873.38,1039.41 1873.38,1039.38 1873.37,1039.35 1873.36,1039.33 1873.35,1039.3 1873.34,1039.27 1873.33,1039.24 1873.32,1039.21 1873.31,1039.18 1873.31,1039.15 1873.3,1039.12 1873.29,1039.09 1873.28,1039.06 1873.27,1039.03 1873.26,1039.01 1873.25,1038.98 1873.25,1038.95 1873.24,1038.92 1873.23,1038.89 1873.22,1038.86 1873.21,1038.83 1873.2,1038.8 1873.19,1038.77 1873.18,1038.74 1873.18,1038.72 1873.17,1038.69 1873.16,1038.66 1873.15,1038.63 1873.14,1038.6 1873.13,1038.57 1873.12,1038.54 1873.11,1038.51 1873.1,1038.48 1873.1,1038.46 1873.09,1038.43 1873.08,1038.4 1873.07,1038.37 1873.06,1038.34 1873.05,1038.31 1873.04,1038.28 1873.03,1038.25 1873.02,1038.22 1873.02,1038.2 1873.01,1038.17 1873,1038.14 1872.99,1038.11 1872.98,1038.08 1872.97,1038.05 1872.96,1038.02 1872.95,1037.99 1872.94,1037.96 1872.94,1037.94 1872.93,1037.91 1872.92,1037.88 1872.91,1037.85 1872.9,1037.82 1872.89,1037.79 1872.88,1037.76 1872.87,1037.73 1872.86,1037.7 1872.85,1037.68 1872.85,1037.65 1872.84,1037.62 1872.83,1037.59 1872.82,1037.56 1872.81,1037.53 1872.8,1037.5 1872.79,1037.47 1872.78,1037.45 1872.77,1037.42 1872.76,1037.39 1872.75,1037.36 1872.75,1037.33 1872.74,1037.3 1872.73,1037.27 1872.72,1037.24 1872.71,1037.22 1872.7,1037.19 1872.69,1037.16 1872.68,1037.13 1872.67,1037.1 1872.66,1037.07 1872.65,1037.04 1872.64,1037.02 1872.64,1036.99 1872.63,1036.96 1872.62,1036.93 1872.61,1036.9 1872.6,1036.87 1872.59,1036.84 1872.58,1036.81 1872.57,1036.79 1872.56,1036.76 1872.55,1036.73 1872.54,1036.7 1872.53,1036.67 1872.52,1036.64 1872.51,1036.61 1872.51,1036.59 1872.5,1036.56 1872.49,1036.53 1872.48,1036.5 1872.47,1036.47 1872.46,1036.44 1872.45,1036.41 1872.44,1036.39 1872.43,1036.36 1872.42,1036.33 1872.41,1036.3 1872.4,1036.27 1872.39,1036.24 1872.38,1036.21 1872.37,1036.19 1872.37,1036.16 1872.36,1036.13 1872.35,1036.1 1872.34,1036.07 1872.33,1036.04 1872.32,1036.01 1872.31,1035.99 1872.3,1035.96 1872.29,1035.93 1872.28,1035.9 1872.27,1035.87 1872.26,1035.84 1872.25,1035.82 1872.24,1035.79 1872.23,1035.76 1872.22,1035.73 1872.21,1035.7 1872.2,1035.67 1872.19,1035.64 1872.18,1035.62 1872.18,1035.59 1872.17,1035.56 1872.16,1035.53 1872.15,1035.5 1872.14,1035.47 1872.13,1035.45 1872.12,1035.42 1872.11,1035.39 1872.1,1035.36 1872.09,1035.33 1872.08,1035.3 1872.07,1035.28 1872.06,1035.25 1872.05,1035.22 1872.04,1035.19 1872.03,1035.16 1872.02,1035.13 1872.01,1035.1 1872,1035.08 1871.99,1035.05 1871.98,1035.02 1871.97,1034.99 1871.96,1034.96 1871.95,1034.93 1871.94,1034.91 1871.93,1034.88 1871.92,1034.85 1871.91,1034.82 1871.91,1034.79 1871.9,1034.77 1871.89,1034.74 1871.88,1034.71 1871.87,1034.68 1871.86,1034.65 1871.85,1034.62 1871.84,1034.6 1871.83,1034.57 1871.82,1034.54 1871.81,1034.51 1871.8,1034.48 1871.79,1034.45 1871.78,1034.43 1871.77,1034.4 1871.76,1034.37 1871.75,1034.34 1871.74,1034.31 1871.73,1034.28 1871.72,1034.26 1871.71,1034.23 1871.7,1034.2 1871.69,1034.17 1871.68,1034.14 1871.67,1034.12 1871.66,1034.09 1871.65,1034.06 1871.64,1034.03 1871.63,1034 1871.62,1033.97 1871.61,1033.95 1871.6,1033.92 1871.59,1033.89 1871.58,1033.86 1871.57,1033.83 1871.56,1033.81 1871.55,1033.78 1871.54,1033.75 1871.53,1033.72 1871.52,1033.69 1871.51,1033.67 1871.5,1033.64 1871.49,1033.61 1871.48,1033.58 1871.47,1033.55 1871.46,1033.53 1871.45,1033.5 1871.44,1033.47 1871.43,1033.44 1871.42,1033.41 1871.41,1033.38 1871.4,1033.36 1871.39,1033.33 1871.38,1033.3 1871.37,1033.27 1871.36,1033.24 1871.35,1033.22 1871.34,1033.19 1871.33,1033.16 1871.32,1033.13 1871.31,1033.1 1871.3,1033.08 1871.29,1033.05 1871.28,1033.02 1871.27,1032.99 1871.26,1032.96 1871.25,1032.94 1871.24,1032.91 1871.23,1032.88 1871.22,1032.85 1871.21,1032.82 1871.2,1032.8 1871.19,1032.77 1871.17,1032.74 1871.16,1032.71 1871.15,1032.69 1871.14,1032.66 1871.13,1032.63 1871.12,1032.6 1871.11,1032.57 1871.1,1032.55 1871.09,1032.52 1871.08,1032.49 1871.07,1032.46 1871.06,1032.43 1871.05,1032.41 1871.04,1032.38 1871.03,1032.35 1871.02,1032.32 1871.01,1032.29 1871,1032.27 1870.99,1032.24 1870.98,1032.21 1870.97,1032.18 1870.96,1032.16 1870.95,1032.13 1870.94,1032.1 1870.93,1032.07 1870.92,1032.04 1870.91,1032.02 1870.9,1031.99 1870.89,1031.96 1870.87,1031.93 1870.86,1031.91 1870.85,1031.88 1870.84,1031.85 1870.83,1031.82 1870.82,1031.79 1870.81,1031.77 1870.8,1031.74 1870.79,1031.71 1870.78,1031.68 1870.77,1031.66 1870.76,1031.63 1870.75,1031.6 1870.74,1031.57 1870.73,1031.54 1870.72,1031.52 1870.71,1031.49 1870.7,1031.46 1870.69,1031.43 1870.68,1031.41 1870.66,1031.38 1870.65,1031.35 1870.64,1031.32 1870.63,1031.3 1870.62,1031.27 1870.61,1031.24 1870.6,1031.21 1870.59,1031.18 1870.58,1031.16 1870.57,1031.13 1870.56,1031.1 1870.55,1031.07 1870.54,1031.05 1870.53,1031.02 1870.52,1030.99 1870.51,1030.96 1870.49,1030.94 1870.48,1030.91 1870.47,1030.88 1870.46,1030.85 1870.45,1030.83 1870.44,1030.8 1870.43,1030.77 1870.42,1030.74 1870.41,1030.71 1870.4,1030.69 1870.39,1030.66 1870.38,1030.63 1870.37,1030.6 1870.36,1030.58 1870.34,1030.55 1870.33,1030.52 1870.32,1030.49 1870.31,1030.47 1870.3,1030.44 1870.29,1030.41 1870.28,1030.38 1870.27,1030.36 1870.26,1030.33 1870.25,1030.3 1870.24,1030.27 1870.23,1030.25 1870.22,1030.22 1870.2,1030.19 1870.19,1030.16 1870.18,1030.14 1870.17,1030.11 1870.16,1030.08 1870.15,1030.05 1870.14,1030.03 1870.13,1030 1870.12,1029.97 1870.11,1029.94 1870.1,1029.92 1870.08,1029.89 1870.07,1029.86 1870.06,1029.83 1870.05,1029.81 1870.04,1029.78 1870.03,1029.75 1870.02,1029.73 1870.01,1029.7 1870,1029.67 1869.99,1029.64 1869.97,1029.62 1869.96,1029.59 1869.95,1029.56 1869.94,1029.53 1869.93,1029.51 1869.92,1029.48 1869.91,1029.45 1869.9,1029.42 1869.89,1029.4 1869.88,1029.37 1869.86,1029.34 1869.85,1029.31 1869.84,1029.29 1869.83,1029.26 1869.82,1029.23 1869.81,1029.21 1869.8,1029.18 1869.79,1029.15 1869.78,1029.12 1869.77,1029.1 1869.75,1029.07 1869.74,1029.04 1869.73,1029.01 1869.72,1028.99 1869.71,1028.96 1869.7,1028.93 1869.69,1028.9 1869.68,1028.88 1869.66,1028.85 1869.65,1028.82 1869.64,1028.8 1869.63,1028.77 1869.62,1028.74 1869.61,1028.71 1869.6,1028.69 1869.59,1028.66 1869.58,1028.63 1869.56,1028.61 1869.55,1028.58 1869.54,1028.55 1869.53,1028.52 1869.52,1028.5 1869.51,1028.47 1869.5,1028.44 1869.49,1028.41 1869.47,1028.39 1869.46,1028.36 1869.45,1028.33 1869.44,1028.31 1869.43,1028.28 1869.42,1028.25 1869.41,1028.22 1869.4,1028.2 1869.38,1028.17 1869.37,1028.14 1869.36,1028.12 1869.35,1028.09 1869.34,1028.06 1869.33,1028.03 1869.32,1028.01 1869.3,1027.98 1869.29,1027.95 1869.28,1027.93 1869.27,1027.9 1869.26,1027.87 1869.25,1027.85 1869.24,1027.82 1869.22,1027.79 1869.21,1027.76 1869.2,1027.74 1869.19,1027.71 1869.18,1027.68 1869.17,1027.66 1869.16,1027.63 1869.14,1027.6 1869.13,1027.57 1869.12,1027.55 1869.11,1027.52 1869.1,1027.49 1869.09,1027.47 1869.08,1027.44 1869.06,1027.41 1869.05,1027.39 1869.04,1027.36 1869.03,1027.33 1869.02,1027.3 1869.01,1027.28 1869,1027.25 1868.98,1027.22 1868.97,1027.2 1868.96,1027.17 1868.95,1027.14 1868.94,1027.12 1868.93,1027.09 1868.91,1027.06 1868.9,1027.04 1868.89,1027.01 1868.88,1026.98 1868.87,1026.95 1868.86,1026.93 1868.85,1026.9 1868.83,1026.87 1868.82,1026.85 1868.81,1026.82 1868.8,1026.79 1868.79,1026.77 1868.78,1026.74 1868.76,1026.71 1868.75,1026.69 1868.74,1026.66 1868.73,1026.63 1868.72,1026.6 1868.71,1026.58 1868.69,1026.55 1868.68,1026.52 1868.67,1026.5 1868.66,1026.47 1868.65,1026.44 1868.64,1026.42 1868.62,1026.39 1868.61,1026.36 1868.6,1026.34 1868.59,1026.31 1868.58,1026.28 1868.56,1026.26 1868.55,1026.23 1868.54,1026.2 1868.53,1026.18 1868.52,1026.15 1868.51,1026.12 1868.49,1026.1 1868.48,1026.07 1868.47,1026.04 1868.46,1026.01 1868.45,1025.99 1868.44,1025.96 1868.42,1025.93 1868.41,1025.91 1868.4,1025.88 1868.39,1025.85 1868.38,1025.83 1868.36,1025.8 1868.35,1025.77 1868.34,1025.75 1868.33,1025.72 1868.32,1025.69 1868.3,1025.67 1868.29,1025.64 1868.28,1025.61 1868.27,1025.59 1868.26,1025.56 1868.25,1025.53 1868.23,1025.51 1868.22,1025.48 1868.21,1025.45 1868.2,1025.43 1868.19,1025.4 1868.17,1025.37 1868.16,1025.35 1868.15,1025.32 1868.14,1025.29 1868.13,1025.27 1868.11,1025.24 1868.1,1025.21 1868.09,1025.19 1868.08,1025.16 1868.07,1025.13 1868.05,1025.11 1868.04,1025.08 1868.03,1025.05 1868.02,1025.03 1868.01,1025 1867.99,1024.98 1867.98,1024.95 1867.97,1024.92 1867.96,1024.9 1867.95,1024.87 1867.93,1024.84 1867.92,1024.82 1867.91,1024.79 1867.9,1024.76 1867.89,1024.74 1867.87,1024.71 1867.86,1024.68 1867.85,1024.66 1867.84,1024.63 1867.82,1024.6 1867.81,1024.58 1867.8,1024.55 1867.79,1024.52 1867.78,1024.5 1867.76,1024.47 1867.75,1024.44 1867.74,1024.42 1867.73,1024.39 1867.72,1024.37 1867.7,1024.34 1867.69,1024.31 1867.68,1024.29 1867.67,1024.26 1867.65,1024.23 1867.64,1024.21 1867.63,1024.18 1867.62,1024.15 1867.61,1024.13 1867.59,1024.1 1867.58,1024.07 1867.57,1024.05 1867.56,1024.02 1867.54,1024 1867.53,1023.97 1867.52,1023.94 1867.51,1023.92 1867.5,1023.89 1867.48,1023.86 1867.47,1023.84 1867.46,1023.81 1867.45,1023.78 1867.43,1023.76 1867.42,1023.73 1867.41,1023.71 1867.4,1023.68 1867.38,1023.65 1867.37,1023.63 1867.36,1023.6 1867.35,1023.57 1867.34,1023.55 1867.32,1023.52 1867.31,1023.49 1867.3,1023.47 1867.29,1023.44 1867.27,1023.42 1867.26,1023.39 1867.25,1023.36 1867.24,1023.34 1867.22,1023.31 1867.21,1023.28 1867.2,1023.26 1867.19,1023.23 1867.17,1023.21 1867.16,1023.18 1867.15,1023.15 1867.14,1023.13 1867.12,1023.1 1867.11,1023.07 1867.1,1023.05 1867.09,1023.02 1867.07,1023 1867.06,1022.97 1867.05,1022.94 1867.04,1022.92 1867.03,1022.89 1867.01,1022.86 1867,1022.84 1866.99,1022.81 1866.98,1022.79 1866.96,1022.76 1866.95,1022.73 1866.94,1022.71 1866.92,1022.68 1866.91,1022.65 1866.9,1022.63 1866.89,1022.6 1866.87,1022.58 1866.86,1022.55 1866.85,1022.52 1866.84,1022.5 1866.82,1022.47 1866.81,1022.45 1866.8,1022.42 1866.79,1022.39 1866.77,1022.37 1866.76,1022.34 1866.75,1022.32 1866.74,1022.29 1866.72,1022.26 1866.71,1022.24 1866.7,1022.21 1866.69,1022.18 1866.67,1022.16 1866.66,1022.13 1866.65,1022.11 1866.64,1022.08 1866.62,1022.05 1866.61,1022.03 1866.6,1022 1866.58,1021.98 1866.57,1021.95 1866.56,1021.92 1866.55,1021.9 1866.53,1021.87 1866.52,1021.85 1866.51,1021.82 1866.5,1021.79 1866.48,1021.77 1866.47,1021.74 1866.46,1021.72 1866.44,1021.69 1866.43,1021.66 1866.42,1021.64 1866.41,1021.61 1866.39,1021.59 1866.38,1021.56 1866.37,1021.53 1866.36,1021.51 1866.34,1021.48 1866.33,1021.46 1866.32,1021.43 1866.3,1021.4 1866.29,1021.38 1866.28,1021.35 1866.27,1021.33 1866.25,1021.3 1866.24,1021.27 1866.23,1021.25 1866.21,1021.22 1866.2,1021.2 1866.19,1021.17 1866.18,1021.15 1866.16,1021.12 1866.15,1021.09 1866.14,1021.07 1866.12,1021.04 1866.11,1021.02 1866.1,1020.99 1866.09,1020.96 1866.07,1020.94 1866.06,1020.91 1866.05,1020.89 1866.03,1020.86 1866.02,1020.84 1866.01,1020.81 1865.99,1020.78 1865.98,1020.76 1865.97,1020.73 1865.96,1020.71 1865.94,1020.68 1865.93,1020.65 1865.92,1020.63 1865.9,1020.6 1865.89,1020.58 1865.88,1020.55 1865.87,1020.53 1865.85,1020.5 1865.84,1020.47 1865.83,1020.45 1865.81,1020.42 1865.8,1020.4 1865.79,1020.37 1865.77,1020.34 1865.76,1020.32 1865.75,1020.29 1865.74,1020.27 1865.72,1020.24 1865.71,1020.22 1865.7,1020.19 1865.68,1020.16 1865.67,1020.14 1865.66,1020.11 1865.64,1020.09 1865.63,1020.06 1865.62,1020.04 1865.6,1020.01 1865.59,1019.98 1865.58,1019.96 1865.56,1019.93 1865.55,1019.91 1865.54,1019.88 1865.53,1019.86 1865.51,1019.83 1865.5,1019.81 1865.49,1019.78 1865.47,1019.75 1865.46,1019.73 1865.45,1019.7 1865.43,1019.68 1865.42,1019.65 1865.41,1019.63 1865.39,1019.6 1865.38,1019.57 1865.37,1019.55 1865.35,1019.52 1865.34,1019.5 1865.33,1019.47 1865.31,1019.45 1865.3,1019.42 1865.29,1019.4 1865.28,1019.37 1865.26,1019.34 1865.25,1019.32 1865.24,1019.29 1865.22,1019.27 1865.21,1019.24 1865.2,1019.22 1865.18,1019.19 1865.17,1019.17 1865.16,1019.14 1865.14,1019.11 1865.13,1019.09 1865.12,1019.06 1865.1,1019.04 1865.09,1019.01 1865.08,1018.99 1865.06,1018.96 1865.05,1018.94 1865.04,1018.91 1865.02,1018.88 1865.01,1018.86 1865,1018.83 1864.98,1018.81 1864.97,1018.78 1864.96,1018.76 1864.94,1018.73 1864.93,1018.71 1864.92,1018.68 1864.9,1018.66 1864.89,1018.63 1864.88,1018.6 1864.86,1018.58 1864.85,1018.55 1864.84,1018.53 1864.82,1018.5 1864.81,1018.48 1864.8,1018.45 1864.78,1018.43 1864.77,1018.4 1864.75,1018.38 1864.74,1018.35 1864.73,1018.32 1864.71,1018.3 1864.7,1018.27 1864.69,1018.25 1864.67,1018.22 1864.66,1018.2 1864.65,1018.17 1864.63,1018.15 1864.62,1018.12 1864.61,1018.1 1864.59,1018.07 1864.58,1018.05 1864.57,1018.02 1864.55,1018 1864.54,1017.97 1864.53,1017.94 1864.51,1017.92 1864.5,1017.89 1864.48,1017.87 1864.47,1017.84 1864.46,1017.82 1864.44,1017.79 1864.43,1017.77 1864.42,1017.74 1864.4,1017.72 1864.39,1017.69 1864.38,1017.67 1864.36,1017.64 1864.35,1017.62 1864.34,1017.59 1864.32,1017.57 1864.31,1017.54 1864.29,1017.51 1864.28,1017.49 1864.27,1017.46 1864.25,1017.44 1864.24,1017.41 1864.23,1017.39 1864.21,1017.36 1864.2,1017.34 1864.19,1017.31 1864.17,1017.29 1864.16,1017.26 1864.14,1017.24 1864.13,1017.21 1864.12,1017.19 1864.1,1017.16 1864.09,1017.14 1864.08,1017.11 1864.06,1017.09 1864.05,1017.06 1864.04,1017.04 1864.02,1017.01 1864.01,1016.99 1863.99,1016.96 1863.98,1016.94 1863.97,1016.91 1863.95,1016.89 1863.94,1016.86 1863.93,1016.83 1863.91,1016.81 1863.9,1016.78 1863.88,1016.76 1863.87,1016.73 1863.86,1016.71 1863.84,1016.68 1863.83,1016.66 1863.82,1016.63 1863.8,1016.61 1863.79,1016.58 1863.77,1016.56 1863.76,1016.53 1863.75,1016.51 1863.73,1016.48 1863.72,1016.46 1863.7,1016.43 1863.69,1016.41 1863.68,1016.38 1863.66,1016.36 1863.65,1016.33 1863.64,1016.31 1863.62,1016.28 1863.61,1016.26 1863.59,1016.23 1863.58,1016.21 1863.57,1016.18 1863.55,1016.16 1863.54,1016.13 1863.52,1016.11 1863.51,1016.08 1863.5,1016.06 1863.48,1016.03 1863.47,1016.01 1863.45,1015.98 1863.44,1015.96 1863.43,1015.93 1863.41,1015.91 1863.4,1015.88 1863.39,1015.86 1863.37,1015.83 1863.36,1015.81 1863.34,1015.78 1863.33,1015.76 1863.32,1015.73 1863.3,1015.71 1863.29,1015.68 1863.27,1015.66 1863.26,1015.63 1863.25,1015.61 1863.23,1015.58 1863.22,1015.56 1863.2,1015.53 1863.19,1015.51 1863.18,1015.48 1863.16,1015.46 1863.15,1015.43 1863.13,1015.41 1863.12,1015.39 1863.11,1015.36 1863.09,1015.34 1863.08,1015.31 1863.06,1015.29 1863.05,1015.26 1863.03,1015.24 1863.02,1015.21 1863.01,1015.19 1862.99,1015.16 1862.98,1015.14 1862.96,1015.11 1862.95,1015.09 1862.94,1015.06 1862.92,1015.04 1862.91,1015.01 1862.89,1014.99 1862.88,1014.96 1862.87,1014.94 1862.85,1014.91 1862.84,1014.89 1862.82,1014.86 1862.81,1014.84 1862.79,1014.81 1862.78,1014.79 1862.77,1014.76 1862.75,1014.74 1862.74,1014.72 1862.72,1014.69 1862.71,1014.67 1862.7,1014.64 1862.68,1014.62 1862.67,1014.59 1862.65,1014.57 1862.64,1014.54 1862.62,1014.52 1862.61,1014.49 1862.6,1014.47 1862.58,1014.44 1862.57,1014.42 1862.55,1014.39 1862.54,1014.37 1862.52,1014.34 1862.51,1014.32 1862.5,1014.3 1862.48,1014.27 1862.47,1014.25 1862.45,1014.22 1862.44,1014.2 1862.43,1014.17 1862.41,1014.15 1862.4,1014.12 1862.38,1014.1 1862.37,1014.07 1862.35,1014.05 1862.34,1014.02 1862.33,1014 1862.31,1013.98 1862.3,1013.95 1862.28,1013.93 1862.27,1013.9 1862.25,1013.88 1862.24,1013.85 1862.22,1013.83 1862.21,1013.8 1862.2,1013.78 1862.18,1013.75 1862.17,1013.73 1862.15,1013.7 1862.14,1013.68 1862.12,1013.66 1862.11,1013.63 1862.1,1013.61 1862.08,1013.58 1862.07,1013.56 1862.05,1013.53 1862.04,1013.51 1862.02,1013.48 1862.01,1013.46 1861.99,1013.43 1861.98,1013.41 1861.97,1013.39 1861.95,1013.36 1861.94,1013.34 1861.92,1013.31 1861.91,1013.29 1861.89,1013.26 1861.88,1013.24 1861.86,1013.21 1861.85,1013.19 1861.84,1013.17 1861.82,1013.14 1861.81,1013.12 1861.79,1013.09 1861.78,1013.07 1861.76,1013.04 1861.75,1013.02 1861.73,1012.99 1861.72,1012.97 1861.71,1012.95 1861.69,1012.92 1861.68,1012.9 1861.66,1012.87 1861.65,1012.85 1861.63,1012.82 1861.62,1012.8 1861.6,1012.77 1861.59,1012.75 1861.57,1012.73 1861.56,1012.7 1861.55,1012.68 1861.53,1012.65 1861.52,1012.63 1861.5,1012.6 1861.49,1012.58 1861.47,1012.56 1861.46,1012.53 1861.44,1012.51 1861.43,1012.48 1861.41,1012.46 1861.4,1012.43 1861.38,1012.41 1861.37,1012.38 1861.36,1012.36 1861.34,1012.34 1861.33,1012.31 1861.31,1012.29 1861.3,1012.26 1861.28,1012.24 1861.27,1012.21 1861.25,1012.19 1861.24,1012.17 1861.22,1012.14 1861.21,1012.12 1861.19,1012.09 1861.18,1012.07 1861.16,1012.04 1861.15,1012.02 1861.14,1012 1861.12,1011.97 1861.11,1011.95 1861.09,1011.92 1861.08,1011.9 1861.06,1011.87 1861.05,1011.85 1861.03,1011.83 1861.02,1011.8 1861,1011.78 1860.99,1011.75 1860.97,1011.73 1860.96,1011.71 1860.94,1011.68 1860.93,1011.66 1860.91,1011.63 1860.9,1011.61 1860.88,1011.58 1860.87,1011.56 1860.86,1011.54 1860.84,1011.51 1860.83,1011.49 1860.81,1011.46 1860.8,1011.44 1860.78,1011.42 1860.77,1011.39 1860.75,1011.37 1860.74,1011.34 1860.72,1011.32 1860.71,1011.29 1860.69,1011.27 1860.68,1011.25 1860.66,1011.22 1860.65,1011.2 1860.63,1011.17 1860.62,1011.15 1860.6,1011.13 1860.59,1011.1 1860.57,1011.08 1860.56,1011.05 1860.54,1011.03 1860.53,1011.01 1860.51,1010.98 1860.5,1010.96 1860.48,1010.93 1860.47,1010.91 1860.45,1010.88 1860.44,1010.86 1860.42,1010.84 1860.41,1010.81 1860.39,1010.79 1860.38,1010.76 1860.36,1010.74 1860.35,1010.72 1860.34,1010.69 1860.32,1010.67 1860.31,1010.64 1860.29,1010.62 1860.28,1010.6 1860.26,1010.57 1860.25,1010.55 1860.23,1010.52 1860.22,1010.5 1860.2,1010.48 1860.19,1010.45 1860.17,1010.43 1860.16,1010.4 1860.14,1010.38 1860.13,1010.36 1860.11,1010.33 1860.1,1010.31 1860.08,1010.28 1860.07,1010.26 1860.05,1010.24 1860.04,1010.21 1860.02,1010.19 1860.01,1010.17 1859.99,1010.14 1859.98,1010.12 1859.96,1010.09 1859.95,1010.07 1859.93,1010.05 1859.91,1010.02 1859.9,1010 1859.88,1009.97 1859.87,1009.95 1859.85,1009.93 1859.84,1009.9 1859.82,1009.88 1859.81,1009.85 1859.79,1009.83 1859.78,1009.81 1859.76,1009.78 1859.75,1009.76 1859.73,1009.74 1859.72,1009.71 1859.7,1009.69 1859.69,1009.66 1859.67,1009.64 1859.66,1009.62 1859.64,1009.59 1859.63,1009.57 1859.61,1009.54 1859.6,1009.52 1859.58,1009.5 1859.57,1009.47 1859.55,1009.45 1859.54,1009.43 1859.52,1009.4 1859.51,1009.38 1859.49,1009.35 1859.48,1009.33 1859.46,1009.31 1859.45,1009.28 1859.43,1009.26 1859.42,1009.24 1859.4,1009.21 1859.38,1009.19 1859.37,1009.16 1859.35,1009.14 1859.34,1009.12 1859.32,1009.09 1859.31,1009.07 1859.29,1009.05 1859.28,1009.02 1859.26,1009 1859.25,1008.97 1859.23,1008.95 1859.22,1008.93 1859.2,1008.9 1859.19,1008.88 1859.17,1008.86 1859.16,1008.83 1859.14,1008.81 1859.13,1008.78 1859.11,1008.76 1859.1,1008.74 1859.08,1008.71 1859.06,1008.69 1859.05,1008.67 1859.03,1008.64 1859.02,1008.62 1859,1008.6 1858.99,1008.57 1858.97,1008.55 1858.96,1008.52 1858.94,1008.5 1858.93,1008.48 1858.91,1008.45 1858.9,1008.43 1858.88,1008.41 1858.87,1008.38 1858.85,1008.36 1858.83,1008.34 1858.82,1008.31 1858.8,1008.29 1858.79,1008.26 1858.77,1008.24 1858.76,1008.22 1858.74,1008.19 1858.73,1008.17 1858.71,1008.15 1858.7,1008.12 1858.68,1008.1 1858.66,1008.08 1858.65,1008.05 1858.63,1008.03 1858.62,1008.01 1858.6,1007.98 1858.59,1007.96 1858.57,1007.94 1858.56,1007.91 1858.54,1007.89 1858.53,1007.86 1858.51,1007.84 1858.5,1007.82 1858.48,1007.79 1858.46,1007.77 1858.45,1007.75 1858.43,1007.72 1858.42,1007.7 1858.4,1007.68 1858.39,1007.65 1858.37,1007.63 1858.36,1007.61 1858.34,1007.58 1858.32,1007.56 1858.31,1007.54 1858.29,1007.51 1858.28,1007.49 1858.26,1007.47 1858.25,1007.44 1858.23,1007.42 1858.22,1007.4 1858.2,1007.37 1858.18,1007.35 1858.17,1007.33 1858.15,1007.3 1858.14,1007.28 1858.12,1007.25 1858.11,1007.23 1858.09,1007.21 1858.08,1007.18 1858.06,1007.16 1858.04,1007.14 1858.03,1007.11 1858.01,1007.09 1858,1007.07 1857.98,1007.04 1857.97,1007.02 1857.95,1007 1857.94,1006.97 1857.92,1006.95 1857.9,1006.93 1857.89,1006.9 1857.87,1006.88 1857.86,1006.86 1857.84,1006.83 1857.83,1006.81 1857.81,1006.79 1857.8,1006.76 1857.78,1006.74 1857.76,1006.72 1857.75,1006.69 1857.73,1006.67 1857.72,1006.65 1857.7,1006.62 1857.69,1006.6 1857.67,1006.58 1857.65,1006.55 1857.64,1006.53 1857.62,1006.51 1857.61,1006.49 1857.59,1006.46 1857.58,1006.44 1857.56,1006.42 1857.54,1006.39 1857.53,1006.37 1857.51,1006.35 1857.5,1006.32 1857.48,1006.3 1857.47,1006.28 1857.45,1006.25 1857.43,1006.23 1857.42,1006.21 1857.4,1006.18 1857.39,1006.16 1857.37,1006.14 1857.36,1006.11 1857.34,1006.09 1857.32,1006.07 1857.31,1006.04 1857.29,1006.02 1857.28,1006 1857.26,1005.97 1857.24,1005.95 1857.23,1005.93 1857.21,1005.9 1857.2,1005.88 1857.18,1005.86 1857.17,1005.84 1857.15,1005.81 1857.13,1005.79 1857.12,1005.77 1857.1,1005.74 1857.09,1005.72 1857.07,1005.7 1857.05,1005.67 1857.04,1005.65 1857.02,1005.63 1857.01,1005.6 1856.99,1005.58 1856.98,1005.56 1856.96,1005.53 1856.94,1005.51 1856.93,1005.49 1856.91,1005.47 1856.9,1005.44 1856.88,1005.42 1856.86,1005.4 1856.85,1005.37 1856.83,1005.35 1856.82,1005.33 1856.8,1005.3 1856.79,1005.28 1856.77,1005.26 1856.75,1005.24 1856.74,1005.21 1856.72,1005.19 1856.71,1005.17 1856.69,1005.14 1856.67,1005.12 1856.66,1005.1 1856.64,1005.07 1856.63,1005.05 1856.61,1005.03 1856.59,1005.01 1856.58,1004.98 1856.56,1004.96 1856.55,1004.94 1856.53,1004.91 1856.51,1004.89 1856.5,1004.87 1856.48,1004.84 1856.47,1004.82 1856.45,1004.8 1856.43,1004.78 1856.42,1004.75 1856.4,1004.73 1856.39,1004.71 1856.37,1004.68 1856.35,1004.66 1856.34,1004.64 1856.32,1004.61 1856.31,1004.59 1856.29,1004.57 1856.27,1004.55 1856.26,1004.52 1856.24,1004.5 1856.23,1004.48 1856.21,1004.45 1856.19,1004.43 1856.18,1004.41 1856.16,1004.39 1856.15,1004.36 1856.13,1004.34 1856.11,1004.32 1856.1,1004.29 1856.08,1004.27 1856.07,1004.25 1856.05,1004.23 1856.03,1004.2 1856.02,1004.18 1856,1004.16 1855.98,1004.13 1855.97,1004.11 1855.95,1004.09 1855.94,1004.07 1855.92,1004.04 1855.9,1004.02 1855.89,1004 1855.87,1003.97 1855.86,1003.95 1855.84,1003.93 1855.82,1003.91 1855.81,1003.88 1855.79,1003.86 1855.78,1003.84 1855.76,1003.82 1855.74,1003.79 1855.73,1003.77 1855.71,1003.75 1855.69,1003.72 1855.68,1003.7 1855.66,1003.68 1855.65,1003.66 1855.63,1003.63 1855.61,1003.61 1855.6,1003.59 1855.58,1003.56 1855.56,1003.54 1855.55,1003.52 1855.53,1003.5 1855.52,1003.47 1855.5,1003.45 1855.48,1003.43 1855.47,1003.41 1855.45,1003.38 1855.44,1003.36 1855.42,1003.34 1855.4,1003.32 1855.39,1003.29 1855.37,1003.27 1855.35,1003.25 1855.34,1003.22 1855.32,1003.2 1855.31,1003.18 1855.29,1003.16 1855.27,1003.13 1855.26,1003.11 1855.24,1003.09 1855.22,1003.07 1855.21,1003.04 1855.19,1003.02 1855.17,1003 1855.16,1002.98 1855.14,1002.95 1855.13,1002.93 1855.11,1002.91 1855.09,1002.88 1855.08,1002.86 1855.06,1002.84 1855.04,1002.82 1855.03,1002.79 1855.01,1002.77 1855,1002.75 1854.98,1002.73 1854.96,1002.7 1854.95,1002.68 1854.93,1002.66 1854.91,1002.64 1854.9,1002.61 1854.88,1002.59 1854.86,1002.57 1854.85,1002.55 1854.83,1002.52 1854.82,1002.5 1854.8,1002.48 1854.78,1002.46 1854.77,1002.43 1854.75,1002.41 1854.73,1002.39 1854.72,1002.37 1854.7,1002.34 1854.68,1002.32 1854.67,1002.3 1854.65,1002.28 1854.64,1002.25 1854.62,1002.23 1854.6,1002.21 1854.59,1002.19 1854.57,1002.16 1854.55,1002.14 1854.54,1002.12 1854.52,1002.1 1854.5,1002.07 1854.49,1002.05 1854.47,1002.03 1854.45,1002.01 1854.44,1001.98 1854.42,1001.96 1854.41,1001.94 1854.39,1001.92 1854.37,1001.89 1854.36,1001.87 1854.34,1001.85 1854.32,1001.83 1854.31,1001.8 1854.29,1001.78 1854.27,1001.76 1854.26,1001.74 1854.24,1001.71 1854.22,1001.69 1854.21,1001.67 1854.19,1001.65 1854.17,1001.63 1854.16,1001.6 1854.14,1001.58 1854.12,1001.56 1854.11,1001.54 1854.09,1001.51 1854.08,1001.49 1854.06,1001.47 1854.04,1001.45 1854.03,1001.42 1854.01,1001.4 1853.99,1001.38 1853.98,1001.36 1853.96,1001.33 1853.94,1001.31 1853.93,1001.29 1853.91,1001.27 1853.89,1001.25 1853.88,1001.22 1853.86,1001.2 1853.84,1001.18 1853.83,1001.16 1853.81,1001.13 1853.79,1001.11 1853.78,1001.09 1853.76,1001.07 1853.74,1001.04 1853.73,1001.02 1853.71,1001 1853.69,1000.98 1853.68,1000.96 1853.66,1000.93 1853.64,1000.91 1853.63,1000.89 1853.61,1000.87 1853.59,1000.84 1853.58,1000.82 1853.56,1000.8 1853.54,1000.78 1853.53,1000.76 1853.51,1000.73 1853.49,1000.71 1853.48,1000.69 1853.46,1000.67 1853.44,1000.64 1853.43,1000.62 1853.41,1000.6 1853.39,1000.58 1853.38,1000.56 1853.36,1000.53 1853.34,1000.51 1853.33,1000.49 1853.31,1000.47 1853.29,1000.44 1853.28,1000.42 1853.26,1000.4 1853.24,1000.38 1853.23,1000.36 1853.21,1000.33 1853.19,1000.31 1853.18,1000.29 1853.16,1000.27 1853.14,1000.25 1853.13,1000.22 1853.11,1000.2 1853.09,1000.18 1853.08,1000.16 1853.06,1000.14 1853.04,1000.11 1853.03,1000.09 1853.01,1000.07 1852.99,1000.05 1852.98,1000.02 1852.96,1000 1852.94,999.98 1852.93,999.958 1852.91,999.936 1852.89,999.914 1852.88,999.892 1852.86,999.87 1852.84,999.848 1852.82,999.826 1852.81,999.804 1852.79,999.782 1852.77,999.76 1852.76,999.738 1852.74,999.716 1852.72,999.694 1852.71,999.672 1852.69,999.65 1852.67,999.628 1852.66,999.606 1852.64,999.584 1852.62,999.562 1852.61,999.54 1852.59,999.518 1852.57,999.496 1852.56,999.474 1852.54,999.452 1852.52,999.43 1852.5,999.408 1852.49,999.386 1852.47,999.364 1852.45,999.342 1852.44,999.32 1852.42,999.298 1852.4,999.276 1852.39,999.254 1852.37,999.232 1852.35,999.21 1852.34,999.188 1852.32,999.166 1852.3,999.144 1852.29,999.122 1852.27,999.101 1852.25,999.079 1852.23,999.057 1852.22,999.035 1852.2,999.013 1852.18,998.991 1852.17,998.969 1852.15,998.947 1852.13,998.925 1852.12,998.903 1852.1,998.882 1852.08,998.86 1852.07,998.838 1852.05,998.816 1852.03,998.794 1852.01,998.772 1852,998.75 1851.98,998.729 1851.96,998.707 1851.95,998.685 1851.93,998.663 1851.91,998.641 1851.9,998.619 1851.88,998.597 1851.86,998.576 1851.84,998.554 1851.83,998.532 1851.81,998.51 1851.79,998.488 1851.78,998.467 1851.76,998.445 1851.74,998.423 1851.73,998.401 1851.71,998.379 1851.69,998.358 1851.67,998.336 1851.66,998.314 1851.64,998.292 1851.62,998.271 1851.61,998.249 1851.59,998.227 1851.57,998.205 1851.55,998.184 1851.54,998.162 1851.52,998.14 1851.5,998.118 1851.49,998.097 1851.47,998.075 1851.45,998.053 1851.44,998.031 1851.42,998.01 1851.4,997.988 1851.38,997.966 1851.37,997.944 1851.35,997.923 1851.33,997.901 1851.32,997.879 1851.3,997.858 1851.28,997.836 1851.26,997.814 1851.25,997.793 1851.23,997.771 1851.21,997.749 1851.2,997.728 1851.18,997.706 1851.16,997.684 1851.14,997.663 1851.13,997.641 1851.11,997.619 1851.09,997.598 1851.08,997.576 1851.06,997.554 1851.04,997.533 1851.02,997.511 1851.01,997.49 1850.99,997.468 1850.97,997.446 1850.96,997.425 1850.94,997.403 1850.92,997.381 1850.9,997.36 1850.89,997.338 1850.87,997.317 1850.85,997.295 1850.84,997.273 1850.82,997.252 1850.8,997.23 1850.78,997.209 1850.77,997.187 1850.75,997.166 1850.73,997.144 1850.72,997.123 1850.7,997.101 1850.68,997.079 1850.66,997.058 1850.65,997.036 1850.63,997.015 1850.61,996.993 1850.59,996.972 1850.58,996.95 1850.56,996.929 1850.54,996.907 1850.53,996.886 1850.51,996.864 1850.49,996.843 1850.47,996.821 1850.46,996.8 1850.44,996.778 1850.42,996.757 1850.4,996.735 1850.39,996.714 1850.37,996.692 1850.35,996.671 1850.34,996.649 1850.32,996.628 1850.3,996.606 1850.28,996.585 1850.27,996.563 1850.25,996.542 1850.23,996.52 1850.21,996.499 1850.2,996.478 1850.18,996.456 1850.16,996.435 1850.15,996.413 1850.13,996.392 1850.11,996.37 1850.09,996.349 1850.08,996.328 1850.06,996.306 1850.04,996.285 1850.02,996.263 1850.01,996.242 1849.99,996.221 1849.97,996.199 1849.95,996.178 1849.94,996.156 1849.92,996.135 1849.9,996.114 1849.89,996.092 1849.87,996.071 1849.85,996.05 1849.83,996.028 1849.82,996.007 1849.8,995.986 1849.78,995.964 1849.76,995.943 1849.75,995.921 1849.73,995.9 1849.71,995.879 1849.69,995.857 1849.68,995.836 1849.66,995.815 1849.64,995.794 1849.62,995.772 1849.61,995.751 1849.59,995.73 1849.57,995.708 1849.55,995.687 1849.54,995.666 1849.52,995.644 1849.5,995.623 1849.48,995.602 1849.47,995.581 1849.45,995.559 1849.43,995.538 1849.42,995.517 1849.4,995.496 1849.38,995.474 1849.36,995.453 1849.35,995.432 1849.33,995.411 1849.31,995.389 1849.29,995.368 1849.28,995.347 1849.26,995.326 1849.24,995.304 1849.22,995.283 1849.21,995.262 1849.19,995.241 1849.17,995.219 1849.15,995.198 1849.14,995.177 1849.12,995.156 1849.1,995.135 1849.08,995.113 1849.07,995.092 1849.05,995.071 1849.03,995.05 1849.01,995.029 1849,995.008 1848.98,994.986 1848.96,994.965 1848.94,994.944 1848.93,994.923 1848.91,994.902 1848.89,994.881 1848.87,994.859 1848.86,994.838 1848.84,994.817 1848.82,994.796 1848.8,994.775 1848.78,994.754 1848.77,994.733 1848.75,994.712 1848.73,994.69 1848.71,994.669 1848.7,994.648 1848.68,994.627 1848.66,994.606 1848.64,994.585 1848.63,994.564 1848.61,994.543 1848.59,994.522 1848.57,994.501 1848.56,994.48 1848.54,994.458 1848.52,994.437 1848.5,994.416 1848.49,994.395 1848.47,994.374 1848.45,994.353 1848.43,994.332 1848.42,994.311 1848.4,994.29 1848.38,994.269 1848.36,994.248 1848.34,994.227 1848.33,994.206 1848.31,994.185 1848.29,994.164 1848.27,994.143 1848.26,994.122 1848.24,994.101 1848.22,994.08 1848.2,994.059 1848.19,994.038 1848.17,994.017 1848.15,993.996 1848.13,993.975 1848.12,993.954 1848.1,993.933 1848.08,993.912 1848.06,993.891 1848.04,993.87 1848.03,993.849 1848.01,993.828 1847.99,993.807 1847.97,993.786 1847.96,993.765 1847.94,993.744 1847.92,993.723 1847.9,993.702 1847.89,993.681 1847.87,993.661 1847.85,993.64 1847.83,993.619 1847.81,993.598 1847.8,993.577 1847.78,993.556 1847.76,993.535 1847.74,993.514 1847.73,993.493 1847.71,993.472 1847.69,993.452 1847.67,993.431 1847.65,993.41 1847.64,993.389 1847.62,993.368 1847.6,993.347 1847.58,993.326 1847.57,993.305 1847.55,993.285 1847.53,993.264 1847.51,993.243 1847.5,993.222 1847.48,993.201 1847.46,993.18 1847.44,993.159 1847.42,993.139 1847.41,993.118 1847.39,993.097 1847.37,993.076 1847.35,993.055 1847.33,993.035 1847.32,993.014 1847.3,992.993 1847.28,992.972 1847.26,992.951 1847.25,992.931 1847.23,992.91 1847.21,992.889 1847.19,992.868 1847.17,992.847 1847.16,992.827 1847.14,992.806 1847.12,992.785 1847.1,992.764 1847.09,992.744 1847.07,992.723 1847.05,992.702 1847.03,992.681 1847.01,992.661 1847,992.64 1846.98,992.619 1846.96,992.598 1846.94,992.578 1846.92,992.557 1846.91,992.536 1846.89,992.516 1846.87,992.495 1846.85,992.474 1846.84,992.453 1846.82,992.433 1846.8,992.412 1846.78,992.391 1846.76,992.371 1846.75,992.35 1846.73,992.329 1846.71,992.309 1846.69,992.288 1846.67,992.267 1846.66,992.247 1846.64,992.226 1846.62,992.205 1846.6,992.185 1846.58,992.164 1846.57,992.143 1846.55,992.123 1846.53,992.102 1846.51,992.081 1846.5,992.061 1846.48,992.04 1846.46,992.019 1846.44,991.999 1846.42,991.978 1846.41,991.958 1846.39,991.937 1846.37,991.916 1846.35,991.896 1846.33,991.875 1846.32,991.855 1846.3,991.834 1846.28,991.813 1846.26,991.793 1846.24,991.772 1846.23,991.752 1846.21,991.731 1846.19,991.711 1846.17,991.69 1846.15,991.669 1846.14,991.649 1846.12,991.628 1846.1,991.608 1846.08,991.587 1846.06,991.567 1846.05,991.546 1846.03,991.526 1846.01,991.505 1845.99,991.485 1845.97,991.464 1845.96,991.443 1845.94,991.423 1845.92,991.402 1845.9,991.382 1845.88,991.361 1845.87,991.341 1845.85,991.32 1845.83,991.3 1845.81,991.279 1845.79,991.259 1845.78,991.238 1845.76,991.218 1845.74,991.198 1845.72,991.177 1845.7,991.157 1845.69,991.136 1845.67,991.116 1845.65,991.095 1845.63,991.075 1845.61,991.054 1845.59,991.034 1845.58,991.013 1845.56,990.993 1845.54,990.973 1845.52,990.952 1845.5,990.932 1845.49,990.911 1845.47,990.891 1845.45,990.87 1845.43,990.85 1845.41,990.83 1845.4,990.809 1845.38,990.789 1845.36,990.768 1845.34,990.748 1845.32,990.728 1845.31,990.707 1845.29,990.687 1845.27,990.666 1845.25,990.646 1845.23,990.626 1845.21,990.605 1845.2,990.585 1845.18,990.565 1845.16,990.544 1845.14,990.524 1845.12,990.504 1845.11,990.483 1845.09,990.463 1845.07,990.443 1845.05,990.422 1845.03,990.402 1845.02,990.382 1845,990.361 1844.98,990.341 1844.96,990.321 1844.94,990.3 1844.92,990.28 1844.91,990.26 1844.89,990.239 1844.87,990.219 1844.85,990.199 1844.83,990.178 1844.82,990.158 1844.8,990.138 1844.78,990.118 1844.76,990.097 1844.74,990.077 1844.72,990.057 1844.71,990.037 1844.69,990.016 1844.67,989.996 1844.65,989.976 1844.63,989.956 1844.62,989.935 1844.6,989.915 1844.58,989.895 1844.56,989.875 1844.54,989.854 1844.52,989.834 1844.51,989.814 1844.49,989.794 1844.47,989.774 1844.45,989.753 1844.43,989.733 1844.41,989.713 1844.4,989.693 1844.38,989.672 1844.36,989.652 1844.34,989.632 1844.32,989.612 1844.31,989.592 1844.29,989.572 1844.27,989.551 1844.25,989.531 1844.23,989.511 1844.21,989.491 1844.2,989.471 1844.18,989.451 1844.16,989.43 1844.14,989.41 1844.12,989.39 1844.1,989.37 1844.09,989.35 1844.07,989.33 1844.05,989.31 1844.03,989.289 1844.01,989.269 1843.99,989.249 1843.98,989.229 1843.96,989.209 1843.94,989.189 1843.92,989.169 1843.9,989.149 1843.88,989.129 1843.87,989.108 1843.85,989.088 1843.83,989.068 1843.81,989.048 1843.79,989.028 1843.77,989.008 1843.76,988.988 1843.74,988.968 1843.72,988.948 1843.7,988.928 1843.68,988.908 1843.66,988.888 1843.65,988.868 1843.63,988.848 1843.61,988.828 1843.59,988.808 1843.57,988.788 1843.55,988.767 1843.54,988.747 1843.52,988.727 1843.5,988.707 1843.48,988.687 1843.46,988.667 1843.44,988.647 1843.43,988.627 1843.41,988.607 1843.39,988.587 1843.37,988.567 1843.35,988.547 1843.33,988.527 1843.32,988.507 1843.3,988.487 1843.28,988.467 1843.26,988.447 1843.24,988.428 1843.22,988.408 1843.21,988.388 1843.19,988.368 1843.17,988.348 1843.15,988.328 1843.13,988.308 1843.11,988.288 1843.09,988.268 1843.08,988.248 1843.06,988.228 1843.04,988.208 1843.02,988.188 1843,988.168 1842.98,988.148 1842.97,988.128 1842.95,988.109 1842.93,988.089 1842.91,988.069 1842.89,988.049 1842.87,988.029 1842.85,988.009 1842.84,987.989 1842.82,987.969 1842.8,987.949 1842.78,987.929 1842.76,987.91 1842.74,987.89 1842.73,987.87 1842.71,987.85 1842.69,987.83 1842.67,987.81 1842.65,987.79 1842.63,987.771 1842.61,987.751 1842.6,987.731 1842.58,987.711 1842.56,987.691 1842.54,987.671 1842.52,987.652 1842.5,987.632 1842.49,987.612 1842.47,987.592 1842.45,987.572 1842.43,987.553 1842.41,987.533 1842.39,987.513 1842.37,987.493 1842.36,987.473 1842.34,987.454 1842.32,987.434 1842.3,987.414 1842.28,987.394 1842.26,987.374 1842.24,987.355 1842.23,987.335 1842.21,987.315 1842.19,987.295 1842.17,987.276 1842.15,987.256 1842.13,987.236 1842.11,987.216 1842.1,987.197 1842.08,987.177 1842.06,987.157 1842.04,987.137 1842.02,987.118 1842,987.098 1841.98,987.078 1841.97,987.059 1841.95,987.039 1841.93,987.019 1841.91,986.999 1841.89,986.98 1841.87,986.96 1841.85,986.94 1841.84,986.921 1841.82,986.901 1841.8,986.881 1841.78,986.862 1841.76,986.842 1841.74,986.822 1841.72,986.803 1841.71,986.783 1841.69,986.763 1841.67,986.744 1841.65,986.724 1841.63,986.704 1841.61,986.685 1841.59,986.665 1841.58,986.645 1841.56,986.626 1841.54,986.606 1841.52,986.586 1841.5,986.567 1841.48,986.547 1841.46,986.527 1841.45,986.508 1841.43,986.488 1841.41,986.469 1841.39,986.449 1841.37,986.429 1841.35,986.41 1841.33,986.39 1841.31,986.371 1841.3,986.351 1841.28,986.331 1841.26,986.312 1841.24,986.292 1841.22,986.273 1841.2,986.253 1841.18,986.234 1841.17,986.214 1841.15,986.194 1841.13,986.175 1841.11,986.155 1841.09,986.136 1841.07,986.116 1841.05,986.097 1841.03,986.077 1841.02,986.058 1841,986.038 1840.98,986.019 1840.96,985.999 1840.94,985.98 1840.92,985.96 1840.9,985.941 1840.89,985.921 1840.87,985.902 1840.85,985.882 1840.83,985.863 1840.81,985.843 1840.79,985.824 1840.77,985.804 1840.75,985.785 1840.74,985.765 1840.72,985.746 1840.7,985.726 1840.68,985.707 1840.66,985.687 1840.64,985.668 1840.62,985.648 1840.6,985.629 1840.59,985.609 1840.57,985.59 1840.55,985.57 1840.53,985.551 1840.51,985.532 1840.49,985.512 1840.47,985.493 1840.45,985.473 1840.44,985.454 1840.42,985.434 1840.4,985.415 1840.38,985.396 1840.36,985.376 1840.34,985.357 1840.32,985.337 1840.3,985.318 1840.29,985.299 1840.27,985.279 1840.25,985.26 1840.23,985.24 1840.21,985.221 1840.19,985.202 1840.17,985.182 1840.15,985.163 1840.14,985.144 1840.12,985.124 1840.1,985.105 1840.08,985.086 1840.06,985.066 1840.04,985.047 1840.02,985.027 1840,985.008 1839.98,984.989 1839.97,984.969 1839.95,984.95 1839.93,984.931 1839.91,984.911 1839.89,984.892 1839.87,984.873 1839.85,984.854 1839.83,984.834 1839.82,984.815 1839.8,984.796 1839.78,984.776 1839.76,984.757 1839.74,984.738 1839.72,984.718 1839.7,984.699 1839.68,984.68 1839.66,984.661 1839.65,984.641 1839.63,984.622 1839.61,984.603 1839.59,984.584 1839.57,984.564 1839.55,984.545 1839.53,984.526 1839.51,984.506 1839.49,984.487 1839.48,984.468 1839.46,984.449 1839.44,984.43 1839.42,984.41 1839.4,984.391 1839.38,984.372 1839.36,984.353 1839.34,984.333 1839.32,984.314 1839.31,984.295 1839.29,984.276 1839.27,984.257 1839.25,984.237 1839.23,984.218 1839.21,984.199 1839.19,984.18 1839.17,984.161 1839.15,984.141 1839.14,984.122 1839.12,984.103 1839.1,984.084 1839.08,984.065 1839.06,984.046 1839.04,984.026 1839.02,984.007 1839,983.988 1838.98,983.969 1838.97,983.95 1838.95,983.931 1838.93,983.911 1838.91,983.892 1838.89,983.873 1838.87,983.854 1838.85,983.835 1838.83,983.816 1838.81,983.797 1838.8,983.778 1838.78,983.758 1838.76,983.739 1838.74,983.72 1838.72,983.701 1838.7,983.682 1838.68,983.663 1838.66,983.644 1838.64,983.625 1838.62,983.606 1838.61,983.587 1838.59,983.568 1838.57,983.548 1838.55,983.529 1838.53,983.51 1838.51,983.491 1838.49,983.472 1838.47,983.453 1838.45,983.434 1838.43,983.415 1838.42,983.396 1838.4,983.377 1838.38,983.358 1838.36,983.339 1838.34,983.32 1838.32,983.301 1838.3,983.282 1838.28,983.263 1838.26,983.244 1838.24,983.225 1838.23,983.206 1838.21,983.187 1838.19,983.168 1838.17,983.149 1838.15,983.13 1838.13,983.111 1838.11,983.092 1838.09,983.073 1838.07,983.054 1838.05,983.035 1838.04,983.016 1838.02,982.997 1838,982.978 1837.98,982.959 1837.96,982.94 1837.94,982.921 1837.92,982.902 1837.9,982.883 1837.88,982.864 1837.86,982.845 1837.85,982.826 1837.83,982.807 1837.81,982.788 1837.79,982.769 1837.77,982.75 1837.75,982.732 1837.73,982.713 1837.71,982.694 1837.69,982.675 1837.67,982.656 1837.65,982.637 1837.64,982.618 1837.62,982.599 1837.6,982.58 1837.58,982.561 1837.56,982.542 1837.54,982.524 1837.52,982.505 1837.5,982.486 1837.48,982.467 1837.46,982.448 1837.44,982.429 1837.43,982.41 1837.41,982.391 1837.39,982.373 1837.37,982.354 1837.35,982.335 1837.33,982.316 1837.31,982.297 1837.29,982.278 1837.27,982.26 1837.25,982.241 1837.23,982.222 1837.22,982.203 1837.2,982.184 1837.18,982.165 1837.16,982.147 1837.14,982.128 1837.12,982.109 1837.1,982.09 1837.08,982.071 1837.06,982.053 1837.04,982.034 1837.02,982.015 1837,981.996 1836.99,981.977 1836.97,981.959 1836.95,981.94 1836.93,981.921 1836.91,981.902 1836.89,981.884 1836.87,981.865 1836.85,981.846 1836.83,981.827 1836.81,981.808 1836.79,981.79 1836.78,981.771 1836.76,981.752 1836.74,981.733 1836.72,981.715 1836.7,981.696 1836.68,981.677 1836.66,981.659 1836.64,981.64 1836.62,981.621 1836.6,981.602 1836.58,981.584 1836.56,981.565 1836.54,981.546 1836.53,981.528 1836.51,981.509 1836.49,981.49 1836.47,981.471 1836.45,981.453 1836.43,981.434 1836.41,981.415 1836.39,981.397 1836.37,981.378 1836.35,981.359 1836.33,981.341 1836.31,981.322 1836.3,981.303 1836.28,981.285 1836.26,981.266 1836.24,981.247 1836.22,981.229 1836.2,981.21 1836.18,981.191 1836.16,981.173 1836.14,981.154 1836.12,981.136 1836.1,981.117 1836.08,981.098 1836.06,981.08 1836.05,981.061 1836.03,981.042 1836.01,981.024 1835.99,981.005 1835.97,980.987 1835.95,980.968 1835.93,980.949 1835.91,980.931 1835.89,980.912 1835.87,980.894 1835.85,980.875 1835.83,980.856 1835.81,980.838 1835.8,980.819 1835.78,980.801 1835.76,980.782 1835.74,980.764 1835.72,980.745 1835.7,980.726 1835.68,980.708 1835.66,980.689 1835.64,980.671 1835.62,980.652 1835.6,980.634 1835.58,980.615 1835.56,980.597 1835.54,980.578 1835.53,980.56 1835.51,980.541 1835.49,980.523 1835.47,980.504 1835.45,980.486 1835.43,980.467 1835.41,980.449 1835.39,980.43 1835.37,980.412 1835.35,980.393 1835.33,980.375 1835.31,980.356 1835.29,980.338 1835.27,980.319 1835.26,980.301 1835.24,980.282 1835.22,980.264 1835.2,980.245 1835.18,980.227 1835.16,980.208 1835.14,980.19 1835.12,980.171 1835.1,980.153 1835.08,980.134 1835.06,980.116 1835.04,980.098 1835.02,980.079 1835,980.061 1834.98,980.042 1834.97,980.024 1834.95,980.005 1834.93,979.987 1834.91,979.969 1834.89,979.95 1834.87,979.932 1834.85,979.913 1834.83,979.895 1834.81,979.876 1834.79,979.858 1834.77,979.84 1834.75,979.821 1834.73,979.803 1834.71,979.785 1834.69,979.766 1834.67,979.748 1834.66,979.729 1834.64,979.711 1834.62,979.693 1834.6,979.674 1834.58,979.656 1834.56,979.638 1834.54,979.619 1834.52,979.601 1834.5,979.582 1834.48,979.564 1834.46,979.546 1834.44,979.527 1834.42,979.509 1834.4,979.491 1834.38,979.472 1834.36,979.454 1834.35,979.436 1834.33,979.418 1834.31,979.399 1834.29,979.381 1834.27,979.363 1834.25,979.344 1834.23,979.326 1834.21,979.308 1834.19,979.289 1834.17,979.271 1834.15,979.253 1834.13,979.235 1834.11,979.216 1834.09,979.198 1834.07,979.18 1834.05,979.161 1834.03,979.143 1834.02,979.125 1834,979.107 1833.98,979.088 1833.96,979.07 1833.94,979.052 1833.92,979.034 1833.9,979.015 1833.88,978.997 1833.86,978.979 1833.84,978.961 1833.82,978.942 1833.8,978.924 1833.78,978.906 1833.76,978.888 1833.74,978.87 1833.72,978.851 1833.7,978.833 1833.68,978.815 1833.67,978.797 1833.65,978.778 1833.63,978.76 1833.61,978.742 1833.59,978.724 1833.57,978.706 1833.55,978.688 1833.53,978.669 1833.51,978.651 1833.49,978.633 1833.47,978.615 1833.45,978.597 1833.43,978.578 1833.41,978.56 1833.39,978.542 1833.37,978.524 1833.35,978.506 1833.33,978.488 1833.31,978.47 1833.3,978.451 1833.28,978.433 1833.26,978.415 1833.24,978.397 1833.22,978.379 1833.2,978.361 1833.18,978.343 1833.16,978.325 1833.14,978.306 1833.12,978.288 1833.1,978.27 1833.08,978.252 1833.06,978.234 1833.04,978.216 1833.02,978.198 1833,978.18 1832.98,978.162 1832.96,978.144 1832.94,978.125 1832.92,978.107 1832.91,978.089 1832.89,978.071 1832.87,978.053 1832.85,978.035 1832.83,978.017 1832.81,977.999 1832.79,977.981 1832.77,977.963 1832.75,977.945 1832.73,977.927 1832.71,977.909 1832.69,977.891 1832.67,977.873 1832.65,977.855 1832.63,977.837 1832.61,977.819 1832.59,977.801 1832.57,977.783 1832.55,977.764 1832.53,977.746 1832.51,977.728 1832.49,977.71 1832.48,977.692 1832.46,977.674 1832.44,977.656 1832.42,977.638 1832.4,977.62 1832.38,977.602 1832.36,977.585 1832.34,977.567 1832.32,977.549 1832.3,977.531 1832.28,977.513 1832.26,977.495 1832.24,977.477 1832.22,977.459 1832.2,977.441 1832.18,977.423 1832.16,977.405 1832.14,977.387 1832.12,977.369 1832.1,977.351 1832.08,977.333 1832.06,977.315 1832.04,977.297 1832.02,977.279 1832.01,977.261 1831.99,977.243 1831.97,977.226 1831.95,977.208 1831.93,977.19 1831.91,977.172 1831.89,977.154 1831.87,977.136 1831.85,977.118 1831.83,977.1 1831.81,977.082 1831.79,977.064 1831.77,977.047 1831.75,977.029 1831.73,977.011 1831.71,976.993 1831.69,976.975 1831.67,976.957 1831.65,976.939 1831.63,976.921 1831.61,976.904 1831.59,976.886 1831.57,976.868 1831.55,976.85 1831.53,976.832 1831.51,976.814 1831.5,976.796 1831.48,976.779 1831.46,976.761 1831.44,976.743 1831.42,976.725 1831.4,976.707 1831.38,976.69 1831.36,976.672 1831.34,976.654 1831.32,976.636 1831.3,976.618 1831.28,976.6 1831.26,976.583 1831.24,976.565 1831.22,976.547 1831.2,976.529 1831.18,976.512 1831.16,976.494 1831.14,976.476 1831.12,976.458 1831.1,976.44 1831.08,976.423 1831.06,976.405 1831.04,976.387 1831.02,976.369 1831,976.352 1830.98,976.334 1830.96,976.316 1830.94,976.298 1830.92,976.281 1830.91,976.263 1830.89,976.245 1830.87,976.227 1830.85,976.21 1830.83,976.192 1830.81,976.174 1830.79,976.156 1830.77,976.139 1830.75,976.121 1830.73,976.103 1830.71,976.086 1830.69,976.068 1830.67,976.05 1830.65,976.032 1830.63,976.015 1830.61,975.997 1830.59,975.979 1830.57,975.962 1830.55,975.944 1830.53,975.926 1830.51,975.909 1830.49,975.891 1830.47,975.873 1830.45,975.856 1830.43,975.838 1830.41,975.82 1830.39,975.803 1830.37,975.785 1830.35,975.767 1830.33,975.75 1830.31,975.732 1830.29,975.714 1830.27,975.697 1830.25,975.679 1830.23,975.662 1830.22,975.644 1830.2,975.626 1830.18,975.609 1830.16,975.591 1830.14,975.573 1830.12,975.556 1830.1,975.538 1830.08,975.521 1830.06,975.503 1830.04,975.485 1830.02,975.468 1830,975.45 1829.98,975.433 1829.96,975.415 1829.94,975.397 1829.92,975.38 1829.9,975.362 1829.88,975.345 1829.86,975.327 1829.84,975.31 1829.82,975.292 1829.8,975.274 1829.78,975.257 1829.76,975.239 1829.74,975.222 1829.72,975.204 1829.7,975.187 1829.68,975.169 1829.66,975.152 1829.64,975.134 1829.62,975.117 1829.6,975.099 1829.58,975.081 1829.56,975.064 1829.54,975.046 1829.52,975.029 1829.5,975.011 1829.48,974.994 1829.46,974.976 1829.44,974.959 1829.42,974.941 1829.4,974.924 1829.38,974.906 1829.36,974.889 1829.35,974.871 1829.33,974.854 1829.31,974.836 1829.29,974.819 1829.27,974.802 1829.25,974.784 1829.23,974.767 1829.21,974.749 1829.19,974.732 1829.17,974.714 1829.15,974.697 1829.13,974.679 1829.11,974.662 1829.09,974.644 1829.07,974.627 1829.05,974.61 1829.03,974.592 1829.01,974.575 1828.99,974.557 1828.97,974.54 1828.95,974.522 1828.93,974.505 1828.91,974.488 1828.89,974.47 1828.87,974.453 1828.85,974.435 1828.83,974.418 1828.81,974.4 1828.79,974.383 1828.77,974.366 1828.75,974.348 1828.73,974.331 1828.71,974.314 1828.69,974.296 1828.67,974.279 1828.65,974.261 1828.63,974.244 1828.61,974.227 1828.59,974.209 1828.57,974.192 1828.55,974.175 1828.53,974.157 1828.51,974.14 1828.49,974.122 1828.47,974.105 1828.45,974.088 1828.43,974.07 1828.41,974.053 1828.39,974.036 1828.37,974.018 1828.35,974.001 1828.33,973.984 1828.31,973.966 1828.29,973.949 1828.27,973.932 1828.25,973.915 1828.23,973.897 1828.21,973.88 1828.19,973.863 1828.17,973.845 1828.15,973.828 1828.13,973.811 1828.11,973.793 1828.09,973.776 1828.07,973.759 1828.05,973.742 1828.03,973.724 1828.01,973.707 1828,973.69 1827.98,973.672 1827.96,973.655 1827.94,973.638 1827.92,973.621 1827.9,973.603 1827.88,973.586 1827.86,973.569 1827.84,973.552 1827.82,973.534 1827.8,973.517 1827.78,973.5 1827.76,973.483 1827.74,973.465 1827.72,973.448 1827.7,973.431 1827.68,973.414 1827.66,973.397 1827.64,973.379 1827.62,973.362 1827.6,973.345 1827.58,973.328 1827.56,973.311 1827.54,973.293 1827.52,973.276 1827.5,973.259 1827.48,973.242 1827.46,973.225 1827.44,973.207 1827.42,973.19 1827.4,973.173 1827.38,973.156 1827.36,973.139 1827.34,973.122 1827.32,973.104 1827.3,973.087 1827.28,973.07 1827.26,973.053 1827.24,973.036 1827.22,973.019 1827.2,973.001 1827.18,972.984 1827.16,972.967 1827.14,972.95 1827.12,972.933 1827.1,972.916 1827.08,972.899 1827.06,972.881 1827.04,972.864 1827.02,972.847 1827,972.83 1826.98,972.813 1826.96,972.796 1826.94,972.779 1826.92,972.762 1826.9,972.745 1826.88,972.728 1826.86,972.71 1826.84,972.693 1826.82,972.676 1826.8,972.659 1826.78,972.642 1826.76,972.625 1826.74,972.608 1826.72,972.591 1826.7,972.574 1826.68,972.557 1826.66,972.54 1826.64,972.523 1826.62,972.506 1826.6,972.488 1826.58,972.471 1826.56,972.454 1826.54,972.437 1826.52,972.42 1826.5,972.403 1826.48,972.386 1826.46,972.369 1826.44,972.352 1826.42,972.335 1826.4,972.318 1826.38,972.301 1826.36,972.284 1826.34,972.267 1826.32,972.25 1826.3,972.233 1826.28,972.216 1826.26,972.199 1826.24,972.182 1826.22,972.165 1826.2,972.148 1826.18,972.131 1826.16,972.114 1826.14,972.097 1826.12,972.08 1826.1,972.063 1826.08,972.046 1826.06,972.029 1826.04,972.012 1826.02,971.995 1826,971.978 1825.98,971.961 1825.96,971.944 1825.94,971.927 1825.92,971.911 1825.9,971.894 1825.88,971.877 1825.86,971.86 1825.84,971.843 1825.82,971.826 1825.8,971.809 1825.78,971.792 1825.76,971.775 1825.74,971.758 1825.72,971.741 1825.7,971.724 1825.68,971.707 1825.66,971.69 1825.64,971.674 1825.62,971.657 1825.6,971.64 1825.58,971.623 1825.56,971.606 1825.54,971.589 1825.52,971.572 1825.5,971.555 1825.48,971.538 1825.46,971.522 1825.44,971.505 1825.42,971.488 1825.4,971.471 1825.38,971.454 1825.36,971.437 1825.34,971.42 1825.32,971.404 1825.3,971.387 1825.28,971.37 1825.26,971.353 1825.24,971.336 1825.22,971.319 1825.2,971.302 1825.18,971.286 1825.16,971.269 1825.14,971.252 1825.12,971.235 1825.1,971.218 1825.08,971.201 1825.06,971.185 1825.04,971.168 1825.02,971.151 1825,971.134 1824.98,971.117 1824.96,971.101 1824.94,971.084 1824.92,971.067 1824.9,971.05 1824.87,971.033 1824.85,971.017 1824.83,971 1824.81,970.983 1824.79,970.966 1824.77,970.95 1824.75,970.933 1824.73,970.916 1824.71,970.899 1824.69,970.882 1824.67,970.866 1824.65,970.849 1824.63,970.832 1824.61,970.815 1824.59,970.799 1824.57,970.782 1824.55,970.765 1824.53,970.749 1824.51,970.732 1824.49,970.715 1824.47,970.698 1824.45,970.682 1824.43,970.665 1824.41,970.648 1824.39,970.631 1824.37,970.615 1824.35,970.598 1824.33,970.581 1824.31,970.565 1824.29,970.548 1824.27,970.531 1824.25,970.515 1824.23,970.498 1824.21,970.481 1824.19,970.464 1824.17,970.448 1824.15,970.431 1824.13,970.414 1824.11,970.398 1824.09,970.381 1824.07,970.364 1824.05,970.348 1824.03,970.331 1824.01,970.314 1823.99,970.298 1823.97,970.281 1823.95,970.264 1823.93,970.248 1823.91,970.231 1823.89,970.215 1823.87,970.198 1823.85,970.181 1823.83,970.165 1823.81,970.148 1823.79,970.131 1823.77,970.115 1823.75,970.098 1823.73,970.082 1823.71,970.065 1823.69,970.048 1823.67,970.032 1823.65,970.015 1823.63,969.999 1823.61,969.982 1823.59,969.965 1823.57,969.949 1823.55,969.932 1823.53,969.916 1823.51,969.899 1823.49,969.882 1823.47,969.866 1823.45,969.849 1823.43,969.833 1823.4,969.816 1823.38,969.8 1823.36,969.783 1823.34,969.766 1823.32,969.75 1823.3,969.733 1823.28,969.717 1823.26,969.7 1823.24,969.684 1823.22,969.667 1823.2,969.651 1823.18,969.634 1823.16,969.618 1823.14,969.601 1823.12,969.584 1823.1,969.568 1823.08,969.551 1823.06,969.535 1823.04,969.518 1823.02,969.502 1823,969.485 1822.98,969.469 1822.96,969.452 1822.94,969.436 1822.92,969.419 1822.9,969.403 1822.88,969.386 1822.86,969.37 1822.84,969.353 1822.82,969.337 1822.8,969.321 1822.78,969.304 1822.76,969.288 1822.74,969.271 1822.72,969.255 1822.7,969.238 1822.68,969.222 1822.66,969.205 1822.64,969.189 1822.62,969.172 1822.6,969.156 1822.58,969.139 1822.56,969.123 1822.54,969.107 1822.52,969.09 1822.5,969.074 1822.48,969.057 1822.46,969.041 1822.44,969.024 1822.41,969.008 1822.39,968.992 1822.37,968.975 1822.35,968.959 1822.33,968.942 1822.31,968.926 1822.29,968.91 1822.27,968.893 1822.25,968.877 1822.23,968.86 1822.21,968.844 1822.19,968.828 1822.17,968.811 1822.15,968.795 1822.13,968.778 1822.11,968.762 1822.09,968.746 1822.07,968.729 1822.05,968.713 1822.03,968.697 1822.01,968.68 1821.99,968.664 1821.97,968.648 1821.95,968.631 1821.93,968.615 1821.91,968.598 1821.89,968.582 1821.87,968.566 1821.85,968.549 1821.83,968.533 1821.81,968.517 1821.79,968.5 1821.77,968.484 1821.75,968.468 1821.73,968.451 1821.71,968.435 1821.69,968.419 1821.67,968.403 1821.65,968.386 1821.63,968.37 1821.6,968.354 1821.58,968.337 1821.56,968.321 1821.54,968.305 1821.52,968.288 1821.5,968.272 1821.48,968.256 1821.46,968.24 1821.44,968.223 1821.42,968.207 1821.4,968.191 1821.38,968.175 1821.36,968.158 1821.34,968.142 1821.32,968.126 1821.3,968.109 1821.28,968.093 1821.26,968.077 1821.24,968.061 1821.22,968.044 1821.2,968.028 1821.18,968.012 1821.16,967.996 1821.14,967.98 1821.12,967.963 1821.1,967.947 1821.08,967.931 1821.06,967.915 1821.04,967.898 1821.02,967.882 1821,967.866 1820.98,967.85 1820.96,967.834 1820.94,967.817 1820.92,967.801 1820.89,967.785 1820.87,967.769 1820.85,967.753 1820.83,967.736 1820.81,967.72 1820.79,967.704 1820.77,967.688 1820.75,967.672 1820.73,967.655 1820.71,967.639 1820.69,967.623 1820.67,967.607 1820.65,967.591 1820.63,967.575 1820.61,967.558 1820.59,967.542 1820.57,967.526 1820.55,967.51 1820.53,967.494 1820.51,967.478 1820.49,967.462 1820.47,967.445 1820.45,967.429 1820.43,967.413 1820.41,967.397 1820.39,967.381 1820.37,967.365 1820.35,967.349 1820.33,967.333 1820.31,967.316 1820.29,967.3 1820.26,967.284 1820.24,967.268 1820.22,967.252 1820.2,967.236 1820.18,967.22 1820.16,967.204 1820.14,967.188 1820.12,967.172 1820.1,967.155 1820.08,967.139 1820.06,967.123 1820.04,967.107 1820.02,967.091 1820,967.075 1819.98,967.059 1819.96,967.043 1819.94,967.027 1819.92,967.011 1819.9,966.995 1819.88,966.979 1819.86,966.963 1819.84,966.947 1819.82,966.931 1819.8,966.915 1819.78,966.899 1819.76,966.882 1819.74,966.866 1819.72,966.85 1819.7,966.834 1819.67,966.818 1819.65,966.802 1819.63,966.786 1819.61,966.77 1819.59,966.754 1819.57,966.738 1819.55,966.722 1819.53,966.706 1819.51,966.69 1819.49,966.674 1819.47,966.658 1819.45,966.642 1819.43,966.626 1819.41,966.61 1819.39,966.594 1819.37,966.578 1819.35,966.562 1819.33,966.546 1819.31,966.53 1819.29,966.514 1819.27,966.499 1819.25,966.483 1819.23,966.467 1819.21,966.451 1819.19,966.435 1819.17,966.419 1819.15,966.403 1819.12,966.387 1819.1,966.371 1819.08,966.355 1819.06,966.339 1819.04,966.323 1819.02,966.307 1819,966.291 1818.98,966.275 1818.96,966.259 1818.94,966.243 1818.92,966.228 1818.9,966.212 1818.88,966.196 1818.86,966.18 1818.84,966.164 1818.82,966.148 1818.8,966.132 1818.78,966.116 1818.76,966.1 1818.74,966.084 1818.72,966.069 1818.7,966.053 1818.68,966.037 1818.66,966.021 1818.64,966.005 1818.62,965.989 1818.59,965.973 1818.57,965.957 1818.55,965.942 1818.53,965.926 1818.51,965.91 1818.49,965.894 1818.47,965.878 1818.45,965.862 1818.43,965.846 1818.41,965.831 1818.39,965.815 1818.37,965.799 1818.35,965.783 1818.33,965.767 1818.31,965.751 1818.29,965.736 1818.27,965.72 1818.25,965.704 1818.23,965.688 1818.21,965.672 1818.19,965.656 1818.17,965.641 1818.15,965.625 1818.13,965.609 1818.1,965.593 1818.08,965.577 1818.06,965.562 1818.04,965.546 1818.02,965.53 1818,965.514 1817.98,965.498 1817.96,965.483 1817.94,965.467 1817.92,965.451 1817.9,965.435 1817.88,965.42 1817.86,965.404 1817.84,965.388 1817.82,965.372 1817.8,965.357 1817.78,965.341 1817.76,965.325 1817.74,965.309 1817.72,965.294 1817.7,965.278 1817.68,965.262 1817.66,965.246 1817.63,965.231 1817.61,965.215 1817.59,965.199 1817.57,965.183 1817.55,965.168 1817.53,965.152 1817.51,965.136 1817.49,965.12 1817.47,965.105 1817.45,965.089 1817.43,965.073 1817.41,965.058 1817.39,965.042 1817.37,965.026 1817.35,965.011 1817.33,964.995 1817.31,964.979 1817.29,964.963 1817.27,964.948 1817.25,964.932 1817.23,964.916 1817.21,964.901 1817.18,964.885 1817.16,964.869 1817.14,964.854 1817.12,964.838 1817.1,964.822 1817.08,964.807 1817.06,964.791 1817.04,964.775 1817.02,964.76 1817,964.744 1816.98,964.728 1816.96,964.713 1816.94,964.697 1816.92,964.682 1816.9,964.666 1816.88,964.65 1816.86,964.635 1816.84,964.619 1816.82,964.603 1816.8,964.588 1816.78,964.572 1816.76,964.557 1816.73,964.541 1816.71,964.525 1816.69,964.51 1816.67,964.494 1816.65,964.479 1816.63,964.463 1816.61,964.447 1816.59,964.432 1816.57,964.416 1816.55,964.401 1816.53,964.385 1816.51,964.369 1816.49,964.354 1816.47,964.338 1816.45,964.323 1816.43,964.307 1816.41,964.292 1816.39,964.276 1816.37,964.26 1816.35,964.245 1816.32,964.229 1816.3,964.214 1816.28,964.198 1816.26,964.183 1816.24,964.167 1816.22,964.152 1816.2,964.136 1816.18,964.12 1816.16,964.105 1816.14,964.089 1816.12,964.074 1816.1,964.058 1816.08,964.043 1816.06,964.027 1816.04,964.012 1816.02,963.996 1816,963.981 1815.98,963.965 1815.96,963.95 1815.94,963.934 1815.91,963.919 1815.89,963.903 1815.87,963.888 1815.85,963.872 1815.83,963.857 1815.81,963.841 1815.79,963.826 1815.77,963.81 1815.75,963.795 1815.73,963.779 1815.71,963.764 1815.69,963.748 1815.67,963.733 1815.65,963.718 1815.63,963.702 1815.61,963.687 1815.59,963.671 1815.57,963.656 1815.55,963.64 1815.53,963.625 1815.5,963.609 1815.48,963.594 1815.46,963.578 1815.44,963.563 1815.42,963.548 1815.4,963.532 1815.38,963.517 1815.36,963.501 1815.34,963.486 1815.32,963.47 1815.3,963.455 1815.28,963.44 1815.26,963.424 1815.24,963.409 1815.22,963.393 1815.2,963.378 1815.18,963.363 1815.16,963.347 1815.14,963.332 1815.11,963.316 1815.09,963.301 1815.07,963.286 1815.05,963.27 1815.03,963.255 1815.01,963.24 1814.99,963.224 1814.97,963.209 1814.95,963.193 1814.93,963.178 1814.91,963.163 1814.89,963.147 1814.87,963.132 1814.85,963.117 1814.83,963.101 1814.81,963.086 1814.79,963.071 1814.77,963.055 1814.75,963.04 1814.72,963.025 1814.7,963.009 1814.68,962.994 1814.66,962.979 1814.64,962.963 1814.62,962.948 1814.6,962.933 1814.58,962.917 1814.56,962.902 1814.54,962.887 1814.52,962.871 1814.5,962.856 1814.48,962.841 1814.46,962.825 1814.44,962.81 1814.42,962.795 1814.4,962.78 1814.38,962.764 1814.35,962.749 1814.33,962.734 1814.31,962.718 1814.29,962.703 1814.27,962.688 1814.25,962.673 1814.23,962.657 1814.21,962.642 1814.19,962.627 1814.17,962.611 1814.15,962.596 1814.13,962.581 1814.11,962.566 1814.09,962.55 1814.07,962.535 1814.05,962.52 1814.03,962.505 1814.01,962.489 1813.98,962.474 1813.96,962.459 1813.94,962.444 1813.92,962.428 1813.9,962.413 1813.88,962.398 1813.86,962.383 1813.84,962.368 1813.82,962.352 1813.8,962.337 1813.78,962.322 1813.76,962.307 1813.74,962.292 1813.72,962.276 1813.7,962.261 1813.68,962.246 1813.66,962.231 1813.63,962.216 1813.61,962.2 1813.59,962.185 1813.57,962.17 1813.55,962.155 1813.53,962.14 1813.51,962.124 1813.49,962.109 1813.47,962.094 1813.45,962.079 1813.43,962.064 1813.41,962.049 1813.39,962.033 1813.37,962.018 1813.35,962.003 1813.33,961.988 1813.31,961.973 1813.29,961.958 1813.26,961.943 1813.24,961.927 1813.22,961.912 1813.2,961.897 1813.18,961.882 1813.16,961.867 1813.14,961.852 1813.12,961.837 1813.1,961.821 1813.08,961.806 1813.06,961.791 1813.04,961.776 1813.02,961.761 1813,961.746 1812.98,961.731 1812.96,961.716 1812.93,961.701 1812.91,961.685 1812.89,961.67 1812.87,961.655 1812.85,961.64 1812.83,961.625 1812.81,961.61 1812.79,961.595 1812.77,961.58 1812.75,961.565 1812.73,961.55 1812.71,961.535 1812.69,961.52 1812.67,961.505 1812.65,961.489 1812.63,961.474 1812.61,961.459 1812.58,961.444 1812.56,961.429 1812.54,961.414 1812.52,961.399 1812.5,961.384 1812.48,961.369 1812.46,961.354 1812.44,961.339 1812.42,961.324 1812.4,961.309 1812.38,961.294 1812.36,961.279 1812.34,961.264 1812.32,961.249 1812.3,961.234 1812.28,961.219 1812.26,961.204 1812.23,961.189 1812.21,961.174 1812.19,961.159 1812.17,961.144 1812.15,961.129 1812.13,961.114 1812.11,961.099 1812.09,961.084 1812.07,961.069 1812.05,961.054 1812.03,961.039 1812.01,961.024 1811.99,961.009 1811.97,960.994 1811.95,960.979 1811.93,960.964 1811.9,960.949 1811.88,960.934 1811.86,960.919 1811.84,960.904 1811.82,960.889 1811.8,960.874 1811.78,960.859 1811.76,960.844 1811.74,960.829 1811.72,960.814 1811.7,960.799 1811.68,960.785 1811.66,960.77 1811.64,960.755 1811.62,960.74 1811.6,960.725 1811.57,960.71 1811.55,960.695 1811.53,960.68 1811.51,960.665 1811.49,960.65 1811.47,960.635 1811.45,960.62 1811.43,960.605 1811.41,960.591 1811.39,960.576 1811.37,960.561 1811.35,960.546 1811.33,960.531 1811.31,960.516 1811.29,960.501 1811.26,960.486 1811.24,960.471 1811.22,960.457 1811.2,960.442 1811.18,960.427 1811.16,960.412 1811.14,960.397 1811.12,960.382 1811.1,960.367 1811.08,960.353 1811.06,960.338 1811.04,960.323 1811.02,960.308 1811,960.293 1810.98,960.278 1810.96,960.263 1810.93,960.249 1810.91,960.234 1810.89,960.219 1810.87,960.204 1810.85,960.189 1810.83,960.174 1810.81,960.16 1810.79,960.145 1810.77,960.13 1810.75,960.115 1810.73,960.1 1810.71,960.086 1810.69,960.071 1810.67,960.056 1810.65,960.041 1810.62,960.026 1810.6,960.011 1810.58,959.997 1810.56,959.982 1810.54,959.967 1810.52,959.952 1810.5,959.938 1810.48,959.923 1810.46,959.908 1810.44,959.893 1810.42,959.878 1810.4,959.864 1810.38,959.849 1810.36,959.834 1810.34,959.819 1810.32,959.805 1810.29,959.79 1810.27,959.775 1810.25,959.76 1810.23,959.746 1810.21,959.731 1810.19,959.716 1810.17,959.701 1810.15,959.687 1810.13,959.672 1810.11,959.657 1810.09,959.642 1810.07,959.628 1810.05,959.613 1810.03,959.598 1810.01,959.583 1809.98,959.569 1809.96,959.554 1809.94,959.539 1809.92,959.525 1809.9,959.51 1809.88,959.495 1809.86,959.481 1809.84,959.466 1809.82,959.451 1809.8,959.436 1809.78,959.422 1809.76,959.407 1809.74,959.392 1809.72,959.378 1809.7,959.363 1809.67,959.348 1809.65,959.334 1809.63,959.319 1809.61,959.304 1809.59,959.29 1809.57,959.275 1809.55,959.26 1809.53,959.246 1809.51,959.231 1809.49,959.216 1809.47,959.202 1809.45,959.187 1809.43,959.172 1809.41,959.158 1809.38,959.143 1809.36,959.128 1809.34,959.114 1809.32,959.099 1809.3,959.085 1809.28,959.07 1809.26,959.055 1809.24,959.041 1809.22,959.026 1809.2,959.011 1809.18,958.997 1809.16,958.982 1809.14,958.968 1809.12,958.953 1809.1,958.938 1809.07,958.924 1809.05,958.909 1809.03,958.895 1809.01,958.88 1808.99,958.865 1808.97,958.851 1808.95,958.836 1808.93,958.822 1808.91,958.807 1808.89,958.792 1808.87,958.778 1808.85,958.763 1808.83,958.749 1808.81,958.734 1808.79,958.72 1808.76,958.705 1808.74,958.69 1808.72,958.676 1808.7,958.661 1808.68,958.647 1808.66,958.632 1808.64,958.618 1808.62,958.603 1808.6,958.589 1808.58,958.574 1808.56,958.559 1808.54,958.545 1808.52,958.53 1808.5,958.516 1808.47,958.501 1808.45,958.487 1808.43,958.472 1808.41,958.458 1808.39,958.443 1808.37,958.429 1808.35,958.414 1808.33,958.4 1808.31,958.385 1808.29,958.371 1808.27,958.356 1808.25,958.342 1808.23,958.327 1808.21,958.313 1808.18,958.298 1808.16,958.284 1808.14,958.269 1808.12,958.255 1808.1,958.24 1808.08,958.226 1808.06,958.211 1808.04,958.197 1808.02,958.182 1808,958.168 1807.98,958.153 1807.96,958.139 1807.94,958.125 1807.92,958.11 1807.9,958.096 1807.87,958.081 1807.85,958.067 1807.83,958.052 1807.81,958.038 1807.79,958.023 1807.77,958.009 1807.75,957.994 1807.73,957.98 1807.71,957.966 1807.69,957.951 1807.67,957.937 1807.65,957.922 1807.63,957.908 1807.61,957.893 1807.58,957.879 1807.56,957.865 1807.54,957.85 1807.52,957.836 1807.5,957.821 1807.48,957.807 1807.46,957.793 1807.44,957.778 1807.42,957.764 1807.4,957.749 1807.38,957.735 1807.36,957.721 1807.34,957.706 1807.32,957.692 1807.29,957.678 1807.27,957.663 1807.25,957.649 1807.23,957.634 1807.21,957.62 1807.19,957.606 1807.17,957.591 1807.15,957.577 1807.13,957.563 1807.11,957.548 1807.09,957.534 1807.07,957.519 1807.05,957.505 1807.03,957.491 1807,957.476 1806.98,957.462 1806.96,957.448 1806.94,957.433 1806.92,957.419 1806.9,957.405 1806.88,957.39 1806.86,957.376 1806.84,957.362 1806.82,957.347 1806.8,957.333 1806.78,957.319 1806.76,957.304 1806.74,957.29 1806.71,957.276 1806.69,957.262 1806.67,957.247 1806.65,957.233 1806.63,957.219 1806.61,957.204 1806.59,957.19 1806.57,957.176 1806.55,957.161 1806.53,957.147 1806.51,957.133 1806.49,957.119 1806.47,957.104 1806.44,957.09 1806.42,957.076 1806.4,957.062 1806.38,957.047 1806.36,957.033 1806.34,957.019 1806.32,957.004 1806.3,956.99 1806.28,956.976 1806.26,956.962 1806.24,956.947 1806.22,956.933 1806.2,956.919 1806.18,956.905 1806.15,956.89 1806.13,956.876 1806.11,956.862 1806.09,956.848 1806.07,956.834 1806.05,956.819 1806.03,956.805 1806.01,956.791 1805.99,956.777 1805.97,956.762 1805.95,956.748 1805.93,956.734 1805.91,956.72 1805.89,956.706 1805.86,956.691 1805.84,956.677 1805.82,956.663 1805.8,956.649 1805.78,956.635 1805.76,956.62 1805.74,956.606 1805.72,956.592 1805.7,956.578 1805.68,956.564 1805.66,956.549 1805.64,956.535 1805.62,956.521 1805.59,956.507 1805.57,956.493 1805.55,956.479 1805.53,956.464 1805.51,956.45 1805.49,956.436 1805.47,956.422 1805.45,956.408 1805.43,956.394 1805.41,956.379 1805.39,956.365 1805.37,956.351 1805.35,956.337 1805.33,956.323 1805.3,956.309 1805.28,956.295 1805.26,956.28 1805.24,956.266 1805.22,956.252 1805.2,956.238 1805.18,956.224 1805.16,956.21 1805.14,956.196 1805.12,956.182 1805.1,956.167 1805.08,956.153 1805.06,956.139 1805.03,956.125 1805.01,956.111 1804.99,956.097 1804.97,956.083 1804.95,956.069 1804.93,956.055 1804.91,956.041 1804.89,956.026 1804.87,956.012 1804.85,955.998 1804.83,955.984 1804.81,955.97 1804.79,955.956 1804.76,955.942 1804.74,955.928 1804.72,955.914 1804.7,955.9 1804.68,955.886 1804.66,955.872 1804.64,955.858 1804.62,955.844 1804.6,955.83 1804.58,955.815 1804.56,955.801 1804.54,955.787 1804.52,955.773 1804.5,955.759 1804.47,955.745 1804.45,955.731 1804.43,955.717 1804.41,955.703 1804.39,955.689 1804.37,955.675 1804.35,955.661 1804.33,955.647 1804.31,955.633 1804.29,955.619 1804.27,955.605 1804.25,955.591 1804.23,955.577 1804.2,955.563 1804.18,955.549 1804.16,955.535 1804.14,955.521 1804.12,955.507 1804.1,955.493 1804.08,955.479 1804.06,955.465 1804.04,955.451 1804.02,955.437 1804,955.423 1803.98,955.409 1803.96,955.395 1803.93,955.381 1803.91,955.367 1803.89,955.353 1803.87,955.339 1803.85,955.325 1803.83,955.311 1803.81,955.297 1803.79,955.283 1803.77,955.269 1803.75,955.255 1803.73,955.242 1803.71,955.228 1803.69,955.214 1803.66,955.2 1803.64,955.186 1803.62,955.172 1803.6,955.158 1803.58,955.144 1803.56,955.13 1803.54,955.116 1803.52,955.102 1803.5,955.088 1803.48,955.074 1803.46,955.06 1803.44,955.046 1803.42,955.033 1803.39,955.019 1803.37,955.005 1803.35,954.991 1803.33,954.977 1803.31,954.963 1803.29,954.949 1803.27,954.935 1803.25,954.921 1803.23,954.907 1803.21,954.894 1803.19,954.88 1803.17,954.866 1803.15,954.852 1803.12,954.838 1803.1,954.824 1803.08,954.81 1803.06,954.796 1803.04,954.783 1803.02,954.769 1803,954.755 1802.98,954.741 1802.96,954.727 1802.94,954.713 1802.92,954.699 1802.9,954.686 1802.88,954.672 1802.86,954.658 1802.83,954.644 1802.81,954.63 1802.79,954.616 1802.77,954.603 1802.75,954.589 1802.73,954.575 1802.71,954.561 1802.69,954.547 1802.67,954.533 1802.65,954.52 1802.63,954.506 1802.61,954.492 1802.59,954.478 1802.56,954.464 1802.54,954.45 1802.52,954.437 1802.5,954.423 1802.48,954.409 1802.46,954.395 1802.44,954.381 1802.42,954.368 1802.4,954.354 1802.38,954.34 1802.36,954.326 1802.34,954.313 1802.31,954.299 1802.29,954.285 1802.27,954.271 1802.25,954.257 1802.23,954.244 1802.21,954.23 1802.19,954.216 1802.17,954.202 1802.15,954.189 1802.13,954.175 1802.11,954.161 1802.09,954.147 1802.07,954.134 1802.04,954.12 1802.02,954.106 1802,954.092 1801.98,954.079 1801.96,954.065 1801.94,954.051 1801.92,954.037 1801.9,954.024 1801.88,954.01 1801.86,953.996 1801.84,953.982 1801.82,953.969 1801.8,953.955 1801.77,953.941 1801.75,953.928 1801.73,953.914 1801.71,953.9 1801.69,953.886 1801.67,953.873 1801.65,953.859 1801.63,953.845 1801.61,953.832 1801.59,953.818 1801.57,953.804 1801.55,953.79 1801.53,953.777 1801.5,953.763 1801.48,953.749 1801.46,953.736 1801.44,953.722 1801.42,953.708 1801.4,953.695 1801.38,953.681 1801.36,953.667 1801.34,953.654 1801.32,953.64 1801.3,953.626 1801.28,953.613 1801.26,953.599 1801.23,953.585 1801.21,953.572 1801.19,953.558 1801.17,953.544 1801.15,953.531 1801.13,953.517 1801.11,953.503 1801.09,953.49 1801.07,953.476 1801.05,953.463 1801.03,953.449 1801.01,953.435 1800.99,953.422 1800.96,953.408 1800.94,953.394 1800.92,953.381 1800.9,953.367 1800.88,953.354 1800.86,953.34 1800.84,953.326 1800.82,953.313 1800.8,953.299 1800.78,953.286 1800.76,953.272 1800.74,953.258 1800.72,953.245 1800.69,953.231 1800.67,953.218 1800.65,953.204 1800.63,953.19 1800.61,953.177 1800.59,953.163 1800.57,953.15 1800.55,953.136 1800.53,953.122 1800.51,953.109 1800.49,953.095 1800.47,953.082 1800.45,953.068 1800.42,953.055 1800.4,953.041 1800.38,953.028 1800.36,953.014 1800.34,953 1800.32,952.987 1800.3,952.973 1800.28,952.96 1800.26,952.946 1800.24,952.933 1800.22,952.919 1800.2,952.906 1800.17,952.892 1800.15,952.879 1800.13,952.865 1800.11,952.851 1800.09,952.838 1800.07,952.824 1800.05,952.811 1800.03,952.797 1800.01,952.784 1799.99,952.77 1799.97,952.757 1799.95,952.743 1799.93,952.73 1799.9,952.716 1799.88,952.703 1799.86,952.689 1799.84,952.676 1799.82,952.662 1799.8,952.649 1799.78,952.635 1799.76,952.622 1799.74,952.608 1799.72,952.595 1799.7,952.581 1799.68,952.568 1799.66,952.554 1799.63,952.541 1799.61,952.528 1799.59,952.514 1799.57,952.501 1799.55,952.487 1799.53,952.474 1799.51,952.46 1799.49,952.447 1799.47,952.433 1799.45,952.42 1799.43,952.406 1799.41,952.393 1799.39,952.38 1799.36,952.366 1799.34,952.353 1799.32,952.339 1799.3,952.326 1799.28,952.312 1799.26,952.299 1799.24,952.285 1799.22,952.272 1799.2,952.259 1799.18,952.245 1799.16,952.232 1799.14,952.218 1799.11,952.205 1799.09,952.192 1799.07,952.178 1799.05,952.165 1799.03,952.151 1799.01,952.138 1798.99,952.125 1798.97,952.111 1798.95,952.098 1798.93,952.084 1798.91,952.071 1798.89,952.058 1798.87,952.044 1798.84,952.031 1798.82,952.017 1798.8,952.004 1798.78,951.991 1798.76,951.977 1798.74,951.964 1798.72,951.951 1798.7,951.937 1798.68,951.924 1798.66,951.91 1798.64,951.897 1798.62,951.884 1798.6,951.87 1798.57,951.857 1798.55,951.844 1798.53,951.83 1798.51,951.817 1798.49,951.804 1798.47,951.79 1798.45,951.777 1798.43,951.764 1798.41,951.75 1798.39,951.737 1798.37,951.724 1798.35,951.71 1798.33,951.697 1798.3,951.684 1798.28,951.67 1798.26,951.657 1798.24,951.644 1798.22,951.63 1798.2,951.617 1798.18,951.604 1798.16,951.59 1798.14,951.577 1798.12,951.564 1798.1,951.551 1798.08,951.537 1798.05,951.524 1798.03,951.511 1798.01,951.497 1797.99,951.484 1797.97,951.471 1797.95,951.458 1797.93,951.444 1797.91,951.431 1797.89,951.418 1797.87,951.404 1797.85,951.391 1797.83,951.378 1797.81,951.365 1797.78,951.351 1797.76,951.338 1797.74,951.325 1797.72,951.312 1797.7,951.298 1797.68,951.285 1797.66,951.272 1797.64,951.259 1797.62,951.245 1797.6,951.232 1797.58,951.219 1797.56,951.206 1797.54,951.192 1797.51,951.179 1797.49,951.166 1797.47,951.153 1797.45,951.139 1797.43,951.126 1797.41,951.113 1797.39,951.1 1797.37,951.087 1797.35,951.073 1797.33,951.06 1797.31,951.047 1797.29,951.034 1797.26,951.021 1797.24,951.007 1797.22,950.994 1797.2,950.981 1797.18,950.968 1797.16,950.955 1797.14,950.941 1797.12,950.928 1797.1,950.915 1797.08,950.902 1797.06,950.889 1797.04,950.875 1797.02,950.862 1796.99,950.849 1796.97,950.836 1796.95,950.823 1796.93,950.81 1796.91,950.796 1796.89,950.783 1796.87,950.77 1796.85,950.757 1796.83,950.744 1796.81,950.731 1796.79,950.717 1796.77,950.704 1796.75,950.691 1796.72,950.678 1796.7,950.665 1796.68,950.652 1796.66,950.639 1796.64,950.625 1796.62,950.612 1796.6,950.599 1796.58,950.586 1796.56,950.573 1796.54,950.56 1796.52,950.547 1796.5,950.534 1796.48,950.52 1796.45,950.507 1796.43,950.494 1796.41,950.481 1796.39,950.468 1796.37,950.455 1796.35,950.442 1796.33,950.429 1796.31,950.416 1796.29,950.402 1796.27,950.389 1796.25,950.376 1796.23,950.363 1796.2,950.35 1796.18,950.337 1796.16,950.324 1796.14,950.311 1796.12,950.298 1796.1,950.285 1796.08,950.272 1796.06,950.258 1796.04,950.245 1796.02,950.232 1796,950.219 1795.98,950.206 1795.96,950.193 1795.93,950.18 1795.91,950.167 1795.89,950.154 1795.87,950.141 1795.85,950.128 1795.83,950.115 1795.81,950.102 1795.79,950.089 1795.77,950.076 1795.75,950.063 1795.73,950.05 1795.71,950.037 1795.69,950.024 1795.66,950.011 1795.64,949.998 1795.62,949.984 1795.6,949.971 1795.58,949.958 1795.56,949.945 1795.54,949.932 1795.52,949.919 1795.5,949.906 1795.48,949.893 1795.46,949.88 1795.44,949.867 1795.42,949.854 1795.39,949.841 1795.37,949.828 1795.35,949.815 1795.33,949.802 1795.31,949.789 1795.29,949.776 1795.27,949.763 1795.25,949.75 1795.23,949.737 1795.21,949.724 1795.19,949.711 1795.17,949.699 1795.15,949.686 1795.12,949.673 1795.1,949.66 1795.08,949.647 1795.06,949.634 1795.04,949.621 1795.02,949.608 1795,949.595 1794.98,949.582 1794.96,949.569 1794.94,949.556 1794.92,949.543 1794.9,949.53 1794.87,949.517 1794.85,949.504 1794.83,949.491 1794.81,949.478 1794.79,949.465 1794.77,949.452 1794.75,949.439 1794.73,949.427 1794.71,949.414 1794.69,949.401 1794.67,949.388 1794.65,949.375 1794.63,949.362 1794.6,949.349 1794.58,949.336 1794.56,949.323 1794.54,949.31 1794.52,949.297 1794.5,949.284 1794.48,949.272 1794.46,949.259 1794.44,949.246 1794.42,949.233 1794.4,949.22 1794.38,949.207 1794.36,949.194 1794.33,949.181 1794.31,949.168 1794.29,949.156 1794.27,949.143 1794.25,949.13 1794.23,949.117 1794.21,949.104 1794.19,949.091 1794.17,949.078 1794.15,949.065 1794.13,949.053 1794.11,949.04 1794.09,949.027 1794.06,949.014 1794.04,949.001 1794.02,948.988 1794,948.975 1793.98,948.963 1793.96,948.95 1793.94,948.937 1793.92,948.924 1793.9,948.911 1793.88,948.898 1793.86,948.886 1793.84,948.873 1793.82,948.86 1793.79,948.847 1793.77,948.834 1793.75,948.821 1793.73,948.809 1793.71,948.796 1793.69,948.783 1793.67,948.77 1793.65,948.757 1793.63,948.745 1793.61,948.732 1793.59,948.719 1793.57,948.706 1793.55,948.693 1793.52,948.681 1793.5,948.668 1793.48,948.655 1793.46,948.642 1793.44,948.629 1793.42,948.617 1793.4,948.604 1793.38,948.591 1793.36,948.578 1793.34,948.565 1793.32,948.553 1793.3,948.54 1793.28,948.527 1793.25,948.514 1793.23,948.502 1793.21,948.489 1793.19,948.476 1793.17,948.463 1793.15,948.451 1793.13,948.438 1793.11,948.425 1793.09,948.412 1793.07,948.4 1793.05,948.387 1793.03,948.374 1793.01,948.361 1792.98,948.349 1792.96,948.336 1792.94,948.323 1792.92,948.31 1792.9,948.298 1792.88,948.285 1792.86,948.272 1792.84,948.259 1792.82,948.247 1792.8,948.234 1792.78,948.221 1792.76,948.209 1792.74,948.196 1792.71,948.183 1792.69,948.17 1792.67,948.158 1792.65,948.145 1792.63,948.132 1792.61,948.12 1792.59,948.107 1792.57,948.094 1792.55,948.082 1792.53,948.069 1792.51,948.056 1792.49,948.043 1792.47,948.031 1792.44,948.018 1792.42,948.005 1792.4,947.993 1792.38,947.98 1792.36,947.967 1792.34,947.955 1792.32,947.942 1792.3,947.929 1792.28,947.917 1792.26,947.904 1792.24,947.891 1792.22,947.879 1792.2,947.866 1792.17,947.853 1792.15,947.841 1792.13,947.828 1792.11,947.815 1792.09,947.803 1792.07,947.79 1792.05,947.778 1792.03,947.765 1792.01,947.752 1791.99,947.74 1791.97,947.727 1791.95,947.714 1791.93,947.702 1791.91,947.689 1791.88,947.676 1791.86,947.664 1791.84,947.651 1791.82,947.639 1791.8,947.626 1791.78,947.613 1791.76,947.601 1791.74,947.588 1791.72,947.576 1791.7,947.563 1791.68,947.55 1791.66,947.538 1791.64,947.525 1791.61,947.513 1791.59,947.5 1791.57,947.487 1791.55,947.475 1791.53,947.462 1791.51,947.45 1791.49,947.437 1791.47,947.424 1791.45,947.412 1791.43,947.399 1791.41,947.387 1791.39,947.374 1791.37,947.362 1791.34,947.349 1791.32,947.336 1791.3,947.324 1791.28,947.311 1791.26,947.299 1791.24,947.286 1791.22,947.274 1791.2,947.261 1791.18,947.249 1791.16,947.236 1791.14,947.223 1791.12,947.211 1791.1,947.198 1791.07,947.186 1791.05,947.173 1791.03,947.161 1791.01,947.148 1790.99,947.136 1790.97,947.123 1790.95,947.111 1790.93,947.098 1790.91,947.086 1790.89,947.073 1790.87,947.061 1790.85,947.048 1790.83,947.036 1790.81,947.023 1790.78,947.011 1790.76,946.998 1790.74,946.985 1790.72,946.973 1790.7,946.96 1790.68,946.948 1790.66,946.936 1790.64,946.923 1790.62,946.911 1790.6,946.898 1790.58,946.886 1790.56,946.873 1790.54,946.861 1790.51,946.848 1790.49,946.836 1790.47,946.823 1790.45,946.811 1790.43,946.798 1790.41,946.786 1790.39,946.773 1790.37,946.761 1790.35,946.748 1790.33,946.736 1790.31,946.723 1790.29,946.711 1790.27,946.698 1790.25,946.686 1790.22,946.674 1790.2,946.661 1790.18,946.649 1790.16,946.636 1790.14,946.624 1790.12,946.611 1790.1,946.599 1790.08,946.586 1790.06,946.574 1790.04,946.562 1790.02,946.549 1790,946.537 1789.98,946.524 1789.95,946.512 1789.93,946.499 1789.91,946.487 1789.89,946.475 1789.87,946.462 1789.85,946.45 1789.83,946.437 1789.81,946.425 1789.79,946.413 1789.77,946.4 1789.75,946.388 1789.73,946.375 1789.71,946.363 1789.69,946.351 1789.66,946.338 1789.64,946.326 1789.62,946.313 1789.6,946.301 1789.58,946.289 1789.56,946.276 1789.54,946.264 1789.52,946.252 1789.5,946.239 1789.48,946.227 1789.46,946.214 1789.44,946.202 1789.42,946.19 1789.39,946.177 1789.37,946.165 1789.35,946.153 1789.33,946.14 1789.31,946.128 1789.29,946.116 1789.27,946.103 1789.25,946.091 1789.23,946.078 1789.21,946.066 1789.19,946.054 1789.17,946.041 1789.15,946.029 1789.13,946.017 1789.1,946.004 1789.08,945.992 1789.06,945.98 1789.04,945.967 1789.02,945.955 1789,945.943 1788.98,945.93 1788.96,945.918 1788.94,945.906 1788.92,945.893 1788.9,945.881 1788.88,945.869 1788.86,945.857 1788.84,945.844 1788.81,945.832 1788.79,945.82 1788.77,945.807 1788.75,945.795 1788.73,945.783 1788.71,945.77 1788.69,945.758 1788.67,945.746 1788.65,945.734 1788.63,945.721 1788.61,945.709 1788.59,945.697 1788.57,945.684 1788.55,945.672 1788.52,945.66 1788.5,945.648 1788.48,945.635 1788.46,945.623 1788.44,945.611 1788.42,945.599 1788.4,945.586 1788.38,945.574 1788.36,945.562 1788.34,945.549 1788.32,945.537 1788.3,945.525 1788.28,945.513 1788.26,945.5 1788.23,945.488 1788.21,945.476 1788.19,945.464 1788.17,945.452 1788.15,945.439 1788.13,945.427 1788.11,945.415 1788.09,945.403 1788.07,945.39 1788.05,945.378 1788.03,945.366 1788.01,945.354 1787.99,945.341 1787.97,945.329 1787.94,945.317 1787.92,945.305 1787.9,945.293 1787.88,945.28 1787.86,945.268 1787.84,945.256 1787.82,945.244 1787.8,945.232 1787.78,945.219 1787.76,945.207 1787.74,945.195 1787.72,945.183 1787.7,945.171 1787.68,945.158 1787.65,945.146 1787.63,945.134 1787.61,945.122 1787.59,945.11 1787.57,945.097 1787.55,945.085 1787.53,945.073 1787.51,945.061 1787.49,945.049 1787.47,945.037 1787.45,945.024 1787.43,945.012 1787.41,945 1787.39,944.988 1787.36,944.976 1787.34,944.964 1787.32,944.951 1787.3,944.939 1787.28,944.927 1787.26,944.915 1787.24,944.903 1787.22,944.891 1787.2,944.879 1787.18,944.866 1787.16,944.854 1787.14,944.842 1787.12,944.83 1787.1,944.818 1787.07,944.806 1787.05,944.794 1787.03,944.781 1787.01,944.769 1786.99,944.757 1786.97,944.745 1786.95,944.733 1786.93,944.721 1786.91,944.709 1786.89,944.697 1786.87,944.685 1786.85,944.672 1786.83,944.66 1786.81,944.648 1786.79,944.636 1786.76,944.624 1786.74,944.612 1786.72,944.6 1786.7,944.588 1786.68,944.576 1786.66,944.564 1786.64,944.552 1786.62,944.539 1786.6,944.527 1786.58,944.515 1786.56,944.503 1786.54,944.491 1786.52,944.479 1786.5,944.467 1786.47,944.455 1786.45,944.443 1786.43,944.431 1786.41,944.419 1786.39,944.407 1786.37,944.395 1786.35,944.383 1786.33,944.37 1786.31,944.358 1786.29,944.346 1786.27,944.334 1786.25,944.322 1786.23,944.31 1786.21,944.298 1786.19,944.286 1786.16,944.274 1786.14,944.262 1786.12,944.25 1786.1,944.238 1786.08,944.226 1786.06,944.214 1786.04,944.202 1786.02,944.19 1786,944.178 1785.98,944.166 1785.96,944.154 1785.94,944.142 1785.92,944.13 1785.9,944.118 1785.87,944.106 1785.85,944.094 1785.83,944.082 1785.81,944.07 1785.79,944.058 1785.77,944.046 1785.75,944.034 1785.73,944.022 1785.71,944.01 1785.69,943.998 1785.67,943.986 1785.65,943.974 1785.63,943.962 1785.61,943.95 1785.59,943.938 1785.56,943.926 1785.54,943.914 1785.52,943.902 1785.5,943.89 1785.48,943.878 1785.46,943.866 1785.44,943.854 1785.42,943.842 1785.4,943.83 1785.38,943.818 1785.36,943.806 1785.34,943.794 1785.32,943.782 1785.3,943.77 1785.28,943.758 1785.25,943.746 1785.23,943.734 1785.21,943.723 1785.19,943.711 1785.17,943.699 1785.15,943.687 1785.13,943.675 1785.11,943.663 1785.09,943.651 1785.07,943.639 1785.05,943.627 1785.03,943.615 1785.01,943.603 1784.99,943.591 1784.97,943.579 1784.94,943.567 1784.92,943.556 1784.9,943.544 1784.88,943.532 1784.86,943.52 1784.84,943.508 1784.82,943.496 1784.8,943.484 1784.78,943.472 1784.76,943.46 1784.74,943.448 1784.72,943.436 1784.7,943.425 1784.68,943.413 1784.66,943.401 1784.63,943.389 1784.61,943.377 1784.59,943.365 1784.57,943.353 1784.55,943.341 1784.53,943.329 1784.51,943.318 1784.49,943.306 1784.47,943.294 1784.45,943.282 1784.43,943.27 1784.41,943.258 1784.39,943.246 1784.37,943.235 1784.35,943.223 1784.32,943.211 1784.3,943.199 1784.28,943.187 1784.26,943.175 1784.24,943.163 1784.22,943.152 1784.2,943.14 1784.18,943.128 1784.16,943.116 1784.14,943.104 1784.12,943.092 1784.1,943.081 1784.08,943.069 1784.06,943.057 1784.04,943.045 1784.02,943.033 1783.99,943.021 1783.97,943.01 1783.95,942.998 1783.93,942.986 1783.91,942.974 1783.89,942.962 1783.87,942.95 1783.85,942.939 1783.83,942.927 1783.81,942.915 1783.79,942.903 1783.77,942.891 1783.75,942.88 1783.73,942.868 1783.71,942.856 1783.68,942.844 1783.66,942.832 1783.64,942.821 1783.62,942.809 1783.6,942.797 1783.58,942.785 1783.56,942.774 1783.54,942.762 1783.52,942.75 1783.5,942.738 1783.48,942.726 1783.46,942.715 1783.44,942.703 1783.42,942.691 1783.4,942.679 1783.38,942.668 1783.35,942.656 1783.33,942.644 1783.31,942.632 1783.29,942.621 1783.27,942.609 1783.25,942.597 1783.23,942.585 1783.21,942.574 1783.19,942.562 1783.17,942.55 1783.15,942.538 1783.13,942.527 1783.11,942.515 1783.09,942.503 1783.07,942.491 1783.05,942.48 1783.02,942.468 1783,942.456 1782.98,942.444 1782.96,942.433 1782.94,942.421 1782.92,942.409 1782.9,942.398 1782.88,942.386 1782.86,942.374 1782.84,942.362 1782.82,942.351 1782.8,942.339 1782.78,942.327 1782.76,942.316 1782.74,942.304 1782.72,942.292 1782.69,942.28 1782.67,942.269 1782.65,942.257 1782.63,942.245 1782.61,942.234 1782.59,942.222 1782.57,942.21 1782.55,942.199 1782.53,942.187 1782.51,942.175 1782.49,942.164 1782.47,942.152 1782.45,942.14 1782.43,942.129 1782.41,942.117 1782.39,942.105 1782.36,942.094 1782.34,942.082 1782.32,942.07 1782.3,942.059 1782.28,942.047 1782.26,942.035 1782.24,942.024 1782.22,942.012 1782.2,942 1782.18,941.989 1782.16,941.977 1782.14,941.965 1782.12,941.954 1782.1,941.942 1782.08,941.93 1782.06,941.919 1782.04,941.907 1782.01,941.895 1781.99,941.884 1781.97,941.872 1781.95,941.861 1781.93,941.849 1781.91,941.837 1781.89,941.826 1781.87,941.814 1781.85,941.802 1781.83,941.791 1781.81,941.779 1781.79,941.768 1781.77,941.756 1781.75,941.744 1781.73,941.733 1781.71,941.721 1781.68,941.71 1781.66,941.698 1781.64,941.686 1781.62,941.675 1781.6,941.663 1781.58,941.652 1781.56,941.64 1781.54,941.628 1781.52,941.617 1781.5,941.605 1781.48,941.594 1781.46,941.582 1781.44,941.571 1781.42,941.559 1781.4,941.547 1781.38,941.536 1781.36,941.524 1781.33,941.513 1781.31,941.501 1781.29,941.49 1781.27,941.478 1781.25,941.466 1781.23,941.455 1781.21,941.443 1781.19,941.432 1781.17,941.42 1781.15,941.409 1781.13,941.397 1781.11,941.386 1781.09,941.374 1781.07,941.362 1781.05,941.351 1781.03,941.339 1781.01,941.328 1780.98,941.316 1780.96,941.305 1780.94,941.293 1780.92,941.282 1780.9,941.27 1780.88,941.259 1780.86,941.247 1780.84,941.236 1780.82,941.224 1780.8,941.213 1780.78,941.201 1780.76,941.189 1780.74,941.178 1780.72,941.166 1780.7,941.155 1780.68,941.143 1780.66,941.132 1780.63,941.12 1780.61,941.109 1780.59,941.097 1780.57,941.086 1780.55,941.074 1780.53,941.063 1780.51,941.051 1780.49,941.04 1780.47,941.028 1780.45,941.017 1780.43,941.006 1780.41,940.994 1780.39,940.983 1780.37,940.971 1780.35,940.96 1780.33,940.948 1780.31,940.937 1780.29,940.925 1780.26,940.914 1780.24,940.902 1780.22,940.891 1780.2,940.879 1780.18,940.868 1780.16,940.856 1780.14,940.845 1780.12,940.833 1780.1,940.822 1780.08,940.811 1780.06,940.799 1780.04,940.788 1780.02,940.776 1780,940.765 1779.98,940.753 1779.96,940.742 1779.94,940.73 1779.92,940.719 1779.89,940.708 1779.87,940.696 1779.85,940.685 1779.83,940.673 1779.81,940.662 1779.79,940.65 1779.77,940.639 1779.75,940.628 1779.73,940.616 1779.71,940.605 1779.69,940.593 1779.67,940.582 1779.65,940.571 1779.63,940.559 1779.61,940.548 1779.59,940.536 1779.57,940.525 1779.55,940.514 1779.52,940.502 1779.5,940.491 1779.48,940.479 1779.46,940.468 1779.44,940.457 1779.42,940.445 1779.4,940.434 1779.38,940.422 1779.36,940.411 1779.34,940.4 1779.32,940.388 1779.3,940.377 1779.28,940.366 1779.26,940.354 1779.24,940.343 1779.22,940.331 1779.2,940.32 1779.18,940.309 1779.15,940.297 1779.13,940.286 1779.11,940.275 1779.09,940.263 1779.07,940.252 1779.05,940.24 1779.03,940.229 1779.01,940.218 1778.99,940.206 1778.97,940.195 1778.95,940.184 1778.93,940.172 1778.91,940.161 1778.89,940.15 1778.87,940.138 1778.85,940.127 1778.83,940.116 1778.81,940.104 1778.79,940.093 1778.76,940.082 1778.74,940.07 1778.72,940.059 1778.7,940.048 1778.68,940.036 1778.66,940.025 1778.64,940.014 1778.62,940.002 1778.6,939.991 1778.58,939.98 1778.56,939.969 1778.54,939.957 1778.52,939.946 1778.5,939.935 1778.48,939.923 1778.46,939.912 1778.44,939.901 1778.42,939.889 1778.4,939.878 1778.37,939.867 1778.35,939.856 1778.33,939.844 1778.31,939.833 1778.29,939.822 1778.27,939.81 1778.25,939.799 1778.23,939.788 1778.21,939.777 1778.19,939.765 1778.17,939.754 1778.15,939.743 1778.13,939.731 1778.11,939.72 1778.09,939.709 1778.07,939.698 1778.05,939.686 1778.03,939.675 1778.01,939.664 1777.98,939.653 1777.96,939.641 1777.94,939.63 1777.92,939.619 1777.9,939.608 1777.88,939.596 1777.86,939.585 1777.84,939.574 1777.82,939.563 1777.8,939.551 1777.78,939.54 1777.76,939.529 1777.74,939.518 1777.72,939.507 1777.7,939.495 1777.68,939.484 1777.66,939.473 1777.64,939.462 1777.62,939.45 1777.6,939.439 1777.57,939.428 1777.55,939.417 1777.53,939.406 1777.51,939.394 1777.49,939.383 1777.47,939.372 1777.45,939.361 1777.43,939.349 1777.41,939.338 1777.39,939.327 1777.37,939.316 1777.35,939.305 1777.33,939.293 1777.31,939.282 1777.29,939.271 1777.27,939.26 1777.25,939.249 1777.23,939.238 1777.21,939.226 1777.19,939.215 1777.16,939.204 1777.14,939.193 1777.12,939.182 1777.1,939.17 1777.08,939.159 1777.06,939.148 1777.04,939.137 1777.02,939.126 1777,939.115 1776.98,939.103 1776.96,939.092 1776.94,939.081 1776.92,939.07 1776.9,939.059 1776.88,939.048 1776.86,939.036 1776.84,939.025 1776.82,939.014 1776.8,939.003 1776.78,938.992 1776.75,938.981 1776.73,938.97 1776.71,938.958 1776.69,938.947 1776.67,938.936 1776.65,938.925 1776.63,938.914 1776.61,938.903 1776.59,938.892 1776.57,938.881 1776.55,938.869 1776.53,938.858 1776.51,938.847 1776.49,938.836 1776.47,938.825 1776.45,938.814 1776.43,938.803 1776.41,938.792 1776.39,938.78 1776.37,938.769 1776.35,938.758 1776.33,938.747 1776.3,938.736 1776.28,938.725 1776.26,938.714 1776.24,938.703 1776.22,938.692 1776.2,938.681 1776.18,938.669 1776.16,938.658 1776.14,938.647 1776.12,938.636 1776.1,938.625 1776.08,938.614 1776.06,938.603 1776.04,938.592 1776.02,938.581 1776,938.57 1775.98,938.559 1775.96,938.548 1775.94,938.536 1775.92,938.525 1775.9,938.514 1775.87,938.503 1775.85,938.492 1775.83,938.481 1775.81,938.47 1775.79,938.459 1775.77,938.448 1775.75,938.437 1775.73,938.426 1775.71,938.415 1775.69,938.404 1775.67,938.393 1775.65,938.382 1775.63,938.371 1775.61,938.36 1775.59,938.349 1775.57,938.338 1775.55,938.327 1775.53,938.315 1775.51,938.304 1775.49,938.293 1775.47,938.282 1775.45,938.271 1775.42,938.26 1775.4,938.249 1775.38,938.238 1775.36,938.227 1775.34,938.216 1775.32,938.205 1775.3,938.194 1775.28,938.183 1775.26,938.172 1775.24,938.161 1775.22,938.15 1775.2,938.139 1775.18,938.128 1775.16,938.117 1775.14,938.106 1775.12,938.095 1775.1,938.084 1775.08,938.073 1775.06,938.062 1775.04,938.051 1775.02,938.04 1775,938.029 1774.98,938.018 1774.95,938.007 1774.93,937.996 1774.91,937.985 1774.89,937.974 1774.87,937.963 1774.85,937.952 1774.83,937.941 1774.81,937.931 1774.79,937.92 1774.77,937.909 1774.75,937.898 1774.73,937.887 1774.71,937.876 1774.69,937.865 1774.67,937.854 1774.65,937.843 1774.63,937.832 1774.61,937.821 1774.59,937.81 1774.57,937.799 1774.55,937.788 1774.53,937.777 1774.51,937.766 1774.49,937.755 1774.46,937.744 1774.44,937.733 1774.42,937.722 1774.4,937.712 1774.38,937.701 1774.36,937.69 1774.34,937.679 1774.32,937.668 1774.3,937.657 1774.28,937.646 1774.26,937.635 1774.24,937.624 1774.22,937.613 1774.2,937.602 1774.18,937.591 1774.16,937.58 1774.14,937.57 1774.12,937.559 1774.1,937.548 1774.08,937.537 1774.06,937.526 1774.04,937.515 1774.02,937.504 1774,937.493 1773.97,937.482 1773.95,937.471 1773.93,937.461 1773.91,937.45 1773.89,937.439 1773.87,937.428 1773.85,937.417 1773.83,937.406 1773.81,937.395 1773.79,937.384 1773.77,937.374 1773.75,937.363 1773.73,937.352 1773.71,937.341 1773.69,937.33 1773.67,937.319 1773.65,937.308 1773.63,937.297 1773.61,937.287 1773.59,937.276 1773.57,937.265 1773.55,937.254 1773.53,937.243 1773.51,937.232 1773.49,937.221 1773.47,937.211 1773.44,937.2 1773.42,937.189 1773.4,937.178 1773.38,937.167 1773.36,937.156 1773.34,937.146 1773.32,937.135 1773.3,937.124 1773.28,937.113 1773.26,937.102 1773.24,937.091 1773.22,937.081 1773.2,937.07 1773.18,937.059 1773.16,937.048 1773.14,937.037 1773.12,937.026 1773.1,937.016 1773.08,937.005 1773.06,936.994 1773.04,936.983 1773.02,936.972 1773,936.962 1772.98,936.951 1772.96,936.94 1772.94,936.929 1772.91,936.918 1772.89,936.908 1772.87,936.897 1772.85,936.886 1772.83,936.875 1772.81,936.864 1772.79,936.854 1772.77,936.843 1772.75,936.832 1772.73,936.821 1772.71,936.81 1772.69,936.8 1772.67,936.789 1772.65,936.778 1772.63,936.767 1772.61,936.757 1772.59,936.746 1772.57,936.735 1772.55,936.724 1772.53,936.713 1772.51,936.703 1772.49,936.692 1772.47,936.681 1772.45,936.67 1772.43,936.66 1772.41,936.649 1772.39,936.638 1772.37,936.627 1772.34,936.617 1772.32,936.606 1772.3,936.595 1772.28,936.584 1772.26,936.574 1772.24,936.563 1772.22,936.552 1772.2,936.541 1772.18,936.531 1772.16,936.52 1772.14,936.509 1772.12,936.498 1772.1,936.488 1772.08,936.477 1772.06,936.466 1772.04,936.456 1772.02,936.445 1772,936.434 1771.98,936.423 1771.96,936.413 1771.94,936.402 1771.92,936.391 1771.9,936.381 1771.88,936.37 1771.86,936.359 1771.84,936.348 1771.82,936.338 1771.8,936.327 1771.78,936.316 1771.75,936.306 1771.73,936.295 1771.71,936.284 1771.69,936.274 1771.67,936.263 1771.65,936.252 1771.63,936.241 1771.61,936.231 1771.59,936.22 1771.57,936.209 1771.55,936.199 1771.53,936.188 1771.51,936.177 1771.49,936.167 1771.47,936.156 1771.45,936.145 1771.43,936.135 1771.41,936.124 1771.39,936.113 1771.37,936.103 1771.35,936.092 1771.33,936.081 1771.31,936.071 1771.29,936.06 1771.27,936.049 1771.25,936.039 1771.23,936.028 1771.21,936.017 1771.19,936.007 1771.17,935.996 1771.15,935.985 1771.12,935.975 1771.1,935.964 1771.08,935.954 1771.06,935.943 1771.04,935.932 1771.02,935.922 1771,935.911 1770.98,935.9 1770.96,935.89 1770.94,935.879 1770.92,935.868 1770.9,935.858 1770.88,935.847 1770.86,935.837 1770.84,935.826 1770.82,935.815 1770.8,935.805 1770.78,935.794 1770.76,935.784 1770.74,935.773 1770.72,935.762 1770.7,935.752 1770.68,935.741 1770.66,935.73 1770.64,935.72 1770.62,935.709 1770.6,935.699 1770.58,935.688 1770.56,935.677 1770.54,935.667 1770.52,935.656 1770.5,935.646 1770.48,935.635 1770.45,935.625 1770.43,935.614 1770.41,935.603 1770.39,935.593 1770.37,935.582 1770.35,935.572 1770.33,935.561 1770.31,935.55 1770.29,935.54 1770.27,935.529 1770.25,935.519 1770.23,935.508 1770.21,935.498 1770.19,935.487 1770.17,935.476 1770.15,935.466 1770.13,935.455 1770.11,935.445 1770.09,935.434 1770.07,935.424 1770.05,935.413 1770.03,935.403 1770.01,935.392 1769.99,935.381 1769.97,935.371 1769.95,935.36 1769.93,935.35 1769.91,935.339 1769.89,935.329 1769.87,935.318 1769.85,935.308 1769.83,935.297 1769.81,935.287 1769.79,935.276 1769.77,935.266 1769.75,935.255 1769.72,935.245 1769.7,935.234 1769.68,935.223 1769.66,935.213 1769.64,935.202 1769.62,935.192 1769.6,935.181 1769.58,935.171 1769.56,935.16 1769.54,935.15 1769.52,935.139 1769.5,935.129 1769.48,935.118 1769.46,935.108 1769.44,935.097 1769.42,935.087 1769.4,935.076 1769.38,935.066 1769.36,935.055 1769.34,935.045 1769.32,935.034 1769.3,935.024 1769.28,935.013 1769.26,935.003 1769.24,934.992 1769.22,934.982 1769.2,934.971 1769.18,934.961 1769.16,934.951 1769.14,934.94 1769.12,934.93 1769.1,934.919 1769.08,934.909 1769.06,934.898 1769.04,934.888 1769.02,934.877 1769,934.867 1768.98,934.856 1768.96,934.846 1768.93,934.835 1768.91,934.825 1768.89,934.814 1768.87,934.804 1768.85,934.794 1768.83,934.783 1768.81,934.773 1768.79,934.762 1768.77,934.752 1768.75,934.741 1768.73,934.731 1768.71,934.72 1768.69,934.71 1768.67,934.7 1768.65,934.689 1768.63,934.679 1768.61,934.668 1768.59,934.658 1768.57,934.647 1768.55,934.637 1768.53,934.627 1768.51,934.616 1768.49,934.606 1768.47,934.595 1768.45,934.585 1768.43,934.575 1768.41,934.564 1768.39,934.554 1768.37,934.543 1768.35,934.533 1768.33,934.522 1768.31,934.512 1768.29,934.502 1768.27,934.491 1768.25,934.481 1768.23,934.47 1768.21,934.46 1768.19,934.45 1768.17,934.439 1768.15,934.429 1768.13,934.418 1768.11,934.408 1768.09,934.398 1768.07,934.387 1768.04,934.377 1768.02,934.367 1768,934.356 1767.98,934.346 1767.96,934.335 1767.94,934.325 1767.92,934.315 1767.9,934.304 1767.88,934.294 1767.86,934.284 1767.84,934.273 1767.82,934.263 1767.8,934.252 1767.78,934.242 1767.76,934.232 1767.74,934.221 1767.72,934.211 1767.7,934.201 1767.68,934.19 1767.66,934.18 1767.64,934.17 1767.62,934.159 1767.6,934.149 1767.58,934.139 1767.56,934.128 1767.54,934.118 1767.52,934.108 1767.5,934.097 1767.48,934.087 1767.46,934.077 1767.44,934.066 1767.42,934.056 1767.4,934.046 1767.38,934.035 1767.36,934.025 1767.34,934.015 1767.32,934.004 1767.3,933.994 1767.28,933.984 1767.26,933.973 1767.24,933.963 1767.22,933.953 1767.2,933.942 1767.18,933.932 1767.16,933.922 1767.14,933.911 1767.12,933.901 1767.1,933.891 1767.08,933.881 1767.06,933.87 1767.04,933.86 1767.02,933.85 1766.99,933.839 1766.97,933.829 1766.95,933.819 1766.93,933.808 1766.91,933.798 1766.89,933.788 1766.87,933.778 1766.85,933.767 1766.83,933.757 1766.81,933.747 1766.79,933.736 1766.77,933.726 1766.75,933.716 1766.73,933.706 1766.71,933.695 1766.69,933.685 1766.67,933.675 1766.65,933.665 1766.63,933.654 1766.61,933.644 1766.59,933.634 1766.57,933.624 1766.55,933.613 1766.53,933.603 1766.51,933.593 1766.49,933.583 1766.47,933.572 1766.45,933.562 1766.43,933.552 1766.41,933.542 1766.39,933.531 1766.37,933.521 1766.35,933.511 1766.33,933.501 1766.31,933.49 1766.29,933.48 1766.27,933.47 1766.25,933.46 1766.23,933.449 1766.21,933.439 1766.19,933.429 1766.17,933.419 1766.15,933.408 1766.13,933.398 1766.11,933.388 1766.09,933.378 1766.07,933.368 1766.05,933.357 1766.03,933.347 1766.01,933.337 1765.99,933.327 1765.97,933.317 1765.95,933.306 1765.93,933.296 1765.91,933.286 1765.89,933.276 1765.87,933.265 1765.85,933.255 1765.83,933.245 1765.81,933.235 1765.79,933.225 1765.77,933.215 1765.75,933.204 1765.73,933.194 1765.71,933.184 1765.69,933.174 1765.67,933.164 1765.64,933.153 1765.62,933.143 1765.6,933.133 1765.58,933.123 1765.56,933.113 1765.54,933.102 1765.52,933.092 1765.5,933.082 1765.48,933.072 1765.46,933.062 1765.44,933.052 1765.42,933.041 1765.4,933.031 1765.38,933.021 1765.36,933.011 1765.34,933.001 1765.32,932.991 1765.3,932.981 1765.28,932.97 1765.26,932.96 1765.24,932.95 1765.22,932.94 1765.2,932.93 1765.18,932.92 1765.16,932.909 1765.14,932.899 1765.12,932.889 1765.1,932.879 1765.08,932.869 1765.06,932.859 1765.04,932.849 1765.02,932.838 1765,932.828 1764.98,932.818 1764.96,932.808 1764.94,932.798 1764.92,932.788 1764.9,932.778 1764.88,932.768 1764.86,932.757 1764.84,932.747 1764.82,932.737 1764.8,932.727 1764.78,932.717 1764.76,932.707 1764.74,932.697 1764.72,932.687 1764.7,932.677 1764.68,932.666 1764.66,932.656 1764.64,932.646 1764.62,932.636 1764.6,932.626 1764.58,932.616 1764.56,932.606 1764.54,932.596 1764.52,932.586 1764.5,932.576 1764.48,932.566 1764.46,932.555 1764.44,932.545 1764.42,932.535 1764.4,932.525 1764.38,932.515 1764.36,932.505 1764.34,932.495 1764.32,932.485 1764.3,932.475 1764.28,932.465 1764.26,932.455 1764.24,932.445 1764.22,932.435 1764.2,932.424 1764.18,932.414 1764.16,932.404 1764.14,932.394 1764.12,932.384 1764.1,932.374 1764.08,932.364 1764.06,932.354 1764.04,932.344 1764.02,932.334 1764,932.324 1763.98,932.314 1763.96,932.304 1763.94,932.294 1763.92,932.284 1763.9,932.274 1763.88,932.264 1763.86,932.254 1763.84,932.244 1763.82,932.234 1763.8,932.223 1763.78,932.213 1763.76,932.203 1763.74,932.193 1763.72,932.183 1763.7,932.173 1763.68,932.163 1763.66,932.153 1763.64,932.143 1763.62,932.133 1763.6,932.123 1763.58,932.113 1763.56,932.103 1763.54,932.093 1763.52,932.083 1763.5,932.073 1763.48,932.063 1763.46,932.053 1763.44,932.043 1763.42,932.033 1763.4,932.023 1763.38,932.013 1763.36,932.003 1763.34,931.993 1763.32,931.983 1763.3,931.973 1763.28,931.963 1763.26,931.953 1763.24,931.943 1763.22,931.933 1763.2,931.923 1763.18,931.913 1763.16,931.903 1763.14,931.893 1763.12,931.883 1763.1,931.873 1763.08,931.863 1763.06,931.853 1763.04,931.843 1763.02,931.833 1763,931.823 1762.98,931.814 1762.96,931.804 1762.94,931.794 1762.91,931.784 1762.89,931.774 1762.87,931.764 1762.85,931.754 1762.83,931.744 1762.81,931.734 1762.79,931.724 1762.77,931.714 1762.75,931.704 1762.73,931.694 1762.71,931.684 1762.69,931.674 1762.67,931.664 1762.65,931.654 1762.63,931.644 1762.61,931.634 1762.59,931.624 1762.57,931.615 1762.55,931.605 1762.53,931.595 1762.51,931.585 1762.49,931.575 1762.47,931.565 1762.45,931.555 1762.43,931.545 1762.41,931.535 1762.39,931.525 1762.37,931.515 1762.35,931.505 1762.33,931.495 1762.31,931.485 1762.29,931.476 1762.27,931.466 1762.25,931.456 1762.23,931.446 1762.21,931.436 1762.19,931.426 1762.17,931.416 1762.15,931.406 1762.13,931.396 1762.11,931.386 1762.09,931.377 1762.07,931.367 1762.05,931.357 1762.03,931.347 1762.01,931.337 1761.99,931.327 1761.97,931.317 1761.95,931.307 1761.93,931.297 1761.91,931.288 1761.89,931.278 1761.87,931.268 1761.85,931.258 1761.83,931.248 1761.82,931.238 1761.8,931.228 1761.78,931.218 1761.76,931.209 1761.74,931.199 1761.72,931.189 1761.7,931.179 1761.68,931.169 1761.66,931.159 1761.64,931.149 1761.62,931.139 1761.6,931.13 1761.58,931.12 1761.56,931.11 1761.54,931.1 1761.52,931.09 1761.5,931.08 1761.48,931.071 1761.46,931.061 1761.44,931.051 1761.42,931.041 1761.4,931.031 1761.38,931.021 1761.36,931.011 1761.34,931.002 1761.32,930.992 1761.3,930.982 1761.28,930.972 1761.26,930.962 1761.24,930.952 1761.22,930.943 1761.2,930.933 1761.18,930.923 1761.16,930.913 1761.14,930.903 1761.12,930.894 1761.1,930.884 1761.08,930.874 1761.06,930.864 1761.04,930.854 1761.02,930.844 1761,930.835 1760.98,930.825 1760.96,930.815 1760.94,930.805 1760.92,930.795 1760.9,930.786 1760.88,930.776 1760.86,930.766 1760.84,930.756 1760.82,930.746 1760.8,930.737 1760.78,930.727 1760.76,930.717 1760.74,930.707 1760.72,930.697 1760.7,930.688 1760.68,930.678 1760.66,930.668 1760.64,930.658 1760.62,930.649 1760.6,930.639 1760.58,930.629 1760.56,930.619 1760.54,930.609 1760.52,930.6 1760.5,930.59 1760.48,930.58 1760.46,930.57 1760.44,930.561 1760.42,930.551 1760.4,930.541 1760.38,930.531 1760.36,930.522 1760.34,930.512 1760.32,930.502 1760.3,930.492 1760.28,930.483 1760.26,930.473 1760.24,930.463 1760.22,930.453 1760.2,930.444 1760.18,930.434 1760.16,930.424 1760.14,930.414 1760.12,930.405 1760.1,930.395 1760.08,930.385 1760.06,930.375 1760.04,930.366 1760.02,930.356 1760,930.346 1759.98,930.336 1759.96,930.327 1759.94,930.317 1759.92,930.307 1759.9,930.298 1759.88,930.288 1759.86,930.278 1759.84,930.268 1759.82,930.259 1759.8,930.249 1759.78,930.239 1759.76,930.229 1759.74,930.22 1759.72,930.21 1759.7,930.2 1759.68,930.191 1759.66,930.181 1759.64,930.171 1759.62,930.162 1759.6,930.152 1759.58,930.142 1759.56,930.132 1759.54,930.123 1759.52,930.113 1759.5,930.103 1759.48,930.094 1759.46,930.084 1759.44,930.074 1759.42,930.065 1759.4,930.055 1759.38,930.045 1759.36,930.036 1759.34,930.026 1759.32,930.016 1759.3,930.006 1759.28,929.997 1759.26,929.987 1759.24,929.977 1759.22,929.968 1759.2,929.958 1759.18,929.948 1759.17,929.939 1759.15,929.929 1759.13,929.919 1759.11,929.91 1759.09,929.9 1759.07,929.89 1759.05,929.881 1759.03,929.871 1759.01,929.862 1758.99,929.852 1758.97,929.842 1758.95,929.833 1758.93,929.823 1758.91,929.813 1758.89,929.804 1758.87,929.794 1758.85,929.784 1758.83,929.775 1758.81,929.765 1758.79,929.755 1758.77,929.746 1758.75,929.736 1758.73,929.727 1758.71,929.717 1758.69,929.707 1758.67,929.698 1758.65,929.688 1758.63,929.678 1758.61,929.669 1758.59,929.659 1758.57,929.649 1758.55,929.64 1758.53,929.63 1758.51,929.621 1758.49,929.611 1758.47,929.601 1758.45,929.592 1758.43,929.582 1758.41,929.573 1758.39,929.563 1758.37,929.553 1758.35,929.544 1758.33,929.534 1758.31,929.525 1758.29,929.515 1758.27,929.505 1758.25,929.496 1758.23,929.486 1758.21,929.477 1758.19,929.467 1758.17,929.457 1758.15,929.448 1758.13,929.438 1758.11,929.429 1758.09,929.419 1758.07,929.409 1758.05,929.4 1758.03,929.39 1758.01,929.381 1757.99,929.371 1757.97,929.362 1757.95,929.352 1757.93,929.342 1757.91,929.333 1757.9,929.323 1757.88,929.314 1757.86,929.304 1757.84,929.295 1757.82,929.285 1757.8,929.275 1757.78,929.266 1757.76,929.256 1757.74,929.247 1757.72,929.237 1757.7,929.228 1757.68,929.218 1757.66,929.209 1757.64,929.199 1757.62,929.189 1757.6,929.18 1757.58,929.17 1757.56,929.161 1757.54,929.151 1757.52,929.142 1757.5,929.132 1757.48,929.123 1757.46,929.113 1757.44,929.104 1757.42,929.094 1757.4,929.085 1757.38,929.075 1757.36,929.065 1757.34,929.056 1757.32,929.046 1757.3,929.037 1757.28,929.027 1757.26,929.018 1757.24,929.008 1757.22,928.999 1757.2,928.989 1757.18,928.98 1757.16,928.97 1757.14,928.961 1757.12,928.951 1757.1,928.942 1757.08,928.932 1757.06,928.923 1757.04,928.913 1757.02,928.904 1757,928.894 1756.98,928.885 1756.96,928.875 1756.94,928.866 1756.93,928.856 1756.91,928.847 1756.89,928.837 1756.87,928.828 1756.85,928.818 1756.83,928.809 1756.81,928.799 1756.79,928.79 1756.77,928.78 1756.75,928.771 1756.73,928.761 1756.71,928.752 1756.69,928.742 1756.67,928.733 1756.65,928.723 1756.63,928.714 1756.61,928.705 1756.59,928.695 1756.57,928.686 1756.55,928.676 1756.53,928.667 1756.51,928.657 1756.49,928.648 1756.47,928.638 1756.45,928.629 1756.43,928.619 1756.41,928.61 1756.39,928.6 1756.37,928.591 1756.35,928.582 1756.33,928.572 1756.31,928.563 1756.29,928.553 1756.27,928.544 1756.25,928.534 1756.23,928.525 1756.21,928.515 1756.19,928.506 1756.17,928.497 1756.15,928.487 1756.13,928.478 1756.12,928.468 1756.1,928.459 1756.08,928.449 1756.06,928.44 1756.04,928.431 1756.02,928.421 1756,928.412 1755.98,928.402 1755.96,928.393 1755.94,928.383 1755.92,928.374 1755.9,928.365 1755.88,928.355 1755.86,928.346 1755.84,928.336 1755.82,928.327 1755.8,928.317 1755.78,928.308 1755.76,928.299 1755.74,928.289 1755.72,928.28 1755.7,928.27 1755.68,928.261 1755.66,928.252 1755.64,928.242 1755.62,928.233 1755.6,928.223 1755.58,928.214 1755.56,928.205 1755.54,928.195 1755.52,928.186 1755.5,928.177 1755.48,928.167 1755.46,928.158 1755.44,928.148 1755.42,928.139 1755.4,928.13 1755.39,928.12 1755.37,928.111 1755.35,928.101 1755.33,928.092 1755.31,928.083 1755.29,928.073 1755.27,928.064 1755.25,928.055 1755.23,928.045 1755.21,928.036 1755.19,928.027 1755.17,928.017 1755.15,928.008 1755.13,927.998 1755.11,927.989 1755.09,927.98 1755.07,927.97 1755.05,927.961 1755.03,927.952 1755.01,927.942 1754.99,927.933 1754.97,927.924 1754.95,927.914 1754.93,927.905 1754.91,927.896 1754.89,927.886 1754.87,927.877 1754.85,927.868 1754.83,927.858 1754.81,927.849 1754.79,927.84 1754.77,927.83 1754.76,927.821 1754.74,927.812 1754.72,927.802 1754.7,927.793 1754.68,927.784 1754.66,927.774 1754.64,927.765 1754.62,927.756 1754.6,927.746 1754.58,927.737 1754.56,927.728 1754.54,927.718 1754.52,927.709 1754.5,927.7 1754.48,927.69 1754.46,927.681 1754.44,927.672 1754.42,927.662 1754.4,927.653 1754.38,927.644 1754.36,927.635 1754.34,927.625 1754.32,927.616 1754.3,927.607 1754.28,927.597 1754.26,927.588 1754.24,927.579 1754.22,927.569 1754.2,927.56 1754.18,927.551 1754.17,927.542 1754.15,927.532 1754.13,927.523 1754.11,927.514 1754.09,927.504 1754.07,927.495 1754.05,927.486 1754.03,927.477 1754.01,927.467 1753.99,927.458 1753.97,927.449 1753.95,927.44 1753.93,927.43 1753.91,927.421 1753.89,927.412 1753.87,927.402 1753.85,927.393 1753.83,927.384 1753.81,927.375 1753.79,927.365 1753.77,927.356 1753.75,927.347 1753.73,927.338 1753.71,927.328 1753.69,927.319 1753.67,927.31 1753.65,927.301 1753.63,927.291 1753.62,927.282 1753.6,927.273 1753.58,927.264 1753.56,927.254 1753.54,927.245 1753.52,927.236 1753.5,927.227 1753.48,927.217 1753.46,927.208 1753.44,927.199 1753.42,927.19 1753.4,927.18 1753.38,927.171 1753.36,927.162 1753.34,927.153 1753.32,927.144 1753.3,927.134 1753.28,927.125 1753.26,927.116 1753.24,927.107 1753.22,927.097 1753.2,927.088 1753.18,927.079 1753.16,927.07 1753.14,927.061 1753.12,927.051 1753.11,927.042 1753.09,927.033 1753.07,927.024 1753.05,927.015 1753.03,927.005 1753.01,926.996 1752.99,926.987 1752.97,926.978 1752.95,926.969 1752.93,926.959 1752.91,926.95 1752.89,926.941 1752.87,926.932 1752.85,926.923 1752.83,926.913 1752.81,926.904 1752.79,926.895 1752.77,926.886 1752.75,926.877 1752.73,926.867 1752.71,926.858 1752.69,926.849 1752.67,926.84 1752.65,926.831 1752.63,926.822 1752.62,926.812 1752.6,926.803 1752.58,926.794 1752.56,926.785 1752.54,926.776 1752.52,926.767 1752.5,926.757 1752.48,926.748 1752.46,926.739 1752.44,926.73 1752.42,926.721 1752.4,926.712 1752.38,926.702 1752.36,926.693 1752.34,926.684 1752.32,926.675 1752.3,926.666 1752.28,926.657 1752.26,926.648 1752.24,926.638 1752.22,926.629 1752.2,926.62 1752.18,926.611 1752.17,926.602 1752.15,926.593 1752.13,926.584 1752.11,926.574 1752.09,926.565 1752.07,926.556 1752.05,926.547 1752.03,926.538 1752.01,926.529 1751.99,926.52 1751.97,926.51 1751.95,926.501 1751.93,926.492 1751.91,926.483 1751.89,926.474 1751.87,926.465 1751.85,926.456 1751.83,926.447 1751.81,926.437 1751.79,926.428 1751.77,926.419 1751.75,926.41 1751.73,926.401 1751.72,926.392 1751.7,926.383 1751.68,926.374 1751.66,926.365 1751.64,926.356 1751.62,926.346 1751.6,926.337 1751.58,926.328 1751.56,926.319 1751.54,926.31 1751.52,926.301 1751.5,926.292 1751.48,926.283 1751.46,926.274 1751.44,926.265 1751.42,926.255 1751.4,926.246 1751.38,926.237 1751.36,926.228 1751.34,926.219 1751.32,926.21 1751.31,926.201 1751.29,926.192 1751.27,926.183 1751.25,926.174 1751.23,926.165 1751.21,926.156 1751.19,926.147 1751.17,926.137 1751.15,926.128 1751.13,926.119 1751.11,926.11 1751.09,926.101 1751.07,926.092 1751.05,926.083 1751.03,926.074 1751.01,926.065 1750.99,926.056 1750.97,926.047 1750.95,926.038 1750.93,926.029 1750.92,926.02 1750.9,926.011 1750.88,926.002 1750.86,925.993 1750.84,925.984 1750.82,925.974 1750.8,925.965 1750.78,925.956 1750.76,925.947 1750.74,925.938 1750.72,925.929 1750.7,925.92 1750.68,925.911 1750.66,925.902 1750.64,925.893 1750.62,925.884 1750.6,925.875 1750.58,925.866 1750.56,925.857 1750.54,925.848 1750.53,925.839 1750.51,925.83 1750.49,925.821 1750.47,925.812 1750.45,925.803 1750.43,925.794 1750.41,925.785 1750.39,925.776 1750.37,925.767 1750.35,925.758 1750.33,925.749 1750.31,925.74 1750.29,925.731 1750.27,925.722 1750.25,925.713 1750.23,925.704 1750.21,925.695 1750.19,925.686 1750.17,925.677 1750.16,925.668 1750.14,925.659 1750.12,925.65 1750.1,925.641 1750.08,925.632 1750.06,925.623 1750.04,925.614 1750.02,925.605 1750,925.596 1749.98,925.587 1749.96,925.578 1749.94,925.569 1749.92,925.56 1749.9,925.551 1749.88,925.542 1749.86,925.533 1749.84,925.524 1749.82,925.515 1749.8,925.506 1749.79,925.497 1749.77,925.488 1749.75,925.479 1749.73,925.47 1749.71,925.461 1749.69,925.452 1749.67,925.443 1749.65,925.434 1749.63,925.425 1749.61,925.416 1749.59,925.408 1749.57,925.399 1749.55,925.39 1749.53,925.381 1749.51,925.372 1749.49,925.363 1749.47,925.354 1749.45,925.345 1749.44,925.336 1749.42,925.327 1749.4,925.318 1749.38,925.309 1749.36,925.3 1749.34,925.291 1749.32,925.282 1749.3,925.273 1749.28,925.264 1749.26,925.255 1749.24,925.247 1749.22,925.238 1749.2,925.229 1749.18,925.22 1749.16,925.211 1749.14,925.202 1749.12,925.193 1749.11,925.184 1749.09,925.175 1749.07,925.166 1749.05,925.157 1749.03,925.148 1749.01,925.139 1748.99,925.131 1748.97,925.122 1748.95,925.113 1748.93,925.104 1748.91,925.095 1748.89,925.086 1748.87,925.077 1748.85,925.068 1748.83,925.059 1748.81,925.05 1748.79,925.042 1748.78,925.033 1748.76,925.024 1748.74,925.015 1748.72,925.006 1748.7,924.997 1748.68,924.988 1748.66,924.979 1748.64,924.97 1748.62,924.961 1748.6,924.953 1748.58,924.944 1748.56,924.935 1748.54,924.926 1748.52,924.917 1748.5,924.908 1748.48,924.899 1748.46,924.89 1748.45,924.882 1748.43,924.873 1748.41,924.864 1748.39,924.855 1748.37,924.846 1748.35,924.837 1748.33,924.828 1748.31,924.819 1748.29,924.811 1748.27,924.802 1748.25,924.793 1748.23,924.784 1748.21,924.775 1748.19,924.766 1748.17,924.757 1748.15,924.749 1748.14,924.74 1748.12,924.731 1748.1,924.722 1748.08,924.713 1748.06,924.704 1748.04,924.696 1748.02,924.687 1748,924.678 1747.98,924.669 1747.96,924.66 1747.94,924.651 1747.92,924.642 1747.9,924.634 1747.88,924.625 1747.86,924.616 1747.85,924.607 1747.83,924.598 1747.81,924.589 1747.79,924.581 1747.77,924.572 1747.75,924.563 1747.73,924.554 1747.71,924.545 1747.69,924.537 1747.67,924.528 1747.65,924.519 1747.63,924.51 1747.61,924.501 1747.59,924.492 1747.57,924.484 1747.55,924.475 1747.54,924.466 1747.52,924.457 1747.5,924.448 1747.48,924.44 1747.46,924.431 1747.44,924.422 1747.42,924.413 1747.4,924.404 1747.38,924.396 1747.36,924.387 1747.34,924.378 1747.32,924.369 1747.3,924.36 1747.28,924.352 1747.26,924.343 1747.25,924.334 1747.23,924.325 1747.21,924.316 1747.19,924.308 1747.17,924.299 1747.15,924.29 1747.13,924.281 1747.11,924.273 1747.09,924.264 1747.07,924.255 1747.05,924.246 1747.03,924.237 1747.01,924.229 1746.99,924.22 1746.98,924.211 1746.96,924.202 1746.94,924.194 1746.92,924.185 1746.9,924.176 1746.88,924.167 1746.86,924.158 1746.84,924.15 1746.82,924.141 1746.8,924.132 1746.78,924.123 1746.76,924.115 1746.74,924.106 1746.72,924.097 1746.7,924.088 1746.69,924.08 1746.67,924.071 1746.65,924.062 1746.63,924.053 1746.61,924.045 1746.59,924.036 1746.57,924.027 1746.55,924.018 1746.53,924.01 1746.51,924.001 1746.49,923.992 1746.47,923.983 1746.45,923.975 1746.43,923.966 1746.42,923.957 1746.4,923.949 1746.38,923.94 1746.36,923.931 1746.34,923.922 1746.32,923.914 1746.3,923.905 1746.28,923.896 1746.26,923.887 1746.24,923.879 1746.22,923.87 1746.2,923.861 1746.18,923.853 1746.16,923.844 1746.15,923.835 1746.13,923.826 1746.11,923.818 1746.09,923.809 1746.07,923.8 1746.05,923.792 1746.03,923.783 1746.01,923.774 1745.99,923.766 1745.97,923.757 1745.95,923.748 1745.93,923.739 1745.91,923.731 1745.9,923.722 1745.88,923.713 1745.86,923.705 1745.84,923.696 1745.82,923.687 1745.8,923.679 1745.78,923.67 1745.76,923.661 1745.74,923.652 1745.72,923.644 1745.7,923.635 1745.68,923.626 1745.66,923.618 1745.64,923.609 1745.63,923.6 1745.61,923.592 1745.59,923.583 1745.57,923.574 1745.55,923.566 1745.53,923.557 1745.51,923.548 1745.49,923.54 1745.47,923.531 1745.45,923.522 1745.43,923.514 1745.41,923.505 1745.39,923.496 1745.38,923.488 1745.36,923.479 1745.34,923.47 1745.32,923.462 1745.3,923.453 1745.28,923.444 1745.26,923.436 1745.24,923.427 1745.22,923.418 1745.2,923.41 1745.18,923.401 1745.16,923.393 1745.14,923.384 1745.13,923.375 1745.11,923.367 1745.09,923.358 1745.07,923.349 1745.05,923.341 1745.03,923.332 1745.01,923.323 1744.99,923.315 1744.97,923.306 1744.95,923.297 1744.93,923.289 1744.91,923.28 1744.89,923.272 1744.88,923.263 1744.86,923.254 1744.84,923.246 1744.82,923.237 1744.8,923.228 1744.78,923.22 1744.76,923.211 1744.74,923.203 1744.72,923.194 1744.7,923.185 1744.68,923.177 1744.66,923.168 1744.65,923.16 1744.63,923.151 1744.61,923.142 1744.59,923.134 1744.57,923.125 1744.55,923.117 1744.53,923.108 1744.51,923.099 1744.49,923.091 1744.47,923.082 1744.45,923.074 1744.43,923.065 1744.41,923.056 1744.4,923.048 1744.38,923.039 1744.36,923.031 1744.34,923.022 1744.32,923.013 1744.3,923.005 1744.28,922.996 1744.26,922.988 1744.24,922.979 1744.22,922.97 1744.2,922.962 1744.18,922.953 1744.17,922.945 1744.15,922.936 1744.13,922.928 1744.11,922.919 1744.09,922.91 1744.07,922.902 1744.05,922.893 1744.03,922.885 1744.01,922.876 1743.99,922.868 1743.97,922.859 1743.95,922.85 1743.94,922.842 1743.92,922.833 1743.9,922.825 1743.88,922.816 1743.86,922.808 1743.84,922.799 1743.82,922.791 1743.8,922.782 1743.78,922.773 1743.76,922.765 1743.74,922.756 1743.72,922.748 1743.71,922.739 1743.69,922.731 1743.67,922.722 1743.65,922.714 1743.63,922.705 1743.61,922.697 1743.59,922.688 1743.57,922.679 1743.55,922.671 1743.53,922.662 1743.51,922.654 1743.5,922.645 1743.48,922.637 1743.46,922.628 1743.44,922.62 1743.42,922.611 1743.4,922.603 1743.38,922.594 1743.36,922.586 1743.34,922.577 1743.32,922.569 1743.3,922.56 1743.28,922.552 1743.27,922.543 1743.25,922.534 1743.23,922.526 1743.21,922.517 1743.19,922.509 1743.17,922.5 1743.15,922.492 1743.13,922.483 1743.11,922.475 1743.09,922.466 1743.07,922.458 1743.06,922.449 1743.04,922.441 1743.02,922.432 1743,922.424 1742.98,922.415 1742.96,922.407 1742.94,922.398 1742.92,922.39 1742.9,922.381 1742.88,922.373 1742.86,922.364 1742.85,922.356 1742.83,922.347 1742.81,922.339 1742.79,922.33 1742.77,922.322 1742.75,922.314 1742.73,922.305 1742.71,922.297 1742.69,922.288 1742.67,922.28 1742.65,922.271 1742.63,922.263 1742.62,922.254 1742.6,922.246 1742.58,922.237 1742.56,922.229 1742.54,922.22 1742.52,922.212 1742.5,922.203 1742.48,922.195 1742.46,922.186 1742.44,922.178 1742.42,922.17 1742.41,922.161 1742.39,922.153 1742.37,922.144 1742.35,922.136 1742.33,922.127 1742.31,922.119 1742.29,922.11 1742.27,922.102 1742.25,922.093 1742.23,922.085 1742.22,922.077 1742.2,922.068 1742.18,922.06 1742.16,922.051 1742.14,922.043 1742.12,922.034 1742.1,922.026 1742.08,922.017 1742.06,922.009 1742.04,922.001 1742.02,921.992 1742.01,921.984 1741.99,921.975 1741.97,921.967 1741.95,921.958 1741.93,921.95 1741.91,921.942 1741.89,921.933 1741.87,921.925 1741.85,921.916 1741.83,921.908 1741.81,921.899 1741.8,921.891 1741.78,921.883 1741.76,921.874 1741.74,921.866 1741.72,921.857 1741.7,921.849 1741.68,921.841 1741.66,921.832 1741.64,921.824 1741.62,921.815 1741.61,921.807 1741.59,921.799 1741.57,921.79 1741.55,921.782 1741.53,921.773 1741.51,921.765 1741.49,921.757 1741.47,921.748 1741.45,921.74 1741.43,921.731 1741.41,921.723 1741.4,921.715 1741.38,921.706 1741.36,921.698 1741.34,921.689 1741.32,921.681 1741.3,921.673 1741.28,921.664 1741.26,921.656 1741.24,921.647 1741.22,921.639 1741.21,921.631 1741.19,921.622 1741.17,921.614 1741.15,921.606 1741.13,921.597 1741.11,921.589 1741.09,921.58 1741.07,921.572 1741.05,921.564 1741.03,921.555 1741.02,921.547 1741,921.539 1740.98,921.53 1740.96,921.522 1740.94,921.513 1740.92,921.505 1740.9,921.497 1740.88,921.488 1740.86,921.48 1740.84,921.472 1740.83,921.463 1740.81,921.455 1740.79,921.447 1740.77,921.438 1740.75,921.43 1740.73,921.422 1740.71,921.413 1740.69,921.405 1740.67,921.397 1740.65,921.388 1740.64,921.38 1740.62,921.372 1740.6,921.363 1740.58,921.355 1740.56,921.347 1740.54,921.338 1740.52,921.33 1740.5,921.322 1740.48,921.313 1740.46,921.305 1740.45,921.297 1740.43,921.288 1740.41,921.28 1740.39,921.272 1740.37,921.263 1740.35,921.255 1740.33,921.247 1740.31,921.238 1740.29,921.23 1740.27,921.222 1740.26,921.213 1740.24,921.205 1740.22,921.197 1740.2,921.188 1740.18,921.18 1740.16,921.172 1740.14,921.163 1740.12,921.155 1740.1,921.147 1740.09,921.139 1740.07,921.13 1740.05,921.122 1740.03,921.114 1740.01,921.105 1739.99,921.097 1739.97,921.089 1739.95,921.08 1739.93,921.072 1739.91,921.064 1739.9,921.056 1739.88,921.047 1739.86,921.039 1739.84,921.031 1739.82,921.022 1739.8,921.014 1739.78,921.006 1739.76,920.998 1739.74,920.989 1739.73,920.981 1739.71,920.973 1739.69,920.964 1739.67,920.956 1739.65,920.948 1739.63,920.94 1739.61,920.931 1739.59,920.923 1739.57,920.915 1739.55,920.906 1739.54,920.898 1739.52,920.89 1739.5,920.882 1739.48,920.873 1739.46,920.865 1739.44,920.857 1739.42,920.849 1739.4,920.84 1739.38,920.832 1739.37,920.824 1739.35,920.816 1739.33,920.807 1739.31,920.799 1739.29,920.791 1739.27,920.783 1739.25,920.774 1739.23,920.766 1739.21,920.758 1739.2,920.75 1739.18,920.741 1739.16,920.733 1739.14,920.725 1739.12,920.717 1739.1,920.708 1739.08,920.7 1739.06,920.692 1739.04,920.684 1739.03,920.675 1739.01,920.667 1738.99,920.659 1738.97,920.651 1738.95,920.642 1738.93,920.634 1738.91,920.626 1738.89,920.618 1738.87,920.61 1738.86,920.601 1738.84,920.593 1738.82,920.585 1738.8,920.577 1738.78,920.568 1738.76,920.56 1738.74,920.552 1738.72,920.544 1738.7,920.536 1738.69,920.527 1738.67,920.519 1738.65,920.511 1738.63,920.503 1738.61,920.494 1738.59,920.486 1738.57,920.478 1738.55,920.47 1738.53,920.462 1738.52,920.453 1738.5,920.445 1738.48,920.437 1738.46,920.429 1738.44,920.421 1738.42,920.412 1738.4,920.404 1738.38,920.396 1738.36,920.388 1738.35,920.38 1738.33,920.372 1738.31,920.363 1738.29,920.355 1738.27,920.347 1738.25,920.339 1738.23,920.331 1738.21,920.322 1738.19,920.314 1738.18,920.306 1738.16,920.298 1738.14,920.29 1738.12,920.281 1738.1,920.273 1738.08,920.265 1738.06,920.257 1738.04,920.249 1738.02,920.241 1738.01,920.232 1737.99,920.224 1737.97,920.216 1737.95,920.208 1737.93,920.2 1737.91,920.192 1737.89,920.183 1737.87,920.175 1737.86,920.167 1737.84,920.159 1737.82,920.151 1737.8,920.143 1737.78,920.135 1737.76,920.126 1737.74,920.118 1737.72,920.11 1737.7,920.102 1737.69,920.094 1737.67,920.086 1737.65,920.077 1737.63,920.069 1737.61,920.061 1737.59,920.053 1737.57,920.045 1737.55,920.037 1737.53,920.029 1737.52,920.02 1737.5,920.012 1737.48,920.004 1737.46,919.996 1737.44,919.988 1737.42,919.98 1737.4,919.972 1737.38,919.964 1737.37,919.955 1737.35,919.947 1737.33,919.939 1737.31,919.931 1737.29,919.923 1737.27,919.915 1737.25,919.907 1737.23,919.899 1737.22,919.89 1737.2,919.882 1737.18,919.874 1737.16,919.866 1737.14,919.858 1737.12,919.85 1737.1,919.842 1737.08,919.834 1737.06,919.825 1737.05,919.817 1737.03,919.809 1737.01,919.801 1736.99,919.793 1736.97,919.785 1736.95,919.777 1736.93,919.769 1736.91,919.761 1736.9,919.753 1736.88,919.744 1736.86,919.736 1736.84,919.728 1736.82,919.72 1736.8,919.712 1736.78,919.704 1736.76,919.696 1736.75,919.688 1736.73,919.68 1736.71,919.672 1736.69,919.664 1736.67,919.655 1736.65,919.647 1736.63,919.639 1736.61,919.631 1736.59,919.623 1736.58,919.615 1736.56,919.607 1736.54,919.599 1736.52,919.591 1736.5,919.583 1736.48,919.575 1736.46,919.567 1736.44,919.559 1736.43,919.55 1736.41,919.542 1736.39,919.534 1736.37,919.526 1736.35,919.518 1736.33,919.51 1736.31,919.502 1736.29,919.494 1736.28,919.486 1736.26,919.478 1736.24,919.47 1736.22,919.462 1736.2,919.454 1736.18,919.446 1736.16,919.438 1736.14,919.43 1736.13,919.422 1736.11,919.413 1736.09,919.405 1736.07,919.397 1736.05,919.389 1736.03,919.381 1736.01,919.373 1735.99,919.365 1735.98,919.357 1735.96,919.349 1735.94,919.341 1735.92,919.333 1735.9,919.325 1735.88,919.317 1735.86,919.309 1735.84,919.301 1735.83,919.293 1735.81,919.285 1735.79,919.277 1735.77,919.269 1735.75,919.261 1735.73,919.253 1735.71,919.245 1735.7,919.237 1735.68,919.229 1735.66,919.221 1735.64,919.213 1735.62,919.205 1735.6,919.197 1735.58,919.189 1735.56,919.181 1735.55,919.173 1735.53,919.165 1735.51,919.157 1735.49,919.149 1735.47,919.141 1735.45,919.133 1735.43,919.125 1735.41,919.117 1735.4,919.109 1735.38,919.101 1735.36,919.093 1735.34,919.085 1735.32,919.077 1735.3,919.069 1735.28,919.061 1735.26,919.053 1735.25,919.045 1735.23,919.037 1735.21,919.029 1735.19,919.021 1735.17,919.013 1735.15,919.005 1735.13,918.997 1735.12,918.989 1735.1,918.981 1735.08,918.973 1735.06,918.965 1735.04,918.957 1735.02,918.949 1735,918.941 1734.98,918.933 1734.97,918.925 1734.95,918.917 1734.93,918.909 1734.91,918.901 1734.89,918.893 1734.87,918.885 1734.85,918.877 1734.83,918.869 1734.82,918.861 1734.8,918.853 1734.78,918.845 1734.76,918.837 1734.74,918.829 1734.72,918.821 1734.7,918.813 1734.69,918.805 1734.67,918.797 1734.65,918.789 1734.63,918.781 1734.61,918.773 1734.59,918.766 1734.57,918.758 1734.55,918.75 1734.54,918.742 1734.52,918.734 1734.5,918.726 1734.48,918.718 1734.46,918.71 1734.44,918.702 1734.42,918.694 1734.41,918.686 1734.39,918.678 1734.37,918.67 1734.35,918.662 1734.33,918.654 1734.31,918.646 1734.29,918.638 1734.28,918.63 1734.26,918.623 1734.24,918.615 1734.22,918.607 1734.2,918.599 1734.18,918.591 1734.16,918.583 1734.14,918.575 1734.13,918.567 1734.11,918.559 1734.09,918.551 1734.07,918.543 1734.05,918.535 1734.03,918.527 1734.01,918.52 1734,918.512 1733.98,918.504 1733.96,918.496 1733.94,918.488 1733.92,918.48 1733.9,918.472 1733.88,918.464 1733.87,918.456 1733.85,918.448 1733.83,918.44 1733.81,918.433 1733.79,918.425 1733.77,918.417 1733.75,918.409 1733.73,918.401 1733.72,918.393 1733.7,918.385 1733.68,918.377 1733.66,918.369 1733.64,918.361 1733.62,918.354 1733.6,918.346 1733.59,918.338 1733.57,918.33 1733.55,918.322 1733.53,918.314 1733.51,918.306 1733.49,918.298 1733.47,918.29 1733.46,918.283 1733.44,918.275 1733.42,918.267 1733.4,918.259 1733.38,918.251 1733.36,918.243 1733.34,918.235 1733.33,918.227 1733.31,918.22 1733.29,918.212 1733.27,918.204 1733.25,918.196 1733.23,918.188 1733.21,918.18 1733.2,918.172 1733.18,918.165 1733.16,918.157 1733.14,918.149 1733.12,918.141 1733.1,918.133 1733.08,918.125 1733.07,918.117 1733.05,918.109 1733.03,918.102 1733.01,918.094 1732.99,918.086 1732.97,918.078 1732.95,918.07 1732.94,918.062 1732.92,918.055 1732.9,918.047 1732.88,918.039 1732.86,918.031 1732.84,918.023 1732.82,918.015 1732.81,918.007 1732.79,918 1732.77,917.992 1732.75,917.984 1732.73,917.976 1732.71,917.968 1732.69,917.96 1732.68,917.953 1732.66,917.945 1732.64,917.937 1732.62,917.929 1732.6,917.921 1732.58,917.913 1732.56,917.906 1732.55,917.898 1732.53,917.89 1732.51,917.882 1732.49,917.874 1732.47,917.867 1732.45,917.859 1732.43,917.851 1732.42,917.843 1732.4,917.835 1732.38,917.827 1732.36,917.82 1732.34,917.812 1732.32,917.804 1732.3,917.796 1732.29,917.788 1732.27,917.781 1732.25,917.773 1732.23,917.765 1732.21,917.757 1732.19,917.749 1732.17,917.742 1732.16,917.734 1732.14,917.726 1732.12,917.718 1732.1,917.71 1732.08,917.703 1732.06,917.695 1732.05,917.687 1732.03,917.679 1732.01,917.671 1731.99,917.664 1731.97,917.656 1731.95,917.648 1731.93,917.64 1731.92,917.632 1731.9,917.625 1731.88,917.617 1731.86,917.609 1731.84,917.601 1731.82,917.593 1731.8,917.586 1731.79,917.578 1731.77,917.57 1731.75,917.562 1731.73,917.555 1731.71,917.547 1731.69,917.539 1731.68,917.531 1731.66,917.524 1731.64,917.516 1731.62,917.508 1731.6,917.5 1731.58,917.492 1731.56,917.485 1731.55,917.477 1731.53,917.469 1731.51,917.461 1731.49,917.454 1731.47,917.446 1731.45,917.438 1731.43,917.43 1731.42,917.423 1731.4,917.415 1731.38,917.407 1731.36,917.399 1731.34,917.392 1731.32,917.384 1731.31,917.376 1731.29,917.368 1731.27,917.361 1731.25,917.353 1731.23,917.345 1731.21,917.337 1731.19,917.33 1731.18,917.322 1731.16,917.314 1731.14,917.306 1731.12,917.299 1731.1,917.291 1731.08,917.283 1731.07,917.275 1731.05,917.268 1731.03,917.26 1731.01,917.252 1730.99,917.245 1730.97,917.237 1730.95,917.229 1730.94,917.221 1730.92,917.214 1730.9,917.206 1730.88,917.198 1730.86,917.19 1730.84,917.183 1730.83,917.175 1730.81,917.167 1730.79,917.16 1730.77,917.152 1730.75,917.144 1730.73,917.136 1730.71,917.129 1730.7,917.121 1730.68,917.113 1730.66,917.106 1730.64,917.098 1730.62,917.09 1730.6,917.082 1730.59,917.075 1730.57,917.067 1730.55,917.059 1730.53,917.052 1730.51,917.044 1730.49,917.036 1730.47,917.029 1730.46,917.021 1730.44,917.013 1730.42,917.005 1730.4,916.998 1730.38,916.99 1730.36,916.982 1730.35,916.975 1730.33,916.967 1730.31,916.959 1730.29,916.952 1730.27,916.944 1730.25,916.936 1730.24,916.929 1730.22,916.921 1730.2,916.913 1730.18,916.906 1730.16,916.898 1730.14,916.89 1730.12,916.882 1730.11,916.875 1730.09,916.867 1730.07,916.859 1730.05,916.852 1730.03,916.844 1730.01,916.836 1730,916.829 1729.98,916.821 1729.96,916.813 1729.94,916.806 1729.92,916.798 1729.9,916.79 1729.89,916.783 1729.87,916.775 1729.85,916.767 1729.83,916.76 1729.81,916.752 1729.79,916.744 1729.78,916.737 1729.76,916.729 1729.74,916.722 1729.72,916.714 1729.7,916.706 1729.68,916.699 1729.66,916.691 1729.65,916.683 1729.63,916.676 1729.61,916.668 1729.59,916.66 1729.57,916.653 1729.55,916.645 1729.54,916.637 1729.52,916.63 1729.5,916.622 1729.48,916.614 1729.46,916.607 1729.44,916.599 1729.43,916.592 1729.41,916.584 1729.39,916.576 1729.37,916.569 1729.35,916.561 1729.33,916.553 1729.32,916.546 1729.3,916.538 1729.28,916.531 1729.26,916.523 1729.24,916.515 1729.22,916.508 1729.21,916.5 1729.19,916.492 1729.17,916.485 1729.15,916.477 1729.13,916.47 1729.11,916.462 1729.1,916.454 1729.08,916.447 1729.06,916.439 1729.04,916.431 1729.02,916.424 1729,916.416 1728.99,916.409 1728.97,916.401 1728.95,916.393 1728.93,916.386 1728.91,916.378 1728.89,916.371 1728.88,916.363 1728.86,916.355 1728.84,916.348 1728.82,916.34 1728.8,916.333 1728.78,916.325 1728.77,916.317 1728.75,916.31 1728.73,916.302 1728.71,916.295 1728.69,916.287 1728.67,916.279 1728.66,916.272 1728.64,916.264 1728.62,916.257 1728.6,916.249 1728.58,916.242 1728.56,916.234 1728.55,916.226 1728.53,916.219 1728.51,916.211 1728.49,916.204 1728.47,916.196 1728.45,916.188 1728.44,916.181 1728.42,916.173 1728.4,916.166 1728.38,916.158 1728.36,916.151 1728.34,916.143 1728.33,916.135 1728.31,916.128 1728.29,916.12 1728.27,916.113 1728.25,916.105 1728.23,916.098 1728.22,916.09 1728.2,916.082 1728.18,916.075 1728.16,916.067 1728.14,916.06 1728.12,916.052 1728.11,916.045 1728.09,916.037 1728.07,916.03 1728.05,916.022 1728.03,916.014 1728.01,916.007 1728,915.999 1727.98,915.992 1727.96,915.984 1727.94,915.977 1727.92,915.969 1727.9,915.962 1727.89,915.954 1727.87,915.947 1727.85,915.939 1727.83,915.931 1727.81,915.924 1727.8,915.916 1727.78,915.909 1727.76,915.901 1727.74,915.894 1727.72,915.886 1727.7,915.879 1727.69,915.871 1727.67,915.864 1727.65,915.856 1727.63,915.849 1727.61,915.841 1727.59,915.834 1727.58,915.826 1727.56,915.819 1727.54,915.811 1727.52,915.803 1727.5,915.796 1727.48,915.788 1727.47,915.781 1727.45,915.773 1727.43,915.766 1727.41,915.758 1727.39,915.751 1727.38,915.743 1727.36,915.736 1727.34,915.728 1727.32,915.721 1727.3,915.713 1727.28,915.706 1727.27,915.698 1727.25,915.691 1727.23,915.683 1727.21,915.676 1727.19,915.668 1727.17,915.661 1727.16,915.653 1727.14,915.646 1727.12,915.638 1727.1,915.631 1727.08,915.623 1727.07,915.616 1727.05,915.608 1727.03,915.601 1727.01,915.593 1726.99,915.586 1726.97,915.578 1726.96,915.571 1726.94,915.563 1726.92,915.556 1726.9,915.548 1726.88,915.541 1726.86,915.533 1726.85,915.526 1726.83,915.518 1726.81,915.511 1726.79,915.504 1726.77,915.496 1726.76,915.489 1726.74,915.481 1726.72,915.474 1726.7,915.466 1726.68,915.459 1726.66,915.451 1726.65,915.444 1726.63,915.436 1726.61,915.429 1726.59,915.421 1726.57,915.414 1726.55,915.406 1726.54,915.399 1726.52,915.391 1726.5,915.384 1726.48,915.377 1726.46,915.369 1726.45,915.362 1726.43,915.354 1726.41,915.347 1726.39,915.339 1726.37,915.332 1726.35,915.324 1726.34,915.317 1726.32,915.309 1726.3,915.302 1726.28,915.295 1726.26,915.287 1726.25,915.28 1726.23,915.272 1726.21,915.265 1726.19,915.257 1726.17,915.25 1726.15,915.242 1726.14,915.235 1726.12,915.228 1726.1,915.22 1726.08,915.213 1726.06,915.205 1726.05,915.198 1726.03,915.19 1726.01,915.183 1725.99,915.176 1725.97,915.168 1725.95,915.161 1725.94,915.153 1725.92,915.146 1725.9,915.138 1725.88,915.131 1725.86,915.124 1725.85,915.116 1725.83,915.109 1725.81,915.101 1725.79,915.094 1725.77,915.086 1725.76,915.079 1725.74,915.072 1725.72,915.064 1725.7,915.057 1725.68,915.049 1725.66,915.042 1725.65,915.035 1725.63,915.027 1725.61,915.02 1725.59,915.012 1725.57,915.005 1725.56,914.997 1725.54,914.99 1725.52,914.983 1725.5,914.975 1725.48,914.968 1725.46,914.96 1725.45,914.953 1725.43,914.946 1725.41,914.938 1725.39,914.931 1725.37,914.923 1725.36,914.916 1725.34,914.909 1725.32,914.901 1725.3,914.894 1725.28,914.887 1725.27,914.879 1725.25,914.872 1725.23,914.864 1725.21,914.857 1725.19,914.85 1725.17,914.842 1725.16,914.835 1725.14,914.827 1725.12,914.82 1725.1,914.813 1725.08,914.805 1725.07,914.798 1725.05,914.791 1725.03,914.783 1725.01,914.776 1724.99,914.768 1724.98,914.761 1724.96,914.754 1724.94,914.746 1724.92,914.739 1724.9,914.732 1724.88,914.724 1724.87,914.717 1724.85,914.709 1724.83,914.702 1724.81,914.695 1724.79,914.687 1724.78,914.68 1724.76,914.673 1724.74,914.665 1724.72,914.658 1724.7,914.651 1724.69,914.643 1724.67,914.636 1724.65,914.629 1724.63,914.621 1724.61,914.614 1724.6,914.606 1724.58,914.599 1724.56,914.592 1724.54,914.584 1724.52,914.577 1724.5,914.57 1724.49,914.562 1724.47,914.555 1724.45,914.548 1724.43,914.54 1724.41,914.533 1724.4,914.526 1724.38,914.518 1724.36,914.511 1724.34,914.504 1724.32,914.496 1724.31,914.489 1724.29,914.482 1724.27,914.474 1724.25,914.467 1724.23,914.46 1724.22,914.452 1724.2,914.445 1724.18,914.438 1724.16,914.43 1724.14,914.423 1724.13,914.416 1724.11,914.408 1724.09,914.401 1724.07,914.394 1724.05,914.386 1724.03,914.379 1724.02,914.372 1724,914.364 1723.98,914.357 1723.96,914.35 1723.94,914.343 1723.93,914.335 1723.91,914.328 1723.89,914.321 1723.87,914.313 1723.85,914.306 1723.84,914.299 1723.82,914.291 1723.8,914.284 1723.78,914.277 1723.76,914.269 1723.75,914.262 1723.73,914.255 1723.71,914.248 1723.69,914.24 1723.67,914.233 1723.66,914.226 1723.64,914.218 1723.62,914.211 1723.6,914.204 1723.58,914.197 1723.57,914.189 1723.55,914.182 1723.53,914.175 1723.51,914.167 1723.49,914.16 1723.48,914.153 1723.46,914.146 1723.44,914.138 1723.42,914.131 1723.4,914.124 1723.39,914.116 1723.37,914.109 1723.35,914.102 1723.33,914.095 1723.31,914.087 1723.3,914.08 1723.28,914.073 1723.26,914.065 1723.24,914.058 1723.22,914.051 1723.21,914.044 1723.19,914.036 1723.17,914.029 1723.15,914.022 1723.13,914.015 1723.12,914.007 1723.1,914 1723.08,913.993 1723.06,913.986 1723.04,913.978 1723.03,913.971 1723.01,913.964 1722.99,913.956 1722.97,913.949 1722.95,913.942 1722.94,913.935 1722.92,913.927 1722.9,913.92 1722.88,913.913 1722.86,913.906 1722.85,913.898 1722.83,913.891 1722.81,913.884 1722.79,913.877 1722.77,913.869 1722.76,913.862 1722.74,913.855 1722.72,913.848 1722.7,913.84 1722.68,913.833 1722.67,913.826 1722.65,913.819 1722.63,913.812 1722.61,913.804 1722.59,913.797 1722.58,913.79 1722.56,913.783 1722.54,913.775 1722.52,913.768 1722.5,913.761 1722.49,913.754 1722.47,913.746 1722.45,913.739 1722.43,913.732 1722.41,913.725 1722.4,913.718 1722.38,913.71 1722.36,913.703 1722.34,913.696 1722.32,913.689 1722.31,913.681 1722.29,913.674 1722.27,913.667 1722.25,913.66 1722.23,913.653 1722.22,913.645 1722.2,913.638 1722.18,913.631 1722.16,913.624 1722.15,913.616 1722.13,913.609 1722.11,913.602 1722.09,913.595 1722.07,913.588 1722.06,913.58 1722.04,913.573 1722.02,913.566 1722,913.559 1721.98,913.552 1721.97,913.544 1721.95,913.537 1721.93,913.53 1721.91,913.523 1721.89,913.516 1721.88,913.508 1721.86,913.501 1721.84,913.494 1721.82,913.487 1721.8,913.48 1721.79,913.473 1721.77,913.465 1721.75,913.458 1721.73,913.451 1721.71,913.444 1721.7,913.437 1721.68,913.429 1721.66,913.422 1721.64,913.415 1721.63,913.408 1721.61,913.401 1721.59,913.394 1721.57,913.386 1721.55,913.379 1721.54,913.372 1721.52,913.365 1721.5,913.358 1721.48,913.35 1721.46,913.343 1721.45,913.336 1721.43,913.329 1721.41,913.322 1721.39,913.315 1721.37,913.307 1721.36,913.3 1721.34,913.293 1721.32,913.286 1721.3,913.279 1721.29,913.272 1721.27,913.264 1721.25,913.257 1721.23,913.25 1721.21,913.243 1721.2,913.236 1721.18,913.229 1721.16,913.222 1721.14,913.214 1721.12,913.207 1721.11,913.2 1721.09,913.193 1721.07,913.186 1721.05,913.179 1721.03,913.171 1721.02,913.164 1721,913.157 1720.98,913.15 1720.96,913.143 1720.95,913.136 1720.93,913.129 1720.91,913.121 1720.89,913.114 1720.87,913.107 1720.86,913.1 1720.84,913.093 1720.82,913.086 1720.8,913.079 1720.78,913.072 1720.77,913.064 1720.75,913.057 1720.73,913.05 1720.71,913.043 1720.7,913.036 1720.68,913.029 1720.66,913.022 1720.64,913.014 1720.62,913.007 1720.61,913 1720.59,912.993 1720.57,912.986 1720.55,912.979 1720.53,912.972 1720.52,912.965 1720.5,912.958 1720.48,912.95 1720.46,912.943 1720.45,912.936 1720.43,912.929 1720.41,912.922 1720.39,912.915 1720.37,912.908 1720.36,912.901 1720.34,912.894 1720.32,912.886 1720.3,912.879 1720.29,912.872 1720.27,912.865 1720.25,912.858 1720.23,912.851 1720.21,912.844 1720.2,912.837 1720.18,912.83 1720.16,912.823 1720.14,912.815 1720.12,912.808 1720.11,912.801 1720.09,912.794 1720.07,912.787 1720.05,912.78 1720.04,912.773 1720.02,912.766 1720,912.759 1719.98,912.752 1719.96,912.744 1719.95,912.737 1719.93,912.73 1719.91,912.723 1719.89,912.716 1719.88,912.709 1719.86,912.702 1719.84,912.695 1719.82,912.688 1719.8,912.681 1719.79,912.674 1719.77,912.667 1719.75,912.66 1719.73,912.652 1719.72,912.645 1719.7,912.638 1719.68,912.631 1719.66,912.624 1719.64,912.617 1719.63,912.61 1719.61,912.603 1719.59,912.596 1719.57,912.589 1719.55,912.582 1719.54,912.575 1719.52,912.568 1719.5,912.561 1719.48,912.554 1719.47,912.546 1719.45,912.539 1719.43,912.532 1719.41,912.525 1719.39,912.518 1719.38,912.511 1719.36,912.504 1719.34,912.497 1719.32,912.49 1719.31,912.483 1719.29,912.476 1719.27,912.469 1719.25,912.462 1719.23,912.455 1719.22,912.448 1719.2,912.441 1719.18,912.434 1719.16,912.427 1719.15,912.42 1719.13,912.413 1719.11,912.405 1719.09,912.398 1719.08,912.391 1719.06,912.384 1719.04,912.377 1719.02,912.37 1719,912.363 1718.99,912.356 1718.97,912.349 1718.95,912.342 1718.93,912.335 1718.92,912.328 1718.9,912.321 1718.88,912.314 1718.86,912.307 1718.84,912.3 1718.83,912.293 1718.81,912.286 1718.79,912.279 1718.77,912.272 1718.76,912.265 1718.74,912.258 1718.72,912.251 1718.7,912.244 1718.68,912.237 1718.67,912.23 1718.65,912.223 1718.63,912.216 1718.61,912.209 1718.6,912.202 1718.58,912.195 1718.56,912.188 1718.54,912.181 1718.53,912.174 1718.51,912.167 1718.49,912.16 1718.47,912.153 1718.45,912.146 1718.44,912.139 1718.42,912.132 1718.4,912.125 1718.38,912.118 1718.37,912.111 1718.35,912.104 1718.33,912.097 1718.31,912.09 1718.29,912.083 1718.28,912.076 1718.26,912.069 1718.24,912.062 1718.22,912.055 1718.21,912.048 1718.19,912.041 1718.17,912.034 1718.15,912.027 1718.14,912.02 1718.12,912.013 1718.1,912.006 1718.08,911.999 1718.06,911.992 1718.05,911.985 1718.03,911.978 1718.01,911.971 1717.99,911.964 1717.98,911.957 1717.96,911.95 1717.94,911.943 1717.92,911.936 1717.91,911.929 1717.89,911.922 1717.87,911.915 1717.85,911.908 1717.83,911.901 1717.82,911.894 1717.8,911.887 1717.78,911.88 1717.76,911.873 1717.75,911.866 1717.73,911.859 1717.71,911.852 1717.69,911.845 1717.68,911.839 1717.66,911.832 1717.64,911.825 1717.62,911.818 1717.61,911.811 1717.59,911.804 1717.57,911.797 1717.55,911.79 1717.53,911.783 1717.52,911.776 1717.5,911.769 1717.48,911.762 1717.46,911.755 1717.45,911.748 1717.43,911.741 1717.41,911.734 1717.39,911.727 1717.38,911.72 1717.36,911.713 1717.34,911.706 1717.32,911.7 1717.3,911.693 1717.29,911.686 1717.27,911.679 1717.25,911.672 1717.23,911.665 1717.22,911.658 1717.2,911.651 1717.18,911.644 1717.16,911.637 1717.15,911.63 1717.13,911.623 1717.11,911.616 1717.09,911.609 1717.08,911.602 1717.06,911.596 1717.04,911.589 1717.02,911.582 1717.01,911.575 1716.99,911.568 1716.97,911.561 1716.95,911.554 1716.93,911.547 1716.92,911.54 1716.9,911.533 1716.88,911.526 1716.86,911.519 1716.85,911.512 1716.83,911.506 1716.81,911.499 1716.79,911.492 1716.78,911.485 1716.76,911.478 1716.74,911.471 1716.72,911.464 1716.71,911.457 1716.69,911.45 1716.67,911.443 1716.65,911.436 1716.64,911.43 1716.62,911.423 1716.6,911.416 1716.58,911.409 1716.56,911.402 1716.55,911.395 1716.53,911.388 1716.51,911.381 1716.49,911.374 1716.48,911.367 1716.46,911.361 1716.44,911.354 1716.42,911.347 1716.41,911.34 1716.39,911.333 1716.37,911.326 1716.35,911.319 1716.34,911.312 1716.32,911.305 1716.3,911.299 1716.28,911.292 1716.27,911.285 1716.25,911.278 1716.23,911.271 1716.21,911.264 1716.2,911.257 1716.18,911.25 1716.16,911.244 1716.14,911.237 1716.13,911.23 1716.11,911.223 1716.09,911.216 1716.07,911.209 1716.05,911.202 1716.04,911.195 1716.02,911.189 1716,911.182 1715.98,911.175 1715.97,911.168 1715.95,911.161 1715.93,911.154 1715.91,911.147 1715.9,911.14 1715.88,911.134 1715.86,911.127 1715.84,911.12 1715.83,911.113 1715.81,911.106 1715.79,911.099 1715.77,911.092 1715.76,911.086 1715.74,911.079 1715.72,911.072 1715.7,911.065 1715.69,911.058 1715.67,911.051 1715.65,911.044 1715.63,911.038 1715.62,911.031 1715.6,911.024 1715.58,911.017 1715.56,911.01 1715.55,911.003 1715.53,910.997 1715.51,910.99 1715.49,910.983 1715.48,910.976 1715.46,910.969 1715.44,910.962 1715.42,910.956 1715.41,910.949 1715.39,910.942 1715.37,910.935 1715.35,910.928 1715.34,910.921 1715.32,910.915 1715.3,910.908 1715.28,910.901 1715.27,910.894 1715.25,910.887 1715.23,910.88 1715.21,910.874 1715.2,910.867 1715.18,910.86 1715.16,910.853 1715.14,910.846 1715.13,910.839 1715.11,910.833 1715.09,910.826 1715.07,910.819 1715.06,910.812 1715.04,910.805 1715.02,910.799 1715,910.792 1714.98,910.785 1714.97,910.778 1714.95,910.771 1714.93,910.764 1714.91,910.758 1714.9,910.751 1714.88,910.744 1714.86,910.737 1714.84,910.73 1714.83,910.724 1714.81,910.717 1714.79,910.71 1714.78,910.703 1714.76,910.696 1714.74,910.69 1714.72,910.683 1714.71,910.676 1714.69,910.669 1714.67,910.662 1714.65,910.656 1714.64,910.649 1714.62,910.642 1714.6,910.635 1714.58,910.628 1714.57,910.622 1714.55,910.615 1714.53,910.608 1714.51,910.601 1714.5,910.594 1714.48,910.588 1714.46,910.581 1714.44,910.574 1714.43,910.567 1714.41,910.561 1714.39,910.554 1714.37,910.547 1714.36,910.54 1714.34,910.533 1714.32,910.527 1714.3,910.52 1714.29,910.513 1714.27,910.506 1714.25,910.5 1714.23,910.493 1714.22,910.486 1714.2,910.479 1714.18,910.472 1714.16,910.466 1714.15,910.459 1714.13,910.452 1714.11,910.445 1714.09,910.439 1714.08,910.432 1714.06,910.425 1714.04,910.418 1714.02,910.412 1714.01,910.405 1713.99,910.398 1713.97,910.391 1713.95,910.384 1713.94,910.378 1713.92,910.371 1713.9,910.364 1713.88,910.357 1713.87,910.351 1713.85,910.344 1713.83,910.337 1713.81,910.33 1713.8,910.324 1713.78,910.317 1713.76,910.31 1713.74,910.303 1713.73,910.297 1713.71,910.29 1713.69,910.283 1713.68,910.276 1713.66,910.27 1713.64,910.263 1713.62,910.256 1713.61,910.249 1713.59,910.243 1713.57,910.236 1713.55,910.229 1713.54,910.223 1713.52,910.216 1713.5,910.209 1713.48,910.202 1713.47,910.196 1713.45,910.189 1713.43,910.182 1713.41,910.175 1713.4,910.169 1713.38,910.162 1713.36,910.155 1713.34,910.148 1713.33,910.142 1713.31,910.135 1713.29,910.128 1713.27,910.122 1713.26,910.115 1713.24,910.108 1713.22,910.101 1713.21,910.095 1713.19,910.088 1713.17,910.081 1713.15,910.075 1713.14,910.068 1713.12,910.061 1713.1,910.054 1713.08,910.048 1713.07,910.041 1713.05,910.034 1713.03,910.028 1713.01,910.021 1713,910.014 1712.98,910.007 1712.96,910.001 1712.94,909.994 1712.93,909.987 1712.91,909.981 1712.89,909.974 1712.87,909.967 1712.86,909.961 1712.84,909.954 1712.82,909.947 1712.81,909.94 1712.79,909.934 1712.77,909.927 1712.75,909.92 1712.74,909.914 1712.72,909.907 1712.7,909.9 1712.68,909.894 1712.67,909.887 1712.65,909.88 1712.63,909.873 1712.61,909.867 1712.6,909.86 1712.58,909.853 1712.56,909.847 1712.55,909.84 1712.53,909.833 1712.51,909.827 1712.49,909.82 1712.48,909.813 1712.46,909.807 1712.44,909.8 1712.42,909.793 1712.41,909.787 1712.39,909.78 1712.37,909.773 1712.35,909.767 1712.34,909.76 1712.32,909.753 1712.3,909.747 1712.28,909.74 1712.27,909.733 1712.25,909.727 1712.23,909.72 1712.22,909.713 1712.2,909.707 1712.18,909.7 1712.16,909.693 1712.15,909.687 1712.13,909.68 1712.11,909.673 1712.09,909.667 1712.08,909.66 1712.06,909.653 1712.04,909.647 1712.03,909.64 1712.01,909.633 1711.99,909.627 1711.97,909.62 1711.96,909.613 1711.94,909.607 1711.92,909.6 1711.9,909.593 1711.89,909.587 1711.87,909.58 1711.85,909.573 1711.83,909.567 1711.82,909.56 1711.8,909.553 1711.78,909.547 1711.77,909.54 1711.75,909.534 1711.73,909.527 1711.71,909.52 1711.7,909.514 1711.68,909.507 1711.66,909.5 1711.64,909.494 1711.63,909.487 1711.61,909.48 1711.59,909.474 1711.58,909.467 1711.56,909.461 1711.54,909.454 1711.52,909.447 1711.51,909.441 1711.49,909.434 1711.47,909.427 1711.45,909.421 1711.44,909.414 1711.42,909.408 1711.4,909.401 1711.38,909.394 1711.37,909.388 1711.35,909.381 1711.33,909.374 1711.32,909.368 1711.3,909.361 1711.28,909.355 1711.26,909.348 1711.25,909.341 1711.23,909.335 1711.21,909.328 1711.19,909.321 1711.18,909.315 1711.16,909.308 1711.14,909.302 1711.13,909.295 1711.11,909.288 1711.09,909.282 1711.07,909.275 1711.06,909.269 1711.04,909.262 1711.02,909.255 1711.01,909.249 1710.99,909.242 1710.97,909.236 1710.95,909.229 1710.94,909.222 1710.92,909.216 1710.9,909.209 1710.88,909.203 1710.87,909.196 1710.85,909.189 1710.83,909.183 1710.82,909.176 1710.8,909.17 1710.78,909.163 1710.76,909.156 1710.75,909.15 1710.73,909.143 1710.71,909.137 1710.69,909.13 1710.68,909.123 1710.66,909.117 1710.64,909.11 1710.63,909.104 1710.61,909.097 1710.59,909.091 1710.57,909.084 1710.56,909.077 1710.54,909.071 1710.52,909.064 1710.51,909.058 1710.49,909.051 1710.47,909.044 1710.45,909.038 1710.44,909.031 1710.42,909.025 1710.4,909.018 1710.38,909.012 1710.37,909.005 1710.35,908.998 1710.33,908.992 1710.32,908.985 1710.3,908.979 1710.28,908.972 1710.26,908.966 1710.25,908.959 1710.23,908.953 1710.21,908.946 1710.2,908.939 1710.18,908.933 1710.16,908.926 1710.14,908.92 1710.13,908.913 1710.11,908.907 1710.09,908.9 1710.07,908.893 1710.06,908.887 1710.04,908.88 1710.02,908.874 1710.01,908.867 1709.99,908.861 1709.97,908.854 1709.95,908.848 1709.94,908.841 1709.92,908.835 1709.9,908.828 1709.89,908.821 1709.87,908.815 1709.85,908.808 1709.83,908.802 1709.82,908.795 1709.8,908.789 1709.78,908.782 1709.77,908.776 1709.75,908.769 1709.73,908.763 1709.71,908.756 1709.7,908.749 1709.68,908.743 1709.66,908.736 1709.65,908.73 1709.63,908.723 1709.61,908.717 1709.59,908.71 1709.58,908.704 1709.56,908.697 1709.54,908.691 1709.53,908.684 1709.51,908.678 1709.49,908.671 1709.47,908.665 1709.46,908.658 1709.44,908.652 1709.42,908.645 1709.41,908.639 1709.39,908.632 1709.37,908.625 1709.35,908.619 1709.34,908.612 1709.32,908.606 1709.3,908.599 1709.29,908.593 1709.27,908.586 1709.25,908.58 1709.23,908.573 1709.22,908.567 1709.2,908.56 1709.18,908.554 1709.17,908.547 1709.15,908.541 1709.13,908.534 1709.11,908.528 1709.1,908.521 1709.08,908.515 1709.06,908.508 1709.05,908.502 1709.03,908.495 1709.01,908.489 1708.99,908.482 1708.98,908.476 1708.96,908.469 1708.94,908.463 1708.93,908.456 1708.91,908.45 1708.89,908.443 1708.87,908.437 1708.86,908.43 1708.84,908.424 1708.82,908.417 1708.81,908.411 1708.79,908.404 1708.77,908.398 1708.75,908.391 1708.74,908.385 1708.72,908.378 1708.7,908.372 1708.69,908.365 1708.67,908.359 1708.65,908.352 1708.63,908.346 1708.62,908.339 1708.6,908.333 1708.58,908.327 1708.57,908.32 1708.55,908.314 1708.53,908.307 1708.51,908.301 1708.5,908.294 1708.48,908.288 1708.46,908.281 1708.45,908.275 1708.43,908.268 1708.41,908.262 1708.39,908.255 1708.38,908.249 1708.36,908.242 1708.34,908.236 1708.33,908.229 1708.31,908.223 1708.29,908.217 1708.28,908.21 1708.26,908.204 1708.24,908.197 1708.22,908.191 1708.21,908.184 1708.19,908.178 1708.17,908.171 1708.16,908.165 1708.14,908.158 1708.12,908.152 1708.1,908.145 1708.09,908.139 1708.07,908.133 1708.05,908.126 1708.04,908.12 1708.02,908.113 1708,908.107 1707.99,908.1 1707.97,908.094 1707.95,908.087 1707.93,908.081 1707.92,908.075 1707.9,908.068 1707.88,908.062 1707.87,908.055 1707.85,908.049 1707.83,908.042 1707.81,908.036 1707.8,908.029 1707.78,908.023 1707.76,908.017 1707.75,908.01 1707.73,908.004 1707.71,907.997 1707.7,907.991 1707.68,907.984 1707.66,907.978 1707.64,907.972 1707.63,907.965 1707.61,907.959 1707.59,907.952 1707.58,907.946 1707.56,907.939 1707.54,907.933 1707.52,907.927 1707.51,907.92 1707.49,907.914 1707.47,907.907 1707.46,907.901 1707.44,907.894 1707.42,907.888 1707.41,907.882 1707.39,907.875 1707.37,907.869 1707.35,907.862 1707.34,907.856 1707.32,907.85 1707.3,907.843 1707.29,907.837 1707.27,907.83 1707.25,907.824 1707.24,907.817 1707.22,907.811 1707.2,907.805 1707.18,907.798 1707.17,907.792 1707.15,907.785 1707.13,907.779 1707.12,907.773 1707.1,907.766 1707.08,907.76 1707.07,907.753 1707.05,907.747 1707.03,907.741 1707.01,907.734 1707,907.728 1706.98,907.721 1706.96,907.715 1706.95,907.709 1706.93,907.702 1706.91,907.696 1706.9,907.689 1706.88,907.683 1706.86,907.677 1706.84,907.67 1706.83,907.664 1706.81,907.657 1706.79,907.651 1706.78,907.645 1706.76,907.638 1706.74,907.632 1706.73,907.626 1706.71,907.619 1706.69,907.613 1706.67,907.606 1706.66,907.6 1706.64,907.594 1706.62,907.587 1706.61,907.581 1706.59,907.574 1706.57,907.568 1706.56,907.562 1706.54,907.555 1706.52,907.549 1706.5,907.543 1706.49,907.536 1706.47,907.53 1706.45,907.524 1706.44,907.517 1706.42,907.511 1706.4,907.504 1706.39,907.498 1706.37,907.492 1706.35,907.485 1706.34,907.479 1706.32,907.473 1706.3,907.466 1706.28,907.46 1706.27,907.453 1706.25,907.447 1706.23,907.441 1706.22,907.434 1706.2,907.428 1706.18,907.422 1706.17,907.415 1706.15,907.409 1706.13,907.403 1706.11,907.396 1706.1,907.39 1706.08,907.384 1706.06,907.377 1706.05,907.371 1706.03,907.365 1706.01,907.358 1706,907.352 1705.98,907.345 1705.96,907.339 1705.95,907.333 1705.93,907.326 1705.91,907.32 1705.89,907.314 1705.88,907.307 1705.86,907.301 1705.84,907.295 1705.83,907.288 1705.81,907.282 1705.79,907.276 1705.78,907.269 1705.76,907.263 1705.74,907.257 1705.73,907.25 1705.71,907.244 1705.69,907.238 1705.67,907.231 1705.66,907.225 1705.64,907.219 1705.62,907.212 1705.61,907.206 1705.59,907.2 1705.57,907.193 1705.56,907.187 1705.54,907.181 1705.52,907.174 1705.51,907.168 1705.49,907.162 1705.47,907.155 1705.45,907.149 1705.44,907.143 1705.42,907.136 1705.4,907.13 1705.39,907.124 1705.37,907.118 1705.35,907.111 1705.34,907.105 1705.32,907.099 1705.3,907.092 1705.29,907.086 1705.27,907.08 1705.25,907.073 1705.24,907.067 1705.22,907.061 1705.2,907.054 1705.18,907.048 1705.17,907.042 1705.15,907.036 1705.13,907.029 1705.12,907.023 1705.1,907.017 1705.08,907.01 1705.07,907.004 1705.05,906.998 1705.03,906.991 1705.02,906.985 1705,906.979 1704.98,906.972 1704.97,906.966 1704.95,906.96 1704.93,906.954 1704.91,906.947 1704.9,906.941 1704.88,906.935 1704.86,906.928 1704.85,906.922 1704.83,906.916 1704.81,906.91 1704.8,906.903 1704.78,906.897 1704.76,906.891 1704.75,906.884 1704.73,906.878 1704.71,906.872 1704.7,906.866 1704.68,906.859 1704.66,906.853 1704.64,906.847 1704.63,906.84 1704.61,906.834 1704.59,906.828 1704.58,906.822 1704.56,906.815 1704.54,906.809 1704.53,906.803 1704.51,906.797 1704.49,906.79 1704.48,906.784 1704.46,906.778 1704.44,906.771 1704.43,906.765 1704.41,906.759 1704.39,906.753 1704.38,906.746 1704.36,906.74 1704.34,906.734 1704.32,906.728 1704.31,906.721 1704.29,906.715 1704.27,906.709 1704.26,906.703 1704.24,906.696 1704.22,906.69 1704.21,906.684 1704.19,906.677 1704.17,906.671 1704.16,906.665 1704.14,906.659 1704.12,906.652 1704.11,906.646 1704.09,906.64 1704.07,906.634 1704.06,906.627 1704.04,906.621 1704.02,906.615 1704.01,906.609 1703.99,906.602 1703.97,906.596 1703.95,906.59 1703.94,906.584 1703.92,906.577 1703.9,906.571 1703.89,906.565 1703.87,906.559 1703.85,906.552 1703.84,906.546 1703.82,906.54 1703.8,906.534 1703.79,906.528 1703.77,906.521 1703.75,906.515 1703.74,906.509 1703.72,906.503 1703.7,906.496 1703.69,906.49 1703.67,906.484 1703.65,906.478 1703.64,906.471 1703.62,906.465 1703.6,906.459 1703.59,906.453 1703.57,906.447 1703.55,906.44 1703.54,906.434 1703.52,906.428 1703.5,906.422 1703.48,906.415 1703.47,906.409 1703.45,906.403 1703.43,906.397 1703.42,906.391 1703.4,906.384 1703.38,906.378 1703.37,906.372 1703.35,906.366 1703.33,906.359 1703.32,906.353 1703.3,906.347 1703.28,906.341 1703.27,906.335 1703.25,906.328 1703.23,906.322 1703.22,906.316 1703.2,906.31 1703.18,906.304 1703.17,906.297 1703.15,906.291 1703.13,906.285 1703.12,906.279 1703.1,906.273 1703.08,906.266 1703.07,906.26 1703.05,906.254 1703.03,906.248 1703.02,906.241 1703,906.235 1702.98,906.229 1702.97,906.223 1702.95,906.217 1702.93,906.211 1702.92,906.204 1702.9,906.198 1702.88,906.192 1702.86,906.186 1702.85,906.18 1702.83,906.173 1702.81,906.167 1702.8,906.161 1702.78,906.155 1702.76,906.149 1702.75,906.142 1702.73,906.136 1702.71,906.13 1702.7,906.124 1702.68,906.118 1702.66,906.111 1702.65,906.105 1702.63,906.099 1702.61,906.093 1702.6,906.087 1702.58,906.081 1702.56,906.074 1702.55,906.068 1702.53,906.062 1702.51,906.056 1702.5,906.05 1702.48,906.044 1702.46,906.037 1702.45,906.031 1702.43,906.025 1702.41,906.019 1702.4,906.013 1702.38,906.007 1702.36,906 1702.35,905.994 1702.33,905.988 1702.31,905.982 1702.3,905.976 1702.28,905.97 1702.26,905.963 1702.25,905.957 1702.23,905.951 1702.21,905.945 1702.2,905.939 1702.18,905.933 1702.16,905.926 1702.15,905.92 1702.13,905.914 1702.11,905.908 1702.1,905.902 1702.08,905.896 1702.06,905.889 1702.05,905.883 1702.03,905.877 1702.01,905.871 1702,905.865 1701.98,905.859 1701.96,905.853 1701.95,905.846 1701.93,905.84 1701.91,905.834 1701.9,905.828 1701.88,905.822 1701.86,905.816 1701.85,905.81 1701.83,905.803 1701.81,905.797 1701.8,905.791 1701.78,905.785 1701.76,905.779 1701.75,905.773 1701.73,905.767 1701.71,905.76 1701.7,905.754 1701.68,905.748 1701.66,905.742 1701.65,905.736 1701.63,905.73 1701.61,905.724 1701.6,905.718 1701.58,905.711 1701.56,905.705 1701.55,905.699 1701.53,905.693 1701.51,905.687 1701.5,905.681 1701.48,905.675 1701.46,905.668 1701.45,905.662 1701.43,905.656 1701.41,905.65 1701.4,905.644 1701.38,905.638 1701.36,905.632 1701.35,905.626 1701.33,905.62 1701.31,905.613 1701.3,905.607 1701.28,905.601 1701.26,905.595 1701.25,905.589 1701.23,905.583 1701.21,905.577 1701.2,905.571 1701.18,905.565 1701.16,905.558 1701.15,905.552 1701.13,905.546 1701.11,905.54 1701.1,905.534 1701.08,905.528 1701.06,905.522 1701.05,905.516 1701.03,905.51 1701.01,905.503 1701,905.497 1700.98,905.491 1700.96,905.485 1700.95,905.479 1700.93,905.473 1700.91,905.467 1700.9,905.461 1700.88,905.455 1700.86,905.449 1700.85,905.442 1700.83,905.436 1700.81,905.43 1700.8,905.424 1700.78,905.418 1700.77,905.412 1700.75,905.406 1700.73,905.4 1700.72,905.394 1700.7,905.388 1700.68,905.382 1700.67,905.375 1700.65,905.369 1700.63,905.363 1700.62,905.357 1700.6,905.351 1700.58,905.345 1700.57,905.339 1700.55,905.333 1700.53,905.327 1700.52,905.321 1700.5,905.315 1700.48,905.309 1700.47,905.303 1700.45,905.296 1700.43,905.29 1700.42,905.284 1700.4,905.278 1700.38,905.272 1700.37,905.266 1700.35,905.26 1700.33,905.254 1700.32,905.248 1700.3,905.242 1700.28,905.236 1700.27,905.23 1700.25,905.224 1700.23,905.218 1700.22,905.211 1700.2,905.205 1700.18,905.199 1700.17,905.193 1700.15,905.187 1700.14,905.181 1700.12,905.175 1700.1,905.169 1700.09,905.163 1700.07,905.157 1700.05,905.151 1700.04,905.145 1700.02,905.139 1700,905.133 1699.99,905.127 1699.97,905.121 1699.95,905.115 1699.94,905.109 1699.92,905.102 1699.9,905.096 1699.89,905.09 1699.87,905.084 1699.85,905.078 1699.84,905.072 1699.82,905.066 1699.8,905.06 1699.79,905.054 1699.77,905.048 1699.75,905.042 1699.74,905.036 1699.72,905.03 1699.71,905.024 1699.69,905.018 1699.67,905.012 1699.66,905.006 1699.64,905 1699.62,904.994 1699.61,904.988 1699.59,904.982 1699.57,904.976 1699.56,904.97 1699.54,904.964 1699.52,904.958 1699.51,904.952 1699.49,904.945 1699.47,904.939 1699.46,904.933 1699.44,904.927 1699.42,904.921 1699.41,904.915 1699.39,904.909 1699.37,904.903 1699.36,904.897 1699.34,904.891 1699.33,904.885 1699.31,904.879 1699.29,904.873 1699.28,904.867 1699.26,904.861 1699.24,904.855 1699.23,904.849 1699.21,904.843 1699.19,904.837 1699.18,904.831 1699.16,904.825 1699.14,904.819 1699.13,904.813 1699.11,904.807 1699.09,904.801 1699.08,904.795 1699.06,904.789 1699.04,904.783 1699.03,904.777 1699.01,904.771 1699,904.765 1698.98,904.759 1698.96,904.753 1698.95,904.747 1698.93,904.741 1698.91,904.735 1698.9,904.729 1698.88,904.723 1698.86,904.717 1698.85,904.711 1698.83,904.705 1698.81,904.699 1698.8,904.693 1698.78,904.687 1698.76,904.681 1698.75,904.675 1698.73,904.669 1698.72,904.663 1698.7,904.657 1698.68,904.651 1698.67,904.645 1698.65,904.639 1698.63,904.633 1698.62,904.627 1698.6,904.621 1698.58,904.615 1698.57,904.609 1698.55,904.603 1698.53,904.597 1698.52,904.591 1698.5,904.585 1698.48,904.579 1698.47,904.573 1698.45,904.567 1698.44,904.561 1698.42,904.555 1698.4,904.549 1698.39,904.543 1698.37,904.537 1698.35,904.531 1698.34,904.525 1698.32,904.519 1698.3,904.513 1698.29,904.507 1698.27,904.502 1698.25,904.496 1698.24,904.49 1698.22,904.484 1698.21,904.478 1698.19,904.472 1698.17,904.466 1698.16,904.46 1698.14,904.454 1698.12,904.448 1698.11,904.442 1698.09,904.436 1698.07,904.43 1698.06,904.424 1698.04,904.418 1698.02,904.412 1698.01,904.406 1697.99,904.4 1697.98,904.394 1697.96,904.388 1697.94,904.382 1697.93,904.376 1697.91,904.37 1697.89,904.364 1697.88,904.358 1697.86,904.353 1697.84,904.347 1697.83,904.341 1697.81,904.335 1697.8,904.329 1697.78,904.323 1697.76,904.317 1697.75,904.311 1697.73,904.305 1697.71,904.299 1697.7,904.293 1697.68,904.287 1697.66,904.281 1697.65,904.275 1697.63,904.269 1697.61,904.263 1697.6,904.257 1697.58,904.251 1697.57,904.246 1697.55,904.24 1697.53,904.234 1697.52,904.228 1697.5,904.222 1697.48,904.216 1697.47,904.21 1697.45,904.204 1697.43,904.198 1697.42,904.192 1697.4,904.186 1697.39,904.18 1697.37,904.174 1697.35,904.168 1697.34,904.162 1697.32,904.157 1697.3,904.151 1697.29,904.145 1697.27,904.139 1697.25,904.133 1697.24,904.127 1697.22,904.121 1697.21,904.115 1697.19,904.109 1697.17,904.103 1697.16,904.097 1697.14,904.091 1697.12,904.086 1697.11,904.08 1697.09,904.074 1697.07,904.068 1697.06,904.062 1697.04,904.056 1697.03,904.05 1697.01,904.044 1696.99,904.038 1696.98,904.032 1696.96,904.026 1696.94,904.02 1696.93,904.015 1696.91,904.009 1696.89,904.003 1696.88,903.997 1696.86,903.991 1696.85,903.985 1696.83,903.979 1696.81,903.973 1696.8,903.967 1696.78,903.961 1696.76,903.956 1696.75,903.95 1696.73,903.944 1696.71,903.938 1696.7,903.932 1696.68,903.926 1696.67,903.92 1696.65,903.914 1696.63,903.908 1696.62,903.902 1696.6,903.897 1696.58,903.891 1696.57,903.885 1696.55,903.879 1696.54,903.873 1696.52,903.867 1696.5,903.861 1696.49,903.855 1696.47,903.849 1696.45,903.844 1696.44,903.838 1696.42,903.832 1696.4,903.826 1696.39,903.82 1696.37,903.814 1696.36,903.808 1696.34,903.802 1696.32,903.797 1696.31,903.791 1696.29,903.785 1696.27,903.779 1696.26,903.773 1696.24,903.767 1696.23,903.761 1696.21,903.755 1696.19,903.75 1696.18,903.744 1696.16,903.738 1696.14,903.732 1696.13,903.726 1696.11,903.72 1696.09,903.714 1696.08,903.708 1696.06,903.703 1696.05,903.697 1696.03,903.691 1696.01,903.685 1696,903.679 1695.98,903.673 1695.96,903.667 1695.95,903.662 1695.93,903.656 1695.92,903.65 1695.9,903.644 1695.88,903.638 1695.87,903.632 1695.85,903.626 1695.83,903.621 1695.82,903.615 1695.8,903.609 1695.79,903.603 1695.77,903.597 1695.75,903.591 1695.74,903.585 1695.72,903.58 1695.7,903.574 1695.69,903.568 1695.67,903.562 1695.66,903.556 1695.64,903.55 1695.62,903.544 1695.61,903.539 1695.59,903.533 1695.57,903.527 1695.56,903.521 1695.54,903.515 1695.53,903.509 1695.51,903.504 1695.49,903.498 1695.48,903.492 1695.46,903.486 1695.44,903.48 1695.43,903.474 1695.41,903.469 1695.4,903.463 1695.38,903.457 1695.36,903.451 1695.35,903.445 1695.33,903.439 1695.31,903.434 1695.3,903.428 1695.28,903.422 1695.27,903.416 1695.25,903.41 1695.23,903.404 1695.22,903.399 1695.2,903.393 1695.18,903.387 1695.17,903.381 1695.15,903.375 1695.14,903.369 1695.12,903.364 1695.1,903.358 1695.09,903.352 1695.07,903.346 1695.05,903.34 1695.04,903.335 1695.02,903.329 1695.01,903.323 1694.99,903.317 1694.97,903.311 1694.96,903.305 1694.94,903.3 1694.92,903.294 1694.91,903.288 1694.89,903.282 1694.88,903.276 1694.86,903.271 1694.84,903.265 1694.83,903.259 1694.81,903.253 1694.79,903.247 1694.78,903.242 1694.76,903.236 1694.75,903.23 1694.73,903.224 1694.71,903.218 1694.7,903.213 1694.68,903.207 1694.67,903.201 1694.65,903.195 1694.63,903.189 1694.62,903.183 1694.6,903.178 1694.58,903.172 1694.57,903.166 1694.55,903.16 1694.54,903.155 1694.52,903.149 1694.5,903.143 1694.49,903.137 1694.47,903.131 1694.45,903.126 1694.44,903.12 1694.42,903.114 1694.41,903.108 1694.39,903.102 1694.37,903.097 1694.36,903.091 1694.34,903.085 1694.33,903.079 1694.31,903.073 1694.29,903.068 1694.28,903.062 1694.26,903.056 1694.24,903.05 1694.23,903.045 1694.21,903.039 1694.2,903.033 1694.18,903.027 1694.16,903.021 1694.15,903.016 1694.13,903.01 1694.12,903.004 1694.1,902.998 1694.08,902.993 1694.07,902.987 1694.05,902.981 1694.03,902.975 1694.02,902.969 1694,902.964 1693.99,902.958 1693.97,902.952 1693.95,902.946 1693.94,902.941 1693.92,902.935 1693.91,902.929 1693.89,902.923 1693.87,902.918 1693.86,902.912 1693.84,902.906 1693.82,902.9 1693.81,902.894 1693.79,902.889 1693.78,902.883 1693.76,902.877 1693.74,902.871 1693.73,902.866 1693.71,902.86 1693.7,902.854 1693.68,902.848 1693.66,902.843 1693.65,902.837 1693.63,902.831 1693.61,902.825 1693.6,902.82 1693.58,902.814 1693.57,902.808 1693.55,902.802 1693.53,902.797 1693.52,902.791 1693.5,902.785 1693.49,902.779 1693.47,902.774 1693.45,902.768 1693.44,902.762 1693.42,902.756 1693.41,902.751 1693.39,902.745 1693.37,902.739 1693.36,902.733 1693.34,902.728 1693.32,902.722 1693.31,902.716 1693.29,902.71 1693.28,902.705 1693.26,902.699 1693.24,902.693 1693.23,902.688 1693.21,902.682 1693.2,902.676 1693.18,902.67 1693.16,902.665 1693.15,902.659 1693.13,902.653 1693.12,902.647 1693.1,902.642 1693.08,902.636 1693.07,902.63 1693.05,902.625 1693.03,902.619 1693.02,902.613 1693,902.607 1692.99,902.602 1692.97,902.596 1692.95,902.59 1692.94,902.584 1692.92,902.579 1692.91,902.573 1692.89,902.567 1692.87,902.562 1692.86,902.556 1692.84,902.55 1692.83,902.544 1692.81,902.539 1692.79,902.533 1692.78,902.527 1692.76,902.522 1692.75,902.516 1692.73,902.51 1692.71,902.504 1692.7,902.499 1692.68,902.493 1692.67,902.487 1692.65,902.482 1692.63,902.476 1692.62,902.47 1692.6,902.464 1692.58,902.459 1692.57,902.453 1692.55,902.447 1692.54,902.442 1692.52,902.436 1692.5,902.43 1692.49,902.425 1692.47,902.419 1692.46,902.413 1692.44,902.407 1692.42,902.402 1692.41,902.396 1692.39,902.39 1692.38,902.385 1692.36,902.379 1692.34,902.373 1692.33,902.368 1692.31,902.362 1692.3,902.356 1692.28,902.35 1692.26,902.345 1692.25,902.339 1692.23,902.333 1692.22,902.328 1692.2,902.322 1692.18,902.316 1692.17,902.311 1692.15,902.305 1692.14,902.299 1692.12,902.294 1692.1,902.288 1692.09,902.282 1692.07,902.277 1692.06,902.271 1692.04,902.265 1692.02,902.259 1692.01,902.254 1691.99,902.248 1691.98,902.242 1691.96,902.237 1691.94,902.231 1691.93,902.225 1691.91,902.22 1691.9,902.214 1691.88,902.208 1691.86,902.203 1691.85,902.197 1691.83,902.191 1691.82,902.186 1691.8,902.18 1691.78,902.174 1691.77,902.169 1691.75,902.163 1691.74,902.157 1691.72,902.152 1691.7,902.146 1691.69,902.14 1691.67,902.135 1691.66,902.129 1691.64,902.123 1691.62,902.118 1691.61,902.112 1691.59,902.106 1691.58,902.101 1691.56,902.095 1691.54,902.089 1691.53,902.084 1691.51,902.078 1691.5,902.072 1691.48,902.067 1691.46,902.061 1691.45,902.055 1691.43,902.05 1691.42,902.044 1691.4,902.039 1691.38,902.033 1691.37,902.027 1691.35,902.022 1691.34,902.016 1691.32,902.01 1691.3,902.005 1691.29,901.999 1691.27,901.993 1691.26,901.988 1691.24,901.982 1691.22,901.976 1691.21,901.971 1691.19,901.965 1691.18,901.959 1691.16,901.954 1691.14,901.948 1691.13,901.943 1691.11,901.937 1691.1,901.931 1691.08,901.926 1691.06,901.92 1691.05,901.914 1691.03,901.909 1691.02,901.903 1691,901.897 1690.98,901.892 1690.97,901.886 1690.95,901.881 1690.94,901.875 1690.92,901.869 1690.9,901.864 1690.89,901.858 1690.87,901.852 1690.86,901.847 1690.84,901.841 1690.82,901.836 1690.81,901.83 1690.79,901.824 1690.78,901.819 1690.76,901.813 1690.74,901.807 1690.73,901.802 1690.71,901.796 1690.7,901.791 1690.68,901.785 1690.67,901.779 1690.65,901.774 1690.63,901.768 1690.62,901.762 1690.6,901.757 1690.59,901.751 1690.57,901.746 1690.55,901.74 1690.54,901.734 1690.52,901.729 1690.51,901.723 1690.49,901.718 1690.47,901.712 1690.46,901.706 1690.44,901.701 1690.43,901.695 1690.41,901.69 1690.39,901.684 1690.38,901.678 1690.36,901.673 1690.35,901.667 1690.33,901.661 1690.31,901.656 1690.3,901.65 1690.28,901.645 1690.27,901.639 1690.25,901.633 1690.24,901.628 1690.22,901.622 1690.2,901.617 1690.19,901.611 1690.17,901.605 1690.16,901.6 1690.14,901.594 1690.12,901.589 1690.11,901.583 1690.09,901.578 1690.08,901.572 1690.06,901.566 1690.04,901.561 1690.03,901.555 1690.01,901.55 1690,901.544 1689.98,901.538 1689.97,901.533 1689.95,901.527 1689.93,901.522 1689.92,901.516 1689.9,901.51 1689.89,901.505 1689.87,901.499 1689.85,901.494 1689.84,901.488 1689.82,901.483 1689.81,901.477 1689.79,901.471 1689.77,901.466 1689.76,901.46 1689.74,901.455 1689.73,901.449 1689.71,901.443 1689.7,901.438 1689.68,901.432 1689.66,901.427 1689.65,901.421 1689.63,901.416 1689.62,901.41 1689.6,901.404 1689.58,901.399 1689.57,901.393 1689.55,901.388 1689.54,901.382 1689.52,901.377 1689.5,901.371 1689.49,901.365 1689.47,901.36 1689.46,901.354 1689.44,901.349 1689.43,901.343 1689.41,901.338 1689.39,901.332 1689.38,901.327 1689.36,901.321 1689.35,901.315 1689.33,901.31 1689.31,901.304 1689.3,901.299 1689.28,901.293 1689.27,901.288 1689.25,901.282 1689.24,901.277 1689.22,901.271 1689.2,901.265 1689.19,901.26 1689.17,901.254 1689.16,901.249 1689.14,901.243 1689.12,901.238 1689.11,901.232 1689.09,901.227 1689.08,901.221 1689.06,901.215 1689.05,901.21 1689.03,901.204 1689.01,901.199 1689,901.193 1688.98,901.188 1688.97,901.182 1688.95,901.177 1688.93,901.171 1688.92,901.166 1688.9,901.16 1688.89,901.155 1688.87,901.149 1688.86,901.143 1688.84,901.138 1688.82,901.132 1688.81,901.127 1688.79,901.121 1688.78,901.116 1688.76,901.11 1688.75,901.105 1688.73,901.099 1688.71,901.094 1688.7,901.088 1688.68,901.083 1688.67,901.077 1688.65,901.072 1688.63,901.066 1688.62,901.06 1688.6,901.055 1688.59,901.049 1688.57,901.044 1688.56,901.038 1688.54,901.033 1688.52,901.027 1688.51,901.022 1688.49,901.016 1688.48,901.011 1688.46,901.005 1688.45,901 1688.43,900.994 1688.41,900.989 1688.4,900.983 1688.38,900.978 1688.37,900.972 1688.35,900.967 1688.33,900.961 1688.32,900.956 1688.3,900.95 1688.29,900.945 1688.27,900.939 1688.26,900.934 1688.24,900.928 1688.22,900.922 1688.21,900.917 1688.19,900.911 1688.18,900.906 1688.16,900.9 1688.15,900.895 1688.13,900.889 1688.11,900.884 1688.1,900.878 1688.08,900.873 1688.07,900.867 1688.05,900.862 1688.04,900.856 1688.02,900.851 1688,900.845 1687.99,900.84 1687.97,900.834 1687.96,900.829 1687.94,900.823 1687.92,900.818 1687.91,900.812 1687.89,900.807 1687.88,900.801 1687.86,900.796 1687.85,900.79 1687.83,900.785 1687.81,900.779 1687.8,900.774 1687.78,900.769 1687.77,900.763 1687.75,900.758 1687.74,900.752 1687.72,900.747 1687.7,900.741 1687.69,900.736 1687.67,900.73 1687.66,900.725 1687.64,900.719 1687.63,900.714 1687.61,900.708 1687.59,900.703 1687.58,900.697 1687.56,900.692 1687.55,900.686 1687.53,900.681 1687.52,900.675 1687.5,900.67 1687.48,900.664 1687.47,900.659 1687.45,900.653 1687.44,900.648 1687.42,900.642 1687.41,900.637 1687.39,900.631 1687.37,900.626 1687.36,900.621 1687.34,900.615 1687.33,900.61 1687.31,900.604 1687.3,900.599 1687.28,900.593 1687.26,900.588 1687.25,900.582 1687.23,900.577 1687.22,900.571 1687.2,900.566 1687.19,900.56 1687.17,900.555 1687.15,900.549 1687.14,900.544 1687.12,900.539 1687.11,900.533 1687.09,900.528 1687.08,900.522 1687.06,900.517 1687.04,900.511 1687.03,900.506 1687.01,900.5 1687,900.495 1686.98,900.489 1686.97,900.484 1686.95,900.479 1686.93,900.473 1686.92,900.468 1686.9,900.462 1686.89,900.457 1686.87,900.451 1686.86,900.446 1686.84,900.44 1686.82,900.435 1686.81,900.429 1686.79,900.424 1686.78,900.419 1686.76,900.413 1686.75,900.408 1686.73,900.402 1686.72,900.397 1686.7,900.391 1686.68,900.386 1686.67,900.38 1686.65,900.375 1686.64,900.37 1686.62,900.364 1686.61,900.359 1686.59,900.353 1686.57,900.348 1686.56,900.342 1686.54,900.337 1686.53,900.332 1686.51,900.326 1686.5,900.321 1686.48,900.315 1686.46,900.31 1686.45,900.304 1686.43,900.299 1686.42,900.294 1686.4,900.288 1686.39,900.283 1686.37,900.277 1686.35,900.272 1686.34,900.266 1686.32,900.261 1686.31,900.256 1686.29,900.25 1686.28,900.245 1686.26,900.239 1686.25,900.234 1686.23,900.228 1686.21,900.223 1686.2,900.218 1686.18,900.212 1686.17,900.207 1686.15,900.201 1686.14,900.196 1686.12,900.19 1686.1,900.185 1686.09,900.18 1686.07,900.174 1686.06,900.169 1686.04,900.163 1686.03,900.158 1686.01,900.153 1686,900.147 1685.98,900.142 1685.96,900.136 1685.95,900.131 1685.93,900.126 1685.92,900.12 1685.9,900.115 1685.89,900.109 1685.87,900.104 1685.85,900.098 1685.84,900.093 1685.82,900.088 1685.81,900.082 1685.79,900.077 1685.78,900.071 1685.76,900.066 1685.75,900.061 1685.73,900.055 1685.71,900.05 1685.7,900.044 1685.68,900.039 1685.67,900.034 1685.65,900.028 1685.64,900.023 1685.62,900.017 1685.61,900.012 1685.59,900.007 1685.57,900.001 1685.56,899.996 1685.54,899.991 1685.53,899.985 1685.51,899.98 1685.5,899.974 1685.48,899.969 1685.46,899.964 1685.45,899.958 1685.43,899.953 1685.42,899.947 1685.4,899.942 1685.39,899.937 1685.37,899.931 1685.36,899.926 1685.34,899.92 1685.32,899.915 1685.31,899.91 1685.29,899.904 1685.28,899.899 1685.26,899.894 1685.25,899.888 1685.23,899.883 1685.22,899.877 1685.2,899.872 1685.18,899.867 1685.17,899.861 1685.15,899.856 1685.14,899.851 1685.12,899.845 1685.11,899.84 1685.09,899.834 1685.08,899.829 1685.06,899.824 1685.04,899.818 1685.03,899.813 1685.01,899.808 1685,899.802 1684.98,899.797 1684.97,899.791 1684.95,899.786 1684.94,899.781 1684.92,899.775 1684.9,899.77 1684.89,899.765 1684.87,899.759 1684.86,899.754 1684.84,899.749 1684.83,899.743 1684.81,899.738 1684.8,899.732 1684.78,899.727 1684.76,899.722 1684.75,899.716 1684.73,899.711 1684.72,899.706 1684.7,899.7 1684.69,899.695 1684.67,899.69 1684.66,899.684 1684.64,899.679 1684.62,899.674 1684.61,899.668 1684.59,899.663 1684.58,899.658 1684.56,899.652 1684.55,899.647 1684.53,899.641 1684.52,899.636 1684.5,899.631 1684.49,899.625 1684.47,899.62 1684.45,899.615 1684.44,899.609 1684.42,899.604 1684.41,899.599 1684.39,899.593 1684.38,899.588 1684.36,899.583 1684.35,899.577 1684.33,899.572 1684.31,899.567 1684.3,899.561 1684.28,899.556 1684.27,899.551 1684.25,899.545 1684.24,899.54 1684.22,899.535 1684.21,899.529 1684.19,899.524 1684.17,899.519 1684.16,899.513 1684.14,899.508 1684.13,899.503 1684.11,899.497 1684.1,899.492 1684.08,899.487 1684.07,899.481 1684.05,899.476 1684.04,899.471 1684.02,899.465 1684,899.46 1683.99,899.455 1683.97,899.449 1683.96,899.444 1683.94,899.439 1683.93,899.433 1683.91,899.428 1683.9,899.423 1683.88,899.417 1683.87,899.412 1683.85,899.407 1683.83,899.402 1683.82,899.396 1683.8,899.391 1683.79,899.386 1683.77,899.38 1683.76,899.375 1683.74,899.37 1683.73,899.364 1683.71,899.359 1683.69,899.354 1683.68,899.348 1683.66,899.343 1683.65,899.338 1683.63,899.332 1683.62,899.327 1683.6,899.322 1683.59,899.317 1683.57,899.311 1683.56,899.306 1683.54,899.301 1683.52,899.295 1683.51,899.29 1683.49,899.285 1683.48,899.279 1683.46,899.274 1683.45,899.269 1683.43,899.263 1683.42,899.258 1683.4,899.253 1683.39,899.248 1683.37,899.242 1683.35,899.237 1683.34,899.232 1683.32,899.226 1683.31,899.221 1683.29,899.216 1683.28,899.211 1683.26,899.205 1683.25,899.2 1683.23,899.195 1683.22,899.189 1683.2,899.184 1683.19,899.179 1683.17,899.173 1683.15,899.168 1683.14,899.163 1683.12,899.158 1683.11,899.152 1683.09,899.147 1683.08,899.142 1683.06,899.136 1683.05,899.131 1683.03,899.126 1683.02,899.121 1683,899.115 1682.98,899.11 1682.97,899.105 1682.95,899.099 1682.94,899.094 1682.92,899.089 1682.91,899.084 1682.89,899.078 1682.88,899.073 1682.86,899.068 1682.85,899.063 1682.83,899.057 1682.81,899.052 1682.8,899.047 1682.78,899.041 1682.77,899.036 1682.75,899.031 1682.74,899.026 1682.72,899.02 1682.71,899.015 1682.69,899.01 1682.68,899.005 1682.66,898.999 1682.65,898.994 1682.63,898.989 1682.61,898.983 1682.6,898.978 1682.58,898.973 1682.57,898.968 1682.55,898.962 1682.54,898.957 1682.52,898.952 1682.51,898.947 1682.49,898.941 1682.48,898.936 1682.46,898.931 1682.45,898.926 1682.43,898.92 1682.41,898.915 1682.4,898.91 1682.38,898.905 1682.37,898.899 1682.35,898.894 1682.34,898.889 1682.32,898.884 1682.31,898.878 1682.29,898.873 1682.28,898.868 1682.26,898.863 1682.25,898.857 1682.23,898.852 1682.21,898.847 1682.2,898.842 1682.18,898.836 1682.17,898.831 1682.15,898.826 1682.14,898.821 1682.12,898.815 1682.11,898.81 1682.09,898.805 1682.08,898.8 1682.06,898.794 1682.05,898.789 1682.03,898.784 1682.02,898.779 1682,898.773 1681.98,898.768 1681.97,898.763 1681.95,898.758 1681.94,898.752 1681.92,898.747 1681.91,898.742 1681.89,898.737 1681.88,898.732 1681.86,898.726 1681.85,898.721 1681.83,898.716 1681.82,898.711 1681.8,898.705 1681.78,898.7 1681.77,898.695 1681.75,898.69 1681.74,898.684 1681.72,898.679 1681.71,898.674 1681.69,898.669 1681.68,898.664 1681.66,898.658 1681.65,898.653 1681.63,898.648 1681.62,898.643 1681.6,898.637 1681.59,898.632 1681.57,898.627 1681.55,898.622 1681.54,898.617 1681.52,898.611 1681.51,898.606 1681.49,898.601 1681.48,898.596 1681.46,898.59 1681.45,898.585 1681.43,898.58 1681.42,898.575 1681.4,898.57 1681.39,898.564 1681.37,898.559 1681.36,898.554 1681.34,898.549 1681.33,898.544 1681.31,898.538 1681.29,898.533 1681.28,898.528 1681.26,898.523 1681.25,898.517 1681.23,898.512 1681.22,898.507 1681.2,898.502 1681.19,898.497 1681.17,898.491 1681.16,898.486 1681.14,898.481 1681.13,898.476 1681.11,898.471 1681.1,898.465 1681.08,898.46 1681.07,898.455 1681.05,898.45 1681.03,898.445 1681.02,898.439 1681,898.434 1680.99,898.429 1680.97,898.424 1680.96,898.419 1680.94,898.413 1680.93,898.408 1680.91,898.403 1680.9,898.398 1680.88,898.393 1680.87,898.388 1680.85,898.382 1680.84,898.377 1680.82,898.372 1680.81,898.367 1680.79,898.362 1680.77,898.356 1680.76,898.351 1680.74,898.346 1680.73,898.341 1680.71,898.336 1680.7,898.33 1680.68,898.325 1680.67,898.32 1680.65,898.315 1680.64,898.31 1680.62,898.305 1680.61,898.299 1680.59,898.294 1680.58,898.289 1680.56,898.284 1680.55,898.279 1680.53,898.273 1680.52,898.268 1680.5,898.263 1680.48,898.258 1680.47,898.253 1680.45,898.248 1680.44,898.242 1680.42,898.237 1680.41,898.232 1680.39,898.227 1680.38,898.222 1680.36,898.217 1680.35,898.211 1680.33,898.206 1680.32,898.201 1680.3,898.196 1680.29,898.191 1680.27,898.186 1680.26,898.18 1680.24,898.175 1680.23,898.17 1680.21,898.165 1680.2,898.16 1680.18,898.155 1680.16,898.149 1680.15,898.144 1680.13,898.139 1680.12,898.134 1680.1,898.129 1680.09,898.124 1680.07,898.118 1680.06,898.113 1680.04,898.108 1680.03,898.103 1680.01,898.098 1680,898.093 1679.98,898.088 1679.97,898.082 1679.95,898.077 1679.94,898.072 1679.92,898.067 1679.91,898.062 1679.89,898.057 1679.88,898.051 1679.86,898.046 1679.85,898.041 1679.83,898.036 1679.81,898.031 1679.8,898.026 1679.78,898.021 1679.77,898.015 1679.75,898.01 1679.74,898.005 1679.72,898 1679.71,897.995 1679.69,897.99 1679.68,897.985 1679.66,897.979 1679.65,897.974 1679.63,897.969 1679.62,897.964 1679.6,897.959 1679.59,897.954 1679.57,897.949 1679.56,897.943 1679.54,897.938 1679.53,897.933 1679.51,897.928 1679.5,897.923 1679.48,897.918 1679.47,897.913 1679.45,897.908 1679.43,897.902 1679.42,897.897 1679.4,897.892 1679.39,897.887 1679.37,897.882 1679.36,897.877 1679.34,897.872 1679.33,897.867 1679.31,897.861 1679.3,897.856 1679.28,897.851 1679.27,897.846 1679.25,897.841 1679.24,897.836 1679.22,897.831 1679.21,897.826 1679.19,897.82 1679.18,897.815 1679.16,897.81 1679.15,897.805 1679.13,897.8 1679.12,897.795 1679.1,897.79 1679.09,897.785 1679.07,897.779 1679.06,897.774 1679.04,897.769 1679.03,897.764 1679.01,897.759 1679,897.754 1678.98,897.749 1678.96,897.744 1678.95,897.739 1678.93,897.733 1678.92,897.728 1678.9,897.723 1678.89,897.718 1678.87,897.713 1678.86,897.708 1678.84,897.703 1678.83,897.698 1678.81,897.693 1678.8,897.687 1678.78,897.682 1678.77,897.677 1678.75,897.672 1678.74,897.667 1678.72,897.662 1678.71,897.657 1678.69,897.652 1678.68,897.647 1678.66,897.642 1678.65,897.636 1678.63,897.631 1678.62,897.626 1678.6,897.621 1678.59,897.616 1678.57,897.611 1678.56,897.606 1678.54,897.601 1678.53,897.596 1678.51,897.591 1678.5,897.586 1678.48,897.58 1678.47,897.575 1678.45,897.57 1678.44,897.565 1678.42,897.56 1678.4,897.555 1678.39,897.55 1678.37,897.545 1678.36,897.54 1678.34,897.535 1678.33,897.53 1678.31,897.524 1678.3,897.519 1678.28,897.514 1678.27,897.509 1678.25,897.504 1678.24,897.499 1678.22,897.494 1678.21,897.489 1678.19,897.484 1678.18,897.479 1678.16,897.474 1678.15,897.469 1678.13,897.464 1678.12,897.458 1678.1,897.453 1678.09,897.448 1678.07,897.443 1678.06,897.438 1678.04,897.433 1678.03,897.428 1678.01,897.423 1678,897.418 1677.98,897.413 1677.97,897.408 1677.95,897.403 1677.94,897.398 1677.92,897.392 1677.91,897.387 1677.89,897.382 1677.88,897.377 1677.86,897.372 1677.85,897.367 1677.83,897.362 1677.82,897.357 1677.8,897.352 1677.79,897.347 1677.77,897.342 1677.76,897.337 1677.74,897.332 1677.73,897.327 1677.71,897.322 1677.7,897.317 1677.68,897.311 1677.67,897.306 1677.65,897.301 1677.64,897.296 1677.62,897.291 1677.61,897.286 1677.59,897.281 1677.58,897.276 1677.56,897.271 1677.55,897.266 1677.53,897.261 1677.52,897.256 1677.5,897.251 1677.48,897.246 1677.47,897.241 1677.45,897.236 1677.44,897.231 1677.42,897.226 1677.41,897.221 1677.39,897.216 1677.38,897.21 1677.36,897.205 1677.35,897.2 1677.33,897.195 1677.32,897.19 1677.3,897.185 1677.29,897.18 1677.27,897.175 1677.26,897.17 1677.24,897.165 1677.23,897.16 1677.21,897.155 1677.2,897.15 1677.18,897.145 1677.17,897.14 1677.15,897.135 1677.14,897.13 1677.12,897.125 1677.11,897.12 1677.09,897.115 1677.08,897.11 1677.06,897.105 1677.05,897.1 1677.03,897.095 1677.02,897.09 1677,897.085 1676.99,897.08 1676.97,897.074 1676.96,897.069 1676.94,897.064 1676.93,897.059 1676.91,897.054 1676.9,897.049 1676.88,897.044 1676.87,897.039 1676.85,897.034 1676.84,897.029 1676.82,897.024 1676.81,897.019 1676.79,897.014 1676.78,897.009 1676.76,897.004 1676.75,896.999 1676.73,896.994 1676.72,896.989 1676.7,896.984 1676.69,896.979 1676.67,896.974 1676.66,896.969 1676.64,896.964 1676.63,896.959 1676.61,896.954 1676.6,896.949 1676.58,896.944 1676.57,896.939 1676.55,896.934 1676.54,896.929 1676.52,896.924 1676.51,896.919 1676.49,896.914 1676.48,896.909 1676.46,896.904 1676.45,896.899 1676.43,896.894 1676.42,896.889 1676.4,896.884 1676.39,896.879 1676.37,896.874 1676.36,896.869 1676.34,896.864 1676.33,896.859 1676.31,896.854 1676.3,896.849 1676.28,896.844 1676.27,896.839 1676.25,896.834 1676.24,896.829 1676.22,896.824 1676.21,896.819 1676.19,896.814 1676.18,896.809 1676.16,896.804 1676.15,896.799 1676.13,896.794 1676.12,896.789 1676.1,896.784 1676.09,896.779 1676.07,896.774 1676.06,896.769 1676.04,896.764 1676.03,896.759 1676.01,896.754 1676,896.749 1675.99,896.744 1675.97,896.739 1675.96,896.734 1675.94,896.729 1675.93,896.724 1675.91,896.719 1675.9,896.714 1675.88,896.709 1675.87,896.704 1675.85,896.699 1675.84,896.694 1675.82,896.689 1675.81,896.684 1675.79,896.679 1675.78,896.674 1675.76,896.669 1675.75,896.664 1675.73,896.659 1675.72,896.654 1675.7,896.649 1675.69,896.644 1675.67,896.639 1675.66,896.634 1675.64,896.629 1675.63,896.624 1675.61,896.619 1675.6,896.614 1675.58,896.61 1675.57,896.605 1675.55,896.6 1675.54,896.595 1675.52,896.59 1675.51,896.585 1675.49,896.58 1675.48,896.575 1675.46,896.57 1675.45,896.565 1675.43,896.56 1675.42,896.555 1675.4,896.55 1675.39,896.545 1675.37,896.54 1675.36,896.535 1675.34,896.53 1675.33,896.525 1675.31,896.52 1675.3,896.515 1675.28,896.51 1675.27,896.505 1675.25,896.5 1675.24,896.495 1675.22,896.49 1675.21,896.485 1675.19,896.48 1675.18,896.476 1675.16,896.471 1675.15,896.466 1675.13,896.461 1675.12,896.456 1675.1,896.451 1675.09,896.446 1675.08,896.441 1675.06,896.436 1675.05,896.431 1675.03,896.426 1675.02,896.421 1675,896.416 1674.99,896.411 1674.97,896.406 1674.96,896.401 1674.94,896.396 1674.93,896.391 1674.91,896.386 1674.9,896.381 1674.88,896.377 1674.87,896.372 1674.85,896.367 1674.84,896.362 1674.82,896.357 1674.81,896.352 1674.79,896.347 1674.78,896.342 1674.76,896.337 1674.75,896.332 1674.73,896.327 1674.72,896.322 1674.7,896.317 1674.69,896.312 1674.67,896.307 1674.66,896.302 1674.64,896.298 1674.63,896.293 1674.61,896.288 1674.6,896.283 1674.58,896.278 1674.57,896.273 1674.55,896.268 1674.54,896.263 1674.52,896.258 1674.51,896.253 1674.5,896.248 1674.48,896.243 1674.47,896.238 1674.45,896.233 1674.44,896.229 1674.42,896.224 1674.41,896.219 1674.39,896.214 1674.38,896.209 1674.36,896.204 1674.35,896.199 1674.33,896.194 1674.32,896.189 1674.3,896.184 1674.29,896.179 1674.27,896.174 1674.26,896.169 1674.24,896.165 1674.23,896.16 1674.21,896.155 1674.2,896.15 1674.18,896.145 1674.17,896.14 1674.15,896.135 1674.14,896.13 1674.12,896.125 1674.11,896.12 1674.09,896.115 1674.08,896.111 1674.06,896.106 1674.05,896.101 1674.04,896.096 1674.02,896.091 1674.01,896.086 1673.99,896.081 1673.98,896.076 1673.96,896.071 1673.95,896.066 1673.93,896.061 1673.92,896.057 1673.9,896.052 1673.89,896.047 1673.87,896.042 1673.86,896.037 1673.84,896.032 1673.83,896.027 1673.81,896.022 1673.8,896.017 1673.78,896.012 1673.77,896.008 1673.75,896.003 1673.74,895.998 1673.72,895.993 1673.71,895.988 1673.69,895.983 1673.68,895.978 1673.67,895.973 1673.65,895.968 1673.64,895.964 1673.62,895.959 1673.61,895.954 1673.59,895.949 1673.58,895.944 1673.56,895.939 1673.55,895.934 1673.53,895.929 1673.52,895.924 1673.5,895.919 1673.49,895.915 1673.47,895.91 1673.46,895.905 1673.44,895.9 1673.43,895.895 1673.41,895.89 1673.4,895.885 1673.38,895.88 1673.37,895.876 1673.35,895.871 1673.34,895.866 1673.33,895.861 1673.31,895.856 1673.3,895.851 1673.28,895.846 1673.27,895.841 1673.25,895.837 1673.24,895.832 1673.22,895.827 1673.21,895.822 1673.19,895.817 1673.18,895.812 1673.16,895.807 1673.15,895.802 1673.13,895.798 1673.12,895.793 1673.1,895.788 1673.09,895.783 1673.07,895.778 1673.06,895.773 1673.04,895.768 1673.03,895.763 1673.02,895.759 1673,895.754 1672.99,895.749 1672.97,895.744 1672.96,895.739 1672.94,895.734 1672.93,895.729 1672.91,895.725 1672.9,895.72 1672.88,895.715 1672.87,895.71 1672.85,895.705 1672.84,895.7 1672.82,895.695 1672.81,895.69 1672.79,895.686 1672.78,895.681 1672.76,895.676 1672.75,895.671 1672.74,895.666 1672.72,895.661 1672.71,895.656 1672.69,895.652 1672.68,895.647 1672.66,895.642 1672.65,895.637 1672.63,895.632 1672.62,895.627 1672.6,895.623 1672.59,895.618 1672.57,895.613 1672.56,895.608 1672.54,895.603 1672.53,895.598 1672.51,895.593 1672.5,895.589 1672.48,895.584 1672.47,895.579 1672.46,895.574 1672.44,895.569 1672.43,895.564 1672.41,895.56 1672.4,895.555 1672.38,895.55 1672.37,895.545 1672.35,895.54 1672.34,895.535 1672.32,895.53 1672.31,895.526 1672.29,895.521 1672.28,895.516 1672.26,895.511 1672.25,895.506 1672.24,895.501 1672.22,895.497 1672.21,895.492 1672.19,895.487 1672.18,895.482 1672.16,895.477 1672.15,895.472 1672.13,895.468 1672.12,895.463 1672.1,895.458 1672.09,895.453 1672.07,895.448 1672.06,895.443 1672.04,895.439 1672.03,895.434 1672.01,895.429 1672,895.424 1671.99,895.419 1671.97,895.415 1671.96,895.41 1671.94,895.405 1671.93,895.4 1671.91,895.395 1671.9,895.39 1671.88,895.386 1671.87,895.381 1671.85,895.376 1671.84,895.371 1671.82,895.366 1671.81,895.361 1671.79,895.357 1671.78,895.352 1671.77,895.347 1671.75,895.342 1671.74,895.337 1671.72,895.333 1671.71,895.328 1671.69,895.323 1671.68,895.318 1671.66,895.313 1671.65,895.309 1671.63,895.304 1671.62,895.299 1671.6,895.294 1671.59,895.289 1671.57,895.284 1671.56,895.28 1671.55,895.275 1671.53,895.27 1671.52,895.265 1671.5,895.26 1671.49,895.256 1671.47,895.251 1671.46,895.246 1671.44,895.241 1671.43,895.236 1671.41,895.232 1671.4,895.227 1671.38,895.222 1671.37,895.217 1671.36,895.212 1671.34,895.208 1671.33,895.203 1671.31,895.198 1671.3,895.193 1671.28,895.188 1671.27,895.184 1671.25,895.179 1671.24,895.174 1671.22,895.169 1671.21,895.164 1671.19,895.16 1671.18,895.155 1671.16,895.15 1671.15,895.145 1671.14,895.14 1671.12,895.136 1671.11,895.131 1671.09,895.126 1671.08,895.121 1671.06,895.116 1671.05,895.112 1671.03,895.107 1671.02,895.102 1671,895.097 1670.99,895.093 1670.97,895.088 1670.96,895.083 1670.95,895.078 1670.93,895.073 1670.92,895.069 1670.9,895.064 1670.89,895.059 1670.87,895.054 1670.86,895.05 1670.84,895.045 1670.83,895.04 1670.81,895.035 1670.8,895.03 1670.78,895.026 1670.77,895.021 1670.76,895.016 1670.74,895.011 1670.73,895.007 1670.71,895.002 1670.7,894.997 1670.68,894.992 1670.67,894.987 1670.65,894.983 1670.64,894.978 1670.62,894.973 1670.61,894.968 1670.6,894.964 1670.58,894.959 1670.57,894.954 1670.55,894.949 1670.54,894.944 1670.52,894.94 1670.51,894.935 1670.49,894.93 1670.48,894.925 1670.46,894.921 1670.45,894.916 1670.43,894.911 1670.42,894.906 1670.41,894.902 1670.39,894.897 1670.38,894.892 1670.36,894.887 1670.35,894.883 1670.33,894.878 1670.32,894.873 1670.3,894.868 1670.29,894.864 1670.27,894.859 1670.26,894.854 1670.25,894.849 1670.23,894.844 1670.22,894.84 1670.2,894.835 1670.19,894.83 1670.17,894.825 1670.16,894.821 1670.14,894.816 1670.13,894.811 1670.11,894.806 1670.1,894.802 1670.09,894.797 1670.07,894.792 1670.06,894.787 1670.04,894.783 1670.03,894.778 1670.01,894.773 1670,894.768 1669.98,894.764 1669.97,894.759 1669.95,894.754 1669.94,894.749 1669.93,894.745 1669.91,894.74 1669.9,894.735 1669.88,894.731 1669.87,894.726 1669.85,894.721 1669.84,894.716 1669.82,894.712 1669.81,894.707 1669.79,894.702 1669.78,894.697 1669.77,894.693 1669.75,894.688 1669.74,894.683 1669.72,894.678 1669.71,894.674 1669.69,894.669 1669.68,894.664 1669.66,894.659 1669.65,894.655 1669.63,894.65 1669.62,894.645 1669.61,894.641 1669.59,894.636 1669.58,894.631 1669.56,894.626 1669.55,894.622 1669.53,894.617 1669.52,894.612 1669.5,894.607 1669.49,894.603 1669.48,894.598 1669.46,894.593 1669.45,894.589 1669.43,894.584 1669.42,894.579 1669.4,894.574 1669.39,894.57 1669.37,894.565 1669.36,894.56 1669.34,894.555 1669.33,894.551 1669.32,894.546 1669.3,894.541 1669.29,894.537 1669.27,894.532 1669.26,894.527 1669.24,894.522 1669.23,894.518 1669.21,894.513 1669.2,894.508 1669.19,894.504 1669.17,894.499 1669.16,894.494 1669.14,894.489 1669.13,894.485 1669.11,894.48 1669.1,894.475 1669.08,894.471 1669.07,894.466 1669.05,894.461 1669.04,894.456 1669.03,894.452 1669.01,894.447 1669,894.442 1668.98,894.438 1668.97,894.433 1668.95,894.428 1668.94,894.424 1668.92,894.419 1668.91,894.414 1668.9,894.409 1668.88,894.405 1668.87,894.4 1668.85,894.395 1668.84,894.391 1668.82,894.386 1668.81,894.381 1668.79,894.377 1668.78,894.372 1668.77,894.367 1668.75,894.362 1668.74,894.358 1668.72,894.353 1668.71,894.348 1668.69,894.344 1668.68,894.339 1668.66,894.334 1668.65,894.33 1668.64,894.325 1668.62,894.32 1668.61,894.315 1668.59,894.311 1668.58,894.306 1668.56,894.301 1668.55,894.297 1668.53,894.292 1668.52,894.287 1668.51,894.283 1668.49,894.278 1668.48,894.273 1668.46,894.269 1668.45,894.264 1668.43,894.259 1668.42,894.255 1668.4,894.25 1668.39,894.245 1668.38,894.24 1668.36,894.236 1668.35,894.231 1668.33,894.226 1668.32,894.222 1668.3,894.217 1668.29,894.212 1668.27,894.208 1668.26,894.203 1668.25,894.198 1668.23,894.194 1668.22,894.189 1668.2,894.184 1668.19,894.18 1668.17,894.175 1668.16,894.17 1668.14,894.166 1668.13,894.161 1668.12,894.156 1668.1,894.152 1668.09,894.147 1668.07,894.142 1668.06,894.138 1668.04,894.133 1668.03,894.128 1668.01,894.124 1668,894.119 1667.99,894.114 1667.97,894.11 1667.96,894.105 1667.94,894.1 1667.93,894.096 1667.91,894.091 1667.9,894.086 1667.88,894.082 1667.87,894.077 1667.86,894.072 1667.84,894.068 1667.83,894.063 1667.81,894.058 1667.8,894.054 1667.78,894.049 1667.77,894.044 1667.76,894.04 1667.74,894.035 1667.73,894.03 1667.71,894.026 1667.7,894.021 1667.68,894.016 1667.67,894.012 1667.65,894.007 1667.64,894.002 1667.63,893.998 1667.61,893.993 1667.6,893.988 1667.58,893.984 1667.57,893.979 1667.55,893.975 1667.54,893.97 1667.53,893.965 1667.51,893.961 1667.5,893.956 1667.48,893.951 1667.47,893.947 1667.45,893.942 1667.44,893.937 1667.42,893.933 1667.41,893.928 1667.4,893.923 1667.38,893.919 1667.37,893.914 1667.35,893.909 1667.34,893.905 1667.32,893.9 1667.31,893.896 1667.3,893.891 1667.28,893.886 1667.27,893.882 1667.25,893.877 1667.24,893.872 1667.22,893.868 1667.21,893.863 1667.19,893.858 1667.18,893.854 1667.17,893.849 1667.15,893.845 1667.14,893.84 1667.12,893.835 1667.11,893.831 1667.09,893.826 1667.08,893.821 1667.07,893.817 1667.05,893.812 1667.04,893.807 1667.02,893.803 1667.01,893.798 1666.99,893.794 1666.98,893.789 1666.96,893.784 1666.95,893.78 1666.94,893.775 1666.92,893.77 1666.91,893.766 1666.89,893.761 1666.88,893.757 1666.86,893.752 1666.85,893.747 1666.84,893.743 1666.82,893.738 1666.81,893.733 1666.79,893.729 1666.78,893.724 1666.76,893.72 1666.75,893.715 1666.74,893.71 1666.72,893.706 1666.71,893.701 1666.69,893.697 1666.68,893.692 1666.66,893.687 1666.65,893.683 1666.64,893.678 1666.62,893.673 1666.61,893.669 1666.59,893.664 1666.58,893.66 1666.56,893.655 1666.55,893.65 1666.54,893.646 1666.52,893.641 1666.51,893.637 1666.49,893.632 1666.48,893.627 1666.46,893.623 1666.45,893.618 1666.44,893.613 1666.42,893.609 1666.41,893.604 1666.39,893.6 1666.38,893.595 1666.36,893.59 1666.35,893.586 1666.33,893.581 1666.32,893.577 1666.31,893.572 1666.29,893.567 1666.28,893.563 1666.26,893.558 1666.25,893.554 1666.23,893.549 1666.22,893.544 1666.21,893.54 1666.19,893.535 1666.18,893.531 1666.16,893.526 1666.15,893.521 1666.13,893.517 1666.12,893.512 1666.11,893.508 1666.09,893.503 1666.08,893.499 1666.06,893.494 1666.05,893.489 1666.03,893.485 1666.02,893.48 1666.01,893.476 1665.99,893.471 1665.98,893.466 1665.96,893.462 1665.95,893.457 1665.93,893.453 1665.92,893.448 1665.91,893.443 1665.89,893.439 1665.88,893.434 1665.86,893.43 1665.85,893.425 1665.84,893.421 1665.82,893.416 1665.81,893.411 1665.79,893.407 1665.78,893.402 1665.76,893.398 1665.75,893.393 1665.74,893.388 1665.72,893.384 1665.71,893.379 1665.69,893.375 1665.68,893.37 1665.66,893.366 1665.65,893.361 1665.64,893.356 1665.62,893.352 1665.61,893.347 1665.59,893.343 1665.58,893.338 1665.56,893.334 1665.55,893.329 1665.54,893.324 1665.52,893.32 1665.51,893.315 1665.49,893.311 1665.48,893.306 1665.46,893.302 1665.45,893.297 1665.44,893.292 1665.42,893.288 1665.41,893.283 1665.39,893.279 1665.38,893.274 1665.36,893.27 1665.35,893.265 1665.34,893.26 1665.32,893.256 1665.31,893.251 1665.29,893.247 1665.28,893.242 1665.27,893.238 1665.25,893.233 1665.24,893.228 1665.22,893.224 1665.21,893.219 1665.19,893.215 1665.18,893.21 1665.17,893.206 1665.15,893.201 1665.14,893.197 1665.12,893.192 1665.11,893.187 1665.09,893.183 1665.08,893.178 1665.07,893.174 1665.05,893.169 1665.04,893.165 1665.02,893.16 1665.01,893.156 1665,893.151 1664.98,893.146 1664.97,893.142 1664.95,893.137 1664.94,893.133 1664.92,893.128 1664.91,893.124 1664.9,893.119 1664.88,893.115 1664.87,893.11 1664.85,893.106 1664.84,893.101 1664.82,893.096 1664.81,893.092 1664.8,893.087 1664.78,893.083 1664.77,893.078 1664.75,893.074 1664.74,893.069 1664.73,893.065 1664.71,893.06 1664.7,893.056 1664.68,893.051 1664.67,893.047 1664.65,893.042 1664.64,893.037 1664.63,893.033 1664.61,893.028 1664.6,893.024 1664.58,893.019 1664.57,893.015 1664.56,893.01 1664.54,893.006 1664.53,893.001 1664.51,892.997 1664.5,892.992 1664.48,892.988 1664.47,892.983 1664.46,892.979 1664.44,892.974 1664.43,892.969 1664.41,892.965 1664.4,892.96 1664.38,892.956 1664.37,892.951 1664.36,892.947 1664.34,892.942 1664.33,892.938 1664.31,892.933 1664.3,892.929 1664.29,892.924 1664.27,892.92 1664.26,892.915 1664.24,892.911 1664.23,892.906 1664.22,892.902 1664.2,892.897 1664.19,892.893 1664.17,892.888 1664.16,892.883 1664.14,892.879 1664.13,892.874 1664.12,892.87 1664.1,892.865 1664.09,892.861 1664.07,892.856 1664.06,892.852 1664.05,892.847 1664.03,892.843 1664.02,892.838 1664,892.834 1663.99,892.829 1663.97,892.825 1663.96,892.82 1663.95,892.816 1663.93,892.811 1663.92,892.807 1663.9,892.802 1663.89,892.798 1663.88,892.793 1663.86,892.789 1663.85,892.784 1663.83,892.78 1663.82,892.775 1663.8,892.771 1663.79,892.766 1663.78,892.762 1663.76,892.757 1663.75,892.753 1663.73,892.748 1663.72,892.744 1663.71,892.739 1663.69,892.735 1663.68,892.73 1663.66,892.726 1663.65,892.721 1663.64,892.717 1663.62,892.712 1663.61,892.708 1663.59,892.703 1663.58,892.699 1663.56,892.694 1663.55,892.69 1663.54,892.685 1663.52,892.681 1663.51,892.676 1663.49,892.672 1663.48,892.667 1663.47,892.663 1663.45,892.658 1663.44,892.654 1663.42,892.649 1663.41,892.645 1663.4,892.64 1663.38,892.636 1663.37,892.631 1663.35,892.627 1663.34,892.622 1663.33,892.618 1663.31,892.613 1663.3,892.609 1663.28,892.604 1663.27,892.6 1663.25,892.595 1663.24,892.591 1663.23,892.586 1663.21,892.582 1663.2,892.577 1663.18,892.573 1663.17,892.569 1663.16,892.564 1663.14,892.56 1663.13,892.555 1663.11,892.551 1663.1,892.546 1663.09,892.542 1663.07,892.537 1663.06,892.533 1663.04,892.528 1663.03,892.524 1663.02,892.519 1663,892.515 1662.99,892.51 1662.97,892.506 1662.96,892.501 1662.94,892.497 1662.93,892.492 1662.92,892.488 1662.9,892.483 1662.89,892.479 1662.87,892.475 1662.86,892.47 1662.85,892.466 1662.83,892.461 1662.82,892.457 1662.8,892.452 1662.79,892.448 1662.78,892.443 1662.76,892.439 1662.75,892.434 1662.73,892.43 1662.72,892.425 1662.71,892.421 1662.69,892.416 1662.68,892.412 1662.66,892.408 1662.65,892.403 1662.64,892.399 1662.62,892.394 1662.61,892.39 1662.59,892.385 1662.58,892.381 1662.57,892.376 1662.55,892.372 1662.54,892.367 1662.52,892.363 1662.51,892.358 1662.5,892.354 1662.48,892.35 1662.47,892.345 1662.45,892.341 1662.44,892.336 1662.42,892.332 1662.41,892.327 1662.4,892.323 1662.38,892.318 1662.37,892.314 1662.35,892.31 1662.34,892.305 1662.33,892.301 1662.31,892.296 1662.3,892.292 1662.28,892.287 1662.27,892.283 1662.26,892.278 1662.24,892.274 1662.23,892.269 1662.21,892.265 1662.2,892.261 1662.19,892.256 1662.17,892.252 1662.16,892.247 1662.14,892.243 1662.13,892.238 1662.12,892.234 1662.1,892.229 1662.09,892.225 1662.07,892.221 1662.06,892.216 1662.05,892.212 1662.03,892.207 1662.02,892.203 1662,892.198 1661.99,892.194 1661.98,892.19 1661.96,892.185 1661.95,892.181 1661.93,892.176 1661.92,892.172 1661.91,892.167 1661.89,892.163 1661.88,892.159 1661.86,892.154 1661.85,892.15 1661.84,892.145 1661.82,892.141 1661.81,892.136 1661.79,892.132 1661.78,892.128 1661.77,892.123 1661.75,892.119 1661.74,892.114 1661.72,892.11 1661.71,892.105 1661.7,892.101 1661.68,892.097 1661.67,892.092 1661.65,892.088 1661.64,892.083 1661.63,892.079 1661.61,892.074 1661.6,892.07 1661.58,892.066 1661.57,892.061 1661.56,892.057 1661.54,892.052 1661.53,892.048 1661.51,892.043 1661.5,892.039 1661.49,892.035 1661.47,892.03 1661.46,892.026 1661.44,892.021 1661.43,892.017 1661.42,892.013 1661.4,892.008 1661.39,892.004 1661.37,891.999 1661.36,891.995 1661.35,891.99 1661.33,891.986 1661.32,891.982 1661.31,891.977 1661.29,891.973 1661.28,891.968 1661.26,891.964 1661.25,891.96 1661.24,891.955 1661.22,891.951 1661.21,891.946 1661.19,891.942 1661.18,891.938 1661.17,891.933 1661.15,891.929 1661.14,891.924 1661.12,891.92 1661.11,891.916 1661.1,891.911 1661.08,891.907 1661.07,891.902 1661.05,891.898 1661.04,891.894 1661.03,891.889 1661.01,891.885 1661,891.88 1660.98,891.876 1660.97,891.872 1660.96,891.867 1660.94,891.863 1660.93,891.858 1660.91,891.854 1660.9,891.85 1660.89,891.845 1660.87,891.841 1660.86,891.836 1660.84,891.832 1660.83,891.828 1660.82,891.823 1660.8,891.819 1660.79,891.814 1660.78,891.81 1660.76,891.806 1660.75,891.801 1660.73,891.797 1660.72,891.792 1660.71,891.788 1660.69,891.784 1660.68,891.779 1660.66,891.775 1660.65,891.771 1660.64,891.766 1660.62,891.762 1660.61,891.757 1660.59,891.753 1660.58,891.749 1660.57,891.744 1660.55,891.74 1660.54,891.735 1660.52,891.731 1660.51,891.727 1660.5,891.722 1660.48,891.718 1660.47,891.714 1660.46,891.709 1660.44,891.705 1660.43,891.7 1660.41,891.696 1660.4,891.692 1660.39,891.687 1660.37,891.683 1660.36,891.679 1660.34,891.674 1660.33,891.67 1660.32,891.665 1660.3,891.661 1660.29,891.657 1660.27,891.652 1660.26,891.648 1660.25,891.644 1660.23,891.639 1660.22,891.635 1660.21,891.63 1660.19,891.626 1660.18,891.622 1660.16,891.617 1660.15,891.613 1660.14,891.609 1660.12,891.604 1660.11,891.6 1660.09,891.596 1660.08,891.591 1660.07,891.587 1660.05,891.582 1660.04,891.578 1660.02,891.574 1660.01,891.569 1660,891.565 1659.98,891.561 1659.97,891.556 1659.96,891.552 1659.94,891.548 1659.93,891.543 1659.91,891.539 1659.9,891.534 1659.89,891.53 1659.87,891.526 1659.86,891.521 1659.84,891.517 1659.83,891.513 1659.82,891.508 1659.8,891.504 1659.79,891.5 1659.78,891.495 1659.76,891.491 1659.75,891.487 1659.73,891.482 1659.72,891.478 1659.71,891.474 1659.69,891.469 1659.68,891.465 1659.66,891.46 1659.65,891.456 1659.64,891.452 1659.62,891.447 1659.61,891.443 1659.6,891.439 1659.58,891.434 1659.57,891.43 1659.55,891.426 1659.54,891.421 1659.53,891.417 1659.51,891.413 1659.5,891.408 1659.48,891.404 1659.47,891.4 1659.46,891.395 1659.44,891.391 1659.43,891.387 1659.42,891.382 1659.4,891.378 1659.39,891.374 1659.37,891.369 1659.36,891.365 1659.35,891.361 1659.33,891.356 1659.32,891.352 1659.3,891.348 1659.29,891.343 1659.28,891.339 1659.26,891.335 1659.25,891.33 1659.24,891.326 1659.22,891.322 1659.21,891.317 1659.19,891.313 1659.18,891.309 1659.17,891.304 1659.15,891.3 1659.14,891.296 1659.12,891.291 1659.11,891.287 1659.1,891.283 1659.08,891.278 1659.07,891.274 1659.06,891.27 1659.04,891.265 1659.03,891.261 1659.01,891.257 1659,891.252 1658.99,891.248 1658.97,891.244 1658.96,891.239 1658.95,891.235 1658.93,891.231 1658.92,891.226 1658.9,891.222 1658.89,891.218 1658.88,891.213 1658.86,891.209 1658.85,891.205 1658.83,891.201 1658.82,891.196 1658.81,891.192 1658.79,891.188 1658.78,891.183 1658.77,891.179 1658.75,891.175 1658.74,891.17 1658.72,891.166 1658.71,891.162 1658.7,891.157 1658.68,891.153 1658.67,891.149 1658.66,891.144 1658.64,891.14 1658.63,891.136 1658.61,891.131 1658.6,891.127 1658.59,891.123 1658.57,891.119 1658.56,891.114 1658.55,891.11 1658.53,891.106 1658.52,891.101 1658.5,891.097 1658.49,891.093 1658.48,891.088 1658.46,891.084 1658.45,891.08 1658.44,891.076 1658.42,891.071 1658.41,891.067 1658.39,891.063 1658.38,891.058 1658.37,891.054 1658.35,891.05 1658.34,891.045 1658.33,891.041 1658.31,891.037 1658.3,891.033 1658.28,891.028 1658.27,891.024 1658.26,891.02 1658.24,891.015 1658.23,891.011 1658.22,891.007 1658.2,891.002 1658.19,890.998 1658.17,890.994 1658.16,890.99 1658.15,890.985 1658.13,890.981 1658.12,890.977 1658.11,890.972 1658.09,890.968 1658.08,890.964 1658.06,890.96 1658.05,890.955 1658.04,890.951 1658.02,890.947 1658.01,890.942 1658,890.938 1657.98,890.934 1657.97,890.93 1657.95,890.925 1657.94,890.921 1657.93,890.917 1657.91,890.912 1657.9,890.908 1657.89,890.904 1657.87,890.9 1657.86,890.895 1657.84,890.891 1657.83,890.887 1657.82,890.882 1657.8,890.878 1657.79,890.874 1657.78,890.87 1657.76,890.865 1657.75,890.861 1657.73,890.857 1657.72,890.852 1657.71,890.848 1657.69,890.844 1657.68,890.84 1657.67,890.835 1657.65,890.831 1657.64,890.827 1657.62,890.823 1657.61,890.818 1657.6,890.814 1657.58,890.81 1657.57,890.805 1657.56,890.801 1657.54,890.797 1657.53,890.793 1657.51,890.788 1657.5,890.784 1657.49,890.78 1657.47,890.776 1657.46,890.771 1657.45,890.767 1657.43,890.763 1657.42,890.759 1657.41,890.754 1657.39,890.75 1657.38,890.746 1657.36,890.741 1657.35,890.737 1657.34,890.733 1657.32,890.729 1657.31,890.724 1657.3,890.72 1657.28,890.716 1657.27,890.712 1657.25,890.707 1657.24,890.703 1657.23,890.699 1657.21,890.695 1657.2,890.69 1657.19,890.686 1657.17,890.682 1657.16,890.678 1657.15,890.673 1657.13,890.669 1657.12,890.665 1657.1,890.661 1657.09,890.656 1657.08,890.652 1657.06,890.648 1657.05,890.644 1657.04,890.639 1657.02,890.635 1657.01,890.631 1656.99,890.627 1656.98,890.622 1656.97,890.618 1656.95,890.614 1656.94,890.61 1656.93,890.605 1656.91,890.601 1656.9,890.597 1656.89,890.593 1656.87,890.588 1656.86,890.584 1656.84,890.58 1656.83,890.576 1656.82,890.571 1656.8,890.567 1656.79,890.563 1656.78,890.559 1656.76,890.554 1656.75,890.55 1656.74,890.546 1656.72,890.542 1656.71,890.537 1656.69,890.533 1656.68,890.529 1656.67,890.525 1656.65,890.52 1656.64,890.516 1656.63,890.512 1656.61,890.508 1656.6,890.504 1656.59,890.499 1656.57,890.495 1656.56,890.491 1656.54,890.487 1656.53,890.482 1656.52,890.478 1656.5,890.474 1656.49,890.47 1656.48,890.465 1656.46,890.461 1656.45,890.457 1656.44,890.453 1656.42,890.449 1656.41,890.444 1656.39,890.44 1656.38,890.436 1656.37,890.432 1656.35,890.427 1656.34,890.423 1656.33,890.419 1656.31,890.415 1656.3,890.41 1656.29,890.406 1656.27,890.402 1656.26,890.398 1656.24,890.394 1656.23,890.389 1656.22,890.385 1656.2,890.381 1656.19,890.377 1656.18,890.372 1656.16,890.368 1656.15,890.364 1656.14,890.36 1656.12,890.356 1656.11,890.351 1656.09,890.347 1656.08,890.343 1656.07,890.339 1656.05,890.335 1656.04,890.33 1656.03,890.326 1656.01,890.322 1656,890.318 1655.99,890.313 1655.97,890.309 1655.96,890.305 1655.94,890.301 1655.93,890.297 1655.92,890.292 1655.9,890.288 1655.89,890.284 1655.88,890.28 1655.86,890.276 1655.85,890.271 1655.84,890.267 1655.82,890.263 1655.81,890.259 1655.8,890.255 1655.78,890.25 1655.77,890.246 1655.75,890.242 1655.74,890.238 1655.73,890.234 1655.71,890.229 1655.7,890.225 1655.69,890.221 1655.67,890.217 1655.66,890.213 1655.65,890.208 1655.63,890.204 1655.62,890.2 1655.61,890.196 1655.59,890.192 1655.58,890.187 1655.56,890.183 1655.55,890.179 1655.54,890.175 1655.52,890.171 1655.51,890.166 1655.5,890.162 1655.48,890.158 1655.47,890.154 1655.46,890.15 1655.44,890.145 1655.43,890.141 1655.42,890.137 1655.4,890.133 1655.39,890.129 1655.37,890.124 1655.36,890.12 1655.35,890.116 1655.33,890.112 1655.32,890.108 1655.31,890.103 1655.29,890.099 1655.28,890.095 1655.27,890.091 1655.25,890.087 1655.24,890.083 1655.23,890.078 1655.21,890.074 1655.2,890.07 1655.18,890.066 1655.17,890.062 1655.16,890.057 1655.14,890.053 1655.13,890.049 1655.12,890.045 1655.1,890.041 1655.09,890.037 1655.08,890.032 1655.06,890.028 1655.05,890.024 1655.04,890.02 1655.02,890.016 1655.01,890.011 1655,890.007 1654.98,890.003 1654.97,889.999 1654.95,889.995 1654.94,889.991 1654.93,889.986 1654.91,889.982 1654.9,889.978 1654.89,889.974 1654.87,889.97 1654.86,889.966 1654.85,889.961 1654.83,889.957 1654.82,889.953 1654.81,889.949 1654.79,889.945 1654.78,889.941 1654.77,889.936 1654.75,889.932 1654.74,889.928 1654.72,889.924 1654.71,889.92 1654.7,889.916 1654.68,889.911 1654.67,889.907 1654.66,889.903 1654.64,889.899 1654.63,889.895 1654.62,889.891 1654.6,889.886 1654.59,889.882 1654.58,889.878 1654.56,889.874 1654.55,889.87 1654.54,889.866 1654.52,889.861 1654.51,889.857 1654.49,889.853 1654.48,889.849 1654.47,889.845 1654.45,889.841 1654.44,889.837 1654.43,889.832 1654.41,889.828 1654.4,889.824 1654.39,889.82 1654.37,889.816 1654.36,889.812 1654.35,889.807 1654.33,889.803 1654.32,889.799 1654.31,889.795 1654.29,889.791 1654.28,889.787 1654.27,889.783 1654.25,889.778 1654.24,889.774 1654.22,889.77 1654.21,889.766 1654.2,889.762 1654.18,889.758 1654.17,889.753 1654.16,889.749 1654.14,889.745 1654.13,889.741 1654.12,889.737 1654.1,889.733 1654.09,889.729 1654.08,889.724 1654.06,889.72 1654.05,889.716 1654.04,889.712 1654.02,889.708 1654.01,889.704 1654,889.7 1653.98,889.696 1653.97,889.691 1653.96,889.687 1653.94,889.683 1653.93,889.679 1653.91,889.675 1653.9,889.671 1653.89,889.667 1653.87,889.662 1653.86,889.658 1653.85,889.654 1653.83,889.65 1653.82,889.646 1653.81,889.642 1653.79,889.638 1653.78,889.633 1653.77,889.629 1653.75,889.625 1653.74,889.621 1653.73,889.617 1653.71,889.613 1653.7,889.609 1653.69,889.605 1653.67,889.6 1653.66,889.596 1653.65,889.592 1653.63,889.588 1653.62,889.584 1653.61,889.58 1653.59,889.576 1653.58,889.572 1653.57,889.567 1653.55,889.563 1653.54,889.559 1653.52,889.555 1653.51,889.551 1653.5,889.547 1653.48,889.543 1653.47,889.539 1653.46,889.534 1653.44,889.53 1653.43,889.526 1653.42,889.522 1653.4,889.518 1653.39,889.514 1653.38,889.51 1653.36,889.506 1653.35,889.502 1653.34,889.497 1653.32,889.493 1653.31,889.489 1653.3,889.485 1653.28,889.481 1653.27,889.477 1653.26,889.473 1653.24,889.469 1653.23,889.464 1653.22,889.46 1653.2,889.456 1653.19,889.452 1653.18,889.448 1653.16,889.444 1653.15,889.44 1653.14,889.436 1653.12,889.432 1653.11,889.428 1653.1,889.423 1653.08,889.419 1653.07,889.415 1653.06,889.411 1653.04,889.407 1653.03,889.403 1653.01,889.399 1653,889.395 1652.99,889.391 1652.97,889.386 1652.96,889.382 1652.95,889.378 1652.93,889.374 1652.92,889.37 1652.91,889.366 1652.89,889.362 1652.88,889.358 1652.87,889.354 1652.85,889.35 1652.84,889.345 1652.83,889.341 1652.81,889.337 1652.8,889.333 1652.79,889.329 1652.77,889.325 1652.76,889.321 1652.75,889.317 1652.73,889.313 1652.72,889.309 1652.71,889.305 1652.69,889.3 1652.68,889.296 1652.67,889.292 1652.65,889.288 1652.64,889.284 1652.63,889.28 1652.61,889.276 1652.6,889.272 1652.59,889.268 1652.57,889.264 1652.56,889.26 1652.55,889.255 1652.53,889.251 1652.52,889.247 1652.51,889.243 1652.49,889.239 1652.48,889.235 1652.47,889.231 1652.45,889.227 1652.44,889.223 1652.43,889.219 1652.41,889.215 1652.4,889.211 1652.39,889.206 1652.37,889.202 1652.36,889.198 1652.35,889.194 1652.33,889.19 1652.32,889.186 1652.31,889.182 1652.29,889.178 1652.28,889.174 1652.27,889.17 1652.25,889.166 1652.24,889.162 1652.23,889.157 1652.21,889.153 1652.2,889.149 1652.19,889.145 1652.17,889.141 1652.16,889.137 1652.15,889.133 1652.13,889.129 1652.12,889.125 1652.11,889.121 1652.09,889.117 1652.08,889.113 1652.07,889.109 1652.05,889.105 1652.04,889.1 1652.03,889.096 1652.01,889.092 1652,889.088 1651.99,889.084 1651.97,889.08 1651.96,889.076 1651.95,889.072 1651.93,889.068 1651.92,889.064 1651.91,889.06 1651.89,889.056 1651.88,889.052 1651.87,889.048 1651.85,889.044 1651.84,889.039 1651.83,889.035 1651.81,889.031 1651.8,889.027 1651.79,889.023 1651.77,889.019 1651.76,889.015 1651.75,889.011 1651.73,889.007 1651.72,889.003 1651.71,888.999 1651.69,888.995 1651.68,888.991 1651.67,888.987 1651.65,888.983 1651.64,888.979 1651.63,888.975 1651.61,888.971 1651.6,888.966 1651.59,888.962 1651.57,888.958 1651.56,888.954 1651.55,888.95 1651.53,888.946 1651.52,888.942 1651.51,888.938 1651.49,888.934 1651.48,888.93 1651.47,888.926 1651.45,888.922 1651.44,888.918 1651.43,888.914 1651.41,888.91 1651.4,888.906 1651.39,888.902 1651.37,888.898 1651.36,888.894 1651.35,888.89 1651.33,888.886 1651.32,888.881 1651.31,888.877 1651.29,888.873 1651.28,888.869 1651.27,888.865 1651.25,888.861 1651.24,888.857 1651.23,888.853 1651.21,888.849 1651.2,888.845 1651.19,888.841 1651.17,888.837 1651.16,888.833 1651.15,888.829 1651.13,888.825 1651.12,888.821 1651.11,888.817 1651.09,888.813 1651.08,888.809 1651.07,888.805 1651.05,888.801 1651.04,888.797 1651.03,888.793 1651.01,888.789 1651,888.785 1650.99,888.781 1650.97,888.777 1650.96,888.772 1650.95,888.768 1650.93,888.764 1650.92,888.76 1650.91,888.756 1650.89,888.752 1650.88,888.748 1650.87,888.744 1650.85,888.74 1650.84,888.736 1650.83,888.732 1650.82,888.728 1650.8,888.724 1650.79,888.72 1650.78,888.716 1650.76,888.712 1650.75,888.708 1650.74,888.704 1650.72,888.7 1650.71,888.696 1650.7,888.692 1650.68,888.688 1650.67,888.684 1650.66,888.68 1650.64,888.676 1650.63,888.672 1650.62,888.668 1650.6,888.664 1650.59,888.66 1650.58,888.656 1650.56,888.652 1650.55,888.648 1650.54,888.644 1650.52,888.64 1650.51,888.636 1650.5,888.632 1650.48,888.628 1650.47,888.624 1650.46,888.62 1650.44,888.616 1650.43,888.612 1650.42,888.608 1650.4,888.604 1650.39,888.6 1650.38,888.596 1650.36,888.592 1650.35,888.588 1650.34,888.584 1650.33,888.58 1650.31,888.576 1650.3,888.572 1650.29,888.568 1650.27,888.564 1650.26,888.56 1650.25,888.556 1650.23,888.552 1650.22,888.548 1650.21,888.544 1650.19,888.54 1650.18,888.536 1650.17,888.532 1650.15,888.528 1650.14,888.524 1650.13,888.52 1650.11,888.516 1650.1,888.512 1650.09,888.508 1650.07,888.504 1650.06,888.5 1650.05,888.496 1650.03,888.492 1650.02,888.488 1650.01,888.484 1649.99,888.48 1649.98,888.476 1649.97,888.472 1649.96,888.468 1649.94,888.464 1649.93,888.46 1649.92,888.456 1649.9,888.452 1649.89,888.448 1649.88,888.444 1649.86,888.44 1649.85,888.436 1649.84,888.432 1649.82,888.428 1649.81,888.424 1649.8,888.42 1649.78,888.416 1649.77,888.412 1649.76,888.408 1649.74,888.404 1649.73,888.4 1649.72,888.396 1649.7,888.392 1649.69,888.388 1649.68,888.384 1649.67,888.38 1649.65,888.376 1649.64,888.372 1649.63,888.368 1649.61,888.364 1649.6,888.36 1649.59,888.356 1649.57,888.352 1649.56,888.348 1649.55,888.344 1649.53,888.34 1649.52,888.336 1649.51,888.332 1649.49,888.328 1649.48,888.324 1649.47,888.32 1649.45,888.316 1649.44,888.312 1649.43,888.308 1649.41,888.304 1649.4,888.3 1649.39,888.296 1649.38,888.292 1649.36,888.288 1649.35,888.284 1649.34,888.28 1649.32,888.276 1649.31,888.272 1649.3,888.268 1649.28,888.265 1649.27,888.261 1649.26,888.257 1649.24,888.253 1649.23,888.249 1649.22,888.245 1649.2,888.241 1649.19,888.237 1649.18,888.233 1649.16,888.229 1649.15,888.225 1649.14,888.221 1649.13,888.217 1649.11,888.213 1649.1,888.209 1649.09,888.205 1649.07,888.201 1649.06,888.197 1649.05,888.193 1649.03,888.189 1649.02,888.185 1649.01,888.181 1648.99,888.177 1648.98,888.173 1648.97,888.169 1648.95,888.165 1648.94,888.161 1648.93,888.157 1648.92,888.154 1648.9,888.15 1648.89,888.146 1648.88,888.142 1648.86,888.138 1648.85,888.134 1648.84,888.13 1648.82,888.126 1648.81,888.122 1648.8,888.118 1648.78,888.114 1648.77,888.11 1648.76,888.106 1648.74,888.102 1648.73,888.098 1648.72,888.094 1648.71,888.09 1648.69,888.086 1648.68,888.082 1648.67,888.078 1648.65,888.074 1648.64,888.071 1648.63,888.067 1648.61,888.063 1648.6,888.059 1648.59,888.055 1648.57,888.051 1648.56,888.047 1648.55,888.043 1648.53,888.039 1648.52,888.035 1648.51,888.031 1648.5,888.027 1648.48,888.023 1648.47,888.019 1648.46,888.015 1648.44,888.011 1648.43,888.007 1648.42,888.004 1648.4,888 1648.39,887.996 1648.38,887.992 1648.36,887.988 1648.35,887.984 1648.34,887.98 1648.33,887.976 1648.31,887.972 1648.3,887.968 1648.29,887.964 1648.27,887.96 1648.26,887.956 1648.25,887.952 1648.23,887.948 1648.22,887.944 1648.21,887.941 1648.19,887.937 1648.18,887.933 1648.17,887.929 1648.15,887.925 1648.14,887.921 1648.13,887.917 1648.12,887.913 1648.1,887.909 1648.09,887.905 1648.08,887.901 1648.06,887.897 1648.05,887.893 1648.04,887.889 1648.02,887.886 1648.01,887.882 1648,887.878 1647.98,887.874 1647.97,887.87 1647.96,887.866 1647.95,887.862 1647.93,887.858 1647.92,887.854 1647.91,887.85 1647.89,887.846 1647.88,887.842 1647.87,887.838 1647.85,887.835 1647.84,887.831 1647.83,887.827 1647.82,887.823 1647.8,887.819 1647.79,887.815 1647.78,887.811 1647.76,887.807 1647.75,887.803 1647.74,887.799 1647.72,887.795 1647.71,887.791 1647.7,887.788 1647.68,887.784 1647.67,887.78 1647.66,887.776 1647.65,887.772 1647.63,887.768 1647.62,887.764 1647.61,887.76 1647.59,887.756 1647.58,887.752 1647.57,887.748 1647.55,887.745 1647.54,887.741 1647.53,887.737 1647.51,887.733 1647.5,887.729 1647.49,887.725 1647.48,887.721 1647.46,887.717 1647.45,887.713 1647.44,887.709 1647.42,887.705 1647.41,887.702 1647.4,887.698 1647.38,887.694 1647.37,887.69 1647.36,887.686 1647.35,887.682 1647.33,887.678 1647.32,887.674 1647.31,887.67 1647.29,887.666 1647.28,887.663 1647.27,887.659 1647.25,887.655 1647.24,887.651 1647.23,887.647 1647.22,887.643 1647.2,887.639 1647.19,887.635 1647.18,887.631 1647.16,887.627 1647.15,887.624 1647.14,887.62 1647.12,887.616 1647.11,887.612 1647.1,887.608 1647.09,887.604 1647.07,887.6 1647.06,887.596 1647.05,887.592 1647.03,887.589 1647.02,887.585 1647.01,887.581 1646.99,887.577 1646.98,887.573 1646.97,887.569 1646.96,887.565 1646.94,887.561 1646.93,887.557 1646.92,887.554 1646.9,887.55 1646.89,887.546 1646.88,887.542 1646.86,887.538 1646.85,887.534 1646.84,887.53 1646.83,887.526 1646.81,887.522 1646.8,887.519 1646.79,887.515 1646.77,887.511 1646.76,887.507 1646.75,887.503 1646.73,887.499 1646.72,887.495 1646.71,887.491 1646.7,887.488 1646.68,887.484 1646.67,887.48 1646.66,887.476 1646.64,887.472 1646.63,887.468 1646.62,887.464 1646.6,887.46 1646.59,887.457 1646.58,887.453 1646.57,887.449 1646.55,887.445 1646.54,887.441 1646.53,887.437 1646.51,887.433 1646.5,887.429 1646.49,887.426 1646.47,887.422 1646.46,887.418 1646.45,887.414 1646.44,887.41 1646.42,887.406 1646.41,887.402 1646.4,887.398 1646.38,887.395 1646.37,887.391 1646.36,887.387 1646.34,887.383 1646.33,887.379 1646.32,887.375 1646.31,887.371 1646.29,887.368 1646.28,887.364 1646.27,887.36 1646.25,887.356 1646.24,887.352 1646.23,887.348 1646.22,887.344 1646.2,887.34 1646.19,887.337 1646.18,887.333 1646.16,887.329 1646.15,887.325 1646.14,887.321 1646.12,887.317 1646.11,887.313 1646.1,887.31 1646.09,887.306 1646.07,887.302 1646.06,887.298 1646.05,887.294 1646.03,887.29 1646.02,887.286 1646.01,887.283 1646,887.279 1645.98,887.275 1645.97,887.271 1645.96,887.267 1645.94,887.263 1645.93,887.26 1645.92,887.256 1645.9,887.252 1645.89,887.248 1645.88,887.244 1645.87,887.24 1645.85,887.236 1645.84,887.233 1645.83,887.229 1645.81,887.225 1645.8,887.221 1645.79,887.217 1645.78,887.213 1645.76,887.209 1645.75,887.206 1645.74,887.202 1645.72,887.198 1645.71,887.194 1645.7,887.19 1645.69,887.186 1645.67,887.183 1645.66,887.179 1645.65,887.175 1645.63,887.171 1645.62,887.167 1645.61,887.163 1645.59,887.16 1645.58,887.156 1645.57,887.152 1645.56,887.148 1645.54,887.144 1645.53,887.14 1645.52,887.136 1645.5,887.133 1645.49,887.129 1645.48,887.125 1645.47,887.121 1645.45,887.117 1645.44,887.113 1645.43,887.11 1645.41,887.106 1645.4,887.102 1645.39,887.098 1645.38,887.094 1645.36,887.09 1645.35,887.087 1645.34,887.083 1645.32,887.079 1645.31,887.075 1645.3,887.071 1645.28,887.067 1645.27,887.064 1645.26,887.06 1645.25,887.056 1645.23,887.052 1645.22,887.048 1645.21,887.045 1645.19,887.041 1645.18,887.037 1645.17,887.033 1645.16,887.029 1645.14,887.025 1645.13,887.022 1645.12,887.018 1645.1,887.014 1645.09,887.01 1645.08,887.006 1645.07,887.002 1645.05,886.999 1645.04,886.995 1645.03,886.991 1645.01,886.987 1645,886.983 1644.99,886.98 1644.98,886.976 1644.96,886.972 1644.95,886.968 1644.94,886.964 1644.92,886.96 1644.91,886.957 1644.9,886.953 1644.89,886.949 1644.87,886.945 1644.86,886.941 1644.85,886.938 1644.83,886.934 1644.82,886.93 1644.81,886.926 1644.8,886.922 1644.78,886.918 1644.77,886.915 1644.76,886.911 1644.74,886.907 1644.73,886.903 1644.72,886.899 1644.71,886.896 1644.69,886.892 1644.68,886.888 1644.67,886.884 1644.65,886.88 1644.64,886.877 1644.63,886.873 1644.62,886.869 1644.6,886.865 1644.59,886.861 1644.58,886.858 1644.56,886.854 1644.55,886.85 1644.54,886.846 1644.53,886.842 1644.51,886.839 1644.5,886.835 1644.49,886.831 1644.47,886.827 1644.46,886.823 1644.45,886.82 1644.44,886.816 1644.42,886.812 1644.41,886.808 1644.4,886.804 1644.38,886.801 1644.37,886.797 1644.36,886.793 1644.35,886.789 1644.33,886.785 1644.32,886.782 1644.31,886.778 1644.29,886.774 1644.28,886.77 1644.27,886.766 1644.26,886.763 1644.24,886.759 1644.23,886.755 1644.22,886.751 1644.21,886.747 1644.19,886.744 1644.18,886.74 1644.17,886.736 1644.15,886.732 1644.14,886.728 1644.13,886.725 1644.12,886.721 1644.1,886.717 1644.09,886.713 1644.08,886.71 1644.06,886.706 1644.05,886.702 1644.04,886.698 1644.03,886.694 1644.01,886.691 1644,886.687 1643.99,886.683 1643.97,886.679 1643.96,886.675 1643.95,886.672 1643.94,886.668 1643.92,886.664 1643.91,886.66 1643.9,886.657 1643.88,886.653 1643.87,886.649 1643.86,886.645 1643.85,886.641 1643.83,886.638 1643.82,886.634 1643.81,886.63 1643.8,886.626 1643.78,886.623 1643.77,886.619 1643.76,886.615 1643.74,886.611 1643.73,886.607 1643.72,886.604 1643.71,886.6 1643.69,886.596 1643.68,886.592 1643.67,886.589 1643.65,886.585 1643.64,886.581 1643.63,886.577 1643.62,886.573 1643.6,886.57 1643.59,886.566 1643.58,886.562 1643.57,886.558 1643.55,886.555 1643.54,886.551 1643.53,886.547 1643.51,886.543 1643.5,886.54 1643.49,886.536 1643.48,886.532 1643.46,886.528 1643.45,886.524 1643.44,886.521 1643.42,886.517 1643.41,886.513 1643.4,886.509 1643.39,886.506 1643.37,886.502 1643.36,886.498 1643.35,886.494 1643.34,886.491 1643.32,886.487 1643.31,886.483 1643.3,886.479 1643.28,886.476 1643.27,886.472 1643.26,886.468 1643.25,886.464 1643.23,886.461 1643.22,886.457 1643.21,886.453 1643.19,886.449 1643.18,886.446 1643.17,886.442 1643.16,886.438 1643.14,886.434 1643.13,886.43 1643.12,886.427 1643.11,886.423 1643.09,886.419 1643.08,886.415 1643.07,886.412 1643.05,886.408 1643.04,886.404 1643.03,886.4 1643.02,886.397 1643,886.393 1642.99,886.389 1642.98,886.385 1642.97,886.382 1642.95,886.378 1642.94,886.374 1642.93,886.37 1642.91,886.367 1642.9,886.363 1642.89,886.359 1642.88,886.355 1642.86,886.352 1642.85,886.348 1642.84,886.344 1642.83,886.341 1642.81,886.337 1642.8,886.333 1642.79,886.329 1642.77,886.326 1642.76,886.322 1642.75,886.318 1642.74,886.314 1642.72,886.311 1642.71,886.307 1642.7,886.303 1642.69,886.299 1642.67,886.296 1642.66,886.292 1642.65,886.288 1642.63,886.284 1642.62,886.281 1642.61,886.277 1642.6,886.273 1642.58,886.269 1642.57,886.266 1642.56,886.262 1642.55,886.258 1642.53,886.255 1642.52,886.251 1642.51,886.247 1642.49,886.243 1642.48,886.24 1642.47,886.236 1642.46,886.232 1642.44,886.228 1642.43,886.225 1642.42,886.221 1642.41,886.217 1642.39,886.213 1642.38,886.21 1642.37,886.206 1642.36,886.202 1642.34,886.199 1642.33,886.195 1642.32,886.191 1642.3,886.187 1642.29,886.184 1642.28,886.18 1642.27,886.176 1642.25,886.172 1642.24,886.169 1642.23,886.165 1642.22,886.161 1642.2,886.158 1642.19,886.154 1642.18,886.15 1642.16,886.146 1642.15,886.143 1642.14,886.139 1642.13,886.135 1642.11,886.132 1642.1,886.128 1642.09,886.124 1642.08,886.12 1642.06,886.117 1642.05,886.113 1642.04,886.109 1642.03,886.106 1642.01,886.102 1642,886.098 1641.99,886.094 1641.97,886.091 1641.96,886.087 1641.95,886.083 1641.94,886.08 1641.92,886.076 1641.91,886.072 1641.9,886.068 1641.89,886.065 1641.87,886.061 1641.86,886.057 1641.85,886.054 1641.84,886.05 1641.82,886.046 1641.81,886.042 1641.8,886.039 1641.78,886.035 1641.77,886.031 1641.76,886.028 1641.75,886.024 1641.73,886.02 1641.72,886.016 1641.71,886.013 1641.7,886.009 1641.68,886.005 1641.67,886.002 1641.66,885.998 1641.65,885.994 1641.63,885.991 1641.62,885.987 1641.61,885.983 1641.59,885.979 1641.58,885.976 1641.57,885.972 1641.56,885.968 1641.54,885.965 1641.53,885.961 1641.52,885.957 1641.51,885.954 1641.49,885.95 1641.48,885.946 1641.47,885.942 1641.46,885.939 1641.44,885.935 1641.43,885.931 1641.42,885.928 1641.41,885.924 1641.39,885.92 1641.38,885.917 1641.37,885.913 1641.35,885.909 1641.34,885.905 1641.33,885.902 1641.32,885.898 1641.3,885.894 1641.29,885.891 1641.28,885.887 1641.27,885.883 1641.25,885.88 1641.24,885.876 1641.23,885.872 1641.22,885.869 1641.2,885.865 1641.19,885.861 1641.18,885.858 1641.17,885.854 1641.15,885.85 1641.14,885.846 1641.13,885.843 1641.11,885.839 1641.1,885.835 1641.09,885.832 1641.08,885.828 1641.06,885.824 1641.05,885.821 1641.04,885.817 1641.03,885.813 1641.01,885.81 1641,885.806 1640.99,885.802 1640.98,885.799 1640.96,885.795 1640.95,885.791 1640.94,885.788 1640.93,885.784 1640.91,885.78 1640.9,885.777 1640.89,885.773 1640.88,885.769 1640.86,885.765 1640.85,885.762 1640.84,885.758 1640.82,885.754 1640.81,885.751 1640.8,885.747 1640.79,885.743 1640.77,885.74 1640.76,885.736 1640.75,885.732 1640.74,885.729 1640.72,885.725 1640.71,885.721 1640.7,885.718 1640.69,885.714 1640.67,885.71 1640.66,885.707 1640.65,885.703 1640.64,885.699 1640.62,885.696 1640.61,885.692 1640.6,885.688 1640.59,885.685 1640.57,885.681 1640.56,885.677 1640.55,885.674 1640.54,885.67 1640.52,885.666 1640.51,885.663 1640.5,885.659 1640.48,885.655 1640.47,885.652 1640.46,885.648 1640.45,885.644 1640.43,885.641 1640.42,885.637 1640.41,885.633 1640.4,885.63 1640.38,885.626 1640.37,885.622 1640.36,885.619 1640.35,885.615 1640.33,885.611 1640.32,885.608 1640.31,885.604 1640.3,885.6 1640.28,885.597 1640.27,885.593 1640.26,885.59 1640.25,885.586 1640.23,885.582 1640.22,885.579 1640.21,885.575 1640.2,885.571 1640.18,885.568 1640.17,885.564 1640.16,885.56 1640.15,885.557 1640.13,885.553 1640.12,885.549 1640.11,885.546 1640.1,885.542 1640.08,885.538 1640.07,885.535 1640.06,885.531 1640.05,885.527 1640.03,885.524 1640.02,885.52 1640.01,885.517 1639.99,885.513 1639.98,885.509 1639.97,885.506 1639.96,885.502 1639.94,885.498 1639.93,885.495 1639.92,885.491 1639.91,885.487 1639.89,885.484 1639.88,885.48 1639.87,885.476 1639.86,885.473 1639.84,885.469 1639.83,885.465 1639.82,885.462 1639.81,885.458 1639.79,885.455 1639.78,885.451 1639.77,885.447 1639.76,885.444 1639.74,885.44 1639.73,885.436 1639.72,885.433 1639.71,885.429 1639.69,885.425 1639.68,885.422 1639.67,885.418 1639.66,885.415 1639.64,885.411 1639.63,885.407 1639.62,885.404 1639.61,885.4 1639.59,885.396 1639.58,885.393 1639.57,885.389 1639.56,885.385 1639.54,885.382 1639.53,885.378 1639.52,885.375 1639.51,885.371 1639.49,885.367 1639.48,885.364 1639.47,885.36 1639.46,885.356 1639.44,885.353 1639.43,885.349 1639.42,885.346 1639.41,885.342 1639.39,885.338 1639.38,885.335 1639.37,885.331 1639.36,885.327 1639.34,885.324 1639.33,885.32 1639.32,885.317 1639.31,885.313 1639.29,885.309 1639.28,885.306 1639.27,885.302 1639.26,885.298 1639.24,885.295 1639.23,885.291 1639.22,885.288 1639.21,885.284 1639.19,885.28 1639.18,885.277 1639.17,885.273 1639.16,885.269 1639.14,885.266 1639.13,885.262 1639.12,885.259 1639.11,885.255 1639.09,885.251 1639.08,885.248 1639.07,885.244 1639.06,885.241 1639.04,885.237 1639.03,885.233 1639.02,885.23 1639.01,885.226 1638.99,885.222 1638.98,885.219 1638.97,885.215 1638.96,885.212 1638.94,885.208 1638.93,885.204 1638.92,885.201 1638.91,885.197 1638.89,885.194 1638.88,885.19 1638.87,885.186 1638.86,885.183 1638.84,885.179 1638.83,885.176 1638.82,885.172 1638.81,885.168 1638.79,885.165 1638.78,885.161 1638.77,885.158 1638.76,885.154 1638.74,885.15 1638.73,885.147 1638.72,885.143 1638.71,885.14 1638.69,885.136 1638.68,885.132 1638.67,885.129 1638.66,885.125 1638.65,885.122 1638.63,885.118 1638.62,885.114 1638.61,885.111 1638.6,885.107 1638.58,885.104 1638.57,885.1 1638.56,885.096 1638.55,885.093 1638.53,885.089 1638.52,885.086 1638.51,885.082 1638.5,885.078 1638.48,885.075 1638.47,885.071 1638.46,885.068 1638.45,885.064 1638.43,885.06 1638.42,885.057 1638.41,885.053 1638.4,885.05 1638.38,885.046 1638.37,885.042 1638.36,885.039 1638.35,885.035 1638.33,885.032 1638.32,885.028 1638.31,885.024 1638.3,885.021 1638.28,885.017 1638.27,885.014 1638.26,885.01 1638.25,885.007 1638.23,885.003 1638.22,884.999 1638.21,884.996 1638.2,884.992 1638.18,884.989 1638.17,884.985 1638.16,884.981 1638.15,884.978 1638.14,884.974 1638.12,884.971 1638.11,884.967 1638.1,884.963 1638.09,884.96 1638.07,884.956 1638.06,884.953 1638.05,884.949 1638.04,884.946 1638.02,884.942 1638.01,884.938 1638,884.935 1637.99,884.931 1637.97,884.928 1637.96,884.924 1637.95,884.921 1637.94,884.917 1637.92,884.913 1637.91,884.91 1637.9,884.906 1637.89,884.903 1637.87,884.899 1637.86,884.896 1637.85,884.892 1637.84,884.888 1637.82,884.885 1637.81,884.881 1637.8,884.878 1637.79,884.874 1637.78,884.87 1637.76,884.867 1637.75,884.863 1637.74,884.86 1637.73,884.856 1637.71,884.853 1637.7,884.849 1637.69,884.846 1637.68,884.842 1637.66,884.838 1637.65,884.835 1637.64,884.831 1637.63,884.828 1637.61,884.824 1637.6,884.821 1637.59,884.817 1637.58,884.813 1637.56,884.81 1637.55,884.806 1637.54,884.803 1637.53,884.799 1637.52,884.796 1637.5,884.792 1637.49,884.788 1637.48,884.785 1637.47,884.781 1637.45,884.778 1637.44,884.774 1637.43,884.771 1637.42,884.767 1637.4,884.764 1637.39,884.76 1637.38,884.756 1637.37,884.753 1637.35,884.749 1637.34,884.746 1637.33,884.742 1637.32,884.739 1637.3,884.735 1637.29,884.732 1637.28,884.728 1637.27,884.724 1637.26,884.721 1637.24,884.717 1637.23,884.714 1637.22,884.71 1637.21,884.707 1637.19,884.703 1637.18,884.7 1637.17,884.696 1637.16,884.692 1637.14,884.689 1637.13,884.685 1637.12,884.682 1637.11,884.678 1637.09,884.675 1637.08,884.671 1637.07,884.668 1637.06,884.664 1637.05,884.661 1637.03,884.657 1637.02,884.653 1637.01,884.65 1637,884.646 1636.98,884.643 1636.97,884.639 1636.96,884.636 1636.95,884.632 1636.93,884.629 1636.92,884.625 1636.91,884.622 1636.9,884.618 1636.88,884.614 1636.87,884.611 1636.86,884.607 1636.85,884.604 1636.84,884.6 1636.82,884.597 1636.81,884.593 1636.8,884.59 1636.79,884.586 1636.77,884.583 1636.76,884.579 1636.75,884.576 1636.74,884.572 1636.72,884.568 1636.71,884.565 1636.7,884.561 1636.69,884.558 1636.67,884.554 1636.66,884.551 1636.65,884.547 1636.64,884.544 1636.63,884.54 1636.61,884.537 1636.6,884.533 1636.59,884.53 1636.58,884.526 1636.56,884.523 1636.55,884.519 1636.54,884.515 1636.53,884.512 1636.51,884.508 1636.5,884.505 1636.49,884.501 1636.48,884.498 1636.47,884.494 1636.45,884.491 1636.44,884.487 1636.43,884.484 1636.42,884.48 1636.4,884.477 1636.39,884.473 1636.38,884.47 1636.37,884.466 1636.35,884.463 1636.34,884.459 1636.33,884.456 1636.32,884.452 1636.31,884.448 1636.29,884.445 1636.28,884.441 1636.27,884.438 1636.26,884.434 1636.24,884.431 1636.23,884.427 1636.22,884.424 1636.21,884.42 1636.19,884.417 1636.18,884.413 1636.17,884.41 1636.16,884.406 1636.15,884.403 1636.13,884.399 1636.12,884.396 1636.11,884.392 1636.1,884.389 1636.08,884.385 1636.07,884.382 1636.06,884.378 1636.05,884.375 1636.04,884.371 1636.02,884.368 1636.01,884.364 1636,884.361 1635.99,884.357 1635.97,884.354 1635.96,884.35 1635.95,884.347 1635.94,884.343 1635.92,884.339 1635.91,884.336 1635.9,884.332 1635.89,884.329 1635.88,884.325 1635.86,884.322 1635.85,884.318 1635.84,884.315 1635.83,884.311 1635.81,884.308 1635.8,884.304 1635.79,884.301 1635.78,884.297 1635.77,884.294 1635.75,884.29 1635.74,884.287 1635.73,884.283 1635.72,884.28 1635.7,884.276 1635.69,884.273 1635.68,884.269 1635.67,884.266 1635.65,884.262 1635.64,884.259 1635.63,884.255 1635.62,884.252 1635.61,884.248 1635.59,884.245 1635.58,884.241 1635.57,884.238 1635.56,884.234 1635.54,884.231 1635.53,884.227 1635.52,884.224 1635.51,884.22 1635.5,884.217 1635.48,884.213 1635.47,884.21 1635.46,884.206 1635.45,884.203 1635.43,884.199 1635.42,884.196 1635.41,884.192 1635.4,884.189 1635.39,884.186 1635.37,884.182 1635.36,884.179 1635.35,884.175 1635.34,884.172 1635.32,884.168 1635.31,884.165 1635.3,884.161 1635.29,884.158 1635.27,884.154 1635.26,884.151 1635.25,884.147 1635.24,884.144 1635.23,884.14 1635.21,884.137 1635.2,884.133 1635.19,884.13 1635.18,884.126 1635.16,884.123 1635.15,884.119 1635.14,884.116 1635.13,884.112 1635.12,884.109 1635.1,884.105 1635.09,884.102 1635.08,884.098 1635.07,884.095 1635.05,884.091 1635.04,884.088 1635.03,884.084 1635.02,884.081 1635.01,884.077 1634.99,884.074 1634.98,884.071 1634.97,884.067 1634.96,884.064 1634.94,884.06 1634.93,884.057 1634.92,884.053 1634.91,884.05 1634.9,884.046 1634.88,884.043 1634.87,884.039 1634.86,884.036 1634.85,884.032 1634.84,884.029 1634.82,884.025 1634.81,884.022 1634.8,884.018 1634.79,884.015 1634.77,884.011 1634.76,884.008 1634.75,884.005 1634.74,884.001 1634.73,883.998 1634.71,883.994 1634.7,883.991 1634.69,883.987 1634.68,883.984 1634.66,883.98 1634.65,883.977 1634.64,883.973 1634.63,883.97 1634.62,883.966 1634.6,883.963 1634.59,883.959 1634.58,883.956 1634.57,883.953 1634.55,883.949 1634.54,883.946 1634.53,883.942 1634.52,883.939 1634.51,883.935 1634.49,883.932 1634.48,883.928 1634.47,883.925 1634.46,883.921 1634.44,883.918 1634.43,883.914 1634.42,883.911 1634.41,883.908 1634.4,883.904 1634.38,883.901 1634.37,883.897 1634.36,883.894 1634.35,883.89 1634.34,883.887 1634.32,883.883 1634.31,883.88 1634.3,883.876 1634.29,883.873 1634.27,883.87 1634.26,883.866 1634.25,883.863 1634.24,883.859 1634.23,883.856 1634.21,883.852 1634.2,883.849 1634.19,883.845 1634.18,883.842 1634.16,883.838 1634.15,883.835 1634.14,883.832 1634.13,883.828 1634.12,883.825 1634.1,883.821 1634.09,883.818 1634.08,883.814 1634.07,883.811 1634.06,883.807 1634.04,883.804 1634.03,883.801 1634.02,883.797 1634.01,883.794 1633.99,883.79 1633.98,883.787 1633.97,883.783 1633.96,883.78 1633.95,883.776 1633.93,883.773 1633.92,883.77 1633.91,883.766 1633.9,883.763 1633.89,883.759 1633.87,883.756 1633.86,883.752 1633.85,883.749 1633.84,883.745 1633.82,883.742 1633.81,883.739 1633.8,883.735 1633.79,883.732 1633.78,883.728 1633.76,883.725 1633.75,883.721 1633.74,883.718 1633.73,883.715 1633.72,883.711 1633.7,883.708 1633.69,883.704 1633.68,883.701 1633.67,883.697 1633.65,883.694 1633.64,883.69 1633.63,883.687 1633.62,883.684 1633.61,883.68 1633.59,883.677 1633.58,883.673 1633.57,883.67 1633.56,883.666 1633.55,883.663 1633.53,883.66 1633.52,883.656 1633.51,883.653 1633.5,883.649 1633.48,883.646 1633.47,883.642 1633.46,883.639 1633.45,883.636 1633.44,883.632 1633.42,883.629 1633.41,883.625 1633.4,883.622 1633.39,883.618 1633.38,883.615 1633.36,883.612 1633.35,883.608 1633.34,883.605 1633.33,883.601 1633.32,883.598 1633.3,883.595 1633.29,883.591 1633.28,883.588 1633.27,883.584 1633.25,883.581 1633.24,883.577 1633.23,883.574 1633.22,883.571 1633.21,883.567 1633.19,883.564 1633.18,883.56 1633.17,883.557 1633.16,883.553 1633.15,883.55 1633.13,883.547 1633.12,883.543 1633.11,883.54 1633.1,883.536 1633.09,883.533 1633.07,883.53 1633.06,883.526 1633.05,883.523 1633.04,883.519 1633.02,883.516 1633.01,883.513 1633,883.509 1632.99,883.506 1632.98,883.502 1632.96,883.499 1632.95,883.495 1632.94,883.492 1632.93,883.489 1632.92,883.485 1632.9,883.482 1632.89,883.478 1632.88,883.475 1632.87,883.472 1632.86,883.468 1632.84,883.465 1632.83,883.461 1632.82,883.458 1632.81,883.455 1632.8,883.451 1632.78,883.448 1632.77,883.444 1632.76,883.441 1632.75,883.438 1632.74,883.434 1632.72,883.431 1632.71,883.427 1632.7,883.424 1632.69,883.421 1632.67,883.417 1632.66,883.414 1632.65,883.41 1632.64,883.407 1632.63,883.404 1632.61,883.4 1632.6,883.397 1632.59,883.393 1632.58,883.39 1632.57,883.387 1632.55,883.383 1632.54,883.38 1632.53,883.376 1632.52,883.373 1632.51,883.37 1632.49,883.366 1632.48,883.363 1632.47,883.359 1632.46,883.356 1632.45,883.353 1632.43,883.349 1632.42,883.346 1632.41,883.342 1632.4,883.339 1632.39,883.336 1632.37,883.332 1632.36,883.329 1632.35,883.325 1632.34,883.322 1632.33,883.319 1632.31,883.315 1632.3,883.312 1632.29,883.309 1632.28,883.305 1632.26,883.302 1632.25,883.298 1632.24,883.295 1632.23,883.292 1632.22,883.288 1632.2,883.285 1632.19,883.281 1632.18,883.278 1632.17,883.275 1632.16,883.271 1632.14,883.268 1632.13,883.265 1632.12,883.261 1632.11,883.258 1632.1,883.254 1632.08,883.251 1632.07,883.248 1632.06,883.244 1632.05,883.241 1632.04,883.237 1632.02,883.234 1632.01,883.231 1632,883.227 1631.99,883.224 1631.98,883.221 1631.96,883.217 1631.95,883.214 1631.94,883.21 1631.93,883.207 1631.92,883.204 1631.9,883.2 1631.89,883.197 1631.88,883.194 1631.87,883.19 1631.86,883.187 1631.84,883.183 1631.83,883.18 1631.82,883.177 1631.81,883.173 1631.8,883.17 1631.78,883.167 1631.77,883.163 1631.76,883.16 1631.75,883.156 1631.74,883.153 1631.72,883.15 1631.71,883.146 1631.7,883.143 1631.69,883.14 1631.68,883.136 1631.66,883.133 1631.65,883.13 1631.64,883.126 1631.63,883.123 1631.62,883.119 1631.6,883.116 1631.59,883.113 1631.58,883.109 1631.57,883.106 1631.56,883.103 1631.54,883.099 1631.53,883.096 1631.52,883.093 1631.51,883.089 1631.5,883.086 1631.48,883.082 1631.47,883.079 1631.46,883.076 1631.45,883.072 1631.44,883.069 1631.42,883.066 1631.41,883.062 1631.4,883.059 1631.39,883.056 1631.38,883.052 1631.36,883.049 1631.35,883.045 1631.34,883.042 1631.33,883.039 1631.32,883.035 1631.3,883.032 1631.29,883.029 1631.28,883.025 1631.27,883.022 1631.26,883.019 1631.24,883.015 1631.23,883.012 1631.22,883.009 1631.21,883.005 1631.2,883.002 1631.18,882.999 1631.17,882.995 1631.16,882.992 1631.15,882.988 1631.14,882.985 1631.12,882.982 1631.11,882.978 1631.1,882.975 1631.09,882.972 1631.08,882.968 1631.06,882.965 1631.05,882.962 1631.04,882.958 1631.03,882.955 1631.02,882.952 1631,882.948 1630.99,882.945 1630.98,882.942 1630.97,882.938 1630.96,882.935 1630.95,882.932 1630.93,882.928 1630.92,882.925 1630.91,882.922 1630.9,882.918 1630.89,882.915 1630.87,882.912 1630.86,882.908 1630.85,882.905 1630.84,882.902 1630.83,882.898 1630.81,882.895 1630.8,882.891 1630.79,882.888 1630.78,882.885 1630.77,882.881 1630.75,882.878 1630.74,882.875 1630.73,882.871 1630.72,882.868 1630.71,882.865 1630.69,882.861 1630.68,882.858 1630.67,882.855 1630.66,882.851 1630.65,882.848 1630.63,882.845 1630.62,882.841 1630.61,882.838 1630.6,882.835 1630.59,882.831 1630.57,882.828 1630.56,882.825 1630.55,882.821 1630.54,882.818 1630.53,882.815 1630.52,882.811 1630.5,882.808 1630.49,882.805 1630.48,882.801 1630.47,882.798 1630.46,882.795 1630.44,882.792 1630.43,882.788 1630.42,882.785 1630.41,882.782 1630.4,882.778 1630.38,882.775 1630.37,882.772 1630.36,882.768 1630.35,882.765 1630.34,882.762 1630.32,882.758 1630.31,882.755 1630.3,882.752 1630.29,882.748 1630.28,882.745 1630.26,882.742 1630.25,882.738 1630.24,882.735 1630.23,882.732 1630.22,882.728 1630.21,882.725 1630.19,882.722 1630.18,882.718 1630.17,882.715 1630.16,882.712 1630.15,882.708 1630.13,882.705 1630.12,882.702 1630.11,882.699 1630.1,882.695 1630.09,882.692 1630.07,882.689 1630.06,882.685 1630.05,882.682 1630.04,882.679 1630.03,882.675 1630.01,882.672 1630,882.669 1629.99,882.665 1629.98,882.662 1629.97,882.659 1629.96,882.655 1629.94,882.652 1629.93,882.649 1629.92,882.646 1629.91,882.642 1629.9,882.639 1629.88,882.636 1629.87,882.632 1629.86,882.629 1629.85,882.626 1629.84,882.622 1629.82,882.619 1629.81,882.616 1629.8,882.612 1629.79,882.609 1629.78,882.606 1629.77,882.603 1629.75,882.599 1629.74,882.596 1629.73,882.593 1629.72,882.589 1629.71,882.586 1629.69,882.583 1629.68,882.579 1629.67,882.576 1629.66,882.573 1629.65,882.569 1629.63,882.566 1629.62,882.563 1629.61,882.56 1629.6,882.556 1629.59,882.553 1629.58,882.55 1629.56,882.546 1629.55,882.543 1629.54,882.54 1629.53,882.536 1629.52,882.533 1629.5,882.53 1629.49,882.527 1629.48,882.523 1629.47,882.52 1629.46,882.517 1629.44,882.513 1629.43,882.51 1629.42,882.507 1629.41,882.504 1629.4,882.5 1629.39,882.497 1629.37,882.494 1629.36,882.49 1629.35,882.487 1629.34,882.484 1629.33,882.48 1629.31,882.477 1629.3,882.474 1629.29,882.471 1629.28,882.467 1629.27,882.464 1629.26,882.461 1629.24,882.457 1629.23,882.454 1629.22,882.451 1629.21,882.448 1629.2,882.444 1629.18,882.441 1629.17,882.438 1629.16,882.434 1629.15,882.431 1629.14,882.428 1629.12,882.425 1629.11,882.421 1629.1,882.418 1629.09,882.415 1629.08,882.411 1629.07,882.408 1629.05,882.405 1629.04,882.402 1629.03,882.398 1629.02,882.395 1629.01,882.392 1628.99,882.389 1628.98,882.385 1628.97,882.382 1628.96,882.379 1628.95,882.375 1628.94,882.372 1628.92,882.369 1628.91,882.366 1628.9,882.362 1628.89,882.359 1628.88,882.356 1628.86,882.352 1628.85,882.349 1628.84,882.346 1628.83,882.343 1628.82,882.339 1628.81,882.336 1628.79,882.333 1628.78,882.33 1628.77,882.326 1628.76,882.323 1628.75,882.32 1628.73,882.316 1628.72,882.313 1628.71,882.31 1628.7,882.307 1628.69,882.303 1628.68,882.3 1628.66,882.297 1628.65,882.294 1628.64,882.29 1628.63,882.287 1628.62,882.284 1628.6,882.28 1628.59,882.277 1628.58,882.274 1628.57,882.271 1628.56,882.267 1628.55,882.264 1628.53,882.261 1628.52,882.258 1628.51,882.254 1628.5,882.251 1628.49,882.248 1628.47,882.245 1628.46,882.241 1628.45,882.238 1628.44,882.235 1628.43,882.232 1628.42,882.228 1628.4,882.225 1628.39,882.222 1628.38,882.218 1628.37,882.215 1628.36,882.212 1628.35,882.209 1628.33,882.205 1628.32,882.202 1628.31,882.199 1628.3,882.196 1628.29,882.192 1628.27,882.189 1628.26,882.186 1628.25,882.183 1628.24,882.179 1628.23,882.176 1628.22,882.173 1628.2,882.17 1628.19,882.166 1628.18,882.163 1628.17,882.16 1628.16,882.157 1628.14,882.153 1628.13,882.15 1628.12,882.147 1628.11,882.144 1628.1,882.14 1628.09,882.137 1628.07,882.134 1628.06,882.131 1628.05,882.127 1628.04,882.124 1628.03,882.121 1628.02,882.118 1628,882.114 1627.99,882.111 1627.98,882.108 1627.97,882.105 1627.96,882.101 1627.94,882.098 1627.93,882.095 1627.92,882.092 1627.91,882.088 1627.9,882.085 1627.89,882.082 1627.87,882.079 1627.86,882.075 1627.85,882.072 1627.84,882.069 1627.83,882.066 1627.82,882.062 1627.8,882.059 1627.79,882.056 1627.78,882.053 1627.77,882.05 1627.76,882.046 1627.74,882.043 1627.73,882.04 1627.72,882.037 1627.71,882.033 1627.7,882.03 1627.69,882.027 1627.67,882.024 1627.66,882.02 1627.65,882.017 1627.64,882.014 1627.63,882.011 1627.62,882.007 1627.6,882.004 1627.59,882.001 1627.58,881.998 1627.57,881.994 1627.56,881.991 1627.55,881.988 1627.53,881.985 1627.52,881.982 1627.51,881.978 1627.5,881.975 1627.49,881.972 1627.47,881.969 1627.46,881.965 1627.45,881.962 1627.44,881.959 1627.43,881.956 1627.42,881.953 1627.4,881.949 1627.39,881.946 1627.38,881.943 1627.37,881.94 1627.36,881.936 1627.35,881.933 1627.33,881.93 1627.32,881.927 1627.31,881.923 1627.3,881.92 1627.29,881.917 1627.28,881.914 1627.26,881.911 1627.25,881.907 1627.24,881.904 1627.23,881.901 1627.22,881.898 1627.21,881.894 1627.19,881.891 1627.18,881.888 1627.17,881.885 1627.16,881.882 1627.15,881.878 1627.13,881.875 1627.12,881.872 1627.11,881.869 1627.1,881.865 1627.09,881.862 1627.08,881.859 1627.06,881.856 1627.05,881.853 1627.04,881.849 1627.03,881.846 1627.02,881.843 1627.01,881.84 1626.99,881.837 1626.98,881.833 1626.97,881.83 1626.96,881.827 1626.95,881.824 1626.94,881.82 1626.92,881.817 1626.91,881.814 1626.9,881.811 1626.89,881.808 1626.88,881.804 1626.87,881.801 1626.85,881.798 1626.84,881.795 1626.83,881.792 1626.82,881.788 1626.81,881.785 1626.8,881.782 1626.78,881.779 1626.77,881.776 1626.76,881.772 1626.75,881.769 1626.74,881.766 1626.73,881.763 1626.71,881.759 1626.7,881.756 1626.69,881.753 1626.68,881.75 1626.67,881.747 1626.66,881.743 1626.64,881.74 1626.63,881.737 1626.62,881.734 1626.61,881.731 1626.6,881.727 1626.59,881.724 1626.57,881.721 1626.56,881.718 1626.55,881.715 1626.54,881.711 1626.53,881.708 1626.52,881.705 1626.5,881.702 1626.49,881.699 1626.48,881.695 1626.47,881.692 1626.46,881.689 1626.45,881.686 1626.43,881.683 1626.42,881.679 1626.41,881.676 1626.4,881.673 1626.39,881.67 1626.38,881.667 1626.36,881.664 1626.35,881.66 1626.34,881.657 1626.33,881.654 1626.32,881.651 1626.31,881.648 1626.29,881.644 1626.28,881.641 1626.27,881.638 1626.26,881.635 1626.25,881.632 1626.24,881.628 1626.22,881.625 1626.21,881.622 1626.2,881.619 1626.19,881.616 1626.18,881.612 1626.17,881.609 1626.15,881.606 1626.14,881.603 1626.13,881.6 1626.12,881.597 1626.11,881.593 1626.1,881.59 1626.08,881.587 1626.07,881.584 1626.06,881.581 1626.05,881.577 1626.04,881.574 1626.03,881.571 1626.01,881.568 1626,881.565 1625.99,881.561 1625.98,881.558 1625.97,881.555 1625.96,881.552 1625.94,881.549 1625.93,881.546 1625.92,881.542 1625.91,881.539 1625.9,881.536 1625.89,881.533 1625.87,881.53 1625.86,881.527 1625.85,881.523 1625.84,881.52 1625.83,881.517 1625.82,881.514 1625.8,881.511 1625.79,881.507 1625.78,881.504 1625.77,881.501 1625.76,881.498 1625.75,881.495 1625.73,881.492 1625.72,881.488 1625.71,881.485 1625.7,881.482 1625.69,881.479 1625.68,881.476 1625.67,881.473 1625.65,881.469 1625.64,881.466 1625.63,881.463 1625.62,881.46 1625.61,881.457 1625.6,881.454 1625.58,881.45 1625.57,881.447 1625.56,881.444 1625.55,881.441 1625.54,881.438 1625.53,881.435 1625.51,881.431 1625.5,881.428 1625.49,881.425 1625.48,881.422 1625.47,881.419 1625.46,881.416 1625.44,881.412 1625.43,881.409 1625.42,881.406 1625.41,881.403 1625.4,881.4 1625.39,881.397 1625.38,881.393 1625.36,881.39 1625.35,881.387 1625.34,881.384 1625.33,881.381 1625.32,881.378 1625.31,881.374 1625.29,881.371 1625.28,881.368 1625.27,881.365 1625.26,881.362 1625.25,881.359 1625.24,881.355 1625.22,881.352 1625.21,881.349 1625.2,881.346 1625.19,881.343 1625.18,881.34 1625.17,881.337 1625.15,881.333 1625.14,881.33 1625.13,881.327 1625.12,881.324 1625.11,881.321 1625.1,881.318 1625.09,881.314 1625.07,881.311 1625.06,881.308 1625.05,881.305 1625.04,881.302 1625.03,881.299 1625.02,881.296 1625,881.292 1624.99,881.289 1624.98,881.286 1624.97,881.283 1624.96,881.28 1624.95,881.277 1624.93,881.273 1624.92,881.27 1624.91,881.267 1624.9,881.264 1624.89,881.261 1624.88,881.258 1624.87,881.255 1624.85,881.251 1624.84,881.248 1624.83,881.245 1624.82,881.242 1624.81,881.239 1624.8,881.236 1624.78,881.233 1624.77,881.229 1624.76,881.226 1624.75,881.223 1624.74,881.22 1624.73,881.217 1624.72,881.214 1624.7,881.211 1624.69,881.207 1624.68,881.204 1624.67,881.201 1624.66,881.198 1624.65,881.195 1624.63,881.192 1624.62,881.189 1624.61,881.185 1624.6,881.182 1624.59,881.179 1624.58,881.176 1624.56,881.173 1624.55,881.17 1624.54,881.167 1624.53,881.164 1624.52,881.16 1624.51,881.157 1624.5,881.154 1624.48,881.151 1624.47,881.148 1624.46,881.145 1624.45,881.142 1624.44,881.138 1624.43,881.135 1624.41,881.132 1624.4,881.129 1624.39,881.126 1624.38,881.123 1624.37,881.12 1624.36,881.117 1624.35,881.113 1624.33,881.11 1624.32,881.107 1624.31,881.104 1624.3,881.101 1624.29,881.098 1624.28,881.095 1624.26,881.092 1624.25,881.088 1624.24,881.085 1624.23,881.082 1624.22,881.079 1624.21,881.076 1624.2,881.073 1624.18,881.07 1624.17,881.067 1624.16,881.063 1624.15,881.06 1624.14,881.057 1624.13,881.054 1624.12,881.051 1624.1,881.048 1624.09,881.045 1624.08,881.042 1624.07,881.038 1624.06,881.035 1624.05,881.032 1624.03,881.029 1624.02,881.026 1624.01,881.023 1624,881.02 1623.99,881.017 1623.98,881.013 1623.97,881.01 1623.95,881.007 1623.94,881.004 1623.93,881.001 1623.92,880.998 1623.91,880.995 1623.9,880.992 1623.88,880.989 1623.87,880.985 1623.86,880.982 1623.85,880.979 1623.84,880.976 1623.83,880.973 1623.82,880.97 1623.8,880.967 1623.79,880.964 1623.78,880.961 1623.77,880.957 1623.76,880.954 1623.75,880.951 1623.74,880.948 1623.72,880.945 1623.71,880.942 1623.7,880.939 1623.69,880.936 1623.68,880.933 1623.67,880.929 1623.65,880.926 1623.64,880.923 1623.63,880.92 1623.62,880.917 1623.61,880.914 1623.6,880.911 1623.59,880.908 1623.57,880.905 1623.56,880.901 1623.55,880.898 1623.54,880.895 1623.53,880.892 1623.52,880.889 1623.51,880.886 1623.49,880.883 1623.48,880.88 1623.47,880.877 1623.46,880.874 1623.45,880.87 1623.44,880.867 1623.43,880.864 1623.41,880.861 1623.4,880.858 1623.39,880.855 1623.38,880.852 1623.37,880.849 1623.36,880.846 1623.34,880.843 1623.33,880.839 1623.32,880.836 1623.31,880.833 1623.3,880.83 1623.29,880.827 1623.28,880.824 1623.26,880.821 1623.25,880.818 1623.24,880.815 1623.23,880.812 1623.22,880.809 1623.21,880.805 1623.2,880.802 1623.18,880.799 1623.17,880.796 1623.16,880.793 1623.15,880.79 1623.14,880.787 1623.13,880.784 1623.12,880.781 1623.1,880.778 1623.09,880.775 1623.08,880.771 1623.07,880.768 1623.06,880.765 1623.05,880.762 1623.04,880.759 1623.02,880.756 1623.01,880.753 1623,880.75 1622.99,880.747 1622.98,880.744 1622.97,880.741 1622.96,880.737 1622.94,880.734 1622.93,880.731 1622.92,880.728 1622.91,880.725 1622.9,880.722 1622.89,880.719 1622.88,880.716 1622.86,880.713 1622.85,880.71 1622.84,880.707 1622.83,880.704 1622.82,880.7 1622.81,880.697 1622.8,880.694 1622.78,880.691 1622.77,880.688 1622.76,880.685 1622.75,880.682 1622.74,880.679 1622.73,880.676 1622.72,880.673 1622.7,880.67 1622.69,880.667 1622.68,880.664 1622.67,880.66 1622.66,880.657 1622.65,880.654 1622.64,880.651 1622.62,880.648 1622.61,880.645 1622.6,880.642 1622.59,880.639 1622.58,880.636 1622.57,880.633 1622.56,880.63 1622.54,880.627 1622.53,880.624 1622.52,880.621 1622.51,880.617 1622.5,880.614 1622.49,880.611 1622.48,880.608 1622.46,880.605 1622.45,880.602 1622.44,880.599 1622.43,880.596 1622.42,880.593 1622.41,880.59 1622.4,880.587 1622.38,880.584 1622.37,880.581 1622.36,880.578 1622.35,880.575 1622.34,880.571 1622.33,880.568 1622.32,880.565 1622.3,880.562 1622.29,880.559 1622.28,880.556 1622.27,880.553 1622.26,880.55 1622.25,880.547 1622.24,880.544 1622.22,880.541 1622.21,880.538 1622.2,880.535 1622.19,880.532 1622.18,880.529 1622.17,880.526 1622.16,880.522 1622.14,880.519 1622.13,880.516 1622.12,880.513 1622.11,880.51 1622.1,880.507 1622.09,880.504 1622.08,880.501 1622.06,880.498 1622.05,880.495 1622.04,880.492 1622.03,880.489 1622.02,880.486 1622.01,880.483 1622,880.48 1621.99,880.477 1621.97,880.474 1621.96,880.471 1621.95,880.467 1621.94,880.464 1621.93,880.461 1621.92,880.458 1621.91,880.455 1621.89,880.452 1621.88,880.449 1621.87,880.446 1621.86,880.443 1621.85,880.44 1621.84,880.437 1621.83,880.434 1621.81,880.431 1621.8,880.428 1621.79,880.425 1621.78,880.422 1621.77,880.419 1621.76,880.416 1621.75,880.413 1621.73,880.41 1621.72,880.406 1621.71,880.403 1621.7,880.4 1621.69,880.397 1621.68,880.394 1621.67,880.391 1621.66,880.388 1621.64,880.385 1621.63,880.382 1621.62,880.379 1621.61,880.376 1621.6,880.373 1621.59,880.37 1621.58,880.367 1621.56,880.364 1621.55,880.361 1621.54,880.358 1621.53,880.355 1621.52,880.352 1621.51,880.349 1621.5,880.346 1621.48,880.343 1621.47,880.34 1621.46,880.337 1621.45,880.333 1621.44,880.33 1621.43,880.327 1621.42,880.324 1621.41,880.321 1621.39,880.318 1621.38,880.315 1621.37,880.312 1621.36,880.309 1621.35,880.306 1621.34,880.303 1621.33,880.3 1621.31,880.297 1621.3,880.294 1621.29,880.291 1621.28,880.288 1621.27,880.285 1621.26,880.282 1621.25,880.279 1621.24,880.276 1621.22,880.273 1621.21,880.27 1621.2,880.267 1621.19,880.264 1621.18,880.261 1621.17,880.258 1621.16,880.255 1621.14,880.252 1621.13,880.249 1621.12,880.246 1621.11,880.243 1621.1,880.24 1621.09,880.237 1621.08,880.233 1621.07,880.23 1621.05,880.227 1621.04,880.224 1621.03,880.221 1621.02,880.218 1621.01,880.215 1621,880.212 1620.99,880.209 1620.97,880.206 1620.96,880.203 1620.95,880.2 1620.94,880.197 1620.93,880.194 1620.92,880.191 1620.91,880.188 1620.9,880.185 1620.88,880.182 1620.87,880.179 1620.86,880.176 1620.85,880.173 1620.84,880.17 1620.83,880.167 1620.82,880.164 1620.81,880.161 1620.79,880.158 1620.78,880.155 1620.77,880.152 1620.76,880.149 1620.75,880.146 1620.74,880.143 1620.73,880.14 1620.71,880.137 1620.7,880.134 1620.69,880.131 1620.68,880.128 1620.67,880.125 1620.66,880.122 1620.65,880.119 1620.64,880.116 1620.62,880.113 1620.61,880.11 1620.6,880.107 1620.59,880.104 1620.58,880.101 1620.57,880.098 1620.56,880.095 1620.55,880.092 1620.53,880.089 1620.52,880.086 1620.51,880.083 1620.5,880.08 1620.49,880.077 1620.48,880.074 1620.47,880.071 1620.45,880.068 1620.44,880.065 1620.43,880.062 1620.42,880.059 1620.41,880.056 1620.4,880.053 1620.39,880.05 1620.38,880.047 1620.36,880.044 1620.35,880.041 1620.34,880.038 1620.33,880.035 1620.32,880.032 1620.31,880.029 1620.3,880.026 1620.29,880.023 1620.27,880.02 1620.26,880.017 1620.25,880.014 1620.24,880.011 1620.23,880.008 1620.22,880.005 1620.21,880.002 1620.2,879.999 1620.18,879.996 1620.17,879.993 1620.16,879.99 1620.15,879.987 1620.14,879.984 1620.13,879.981 1620.12,879.978 1620.11,879.975 1620.09,879.972 1620.08,879.969 1620.07,879.966 1620.06,879.963 1620.05,879.96 1620.04,879.957 1620.03,879.954 1620.02,879.951 1620,879.948 1619.99,879.945 1619.98,879.942 1619.97,879.939 1619.96,879.936 1619.95,879.933 1619.94,879.93 1619.93,879.927 1619.91,879.924 1619.9,879.921 1619.89,879.918 1619.88,879.915 1619.87,879.912 1619.86,879.909 1619.85,879.906 1619.83,879.903 1619.82,879.9 1619.81,879.897 1619.8,879.894 1619.79,879.891 1619.78,879.888 1619.77,879.885 1619.76,879.882 1619.75,879.879 1619.73,879.876 1619.72,879.873 1619.71,879.87 1619.7,879.867 1619.69,879.864 1619.68,879.861 1619.67,879.858 1619.66,879.855 1619.64,879.852 1619.63,879.849 1619.62,879.846 1619.61,879.843 1619.6,879.84 1619.59,879.837 1619.58,879.834 1619.57,879.831 1619.55,879.828 1619.54,879.825 1619.53,879.822 1619.52,879.819 1619.51,879.816 1619.5,879.814 1619.49,879.811 1619.48,879.808 1619.46,879.805 1619.45,879.802 1619.44,879.799 1619.43,879.796 1619.42,879.793 1619.41,879.79 1619.4,879.787 1619.39,879.784 1619.37,879.781 1619.36,879.778 1619.35,879.775 1619.34,879.772 1619.33,879.769 1619.32,879.766 1619.31,879.763 1619.3,879.76 1619.28,879.757 1619.27,879.754 1619.26,879.751 1619.25,879.748 1619.24,879.745 1619.23,879.742 1619.22,879.739 1619.21,879.736 1619.19,879.733 1619.18,879.73 1619.17,879.727 1619.16,879.724 1619.15,879.721 1619.14,879.719 1619.13,879.716 1619.12,879.713 1619.11,879.71 1619.09,879.707 1619.08,879.704 1619.07,879.701 1619.06,879.698 1619.05,879.695 1619.04,879.692 1619.03,879.689 1619.02,879.686 1619,879.683 1618.99,879.68 1618.98,879.677 1618.97,879.674 1618.96,879.671 1618.95,879.668 1618.94,879.665 1618.93,879.662 1618.91,879.659 1618.9,879.656 1618.89,879.653 1618.88,879.65 1618.87,879.647 1618.86,879.645 1618.85,879.642 1618.84,879.639 1618.83,879.636 1618.81,879.633 1618.8,879.63 1618.79,879.627 1618.78,879.624 1618.77,879.621 1618.76,879.618 1618.75,879.615 1618.74,879.612 1618.72,879.609 1618.71,879.606 1618.7,879.603 1618.69,879.6 1618.68,879.597 1618.67,879.594 1618.66,879.591 1618.65,879.588 1618.64,879.586 1618.62,879.583 1618.61,879.58 1618.6,879.577 1618.59,879.574 1618.58,879.571 1618.57,879.568 1618.56,879.565 1618.55,879.562 1618.53,879.559 1618.52,879.556 1618.51,879.553 1618.5,879.55 1618.49,879.547 1618.48,879.544 1618.47,879.541 1618.46,879.538 1618.45,879.535 1618.43,879.533 1618.42,879.53 1618.41,879.527 1618.4,879.524 1618.39,879.521 1618.38,879.518 1618.37,879.515 1618.36,879.512 1618.35,879.509 1618.33,879.506 1618.32,879.503 1618.31,879.5 1618.3,879.497 1618.29,879.494 1618.28,879.491 1618.27,879.488 1618.26,879.486 1618.24,879.483 1618.23,879.48 1618.22,879.477 1618.21,879.474 1618.2,879.471 1618.19,879.468 1618.18,879.465 1618.17,879.462 1618.16,879.459 1618.14,879.456 1618.13,879.453 1618.12,879.45 1618.11,879.447 1618.1,879.444 1618.09,879.442 1618.08,879.439 1618.07,879.436 1618.06,879.433 1618.04,879.43 1618.03,879.427 1618.02,879.424 1618.01,879.421 1618,879.418 1617.99,879.415 1617.98,879.412 1617.97,879.409 1617.96,879.406 1617.94,879.403 1617.93,879.401 1617.92,879.398 1617.91,879.395 1617.9,879.392 1617.89,879.389 1617.88,879.386 1617.87,879.383 1617.85,879.38 1617.84,879.377 1617.83,879.374 1617.82,879.371 1617.81,879.368 1617.8,879.365 1617.79,879.363 1617.78,879.36 1617.77,879.357 1617.75,879.354 1617.74,879.351 1617.73,879.348 1617.72,879.345 1617.71,879.342 1617.7,879.339 1617.69,879.336 1617.68,879.333 1617.67,879.33 1617.65,879.327 1617.64,879.325 1617.63,879.322 1617.62,879.319 1617.61,879.316 1617.6,879.313 1617.59,879.31 1617.58,879.307 1617.57,879.304 1617.55,879.301 1617.54,879.298 1617.53,879.295 1617.52,879.293 1617.51,879.29 1617.5,879.287 1617.49,879.284 1617.48,879.281 1617.47,879.278 1617.45,879.275 1617.44,879.272 1617.43,879.269 1617.42,879.266 1617.41,879.263 1617.4,879.26 1617.39,879.258 1617.38,879.255 1617.37,879.252 1617.35,879.249 1617.34,879.246 1617.33,879.243 1617.32,879.24 1617.31,879.237 1617.3,879.234 1617.29,879.231 1617.28,879.229 1617.27,879.226 1617.26,879.223 1617.24,879.22 1617.23,879.217 1617.22,879.214 1617.21,879.211 1617.2,879.208 1617.19,879.205 1617.18,879.202 1617.17,879.199 1617.16,879.197 1617.14,879.194 1617.13,879.191 1617.12,879.188 1617.11,879.185 1617.1,879.182 1617.09,879.179 1617.08,879.176 1617.07,879.173 1617.06,879.17 1617.04,879.168 1617.03,879.165 1617.02,879.162 1617.01,879.159 1617,879.156 1616.99,879.153 1616.98,879.15 1616.97,879.147 1616.96,879.144 1616.94,879.142 1616.93,879.139 1616.92,879.136 1616.91,879.133 1616.9,879.13 1616.89,879.127 1616.88,879.124 1616.87,879.121 1616.86,879.118 1616.85,879.115 1616.83,879.113 1616.82,879.11 1616.81,879.107 1616.8,879.104 1616.79,879.101 1616.78,879.098 1616.77,879.095 1616.76,879.092 1616.75,879.089 1616.73,879.087 1616.72,879.084 1616.71,879.081 1616.7,879.078 1616.69,879.075 1616.68,879.072 1616.67,879.069 1616.66,879.066 1616.65,879.064 1616.64,879.061 1616.62,879.058 1616.61,879.055 1616.6,879.052 1616.59,879.049 1616.58,879.046 1616.57,879.043 1616.56,879.04 1616.55,879.038 1616.54,879.035 1616.52,879.032 1616.51,879.029 1616.5,879.026 1616.49,879.023 1616.48,879.02 1616.47,879.017 1616.46,879.015 1616.45,879.012 1616.44,879.009 1616.43,879.006 1616.41,879.003 1616.4,879 1616.39,878.997 1616.38,878.994 1616.37,878.991 1616.36,878.989 1616.35,878.986 1616.34,878.983 1616.33,878.98 1616.32,878.977 1616.3,878.974 1616.29,878.971 1616.28,878.968 1616.27,878.966 1616.26,878.963 1616.25,878.96 1616.24,878.957 1616.23,878.954 1616.22,878.951 1616.2,878.948 1616.19,878.945 1616.18,878.943 1616.17,878.94 1616.16,878.937 1616.15,878.934 1616.14,878.931 1616.13,878.928 1616.12,878.925 1616.11,878.923 1616.09,878.92 1616.08,878.917 1616.07,878.914 1616.06,878.911 1616.05,878.908 1616.04,878.905 1616.03,878.902 1616.02,878.9 1616.01,878.897 1616,878.894 1615.98,878.891 1615.97,878.888 1615.96,878.885 1615.95,878.882 1615.94,878.88 1615.93,878.877 1615.92,878.874 1615.91,878.871 1615.9,878.868 1615.89,878.865 1615.87,878.862 1615.86,878.86 1615.85,878.857 1615.84,878.854 1615.83,878.851 1615.82,878.848 1615.81,878.845 1615.8,878.842 1615.79,878.84 1615.78,878.837 1615.76,878.834 1615.75,878.831 1615.74,878.828 1615.73,878.825 1615.72,878.822 1615.71,878.82 1615.7,878.817 1615.69,878.814 1615.68,878.811 1615.67,878.808 1615.65,878.805 1615.64,878.802 1615.63,878.8 1615.62,878.797 1615.61,878.794 1615.6,878.791 1615.59,878.788 1615.58,878.785 1615.57,878.782 1615.56,878.78 1615.54,878.777 1615.53,878.774 1615.52,878.771 1615.51,878.768 1615.5,878.765 1615.49,878.762 1615.48,878.76 1615.47,878.757 1615.46,878.754 1615.45,878.751 1615.43,878.748 1615.42,878.745 1615.41,878.743 1615.4,878.74 1615.39,878.737 1615.38,878.734 1615.37,878.731 1615.36,878.728 1615.35,878.725 1615.34,878.723 1615.33,878.72 1615.31,878.717 1615.3,878.714 1615.29,878.711 1615.28,878.708 1615.27,878.706 1615.26,878.703 1615.25,878.7 1615.24,878.697 1615.23,878.694 1615.22,878.691 1615.2,878.688 1615.19,878.686 1615.18,878.683 1615.17,878.68 1615.16,878.677 1615.15,878.674 1615.14,878.671 1615.13,878.669 1615.12,878.666 1615.11,878.663 1615.1,878.66 1615.08,878.657 1615.07,878.654 1615.06,878.652 1615.05,878.649 1615.04,878.646 1615.03,878.643 1615.02,878.64 1615.01,878.637 1615,878.635 1614.99,878.632 1614.97,878.629 1614.96,878.626 1614.95,878.623 1614.94,878.62 1614.93,878.618 1614.92,878.615 1614.91,878.612 1614.9,878.609 1614.89,878.606 1614.88,878.603 1614.87,878.601 1614.85,878.598 1614.84,878.595 1614.83,878.592 1614.82,878.589 1614.81,878.586 1614.8,878.584 1614.79,878.581 1614.78,878.578 1614.77,878.575 1614.76,878.572 1614.74,878.57 1614.73,878.567 1614.72,878.564 1614.71,878.561 1614.7,878.558 1614.69,878.555 1614.68,878.553 1614.67,878.55 1614.66,878.547 1614.65,878.544 1614.64,878.541 1614.62,878.538 1614.61,878.536 1614.6,878.533 1614.59,878.53 1614.58,878.527 1614.57,878.524 1614.56,878.522 1614.55,878.519 1614.54,878.516 1614.53,878.513 1614.52,878.51 1614.5,878.507 1614.49,878.505 1614.48,878.502 1614.47,878.499 1614.46,878.496 1614.45,878.493 1614.44,878.491 1614.43,878.488 1614.42,878.485 1614.41,878.482 1614.4,878.479 1614.38,878.476 1614.37,878.474 1614.36,878.471 1614.35,878.468 1614.34,878.465 1614.33,878.462 1614.32,878.46 1614.31,878.457 1614.3,878.454 1614.29,878.451 1614.28,878.448 1614.26,878.445 1614.25,878.443 1614.24,878.44 1614.23,878.437 1614.22,878.434 1614.21,878.431 1614.2,878.429 1614.19,878.426 1614.18,878.423 1614.17,878.42 1614.16,878.417 1614.14,878.415 1614.13,878.412 1614.12,878.409 1614.11,878.406 1614.1,878.403 1614.09,878.401 1614.08,878.398 1614.07,878.395 1614.06,878.392 1614.05,878.389 1614.04,878.387 1614.02,878.384 1614.01,878.381 1614,878.378 1613.99,878.375 1613.98,878.373 1613.97,878.37 1613.96,878.367 1613.95,878.364 1613.94,878.361 1613.93,878.359 1613.92,878.356 1613.91,878.353 1613.89,878.35 1613.88,878.347 1613.87,878.345 1613.86,878.342 1613.85,878.339 1613.84,878.336 1613.83,878.333 1613.82,878.331 1613.81,878.328 1613.8,878.325 1613.79,878.322 1613.77,878.319 1613.76,878.317 1613.75,878.314 1613.74,878.311 1613.73,878.308 1613.72,878.305 1613.71,878.303 1613.7,878.3 1613.69,878.297 1613.68,878.294 1613.67,878.291 1613.66,878.289 1613.64,878.286 1613.63,878.283 1613.62,878.28 1613.61,878.277 1613.6,878.275 1613.59,878.272 1613.58,878.269 1613.57,878.266 1613.56,878.263 1613.55,878.261 1613.54,878.258 1613.52,878.255 1613.51,878.252 1613.5,878.25 1613.49,878.247 1613.48,878.244 1613.47,878.241 1613.46,878.238 1613.45,878.236 1613.44,878.233 1613.43,878.23 1613.42,878.227 1613.41,878.224 1613.39,878.222 1613.38,878.219 1613.37,878.216 1613.36,878.213 1613.35,878.211 1613.34,878.208 1613.33,878.205 1613.32,878.202 1613.31,878.199 1613.3,878.197 1613.29,878.194 1613.28,878.191 1613.26,878.188 1613.25,878.186 1613.24,878.183 1613.23,878.18 1613.22,878.177 1613.21,878.174 1613.2,878.172 1613.19,878.169 1613.18,878.166 1613.17,878.163 1613.16,878.161 1613.15,878.158 1613.13,878.155 1613.12,878.152 1613.11,878.149 1613.1,878.147 1613.09,878.144 1613.08,878.141 1613.07,878.138 1613.06,878.136 1613.05,878.133 1613.04,878.13 1613.03,878.127 1613.02,878.124 1613,878.122 1612.99,878.119 1612.98,878.116 1612.97,878.113 1612.96,878.111 1612.95,878.108 1612.94,878.105 1612.93,878.102 1612.92,878.1 1612.91,878.097 1612.9,878.094 1612.89,878.091 1612.87,878.088 1612.86,878.086 1612.85,878.083 1612.84,878.08 1612.83,878.077 1612.82,878.075 1612.81,878.072 1612.8,878.069 1612.79,878.066 1612.78,878.064 1612.77,878.061 1612.76,878.058 1612.74,878.055 1612.73,878.052 1612.72,878.05 1612.71,878.047 1612.7,878.044 1612.69,878.041 1612.68,878.039 1612.67,878.036 1612.66,878.033 1612.65,878.03 1612.64,878.028 1612.63,878.025 1612.62,878.022 1612.6,878.019 1612.59,878.017 1612.58,878.014 1612.57,878.011 1612.56,878.008 1612.55,878.006 1612.54,878.003 1612.53,878 1612.52,877.997 1612.51,877.995 1612.5,877.992 1612.49,877.989 1612.47,877.986 1612.46,877.984 1612.45,877.981 1612.44,877.978 1612.43,877.975 1612.42,877.972 1612.41,877.97 1612.4,877.967 1612.39,877.964 1612.38,877.961 1612.37,877.959 1612.36,877.956 1612.35,877.953 1612.33,877.95 1612.32,877.948 1612.31,877.945 1612.3,877.942 1612.29,877.939 1612.28,877.937 1612.27,877.934 1612.26,877.931 1612.25,877.928 1612.24,877.926 1612.23,877.923 1612.22,877.92 1612.21,877.917 1612.19,877.915 1612.18,877.912 1612.17,877.909 1612.16,877.906 1612.15,877.904 1612.14,877.901 1612.13,877.898 1612.12,877.896 1612.11,877.893 1612.1,877.89 1612.09,877.887 1612.08,877.885 1612.07,877.882 1612.05,877.879 1612.04,877.876 1612.03,877.874 1612.02,877.871 1612.01,877.868 1612,877.865 1611.99,877.863 1611.98,877.86 1611.97,877.857 1611.96,877.854 1611.95,877.852 1611.94,877.849 1611.93,877.846 1611.91,877.843 1611.9,877.841 1611.89,877.838 1611.88,877.835 1611.87,877.832 1611.86,877.83 1611.85,877.827 1611.84,877.824 1611.83,877.822 1611.82,877.819 1611.81,877.816 1611.8,877.813 1611.79,877.811 1611.77,877.808 1611.76,877.805 1611.75,877.802 1611.74,877.8 1611.73,877.797 1611.72,877.794 1611.71,877.791 1611.7,877.789 1611.69,877.786 1611.68,877.783 1611.67,877.781 1611.66,877.778 1611.65,877.775 1611.63,877.772 1611.62,877.77 1611.61,877.767 1611.6,877.764 1611.59,877.761 1611.58,877.759 1611.57,877.756 1611.56,877.753 1611.55,877.751 1611.54,877.748 1611.53,877.745 1611.52,877.742 1611.51,877.74 1611.5,877.737 1611.48,877.734 1611.47,877.731 1611.46,877.729 1611.45,877.726 1611.44,877.723 1611.43,877.721 1611.42,877.718 1611.41,877.715 1611.4,877.712 1611.39,877.71 1611.38,877.707 1611.37,877.704 1611.36,877.701 1611.35,877.699 1611.33,877.696 1611.32,877.693 1611.31,877.691 1611.3,877.688 1611.29,877.685 1611.28,877.682 1611.27,877.68 1611.26,877.677 1611.25,877.674 1611.24,877.672 1611.23,877.669 1611.22,877.666 1611.21,877.663 1611.2,877.661 1611.18,877.658 1611.17,877.655 1611.16,877.653 1611.15,877.65 1611.14,877.647 1611.13,877.644 1611.12,877.642 1611.11,877.639 1611.1,877.636 1611.09,877.634 1611.08,877.631 1611.07,877.628 1611.06,877.625 1611.05,877.623 1611.03,877.62 1611.02,877.617 1611.01,877.615 1611,877.612 1610.99,877.609 1610.98,877.606 1610.97,877.604 1610.96,877.601 1610.95,877.598 1610.94,877.596 1610.93,877.593 1610.92,877.59 1610.91,877.587 1610.9,877.585 1610.88,877.582 1610.87,877.579 1610.86,877.577 1610.85,877.574 1610.84,877.571 1610.83,877.569 1610.82,877.566 1610.81,877.563 1610.8,877.56 1610.79,877.558 1610.78,877.555 1610.77,877.552 1610.76,877.55 1610.75,877.547 1610.74,877.544 1610.72,877.542 1610.71,877.539 1610.7,877.536 1610.69,877.533 1610.68,877.531 1610.67,877.528 1610.66,877.525 1610.65,877.523 1610.64,877.52 1610.63,877.517 1610.62,877.514 1610.61,877.512 1610.6,877.509 1610.59,877.506 1610.57,877.504 1610.56,877.501 1610.55,877.498 1610.54,877.496 1610.53,877.493 1610.52,877.49 1610.51,877.488 1610.5,877.485 1610.49,877.482 1610.48,877.479 1610.47,877.477 1610.46,877.474 1610.45,877.471 1610.44,877.469 1610.43,877.466 1610.41,877.463 1610.4,877.461 1610.39,877.458 1610.38,877.455 1610.37,877.453 1610.36,877.45 1610.35,877.447 1610.34,877.444 1610.33,877.442 1610.32,877.439 1610.31,877.436 1610.3,877.434 1610.29,877.431 1610.28,877.428 1610.27,877.426 1610.25,877.423 1610.24,877.42 1610.23,877.418 1610.22,877.415 1610.21,877.412 1610.2,877.41 1610.19,877.407 1610.18,877.404 1610.17,877.401 1610.16,877.399 1610.15,877.396 1610.14,877.393 1610.13,877.391 1610.12,877.388 1610.11,877.385 1610.1,877.383 1610.08,877.38 1610.07,877.377 1610.06,877.375 1610.05,877.372 1610.04,877.369 1610.03,877.367 1610.02,877.364 1610.01,877.361 1610,877.359 1609.99,877.356 1609.98,877.353 1609.97,877.351 1609.96,877.348 1609.95,877.345 1609.94,877.342 1609.92,877.34 1609.91,877.337 1609.9,877.334 1609.89,877.332 1609.88,877.329 1609.87,877.326 1609.86,877.324 1609.85,877.321 1609.84,877.318 1609.83,877.316 1609.82,877.313 1609.81,877.31 1609.8,877.308 1609.79,877.305 1609.78,877.302 1609.77,877.3 1609.75,877.297 1609.74,877.294 1609.73,877.292 1609.72,877.289 1609.71,877.286 1609.7,877.284 1609.69,877.281 1609.68,877.278 1609.67,877.276 1609.66,877.273 1609.65,877.27 1609.64,877.268 1609.63,877.265 1609.62,877.262 1609.61,877.26 1609.6,877.257 1609.58,877.254 1609.57,877.252 1609.56,877.249 1609.55,877.246 1609.54,877.244 1609.53,877.241 1609.52,877.238 1609.51,877.236 1609.5,877.233 1609.49,877.23 1609.48,877.228 1609.47,877.225 1609.46,877.222 1609.45,877.22 1609.44,877.217 1609.43,877.214 1609.42,877.212 1609.4,877.209 1609.39,877.206 1609.38,877.204 1609.37,877.201 1609.36,877.198 1609.35,877.196 1609.34,877.193 1609.33,877.19 1609.32,877.188 1609.31,877.185 1609.3,877.182 1609.29,877.18 1609.28,877.177 1609.27,877.174 1609.26,877.172 1609.25,877.169 1609.23,877.166 1609.22,877.164 1609.21,877.161 1609.2,877.158 1609.19,877.156 1609.18,877.153 1609.17,877.151 1609.16,877.148 1609.15,877.145 1609.14,877.143 1609.13,877.14 1609.12,877.137 1609.11,877.135 1609.1,877.132 1609.09,877.129 1609.08,877.127 1609.07,877.124 1609.05,877.121 1609.04,877.119 1609.03,877.116 1609.02,877.113 1609.01,877.111 1609,877.108 1608.99,877.105 1608.98,877.103 1608.97,877.1 1608.96,877.098 1608.95,877.095 1608.94,877.092 1608.93,877.09 1608.92,877.087 1608.91,877.084 1608.9,877.082 1608.89,877.079 1608.87,877.076 1608.86,877.074 1608.85,877.071 1608.84,877.068 1608.83,877.066 1608.82,877.063 1608.81,877.06 1608.8,877.058 1608.79,877.055 1608.78,877.053 1608.77,877.05 1608.76,877.047 1608.75,877.045 1608.74,877.042 1608.73,877.039 1608.72,877.037 1608.71,877.034 1608.7,877.031 1608.68,877.029 1608.67,877.026 1608.66,877.023 1608.65,877.021 1608.64,877.018 1608.63,877.016 1608.62,877.013 1608.61,877.01 1608.6,877.008 1608.59,877.005 1608.58,877.002 1608.57,877 1608.56,876.997 1608.55,876.994 1608.54,876.992 1608.53,876.989 1608.52,876.987 1608.51,876.984 1608.49,876.981 1608.48,876.979 1608.47,876.976 1608.46,876.973 1608.45,876.971 1608.44,876.968 1608.43,876.966 1608.42,876.963 1608.41,876.96 1608.4,876.958 1608.39,876.955 1608.38,876.952 1608.37,876.95 1608.36,876.947 1608.35,876.944 1608.34,876.942 1608.33,876.939 1608.32,876.937 1608.31,876.934 1608.29,876.931 1608.28,876.929 1608.27,876.926 1608.26,876.923 1608.25,876.921 1608.24,876.918 1608.23,876.916 1608.22,876.913 1608.21,876.91 1608.2,876.908 1608.19,876.905 1608.18,876.902 1608.17,876.9 1608.16,876.897 1608.15,876.895 1608.14,876.892 1608.13,876.889 1608.12,876.887 1608.1,876.884 1608.09,876.881 1608.08,876.879 1608.07,876.876 1608.06,876.874 1608.05,876.871 1608.04,876.868 1608.03,876.866 1608.02,876.863 1608.01,876.861 1608,876.858 1607.99,876.855 1607.98,876.853 1607.97,876.85 1607.96,876.847 1607.95,876.845 1607.94,876.842 1607.93,876.84 1607.92,876.837 1607.91,876.834 1607.89,876.832 1607.88,876.829 1607.87,876.826 1607.86,876.824 1607.85,876.821 1607.84,876.819 1607.83,876.816 1607.82,876.813 1607.81,876.811 1607.8,876.808 1607.79,876.806 1607.78,876.803 1607.77,876.8 1607.76,876.798 1607.75,876.795 1607.74,876.793 1607.73,876.79 1607.72,876.787 1607.71,876.785 1607.69,876.782 1607.68,876.779 1607.67,876.777 1607.66,876.774 1607.65,876.772 1607.64,876.769 1607.63,876.766 1607.62,876.764 1607.61,876.761 1607.6,876.759 1607.59,876.756 1607.58,876.753 1607.57,876.751 1607.56,876.748 1607.55,876.746 1607.54,876.743 1607.53,876.74 1607.52,876.738 1607.51,876.735 1607.5,876.733 1607.49,876.73 1607.47,876.727 1607.46,876.725 1607.45,876.722 1607.44,876.72 1607.43,876.717 1607.42,876.714 1607.41,876.712 1607.4,876.709 1607.39,876.707 1607.38,876.704 1607.37,876.701 1607.36,876.699 1607.35,876.696 1607.34,876.694 1607.33,876.691 1607.32,876.688 1607.31,876.686 1607.3,876.683 1607.29,876.681 1607.28,876.678 1607.26,876.675 1607.25,876.673 1607.24,876.67 1607.23,876.668 1607.22,876.665 1607.21,876.662 1607.2,876.66 1607.19,876.657 1607.18,876.655 1607.17,876.652 1607.16,876.649 1607.15,876.647 1607.14,876.644 1607.13,876.642 1607.12,876.639 1607.11,876.636 1607.1,876.634 1607.09,876.631 1607.08,876.629 1607.07,876.626 1607.06,876.624 1607.05,876.621 1607.03,876.618 1607.02,876.616 1607.01,876.613 1607,876.611 1606.99,876.608 1606.98,876.605 1606.97,876.603 1606.96,876.6 1606.95,876.598 1606.94,876.595 1606.93,876.592 1606.92,876.59 1606.91,876.587 1606.9,876.585 1606.89,876.582 1606.88,876.58 1606.87,876.577 1606.86,876.574 1606.85,876.572 1606.84,876.569 1606.83,876.567 1606.82,876.564 1606.8,876.561 1606.79,876.559 1606.78,876.556 1606.77,876.554 1606.76,876.551 1606.75,876.549 1606.74,876.546 1606.73,876.543 1606.72,876.541 1606.71,876.538 1606.7,876.536 1606.69,876.533 1606.68,876.53 1606.67,876.528 1606.66,876.525 1606.65,876.523 1606.64,876.52 1606.63,876.518 1606.62,876.515 1606.61,876.512 1606.6,876.51 1606.59,876.507 1606.58,876.505 1606.56,876.502 1606.55,876.5 1606.54,876.497 1606.53,876.494 1606.52,876.492 1606.51,876.489 1606.5,876.487 1606.49,876.484 1606.48,876.482 1606.47,876.479 1606.46,876.476 1606.45,876.474 1606.44,876.471 1606.43,876.469 1606.42,876.466 1606.41,876.464 1606.4,876.461 1606.39,876.458 1606.38,876.456 1606.37,876.453 1606.36,876.451 1606.35,876.448 1606.34,876.446 1606.32,876.443 1606.31,876.44 1606.3,876.438 1606.29,876.435 1606.28,876.433 1606.27,876.43 1606.26,876.428 1606.25,876.425 1606.24,876.422 1606.23,876.42 1606.22,876.417 1606.21,876.415 1606.2,876.412 1606.19,876.41 1606.18,876.407 1606.17,876.405 1606.16,876.402 1606.15,876.399 1606.14,876.397 1606.13,876.394 1606.12,876.392 1606.11,876.389 1606.1,876.387 1606.09,876.384 1606.07,876.381 1606.06,876.379 1606.05,876.376 1606.04,876.374 1606.03,876.371 1606.02,876.369 1606.01,876.366 1606,876.364 1605.99,876.361 1605.98,876.358 1605.97,876.356 1605.96,876.353 1605.95,876.351 1605.94,876.348 1605.93,876.346 1605.92,876.343 1605.91,876.341 1605.9,876.338 1605.89,876.335 1605.88,876.333 1605.87,876.33 1605.86,876.328 1605.85,876.325 1605.84,876.323 1605.83,876.32 1605.82,876.318 1605.8,876.315 1605.79,876.312 1605.78,876.31 1605.77,876.307 1605.76,876.305 1605.75,876.302 1605.74,876.3 1605.73,876.297 1605.72,876.295 1605.71,876.292 1605.7,876.29 1605.69,876.287 1605.68,876.284 1605.67,876.282 1605.66,876.279 1605.65,876.277 1605.64,876.274 1605.63,876.272 1605.62,876.269 1605.61,876.267 1605.6,876.264 1605.59,876.262 1605.58,876.259 1605.57,876.256 1605.56,876.254 1605.55,876.251 1605.53,876.249 1605.52,876.246 1605.51,876.244 1605.5,876.241 1605.49,876.239 1605.48,876.236 1605.47,876.234 1605.46,876.231 1605.45,876.228 1605.44,876.226 1605.43,876.223 1605.42,876.221 1605.41,876.218 1605.4,876.216 1605.39,876.213 1605.38,876.211 1605.37,876.208 1605.36,876.206 1605.35,876.203 1605.34,876.201 1605.33,876.198 1605.32,876.195 1605.31,876.193 1605.3,876.19 1605.29,876.188 1605.28,876.185 1605.27,876.183 1605.26,876.18 1605.24,876.178 1605.23,876.175 1605.22,876.173 1605.21,876.17 1605.2,876.168 1605.19,876.165 1605.18,876.162 1605.17,876.16 1605.16,876.157 1605.15,876.155 1605.14,876.152 1605.13,876.15 1605.12,876.147 1605.11,876.145 1605.1,876.142 1605.09,876.14 1605.08,876.137 1605.07,876.135 1605.06,876.132 1605.05,876.13 1605.04,876.127 1605.03,876.125 1605.02,876.122 1605.01,876.119 1605,876.117 1604.99,876.114 1604.98,876.112 1604.97,876.109 1604.96,876.107 1604.94,876.104 1604.93,876.102 1604.92,876.099 1604.91,876.097 1604.9,876.094 1604.89,876.092 1604.88,876.089 1604.87,876.087 1604.86,876.084 1604.85,876.082 1604.84,876.079 1604.83,876.077 1604.82,876.074 1604.81,876.071 1604.8,876.069 1604.79,876.066 1604.78,876.064 1604.77,876.061 1604.76,876.059 1604.75,876.056 1604.74,876.054 1604.73,876.051 1604.72,876.049 1604.71,876.046 1604.7,876.044 1604.69,876.041 1604.68,876.039 1604.67,876.036 1604.66,876.034 1604.65,876.031 1604.64,876.029 1604.62,876.026 1604.61,876.024 1604.6,876.021 1604.59,876.019 1604.58,876.016 1604.57,876.014 1604.56,876.011 1604.55,876.009 1604.54,876.006 1604.53,876.004 1604.52,876.001 1604.51,875.998 1604.5,875.996 1604.49,875.993 1604.48,875.991 1604.47,875.988 1604.46,875.986 1604.45,875.983 1604.44,875.981 1604.43,875.978 1604.42,875.976 1604.41,875.973 1604.4,875.971 1604.39,875.968 1604.38,875.966 1604.37,875.963 1604.36,875.961 1604.35,875.958 1604.34,875.956 1604.33,875.953 1604.32,875.951 1604.31,875.948 1604.29,875.946 1604.28,875.943 1604.27,875.941 1604.26,875.938 1604.25,875.936 1604.24,875.933 1604.23,875.931 1604.22,875.928 1604.21,875.926 1604.2,875.923 1604.19,875.921 1604.18,875.918 1604.17,875.916 1604.16,875.913 1604.15,875.911 1604.14,875.908 1604.13,875.906 1604.12,875.903 1604.11,875.901 1604.1,875.898 1604.09,875.896 1604.08,875.893 1604.07,875.891 1604.06,875.888 1604.05,875.886 1604.04,875.883 1604.03,875.881 1604.02,875.878 1604.01,875.876 1604,875.873 1603.99,875.871 1603.98,875.868 1603.97,875.866 1603.96,875.863 1603.95,875.861 1603.93,875.858 1603.92,875.856 1603.91,875.853 1603.9,875.851 1603.89,875.848 1603.88,875.846 1603.87,875.843 1603.86,875.841 1603.85,875.838 1603.84,875.836 1603.83,875.833 1603.82,875.831 1603.81,875.828 1603.8,875.826 1603.79,875.823 1603.78,875.821 1603.77,875.818 1603.76,875.816 1603.75,875.813 1603.74,875.811 1603.73,875.808 1603.72,875.806 1603.71,875.803 1603.7,875.801 1603.69,875.798 1603.68,875.796 1603.67,875.793 1603.66,875.791 1603.65,875.788 1603.64,875.786 1603.63,875.784 1603.62,875.781 1603.61,875.779 1603.6,875.776 1603.59,875.774 1603.58,875.771 1603.57,875.769 1603.56,875.766 1603.55,875.764 1603.53,875.761 1603.52,875.759 1603.51,875.756 1603.5,875.754 1603.49,875.751 1603.48,875.749 1603.47,875.746 1603.46,875.744 1603.45,875.741 1603.44,875.739 1603.43,875.736 1603.42,875.734 1603.41,875.731 1603.4,875.729 1603.39,875.726 1603.38,875.724 1603.37,875.721 1603.36,875.719 1603.35,875.716 1603.34,875.714 1603.33,875.712 1603.32,875.709 1603.31,875.707 1603.3,875.704 1603.29,875.702 1603.28,875.699 1603.27,875.697 1603.26,875.694 1603.25,875.692 1603.24,875.689 1603.23,875.687 1603.22,875.684 1603.21,875.682 1603.2,875.679 1603.19,875.677 1603.18,875.674 1603.17,875.672 1603.16,875.669 1603.15,875.667 1603.14,875.665 1603.13,875.662 1603.12,875.66 1603.1,875.657 1603.09,875.655 1603.08,875.652 1603.07,875.65 1603.06,875.647 1603.05,875.645 1603.04,875.642 1603.03,875.64 1603.02,875.637 1603.01,875.635 1603,875.632 1602.99,875.63 1602.98,875.627 1602.97,875.625 1602.96,875.623 1602.95,875.62 1602.94,875.618 1602.93,875.615 1602.92,875.613 1602.91,875.61 1602.9,875.608 1602.89,875.605 1602.88,875.603 1602.87,875.6 1602.86,875.598 1602.85,875.595 1602.84,875.593 1602.83,875.591 1602.82,875.588 1602.81,875.586 1602.8,875.583 1602.79,875.581 1602.78,875.578 1602.77,875.576 1602.76,875.573 1602.75,875.571 1602.74,875.568 1602.73,875.566 1602.72,875.563 1602.71,875.561 1602.7,875.559 1602.69,875.556 1602.68,875.554 1602.67,875.551 1602.66,875.549 1602.65,875.546 1602.64,875.544 1602.62,875.541 1602.61,875.539 1602.6,875.536 1602.59,875.534 1602.58,875.532 1602.57,875.529 1602.56,875.527 1602.55,875.524 1602.54,875.522 1602.53,875.519 1602.52,875.517 1602.51,875.514 1602.5,875.512 1602.49,875.509 1602.48,875.507 1602.47,875.505 1602.46,875.502 1602.45,875.5 1602.44,875.497 1602.43,875.495 1602.42,875.492 1602.41,875.49 1602.4,875.487 1602.39,875.485 1602.38,875.482 1602.37,875.48 1602.36,875.478 1602.35,875.475 1602.34,875.473 1602.33,875.47 1602.32,875.468 1602.31,875.465 1602.3,875.463 1602.29,875.46 1602.28,875.458 1602.27,875.456 1602.26,875.453 1602.25,875.451 1602.24,875.448 1602.23,875.446 1602.22,875.443 1602.21,875.441 1602.2,875.438 1602.19,875.436 1602.18,875.434 1602.17,875.431 1602.16,875.429 1602.15,875.426 1602.14,875.424 1602.13,875.421 1602.12,875.419 1602.11,875.416 1602.1,875.414 1602.09,875.412 1602.08,875.409 1602.07,875.407 1602.05,875.404 1602.04,875.402 1602.03,875.399 1602.02,875.397 1602.01,875.395 1602,875.392 1601.99,875.39 1601.98,875.387 1601.97,875.385 1601.96,875.382 1601.95,875.38 1601.94,875.377 1601.93,875.375 1601.92,875.373 1601.91,875.37 1601.9,875.368 1601.89,875.365 1601.88,875.363 1601.87,875.36 1601.86,875.358 1601.85,875.356 1601.84,875.353 1601.83,875.351 1601.82,875.348 1601.81,875.346 1601.8,875.343 1601.79,875.341 1601.78,875.339 1601.77,875.336 1601.76,875.334 1601.75,875.331 1601.74,875.329 1601.73,875.326 1601.72,875.324 1601.71,875.322 1601.7,875.319 1601.69,875.317 1601.68,875.314 1601.67,875.312 1601.66,875.309 1601.65,875.307 1601.64,875.305 1601.63,875.302 1601.62,875.3 1601.61,875.297 1601.6,875.295 1601.59,875.292 1601.58,875.29 1601.57,875.288 1601.56,875.285 1601.55,875.283 1601.54,875.28 1601.53,875.278 1601.52,875.275 1601.51,875.273 1601.5,875.271 1601.49,875.268 1601.48,875.266 1601.47,875.263 1601.46,875.261 1601.45,875.258 1601.44,875.256 1601.43,875.254 1601.42,875.251 1601.41,875.249 1601.4,875.246 1601.39,875.244 1601.38,875.242 1601.37,875.239 1601.36,875.237 1601.35,875.234 1601.34,875.232 1601.32,875.229 1601.31,875.227 1601.3,875.225 1601.29,875.222 1601.28,875.22 1601.27,875.217 1601.26,875.215 1601.25,875.213 1601.24,875.21 1601.23,875.208 1601.22,875.205 1601.21,875.203 1601.2,875.2 1601.19,875.198 1601.18,875.196 1601.17,875.193 1601.16,875.191 1601.15,875.188 1601.14,875.186 1601.13,875.184 1601.12,875.181 1601.11,875.179 1601.1,875.176 1601.09,875.174 1601.08,875.172 1601.07,875.169 1601.06,875.167 1601.05,875.164 1601.04,875.162 1601.03,875.159 1601.02,875.157 1601.01,875.155 1601,875.152 1600.99,875.15 1600.98,875.147 1600.97,875.145 1600.96,875.143 1600.95,875.14 1600.94,875.138 1600.93,875.135 1600.92,875.133 1600.91,875.131 1600.9,875.128 1600.89,875.126 1600.88,875.123 1600.87,875.121 1600.86,875.119 1600.85,875.116 1600.84,875.114 1600.83,875.111 1600.82,875.109 1600.81,875.107 1600.8,875.104 1600.79,875.102 1600.78,875.099 1600.77,875.097 1600.76,875.095 1600.75,875.092 1600.74,875.09 1600.73,875.087 1600.72,875.085 1600.71,875.083 1600.7,875.08 1600.69,875.078 1600.68,875.075 1600.67,875.073 1600.66,875.071 1600.65,875.068 1600.64,875.066 1600.63,875.063 1600.62,875.061 1600.61,875.059 1600.6,875.056 1600.59,875.054 1600.58,875.051 1600.57,875.049 1600.56,875.047 1600.55,875.044 1600.54,875.042 1600.53,875.039 1600.52,875.037 1600.51,875.035 1600.5,875.032 1600.49,875.03 1600.48,875.027 1600.47,875.025 1600.46,875.023 1600.45,875.02 1600.44,875.018 1600.43,875.015 1600.42,875.013 1600.41,875.011 1600.4,875.008 1600.39,875.006 1600.38,875.004 1600.37,875.001 1600.36,874.999 1600.35,874.996 1600.34,874.994 1600.33,874.992 1600.32,874.989 1600.31,874.987 1600.3,874.984 1600.29,874.982 1600.28,874.98 1600.27,874.977 1600.26,874.975 1600.25,874.973 1600.24,874.97 1600.23,874.968 1600.22,874.965 1600.21,874.963 1600.2,874.961 1600.19,874.958 1600.18,874.956 1600.17,874.953 1600.16,874.951 1600.15,874.949 1600.14,874.946 1600.13,874.944 1600.12,874.942 1600.1,874.939 1600.09,874.937 1600.08,874.934 1600.07,874.932 1600.06,874.93 1600.05,874.927 1600.04,874.925 1600.03,874.922 1600.02,874.92 1600.01,874.918 1600,874.915 1599.99,874.913 1599.98,874.911 1599.97,874.908 1599.96,874.906 1599.95,874.903 1599.94,874.901 1599.93,874.899 1599.92,874.896 1599.91,874.894 1599.9,874.892 1599.89,874.889 1599.88,874.887 1599.87,874.884 1599.86,874.882 1599.85,874.88 1599.84,874.877 1599.83,874.875 1599.82,874.873 1599.81,874.87 1599.8,874.868 1599.79,874.865 1599.78,874.863 1599.77,874.861 1599.76,874.858 1599.75,874.856 1599.74,874.854 1599.73,874.851 1599.72,874.849 1599.71,874.847 1599.7,874.844 1599.69,874.842 1599.68,874.839 1599.67,874.837 1599.66,874.835 1599.65,874.832 1599.64,874.83 1599.63,874.828 1599.62,874.825 1599.61,874.823 1599.6,874.82 1599.59,874.818 1599.58,874.816 1599.57,874.813 1599.56,874.811 1599.55,874.809 1599.54,874.806 1599.53,874.804 1599.52,874.802 1599.51,874.799 1599.5,874.797 1599.49,874.794 1599.48,874.792 1599.47,874.79 1599.46,874.787 1599.45,874.785 1599.44,874.783 1599.43,874.78 1599.42,874.778 1599.41,874.776 1599.4,874.773 1599.39,874.771 1599.38,874.768 1599.37,874.766 1599.36,874.764 1599.35,874.761 1599.34,874.759 1599.33,874.757 1599.32,874.754 1599.31,874.752 1599.3,874.75 1599.29,874.747 1599.28,874.745 1599.27,874.743 1599.26,874.74 1599.25,874.738 1599.24,874.735 1599.23,874.733 1599.22,874.731 1599.21,874.728 1599.2,874.726 1599.19,874.724 1599.18,874.721 1599.17,874.719 1599.16,874.717 1599.15,874.714 1599.14,874.712 1599.13,874.71 1599.12,874.707 1599.11,874.705 1599.1,874.703 1599.09,874.7 1599.08,874.698 1599.07,874.695 1599.06,874.693 1599.05,874.691 1599.04,874.688 1599.03,874.686 1599.02,874.684 1599.01,874.681 1599,874.679 1598.99,874.677 1598.98,874.674 1598.97,874.672 1598.96,874.67 1598.95,874.667 1598.94,874.665 1598.93,874.663 1598.92,874.66 1598.91,874.658 1598.9,874.656 1598.89,874.653 1598.88,874.651 1598.87,874.649 1598.86,874.646 1598.85,874.644 1598.84,874.641 1598.83,874.639 1598.82,874.637 1598.81,874.634 1598.8,874.632 1598.79,874.63 1598.78,874.627 1598.77,874.625 1598.76,874.623 1598.75,874.62 1598.74,874.618 1598.73,874.616 1598.72,874.613 1598.71,874.611 1598.7,874.609 1598.69,874.606 1598.68,874.604 1598.67,874.602 1598.66,874.599 1598.65,874.597 1598.64,874.595 1598.63,874.592 1598.62,874.59 1598.61,874.588 1598.6,874.585 1598.59,874.583 1598.58,874.581 1598.57,874.578 1598.56,874.576 1598.56,874.574 1598.55,874.571 1598.54,874.569 1598.53,874.567 1598.52,874.564 1598.51,874.562 1598.5,874.56 1598.49,874.557 1598.48,874.555 1598.47,874.553 1598.46,874.55 1598.45,874.548 1598.44,874.546 1598.43,874.543 1598.42,874.541 1598.41,874.539 1598.4,874.536 1598.39,874.534 1598.38,874.532 1598.37,874.529 1598.36,874.527 1598.35,874.525 1598.34,874.522 1598.33,874.52 1598.32,874.518 1598.31,874.515 1598.3,874.513 1598.29,874.511 1598.28,874.508 1598.27,874.506 1598.26,874.504 1598.25,874.501 1598.24,874.499 1598.23,874.497 1598.22,874.494 1598.21,874.492 1598.2,874.49 1598.19,874.487 1598.18,874.485 1598.17,874.483 1598.16,874.48 1598.15,874.478 1598.14,874.476 1598.13,874.474 1598.12,874.471 1598.11,874.469 1598.1,874.467 1598.09,874.464 1598.08,874.462 1598.07,874.46 1598.06,874.457 1598.05,874.455 1598.04,874.453 1598.03,874.45 1598.02,874.448 1598.01,874.446 1598,874.443 1597.99,874.441 1597.98,874.439 1597.97,874.436 1597.96,874.434 1597.95,874.432 1597.94,874.429 1597.93,874.427 1597.92,874.425 1597.91,874.423 1597.9,874.42 1597.89,874.418 1597.88,874.416 1597.87,874.413 1597.86,874.411 1597.85,874.409 1597.84,874.406 1597.83,874.404 1597.82,874.402 1597.81,874.399 1597.8,874.397 1597.79,874.395 1597.78,874.392 1597.77,874.39 1597.76,874.388 1597.75,874.385 1597.74,874.383 1597.73,874.381 1597.72,874.379 1597.71,874.376 1597.7,874.374 1597.69,874.372 1597.68,874.369 1597.67,874.367 1597.66,874.365 1597.65,874.362 1597.64,874.36 1597.63,874.358 1597.62,874.355 1597.61,874.353 1597.6,874.351 1597.59,874.349 1597.58,874.346 1597.57,874.344 1597.56,874.342 1597.55,874.339 1597.54,874.337 1597.53,874.335 1597.52,874.332 1597.51,874.33 1597.5,874.328 1597.49,874.325 1597.48,874.323 1597.47,874.321 1597.46,874.319 1597.45,874.316 1597.44,874.314 1597.43,874.312 1597.42,874.309 1597.41,874.307 1597.4,874.305 1597.39,874.302 1597.38,874.3 1597.37,874.298 1597.36,874.296 1597.35,874.293 1597.34,874.291 1597.34,874.289 1597.33,874.286 1597.32,874.284 1597.31,874.282 1597.3,874.279 1597.29,874.277 1597.28,874.275 1597.27,874.273 1597.26,874.27 1597.25,874.268 1597.24,874.266 1597.23,874.263 1597.22,874.261 1597.21,874.259 1597.2,874.257 1597.19,874.254 1597.18,874.252 1597.17,874.25 1597.16,874.247 1597.15,874.245 1597.14,874.243 1597.13,874.24 1597.12,874.238 1597.11,874.236 1597.1,874.234 1597.09,874.231 1597.08,874.229 1597.07,874.227 1597.06,874.224 1597.05,874.222 1597.04,874.22 1597.03,874.218 1597.02,874.215 1597.01,874.213 1597,874.211 1596.99,874.208 1596.98,874.206 1596.97,874.204 1596.96,874.202 1596.95,874.199 1596.94,874.197 1596.93,874.195 1596.92,874.192 1596.91,874.19 1596.9,874.188 1596.89,874.186 1596.88,874.183 1596.87,874.181 1596.86,874.179 1596.85,874.176 1596.84,874.174 1596.83,874.172 1596.82,874.17 1596.81,874.167 1596.8,874.165 1596.79,874.163 1596.78,874.16 1596.77,874.158 1596.76,874.156 1596.75,874.154 1596.74,874.151 1596.73,874.149 1596.72,874.147 1596.71,874.144 1596.7,874.142 1596.69,874.14 1596.68,874.138 1596.67,874.135 1596.66,874.133 1596.65,874.131 1596.64,874.128 1596.63,874.126 1596.63,874.124 1596.62,874.122 1596.61,874.119 1596.6,874.117 1596.59,874.115 1596.58,874.113 1596.57,874.11 1596.56,874.108 1596.55,874.106 1596.54,874.103 1596.53,874.101 1596.52,874.099 1596.51,874.097 1596.5,874.094 1596.49,874.092 1596.48,874.09 1596.47,874.088 1596.46,874.085 1596.45,874.083 1596.44,874.081 1596.43,874.078 1596.42,874.076 1596.41,874.074 1596.4,874.072 1596.39,874.069 1596.38,874.067 1596.37,874.065 1596.36,874.063 1596.35,874.06 1596.34,874.058 1596.33,874.056 1596.32,874.053 1596.31,874.051 1596.3,874.049 1596.29,874.047 1596.28,874.044 1596.27,874.042 1596.26,874.04 1596.25,874.038 1596.24,874.035 1596.23,874.033 1596.22,874.031 1596.21,874.028 1596.2,874.026 1596.19,874.024 1596.18,874.022 1596.17,874.019 1596.16,874.017 1596.15,874.015 1596.14,874.013 1596.13,874.01 1596.12,874.008 1596.11,874.006 1596.1,874.004 1596.09,874.001 1596.08,873.999 1596.07,873.997 1596.07,873.995 1596.06,873.992 1596.05,873.99 1596.04,873.988 1596.03,873.985 1596.02,873.983 1596.01,873.981 1596,873.979 1595.99,873.976 1595.98,873.974 1595.97,873.972 1595.96,873.97 1595.95,873.967 1595.94,873.965 1595.93,873.963 1595.92,873.961 1595.91,873.958 1595.9,873.956 1595.89,873.954 1595.88,873.952 1595.87,873.949 1595.86,873.947 1595.85,873.945 1595.84,873.943 1595.83,873.94 1595.82,873.938 1595.81,873.936 1595.8,873.934 1595.79,873.931 1595.78,873.929 1595.77,873.927 1595.76,873.925 1595.75,873.922 1595.74,873.92 1595.73,873.918 1595.72,873.916 1595.71,873.913 1595.7,873.911 1595.69,873.909 1595.68,873.907 1595.67,873.904 1595.66,873.902 1595.65,873.9 1595.64,873.898 1595.63,873.895 1595.62,873.893 1595.61,873.891 1595.6,873.889 1595.59,873.886 1595.59,873.884 1595.58,873.882 1595.57,873.88 1595.56,873.877 1595.55,873.875 1595.54,873.873 1595.53,873.871 1595.52,873.868 1595.51,873.866 1595.5,873.864 1595.49,873.862 1595.48,873.859 1595.47,873.857 1595.46,873.855 1595.45,873.853 1595.44,873.85 1595.43,873.848 1595.42,873.846 1595.41,873.844 1595.4,873.841 1595.39,873.839 1595.38,873.837 1595.37,873.835 1595.36,873.832 1595.35,873.83 1595.34,873.828 1595.33,873.826 1595.32,873.824 1595.31,873.821 1595.3,873.819 1595.29,873.817 1595.28,873.815 1595.27,873.812 1595.26,873.81 1595.25,873.808 1595.24,873.806 1595.23,873.803 1595.22,873.801 1595.21,873.799 1595.2,873.797 1595.19,873.794 1595.18,873.792 1595.17,873.79 1595.17,873.788 1595.16,873.785 1595.15,873.783 1595.14,873.781 1595.13,873.779 1595.12,873.777 1595.11,873.774 1595.1,873.772 1595.09,873.77 1595.08,873.768 1595.07,873.765 1595.06,873.763 1595.05,873.761 1595.04,873.759 1595.03,873.756 1595.02,873.754 1595.01,873.752 1595,873.75 1594.99,873.748 1594.98,873.745 1594.97,873.743 1594.96,873.741 1594.95,873.739 1594.94,873.736 1594.93,873.734 1594.92,873.732 1594.91,873.73 1594.9,873.727 1594.89,873.725 1594.88,873.723 1594.87,873.721 1594.86,873.719 1594.85,873.716 1594.84,873.714 1594.83,873.712 1594.82,873.71 1594.81,873.707 1594.8,873.705 1594.79,873.703 1594.79,873.701 1594.78,873.699 1594.77,873.696 1594.76,873.694 1594.75,873.692 1594.74,873.69 1594.73,873.687 1594.72,873.685 1594.71,873.683 1594.7,873.681 1594.69,873.679 1594.68,873.676 1594.67,873.674 1594.66,873.672 1594.65,873.67 1594.64,873.667 1594.63,873.665 1594.62,873.663 1594.61,873.661 1594.6,873.659 1594.59,873.656 1594.58,873.654 1594.57,873.652 1594.56,873.65 1594.55,873.647 1594.54,873.645 1594.53,873.643 1594.52,873.641 1594.51,873.639 1594.5,873.636 1594.49,873.634 1594.48,873.632 1594.47,873.63 1594.46,873.628 1594.45,873.625 1594.44,873.623 1594.43,873.621 1594.43,873.619 1594.42,873.616 1594.41,873.614 1594.4,873.612 1594.39,873.61 1594.38,873.608 1594.37,873.605 1594.36,873.603 1594.35,873.601 1594.34,873.599 1594.33,873.597 1594.32,873.594 1594.31,873.592 1594.3,873.59 1594.29,873.588 1594.28,873.586 1594.27,873.583 1594.26,873.581 1594.25,873.579 1594.24,873.577 1594.23,873.574 1594.22,873.572 1594.21,873.57 1594.2,873.568 1594.19,873.566 1594.18,873.563 1594.17,873.561 1594.16,873.559 1594.15,873.557 1594.14,873.555 1594.13,873.552 1594.12,873.55 1594.11,873.548 1594.11,873.546 1594.1,873.544 1594.09,873.541 1594.08,873.539 1594.07,873.537 1594.06,873.535 1594.05,873.533 1594.04,873.53 1594.03,873.528 1594.02,873.526 1594.01,873.524 1594,873.522 1593.99,873.519 1593.98,873.517 1593.97,873.515 1593.96,873.513 1593.95,873.511 1593.94,873.508 1593.93,873.506 1593.92,873.504 1593.91,873.502 1593.9,873.5 1593.89,873.497 1593.88,873.495 1593.87,873.493 1593.86,873.491 1593.85,873.489 1593.84,873.486 1593.83,873.484 1593.82,873.482 1593.81,873.48 1593.8,873.478 1593.8,873.475 1593.79,873.473 1593.78,873.471 1593.77,873.469 1593.76,873.467 1593.75,873.464 1593.74,873.462 1593.73,873.46 1593.72,873.458 1593.71,873.456 1593.7,873.453 1593.69,873.451 1593.68,873.449 1593.67,873.447 1593.66,873.445 1593.65,873.443 1593.64,873.44 1593.63,873.438 1593.62,873.436 1593.61,873.434 1593.6,873.432 1593.59,873.429 1593.58,873.427 1593.57,873.425 1593.56,873.423 1593.55,873.421 1593.54,873.418 1593.53,873.416 1593.52,873.414 1593.51,873.412 1593.51,873.41 1593.5,873.407 1593.49,873.405 1593.48,873.403 1593.47,873.401 1593.46,873.399 1593.45,873.397 1593.44,873.394 1593.43,873.392 1593.42,873.39 1593.41,873.388 1593.4,873.386 1593.39,873.383 1593.38,873.381 1593.37,873.379 1593.36,873.377 1593.35,873.375 1593.34,873.373 1593.33,873.37 1593.32,873.368 1593.31,873.366 1593.3,873.364 1593.29,873.362 1593.28,873.359 1593.27,873.357 1593.26,873.355 1593.25,873.353 1593.24,873.351 1593.23,873.349 1593.23,873.346 1593.22,873.344 1593.21,873.342 1593.2,873.34 1593.19,873.338 1593.18,873.336 1593.17,873.333 1593.16,873.331 1593.15,873.329 1593.14,873.327 1593.13,873.325 1593.12,873.322 1593.11,873.32 1593.1,873.318 1593.09,873.316 1593.08,873.314 1593.07,873.312 1593.06,873.309 1593.05,873.307 1593.04,873.305 1593.03,873.303 1593.02,873.301 1593.01,873.299 1593,873.296 1592.99,873.294 1592.98,873.292 1592.97,873.29 1592.97,873.288 1592.96,873.286 1592.95,873.283 1592.94,873.281 1592.93,873.279 1592.92,873.277 1592.91,873.275 1592.9,873.273 1592.89,873.27 1592.88,873.268 1592.87,873.266 1592.86,873.264 1592.85,873.262 1592.84,873.259 1592.83,873.257 1592.82,873.255 1592.81,873.253 1592.8,873.251 1592.79,873.249 1592.78,873.246 1592.77,873.244 1592.76,873.242 1592.75,873.24 1592.74,873.238 1592.73,873.236 1592.72,873.234 1592.71,873.231 1592.71,873.229 1592.7,873.227 1592.69,873.225 1592.68,873.223 1592.67,873.221 1592.66,873.218 1592.65,873.216 1592.64,873.214 1592.63,873.212 1592.62,873.21 1592.61,873.208 1592.6,873.205 1592.59,873.203 1592.58,873.201 1592.57,873.199 1592.56,873.197 1592.55,873.195 1592.54,873.192 1592.53,873.19 1592.52,873.188 1592.51,873.186 1592.5,873.184 1592.49,873.182 1592.48,873.18 1592.47,873.177 1592.47,873.175 1592.46,873.173 1592.45,873.171 1592.44,873.169 1592.43,873.167 1592.42,873.164 1592.41,873.162 1592.4,873.16 1592.39,873.158 1592.38,873.156 1592.37,873.154 1592.36,873.151 1592.35,873.149 1592.34,873.147 1592.33,873.145 1592.32,873.143 1592.31,873.141 1592.3,873.139 1592.29,873.136 1592.28,873.134 1592.27,873.132 1592.26,873.13 1592.25,873.128 1592.24,873.126 1592.23,873.124 1592.23,873.121 1592.22,873.119 1592.21,873.117 1592.2,873.115 1592.19,873.113 1592.18,873.111 1592.17,873.108 1592.16,873.106 1592.15,873.104 1592.14,873.102 1592.13,873.1 1592.12,873.098 1592.11,873.096 1592.1,873.093 1592.09,873.091 1592.08,873.089 1592.07,873.087 1592.06,873.085 1592.05,873.083 1592.04,873.081 1592.03,873.078 1592.02,873.076 1592.01,873.074 1592.01,873.072 1592,873.07 1591.99,873.068 1591.98,873.066 1591.97,873.063 1591.96,873.061 1591.95,873.059 1591.94,873.057 1591.93,873.055 1591.92,873.053 1591.91,873.051 1591.9,873.048 1591.89,873.046 1591.88,873.044 1591.87,873.042 1591.86,873.04 1591.85,873.038 1591.84,873.036 1591.83,873.034 1591.82,873.031 1591.81,873.029 1591.8,873.027 1591.79,873.025 1591.79,873.023 1591.78,873.021 1591.77,873.019 1591.76,873.016 1591.75,873.014 1591.74,873.012 1591.73,873.01 1591.72,873.008 1591.71,873.006 1591.7,873.004 1591.69,873.001 1591.68,872.999 1591.67,872.997 1591.66,872.995 1591.65,872.993 1591.64,872.991 1591.63,872.989 1591.62,872.987 1591.61,872.984 1591.6,872.982 1591.59,872.98 1591.58,872.978 1591.57,872.976 1591.57,872.974 1591.56,872.972 1591.55,872.97 1591.54,872.967 1591.53,872.965 1591.52,872.963 1591.51,872.961 1591.5,872.959 1591.49,872.957 1591.48,872.955 1591.47,872.952 1591.46,872.95 1591.45,872.948 1591.44,872.946 1591.43,872.944 1591.42,872.942 1591.41,872.94 1591.4,872.938 1591.39,872.935 1591.38,872.933 1591.37,872.931 1591.36,872.929 1591.36,872.927 1591.35,872.925 1591.34,872.923 1591.33,872.921 1591.32,872.918 1591.31,872.916 1591.3,872.914 1591.29,872.912 1591.28,872.91 1591.27,872.908 1591.26,872.906 1591.25,872.904 1591.24,872.902 1591.23,872.899 1591.22,872.897 1591.21,872.895 1591.2,872.893 1591.19,872.891 1591.18,872.889 1591.17,872.887 1591.16,872.885 1591.16,872.882 1591.15,872.88 1591.14,872.878 1591.13,872.876 1591.12,872.874 1591.11,872.872 1591.1,872.87 1591.09,872.868 1591.08,872.865 1591.07,872.863 1591.06,872.861 1591.05,872.859 1591.04,872.857 1591.03,872.855 1591.02,872.853 1591.01,872.851 1591,872.849 1590.99,872.846 1590.98,872.844 1590.97,872.842 1590.96,872.84 1590.96,872.838 1590.95,872.836 1590.94,872.834 1590.93,872.832 1590.92,872.83 1590.91,872.827 1590.9,872.825 1590.89,872.823 1590.88,872.821 1590.87,872.819 1590.86,872.817 1590.85,872.815 1590.84,872.813 1590.83,872.811 1590.82,872.808 1590.81,872.806 1590.8,872.804 1590.79,872.802 1590.78,872.8 1590.77,872.798 1590.77,872.796 1590.76,872.794 1590.75,872.792 1590.74,872.79 1590.73,872.787 1590.72,872.785 1590.71,872.783 1590.7,872.781 1590.69,872.779 1590.68,872.777 1590.67,872.775 1590.66,872.773 1590.65,872.771 1590.64,872.768 1590.63,872.766 1590.62,872.764 1590.61,872.762 1590.6,872.76 1590.59,872.758 1590.58,872.756 1590.58,872.754 1590.57,872.752 1590.56,872.75 1590.55,872.747 1590.54,872.745 1590.53,872.743 1590.52,872.741 1590.51,872.739 1590.5,872.737 1590.49,872.735 1590.48,872.733 1590.47,872.731 1590.46,872.729 1590.45,872.726 1590.44,872.724 1590.43,872.722 1590.42,872.72 1590.41,872.718 1590.4,872.716 1590.4,872.714 1590.39,872.712 1590.38,872.71 1590.37,872.708 1590.36,872.706 1590.35,872.703 1590.34,872.701 1590.33,872.699 1590.32,872.697 1590.31,872.695 1590.3,872.693 1590.29,872.691 1590.28,872.689 1590.27,872.687 1590.26,872.685 1590.25,872.682 1590.24,872.68 1590.23,872.678 1590.22,872.676 1590.22,872.674 1590.21,872.672 1590.2,872.67 1590.19,872.668 1590.18,872.666 1590.17,872.664 1590.16,872.662 1590.15,872.659 1590.14,872.657 1590.13,872.655 1590.12,872.653 1590.11,872.651 1590.1,872.649 1590.09,872.647 1590.08,872.645 1590.07,872.643 1590.06,872.641 1590.05,872.639 1590.04,872.637 1590.04,872.634 1590.03,872.632 1590.02,872.63 1590.01,872.628 1590,872.626 1589.99,872.624 1589.98,872.622 1589.97,872.62 1589.96,872.618 1589.95,872.616 1589.94,872.614 1589.93,872.612 1589.92,872.609 1589.91,872.607 1589.9,872.605 1589.89,872.603 1589.88,872.601 1589.87,872.599 1589.87,872.597 1589.86,872.595 1589.85,872.593 1589.84,872.591 1589.83,872.589 1589.82,872.587 1589.81,872.584 1589.8,872.582 1589.79,872.58 1589.78,872.578 1589.77,872.576 1589.76,872.574 1589.75,872.572 1589.74,872.57 1589.73,872.568 1589.72,872.566 1589.71,872.564 1589.7,872.562 1589.7,872.56 1589.69,872.557 1589.68,872.555 1589.67,872.553 1589.66,872.551 1589.65,872.549 1589.64,872.547 1589.63,872.545 1589.62,872.543 1589.61,872.541 1589.6,872.539 1589.59,872.537 1589.58,872.535 1589.57,872.533 1589.56,872.531 1589.55,872.528 1589.54,872.526 1589.53,872.524 1589.53,872.522 1589.52,872.52 1589.51,872.518 1589.5,872.516 1589.49,872.514 1589.48,872.512 1589.47,872.51 1589.46,872.508 1589.45,872.506 1589.44,872.504 1589.43,872.502 1589.42,872.499 1589.41,872.497 1589.4,872.495 1589.39,872.493 1589.38,872.491 1589.37,872.489 1589.37,872.487 1589.36,872.485 1589.35,872.483 1589.34,872.481 1589.33,872.479 1589.32,872.477 1589.31,872.475 1589.3,872.473 1589.29,872.471 1589.28,872.468 1589.27,872.466 1589.26,872.464 1589.25,872.462 1589.24,872.46 1589.23,872.458 1589.22,872.456 1589.21,872.454 1589.2,872.452 1589.2,872.45 1589.19,872.448 1589.18,872.446 1589.17,872.444 1589.16,872.442 1589.15,872.44 1589.14,872.438 1589.13,872.436 1589.12,872.433 1589.11,872.431 1589.1,872.429 1589.09,872.427 1589.08,872.425 1589.07,872.423 1589.06,872.421 1589.05,872.419 1589.05,872.417 1589.04,872.415 1589.03,872.413 1589.02,872.411 1589.01,872.409 1589,872.407 1588.99,872.405 1588.98,872.403 1588.97,872.401 1588.96,872.398 1588.95,872.396 1588.94,872.394 1588.93,872.392 1588.92,872.39 1588.91,872.388 1588.9,872.386 1588.89,872.384 1588.89,872.382 1588.88,872.38 1588.87,872.378 1588.86,872.376 1588.85,872.374 1588.84,872.372 1588.83,872.37 1588.82,872.368 1588.81,872.366 1588.8,872.364 1588.79,872.362 1588.78,872.359 1588.77,872.357 1588.76,872.355 1588.75,872.353 1588.74,872.351 1588.73,872.349 1588.73,872.347 1588.72,872.345 1588.71,872.343 1588.7,872.341 1588.69,872.339 1588.68,872.337 1588.67,872.335 1588.66,872.333 1588.65,872.331 1588.64,872.329 1588.63,872.327 1588.62,872.325 1588.61,872.323 1588.6,872.321 1588.59,872.319 1588.58,872.317 1588.58,872.314 1588.57,872.312 1588.56,872.31 1588.55,872.308 1588.54,872.306 1588.53,872.304 1588.52,872.302 1588.51,872.3 1588.5,872.298 1588.49,872.296 1588.48,872.294 1588.47,872.292 1588.46,872.29 1588.45,872.288 1588.44,872.286 1588.43,872.284 1588.43,872.282 1588.42,872.28 1588.41,872.278 1588.4,872.276 1588.39,872.274 1588.38,872.272 1588.37,872.27 1588.36,872.268 1588.35,872.266 1588.34,872.263 1588.33,872.261 1588.32,872.259 1588.31,872.257 1588.3,872.255 1588.29,872.253 1588.29,872.251 1588.28,872.249 1588.27,872.247 1588.26,872.245 1588.25,872.243 1588.24,872.241 1588.23,872.239 1588.22,872.237 1588.21,872.235 1588.2,872.233 1588.19,872.231 1588.18,872.229 1588.17,872.227 1588.16,872.225 1588.15,872.223 1588.14,872.221 1588.14,872.219 1588.13,872.217 1588.12,872.215 1588.11,872.213 1588.1,872.211 1588.09,872.209 1588.08,872.207 1588.07,872.205 1588.06,872.203 1588.05,872.2 1588.04,872.198 1588.03,872.196 1588.02,872.194 1588.01,872.192 1588,872.19 1588,872.188 1587.99,872.186 1587.98,872.184 1587.97,872.182 1587.96,872.18 1587.95,872.178 1587.94,872.176 1587.93,872.174 1587.92,872.172 1587.91,872.17 1587.9,872.168 1587.89,872.166 1587.88,872.164 1587.87,872.162 1587.86,872.16 1587.86,872.158 1587.85,872.156 1587.84,872.154 1587.83,872.152 1587.82,872.15 1587.81,872.148 1587.8,872.146 1587.79,872.144 1587.78,872.142 1587.77,872.14 1587.76,872.138 1587.75,872.136 1587.74,872.134 1587.73,872.132 1587.72,872.13 1587.72,872.128 1587.71,872.126 1587.7,872.124 1587.69,872.122 1587.68,872.12 1587.67,872.118 1587.66,872.116 1587.65,872.114 1587.64,872.112 1587.63,872.109 1587.62,872.107 1587.61,872.105 1587.6,872.103 1587.59,872.101 1587.58,872.099 1587.58,872.097 1587.57,872.095 1587.56,872.093 1587.55,872.091 1587.54,872.089 1587.53,872.087 1587.52,872.085 1587.51,872.083 1587.5,872.081 1587.49,872.079 1587.48,872.077 1587.47,872.075 1587.46,872.073 1587.45,872.071 1587.44,872.069 1587.44,872.067 1587.43,872.065 1587.42,872.063 1587.41,872.061 1587.4,872.059 1587.39,872.057 1587.38,872.055 1587.37,872.053 1587.36,872.051 1587.35,872.049 1587.34,872.047 1587.33,872.045 1587.32,872.043 1587.31,872.041 1587.31,872.039 1587.3,872.037 1587.29,872.035 1587.28,872.033 1587.27,872.031 1587.26,872.029 1587.25,872.027 1587.24,872.025 1587.23,872.023 1587.22,872.021 1587.21,872.019 1587.2,872.017 1587.19,872.015 1587.18,872.013 1587.18,872.011 1587.17,872.009 1587.16,872.007 1587.15,872.005 1587.14,872.003 1587.13,872.001 1587.12,871.999 1587.11,871.997 1587.1,871.995 1587.09,871.993 1587.08,871.991 1587.07,871.989 1587.06,871.987 1587.05,871.985 1587.04,871.983 1587.04,871.981 1587.03,871.979 1587.02,871.977 1587.01,871.975 1587,871.973 1586.99,871.971 1586.98,871.969 1586.97,871.967 1586.96,871.965 1586.95,871.963 1586.94,871.961 1586.93,871.959 1586.92,871.957 1586.91,871.955 1586.91,871.953 1586.9,871.951 1586.89,871.949 1586.88,871.947 1586.87,871.945 1586.86,871.943 1586.85,871.941 1586.84,871.939 1586.83,871.937 1586.82,871.935 1586.81,871.933 1586.8,871.931 1586.79,871.929 1586.79,871.927 1586.78,871.925 1586.77,871.923 1586.76,871.921 1586.75,871.919 1586.74,871.917 1586.73,871.915 1586.72,871.913 1586.71,871.911 1586.7,871.909 1586.69,871.907 1586.68,871.905 1586.67,871.903 1586.66,871.901 1586.66,871.899 1586.65,871.897 1586.64,871.895 1586.63,871.893 1586.62,871.891 1586.61,871.889 1586.6,871.887 1586.59,871.885 1586.58,871.883 1586.57,871.881 1586.56,871.879 1586.55,871.877 1586.54,871.875 1586.53,871.873 1586.53,871.871 1586.52,871.87 1586.51,871.868 1586.5,871.866 1586.49,871.864 1586.48,871.862 1586.47,871.86 1586.46,871.858 1586.45,871.856 1586.44,871.854 1586.43,871.852 1586.42,871.85 1586.41,871.848 1586.41,871.846 1586.4,871.844 1586.39,871.842 1586.38,871.84 1586.37,871.838 1586.36,871.836 1586.35,871.834 1586.34,871.832 1586.33,871.83 1586.32,871.828 1586.31,871.826 1586.3,871.824 1586.29,871.822 1586.29,871.82 1586.28,871.818 1586.27,871.816 1586.26,871.814 1586.25,871.812 1586.24,871.81 1586.23,871.808 1586.22,871.806 1586.21,871.804 1586.2,871.802 1586.19,871.8 1586.18,871.798 1586.17,871.796 1586.16,871.794 1586.16,871.792 1586.15,871.79 1586.14,871.788 1586.13,871.786 1586.12,871.784 1586.11,871.782 1586.1,871.781 1586.09,871.779 1586.08,871.777 1586.07,871.775 1586.06,871.773 1586.05,871.771 1586.04,871.769 1586.04,871.767 1586.03,871.765 1586.02,871.763 1586.01,871.761 1586,871.759 1585.99,871.757 1585.98,871.755 1585.97,871.753 1585.96,871.751 1585.95,871.749 1585.94,871.747 1585.93,871.745 1585.92,871.743 1585.92,871.741 1585.91,871.739 1585.9,871.737 1585.89,871.735 1585.88,871.733 1585.87,871.731 1585.86,871.729 1585.85,871.727 1585.84,871.725 1585.83,871.723 1585.82,871.721 1585.81,871.72 1585.8,871.718 1585.8,871.716 1585.79,871.714 1585.78,871.712 1585.77,871.71 1585.76,871.708 1585.75,871.706 1585.74,871.704 1585.73,871.702 1585.72,871.7 1585.71,871.698 1585.7,871.696 1585.69,871.694 1585.69,871.692 1585.68,871.69 1585.67,871.688 1585.66,871.686 1585.65,871.684 1585.64,871.682 1585.63,871.68 1585.62,871.678 1585.61,871.676 1585.6,871.674 1585.59,871.672 1585.58,871.67 1585.57,871.669 1585.57,871.667 1585.56,871.665 1585.55,871.663 1585.54,871.661 1585.53,871.659 1585.52,871.657 1585.51,871.655 1585.5,871.653 1585.49,871.651 1585.48,871.649 1585.47,871.647 1585.46,871.645 1585.45,871.643 1585.45,871.641 1585.44,871.639 1585.43,871.637 1585.42,871.635 1585.41,871.633 1585.4,871.631 1585.39,871.629 1585.38,871.628 1585.37,871.626 1585.36,871.624 1585.35,871.622 1585.34,871.62 1585.34,871.618 1585.33,871.616 1585.32,871.614 1585.31,871.612 1585.3,871.61 1585.29,871.608 1585.28,871.606 1585.27,871.604 1585.26,871.602 1585.25,871.6 1585.24,871.598 1585.23,871.596 1585.23,871.594 1585.22,871.592 1585.21,871.59 1585.2,871.589 1585.19,871.587 1585.18,871.585 1585.17,871.583 1585.16,871.581 1585.15,871.579 1585.14,871.577 1585.13,871.575 1585.12,871.573 1585.11,871.571 1585.11,871.569 1585.1,871.567 1585.09,871.565 1585.08,871.563 1585.07,871.561 1585.06,871.559 1585.05,871.557 1585.04,871.555 1585.03,871.554 1585.02,871.552 1585.01,871.55 1585,871.548 1585,871.546 1584.99,871.544 1584.98,871.542 1584.97,871.54 1584.96,871.538 1584.95,871.536 1584.94,871.534 1584.93,871.532 1584.92,871.53 1584.91,871.528 1584.9,871.526 1584.89,871.524 1584.89,871.523 1584.88,871.521 1584.87,871.519 1584.86,871.517 1584.85,871.515 1584.84,871.513 1584.83,871.511 1584.82,871.509 1584.81,871.507 1584.8,871.505 1584.79,871.503 1584.78,871.501 1584.78,871.499 1584.77,871.497 1584.76,871.495 1584.75,871.493 1584.74,871.492 1584.73,871.49 1584.72,871.488 1584.71,871.486 1584.7,871.484 1584.69,871.482 1584.68,871.48 1584.67,871.478 1584.67,871.476 1584.66,871.474 1584.65,871.472 1584.64,871.47 1584.63,871.468 1584.62,871.466 1584.61,871.465 1584.6,871.463 1584.59,871.461 1584.58,871.459 1584.57,871.457 1584.57,871.455 1584.56,871.453 1584.55,871.451 1584.54,871.449 1584.53,871.447 1584.52,871.445 1584.51,871.443 1584.5,871.441 1584.49,871.439 1584.48,871.438 1584.47,871.436 1584.46,871.434 1584.46,871.432 1584.45,871.43 1584.44,871.428 1584.43,871.426 1584.42,871.424 1584.41,871.422 1584.4,871.42 1584.39,871.418 1584.38,871.416 1584.37,871.414 1584.36,871.413 1584.35,871.411 1584.35,871.409 1584.34,871.407 1584.33,871.405 1584.32,871.403 1584.31,871.401 1584.3,871.399 1584.29,871.397 1584.28,871.395 1584.27,871.393 1584.26,871.391 1584.25,871.389 1584.25,871.388 1584.24,871.386 1584.23,871.384 1584.22,871.382 1584.21,871.38 1584.2,871.378 1584.19,871.376 1584.18,871.374 1584.17,871.372 1584.16,871.37 1584.15,871.368 1584.14,871.366 1584.14,871.365 1584.13,871.363 1584.12,871.361 1584.11,871.359 1584.1,871.357 1584.09,871.355 1584.08,871.353 1584.07,871.351 1584.06,871.349 1584.05,871.347 1584.04,871.345 1584.04,871.343 1584.03,871.342 1584.02,871.34 1584.01,871.338 1584,871.336 1583.99,871.334 1583.98,871.332 1583.97,871.33 1583.96,871.328 1583.95,871.326 1583.94,871.324 1583.93,871.322 1583.93,871.321 1583.92,871.319 1583.91,871.317 1583.9,871.315 1583.89,871.313 1583.88,871.311 1583.87,871.309 1583.86,871.307 1583.85,871.305 1583.84,871.303 1583.83,871.301 1583.83,871.3 1583.82,871.298 1583.81,871.296 1583.8,871.294 1583.79,871.292 1583.78,871.29 1583.77,871.288 1583.76,871.286 1583.75,871.284 1583.74,871.282 1583.73,871.281 1583.73,871.279 1583.72,871.277 1583.71,871.275 1583.7,871.273 1583.69,871.271 1583.68,871.269 1583.67,871.267 1583.66,871.265 1583.65,871.263 1583.64,871.261 1583.63,871.26 1583.63,871.258 1583.62,871.256 1583.61,871.254 1583.6,871.252 1583.59,871.25 1583.58,871.248 1583.57,871.246 1583.56,871.244 1583.55,871.242 1583.54,871.241 1583.53,871.239 1583.53,871.237 1583.52,871.235 1583.51,871.233 1583.5,871.231 1583.49,871.229 1583.48,871.227 1583.47,871.225 1583.46,871.224 1583.45,871.222 1583.44,871.22 1583.43,871.218 1583.43,871.216 1583.42,871.214 1583.41,871.212 1583.4,871.21 1583.39,871.208 1583.38,871.206 1583.37,871.205 1583.36,871.203 1583.35,871.201 1583.34,871.199 1583.33,871.197 1583.33,871.195 1583.32,871.193 1583.31,871.191 1583.3,871.189 1583.29,871.188 1583.28,871.186 1583.27,871.184 1583.26,871.182 1583.25,871.18 1583.24,871.178 1583.23,871.176 1583.23,871.174 1583.22,871.172 1583.21,871.171 1583.2,871.169 1583.19,871.167 1583.18,871.165 1583.17,871.163 1583.16,871.161 1583.15,871.159 1583.14,871.157 1583.13,871.155 1583.13,871.154 1583.12,871.152 1583.11,871.15 1583.1,871.148 1583.09,871.146 1583.08,871.144 1583.07,871.142 1583.06,871.14 1583.05,871.138 1583.04,871.137 1583.04,871.135 1583.03,871.133 1583.02,871.131 1583.01,871.129 1583,871.127 1582.99,871.125 1582.98,871.123 1582.97,871.121 1582.96,871.12 1582.95,871.118 1582.94,871.116 1582.94,871.114 1582.93,871.112 1582.92,871.11 1582.91,871.108 1582.9,871.106 1582.89,871.105 1582.88,871.103 1582.87,871.101 1582.86,871.099 1582.85,871.097 1582.84,871.095 1582.84,871.093 1582.83,871.091 1582.82,871.09 1582.81,871.088 1582.8,871.086 1582.79,871.084 1582.78,871.082 1582.77,871.08 1582.76,871.078 1582.75,871.076 1582.75,871.075 1582.74,871.073 1582.73,871.071 1582.72,871.069 1582.71,871.067 1582.7,871.065 1582.69,871.063 1582.68,871.061 1582.67,871.06 1582.66,871.058 1582.65,871.056 1582.65,871.054 1582.64,871.052 1582.63,871.05 1582.62,871.048 1582.61,871.046 1582.6,871.045 1582.59,871.043 1582.58,871.041 1582.57,871.039 1582.56,871.037 1582.56,871.035 1582.55,871.033 1582.54,871.031 1582.53,871.03 1582.52,871.028 1582.51,871.026 1582.5,871.024 1582.49,871.022 1582.48,871.02 1582.47,871.018 1582.47,871.016 1582.46,871.015 1582.45,871.013 1582.44,871.011 1582.43,871.009 1582.42,871.007 1582.41,871.005 1582.4,871.003 1582.39,871.002 1582.38,871 1582.37,870.998 1582.37,870.996 1582.36,870.994 1582.35,870.992 1582.34,870.99 1582.33,870.988 1582.32,870.987 1582.31,870.985 1582.3,870.983 1582.29,870.981 1582.28,870.979 1582.28,870.977 1582.27,870.975 1582.26,870.974 1582.25,870.972 1582.24,870.97 1582.23,870.968 1582.22,870.966 1582.21,870.964 1582.2,870.962 1582.19,870.961 1582.19,870.959 1582.18,870.957 1582.17,870.955 1582.16,870.953 1582.15,870.951 1582.14,870.949 1582.13,870.948 1582.12,870.946 1582.11,870.944 1582.1,870.942 1582.1,870.94 1582.09,870.938 1582.08,870.936 1582.07,870.935 1582.06,870.933 1582.05,870.931 1582.04,870.929 1582.03,870.927 1582.02,870.925 1582.01,870.923 1582.01,870.922 1582,870.92 1581.99,870.918 1581.98,870.916 1581.97,870.914 1581.96,870.912 1581.95,870.91 1581.94,870.909 1581.93,870.907 1581.92,870.905 1581.92,870.903 1581.91,870.901 1581.9,870.899 1581.89,870.897 1581.88,870.896 1581.87,870.894 1581.86,870.892 1581.85,870.89 1581.84,870.888 1581.83,870.886 1581.83,870.884 1581.82,870.883 1581.81,870.881 1581.8,870.879 1581.79,870.877 1581.78,870.875 1581.77,870.873 1581.76,870.872 1581.75,870.87 1581.74,870.868 1581.74,870.866 1581.73,870.864 1581.72,870.862 1581.71,870.86 1581.7,870.859 1581.69,870.857 1581.68,870.855 1581.67,870.853 1581.66,870.851 1581.65,870.849 1581.65,870.848 1581.64,870.846 1581.63,870.844 1581.62,870.842 1581.61,870.84 1581.6,870.838 1581.59,870.836 1581.58,870.835 1581.57,870.833 1581.56,870.831 1581.56,870.829 1581.55,870.827 1581.54,870.825 1581.53,870.824 1581.52,870.822 1581.51,870.82 1581.5,870.818 1581.49,870.816 1581.48,870.814 1581.47,870.813 1581.47,870.811 1581.46,870.809 1581.45,870.807 1581.44,870.805 1581.43,870.803 1581.42,870.802 1581.41,870.8 1581.4,870.798 1581.39,870.796 1581.38,870.794 1581.38,870.792 1581.37,870.79 1581.36,870.789 1581.35,870.787 1581.34,870.785 1581.33,870.783 1581.32,870.781 1581.31,870.779 1581.3,870.778 1581.3,870.776 1581.29,870.774 1581.28,870.772 1581.27,870.77 1581.26,870.768 1581.25,870.767 1581.24,870.765 1581.23,870.763 1581.22,870.761 1581.21,870.759 1581.21,870.757 1581.2,870.756 1581.19,870.754 1581.18,870.752 1581.17,870.75 1581.16,870.748 1581.15,870.746 1581.14,870.745 1581.13,870.743 1581.12,870.741 1581.12,870.739 1581.11,870.737 1581.1,870.736 1581.09,870.734 1581.08,870.732 1581.07,870.73 1581.06,870.728 1581.05,870.726 1581.04,870.725 1581.04,870.723 1581.03,870.721 1581.02,870.719 1581.01,870.717 1581,870.715 1580.99,870.714 1580.98,870.712 1580.97,870.71 1580.96,870.708 1580.95,870.706 1580.95,870.704 1580.94,870.703 1580.93,870.701 1580.92,870.699 1580.91,870.697 1580.9,870.695 1580.89,870.694 1580.88,870.692 1580.87,870.69 1580.87,870.688 1580.86,870.686 1580.85,870.684 1580.84,870.683 1580.83,870.681 1580.82,870.679 1580.81,870.677 1580.8,870.675 1580.79,870.673 1580.78,870.672 1580.78,870.67 1580.77,870.668 1580.76,870.666 1580.75,870.664 1580.74,870.663 1580.73,870.661 1580.72,870.659 1580.71,870.657 1580.7,870.655 1580.7,870.653 1580.69,870.652 1580.68,870.65 1580.67,870.648 1580.66,870.646 1580.65,870.644 1580.64,870.643 1580.63,870.641 1580.62,870.639 1580.62,870.637 1580.61,870.635 1580.6,870.633 1580.59,870.632 1580.58,870.63 1580.57,870.628 1580.56,870.626 1580.55,870.624 1580.54,870.623 1580.53,870.621 1580.53,870.619 1580.52,870.617 1580.51,870.615 1580.5,870.614 1580.49,870.612 1580.48,870.61 1580.47,870.608 1580.46,870.606 1580.45,870.604 1580.45,870.603 1580.44,870.601 1580.43,870.599 1580.42,870.597 1580.41,870.595 1580.4,870.594 1580.39,870.592 1580.38,870.59 1580.37,870.588 1580.37,870.586 1580.36,870.585 1580.35,870.583 1580.34,870.581 1580.33,870.579 1580.32,870.577 1580.31,870.576 1580.3,870.574 1580.29,870.572 1580.29,870.57 1580.28,870.568 1580.27,870.566 1580.26,870.565 1580.25,870.563 1580.24,870.561 1580.23,870.559 1580.22,870.557 1580.21,870.556 1580.21,870.554 1580.2,870.552 1580.19,870.55 1580.18,870.548 1580.17,870.547 1580.16,870.545 1580.15,870.543 1580.14,870.541 1580.13,870.539 1580.12,870.538 1580.12,870.536 1580.11,870.534 1580.1,870.532 1580.09,870.53 1580.08,870.529 1580.07,870.527 1580.06,870.525 1580.05,870.523 1580.04,870.521 1580.04,870.52 1580.03,870.518 1580.02,870.516 1580.01,870.514 1580,870.512 1579.99,870.511 1579.98,870.509 1579.97,870.507 1579.96,870.505 1579.96,870.503 1579.95,870.502 1579.94,870.5 1579.93,870.498 1579.92,870.496 1579.91,870.494 1579.9,870.493 1579.89,870.491 1579.88,870.489 1579.88,870.487 1579.87,870.486 1579.86,870.484 1579.85,870.482 1579.84,870.48 1579.83,870.478 1579.82,870.477 1579.81,870.475 1579.8,870.473 1579.8,870.471 1579.79,870.469 1579.78,870.468 1579.77,870.466 1579.76,870.464 1579.75,870.462 1579.74,870.46 1579.73,870.459 1579.72,870.457 1579.72,870.455 1579.71,870.453 1579.7,870.451 1579.69,870.45 1579.68,870.448 1579.67,870.446 1579.66,870.444 1579.65,870.443 1579.64,870.441 1579.64,870.439 1579.63,870.437 1579.62,870.435 1579.61,870.434 1579.6,870.432 1579.59,870.43 1579.58,870.428 1579.57,870.426 1579.57,870.425 1579.56,870.423 1579.55,870.421 1579.54,870.419 1579.53,870.418 1579.52,870.416 1579.51,870.414 1579.5,870.412 1579.49,870.41 1579.49,870.409 1579.48,870.407 1579.47,870.405 1579.46,870.403 1579.45,870.401 1579.44,870.4 1579.43,870.398 1579.42,870.396 1579.41,870.394 1579.41,870.393 1579.4,870.391 1579.39,870.389 1579.38,870.387 1579.37,870.385 1579.36,870.384 1579.35,870.382 1579.34,870.38 1579.33,870.378 1579.33,870.377 1579.32,870.375 1579.31,870.373 1579.3,870.371 1579.29,870.369 1579.28,870.368 1579.27,870.366 1579.26,870.364 1579.25,870.362 1579.25,870.361 1579.24,870.359 1579.23,870.357 1579.22,870.355 1579.21,870.353 1579.2,870.352 1579.19,870.35 1579.18,870.348 1579.18,870.346 1579.17,870.345 1579.16,870.343 1579.15,870.341 1579.14,870.339 1579.13,870.337 1579.12,870.336 1579.11,870.334 1579.1,870.332 1579.1,870.33 1579.09,870.329 1579.08,870.327 1579.07,870.325 1579.06,870.323 1579.05,870.322 1579.04,870.32 1579.03,870.318 1579.02,870.316 1579.02,870.314 1579.01,870.313 1579,870.311 1578.99,870.309 1578.98,870.307 1578.97,870.306 1578.96,870.304 1578.95,870.302 1578.95,870.3 1578.94,870.299 1578.93,870.297 1578.92,870.295 1578.91,870.293 1578.9,870.291 1578.89,870.29 1578.88,870.288 1578.87,870.286 1578.87,870.284 1578.86,870.283 1578.85,870.281 1578.84,870.279 1578.83,870.277 1578.82,870.276 1578.81,870.274 1578.8,870.272 1578.8,870.27 1578.79,870.268 1578.78,870.267 1578.77,870.265 1578.76,870.263 1578.75,870.261 1578.74,870.26 1578.73,870.258 1578.72,870.256 1578.72,870.254 1578.71,870.253 1578.7,870.251 1578.69,870.249 1578.68,870.247 1578.67,870.246 1578.66,870.244 1578.65,870.242 1578.65,870.24 1578.64,870.239 1578.63,870.237 1578.62,870.235 1578.61,870.233 1578.6,870.232 1578.59,870.23 1578.58,870.228 1578.57,870.226 1578.57,870.224 1578.56,870.223 1578.55,870.221 1578.54,870.219 1578.53,870.217 1578.52,870.216 1578.51,870.214 1578.5,870.212 1578.5,870.21 1578.49,870.209 1578.48,870.207 1578.47,870.205 1578.46,870.203 1578.45,870.202 1578.44,870.2 1578.43,870.198 1578.42,870.196 1578.42,870.195 1578.41,870.193 1578.4,870.191 1578.39,870.189 1578.38,870.188 1578.37,870.186 1578.36,870.184 1578.35,870.182 1578.35,870.181 1578.34,870.179 1578.33,870.177 1578.32,870.175 1578.31,870.174 1578.3,870.172 1578.29,870.17 1578.28,870.168 1578.28,870.167 1578.27,870.165 1578.26,870.163 1578.25,870.161 1578.24,870.16 1578.23,870.158 1578.22,870.156 1578.21,870.154 1578.2,870.153 1578.2,870.151 1578.19,870.149 1578.18,870.147 1578.17,870.146 1578.16,870.144 1578.15,870.142 1578.14,870.14 1578.13,870.139 1578.13,870.137 1578.12,870.135 1578.11,870.133 1578.1,870.132 1578.09,870.13 1578.08,870.128 1578.07,870.126 1578.06,870.125 1578.06,870.123 1578.05,870.121 1578.04,870.119 1578.03,870.118 1578.02,870.116 1578.01,870.114 1578,870.113 1577.99,870.111 1577.98,870.109 1577.98,870.107 1577.97,870.106 1577.96,870.104 1577.95,870.102 1577.94,870.1 1577.93,870.099 1577.92,870.097 1577.91,870.095 1577.91,870.093 1577.9,870.092 1577.89,870.09 1577.88,870.088 1577.87,870.086 1577.86,870.085 1577.85,870.083 1577.84,870.081 1577.84,870.079 1577.83,870.078 1577.82,870.076 1577.81,870.074 1577.8,870.073 1577.79,870.071 1577.78,870.069 1577.77,870.067 1577.77,870.066 1577.76,870.064 1577.75,870.062 1577.74,870.06 1577.73,870.059 1577.72,870.057 1577.71,870.055 1577.7,870.053 1577.7,870.052 1577.69,870.05 1577.68,870.048 1577.67,870.047 1577.66,870.045 1577.65,870.043 1577.64,870.041 1577.63,870.04 1577.63,870.038 1577.62,870.036 1577.61,870.034 1577.6,870.033 1577.59,870.031 1577.58,870.029 1577.57,870.027 1577.56,870.026 1577.56,870.024 1577.55,870.022 1577.54,870.021 1577.53,870.019 1577.52,870.017 1577.51,870.015 1577.5,870.014 1577.49,870.012 1577.48,870.01 1577.48,870.008 1577.47,870.007 1577.46,870.005 1577.45,870.003 1577.44,870.002 1577.43,870 1577.42,869.998 1577.41,869.996 1577.41,869.995 1577.4,869.993 1577.39,869.991 1577.38,869.99 1577.37,869.988 1577.36,869.986 1577.35,869.984 1577.34,869.983 1577.34,869.981 1577.33,869.979 1577.32,869.977 1577.31,869.976 1577.3,869.974 1577.29,869.972 1577.28,869.971 1577.27,869.969 1577.27,869.967 1577.26,869.965 1577.25,869.964 1577.24,869.962 1577.23,869.96 1577.22,869.959 1577.21,869.957 1577.21,869.955 1577.2,869.953 1577.19,869.952 1577.18,869.95 1577.17,869.948 1577.16,869.946 1577.15,869.945 1577.14,869.943 1577.14,869.941 1577.13,869.94 1577.12,869.938 1577.11,869.936 1577.1,869.934 1577.09,869.933 1577.08,869.931 1577.07,869.929 1577.07,869.928 1577.06,869.926 1577.05,869.924 1577.04,869.922 1577.03,869.921 1577.02,869.919 1577.01,869.917 1577,869.916 1577,869.914 1576.99,869.912 1576.98,869.91 1576.97,869.909 1576.96,869.907 1576.95,869.905 1576.94,869.904 1576.93,869.902 1576.93,869.9 1576.92,869.898 1576.91,869.897 1576.9,869.895 1576.89,869.893 1576.88,869.892 1576.87,869.89 1576.86,869.888 1576.86,869.887 1576.85,869.885 1576.84,869.883 1576.83,869.881 1576.82,869.88 1576.81,869.878 1576.8,869.876 1576.79,869.875 1576.79,869.873 1576.78,869.871 1576.77,869.869 1576.76,869.868 1576.75,869.866 1576.74,869.864 1576.73,869.863 1576.72,869.861 1576.72,869.859 1576.71,869.858 1576.7,869.856 1576.69,869.854 1576.68,869.852 1576.67,869.851 1576.66,869.849 1576.66,869.847 1576.65,869.846 1576.64,869.844 1576.63,869.842 1576.62,869.84 1576.61,869.839 1576.6,869.837 1576.59,869.835 1576.59,869.834 1576.58,869.832 1576.57,869.83 1576.56,869.829 1576.55,869.827 1576.54,869.825 1576.53,869.823 1576.52,869.822 1576.52,869.82 1576.51,869.818 1576.5,869.817 1576.49,869.815 1576.48,869.813 1576.47,869.812 1576.46,869.81 1576.45,869.808 1576.45,869.806 1576.44,869.805 1576.43,869.803 1576.42,869.801 1576.41,869.8 1576.4,869.798 1576.39,869.796 1576.39,869.795 1576.38,869.793 1576.37,869.791 1576.36,869.79 1576.35,869.788 1576.34,869.786 1576.33,869.784 1576.32,869.783 1576.32,869.781 1576.31,869.779 1576.3,869.778 1576.29,869.776 1576.28,869.774 1576.27,869.773 1576.26,869.771 1576.26,869.769 1576.25,869.767 1576.24,869.766 1576.23,869.764 1576.22,869.762 1576.21,869.761 1576.2,869.759 1576.19,869.757 1576.19,869.756 1576.18,869.754 1576.17,869.752 1576.16,869.751 1576.15,869.749 1576.14,869.747 1576.13,869.746 1576.12,869.744 1576.12,869.742 1576.11,869.74 1576.1,869.739 1576.09,869.737 1576.08,869.735 1576.07,869.734 1576.06,869.732 1576.06,869.73 1576.05,869.729 1576.04,869.727 1576.03,869.725 1576.02,869.724 1576.01,869.722 1576,869.72 1575.99,869.719 1575.99,869.717 1575.98,869.715 1575.97,869.713 1575.96,869.712 1575.95,869.71 1575.94,869.708 1575.93,869.707 1575.93,869.705 1575.92,869.703 1575.91,869.702 1575.9,869.7 1575.89,869.698 1575.88,869.697 1575.87,869.695 1575.86,869.693 1575.86,869.692 1575.85,869.69 1575.84,869.688 1575.83,869.687 1575.82,869.685 1575.81,869.683 1575.8,869.682 1575.8,869.68 1575.79,869.678 1575.78,869.676 1575.77,869.675 1575.76,869.673 1575.75,869.671 1575.74,869.67 1575.73,869.668 1575.73,869.666 1575.72,869.665 1575.71,869.663 1575.7,869.661 1575.69,869.66 1575.68,869.658 1575.67,869.656 1575.67,869.655 1575.66,869.653 1575.65,869.651 1575.64,869.65 1575.63,869.648 1575.62,869.646 1575.61,869.645 1575.6,869.643 1575.6,869.641 1575.59,869.64 1575.58,869.638 1575.57,869.636 1575.56,869.635 1575.55,869.633 1575.54,869.631 1575.54,869.63 1575.53,869.628 1575.52,869.626 1575.51,869.625 1575.5,869.623 1575.49,869.621 1575.48,869.62 1575.47,869.618 1575.47,869.616 1575.46,869.615 1575.45,869.613 1575.44,869.611 1575.43,869.61 1575.42,869.608 1575.41,869.606 1575.41,869.605 1575.4,869.603 1575.39,869.601 1575.38,869.6 1575.37,869.598 1575.36,869.596 1575.35,869.595 1575.35,869.593 1575.34,869.591 1575.33,869.59 1575.32,869.588 1575.31,869.586 1575.3,869.585 1575.29,869.583 1575.28,869.581 1575.28,869.58 1575.27,869.578 1575.26,869.576 1575.25,869.575 1575.24,869.573 1575.23,869.571 1575.22,869.57 1575.22,869.568 1575.21,869.566 1575.2,869.565 1575.19,869.563 1575.18,869.561 1575.17,869.56 1575.16,869.558 1575.16,869.556 1575.15,869.555 1575.14,869.553 1575.13,869.551 1575.12,869.55 1575.11,869.548 1575.1,869.546 1575.09,869.545 1575.09,869.543 1575.08,869.541 1575.07,869.54 1575.06,869.538 1575.05,869.536 1575.04,869.535 1575.03,869.533 1575.03,869.531 1575.02,869.53 1575.01,869.528 1575,869.526 1574.99,869.525 1574.98,869.523 1574.97,869.521 1574.97,869.52 1574.96,869.518 1574.95,869.516 1574.94,869.515 1574.93,869.513 1574.92,869.512 1574.91,869.51 1574.91,869.508 1574.9,869.507 1574.89,869.505 1574.88,869.503 1574.87,869.502 1574.86,869.5 1574.85,869.498 1574.84,869.497 1574.84,869.495 1574.83,869.493 1574.82,869.492 1574.81,869.49 1574.8,869.488 1574.79,869.487 1574.78,869.485 1574.78,869.483 1574.77,869.482 1574.76,869.48 1574.75,869.478 1574.74,869.477 1574.73,869.475 1574.72,869.474 1574.72,869.472 1574.71,869.47 1574.7,869.469 1574.69,869.467 1574.68,869.465 1574.67,869.464 1574.66,869.462 1574.66,869.46 1574.65,869.459 1574.64,869.457 1574.63,869.455 1574.62,869.454 1574.61,869.452 1574.6,869.45 1574.6,869.449 1574.59,869.447 1574.58,869.446 1574.57,869.444 1574.56,869.442 1574.55,869.441 1574.54,869.439 1574.54,869.437 1574.53,869.436 1574.52,869.434 1574.51,869.432 1574.5,869.431 1574.49,869.429 1574.48,869.427 1574.47,869.426 1574.47,869.424 1574.46,869.423 1574.45,869.421 1574.44,869.419 1574.43,869.418 1574.42,869.416 1574.41,869.414 1574.41,869.413 1574.4,869.411 1574.39,869.409 1574.38,869.408 1574.37,869.406 1574.36,869.404 1574.35,869.403 1574.35,869.401 1574.34,869.4 1574.33,869.398 1574.32,869.396 1574.31,869.395 1574.3,869.393 1574.29,869.391 1574.29,869.39 1574.28,869.388 1574.27,869.386 1574.26,869.385 1574.25,869.383 1574.24,869.382 1574.23,869.38 1574.23,869.378 1574.22,869.377 1574.21,869.375 1574.2,869.373 1574.19,869.372 1574.18,869.37 1574.17,869.368 1574.17,869.367 1574.16,869.365 1574.15,869.364 1574.14,869.362 1574.13,869.36 1574.12,869.359 1574.11,869.357 1574.11,869.355 1574.1,869.354 1574.09,869.352 1574.08,869.351 1574.07,869.349 1574.06,869.347 1574.05,869.346 1574.05,869.344 1574.04,869.342 1574.03,869.341 1574.02,869.339 1574.01,869.337 1574,869.336 1573.99,869.334 1573.99,869.333 1573.98,869.331 1573.97,869.329 1573.96,869.328 1573.95,869.326 1573.94,869.324 1573.93,869.323 1573.93,869.321 1573.92,869.32 1573.91,869.318 1573.9,869.316 1573.89,869.315 1573.88,869.313 1573.87,869.311 1573.87,869.31 1573.86,869.308 1573.85,869.307 1573.84,869.305 1573.83,869.303 1573.82,869.302 1573.81,869.3 1573.81,869.298 1573.8,869.297 1573.79,869.295 1573.78,869.294 1573.77,869.292 1573.76,869.29 1573.75,869.289 1573.75,869.287 1573.74,869.285 1573.73,869.284 1573.72,869.282 1573.71,869.281 1573.7,869.279 1573.69,869.277 1573.69,869.276 1573.68,869.274 1573.67,869.273 1573.66,869.271 1573.65,869.269 1573.64,869.268 1573.64,869.266 1573.63,869.264 1573.62,869.263 1573.61,869.261 1573.6,869.26 1573.59,869.258 1573.58,869.256 1573.58,869.255 1573.57,869.253 1573.56,869.251 1573.55,869.25 1573.54,869.248 1573.53,869.247 1573.52,869.245 1573.52,869.243 1573.51,869.242 1573.5,869.24 1573.49,869.239 1573.48,869.237 1573.47,869.235 1573.46,869.234 1573.46,869.232 1573.45,869.23 1573.44,869.229 1573.43,869.227 1573.42,869.226 1573.41,869.224 1573.4,869.222 1573.4,869.221 1573.39,869.219 1573.38,869.218 1573.37,869.216 1573.36,869.214 1573.35,869.213 1573.34,869.211 1573.34,869.21 1573.33,869.208 1573.32,869.206 1573.31,869.205 1573.3,869.203 1573.29,869.201 1573.28,869.2 1573.28,869.198 1573.27,869.197 1573.26,869.195 1573.25,869.193 1573.24,869.192 1573.23,869.19 1573.23,869.189 1573.22,869.187 1573.21,869.185 1573.2,869.184 1573.19,869.182 1573.18,869.181 1573.17,869.179 1573.17,869.177 1573.16,869.176 1573.15,869.174 1573.14,869.173 1573.13,869.171 1573.12,869.169 1573.11,869.168 1573.11,869.166 1573.1,869.165 1573.09,869.163 1573.08,869.161 1573.07,869.16 1573.06,869.158 1573.05,869.157 1573.05,869.155 1573.04,869.153 1573.03,869.152 1573.02,869.15 1573.01,869.149 1573,869.147 1573,869.145 1572.99,869.144 1572.98,869.142 1572.97,869.141 1572.96,869.139 1572.95,869.137 1572.94,869.136 1572.94,869.134 1572.93,869.133 1572.92,869.131 1572.91,869.129 1572.9,869.128 1572.89,869.126 1572.88,869.125 1572.88,869.123 1572.87,869.121 1572.86,869.12 1572.85,869.118 1572.84,869.117 1572.83,869.115 1572.83,869.113 1572.82,869.112 1572.81,869.11 1572.8,869.109 1572.79,869.107 1572.78,869.105 1572.77,869.104 1572.77,869.102 1572.76,869.101 1572.75,869.099 1572.74,869.097 1572.73,869.096 1572.72,869.094 1572.71,869.093 1572.71,869.091 1572.7,869.089 1572.69,869.088 1572.68,869.086 1572.67,869.085 1572.66,869.083 1572.66,869.081 1572.65,869.08 1572.64,869.078 1572.63,869.077 1572.62,869.075 1572.61,869.074 1572.6,869.072 1572.6,869.07 1572.59,869.069 1572.58,869.067 1572.57,869.066 1572.56,869.064 1572.55,869.062 1572.54,869.061 1572.54,869.059 1572.53,869.058 1572.52,869.056 1572.51,869.054 1572.5,869.053 1572.49,869.051 1572.49,869.05 1572.48,869.048 1572.47,869.047 1572.46,869.045 1572.45,869.043 1572.44,869.042 1572.43,869.04 1572.43,869.039 1572.42,869.037 1572.41,869.035 1572.4,869.034 1572.39,869.032 1572.38,869.031 1572.38,869.029 1572.37,869.028 1572.36,869.026 1572.35,869.024 1572.34,869.023 1572.33,869.021 1572.32,869.02 1572.32,869.018 1572.31,869.016 1572.3,869.015 1572.29,869.013 1572.28,869.012 1572.27,869.01 1572.26,869.009 1572.26,869.007 1572.25,869.005 1572.24,869.004 1572.23,869.002 1572.22,869.001 1572.21,868.999 1572.21,868.998 1572.2,868.996 1572.19,868.994 1572.18,868.993 1572.17,868.991 1572.16,868.99 1572.15,868.988 1572.15,868.986 1572.14,868.985 1572.13,868.983 1572.12,868.982 1572.11,868.98 1572.1,868.979 1572.1,868.977 1572.09,868.975 1572.08,868.974 1572.07,868.972 1572.06,868.971 1572.05,868.969 1572.04,868.968 1572.04,868.966 1572.03,868.964 1572.02,868.963 1572.01,868.961 1572,868.96 1571.99,868.958 1571.99,868.957 1571.98,868.955 1571.97,868.953 1571.96,868.952 1571.95,868.95 1571.94,868.949 1571.93,868.947 1571.93,868.946 1571.92,868.944 1571.91,868.942 1571.9,868.941 1571.89,868.939 1571.88,868.938 1571.88,868.936 1571.87,868.935 1571.86,868.933 1571.85,868.931 1571.84,868.93 1571.83,868.928 1571.82,868.927 1571.82,868.925 1571.81,868.924 1571.8,868.922 1571.79,868.92 1571.78,868.919 1571.77,868.917 1571.77,868.916 1571.76,868.914 1571.75,868.913 1571.74,868.911 1571.73,868.909 1571.72,868.908 1571.72,868.906 1571.71,868.905 1571.7,868.903 1571.69,868.902 1571.68,868.9 1571.67,868.899 1571.66,868.897 1571.66,868.895 1571.65,868.894 1571.64,868.892 1571.63,868.891 1571.62,868.889 1571.61,868.888 1571.61,868.886 1571.6,868.884 1571.59,868.883 1571.58,868.881 1571.57,868.88 1571.56,868.878 1571.55,868.877 1571.55,868.875 1571.54,868.874 1571.53,868.872 1571.52,868.87 1571.51,868.869 1571.5,868.867 1571.5,868.866 1571.49,868.864 1571.48,868.863 1571.47,868.861 1571.46,868.86 1571.45,868.858 1571.45,868.856 1571.44,868.855 1571.43,868.853 1571.42,868.852 1571.41,868.85 1571.4,868.849 1571.39,868.847 1571.39,868.846 1571.38,868.844 1571.37,868.842 1571.36,868.841 1571.35,868.839 1571.34,868.838 1571.34,868.836 1571.33,868.835 1571.32,868.833 1571.31,868.832 1571.3,868.83 1571.29,868.828 1571.28,868.827 1571.28,868.825 1571.27,868.824 1571.26,868.822 1571.25,868.821 1571.24,868.819 1571.23,868.818 1571.23,868.816 1571.22,868.814 1571.21,868.813 1571.2,868.811 1571.19,868.81 1571.18,868.808 1571.18,868.807 1571.17,868.805 1571.16,868.804 1571.15,868.802 1571.14,868.801 1571.13,868.799 1571.13,868.797 1571.12,868.796 1571.11,868.794 1571.1,868.793 1571.09,868.791 1571.08,868.79 1571.07,868.788 1571.07,868.787 1571.06,868.785 1571.05,868.783 1571.04,868.782 1571.03,868.78 1571.02,868.779 1571.02,868.777 1571.01,868.776 1571,868.774 1570.99,868.773 1570.98,868.771 1570.97,868.77 1570.97,868.768 1570.96,868.767 1570.95,868.765 1570.94,868.763 1570.93,868.762 1570.92,868.76 1570.91,868.759 1570.91,868.757 1570.9,868.756 1570.89,868.754 1570.88,868.753 1570.87,868.751 1570.86,868.75 1570.86,868.748 1570.85,868.746 1570.84,868.745 1570.83,868.743 1570.82,868.742 1570.81,868.74 1570.81,868.739 1570.8,868.737 1570.79,868.736 1570.78,868.734 1570.77,868.733 1570.76,868.731 1570.76,868.73 1570.75,868.728 1570.74,868.726 1570.73,868.725 1570.72,868.723 1570.71,868.722 1570.7,868.72 1570.7,868.719 1570.69,868.717 1570.68,868.716 1570.67,868.714 1570.66,868.713 1570.65,868.711 1570.65,868.71 1570.64,868.708 1570.63,868.706 1570.62,868.705 1570.61,868.703 1570.6,868.702 1570.6,868.7 1570.59,868.699 1570.58,868.697 1570.57,868.696 1570.56,868.694 1570.55,868.693 1570.55,868.691 1570.54,868.69 1570.53,868.688 1570.52,868.687 1570.51,868.685 1570.5,868.684 1570.5,868.682 1570.49,868.68 1570.48,868.679 1570.47,868.677 1570.46,868.676 1570.45,868.674 1570.45,868.673 1570.44,868.671 1570.43,868.67 1570.42,868.668 1570.41,868.667 1570.4,868.665 1570.39,868.664 1570.39,868.662 1570.38,868.661 1570.37,868.659 1570.36,868.658 1570.35,868.656 1570.34,868.654 1570.34,868.653 1570.33,868.651 1570.32,868.65 1570.31,868.648 1570.3,868.647 1570.29,868.645 1570.29,868.644 1570.28,868.642 1570.27,868.641 1570.26,868.639 1570.25,868.638 1570.24,868.636 1570.24,868.635 1570.23,868.633 1570.22,868.632 1570.21,868.63 1570.2,868.629 1570.19,868.627 1570.19,868.626 1570.18,868.624 1570.17,868.622 1570.16,868.621 1570.15,868.619 1570.14,868.618 1570.14,868.616 1570.13,868.615 1570.12,868.613 1570.11,868.612 1570.1,868.61 1570.09,868.609 1570.09,868.607 1570.08,868.606 1570.07,868.604 1570.06,868.603 1570.05,868.601 1570.04,868.6 1570.04,868.598 1570.03,868.597 1570.02,868.595 1570.01,868.594 1570,868.592 1569.99,868.591 1569.99,868.589 1569.98,868.588 1569.97,868.586 1569.96,868.585 1569.95,868.583 1569.94,868.581 1569.93,868.58 1569.93,868.578 1569.92,868.577 1569.91,868.575 1569.9,868.574 1569.89,868.572 1569.88,868.571 1569.88,868.569 1569.87,868.568 1569.86,868.566 1569.85,868.565 1569.84,868.563 1569.83,868.562 1569.83,868.56 1569.82,868.559 1569.81,868.557 1569.8,868.556 1569.79,868.554 1569.78,868.553 1569.78,868.551 1569.77,868.55 1569.76,868.548 1569.75,868.547 1569.74,868.545 1569.73,868.544 1569.73,868.542 1569.72,868.541 1569.71,868.539 1569.7,868.538 1569.69,868.536 1569.68,868.535 1569.68,868.533 1569.67,868.532 1569.66,868.53 1569.65,868.529 1569.64,868.527 1569.63,868.526 1569.63,868.524 1569.62,868.523 1569.61,868.521 1569.6,868.52 1569.59,868.518 1569.58,868.517 1569.58,868.515 1569.57,868.514 1569.56,868.512 1569.55,868.511 1569.54,868.509 1569.53,868.508 1569.53,868.506 1569.52,868.505 1569.51,868.503 1569.5,868.502 1569.49,868.5 1569.48,868.499 1569.48,868.497 1569.47,868.496 1569.46,868.494 1569.45,868.492 1569.44,868.491 1569.43,868.489 1569.43,868.488 1569.42,868.486 1569.41,868.485 1569.4,868.483 1569.39,868.482 1569.38,868.48 1569.38,868.479 1569.37,868.477 1569.36,868.476 1569.35,868.475 1569.34,868.473 1569.33,868.472 1569.33,868.47 1569.32,868.469 1569.31,868.467 1569.3,868.466 1569.29,868.464 1569.29,868.463 1569.28,868.461 1569.27,868.46 1569.26,868.458 1569.25,868.457 1569.24,868.455 1569.24,868.454 1569.23,868.452 1569.22,868.451 1569.21,868.449 1569.2,868.448 1569.19,868.446 1569.19,868.445 1569.18,868.443 1569.17,868.442 1569.16,868.44 1569.15,868.439 1569.14,868.437 1569.14,868.436 1569.13,868.434 1569.12,868.433 1569.11,868.431 1569.1,868.43 1569.09,868.428 1569.09,868.427 1569.08,868.425 1569.07,868.424 1569.06,868.422 1569.05,868.421 1569.04,868.419 1569.04,868.418 1569.03,868.416 1569.02,868.415 1569.01,868.413 1569,868.412 1568.99,868.41 1568.99,868.409 1568.98,868.407 1568.97,868.406 1568.96,868.404 1568.95,868.403 1568.94,868.401 1568.94,868.4 1568.93,868.398 1568.92,868.397 1568.91,868.395 1568.9,868.394 1568.89,868.392 1568.89,868.391 1568.88,868.389 1568.87,868.388 1568.86,868.386 1568.85,868.385 1568.84,868.384 1568.84,868.382 1568.83,868.381 1568.82,868.379 1568.81,868.378 1568.8,868.376 1568.8,868.375 1568.79,868.373 1568.78,868.372 1568.77,868.37 1568.76,868.369 1568.75,868.367 1568.75,868.366 1568.74,868.364 1568.73,868.363 1568.72,868.361 1568.71,868.36 1568.7,868.358 1568.7,868.357 1568.69,868.355 1568.68,868.354 1568.67,868.352 1568.66,868.351 1568.65,868.349 1568.65,868.348 1568.64,868.346 1568.63,868.345 1568.62,868.344 1568.61,868.342 1568.6,868.341 1568.6,868.339 1568.59,868.338 1568.58,868.336 1568.57,868.335 1568.56,868.333 1568.56,868.332 1568.55,868.33 1568.54,868.329 1568.53,868.327 1568.52,868.326 1568.51,868.324 1568.51,868.323 1568.5,868.321 1568.49,868.32 1568.48,868.318 1568.47,868.317 1568.46,868.315 1568.46,868.314 1568.45,868.313 1568.44,868.311 1568.43,868.31 1568.42,868.308 1568.41,868.307 1568.41,868.305 1568.4,868.304 1568.39,868.302 1568.38,868.301 1568.37,868.299 1568.36,868.298 1568.36,868.296 1568.35,868.295 1568.34,868.293 1568.33,868.292 1568.32,868.29 1568.32,868.289 1568.31,868.288 1568.3,868.286 1568.29,868.285 1568.28,868.283 1568.27,868.282 1568.27,868.28 1568.26,868.279 1568.25,868.277 1568.24,868.276 1568.23,868.274 1568.22,868.273 1568.22,868.271 1568.21,868.27 1568.2,868.268 1568.19,868.267 1568.18,868.266 1568.17,868.264 1568.17,868.263 1568.16,868.261 1568.15,868.26 1568.14,868.258 1568.13,868.257 1568.13,868.255 1568.12,868.254 1568.11,868.252 1568.1,868.251 1568.09,868.249 1568.08,868.248 1568.08,868.246 1568.07,868.245 1568.06,868.244 1568.05,868.242 1568.04,868.241 1568.03,868.239 1568.03,868.238 1568.02,868.236 1568.01,868.235 1568,868.233 1567.99,868.232 1567.99,868.23 1567.98,868.229 1567.97,868.227 1567.96,868.226 1567.95,868.225 1567.94,868.223 1567.94,868.222 1567.93,868.22 1567.92,868.219 1567.91,868.217 1567.9,868.216 1567.89,868.214 1567.89,868.213 1567.88,868.211 1567.87,868.21 1567.86,868.209 1567.85,868.207 1567.84,868.206 1567.84,868.204 1567.83,868.203 1567.82,868.201 1567.81,868.2 1567.8,868.198 1567.8,868.197 1567.79,868.195 1567.78,868.194 1567.77,868.193 1567.76,868.191 1567.75,868.19 1567.75,868.188 1567.74,868.187 1567.73,868.185 1567.72,868.184 1567.71,868.182 1567.7,868.181 1567.7,868.179 1567.69,868.178 1567.68,868.177 1567.67,868.175 1567.66,868.174 1567.66,868.172 1567.65,868.171 1567.64,868.169 1567.63,868.168 1567.62,868.166 1567.61,868.165 1567.61,868.163 1567.6,868.162 1567.59,868.161 1567.58,868.159 1567.57,868.158 1567.57,868.156 1567.56,868.155 1567.55,868.153 1567.54,868.152 1567.53,868.15 1567.52,868.149 1567.52,868.148 1567.51,868.146 1567.5,868.145 1567.49,868.143 1567.48,868.142 1567.47,868.14 1567.47,868.139 1567.46,868.137 1567.45,868.136 1567.44,868.135 1567.43,868.133 1567.43,868.132 1567.42,868.13 1567.41,868.129 1567.4,868.127 1567.39,868.126 1567.38,868.124 1567.38,868.123 1567.37,868.122 1567.36,868.12 1567.35,868.119 1567.34,868.117 1567.34,868.116 1567.33,868.114 1567.32,868.113 1567.31,868.111 1567.3,868.11 1567.29,868.109 1567.29,868.107 1567.28,868.106 1567.27,868.104 1567.26,868.103 1567.25,868.101 1567.24,868.1 1567.24,868.098 1567.23,868.097 1567.22,868.096 1567.21,868.094 1567.2,868.093 1567.2,868.091 1567.19,868.09 1567.18,868.088 1567.17,868.087 1567.16,868.086 1567.15,868.084 1567.15,868.083 1567.14,868.081 1567.13,868.08 1567.12,868.078 1567.11,868.077 1567.11,868.075 1567.1,868.074 1567.09,868.073 1567.08,868.071 1567.07,868.07 1567.06,868.068 1567.06,868.067 1567.05,868.065 1567.04,868.064 1567.03,868.063 1567.02,868.061 1567.02,868.06 1567.01,868.058 1567,868.057 1566.99,868.055 1566.98,868.054 1566.97,868.053 1566.97,868.051 1566.96,868.05 1566.95,868.048 1566.94,868.047 1566.93,868.045 1566.92,868.044 1566.92,868.043 1566.91,868.041 1566.9,868.04 1566.89,868.038 1566.88,868.037 1566.88,868.035 1566.87,868.034 1566.86,868.033 1566.85,868.031 1566.84,868.03 1566.83,868.028 1566.83,868.027 1566.82,868.025 1566.81,868.024 1566.8,868.023 1566.79,868.021 1566.79,868.02 1566.78,868.018 1566.77,868.017 1566.76,868.015 1566.75,868.014 1566.74,868.013 1566.74,868.011 1566.73,868.01 1566.72,868.008 1566.71,868.007 1566.7,868.005 1566.7,868.004 1566.69,868.003 1566.68,868.001 1566.67,868 1566.66,867.998 1566.65,867.997 1566.65,867.995 1566.64,867.994 1566.63,867.993 1566.62,867.991 1566.61,867.99 1566.61,867.988 1566.6,867.987 1566.59,867.985 1566.58,867.984 1566.57,867.983 1566.57,867.981 1566.56,867.98 1566.55,867.978 1566.54,867.977 1566.53,867.976 1566.52,867.974 1566.52,867.973 1566.51,867.971 1566.5,867.97 1566.49,867.968 1566.48,867.967 1566.48,867.966 1566.47,867.964 1566.46,867.963 1566.45,867.961 1566.44,867.96 1566.43,867.959 1566.43,867.957 1566.42,867.956 1566.41,867.954 1566.4,867.953 1566.39,867.951 1566.39,867.95 1566.38,867.949 1566.37,867.947 1566.36,867.946 1566.35,867.944 1566.34,867.943 1566.34,867.942 1566.33,867.94 1566.32,867.939 1566.31,867.937 1566.3,867.936 1566.3,867.934 1566.29,867.933 1566.28,867.932 1566.27,867.93 1566.26,867.929 1566.25,867.927 1566.25,867.926 1566.24,867.925 1566.23,867.923 1566.22,867.922 1566.21,867.92 1566.21,867.919 1566.2,867.918 1566.19,867.916 1566.18,867.915 1566.17,867.913 1566.17,867.912 1566.16,867.91 1566.15,867.909 1566.14,867.908 1566.13,867.906 1566.12,867.905 1566.12,867.903 1566.11,867.902 1566.1,867.901 1566.09,867.899 1566.08,867.898 1566.08,867.896 1566.07,867.895 1566.06,867.894 1566.05,867.892 1566.04,867.891 1566.03,867.889 1566.03,867.888 1566.02,867.887 1566.01,867.885 1566,867.884 1565.99,867.882 1565.99,867.881 1565.98,867.88 1565.97,867.878 1565.96,867.877 1565.95,867.875 1565.95,867.874 1565.94,867.873 1565.93,867.871 1565.92,867.87 1565.91,867.868 1565.9,867.867 1565.9,867.865 1565.89,867.864 1565.88,867.863 1565.87,867.861 1565.86,867.86 1565.86,867.858 1565.85,867.857 1565.84,867.856 1565.83,867.854 1565.82,867.853 1565.82,867.851 1565.81,867.85 1565.8,867.849 1565.79,867.847 1565.78,867.846 1565.77,867.844 1565.77,867.843 1565.76,867.842 1565.75,867.84 1565.74,867.839 1565.73,867.838 1565.73,867.836 1565.72,867.835 1565.71,867.833 1565.7,867.832 1565.69,867.831 1565.69,867.829 1565.68,867.828 1565.67,867.826 1565.66,867.825 1565.65,867.824 1565.64,867.822 1565.64,867.821 1565.63,867.819 1565.62,867.818 1565.61,867.817 1565.6,867.815 1565.6,867.814 1565.59,867.812 1565.58,867.811 1565.57,867.81 1565.56,867.808 1565.56,867.807 1565.55,867.805 1565.54,867.804 1565.53,867.803 1565.52,867.801 1565.51,867.8 1565.51,867.798 1565.5,867.797 1565.49,867.796 1565.48,867.794 1565.47,867.793 1565.47,867.792 1565.46,867.79 1565.45,867.789 1565.44,867.787 1565.43,867.786 1565.43,867.785 1565.42,867.783 1565.41,867.782 1565.4,867.78 1565.39,867.779 1565.38,867.778 1565.38,867.776 1565.37,867.775 1565.36,867.773 1565.35,867.772 1565.34,867.771 1565.34,867.769 1565.33,867.768 1565.32,867.767 1565.31,867.765 1565.3,867.764 1565.3,867.762 1565.29,867.761 1565.28,867.76 1565.27,867.758 1565.26,867.757 1565.26,867.755 1565.25,867.754 1565.24,867.753 1565.23,867.751 1565.22,867.75 1565.21,867.749 1565.21,867.747 1565.2,867.746 1565.19,867.744 1565.18,867.743 1565.17,867.742 1565.17,867.74 1565.16,867.739 1565.15,867.737 1565.14,867.736 1565.13,867.735 1565.13,867.733 1565.12,867.732 1565.11,867.731 1565.1,867.729 1565.09,867.728 1565.09,867.726 1565.08,867.725 1565.07,867.724 1565.06,867.722 1565.05,867.721 1565.04,867.72 1565.04,867.718 1565.03,867.717 1565.02,867.715 1565.01,867.714 1565,867.713 1565,867.711 1564.99,867.71 1564.98,867.709 1564.97,867.707 1564.96,867.706 1564.96,867.704 1564.95,867.703 1564.94,867.702 1564.93,867.7 1564.92,867.699 1564.92,867.698 1564.91,867.696 1564.9,867.695 1564.89,867.693 1564.88,867.692 1564.87,867.691 1564.87,867.689 1564.86,867.688 1564.85,867.687 1564.84,867.685 1564.83,867.684 1564.83,867.682 1564.82,867.681 1564.81,867.68 1564.8,867.678 1564.79,867.677 1564.79,867.676 1564.78,867.674 1564.77,867.673 1564.76,867.671 1564.75,867.67 1564.75,867.669 1564.74,867.667 1564.73,867.666 1564.72,867.665 1564.71,867.663 1564.71,867.662 1564.7,867.66 1564.69,867.659 1564.68,867.658 1564.67,867.656 1564.66,867.655 1564.66,867.654 1564.65,867.652 1564.64,867.651 1564.63,867.65 1564.62,867.648 1564.62,867.647 1564.61,867.645 1564.6,867.644 1564.59,867.643 1564.58,867.641 1564.58,867.64 1564.57,867.639 1564.56,867.637 1564.55,867.636 1564.54,867.635 1564.54,867.633 1564.53,867.632 1564.52,867.63 1564.51,867.629 1564.5,867.628 1564.5,867.626 1564.49,867.625 1564.48,867.624 1564.47,867.622 1564.46,867.621 1564.46,867.62 1564.45,867.618 1564.44,867.617 1564.43,867.615 1564.42,867.614 1564.41,867.613 1564.41,867.611 1564.4,867.61 1564.39,867.609 1564.38,867.607 1564.37,867.606 1564.37,867.605 1564.36,867.603 1564.35,867.602 1564.34,867.601 1564.33,867.599 1564.33,867.598 1564.32,867.596 1564.31,867.595 1564.3,867.594 1564.29,867.592 1564.29,867.591 1564.28,867.59 1564.27,867.588 1564.26,867.587 1564.25,867.586 1564.25,867.584 1564.24,867.583 1564.23,867.582 1564.22,867.58 1564.21,867.579 1564.21,867.577 1564.2,867.576 1564.19,867.575 1564.18,867.573 1564.17,867.572 1564.17,867.571 1564.16,867.569 1564.15,867.568 1564.14,867.567 1564.13,867.565 1564.12,867.564 1564.12,867.563 1564.11,867.561 1564.1,867.56 1564.09,867.559 1564.08,867.557 1564.08,867.556 1564.07,867.554 1564.06,867.553 1564.05,867.552 1564.04,867.55 1564.04,867.549 1564.03,867.548 1564.02,867.546 1564.01,867.545 1564,867.544 1564,867.542 1563.99,867.541 1563.98,867.54 1563.97,867.538 1563.96,867.537 1563.96,867.536 1563.95,867.534 1563.94,867.533 1563.93,867.532 1563.92,867.53 1563.92,867.529 1563.91,867.527 1563.9,867.526 1563.89,867.525 1563.88,867.523 1563.88,867.522 1563.87,867.521 1563.86,867.519 1563.85,867.518 1563.84,867.517 1563.84,867.515 1563.83,867.514 1563.82,867.513 1563.81,867.511 1563.8,867.51 1563.8,867.509 1563.79,867.507 1563.78,867.506 1563.77,867.505 1563.76,867.503 1563.76,867.502 1563.75,867.501 1563.74,867.499 1563.73,867.498 1563.72,867.497 1563.72,867.495 1563.71,867.494 1563.7,867.493 1563.69,867.491 1563.68,867.49 1563.68,867.489 1563.67,867.487 1563.66,867.486 1563.65,867.485 1563.64,867.483 1563.64,867.482 1563.63,867.48 1563.62,867.479 1563.61,867.478 1563.6,867.476 1563.6,867.475 1563.59,867.474 1563.58,867.472 1563.57,867.471 1563.56,867.47 1563.55,867.468 1563.55,867.467 1563.54,867.466 1563.53,867.464 1563.52,867.463 1563.51,867.462 1563.51,867.46 1563.5,867.459 1563.49,867.458 1563.48,867.456 1563.47,867.455 1563.47,867.454 1563.46,867.452 1563.45,867.451 1563.44,867.45 1563.43,867.448 1563.43,867.447 1563.42,867.446 1563.41,867.444 1563.4,867.443 1563.39,867.442 1563.39,867.44 1563.38,867.439 1563.37,867.438 1563.36,867.436 1563.35,867.435 1563.35,867.434 1563.34,867.432 1563.33,867.431 1563.32,867.43 1563.31,867.428 1563.31,867.427 1563.3,867.426 1563.29,867.424 1563.28,867.423 1563.27,867.422 1563.27,867.42 1563.26,867.419 1563.25,867.418 1563.24,867.417 1563.23,867.415 1563.23,867.414 1563.22,867.413 1563.21,867.411 1563.2,867.41 1563.19,867.409 1563.19,867.407 1563.18,867.406 1563.17,867.405 1563.16,867.403 1563.15,867.402 1563.15,867.401 1563.14,867.399 1563.13,867.398 1563.12,867.397 1563.11,867.395 1563.11,867.394 1563.1,867.393 1563.09,867.391 1563.08,867.39 1563.07,867.389 1563.07,867.387 1563.06,867.386 1563.05,867.385 1563.04,867.383 1563.04,867.382 1563.03,867.381 1563.02,867.379 1563.01,867.378 1563,867.377 1563,867.375 1562.99,867.374 1562.98,867.373 1562.97,867.371 1562.96,867.37 1562.96,867.369 1562.95,867.368 1562.94,867.366 1562.93,867.365 1562.92,867.364 1562.92,867.362 1562.91,867.361 1562.9,867.36 1562.89,867.358 1562.88,867.357 1562.88,867.356 1562.87,867.354 1562.86,867.353 1562.85,867.352 1562.84,867.35 1562.84,867.349 1562.83,867.348 1562.82,867.346 1562.81,867.345 1562.8,867.344 1562.8,867.342 1562.79,867.341 1562.78,867.34 1562.77,867.339 1562.76,867.337 1562.76,867.336 1562.75,867.335 1562.74,867.333 1562.73,867.332 1562.72,867.331 1562.72,867.329 1562.71,867.328 1562.7,867.327 1562.69,867.325 1562.68,867.324 1562.68,867.323 1562.67,867.321 1562.66,867.32 1562.65,867.319 1562.64,867.318 1562.64,867.316 1562.63,867.315 1562.62,867.314 1562.61,867.312 1562.6,867.311 1562.6,867.31 1562.59,867.308 1562.58,867.307 1562.57,867.306 1562.56,867.304 1562.56,867.303 1562.55,867.302 1562.54,867.301 1562.53,867.299 1562.52,867.298 1562.52,867.297 1562.51,867.295 1562.5,867.294 1562.49,867.293 1562.48,867.291 1562.48,867.29 1562.47,867.289 1562.46,867.287 1562.45,867.286 1562.45,867.285 1562.44,867.284 1562.43,867.282 1562.42,867.281 1562.41,867.28 1562.41,867.278 1562.4,867.277 1562.39,867.276 1562.38,867.274 1562.37,867.273 1562.37,867.272 1562.36,867.27 1562.35,867.269 1562.34,867.268 1562.33,867.267 1562.33,867.265 1562.32,867.264 1562.31,867.263 1562.3,867.261 1562.29,867.26 1562.29,867.259 1562.28,867.257 1562.27,867.256 1562.26,867.255 1562.25,867.254 1562.25,867.252 1562.24,867.251 1562.23,867.25 1562.22,867.248 1562.21,867.247 1562.21,867.246 1562.2,867.244 1562.19,867.243 1562.18,867.242 1562.17,867.241 1562.17,867.239 1562.16,867.238 1562.15,867.237 1562.14,867.235 1562.14,867.234 1562.13,867.233 1562.12,867.232 1562.11,867.23 1562.1,867.229 1562.1,867.228 1562.09,867.226 1562.08,867.225 1562.07,867.224 1562.06,867.222 1562.06,867.221 1562.05,867.22 1562.04,867.219 1562.03,867.217 1562.02,867.216 1562.02,867.215 1562.01,867.213 1562,867.212 1561.99,867.211 1561.98,867.21 1561.98,867.208 1561.97,867.207 1561.96,867.206 1561.95,867.204 1561.94,867.203 1561.94,867.202 1561.93,867.2 1561.92,867.199 1561.91,867.198 1561.91,867.197 1561.9,867.195 1561.89,867.194 1561.88,867.193 1561.87,867.191 1561.87,867.19 1561.86,867.189 1561.85,867.188 1561.84,867.186 1561.83,867.185 1561.83,867.184 1561.82,867.182 1561.81,867.181 1561.8,867.18 1561.79,867.179 1561.79,867.177 1561.78,867.176 1561.77,867.175 1561.76,867.173 1561.75,867.172 1561.75,867.171 1561.74,867.17 1561.73,867.168 1561.72,867.167 1561.72,867.166 1561.71,867.164 1561.7,867.163 1561.69,867.162 1561.68,867.161 1561.68,867.159 1561.67,867.158 1561.66,867.157 1561.65,867.155 1561.64,867.154 1561.64,867.153 1561.63,867.152 1561.62,867.15 1561.61,867.149 1561.6,867.148 1561.6,867.146 1561.59,867.145 1561.58,867.144 1561.57,867.143 1561.56,867.141 1561.56,867.14 1561.55,867.139 1561.54,867.137 1561.53,867.136 1561.53,867.135 1561.52,867.134 1561.51,867.132 1561.5,867.131 1561.49,867.13 1561.49,867.129 1561.48,867.127 1561.47,867.126 1561.46,867.125 1561.45,867.123 1561.45,867.122 1561.44,867.121 1561.43,867.12 1561.42,867.118 1561.41,867.117 1561.41,867.116 1561.4,867.114 1561.39,867.113 1561.38,867.112 1561.37,867.111 1561.37,867.109 1561.36,867.108 1561.35,867.107 1561.34,867.106 1561.34,867.104 1561.33,867.103 1561.32,867.102 1561.31,867.1 1561.3,867.099 1561.3,867.098 1561.29,867.097 1561.28,867.095 1561.27,867.094 1561.26,867.093 1561.26,867.092 1561.25,867.09 1561.24,867.089 1561.23,867.088 1561.22,867.086 1561.22,867.085 1561.21,867.084 1561.2,867.083 1561.19,867.081 1561.19,867.08 1561.18,867.079 1561.17,867.078 1561.16,867.076 1561.15,867.075 1561.15,867.074 1561.14,867.072 1561.13,867.071 1561.12,867.07 1561.11,867.069 1561.11,867.067 1561.1,867.066 1561.09,867.065 1561.08,867.064 1561.08,867.062 1561.07,867.061 1561.06,867.06 1561.05,867.059 1561.04,867.057 1561.04,867.056 1561.03,867.055 1561.02,867.053 1561.01,867.052 1561,867.051 1561,867.05 1560.99,867.048 1560.98,867.047 1560.97,867.046 1560.96,867.045 1560.96,867.043 1560.95,867.042 1560.94,867.041 1560.93,867.04 1560.93,867.038 1560.92,867.037 1560.91,867.036 1560.9,867.035 1560.89,867.033 1560.89,867.032 1560.88,867.031 1560.87,867.029 1560.86,867.028 1560.85,867.027 1560.85,867.026 1560.84,867.024 1560.83,867.023 1560.82,867.022 1560.82,867.021 1560.81,867.019 1560.8,867.018 1560.79,867.017 1560.78,867.016 1560.78,867.014 1560.77,867.013 1560.76,867.012 1560.75,867.011 1560.74,867.009 1560.74,867.008 1560.73,867.007 1560.72,867.006 1560.71,867.004 1560.7,867.003 1560.7,867.002 1560.69,867.001 1560.68,866.999 1560.67,866.998 1560.67,866.997 1560.66,866.995 1560.65,866.994 1560.64,866.993 1560.63,866.992 1560.63,866.99 1560.62,866.989 1560.61,866.988 1560.6,866.987 1560.59,866.985 1560.59,866.984 1560.58,866.983 1560.57,866.982 1560.56,866.98 1560.56,866.979 1560.55,866.978 1560.54,866.977 1560.53,866.975 1560.52,866.974 1560.52,866.973 1560.51,866.972 1560.5,866.97 1560.49,866.969 1560.48,866.968 1560.48,866.967 1560.47,866.965 1560.46,866.964 1560.45,866.963 1560.45,866.962 1560.44,866.96 1560.43,866.959 1560.42,866.958 1560.41,866.957 1560.41,866.955 1560.4,866.954 1560.39,866.953 1560.38,866.952 1560.37,866.95 1560.37,866.949 1560.36,866.948 1560.35,866.947 1560.34,866.945 1560.34,866.944 1560.33,866.943 1560.32,866.942 1560.31,866.94 1560.3,866.939 1560.3,866.938 1560.29,866.937 1560.28,866.935 1560.27,866.934 1560.27,866.933 1560.26,866.932 1560.25,866.931 1560.24,866.929 1560.23,866.928 1560.23,866.927 1560.22,866.926 1560.21,866.924 1560.2,866.923 1560.19,866.922 1560.19,866.921 1560.18,866.919 1560.17,866.918 1560.16,866.917 1560.16,866.916 1560.15,866.914 1560.14,866.913 1560.13,866.912 1560.12,866.911 1560.12,866.909 1560.11,866.908 1560.1,866.907 1560.09,866.906 1560.08,866.904 1560.08,866.903 1560.07,866.902 1560.06,866.901 1560.05,866.899 1560.05,866.898 1560.04,866.897 1560.03,866.896 1560.02,866.895 1560.01,866.893 1560.01,866.892 1560,866.891 1559.99,866.89 1559.98,866.888 1559.98,866.887 1559.97,866.886 1559.96,866.885 1559.95,866.883 1559.94,866.882 1559.94,866.881 1559.93,866.88 1559.92,866.878 1559.91,866.877 1559.9,866.876 1559.9,866.875 1559.89,866.874 1559.88,866.872 1559.87,866.871 1559.87,866.87 1559.86,866.869 1559.85,866.867 1559.84,866.866 1559.83,866.865 1559.83,866.864 1559.82,866.862 1559.81,866.861 1559.8,866.86 1559.8,866.859 1559.79,866.858 1559.78,866.856 1559.77,866.855 1559.76,866.854 1559.76,866.853 1559.75,866.851 1559.74,866.85 1559.73,866.849 1559.72,866.848 1559.72,866.846 1559.71,866.845 1559.7,866.844 1559.69,866.843 1559.69,866.842 1559.68,866.84 1559.67,866.839 1559.66,866.838 1559.65,866.837 1559.65,866.835 1559.64,866.834 1559.63,866.833 1559.62,866.832 1559.62,866.83 1559.61,866.829 1559.6,866.828 1559.59,866.827 1559.58,866.826 1559.58,866.824 1559.57,866.823 1559.56,866.822 1559.55,866.821 1559.55,866.819 1559.54,866.818 1559.53,866.817 1559.52,866.816 1559.51,866.815 1559.51,866.813 1559.5,866.812 1559.49,866.811 1559.48,866.81 1559.48,866.808 1559.47,866.807 1559.46,866.806 1559.45,866.805 1559.44,866.804 1559.44,866.802 1559.43,866.801 1559.42,866.8 1559.41,866.799 1559.4,866.797 1559.4,866.796 1559.39,866.795 1559.38,866.794 1559.37,866.793 1559.37,866.791 1559.36,866.79 1559.35,866.789 1559.34,866.788 1559.33,866.786 1559.33,866.785 1559.32,866.784 1559.31,866.783 1559.3,866.782 1559.3,866.78 1559.29,866.779 1559.28,866.778 1559.27,866.777 1559.26,866.776 1559.26,866.774 1559.25,866.773 1559.24,866.772 1559.23,866.771 1559.23,866.769 1559.22,866.768 1559.21,866.767 1559.2,866.766 1559.19,866.765 1559.19,866.763 1559.18,866.762 1559.17,866.761 1559.16,866.76 1559.16,866.759 1559.15,866.757 1559.14,866.756 1559.13,866.755 1559.12,866.754 1559.12,866.752 1559.11,866.751 1559.1,866.75 1559.09,866.749 1559.09,866.748 1559.08,866.746 1559.07,866.745 1559.06,866.744 1559.05,866.743 1559.05,866.742 1559.04,866.74 1559.03,866.739 1559.02,866.738 1559.02,866.737 1559.01,866.736 1559,866.734 1558.99,866.733 1558.98,866.732 1558.98,866.731 1558.97,866.729 1558.96,866.728 1558.95,866.727 1558.95,866.726 1558.94,866.725 1558.93,866.723 1558.92,866.722 1558.91,866.721 1558.91,866.72 1558.9,866.719 1558.89,866.717 1558.88,866.716 1558.88,866.715 1558.87,866.714 1558.86,866.713 1558.85,866.711 1558.84,866.71 1558.84,866.709 1558.83,866.708 1558.82,866.707 1558.81,866.705 1558.81,866.704 1558.8,866.703 1558.79,866.702 1558.78,866.701 1558.77,866.699 1558.77,866.698 1558.76,866.697 1558.75,866.696 1558.74,866.695 1558.74,866.693 1558.73,866.692 1558.72,866.691 1558.71,866.69 1558.7,866.689 1558.7,866.687 1558.69,866.686 1558.68,866.685 1558.67,866.684 1558.67,866.683 1558.66,866.681 1558.65,866.68 1558.64,866.679 1558.63,866.678 1558.63,866.677 1558.62,866.675 1558.61,866.674 1558.6,866.673 1558.6,866.672 1558.59,866.671 1558.58,866.669 1558.57,866.668 1558.56,866.667 1558.56,866.666 1558.55,866.665 1558.54,866.663 1558.53,866.662 1558.53,866.661 1558.52,866.66 1558.51,866.659 1558.5,866.657 1558.5,866.656 1558.49,866.655 1558.48,866.654 1558.47,866.653 1558.46,866.651 1558.46,866.65 1558.45,866.649 1558.44,866.648 1558.43,866.647 1558.43,866.645 1558.42,866.644 1558.41,866.643 1558.4,866.642 1558.39,866.641 1558.39,866.64 1558.38,866.638 1558.37,866.637 1558.36,866.636 1558.36,866.635 1558.35,866.634 1558.34,866.632 1558.33,866.631 1558.32,866.63 1558.32,866.629 1558.31,866.628 1558.3,866.626 1558.29,866.625 1558.29,866.624 1558.28,866.623 1558.27,866.622 1558.26,866.62 1558.26,866.619 1558.25,866.618 1558.24,866.617 1558.23,866.616 1558.22,866.615 1558.22,866.613 1558.21,866.612 1558.2,866.611 1558.19,866.61 1558.19,866.609 1558.18,866.607 1558.17,866.606 1558.16,866.605 1558.15,866.604 1558.15,866.603 1558.14,866.602 1558.13,866.6 1558.12,866.599 1558.12,866.598 1558.11,866.597 1558.1,866.596 1558.09,866.594 1558.08,866.593 1558.08,866.592 1558.07,866.591 1558.06,866.59 1558.05,866.588 1558.05,866.587 1558.04,866.586 1558.03,866.585 1558.02,866.584 1558.02,866.583 1558.01,866.581 1558,866.58 1557.99,866.579 1557.98,866.578 1557.98,866.577 1557.97,866.575 1557.96,866.574 1557.95,866.573 1557.95,866.572 1557.94,866.571 1557.93,866.57 1557.92,866.568 1557.91,866.567 1557.91,866.566 1557.9,866.565 1557.89,866.564 1557.88,866.563 1557.88,866.561 1557.87,866.56 1557.86,866.559 1557.85,866.558 1557.85,866.557 1557.84,866.555 1557.83,866.554 1557.82,866.553 1557.81,866.552 1557.81,866.551 1557.8,866.55 1557.79,866.548 1557.78,866.547 1557.78,866.546 1557.77,866.545 1557.76,866.544 1557.75,866.543 1557.75,866.541 1557.74,866.54 1557.73,866.539 1557.72,866.538 1557.71,866.537 1557.71,866.536 1557.7,866.534 1557.69,866.533 1557.68,866.532 1557.68,866.531 1557.67,866.53 1557.66,866.528 1557.65,866.527 1557.64,866.526 1557.64,866.525 1557.63,866.524 1557.62,866.523 1557.61,866.521 1557.61,866.52 1557.6,866.519 1557.59,866.518 1557.58,866.517 1557.58,866.516 1557.57,866.514 1557.56,866.513 1557.55,866.512 1557.54,866.511 1557.54,866.51 1557.53,866.509 1557.52,866.507 1557.51,866.506 1557.51,866.505 1557.5,866.504 1557.49,866.503 1557.48,866.502 1557.48,866.5 1557.47,866.499 1557.46,866.498 1557.45,866.497 1557.44,866.496 1557.44,866.495 1557.43,866.493 1557.42,866.492 1557.41,866.491 1557.41,866.49 1557.4,866.489 1557.39,866.488 1557.38,866.486 1557.38,866.485 1557.37,866.484 1557.36,866.483 1557.35,866.482 1557.34,866.481 1557.34,866.48 1557.33,866.478 1557.32,866.477 1557.31,866.476 1557.31,866.475 1557.3,866.474 1557.29,866.473 1557.28,866.471 1557.28,866.47 1557.27,866.469 1557.26,866.468 1557.25,866.467 1557.24,866.466 1557.24,866.464 1557.23,866.463 1557.22,866.462 1557.21,866.461 1557.21,866.46 1557.2,866.459 1557.19,866.457 1557.18,866.456 1557.18,866.455 1557.17,866.454 1557.16,866.453 1557.15,866.452 1557.14,866.451 1557.14,866.449 1557.13,866.448 1557.12,866.447 1557.11,866.446 1557.11,866.445 1557.1,866.444 1557.09,866.442 1557.08,866.441 1557.08,866.44 1557.07,866.439 1557.06,866.438 1557.05,866.437 1557.04,866.436 1557.04,866.434 1557.03,866.433 1557.02,866.432 1557.01,866.431 1557.01,866.43 1557,866.429 1556.99,866.427 1556.98,866.426 1556.98,866.425 1556.97,866.424 1556.96,866.423 1556.95,866.422 1556.95,866.421 1556.94,866.419 1556.93,866.418 1556.92,866.417 1556.91,866.416 1556.91,866.415 1556.9,866.414 1556.89,866.412 1556.88,866.411 1556.88,866.41 1556.87,866.409 1556.86,866.408 1556.85,866.407 1556.85,866.406 1556.84,866.404 1556.83,866.403 1556.82,866.402 1556.81,866.401 1556.81,866.4 1556.8,866.399 1556.79,866.398 1556.78,866.396 1556.78,866.395 1556.77,866.394 1556.76,866.393 1556.75,866.392 1556.75,866.391 1556.74,866.39 1556.73,866.388 1556.72,866.387 1556.72,866.386 1556.71,866.385 1556.7,866.384 1556.69,866.383 1556.68,866.382 1556.68,866.38 1556.67,866.379 1556.66,866.378 1556.65,866.377 1556.65,866.376 1556.64,866.375 1556.63,866.374 1556.62,866.372 1556.62,866.371 1556.61,866.37 1556.6,866.369 1556.59,866.368 1556.58,866.367 1556.58,866.366 1556.57,866.364 1556.56,866.363 1556.55,866.362 1556.55,866.361 1556.54,866.36 1556.53,866.359 1556.52,866.358 1556.52,866.356 1556.51,866.355 1556.5,866.354 1556.49,866.353 1556.49,866.352 1556.48,866.351 1556.47,866.35 1556.46,866.348 1556.45,866.347 1556.45,866.346 1556.44,866.345 1556.43,866.344 1556.42,866.343 1556.42,866.342 1556.41,866.341 1556.4,866.339 1556.39,866.338 1556.39,866.337 1556.38,866.336 1556.37,866.335 1556.36,866.334 1556.36,866.333 1556.35,866.331 1556.34,866.33 1556.33,866.329 1556.32,866.328 1556.32,866.327 1556.31,866.326 1556.3,866.325 1556.29,866.324 1556.29,866.322 1556.28,866.321 1556.27,866.32 1556.26,866.319 1556.26,866.318 1556.25,866.317 1556.24,866.316 1556.23,866.314 1556.23,866.313 1556.22,866.312 1556.21,866.311 1556.2,866.31 1556.19,866.309 1556.19,866.308 1556.18,866.307 1556.17,866.305 1556.16,866.304 1556.16,866.303 1556.15,866.302 1556.14,866.301 1556.13,866.3 1556.13,866.299 1556.12,866.298 1556.11,866.296 1556.1,866.295 1556.1,866.294 1556.09,866.293 1556.08,866.292 1556.07,866.291 1556.07,866.29 1556.06,866.289 1556.05,866.287 1556.04,866.286 1556.03,866.285 1556.03,866.284 1556.02,866.283 1556.01,866.282 1556,866.281 1556,866.28 1555.99,866.278 1555.98,866.277 1555.97,866.276 1555.97,866.275 1555.96,866.274 1555.95,866.273 1555.94,866.272 1555.94,866.271 1555.93,866.269 1555.92,866.268 1555.91,866.267 1555.91,866.266 1555.9,866.265 1555.89,866.264 1555.88,866.263 1555.87,866.262 1555.87,866.26 1555.86,866.259 1555.85,866.258 1555.84,866.257 1555.84,866.256 1555.83,866.255 1555.82,866.254 1555.81,866.253 1555.81,866.252 1555.8,866.25 1555.79,866.249 1555.78,866.248 1555.78,866.247 1555.77,866.246 1555.76,866.245 1555.75,866.244 1555.75,866.243 1555.74,866.241 1555.73,866.24 1555.72,866.239 1555.71,866.238 1555.71,866.237 1555.7,866.236 1555.69,866.235 1555.68,866.234 1555.68,866.233 1555.67,866.231 1555.66,866.23 1555.65,866.229 1555.65,866.228 1555.64,866.227 1555.63,866.226 1555.62,866.225 1555.62,866.224 1555.61,866.223 1555.6,866.221 1555.59,866.22 1555.59,866.219 1555.58,866.218 1555.57,866.217 1555.56,866.216 1555.56,866.215 1555.55,866.214 1555.54,866.213 1555.53,866.211 1555.52,866.21 1555.52,866.209 1555.51,866.208 1555.5,866.207 1555.49,866.206 1555.49,866.205 1555.48,866.204 1555.47,866.203 1555.46,866.201 1555.46,866.2 1555.45,866.199 1555.44,866.198 1555.43,866.197 1555.43,866.196 1555.42,866.195 1555.41,866.194 1555.4,866.193 1555.4,866.191 1555.39,866.19 1555.38,866.189 1555.37,866.188 1555.37,866.187 1555.36,866.186 1555.35,866.185 1555.34,866.184 1555.33,866.183 1555.33,866.181 1555.32,866.18 1555.31,866.179 1555.3,866.178 1555.3,866.177 1555.29,866.176 1555.28,866.175 1555.27,866.174 1555.27,866.173 1555.26,866.172 1555.25,866.17 1555.24,866.169 1555.24,866.168 1555.23,866.167 1555.22,866.166 1555.21,866.165 1555.21,866.164 1555.2,866.163 1555.19,866.162 1555.18,866.161 1555.18,866.159 1555.17,866.158 1555.16,866.157 1555.15,866.156 1555.15,866.155 1555.14,866.154 1555.13,866.153 1555.12,866.152 1555.11,866.151 1555.11,866.15 1555.1,866.148 1555.09,866.147 1555.08,866.146 1555.08,866.145 1555.07,866.144 1555.06,866.143 1555.05,866.142 1555.05,866.141 1555.04,866.14 1555.03,866.139 1555.02,866.137 1555.02,866.136 1555.01,866.135 1555,866.134 1554.99,866.133 1554.99,866.132 1554.98,866.131 1554.97,866.13 1554.96,866.129 1554.96,866.128 1554.95,866.127 1554.94,866.125 1554.93,866.124 1554.93,866.123 1554.92,866.122 1554.91,866.121 1554.9,866.12 1554.9,866.119 1554.89,866.118 1554.88,866.117 1554.87,866.116 1554.86,866.115 1554.86,866.113 1554.85,866.112 1554.84,866.111 1554.83,866.11 1554.83,866.109 1554.82,866.108 1554.81,866.107 1554.8,866.106 1554.8,866.105 1554.79,866.104 1554.78,866.103 1554.77,866.101 1554.77,866.1 1554.76,866.099 1554.75,866.098 1554.74,866.097 1554.74,866.096 1554.73,866.095 1554.72,866.094 1554.71,866.093 1554.71,866.092 1554.7,866.091 1554.69,866.089 1554.68,866.088 1554.68,866.087 1554.67,866.086 1554.66,866.085 1554.65,866.084 1554.65,866.083 1554.64,866.082 1554.63,866.081 1554.62,866.08 1554.62,866.079 1554.61,866.078 1554.6,866.076 1554.59,866.075 1554.59,866.074 1554.58,866.073 1554.57,866.072 1554.56,866.071 1554.55,866.07 1554.55,866.069 1554.54,866.068 1554.53,866.067 1554.52,866.066 1554.52,866.065 1554.51,866.063 1554.5,866.062 1554.49,866.061 1554.49,866.06 1554.48,866.059 1554.47,866.058 1554.46,866.057 1554.46,866.056 1554.45,866.055 1554.44,866.054 1554.43,866.053 1554.43,866.052 1554.42,866.051 1554.41,866.049 1554.4,866.048 1554.4,866.047 1554.39,866.046 1554.38,866.045 1554.37,866.044 1554.37,866.043 1554.36,866.042 1554.35,866.041 1554.34,866.04 1554.34,866.039 1554.33,866.038 1554.32,866.037 1554.31,866.035 1554.31,866.034 1554.3,866.033 1554.29,866.032 1554.28,866.031 1554.28,866.03 1554.27,866.029 1554.26,866.028 1554.25,866.027 1554.25,866.026 1554.24,866.025 1554.23,866.024 1554.22,866.023 1554.22,866.021 1554.21,866.02 1554.2,866.019 1554.19,866.018 1554.19,866.017 1554.18,866.016 1554.17,866.015 1554.16,866.014 1554.16,866.013 1554.15,866.012 1554.14,866.011 1554.13,866.01 1554.13,866.009 1554.12,866.008 1554.11,866.006 1554.1,866.005 1554.1,866.004 1554.09,866.003 1554.08,866.002 1554.07,866.001 1554.06,866 1554.06,865.999 1554.05,865.998 1554.04,865.997 1554.03,865.996 1554.03,865.995 1554.02,865.994 1554.01,865.993 1554,865.992 1554,865.99 1553.99,865.989 1553.98,865.988 1553.97,865.987 1553.97,865.986 1553.96,865.985 1553.95,865.984 1553.94,865.983 1553.94,865.982 1553.93,865.981 1553.92,865.98 1553.91,865.979 1553.91,865.978 1553.9,865.977 1553.89,865.976 1553.88,865.974 1553.88,865.973 1553.87,865.972 1553.86,865.971 1553.85,865.97 1553.85,865.969 1553.84,865.968 1553.83,865.967 1553.82,865.966 1553.82,865.965 1553.81,865.964 1553.8,865.963 1553.79,865.962 1553.79,865.961 1553.78,865.96 1553.77,865.959 1553.76,865.957 1553.76,865.956 1553.75,865.955 1553.74,865.954 1553.73,865.953 1553.73,865.952 1553.72,865.951 1553.71,865.95 1553.7,865.949 1553.7,865.948 1553.69,865.947 1553.68,865.946 1553.67,865.945 1553.67,865.944 1553.66,865.943 1553.65,865.942 1553.64,865.941 1553.64,865.939 1553.63,865.938 1553.62,865.937 1553.61,865.936 1553.61,865.935 1553.6,865.934 1553.59,865.933 1553.58,865.932 1553.58,865.931 1553.57,865.93 1553.56,865.929 1553.55,865.928 1553.55,865.927 1553.54,865.926 1553.53,865.925 1553.52,865.924 1553.52,865.923 1553.51,865.922 1553.5,865.921 1553.49,865.919 1553.49,865.918 1553.48,865.917 1553.47,865.916 1553.46,865.915 1553.46,865.914 1553.45,865.913 1553.44,865.912 1553.43,865.911 1553.43,865.91 1553.42,865.909 1553.41,865.908 1553.4,865.907 1553.4,865.906 1553.39,865.905 1553.38,865.904 1553.37,865.903 1553.37,865.902 1553.36,865.901 1553.35,865.9 1553.34,865.898 1553.34,865.897 1553.33,865.896 1553.32,865.895 1553.31,865.894 1553.31,865.893 1553.3,865.892 1553.29,865.891 1553.28,865.89 1553.28,865.889 1553.27,865.888 1553.26,865.887 1553.25,865.886 1553.25,865.885 1553.24,865.884 1553.23,865.883 1553.22,865.882 1553.22,865.881 1553.21,865.88 1553.2,865.879 1553.19,865.878 1553.19,865.877 1553.18,865.875 1553.17,865.874 1553.16,865.873 1553.16,865.872 1553.15,865.871 1553.14,865.87 1553.13,865.869 1553.13,865.868 1553.12,865.867 1553.11,865.866 1553.1,865.865 1553.1,865.864 1553.09,865.863 1553.08,865.862 1553.07,865.861 1553.07,865.86 1553.06,865.859 1553.05,865.858 1553.04,865.857 1553.04,865.856 1553.03,865.855 1553.02,865.854 1553.02,865.853 1553.01,865.852 1553,865.851 1552.99,865.849 1552.99,865.848 1552.98,865.847 1552.97,865.846 1552.96,865.845 1552.96,865.844 1552.95,865.843 1552.94,865.842 1552.93,865.841 1552.93,865.84 1552.92,865.839 1552.91,865.838 1552.9,865.837 1552.9,865.836 1552.89,865.835 1552.88,865.834 1552.87,865.833 1552.87,865.832 1552.86,865.831 1552.85,865.83 1552.84,865.829 1552.84,865.828 1552.83,865.827 1552.82,865.826 1552.81,865.825 1552.81,865.824 1552.8,865.823 1552.79,865.822 1552.78,865.821 1552.78,865.819 1552.77,865.818 1552.76,865.817 1552.75,865.816 1552.75,865.815 1552.74,865.814 1552.73,865.813 1552.72,865.812 1552.72,865.811 1552.71,865.81 1552.7,865.809 1552.69,865.808 1552.69,865.807 1552.68,865.806 1552.67,865.805 1552.66,865.804 1552.66,865.803 1552.65,865.802 1552.64,865.801 1552.63,865.8 1552.63,865.799 1552.62,865.798 1552.61,865.797 1552.6,865.796 1552.6,865.795 1552.59,865.794 1552.58,865.793 1552.57,865.792 1552.57,865.791 1552.56,865.79 1552.55,865.789 1552.54,865.788 1552.54,865.787 1552.53,865.786 1552.52,865.785 1552.52,865.784 1552.51,865.782 1552.5,865.781 1552.49,865.78 1552.49,865.779 1552.48,865.778 1552.47,865.777 1552.46,865.776 1552.46,865.775 1552.45,865.774 1552.44,865.773 1552.43,865.772 1552.43,865.771 1552.42,865.77 1552.41,865.769 1552.4,865.768 1552.4,865.767 1552.39,865.766 1552.38,865.765 1552.37,865.764 1552.37,865.763 1552.36,865.762 1552.35,865.761 1552.34,865.76 1552.34,865.759 1552.33,865.758 1552.32,865.757 1552.31,865.756 1552.31,865.755 1552.3,865.754 1552.29,865.753 1552.28,865.752 1552.28,865.751 1552.27,865.75 1552.26,865.749 1552.25,865.748 1552.25,865.747 1552.24,865.746 1552.23,865.745 1552.23,865.744 1552.22,865.743 1552.21,865.742 1552.2,865.741 1552.2,865.74 1552.19,865.739 1552.18,865.738 1552.17,865.737 1552.17,865.736 1552.16,865.735 1552.15,865.734 1552.14,865.733 1552.14,865.732 1552.13,865.731 1552.12,865.73 1552.11,865.729 1552.11,865.728 1552.1,865.727 1552.09,865.726 1552.08,865.724 1552.08,865.723 1552.07,865.722 1552.06,865.721 1552.05,865.72 1552.05,865.719 1552.04,865.718 1552.03,865.717 1552.02,865.716 1552.02,865.715 1552.01,865.714 1552,865.713 1551.99,865.712 1551.99,865.711 1551.98,865.71 1551.97,865.709 1551.97,865.708 1551.96,865.707 1551.95,865.706 1551.94,865.705 1551.94,865.704 1551.93,865.703 1551.92,865.702 1551.91,865.701 1551.91,865.7 1551.9,865.699 1551.89,865.698 1551.88,865.697 1551.88,865.696 1551.87,865.695 1551.86,865.694 1551.85,865.693 1551.85,865.692 1551.84,865.691 1551.83,865.69 1551.82,865.689 1551.82,865.688 1551.81,865.687 1551.8,865.686 1551.79,865.685 1551.79,865.684 1551.78,865.683 1551.77,865.682 1551.76,865.681 1551.76,865.68 1551.75,865.679 1551.74,865.678 1551.74,865.677 1551.73,865.676 1551.72,865.675 1551.71,865.674 1551.71,865.673 1551.7,865.672 1551.69,865.671 1551.68,865.67 1551.68,865.669 1551.67,865.668 1551.66,865.667 1551.65,865.666 1551.65,865.665 1551.64,865.664 1551.63,865.663 1551.62,865.662 1551.62,865.661 1551.61,865.66 1551.6,865.659 1551.59,865.658 1551.59,865.657 1551.58,865.656 1551.57,865.655 1551.56,865.654 1551.56,865.653 1551.55,865.652 1551.54,865.651 1551.54,865.65 1551.53,865.649 1551.52,865.648 1551.51,865.647 1551.51,865.646 1551.5,865.645 1551.49,865.644 1551.48,865.643 1551.48,865.642 1551.47,865.641 1551.46,865.64 1551.45,865.639 1551.45,865.638 1551.44,865.637 1551.43,865.636 1551.42,865.635 1551.42,865.634 1551.41,865.633 1551.4,865.632 1551.39,865.631 1551.39,865.63 1551.38,865.629 1551.37,865.628 1551.37,865.627 1551.36,865.626 1551.35,865.625 1551.34,865.624 1551.34,865.623 1551.33,865.622 1551.32,865.621 1551.31,865.62 1551.31,865.62 1551.3,865.619 1551.29,865.618 1551.28,865.617 1551.28,865.616 1551.27,865.615 1551.26,865.614 1551.25,865.613 1551.25,865.612 1551.24,865.611 1551.23,865.61 1551.22,865.609 1551.22,865.608 1551.21,865.607 1551.2,865.606 1551.2,865.605 1551.19,865.604 1551.18,865.603 1551.17,865.602 1551.17,865.601 1551.16,865.6 1551.15,865.599 1551.14,865.598 1551.14,865.597 1551.13,865.596 1551.12,865.595 1551.11,865.594 1551.11,865.593 1551.1,865.592 1551.09,865.591 1551.08,865.59 1551.08,865.589 1551.07,865.588 1551.06,865.587 1551.06,865.586 1551.05,865.585 1551.04,865.584 1551.03,865.583 1551.03,865.582 1551.02,865.581 1551.01,865.58 1551,865.579 1551,865.578 1550.99,865.577 1550.98,865.576 1550.97,865.575 1550.97,865.574 1550.96,865.573 1550.95,865.572 1550.94,865.571 1550.94,865.57 1550.93,865.569 1550.92,865.568 1550.92,865.567 1550.91,865.566 1550.9,865.565 1550.89,865.564 1550.89,865.564 1550.88,865.563 1550.87,865.562 1550.86,865.561 1550.86,865.56 1550.85,865.559 1550.84,865.558 1550.83,865.557 1550.83,865.556 1550.82,865.555 1550.81,865.554 1550.8,865.553 1550.8,865.552 1550.79,865.551 1550.78,865.55 1550.78,865.549 1550.77,865.548 1550.76,865.547 1550.75,865.546 1550.75,865.545 1550.74,865.544 1550.73,865.543 1550.72,865.542 1550.72,865.541 1550.71,865.54 1550.7,865.539 1550.69,865.538 1550.69,865.537 1550.68,865.536 1550.67,865.535 1550.66,865.534 1550.66,865.533 1550.65,865.532 1550.64,865.531 1550.64,865.53 1550.63,865.529 1550.62,865.528 1550.61,865.528 1550.61,865.527 1550.6,865.526 1550.59,865.525 1550.58,865.524 1550.58,865.523 1550.57,865.522 1550.56,865.521 1550.55,865.52 1550.55,865.519 1550.54,865.518 1550.53,865.517 1550.53,865.516 1550.52,865.515 1550.51,865.514 1550.5,865.513 1550.5,865.512 1550.49,865.511 1550.48,865.51 1550.47,865.509 1550.47,865.508 1550.46,865.507 1550.45,865.506 1550.44,865.505 1550.44,865.504 1550.43,865.503 1550.42,865.502 1550.42,865.501 1550.41,865.501 1550.4,865.5 1550.39,865.499 1550.39,865.498 1550.38,865.497 1550.37,865.496 1550.36,865.495 1550.36,865.494 1550.35,865.493 1550.34,865.492 1550.33,865.491 1550.33,865.49 1550.32,865.489 1550.31,865.488 1550.3,865.487 1550.3,865.486 1550.29,865.485 1550.28,865.484 1550.28,865.483 1550.27,865.482 1550.26,865.481 1550.25,865.48 1550.25,865.479 1550.24,865.478 1550.23,865.477 1550.22,865.477 1550.22,865.476 1550.21,865.475 1550.2,865.474 1550.19,865.473 1550.19,865.472 1550.18,865.471 1550.17,865.47 1550.17,865.469 1550.16,865.468 1550.15,865.467 1550.14,865.466 1550.14,865.465 1550.13,865.464 1550.12,865.463 1550.11,865.462 1550.11,865.461 1550.1,865.46 1550.09,865.459 1550.09,865.458 1550.08,865.457 1550.07,865.456 1550.06,865.456 1550.06,865.455 1550.05,865.454 1550.04,865.453 1550.03,865.452 1550.03,865.451 1550.02,865.45 1550.01,865.449 1550,865.448 1550,865.447 1549.99,865.446 1549.98,865.445 1549.98,865.444 1549.97,865.443 1549.96,865.442 1549.95,865.441 1549.95,865.44 1549.94,865.439 1549.93,865.438 1549.92,865.437 1549.92,865.437 1549.91,865.436 1549.9,865.435 1549.89,865.434 1549.89,865.433 1549.88,865.432 1549.87,865.431 1549.87,865.43 1549.86,865.429 1549.85,865.428 1549.84,865.427 1549.84,865.426 1549.83,865.425 1549.82,865.424 1549.81,865.423 1549.81,865.422 1549.8,865.421 1549.79,865.42 1549.79,865.419 1549.78,865.419 1549.77,865.418 1549.76,865.417 1549.76,865.416 1549.75,865.415 1549.74,865.414 1549.73,865.413 1549.73,865.412 1549.72,865.411 1549.71,865.41 1549.7,865.409 1549.7,865.408 1549.69,865.407 1549.68,865.406 1549.68,865.405 1549.67,865.404 1549.66,865.403 1549.65,865.403 1549.65,865.402 1549.64,865.401 1549.63,865.4 1549.62,865.399 1549.62,865.398 1549.61,865.397 1549.6,865.396 1549.6,865.395 1549.59,865.394 1549.58,865.393 1549.57,865.392 1549.57,865.391 1549.56,865.39 1549.55,865.389 1549.54,865.388 1549.54,865.388 1549.53,865.387 1549.52,865.386 1549.51,865.385 1549.51,865.384 1549.5,865.383 1549.49,865.382 1549.49,865.381 1549.48,865.38 1549.47,865.379 1549.46,865.378 1549.46,865.377 1549.45,865.376 1549.44,865.375 1549.43,865.374 1549.43,865.373 1549.42,865.373 1549.41,865.372 1549.41,865.371 1549.4,865.37 1549.39,865.369 1549.38,865.368 1549.38,865.367 1549.37,865.366 1549.36,865.365 1549.35,865.364 1549.35,865.363 1549.34,865.362 1549.33,865.361 1549.33,865.36 1549.32,865.36 1549.31,865.359 1549.3,865.358 1549.3,865.357 1549.29,865.356 1549.28,865.355 1549.27,865.354 1549.27,865.353 1549.26,865.352 1549.25,865.351 1549.25,865.35 1549.24,865.349 1549.23,865.348 1549.22,865.347 1549.22,865.347 1549.21,865.346 1549.2,865.345 1549.19,865.344 1549.19,865.343 1549.18,865.342 1549.17,865.341 1549.16,865.34 1549.16,865.339 1549.15,865.338 1549.14,865.337 1549.14,865.336 1549.13,865.335 1549.12,865.334 1549.11,865.334 1549.11,865.333 1549.1,865.332 1549.09,865.331 1549.08,865.33 1549.08,865.329 1549.07,865.328 1549.06,865.327 1549.06,865.326 1549.05,865.325 1549.04,865.324 1549.03,865.323 1549.03,865.322 1549.02,865.322 1549.01,865.321 1549,865.32 1549,865.319 1548.99,865.318 1548.98,865.317 1548.98,865.316 1548.97,865.315 1548.96,865.314 1548.95,865.313 1548.95,865.312 1548.94,865.311 1548.93,865.311 1548.92,865.31 1548.92,865.309 1548.91,865.308 1548.9,865.307 1548.9,865.306 1548.89,865.305 1548.88,865.304 1548.87,865.303 1548.87,865.302 1548.86,865.301 1548.85,865.3 1548.85,865.3 1548.84,865.299 1548.83,865.298 1548.82,865.297 1548.82,865.296 1548.81,865.295 1548.8,865.294 1548.79,865.293 1548.79,865.292 1548.78,865.291 1548.77,865.29 1548.77,865.289 1548.76,865.289 1548.75,865.288 1548.74,865.287 1548.74,865.286 1548.73,865.285 1548.72,865.284 1548.71,865.283 1548.71,865.282 1548.7,865.281 1548.69,865.28 1548.69,865.279 1548.68,865.279 1548.67,865.278 1548.66,865.277 1548.66,865.276 1548.65,865.275 1548.64,865.274 1548.63,865.273 1548.63,865.272 1548.62,865.271 1548.61,865.27 1548.61,865.269 1548.6,865.269 1548.59,865.268 1548.58,865.267 1548.58,865.266 1548.57,865.265 1548.56,865.264 1548.55,865.263 1548.55,865.262 1548.54,865.261 1548.53,865.26 1548.53,865.259 1548.52,865.259 1548.51,865.258 1548.5,865.257 1548.5,865.256 1548.49,865.255 1548.48,865.254 1548.48,865.253 1548.47,865.252 1548.46,865.251 1548.45,865.25 1548.45,865.249 1548.44,865.249 1548.43,865.248 1548.42,865.247 1548.42,865.246 1548.41,865.245 1548.4,865.244 1548.4,865.243 1548.39,865.242 1548.38,865.241 1548.37,865.24 1548.37,865.24 1548.36,865.239 1548.35,865.238 1548.34,865.237 1548.34,865.236 1548.33,865.235 1548.32,865.234 1548.32,865.233 1548.31,865.232 1548.3,865.231 1548.29,865.231 1548.29,865.23 1548.28,865.229 1548.27,865.228 1548.27,865.227 1548.26,865.226 1548.25,865.225 1548.24,865.224 1548.24,865.223 1548.23,865.222 1548.22,865.222 1548.21,865.221 1548.21,865.22 1548.2,865.219 1548.19,865.218 1548.19,865.217 1548.18,865.216 1548.17,865.215 1548.16,865.214 1548.16,865.213 1548.15,865.213 1548.14,865.212 1548.13,865.211 1548.13,865.21 1548.12,865.209 1548.11,865.208 1548.11,865.207 1548.1,865.206 1548.09,865.205 1548.08,865.205 1548.08,865.204 1548.07,865.203 1548.06,865.202 1548.06,865.201 1548.05,865.2 1548.04,865.199 1548.03,865.198 1548.03,865.197 1548.02,865.197 1548.01,865.196 1548,865.195 1548,865.194 1547.99,865.193 1547.98,865.192 1547.98,865.191 1547.97,865.19 1547.96,865.189 1547.95,865.189 1547.95,865.188 1547.94,865.187 1547.93,865.186 1547.93,865.185 1547.92,865.184 1547.91,865.183 1547.9,865.182 1547.9,865.181 1547.89,865.181 1547.88,865.18 1547.87,865.179 1547.87,865.178 1547.86,865.177 1547.85,865.176 1547.85,865.175 1547.84,865.174 1547.83,865.173 1547.82,865.173 1547.82,865.172 1547.81,865.171 1547.8,865.17 1547.8,865.169 1547.79,865.168 1547.78,865.167 1547.77,865.166 1547.77,865.165 1547.76,865.165 1547.75,865.164 1547.75,865.163 1547.74,865.162 1547.73,865.161 1547.72,865.16 1547.72,865.159 1547.71,865.158 1547.7,865.158 1547.69,865.157 1547.69,865.156 1547.68,865.155 1547.67,865.154 1547.67,865.153 1547.66,865.152 1547.65,865.151 1547.64,865.15 1547.64,865.15 1547.63,865.149 1547.62,865.148 1547.62,865.147 1547.61,865.146 1547.6,865.145 1547.59,865.144 1547.59,865.143 1547.58,865.143 1547.57,865.142 1547.57,865.141 1547.56,865.14 1547.55,865.139 1547.54,865.138 1547.54,865.137 1547.53,865.136 1547.52,865.136 1547.51,865.135 1547.51,865.134 1547.5,865.133 1547.49,865.132 1547.49,865.131 1547.48,865.13 1547.47,865.129 1547.46,865.129 1547.46,865.128 1547.45,865.127 1547.44,865.126 1547.44,865.125 1547.43,865.124 1547.42,865.123 1547.41,865.122 1547.41,865.122 1547.4,865.121 1547.39,865.12 1547.39,865.119 1547.38,865.118 1547.37,865.117 1547.36,865.116 1547.36,865.115 1547.35,865.115 1547.34,865.114 1547.33,865.113 1547.33,865.112 1547.32,865.111 1547.31,865.11 1547.31,865.109 1547.3,865.108 1547.29,865.108 1547.28,865.107 1547.28,865.106 1547.27,865.105 1547.26,865.104 1547.26,865.103 1547.25,865.102 1547.24,865.102 1547.23,865.101 1547.23,865.1 1547.22,865.099 1547.21,865.098 1547.21,865.097 1547.2,865.096 1547.19,865.095 1547.18,865.095 1547.18,865.094 1547.17,865.093 1547.16,865.092 1547.16,865.091 1547.15,865.09 1547.14,865.089 1547.13,865.089 1547.13,865.088 1547.12,865.087 1547.11,865.086 1547.11,865.085 1547.1,865.084 1547.09,865.083 1547.08,865.082 1547.08,865.082 1547.07,865.081 1547.06,865.08 1547.05,865.079 1547.05,865.078 1547.04,865.077 1547.03,865.076 1547.03,865.076 1547.02,865.075 1547.01,865.074 1547,865.073 1547,865.072 1546.99,865.071 1546.98,865.07 1546.98,865.07 1546.97,865.069 1546.96,865.068 1546.95,865.067 1546.95,865.066 1546.94,865.065 1546.93,865.064 1546.93,865.064 1546.92,865.063 1546.91,865.062 1546.9,865.061 1546.9,865.06 1546.89,865.059 1546.88,865.058 1546.88,865.058 1546.87,865.057 1546.86,865.056 1546.85,865.055 1546.85,865.054 1546.84,865.053 1546.83,865.052 1546.83,865.052 1546.82,865.051 1546.81,865.05 1546.8,865.049 1546.8,865.048 1546.79,865.047 1546.78,865.046 1546.78,865.046 1546.77,865.045 1546.76,865.044 1546.75,865.043 1546.75,865.042 1546.74,865.041 1546.73,865.04 1546.73,865.04 1546.72,865.039 1546.71,865.038 1546.7,865.037 1546.7,865.036 1546.69,865.035 1546.68,865.035 1546.68,865.034 1546.67,865.033 1546.66,865.032 1546.65,865.031 1546.65,865.03 1546.64,865.029 1546.63,865.029 1546.63,865.028 1546.62,865.027 1546.61,865.026 1546.6,865.025 1546.6,865.024 1546.59,865.023 1546.58,865.023 1546.58,865.022 1546.57,865.021 1546.56,865.02 1546.55,865.019 1546.55,865.018 1546.54,865.018 1546.53,865.017 1546.52,865.016 1546.52,865.015 1546.51,865.014 1546.5,865.013 1546.5,865.012 1546.49,865.012 1546.48,865.011 1546.47,865.01 1546.47,865.009 1546.46,865.008 1546.45,865.007 1546.45,865.007 1546.44,865.006 1546.43,865.005 1546.42,865.004 1546.42,865.003 1546.41,865.002 1546.4,865.001 1546.4,865.001 1546.39,865 1546.38,864.999 1546.37,864.998 1546.37,864.997 1546.36,864.996 1546.35,864.996 1546.35,864.995 1546.34,864.994 1546.33,864.993 1546.32,864.992 1546.32,864.991 1546.31,864.991 1546.3,864.99 1546.3,864.989 1546.29,864.988 1546.28,864.987 1546.28,864.986 1546.27,864.986 1546.26,864.985 1546.25,864.984 1546.25,864.983 1546.24,864.982 1546.23,864.981 1546.23,864.981 1546.22,864.98 1546.21,864.979 1546.2,864.978 1546.2,864.977 1546.19,864.976 1546.18,864.975 1546.18,864.975 1546.17,864.974 1546.16,864.973 1546.15,864.972 1546.15,864.971 1546.14,864.97 1546.13,864.97 1546.13,864.969 1546.12,864.968 1546.11,864.967 1546.1,864.966 1546.1,864.965 1546.09,864.965 1546.08,864.964 1546.08,864.963 1546.07,864.962 1546.06,864.961 1546.05,864.96 1546.05,864.96 1546.04,864.959 1546.03,864.958 1546.03,864.957 1546.02,864.956 1546.01,864.956 1546,864.955 1546,864.954 1545.99,864.953 1545.98,864.952 1545.98,864.951 1545.97,864.951 1545.96,864.95 1545.95,864.949 1545.95,864.948 1545.94,864.947 1545.93,864.946 1545.93,864.946 1545.92,864.945 1545.91,864.944 1545.9,864.943 1545.9,864.942 1545.89,864.941 1545.88,864.941 1545.88,864.94 1545.87,864.939 1545.86,864.938 1545.85,864.937 1545.85,864.936 1545.84,864.936 1545.83,864.935 1545.83,864.934 1545.82,864.933 1545.81,864.932 1545.8,864.932 1545.8,864.931 1545.79,864.93 1545.78,864.929 1545.78,864.928 1545.77,864.927 1545.76,864.927 1545.76,864.926 1545.75,864.925 1545.74,864.924 1545.73,864.923 1545.73,864.922 1545.72,864.922 1545.71,864.921 1545.71,864.92 1545.7,864.919 1545.69,864.918 1545.68,864.918 1545.68,864.917 1545.67,864.916 1545.66,864.915 1545.66,864.914 1545.65,864.913 1545.64,864.913 1545.63,864.912 1545.63,864.911 1545.62,864.91 1545.61,864.909 1545.61,864.909 1545.6,864.908 1545.59,864.907 1545.58,864.906 1545.58,864.905 1545.57,864.904 1545.56,864.904 1545.56,864.903 1545.55,864.902 1545.54,864.901 1545.53,864.9 1545.53,864.9 1545.52,864.899 1545.51,864.898 1545.51,864.897 1545.5,864.896 1545.49,864.895 1545.49,864.895 1545.48,864.894 1545.47,864.893 1545.46,864.892 1545.46,864.891 1545.45,864.891 1545.44,864.89 1545.44,864.889 1545.43,864.888 1545.42,864.887 1545.41,864.887 1545.41,864.886 1545.4,864.885 1545.39,864.884 1545.39,864.883 1545.38,864.882 1545.37,864.882 1545.36,864.881 1545.36,864.88 1545.35,864.879 1545.34,864.878 1545.34,864.878 1545.33,864.877 1545.32,864.876 1545.32,864.875 1545.31,864.874 1545.3,864.874 1545.29,864.873 1545.29,864.872 1545.28,864.871 1545.27,864.87 1545.27,864.87 1545.26,864.869 1545.25,864.868 1545.24,864.867 1545.24,864.866 1545.23,864.866 1545.22,864.865 1545.22,864.864 1545.21,864.863 1545.2,864.862 1545.19,864.861 1545.19,864.861 1545.18,864.86 1545.17,864.859 1545.17,864.858 1545.16,864.857 1545.15,864.857 1545.15,864.856 1545.14,864.855 1545.13,864.854 1545.12,864.853 1545.12,864.853 1545.11,864.852 1545.1,864.851 1545.1,864.85 1545.09,864.849 1545.08,864.849 1545.07,864.848 1545.07,864.847 1545.06,864.846 1545.05,864.845 1545.05,864.845 1545.04,864.844 1545.03,864.843 1545.02,864.842 1545.02,864.841 1545.01,864.841 1545,864.84 1545,864.839 1544.99,864.838 1544.98,864.837 1544.98,864.837 1544.97,864.836 1544.96,864.835 1544.95,864.834 1544.95,864.833 1544.94,864.833 1544.93,864.832 1544.93,864.831 1544.92,864.83 1544.91,864.829 1544.9,864.829 1544.9,864.828 1544.89,864.827 1544.88,864.826 1544.88,864.825 1544.87,864.825 1544.86,864.824 1544.86,864.823 1544.85,864.822 1544.84,864.822 1544.83,864.821 1544.83,864.82 1544.82,864.819 1544.81,864.818 1544.81,864.818 1544.8,864.817 1544.79,864.816 1544.78,864.815 1544.78,864.814 1544.77,864.814 1544.76,864.813 1544.76,864.812 1544.75,864.811 1544.74,864.81 1544.74,864.81 1544.73,864.809 1544.72,864.808 1544.71,864.807 1544.71,864.806 1544.7,864.806 1544.69,864.805 1544.69,864.804 1544.68,864.803 1544.67,864.803 1544.66,864.802 1544.66,864.801 1544.65,864.8 1544.64,864.799 1544.64,864.799 1544.63,864.798 1544.62,864.797 1544.62,864.796 1544.61,864.795 1544.6,864.795 1544.59,864.794 1544.59,864.793 1544.58,864.792 1544.57,864.792 1544.57,864.791 1544.56,864.79 1544.55,864.789 1544.54,864.788 1544.54,864.788 1544.53,864.787 1544.52,864.786 1544.52,864.785 1544.51,864.784 1544.5,864.784 1544.5,864.783 1544.49,864.782 1544.48,864.781 1544.47,864.781 1544.47,864.78 1544.46,864.779 1544.45,864.778 1544.45,864.777 1544.44,864.777 1544.43,864.776 1544.42,864.775 1544.42,864.774 1544.41,864.773 1544.4,864.773 1544.4,864.772 1544.39,864.771 1544.38,864.77 1544.38,864.77 1544.37,864.769 1544.36,864.768 1544.35,864.767 1544.35,864.766 1544.34,864.766 1544.33,864.765 1544.33,864.764 1544.32,864.763 1544.31,864.763 1544.31,864.762 1544.3,864.761 1544.29,864.76 1544.28,864.759 1544.28,864.759 1544.27,864.758 1544.26,864.757 1544.26,864.756 1544.25,864.756 1544.24,864.755 1544.23,864.754 1544.23,864.753 1544.22,864.753 1544.21,864.752 1544.21,864.751 1544.2,864.75 1544.19,864.749 1544.19,864.749 1544.18,864.748 1544.17,864.747 1544.16,864.746 1544.16,864.746 1544.15,864.745 1544.14,864.744 1544.14,864.743 1544.13,864.742 1544.12,864.742 1544.12,864.741 1544.11,864.74 1544.1,864.739 1544.09,864.739 1544.09,864.738 1544.08,864.737 1544.07,864.736 1544.07,864.736 1544.06,864.735 1544.05,864.734 1544.05,864.733 1544.04,864.732 1544.03,864.732 1544.02,864.731 1544.02,864.73 1544.01,864.729 1544,864.729 1544,864.728 1543.99,864.727 1543.98,864.726 1543.97,864.726 1543.97,864.725 1543.96,864.724 1543.95,864.723 1543.95,864.722 1543.94,864.722 1543.93,864.721 1543.93,864.72 1543.92,864.719 1543.91,864.719 1543.9,864.718 1543.9,864.717 1543.89,864.716 1543.88,864.716 1543.88,864.715 1543.87,864.714 1543.86,864.713 1543.86,864.713 1543.85,864.712 1543.84,864.711 1543.83,864.71 1543.83,864.709 1543.82,864.709 1543.81,864.708 1543.81,864.707 1543.8,864.706 1543.79,864.706 1543.79,864.705 1543.78,864.704 1543.77,864.703 1543.76,864.703 1543.76,864.702 1543.75,864.701 1543.74,864.7 1543.74,864.7 1543.73,864.699 1543.72,864.698 1543.72,864.697 1543.71,864.697 1543.7,864.696 1543.69,864.695 1543.69,864.694 1543.68,864.694 1543.67,864.693 1543.67,864.692 1543.66,864.691 1543.65,864.691 1543.65,864.69 1543.64,864.689 1543.63,864.688 1543.62,864.687 1543.62,864.687 1543.61,864.686 1543.6,864.685 1543.6,864.684 1543.59,864.684 1543.58,864.683 1543.58,864.682 1543.57,864.681 1543.56,864.681 1543.55,864.68 1543.55,864.679 1543.54,864.678 1543.53,864.678 1543.53,864.677 1543.52,864.676 1543.51,864.675 1543.51,864.675 1543.5,864.674 1543.49,864.673 1543.48,864.672 1543.48,864.672 1543.47,864.671 1543.46,864.67 1543.46,864.669 1543.45,864.669 1543.44,864.668 1543.44,864.667 1543.43,864.666 1543.42,864.666 1543.41,864.665 1543.41,864.664 1543.4,864.663 1543.39,864.663 1543.39,864.662 1543.38,864.661 1543.37,864.66 1543.37,864.66 1543.36,864.659 1543.35,864.658 1543.34,864.657 1543.34,864.657 1543.33,864.656 1543.32,864.655 1543.32,864.654 1543.31,864.654 1543.3,864.653 1543.3,864.652 1543.29,864.651 1543.28,864.651 1543.27,864.65 1543.27,864.649 1543.26,864.648 1543.25,864.648 1543.25,864.647 1543.24,864.646 1543.23,864.646 1543.23,864.645 1543.22,864.644 1543.21,864.643 1543.2,864.643 1543.2,864.642 1543.19,864.641 1543.18,864.64 1543.18,864.64 1543.17,864.639 1543.16,864.638 1543.16,864.637 1543.15,864.637 1543.14,864.636 1543.14,864.635 1543.13,864.634 1543.12,864.634 1543.11,864.633 1543.11,864.632 1543.1,864.631 1543.09,864.631 1543.09,864.63 1543.08,864.629 1543.07,864.628 1543.07,864.628 1543.06,864.627 1543.05,864.626 1543.04,864.626 1543.04,864.625 1543.03,864.624 1543.02,864.623 1543.02,864.623 1543.01,864.622 1543,864.621 1543,864.62 1542.99,864.62 1542.98,864.619 1542.97,864.618 1542.97,864.617 1542.96,864.617 1542.95,864.616 1542.95,864.615 1542.94,864.615 1542.93,864.614 1542.93,864.613 1542.92,864.612 1542.91,864.612 1542.91,864.611 1542.9,864.61 1542.89,864.609 1542.88,864.609 1542.88,864.608 1542.87,864.607 1542.86,864.606 1542.86,864.606 1542.85,864.605 1542.84,864.604 1542.84,864.604 1542.83,864.603 1542.82,864.602 1542.81,864.601 1542.81,864.601 1542.8,864.6 1542.79,864.599 1542.79,864.598 1542.78,864.598 1542.77,864.597 1542.77,864.596 1542.76,864.596 1542.75,864.595 1542.74,864.594 1542.74,864.593 1542.73,864.593 1542.72,864.592 1542.72,864.591 1542.71,864.59 1542.7,864.59 1542.7,864.589 1542.69,864.588 1542.68,864.588 1542.68,864.587 1542.67,864.586 1542.66,864.585 1542.65,864.585 1542.65,864.584 1542.64,864.583 1542.63,864.582 1542.63,864.582 1542.62,864.581 1542.61,864.58 1542.61,864.58 1542.6,864.579 1542.59,864.578 1542.58,864.577 1542.58,864.577 1542.57,864.576 1542.56,864.575 1542.56,864.575 1542.55,864.574 1542.54,864.573 1542.54,864.572 1542.53,864.572 1542.52,864.571 1542.52,864.57 1542.51,864.569 1542.5,864.569 1542.49,864.568 1542.49,864.567 1542.48,864.567 1542.47,864.566 1542.47,864.565 1542.46,864.564 1542.45,864.564 1542.45,864.563 1542.44,864.562 1542.43,864.562 1542.43,864.561 1542.42,864.56 1542.41,864.559 1542.4,864.559 1542.4,864.558 1542.39,864.557 1542.38,864.557 1542.38,864.556 1542.37,864.555 1542.36,864.554 1542.36,864.554 1542.35,864.553 1542.34,864.552 1542.33,864.552 1542.33,864.551 1542.32,864.55 1542.31,864.549 1542.31,864.549 1542.3,864.548 1542.29,864.547 1542.29,864.547 1542.28,864.546 1542.27,864.545 1542.27,864.544 1542.26,864.544 1542.25,864.543 1542.24,864.542 1542.24,864.542 1542.23,864.541 1542.22,864.54 1542.22,864.539 1542.21,864.539 1542.2,864.538 1542.2,864.537 1542.19,864.537 1542.18,864.536 1542.18,864.535 1542.17,864.534 1542.16,864.534 1542.15,864.533 1542.15,864.532 1542.14,864.532 1542.13,864.531 1542.13,864.53 1542.12,864.53 1542.11,864.529 1542.11,864.528 1542.1,864.527 1542.09,864.527 1542.09,864.526 1542.08,864.525 1542.07,864.525 1542.06,864.524 1542.06,864.523 1542.05,864.522 1542.04,864.522 1542.04,864.521 1542.03,864.52 1542.02,864.52 1542.02,864.519 1542.01,864.518 1542,864.518 1542,864.517 1541.99,864.516 1541.98,864.515 1541.97,864.515 1541.97,864.514 1541.96,864.513 1541.95,864.513 1541.95,864.512 1541.94,864.511 1541.93,864.51 1541.93,864.51 1541.92,864.509 1541.91,864.508 1541.91,864.508 1541.9,864.507 1541.89,864.506 1541.88,864.506 1541.88,864.505 1541.87,864.504 1541.86,864.504 1541.86,864.503 1541.85,864.502 1541.84,864.501 1541.84,864.501 1541.83,864.5 1541.82,864.499 1541.82,864.499 1541.81,864.498 1541.8,864.497 1541.79,864.497 1541.79,864.496 1541.78,864.495 1541.77,864.494 1541.77,864.494 1541.76,864.493 1541.75,864.492 1541.75,864.492 1541.74,864.491 1541.73,864.49 1541.73,864.49 1541.72,864.489 1541.71,864.488 1541.71,864.487 1541.7,864.487 1541.69,864.486 1541.68,864.485 1541.68,864.485 1541.67,864.484 1541.66,864.483 1541.66,864.483 1541.65,864.482 1541.64,864.481 1541.64,864.481 1541.63,864.48 1541.62,864.479 1541.62,864.478 1541.61,864.478 1541.6,864.477 1541.59,864.476 1541.59,864.476 1541.58,864.475 1541.57,864.474 1541.57,864.474 1541.56,864.473 1541.55,864.472 1541.55,864.472 1541.54,864.471 1541.53,864.47 1541.53,864.47 1541.52,864.469 1541.51,864.468 1541.5,864.467 1541.5,864.467 1541.49,864.466 1541.48,864.465 1541.48,864.465 1541.47,864.464 1541.46,864.463 1541.46,864.463 1541.45,864.462 1541.44,864.461 1541.44,864.461 1541.43,864.46 1541.42,864.459 1541.42,864.459 1541.41,864.458 1541.4,864.457 1541.39,864.457 1541.39,864.456 1541.38,864.455 1541.37,864.454 1541.37,864.454 1541.36,864.453 1541.35,864.452 1541.35,864.452 1541.34,864.451 1541.33,864.45 1541.33,864.45 1541.32,864.449 1541.31,864.448 1541.31,864.448 1541.3,864.447 1541.29,864.446 1541.28,864.446 1541.28,864.445 1541.27,864.444 1541.26,864.444 1541.26,864.443 1541.25,864.442 1541.24,864.442 1541.24,864.441 1541.23,864.44 1541.22,864.44 1541.22,864.439 1541.21,864.438 1541.2,864.437 1541.19,864.437 1541.19,864.436 1541.18,864.435 1541.17,864.435 1541.17,864.434 1541.16,864.433 1541.15,864.433 1541.15,864.432 1541.14,864.431 1541.13,864.431 1541.13,864.43 1541.12,864.429 1541.11,864.429 1541.11,864.428 1541.1,864.427 1541.09,864.427 1541.08,864.426 1541.08,864.425 1541.07,864.425 1541.06,864.424 1541.06,864.423 1541.05,864.423 1541.04,864.422 1541.04,864.421 1541.03,864.421 1541.02,864.42 1541.02,864.419 1541.01,864.419 1541,864.418 1541,864.417 1540.99,864.417 1540.98,864.416 1540.97,864.415 1540.97,864.415 1540.96,864.414 1540.95,864.413 1540.95,864.413 1540.94,864.412 1540.93,864.411 1540.93,864.411 1540.92,864.41 1540.91,864.409 1540.91,864.409 1540.9,864.408 1540.89,864.407 1540.89,864.407 1540.88,864.406 1540.87,864.405 1540.87,864.405 1540.86,864.404 1540.85,864.403 1540.84,864.403 1540.84,864.402 1540.83,864.401 1540.82,864.401 1540.82,864.4 1540.81,864.399 1540.8,864.399 1540.8,864.398 1540.79,864.397 1540.78,864.397 1540.78,864.396 1540.77,864.395 1540.76,864.395 1540.76,864.394 1540.75,864.393 1540.74,864.393 1540.73,864.392 1540.73,864.391 1540.72,864.391 1540.71,864.39 1540.71,864.389 1540.7,864.389 1540.69,864.388 1540.69,864.387 1540.68,864.387 1540.67,864.386 1540.67,864.385 1540.66,864.385 1540.65,864.384 1540.65,864.383 1540.64,864.383 1540.63,864.382 1540.63,864.381 1540.62,864.381 1540.61,864.38 1540.6,864.379 1540.6,864.379 1540.59,864.378 1540.58,864.377 1540.58,864.377 1540.57,864.376 1540.56,864.376 1540.56,864.375 1540.55,864.374 1540.54,864.374 1540.54,864.373 1540.53,864.372 1540.52,864.372 1540.52,864.371 1540.51,864.37 1540.5,864.37 1540.49,864.369 1540.49,864.368 1540.48,864.368 1540.47,864.367 1540.47,864.366 1540.46,864.366 1540.45,864.365 1540.45,864.364 1540.44,864.364 1540.43,864.363 1540.43,864.362 1540.42,864.362 1540.41,864.361 1540.41,864.361 1540.4,864.36 1540.39,864.359 1540.39,864.359 1540.38,864.358 1540.37,864.357 1540.36,864.357 1540.36,864.356 1540.35,864.355 1540.34,864.355 1540.34,864.354 1540.33,864.353 1540.32,864.353 1540.32,864.352 1540.31,864.351 1540.3,864.351 1540.3,864.35 1540.29,864.349 1540.28,864.349 1540.28,864.348 1540.27,864.348 1540.26,864.347 1540.26,864.346 1540.25,864.346 1540.24,864.345 1540.24,864.344 1540.23,864.344 1540.22,864.343 1540.21,864.342 1540.21,864.342 1540.2,864.341 1540.19,864.34 1540.19,864.34 1540.18,864.339 1540.17,864.339 1540.17,864.338 1540.16,864.337 1540.15,864.337 1540.15,864.336 1540.14,864.335 1540.13,864.335 1540.13,864.334 1540.12,864.333 1540.11,864.333 1540.11,864.332 1540.1,864.331 1540.09,864.331 1540.08,864.33 1540.08,864.33 1540.07,864.329 1540.06,864.328 1540.06,864.328 1540.05,864.327 1540.04,864.326 1540.04,864.326 1540.03,864.325 1540.02,864.324 1540.02,864.324 1540.01,864.323 1540,864.323 1540,864.322 1539.99,864.321 1539.98,864.321 1539.98,864.32 1539.97,864.319 1539.96,864.319 1539.96,864.318 1539.95,864.317 1539.94,864.317 1539.93,864.316 1539.93,864.316 1539.92,864.315 1539.91,864.314 1539.91,864.314 1539.9,864.313 1539.89,864.312 1539.89,864.312 1539.88,864.311 1539.87,864.31 1539.87,864.31 1539.86,864.309 1539.85,864.309 1539.85,864.308 1539.84,864.307 1539.83,864.307 1539.83,864.306 1539.82,864.305 1539.81,864.305 1539.81,864.304 1539.8,864.304 1539.79,864.303 1539.78,864.302 1539.78,864.302 1539.77,864.301 1539.76,864.3 1539.76,864.3 1539.75,864.299 1539.74,864.299 1539.74,864.298 1539.73,864.297 1539.72,864.297 1539.72,864.296 1539.71,864.295 1539.7,864.295 1539.7,864.294 1539.69,864.294 1539.68,864.293 1539.68,864.292 1539.67,864.292 1539.66,864.291 1539.66,864.29 1539.65,864.29 1539.64,864.289 1539.64,864.289 1539.63,864.288 1539.62,864.287 1539.61,864.287 1539.61,864.286 1539.6,864.285 1539.59,864.285 1539.59,864.284 1539.58,864.284 1539.57,864.283 1539.57,864.282 1539.56,864.282 1539.55,864.281 1539.55,864.28 1539.54,864.28 1539.53,864.279 1539.53,864.279 1539.52,864.278 1539.51,864.277 1539.51,864.277 1539.5,864.276 1539.49,864.275 1539.49,864.275 1539.48,864.274 1539.47,864.274 1539.47,864.273 1539.46,864.272 1539.45,864.272 1539.44,864.271 1539.44,864.271 1539.43,864.27 1539.42,864.269 1539.42,864.269 1539.41,864.268 1539.4,864.267 1539.4,864.267 1539.39,864.266 1539.38,864.266 1539.38,864.265 1539.37,864.264 1539.36,864.264 1539.36,864.263 1539.35,864.263 1539.34,864.262 1539.34,864.261 1539.33,864.261 1539.32,864.26 1539.32,864.259 1539.31,864.259 1539.3,864.258 1539.3,864.258 1539.29,864.257 1539.28,864.256 1539.28,864.256 1539.27,864.255 1539.26,864.255 1539.25,864.254 1539.25,864.253 1539.24,864.253 1539.23,864.252 1539.23,864.251 1539.22,864.251 1539.21,864.25 1539.21,864.25 1539.2,864.249 1539.19,864.248 1539.19,864.248 1539.18,864.247 1539.17,864.247 1539.17,864.246 1539.16,864.245 1539.15,864.245 1539.15,864.244 1539.14,864.244 1539.13,864.243 1539.13,864.242 1539.12,864.242 1539.11,864.241 1539.11,864.241 1539.1,864.24 1539.09,864.239 1539.09,864.239 1539.08,864.238 1539.07,864.238 1539.06,864.237 1539.06,864.236 1539.05,864.236 1539.04,864.235 1539.04,864.235 1539.03,864.234 1539.02,864.233 1539.02,864.233 1539.01,864.232 1539,864.231 1539,864.231 1538.99,864.23 1538.98,864.23 1538.98,864.229 1538.97,864.228 1538.96,864.228 1538.96,864.227 1538.95,864.227 1538.94,864.226 1538.94,864.225 1538.93,864.225 1538.92,864.224 1538.92,864.224 1538.91,864.223 1538.9,864.222 1538.9,864.222 1538.89,864.221 1538.88,864.221 1538.88,864.22 1538.87,864.219 1538.86,864.219 1538.86,864.218 1538.85,864.218 1538.84,864.217 1538.83,864.217 1538.83,864.216 1538.82,864.215 1538.81,864.215 1538.81,864.214 1538.8,864.214 1538.79,864.213 1538.79,864.212 1538.78,864.212 1538.77,864.211 1538.77,864.211 1538.76,864.21 1538.75,864.209 1538.75,864.209 1538.74,864.208 1538.73,864.208 1538.73,864.207 1538.72,864.206 1538.71,864.206 1538.71,864.205 1538.7,864.205 1538.69,864.204 1538.69,864.203 1538.68,864.203 1538.67,864.202 1538.67,864.202 1538.66,864.201 1538.65,864.2 1538.65,864.2 1538.64,864.199 1538.63,864.199 1538.63,864.198 1538.62,864.198 1538.61,864.197 1538.61,864.196 1538.6,864.196 1538.59,864.195 1538.58,864.195 1538.58,864.194 1538.57,864.193 1538.56,864.193 1538.56,864.192 1538.55,864.192 1538.54,864.191 1538.54,864.191 1538.53,864.19 1538.52,864.189 1538.52,864.189 1538.51,864.188 1538.5,864.188 1538.5,864.187 1538.49,864.186 1538.48,864.186 1538.48,864.185 1538.47,864.185 1538.46,864.184 1538.46,864.183 1538.45,864.183 1538.44,864.182 1538.44,864.182 1538.43,864.181 1538.42,864.181 1538.42,864.18 1538.41,864.179 1538.4,864.179 1538.4,864.178 1538.39,864.178 1538.38,864.177 1538.38,864.177 1538.37,864.176 1538.36,864.175 1538.36,864.175 1538.35,864.174 1538.34,864.174 1538.34,864.173 1538.33,864.172 1538.32,864.172 1538.32,864.171 1538.31,864.171 1538.3,864.17 1538.29,864.17 1538.29,864.169 1538.28,864.168 1538.27,864.168 1538.27,864.167 1538.26,864.167 1538.25,864.166 1538.25,864.166 1538.24,864.165 1538.23,864.164 1538.23,864.164 1538.22,864.163 1538.21,864.163 1538.21,864.162 1538.2,864.162 1538.19,864.161 1538.19,864.16 1538.18,864.16 1538.17,864.159 1538.17,864.159 1538.16,864.158 1538.15,864.157 1538.15,864.157 1538.14,864.156 1538.13,864.156 1538.13,864.155 1538.12,864.155 1538.11,864.154 1538.11,864.153 1538.1,864.153 1538.09,864.152 1538.09,864.152 1538.08,864.151 1538.07,864.151 1538.07,864.15 1538.06,864.15 1538.05,864.149 1538.05,864.148 1538.04,864.148 1538.03,864.147 1538.03,864.147 1538.02,864.146 1538.01,864.146 1538.01,864.145 1538,864.144 1537.99,864.144 1537.99,864.143 1537.98,864.143 1537.97,864.142 1537.97,864.142 1537.96,864.141 1537.95,864.14 1537.95,864.14 1537.94,864.139 1537.93,864.139 1537.92,864.138 1537.92,864.138 1537.91,864.137 1537.9,864.136 1537.9,864.136 1537.89,864.135 1537.88,864.135 1537.88,864.134 1537.87,864.134 1537.86,864.133 1537.86,864.133 1537.85,864.132 1537.84,864.131 1537.84,864.131 1537.83,864.13 1537.82,864.13 1537.82,864.129 1537.81,864.129 1537.8,864.128 1537.8,864.127 1537.79,864.127 1537.78,864.126 1537.78,864.126 1537.77,864.125 1537.76,864.125 1537.76,864.124 1537.75,864.124 1537.74,864.123 1537.74,864.122 1537.73,864.122 1537.72,864.121 1537.72,864.121 1537.71,864.12 1537.7,864.12 1537.7,864.119 1537.69,864.119 1537.68,864.118 1537.68,864.117 1537.67,864.117 1537.66,864.116 1537.66,864.116 1537.65,864.115 1537.64,864.115 1537.64,864.114 1537.63,864.114 1537.62,864.113 1537.62,864.112 1537.61,864.112 1537.6,864.111 1537.6,864.111 1537.59,864.11 1537.58,864.11 1537.58,864.109 1537.57,864.109 1537.56,864.108 1537.56,864.108 1537.55,864.107 1537.54,864.106 1537.54,864.106 1537.53,864.105 1537.52,864.105 1537.52,864.104 1537.51,864.104 1537.5,864.103 1537.5,864.103 1537.49,864.102 1537.48,864.101 1537.48,864.101 1537.47,864.1 1537.46,864.1 1537.46,864.099 1537.45,864.099 1537.44,864.098 1537.44,864.098 1537.43,864.097 1537.42,864.097 1537.42,864.096 1537.41,864.095 1537.4,864.095 1537.4,864.094 1537.39,864.094 1537.38,864.093 1537.38,864.093 1537.37,864.092 1537.36,864.092 1537.36,864.091 1537.35,864.091 1537.34,864.09 1537.34,864.089 1537.33,864.089 1537.32,864.088 1537.32,864.088 1537.31,864.087 1537.3,864.087 1537.3,864.086 1537.29,864.086 1537.28,864.085 1537.28,864.085 1537.27,864.084 1537.26,864.083 1537.26,864.083 1537.25,864.082 1537.24,864.082 1537.23,864.081 1537.23,864.081 1537.22,864.08 1537.21,864.08 1537.21,864.079 1537.2,864.079 1537.19,864.078 1537.19,864.078 1537.18,864.077 1537.17,864.076 1537.17,864.076 1537.16,864.075 1537.15,864.075 1537.15,864.074 1537.14,864.074 1537.13,864.073 1537.13,864.073 1537.12,864.072 1537.11,864.072 1537.11,864.071 1537.1,864.071 1537.09,864.07 1537.09,864.07 1537.08,864.069 1537.07,864.068 1537.07,864.068 1537.06,864.067 1537.05,864.067 1537.05,864.066 1537.04,864.066 1537.03,864.065 1537.03,864.065 1537.02,864.064 1537.01,864.064 1537.01,864.063 1537,864.063 1536.99,864.062 1536.99,864.062 1536.98,864.061 1536.97,864.06 1536.97,864.06 1536.96,864.059 1536.95,864.059 1536.95,864.058 1536.94,864.058 1536.93,864.057 1536.93,864.057 1536.92,864.056 1536.91,864.056 1536.91,864.055 1536.9,864.055 1536.89,864.054 1536.89,864.054 1536.88,864.053 1536.87,864.053 1536.87,864.052 1536.86,864.052 1536.85,864.051 1536.85,864.05 1536.84,864.05 1536.83,864.049 1536.83,864.049 1536.82,864.048 1536.81,864.048 1536.81,864.047 1536.8,864.047 1536.79,864.046 1536.79,864.046 1536.78,864.045 1536.77,864.045 1536.77,864.044 1536.76,864.044 1536.75,864.043 1536.75,864.043 1536.74,864.042 1536.73,864.042 1536.73,864.041 1536.72,864.041 1536.71,864.04 1536.71,864.039 1536.7,864.039 1536.69,864.038 1536.69,864.038 1536.68,864.037 1536.67,864.037 1536.67,864.036 1536.66,864.036 1536.65,864.035 1536.65,864.035 1536.64,864.034 1536.64,864.034 1536.63,864.033 1536.62,864.033 1536.62,864.032 1536.61,864.032 1536.6,864.031 1536.6,864.031 1536.59,864.03 1536.58,864.03 1536.58,864.029 1536.57,864.029 1536.56,864.028 1536.56,864.028 1536.55,864.027 1536.54,864.027 1536.54,864.026 1536.53,864.026 1536.52,864.025 1536.52,864.025 1536.51,864.024 1536.5,864.023 1536.5,864.023 1536.49,864.022 1536.48,864.022 1536.48,864.021 1536.47,864.021 1536.46,864.02 1536.46,864.02 1536.45,864.019 1536.44,864.019 1536.44,864.018 1536.43,864.018 1536.42,864.017 1536.42,864.017 1536.41,864.016 1536.4,864.016 1536.4,864.015 1536.39,864.015 1536.38,864.014 1536.38,864.014 1536.37,864.013 1536.36,864.013 1536.36,864.012 1536.35,864.012 1536.34,864.011 1536.34,864.011 1536.33,864.01 1536.32,864.01 1536.32,864.009 1536.31,864.009 1536.3,864.008 1536.3,864.008 1536.29,864.007 1536.28,864.007 1536.28,864.006 1536.27,864.006 1536.26,864.005 1536.26,864.005 1536.25,864.004 1536.24,864.004 1536.24,864.003 1536.23,864.003 1536.22,864.002 1536.22,864.002 1536.21,864.001 1536.2,864.001 1536.2,864 1536.19,864 1536.18,863.999 1536.18,863.999 1536.17,863.998 1536.16,863.998 1536.16,863.997 1536.15,863.997 1536.14,863.996 1536.14,863.996 1536.13,863.995 1536.12,863.995 1536.12,863.994 1536.11,863.994 1536.1,863.993 1536.1,863.993 1536.09,863.992 1536.08,863.992 1536.08,863.991 1536.07,863.991 1536.06,863.99 1536.06,863.99 1536.05,863.989 1536.04,863.989 1536.04,863.988 1536.03,863.988 1536.02,863.987 1536.02,863.987 1536.01,863.986 1536,863.986 1536,863.985 1535.99,863.985 1535.98,863.984 1535.98,863.984 1535.97,863.983 1535.97,863.983 1535.96,863.982 1535.95,863.982 1535.95,863.981 1535.94,863.981 1535.93,863.98 1535.93,863.98 1535.92,863.979 1535.91,863.979 1535.91,863.978 1535.9,863.978 1535.89,863.977 1535.89,863.977 1535.88,863.976 1535.87,863.976 1535.87,863.975 1535.86,863.975 1535.85,863.974 1535.85,863.974 1535.84,863.973 1535.83,863.973 1535.83,863.973 1535.82,863.972 1535.81,863.972 1535.81,863.971 1535.8,863.971 1535.79,863.97 1535.79,863.97 1535.78,863.969 1535.77,863.969 1535.77,863.968 1535.76,863.968 1535.75,863.967 1535.75,863.967 1535.74,863.966 1535.73,863.966 1535.73,863.965 1535.72,863.965 1535.71,863.964 1535.71,863.964 1535.7,863.963 1535.69,863.963 1535.69,863.962 1535.68,863.962 1535.67,863.961 1535.67,863.961 1535.66,863.96 1535.65,863.96 1535.65,863.959 1535.64,863.959 1535.63,863.958 1535.63,863.958 1535.62,863.958 1535.61,863.957 1535.61,863.957 1535.6,863.956 1535.6,863.956 1535.59,863.955 1535.58,863.955 1535.58,863.954 1535.57,863.954 1535.56,863.953 1535.56,863.953 1535.55,863.952 1535.54,863.952 1535.54,863.951 1535.53,863.951 1535.52,863.95 1535.52,863.95 1535.51,863.949 1535.5,863.949 1535.5,863.948 1535.49,863.948 1535.48,863.948 1535.48,863.947 1535.47,863.947 1535.46,863.946 1535.46,863.946 1535.45,863.945 1535.44,863.945 1535.44,863.944 1535.43,863.944 1535.42,863.943 1535.42,863.943 1535.41,863.942 1535.4,863.942 1535.4,863.941 1535.39,863.941 1535.38,863.94 1535.38,863.94 1535.37,863.939 1535.36,863.939 1535.36,863.939 1535.35,863.938 1535.34,863.938 1535.34,863.937 1535.33,863.937 1535.32,863.936 1535.32,863.936 1535.31,863.935 1535.31,863.935 1535.3,863.934 1535.29,863.934 1535.29,863.933 1535.28,863.933 1535.27,863.932 1535.27,863.932 1535.26,863.932 1535.25,863.931 1535.25,863.931 1535.24,863.93 1535.23,863.93 1535.23,863.929 1535.22,863.929 1535.21,863.928 1535.21,863.928 1535.2,863.927 1535.19,863.927 1535.19,863.926 1535.18,863.926 1535.17,863.926 1535.17,863.925 1535.16,863.925 1535.15,863.924 1535.15,863.924 1535.14,863.923 1535.13,863.923 1535.13,863.922 1535.12,863.922 1535.11,863.921 1535.11,863.921 1535.1,863.92 1535.09,863.92 1535.09,863.92 1535.08,863.919 1535.07,863.919 1535.07,863.918 1535.06,863.918 1535.06,863.917 1535.05,863.917 1535.04,863.916 1535.04,863.916 1535.03,863.915 1535.02,863.915 1535.02,863.914 1535.01,863.914 1535,863.914 1535,863.913 1534.99,863.913 1534.98,863.912 1534.98,863.912 1534.97,863.911 1534.96,863.911 1534.96,863.91 1534.95,863.91 1534.94,863.909 1534.94,863.909 1534.93,863.909 1534.92,863.908 1534.92,863.908 1534.91,863.907 1534.9,863.907 1534.9,863.906 1534.89,863.906 1534.88,863.905 1534.88,863.905 1534.87,863.905 1534.86,863.904 1534.86,863.904 1534.85,863.903 1534.85,863.903 1534.84,863.902 1534.83,863.902 1534.83,863.901 1534.82,863.901 1534.81,863.9 1534.81,863.9 1534.8,863.9 1534.79,863.899 1534.79,863.899 1534.78,863.898 1534.77,863.898 1534.77,863.897 1534.76,863.897 1534.75,863.896 1534.75,863.896 1534.74,863.896 1534.73,863.895 1534.73,863.895 1534.72,863.894 1534.71,863.894 1534.71,863.893 1534.7,863.893 1534.69,863.892 1534.69,863.892 1534.68,863.892 1534.67,863.891 1534.67,863.891 1534.66,863.89 1534.65,863.89 1534.65,863.889 1534.64,863.889 1534.64,863.888 1534.63,863.888 1534.62,863.888 1534.62,863.887 1534.61,863.887 1534.6,863.886 1534.6,863.886 1534.59,863.885 1534.58,863.885 1534.58,863.885 1534.57,863.884 1534.56,863.884 1534.56,863.883 1534.55,863.883 1534.54,863.882 1534.54,863.882 1534.53,863.881 1534.52,863.881 1534.52,863.881 1534.51,863.88 1534.5,863.88 1534.5,863.879 1534.49,863.879 1534.48,863.878 1534.48,863.878 1534.47,863.878 1534.47,863.877 1534.46,863.877 1534.45,863.876 1534.45,863.876 1534.44,863.875 1534.43,863.875 1534.43,863.874 1534.42,863.874 1534.41,863.874 1534.41,863.873 1534.4,863.873 1534.39,863.872 1534.39,863.872 1534.38,863.871 1534.37,863.871 1534.37,863.871 1534.36,863.87 1534.35,863.87 1534.35,863.869 1534.34,863.869 1534.33,863.868 1534.33,863.868 1534.32,863.868 1534.31,863.867 1534.31,863.867 1534.3,863.866 1534.3,863.866 1534.29,863.865 1534.28,863.865 1534.28,863.865 1534.27,863.864 1534.26,863.864 1534.26,863.863 1534.25,863.863 1534.24,863.862 1534.24,863.862 1534.23,863.862 1534.22,863.861 1534.22,863.861 1534.21,863.86 1534.2,863.86 1534.2,863.859 1534.19,863.859 1534.18,863.859 1534.18,863.858 1534.17,863.858 1534.16,863.857 1534.16,863.857 1534.15,863.857 1534.15,863.856 1534.14,863.856 1534.13,863.855 1534.13,863.855 1534.12,863.854 1534.11,863.854 1534.11,863.854 1534.1,863.853 1534.09,863.853 1534.09,863.852 1534.08,863.852 1534.07,863.851 1534.07,863.851 1534.06,863.851 1534.05,863.85 1534.05,863.85 1534.04,863.849 1534.03,863.849 1534.03,863.849 1534.02,863.848 1534.01,863.848 1534.01,863.847 1534,863.847 1534,863.846 1533.99,863.846 1533.98,863.846 1533.98,863.845 1533.97,863.845 1533.96,863.844 1533.96,863.844 1533.95,863.844 1533.94,863.843 1533.94,863.843 1533.93,863.842 1533.92,863.842 1533.92,863.841 1533.91,863.841 1533.9,863.841 1533.9,863.84 1533.89,863.84 1533.88,863.839 1533.88,863.839 1533.87,863.839 1533.86,863.838 1533.86,863.838 1533.85,863.837 1533.85,863.837 1533.84,863.837 1533.83,863.836 1533.83,863.836 1533.82,863.835 1533.81,863.835 1533.81,863.834 1533.8,863.834 1533.79,863.834 1533.79,863.833 1533.78,863.833 1533.77,863.832 1533.77,863.832 1533.76,863.832 1533.75,863.831 1533.75,863.831 1533.74,863.83 1533.73,863.83 1533.73,863.83 1533.72,863.829 1533.72,863.829 1533.71,863.828 1533.7,863.828 1533.7,863.828 1533.69,863.827 1533.68,863.827 1533.68,863.826 1533.67,863.826 1533.66,863.826 1533.66,863.825 1533.65,863.825 1533.64,863.824 1533.64,863.824 1533.63,863.824 1533.62,863.823 1533.62,863.823 1533.61,863.822 1533.6,863.822 1533.6,863.822 1533.59,863.821 1533.59,863.821 1533.58,863.82 1533.57,863.82 1533.57,863.82 1533.56,863.819 1533.55,863.819 1533.55,863.818 1533.54,863.818 1533.53,863.818 1533.53,863.817 1533.52,863.817 1533.51,863.816 1533.51,863.816 1533.5,863.816 1533.49,863.815 1533.49,863.815 1533.48,863.814 1533.47,863.814 1533.47,863.814 1533.46,863.813 1533.46,863.813 1533.45,863.812 1533.44,863.812 1533.44,863.812 1533.43,863.811 1533.42,863.811 1533.42,863.81 1533.41,863.81 1533.4,863.81 1533.4,863.809 1533.39,863.809 1533.38,863.809 1533.38,863.808 1533.37,863.808 1533.36,863.807 1533.36,863.807 1533.35,863.807 1533.35,863.806 1533.34,863.806 1533.33,863.805 1533.33,863.805 1533.32,863.805 1533.31,863.804 1533.31,863.804 1533.3,863.803 1533.29,863.803 1533.29,863.803 1533.28,863.802 1533.27,863.802 1533.27,863.802 1533.26,863.801 1533.25,863.801 1533.25,863.8 1533.24,863.8 1533.24,863.8 1533.23,863.799 1533.22,863.799 1533.22,863.798 1533.21,863.798 1533.2,863.798 1533.2,863.797 1533.19,863.797 1533.18,863.797 1533.18,863.796 1533.17,863.796 1533.16,863.795 1533.16,863.795 1533.15,863.795 1533.14,863.794 1533.14,863.794 1533.13,863.793 1533.13,863.793 1533.12,863.793 1533.11,863.792 1533.11,863.792 1533.1,863.792 1533.09,863.791 1533.09,863.791 1533.08,863.79 1533.07,863.79 1533.07,863.79 1533.06,863.789 1533.05,863.789 1533.05,863.789 1533.04,863.788 1533.03,863.788 1533.03,863.787 1533.02,863.787 1533.02,863.787 1533.01,863.786 1533,863.786 1533,863.786 1532.99,863.785 1532.98,863.785 1532.98,863.784 1532.97,863.784 1532.96,863.784 1532.96,863.783 1532.95,863.783 1532.94,863.783 1532.94,863.782 1532.93,863.782 1532.92,863.781 1532.92,863.781 1532.91,863.781 1532.91,863.78 1532.9,863.78 1532.89,863.78 1532.89,863.779 1532.88,863.779 1532.87,863.778 1532.87,863.778 1532.86,863.778 1532.85,863.777 1532.85,863.777 1532.84,863.777 1532.83,863.776 1532.83,863.776 1532.82,863.775 1532.81,863.775 1532.81,863.775 1532.8,863.774 1532.8,863.774 1532.79,863.774 1532.78,863.773 1532.78,863.773 1532.77,863.773 1532.76,863.772 1532.76,863.772 1532.75,863.771 1532.74,863.771 1532.74,863.771 1532.73,863.77 1532.72,863.77 1532.72,863.77 1532.71,863.769 1532.71,863.769 1532.7,863.769 1532.69,863.768 1532.69,863.768 1532.68,863.767 1532.67,863.767 1532.67,863.767 1532.66,863.766 1532.65,863.766 1532.65,863.766 1532.64,863.765 1532.63,863.765 1532.63,863.765 1532.62,863.764 1532.61,863.764 1532.61,863.763 1532.6,863.763 1532.6,863.763 1532.59,863.762 1532.58,863.762 1532.58,863.762 1532.57,863.761 1532.56,863.761 1532.56,863.761 1532.55,863.76 1532.54,863.76 1532.54,863.76 1532.53,863.759 1532.52,863.759 1532.52,863.758 1532.51,863.758 1532.51,863.758 1532.5,863.757 1532.49,863.757 1532.49,863.757 1532.48,863.756 1532.47,863.756 1532.47,863.756 1532.46,863.755 1532.45,863.755 1532.45,863.755 1532.44,863.754 1532.43,863.754 1532.43,863.754 1532.42,863.753 1532.42,863.753 1532.41,863.752 1532.4,863.752 1532.4,863.752 1532.39,863.751 1532.38,863.751 1532.38,863.751 1532.37,863.75 1532.36,863.75 1532.36,863.75 1532.35,863.749 1532.34,863.749 1532.34,863.749 1532.33,863.748 1532.33,863.748 1532.32,863.748 1532.31,863.747 1532.31,863.747 1532.3,863.747 1532.29,863.746 1532.29,863.746 1532.28,863.746 1532.27,863.745 1532.27,863.745 1532.26,863.744 1532.25,863.744 1532.25,863.744 1532.24,863.743 1532.24,863.743 1532.23,863.743 1532.22,863.742 1532.22,863.742 1532.21,863.742 1532.2,863.741 1532.2,863.741 1532.19,863.741 1532.18,863.74 1532.18,863.74 1532.17,863.74 1532.16,863.739 1532.16,863.739 1532.15,863.739 1532.15,863.738 1532.14,863.738 1532.13,863.738 1532.13,863.737 1532.12,863.737 1532.11,863.737 1532.11,863.736 1532.1,863.736 1532.09,863.736 1532.09,863.735 1532.08,863.735 1532.07,863.735 1532.07,863.734 1532.06,863.734 1532.06,863.734 1532.05,863.733 1532.04,863.733 1532.04,863.733 1532.03,863.732 1532.02,863.732 1532.02,863.732 1532.01,863.731 1532,863.731 1532,863.731 1531.99,863.73 1531.99,863.73 1531.98,863.73 1531.97,863.729 1531.97,863.729 1531.96,863.729 1531.95,863.728 1531.95,863.728 1531.94,863.728 1531.93,863.727 1531.93,863.727 1531.92,863.727 1531.91,863.726 1531.91,863.726 1531.9,863.726 1531.9,863.725 1531.89,863.725 1531.88,863.725 1531.88,863.724 1531.87,863.724 1531.86,863.724 1531.86,863.723 1531.85,863.723 1531.84,863.723 1531.84,863.722 1531.83,863.722 1531.82,863.722 1531.82,863.721 1531.81,863.721 1531.81,863.721 1531.8,863.72 1531.79,863.72 1531.79,863.72 1531.78,863.719 1531.77,863.719 1531.77,863.719 1531.76,863.718 1531.75,863.718 1531.75,863.718 1531.74,863.717 1531.74,863.717 1531.73,863.717 1531.72,863.717 1531.72,863.716 1531.71,863.716 1531.7,863.716 1531.7,863.715 1531.69,863.715 1531.68,863.715 1531.68,863.714 1531.67,863.714 1531.66,863.714 1531.66,863.713 1531.65,863.713 1531.65,863.713 1531.64,863.712 1531.63,863.712 1531.63,863.712 1531.62,863.711 1531.61,863.711 1531.61,863.711 1531.6,863.71 1531.59,863.71 1531.59,863.71 1531.58,863.71 1531.58,863.709 1531.57,863.709 1531.56,863.709 1531.56,863.708 1531.55,863.708 1531.54,863.708 1531.54,863.707 1531.53,863.707 1531.52,863.707 1531.52,863.706 1531.51,863.706 1531.51,863.706 1531.5,863.705 1531.49,863.705 1531.49,863.705 1531.48,863.704 1531.47,863.704 1531.47,863.704 1531.46,863.704 1531.45,863.703 1531.45,863.703 1531.44,863.703 1531.43,863.702 1531.43,863.702 1531.42,863.702 1531.42,863.701 1531.41,863.701 1531.4,863.701 1531.4,863.7 1531.39,863.7 1531.38,863.7 1531.38,863.7 1531.37,863.699 1531.36,863.699 1531.36,863.699 1531.35,863.698 1531.35,863.698 1531.34,863.698 1531.33,863.697 1531.33,863.697 1531.32,863.697 1531.31,863.697 1531.31,863.696 1531.3,863.696 1531.29,863.696 1531.29,863.695 1531.28,863.695 1531.28,863.695 1531.27,863.694 1531.26,863.694 1531.26,863.694 1531.25,863.693 1531.24,863.693 1531.24,863.693 1531.23,863.693 1531.22,863.692 1531.22,863.692 1531.21,863.692 1531.21,863.691 1531.2,863.691 1531.19,863.691 1531.19,863.69 1531.18,863.69 1531.17,863.69 1531.17,863.69 1531.16,863.689 1531.15,863.689 1531.15,863.689 1531.14,863.688 1531.14,863.688 1531.13,863.688 1531.12,863.688 1531.12,863.687 1531.11,863.687 1531.1,863.687 1531.1,863.686 1531.09,863.686 1531.08,863.686 1531.08,863.685 1531.07,863.685 1531.07,863.685 1531.06,863.685 1531.05,863.684 1531.05,863.684 1531.04,863.684 1531.03,863.683 1531.03,863.683 1531.02,863.683 1531.01,863.683 1531.01,863.682 1531,863.682 1531,863.682 1530.99,863.681 1530.98,863.681 1530.98,863.681 1530.97,863.681 1530.96,863.68 1530.96,863.68 1530.95,863.68 1530.94,863.679 1530.94,863.679 1530.93,863.679 1530.93,863.679 1530.92,863.678 1530.91,863.678 1530.91,863.678 1530.9,863.677 1530.89,863.677 1530.89,863.677 1530.88,863.677 1530.87,863.676 1530.87,863.676 1530.86,863.676 1530.86,863.675 1530.85,863.675 1530.84,863.675 1530.84,863.675 1530.83,863.674 1530.82,863.674 1530.82,863.674 1530.81,863.673 1530.8,863.673 1530.8,863.673 1530.79,863.673 1530.79,863.672 1530.78,863.672 1530.77,863.672 1530.77,863.671 1530.76,863.671 1530.75,863.671 1530.75,863.671 1530.74,863.67 1530.73,863.67 1530.73,863.67 1530.72,863.67 1530.72,863.669 1530.71,863.669 1530.7,863.669 1530.7,863.668 1530.69,863.668 1530.68,863.668 1530.68,863.668 1530.67,863.667 1530.67,863.667 1530.66,863.667 1530.65,863.666 1530.65,863.666 1530.64,863.666 1530.63,863.666 1530.63,863.665 1530.62,863.665 1530.61,863.665 1530.61,863.665 1530.6,863.664 1530.6,863.664 1530.59,863.664 1530.58,863.663 1530.58,863.663 1530.57,863.663 1530.56,863.663 1530.56,863.662 1530.55,863.662 1530.54,863.662 1530.54,863.662 1530.53,863.661 1530.53,863.661 1530.52,863.661 1530.51,863.661 1530.51,863.66 1530.5,863.66 1530.49,863.66 1530.49,863.659 1530.48,863.659 1530.48,863.659 1530.47,863.659 1530.46,863.658 1530.46,863.658 1530.45,863.658 1530.44,863.658 1530.44,863.657 1530.43,863.657 1530.42,863.657 1530.42,863.657 1530.41,863.656 1530.41,863.656 1530.4,863.656 1530.39,863.655 1530.39,863.655 1530.38,863.655 1530.37,863.655 1530.37,863.654 1530.36,863.654 1530.35,863.654 1530.35,863.654 1530.34,863.653 1530.34,863.653 1530.33,863.653 1530.32,863.653 1530.32,863.652 1530.31,863.652 1530.3,863.652 1530.3,863.652 1530.29,863.651 1530.29,863.651 1530.28,863.651 1530.27,863.651 1530.27,863.65 1530.26,863.65 1530.25,863.65 1530.25,863.65 1530.24,863.649 1530.23,863.649 1530.23,863.649 1530.22,863.649 1530.22,863.648 1530.21,863.648 1530.2,863.648 1530.2,863.648 1530.19,863.647 1530.18,863.647 1530.18,863.647 1530.17,863.646 1530.17,863.646 1530.16,863.646 1530.15,863.646 1530.15,863.645 1530.14,863.645 1530.13,863.645 1530.13,863.645 1530.12,863.644 1530.11,863.644 1530.11,863.644 1530.1,863.644 1530.1,863.643 1530.09,863.643 1530.08,863.643 1530.08,863.643 1530.07,863.642 1530.06,863.642 1530.06,863.642 1530.05,863.642 1530.05,863.642 1530.04,863.641 1530.03,863.641 1530.03,863.641 1530.02,863.641 1530.01,863.64 1530.01,863.64 1530,863.64 1529.99,863.64 1529.99,863.639 1529.98,863.639 1529.98,863.639 1529.97,863.639 1529.96,863.638 1529.96,863.638 1529.95,863.638 1529.94,863.638 1529.94,863.637 1529.93,863.637 1529.93,863.637 1529.92,863.637 1529.91,863.636 1529.91,863.636 1529.9,863.636 1529.89,863.636 1529.89,863.635 1529.88,863.635 1529.88,863.635 1529.87,863.635 1529.86,863.634 1529.86,863.634 1529.85,863.634 1529.84,863.634 1529.84,863.634 1529.83,863.633 1529.82,863.633 1529.82,863.633 1529.81,863.633 1529.81,863.632 1529.8,863.632 1529.79,863.632 1529.79,863.632 1529.78,863.631 1529.77,863.631 1529.77,863.631 1529.76,863.631 1529.76,863.63 1529.75,863.63 1529.74,863.63 1529.74,863.63 1529.73,863.63 1529.72,863.629 1529.72,863.629 1529.71,863.629 1529.71,863.629 1529.7,863.628 1529.69,863.628 1529.69,863.628 1529.68,863.628 1529.67,863.628 1529.67,863.627 1529.66,863.627 1529.65,863.627 1529.65,863.627 1529.64,863.626 1529.64,863.626 1529.63,863.626 1529.62,863.626 1529.62,863.625 1529.61,863.625 1529.6,863.625 1529.6,863.625 1529.59,863.625 1529.59,863.624 1529.58,863.624 1529.57,863.624 1529.57,863.624 1529.56,863.623 1529.55,863.623 1529.55,863.623 1529.54,863.623 1529.54,863.623 1529.53,863.622 1529.52,863.622 1529.52,863.622 1529.51,863.622 1529.5,863.621 1529.5,863.621 1529.49,863.621 1529.49,863.621 1529.48,863.621 1529.47,863.62 1529.47,863.62 1529.46,863.62 1529.45,863.62 1529.45,863.619 1529.44,863.619 1529.44,863.619 1529.43,863.619 1529.42,863.619 1529.42,863.618 1529.41,863.618 1529.4,863.618 1529.4,863.618 1529.39,863.618 1529.38,863.617 1529.38,863.617 1529.37,863.617 1529.37,863.617 1529.36,863.616 1529.35,863.616 1529.35,863.616 1529.34,863.616 1529.33,863.616 1529.33,863.615 1529.32,863.615 1529.32,863.615 1529.31,863.615 1529.3,863.615 1529.3,863.614 1529.29,863.614 1529.28,863.614 1529.28,863.614 1529.27,863.613 1529.27,863.613 1529.26,863.613 1529.25,863.613 1529.25,863.613 1529.24,863.612 1529.23,863.612 1529.23,863.612 1529.22,863.612 1529.22,863.612 1529.21,863.611 1529.2,863.611 1529.2,863.611 1529.19,863.611 1529.18,863.611 1529.18,863.61 1529.17,863.61 1529.17,863.61 1529.16,863.61 1529.15,863.61 1529.15,863.609 1529.14,863.609 1529.13,863.609 1529.13,863.609 1529.12,863.609 1529.12,863.608 1529.11,863.608 1529.1,863.608 1529.1,863.608 1529.09,863.608 1529.08,863.607 1529.08,863.607 1529.07,863.607 1529.07,863.607 1529.06,863.607 1529.05,863.606 1529.05,863.606 1529.04,863.606 1529.03,863.606 1529.03,863.606 1529.02,863.605 1529.02,863.605 1529.01,863.605 1529,863.605 1529,863.605 1528.99,863.604 1528.98,863.604 1528.98,863.604 1528.97,863.604 1528.97,863.604 1528.96,863.603 1528.95,863.603 1528.95,863.603 1528.94,863.603 1528.93,863.603 1528.93,863.602 1528.92,863.602 1528.92,863.602 1528.91,863.602 1528.9,863.602 1528.9,863.601 1528.89,863.601 1528.88,863.601 1528.88,863.601 1528.87,863.601 1528.87,863.6 1528.86,863.6 1528.85,863.6 1528.85,863.6 1528.84,863.6 1528.83,863.6 1528.83,863.599 1528.82,863.599 1528.82,863.599 1528.81,863.599 1528.8,863.599 1528.8,863.598 1528.79,863.598 1528.78,863.598 1528.78,863.598 1528.77,863.598 1528.77,863.597 1528.76,863.597 1528.75,863.597 1528.75,863.597 1528.74,863.597 1528.73,863.597 1528.73,863.596 1528.72,863.596 1528.72,863.596 1528.71,863.596 1528.7,863.596 1528.7,863.595 1528.69,863.595 1528.68,863.595 1528.68,863.595 1528.67,863.595 1528.67,863.595 1528.66,863.594 1528.65,863.594 1528.65,863.594 1528.64,863.594 1528.63,863.594 1528.63,863.593 1528.62,863.593 1528.62,863.593 1528.61,863.593 1528.6,863.593 1528.6,863.593 1528.59,863.592 1528.58,863.592 1528.58,863.592 1528.57,863.592 1528.57,863.592 1528.56,863.592 1528.55,863.591 1528.55,863.591 1528.54,863.591 1528.53,863.591 1528.53,863.591 1528.52,863.591 1528.52,863.59 1528.51,863.59 1528.5,863.59 1528.5,863.59 1528.49,863.59 1528.49,863.589 1528.48,863.589 1528.47,863.589 1528.47,863.589 1528.46,863.589 1528.45,863.589 1528.45,863.588 1528.44,863.588 1528.44,863.588 1528.43,863.588 1528.42,863.588 1528.42,863.588 1528.41,863.587 1528.4,863.587 1528.4,863.587 1528.39,863.587 1528.39,863.587 1528.38,863.587 1528.37,863.586 1528.37,863.586 1528.36,863.586 1528.35,863.586 1528.35,863.586 1528.34,863.586 1528.34,863.585 1528.33,863.585 1528.32,863.585 1528.32,863.585 1528.31,863.585 1528.3,863.585 1528.3,863.584 1528.29,863.584 1528.29,863.584 1528.28,863.584 1528.27,863.584 1528.27,863.584 1528.26,863.584 1528.26,863.583 1528.25,863.583 1528.24,863.583 1528.24,863.583 1528.23,863.583 1528.22,863.583 1528.22,863.582 1528.21,863.582 1528.21,863.582 1528.2,863.582 1528.19,863.582 1528.19,863.582 1528.18,863.581 1528.17,863.581 1528.17,863.581 1528.16,863.581 1528.16,863.581 1528.15,863.581 1528.14,863.581 1528.14,863.58 1528.13,863.58 1528.12,863.58 1528.12,863.58 1528.11,863.58 1528.11,863.58 1528.1,863.579 1528.09,863.579 1528.09,863.579 1528.08,863.579 1528.08,863.579 1528.07,863.579 1528.06,863.579 1528.06,863.578 1528.05,863.578 1528.04,863.578 1528.04,863.578 1528.03,863.578 1528.03,863.578 1528.02,863.578 1528.01,863.577 1528.01,863.577 1528,863.577 1527.99,863.577 1527.99,863.577 1527.98,863.577 1527.98,863.576 1527.97,863.576 1527.96,863.576 1527.96,863.576 1527.95,863.576 1527.94,863.576 1527.94,863.576 1527.93,863.575 1527.93,863.575 1527.92,863.575 1527.91,863.575 1527.91,863.575 1527.9,863.575 1527.9,863.575 1527.89,863.574 1527.88,863.574 1527.88,863.574 1527.87,863.574 1527.86,863.574 1527.86,863.574 1527.85,863.574 1527.85,863.574 1527.84,863.573 1527.83,863.573 1527.83,863.573 1527.82,863.573 1527.81,863.573 1527.81,863.573 1527.8,863.573 1527.8,863.572 1527.79,863.572 1527.78,863.572 1527.78,863.572 1527.77,863.572 1527.77,863.572 1527.76,863.572 1527.75,863.571 1527.75,863.571 1527.74,863.571 1527.73,863.571 1527.73,863.571 1527.72,863.571 1527.72,863.571 1527.71,863.571 1527.7,863.57 1527.7,863.57 1527.69,863.57 1527.69,863.57 1527.68,863.57 1527.67,863.57 1527.67,863.57 1527.66,863.569 1527.65,863.569 1527.65,863.569 1527.64,863.569 1527.64,863.569 1527.63,863.569 1527.62,863.569 1527.62,863.569 1527.61,863.568 1527.6,863.568 1527.6,863.568 1527.59,863.568 1527.59,863.568 1527.58,863.568 1527.57,863.568 1527.57,863.568 1527.56,863.567 1527.56,863.567 1527.55,863.567 1527.54,863.567 1527.54,863.567 1527.53,863.567 1527.52,863.567 1527.52,863.567 1527.51,863.566 1527.51,863.566 1527.5,863.566 1527.49,863.566 1527.49,863.566 1527.48,863.566 1527.48,863.566 1527.47,863.566 1527.46,863.566 1527.46,863.565 1527.45,863.565 1527.44,863.565 1527.44,863.565 1527.43,863.565 1527.43,863.565 1527.42,863.565 1527.41,863.565 1527.41,863.564 1527.4,863.564 1527.4,863.564 1527.39,863.564 1527.38,863.564 1527.38,863.564 1527.37,863.564 1527.36,863.564 1527.36,863.564 1527.35,863.563 1527.35,863.563 1527.34,863.563 1527.33,863.563 1527.33,863.563 1527.32,863.563 1527.32,863.563 1527.31,863.563 1527.3,863.563 1527.3,863.562 1527.29,863.562 1527.28,863.562 1527.28,863.562 1527.27,863.562 1527.27,863.562 1527.26,863.562 1527.25,863.562 1527.25,863.562 1527.24,863.561 1527.23,863.561 1527.23,863.561 1527.22,863.561 1527.22,863.561 1527.21,863.561 1527.2,863.561 1527.2,863.561 1527.19,863.561 1527.19,863.56 1527.18,863.56 1527.17,863.56 1527.17,863.56 1527.16,863.56 1527.15,863.56 1527.15,863.56 1527.14,863.56 1527.14,863.56 1527.13,863.56 1527.12,863.559 1527.12,863.559 1527.11,863.559 1527.11,863.559 1527.1,863.559 1527.09,863.559 1527.09,863.559 1527.08,863.559 1527.08,863.559 1527.07,863.559 1527.06,863.558 1527.06,863.558 1527.05,863.558 1527.04,863.558 1527.04,863.558 1527.03,863.558 1527.03,863.558 1527.02,863.558 1527.01,863.558 1527.01,863.558 1527,863.557 1527,863.557 1526.99,863.557 1526.98,863.557 1526.98,863.557 1526.97,863.557 1526.96,863.557 1526.96,863.557 1526.95,863.557 1526.95,863.557 1526.94,863.557 1526.93,863.556 1526.93,863.556 1526.92,863.556 1526.92,863.556 1526.91,863.556 1526.9,863.556 1526.9,863.556 1526.89,863.556 1526.88,863.556 1526.88,863.556 1526.87,863.556 1526.87,863.555 1526.86,863.555 1526.85,863.555 1526.85,863.555 1526.84,863.555 1526.84,863.555 1526.83,863.555 1526.82,863.555 1526.82,863.555 1526.81,863.555 1526.81,863.555 1526.8,863.555 1526.79,863.554 1526.79,863.554 1526.78,863.554 1526.77,863.554 1526.77,863.554 1526.76,863.554 1526.76,863.554 1526.75,863.554 1526.74,863.554 1526.74,863.554 1526.73,863.554 1526.73,863.554 1526.72,863.553 1526.71,863.553 1526.71,863.553 1526.7,863.553 1526.69,863.553 1526.69,863.553 1526.68,863.553 1526.68,863.553 1526.67,863.553 1526.66,863.553 1526.66,863.553 1526.65,863.553 1526.65,863.553 1526.64,863.552 1526.63,863.552 1526.63,863.552 1526.62,863.552 1526.62,863.552 1526.61,863.552 1526.6,863.552 1526.6,863.552 1526.59,863.552 1526.58,863.552 1526.58,863.552 1526.57,863.552 1526.57,863.552 1526.56,863.552 1526.55,863.551 1526.55,863.551 1526.54,863.551 1526.54,863.551 1526.53,863.551 1526.52,863.551 1526.52,863.551 1526.51,863.551 1526.51,863.551 1526.5,863.551 1526.49,863.551 1526.49,863.551 1526.48,863.551 1526.47,863.551 1526.47,863.551 1526.46,863.55 1526.46,863.55 1526.45,863.55 1526.44,863.55 1526.44,863.55 1526.43,863.55 1526.43,863.55 1526.42,863.55 1526.41,863.55 1526.41,863.55 1526.4,863.55 1526.4,863.55 1526.39,863.55 1526.38,863.55 1526.38,863.55 1526.37,863.549 1526.36,863.549 1526.36,863.549 1526.35,863.549 1526.35,863.549 1526.34,863.549 1526.33,863.549 1526.33,863.549 1526.32,863.549 1526.32,863.549 1526.31,863.549 1526.3,863.549 1526.3,863.549 1526.29,863.549 1526.29,863.549 1526.28,863.549 1526.27,863.549 1526.27,863.549 1526.26,863.548 1526.25,863.548 1526.25,863.548 1526.24,863.548 1526.24,863.548 1526.23,863.548 1526.22,863.548 1526.22,863.548 1526.21,863.548 1526.21,863.548 1526.2,863.548 1526.19,863.548 1526.19,863.548 1526.18,863.548 1526.18,863.548 1526.17,863.548 1526.16,863.548 1526.16,863.548 1526.15,863.548 1526.14,863.547 1526.14,863.547 1526.13,863.547 1526.13,863.547 1526.12,863.547 1526.11,863.547 1526.11,863.547 1526.1,863.547 1526.1,863.547 1526.09,863.547 1526.08,863.547 1526.08,863.547 1526.07,863.547 1526.07,863.547 1526.06,863.547 1526.05,863.547 1526.05,863.547 1526.04,863.547 1526.04,863.547 1526.03,863.547 1526.02,863.547 1526.02,863.547 1526.01,863.547 1526,863.546 1526,863.546 1525.99,863.546 1525.99,863.546 1525.98,863.546 1525.97,863.546 1525.97,863.546 1525.96,863.546 1525.96,863.546 1525.95,863.546 1525.94,863.546 1525.94,863.546 1525.93,863.546 1525.93,863.546 1525.92,863.546 1525.91,863.546 1525.91,863.546 1525.9,863.546 1525.9,863.546 1525.89,863.546 1525.88,863.546 1525.88,863.546 1525.87,863.546 1525.87,863.546 1525.86,863.546 1525.85,863.546 1525.85,863.546 1525.84,863.546 1525.83,863.545 1525.83,863.545 1525.82,863.545 1525.82,863.545 1525.81,863.545 1525.8,863.545 1525.8,863.545 1525.79,863.545 1525.79,863.545 1525.78,863.545 1525.77,863.545 1525.77,863.545 1525.76,863.545 1525.76,863.545 1525.75,863.545 1525.74,863.545 1525.74,863.545 1525.73,863.545 1525.73,863.545 1525.72,863.545 1525.71,863.545 1525.71,863.545 1525.7,863.545 1525.7,863.545 1525.69,863.545 1525.68,863.545 1525.68,863.545 1525.67,863.545 1525.66,863.545 1525.66,863.545 1525.65,863.545 1525.65,863.545 1525.64,863.545 1525.63,863.545 1525.63,863.545 1525.62,863.545 1525.62,863.545 1525.61,863.545 1525.6,863.545 1525.6,863.545 1525.59,863.545 1525.59,863.545 1525.58,863.545 1525.57,863.545 1525.57,863.544 1525.56,863.544 1525.56,863.544 1525.55,863.544 1525.54,863.544 1525.54,863.544 1525.53,863.544 1525.53,863.544 1525.52,863.544 1525.51,863.544 1525.51,863.544 1525.5,863.544 1525.5,863.544 1525.49,863.544 1525.48,863.544 1525.48,863.544 1525.47,863.544 1525.46,863.544 1525.46,863.544 1525.45,863.544 1525.45,863.544 1525.44,863.544 1525.43,863.544 1525.43,863.544 1525.42,863.544 1525.42,863.544 1525.41,863.544 1525.4,863.544 1525.4,863.544 1525.39,863.544 1525.39,863.544 1525.38,863.544 1525.37,863.544 1525.37,863.544 1525.36,863.544 1525.36,863.544 1525.35,863.544 1525.34,863.544 1525.34,863.544 1525.33,863.544 1525.33,863.544 1525.32,863.544 1525.31,863.544 1525.31,863.544 1525.3,863.544 1525.3,863.544 1525.29,863.544 1525.28,863.544 1525.28,863.544 1525.27,863.544 1525.27,863.544 1525.26,863.544 1525.25,863.544 1525.25,863.544 1525.24,863.544 1525.23,863.544 1525.23,863.544 1525.22,863.544 1525.22,863.544 1525.21,863.544 1525.2,863.544 1525.2,863.544 1525.19,863.544 1525.19,863.544 1525.18,863.544 1525.17,863.544 1525.17,863.544 1525.16,863.544 1525.16,863.544 1525.15,863.544 1525.14,863.544 1525.14,863.544 1525.13,863.544 1525.13,863.544 1525.12,863.544 1525.11,863.544 1525.11,863.544 1525.1,863.544 1525.1,863.544 1525.09,863.544 1525.08,863.544 1525.08,863.544 1525.07,863.544 1525.07,863.544 1525.06,863.544 1525.05,863.544 1525.05,863.544 1525.04,863.545 1525.04,863.545 1525.03,863.545 1525.02,863.545 1525.02,863.545 1525.01,863.545 1525.01,863.545 1525,863.545 1524.99,863.545 1524.99,863.545 1524.98,863.545 1524.98,863.545 1524.97,863.545 1524.96,863.545 1524.96,863.545 1524.95,863.545 1524.95,863.545 1524.94,863.545 1524.93,863.545 1524.93,863.545 1524.92,863.545 1524.92,863.545 1524.91,863.545 1524.9,863.545 1524.9,863.545 1524.89,863.545 1524.89,863.545 1524.88,863.545 1524.87,863.545 1524.87,863.545 1524.86,863.545 1524.86,863.545 1524.85,863.545 1524.84,863.545 1524.84,863.545 1524.83,863.545 1524.83,863.545 1524.82,863.545 1524.81,863.545 1524.81,863.545 1524.8,863.545 1524.79,863.545 1524.79,863.545 1524.78,863.546 1524.78,863.546 1524.77,863.546 1524.76,863.546 1524.76,863.546 1524.75,863.546 1524.75,863.546 1524.74,863.546 1524.73,863.546 1524.73,863.546 1524.72,863.546 1524.72,863.546 1524.71,863.546 1524.7,863.546 1524.7,863.546 1524.69,863.546 1524.69,863.546 1524.68,863.546 1524.67,863.546 1524.67,863.546 1524.66,863.546 1524.66,863.546 1524.65,863.546 1524.64,863.546 1524.64,863.546 1524.63,863.546 1524.63,863.546 1524.62,863.546 1524.61,863.547 1524.61,863.547 1524.6,863.547 1524.6,863.547 1524.59,863.547 1524.58,863.547 1524.58,863.547 1524.57,863.547 1524.57,863.547 1524.56,863.547 1524.55,863.547 1524.55,863.547 1524.54,863.547 1524.54,863.547 1524.53,863.547 1524.52,863.547 1524.52,863.547 1524.51,863.547 1524.51,863.547 1524.5,863.547 1524.49,863.547 1524.49,863.547 1524.48,863.548 1524.48,863.548 1524.47,863.548 1524.46,863.548 1524.46,863.548 1524.45,863.548 1524.45,863.548 1524.44,863.548 1524.43,863.548 1524.43,863.548 1524.42,863.548 1524.42,863.548 1524.41,863.548 1524.4,863.548 1524.4,863.548 1524.39,863.548 1524.39,863.548 1524.38,863.548 1524.37,863.548 1524.37,863.549 1524.36,863.549 1524.36,863.549 1524.35,863.549 1524.34,863.549 1524.34,863.549 1524.33,863.549 1524.33,863.549 1524.32,863.549 1524.31,863.549 1524.31,863.549 1524.3,863.549 1524.3,863.549 1524.29,863.549 1524.28,863.549 1524.28,863.549 1524.27,863.549 1524.27,863.55 1524.26,863.55 1524.26,863.55 1524.25,863.55 1524.24,863.55 1524.24,863.55 1524.23,863.55 1524.23,863.55 1524.22,863.55 1524.21,863.55 1524.21,863.55 1524.2,863.55 1524.2,863.55 1524.19,863.55 1524.18,863.55 1524.18,863.551 1524.17,863.551 1524.17,863.551 1524.16,863.551 1524.15,863.551 1524.15,863.551 1524.14,863.551 1524.14,863.551 1524.13,863.551 1524.12,863.551 1524.12,863.551 1524.11,863.551 1524.11,863.551 1524.1,863.551 1524.09,863.551 1524.09,863.552 1524.08,863.552 1524.08,863.552 1524.07,863.552 1524.06,863.552 1524.06,863.552 1524.05,863.552 1524.05,863.552 1524.04,863.552 1524.03,863.552 1524.03,863.552 1524.02,863.552 1524.02,863.552 1524.01,863.553 1524,863.553 1524,863.553 1523.99,863.553 1523.99,863.553 1523.98,863.553 1523.97,863.553 1523.97,863.553 1523.96,863.553 1523.96,863.553 1523.95,863.553 1523.94,863.553 1523.94,863.554 1523.93,863.554 1523.93,863.554 1523.92,863.554 1523.91,863.554 1523.91,863.554 1523.9,863.554 1523.9,863.554 1523.89,863.554 1523.88,863.554 1523.88,863.554 1523.87,863.554 1523.87,863.555 1523.86,863.555 1523.86,863.555 1523.85,863.555 1523.84,863.555 1523.84,863.555 1523.83,863.555 1523.83,863.555 1523.82,863.555 1523.81,863.555 1523.81,863.555 1523.8,863.556 1523.8,863.556 1523.79,863.556 1523.78,863.556 1523.78,863.556 1523.77,863.556 1523.77,863.556 1523.76,863.556 1523.75,863.556 1523.75,863.556 1523.74,863.556 1523.74,863.557 1523.73,863.557 1523.72,863.557 1523.72,863.557 1523.71,863.557 1523.71,863.557 1523.7,863.557 1523.69,863.557 1523.69,863.557 1523.68,863.557 1523.68,863.558 1523.67,863.558 1523.66,863.558 1523.66,863.558 1523.65,863.558 1523.65,863.558 1523.64,863.558 1523.63,863.558 1523.63,863.558 1523.62,863.558 1523.62,863.559 1523.61,863.559 1523.61,863.559 1523.6,863.559 1523.59,863.559 1523.59,863.559 1523.58,863.559 1523.58,863.559 1523.57,863.559 1523.56,863.56 1523.56,863.56 1523.55,863.56 1523.55,863.56 1523.54,863.56 1523.53,863.56 1523.53,863.56 1523.52,863.56 1523.52,863.56 1523.51,863.56 1523.5,863.561 1523.5,863.561 1523.49,863.561 1523.49,863.561 1523.48,863.561 1523.47,863.561 1523.47,863.561 1523.46,863.561 1523.46,863.561 1523.45,863.562 1523.44,863.562 1523.44,863.562 1523.43,863.562 1523.43,863.562 1523.42,863.562 1523.42,863.562 1523.41,863.562 1523.4,863.563 1523.4,863.563 1523.39,863.563 1523.39,863.563 1523.38,863.563 1523.37,863.563 1523.37,863.563 1523.36,863.563 1523.36,863.563 1523.35,863.564 1523.34,863.564 1523.34,863.564 1523.33,863.564 1523.33,863.564 1523.32,863.564 1523.31,863.564 1523.31,863.564 1523.3,863.565 1523.3,863.565 1523.29,863.565 1523.28,863.565 1523.28,863.565 1523.27,863.565 1523.27,863.565 1523.26,863.565 1523.25,863.566 1523.25,863.566 1523.24,863.566 1523.24,863.566 1523.23,863.566 1523.23,863.566 1523.22,863.566 1523.21,863.566 1523.21,863.567 1523.2,863.567 1523.2,863.567 1523.19,863.567 1523.18,863.567 1523.18,863.567 1523.17,863.567 1523.17,863.568 1523.16,863.568 1523.15,863.568 1523.15,863.568 1523.14,863.568 1523.14,863.568 1523.13,863.568 1523.12,863.568 1523.12,863.569 1523.11,863.569 1523.11,863.569 1523.1,863.569 1523.1,863.569 1523.09,863.569 1523.08,863.569 1523.08,863.57 1523.07,863.57 1523.07,863.57 1523.06,863.57 1523.05,863.57 1523.05,863.57 1523.04,863.57 1523.04,863.571 1523.03,863.571 1523.02,863.571 1523.02,863.571 1523.01,863.571 1523.01,863.571 1523,863.571 1522.99,863.572 1522.99,863.572 1522.98,863.572 1522.98,863.572 1522.97,863.572 1522.97,863.572 1522.96,863.572 1522.95,863.573 1522.95,863.573 1522.94,863.573 1522.94,863.573 1522.93,863.573 1522.92,863.573 1522.92,863.573 1522.91,863.574 1522.91,863.574 1522.9,863.574 1522.89,863.574 1522.89,863.574 1522.88,863.574 1522.88,863.575 1522.87,863.575 1522.86,863.575 1522.86,863.575 1522.85,863.575 1522.85,863.575 1522.84,863.575 1522.84,863.576 1522.83,863.576 1522.82,863.576 1522.82,863.576 1522.81,863.576 1522.81,863.576 1522.8,863.577 1522.79,863.577 1522.79,863.577 1522.78,863.577 1522.78,863.577 1522.77,863.577 1522.76,863.577 1522.76,863.578 1522.75,863.578 1522.75,863.578 1522.74,863.578 1522.74,863.578 1522.73,863.578 1522.72,863.579 1522.72,863.579 1522.71,863.579 1522.71,863.579 1522.7,863.579 1522.69,863.579 1522.69,863.58 1522.68,863.58 1522.68,863.58 1522.67,863.58 1522.66,863.58 1522.66,863.58 1522.65,863.581 1522.65,863.581 1522.64,863.581 1522.64,863.581 1522.63,863.581 1522.62,863.581 1522.62,863.582 1522.61,863.582 1522.61,863.582 1522.6,863.582 1522.59,863.582 1522.59,863.582 1522.58,863.583 1522.58,863.583 1522.57,863.583 1522.56,863.583 1522.56,863.583 1522.55,863.584 1522.55,863.584 1522.54,863.584 1522.54,863.584 1522.53,863.584 1522.52,863.584 1522.52,863.585 1522.51,863.585 1522.51,863.585 1522.5,863.585 1522.49,863.585 1522.49,863.585 1522.48,863.586 1522.48,863.586 1522.47,863.586 1522.46,863.586 1522.46,863.586 1522.45,863.587 1522.45,863.587 1522.44,863.587 1522.44,863.587 1522.43,863.587 1522.42,863.587 1522.42,863.588 1522.41,863.588 1522.41,863.588 1522.4,863.588 1522.39,863.588 1522.39,863.589 1522.38,863.589 1522.38,863.589 1522.37,863.589 1522.36,863.589 1522.36,863.589 1522.35,863.59 1522.35,863.59 1522.34,863.59 1522.34,863.59 1522.33,863.59 1522.32,863.591 1522.32,863.591 1522.31,863.591 1522.31,863.591 1522.3,863.591 1522.29,863.592 1522.29,863.592 1522.28,863.592 1522.28,863.592 1522.27,863.592 1522.27,863.593 1522.26,863.593 1522.25,863.593 1522.25,863.593 1522.24,863.593 1522.24,863.594 1522.23,863.594 1522.22,863.594 1522.22,863.594 1522.21,863.594 1522.21,863.594 1522.2,863.595 1522.19,863.595 1522.19,863.595 1522.18,863.595 1522.18,863.595 1522.17,863.596 1522.17,863.596 1522.16,863.596 1522.15,863.596 1522.15,863.596 1522.14,863.597 1522.14,863.597 1522.13,863.597 1522.12,863.597 1522.12,863.598 1522.11,863.598 1522.11,863.598 1522.1,863.598 1522.1,863.598 1522.09,863.599 1522.08,863.599 1522.08,863.599 1522.07,863.599 1522.07,863.599 1522.06,863.6 1522.05,863.6 1522.05,863.6 1522.04,863.6 1522.04,863.6 1522.03,863.601 1522.03,863.601 1522.02,863.601 1522.01,863.601 1522.01,863.601 1522,863.602 1522,863.602 1521.99,863.602 1521.98,863.602 1521.98,863.603 1521.97,863.603 1521.97,863.603 1521.96,863.603 1521.95,863.603 1521.95,863.604 1521.94,863.604 1521.94,863.604 1521.93,863.604 1521.93,863.604 1521.92,863.605 1521.91,863.605 1521.91,863.605 1521.9,863.605 1521.9,863.606 1521.89,863.606 1521.88,863.606 1521.88,863.606 1521.87,863.606 1521.87,863.607 1521.86,863.607 1521.86,863.607 1521.85,863.607 1521.84,863.608 1521.84,863.608 1521.83,863.608 1521.83,863.608 1521.82,863.608 1521.81,863.609 1521.81,863.609 1521.8,863.609 1521.8,863.609 1521.79,863.61 1521.79,863.61 1521.78,863.61 1521.77,863.61 1521.77,863.611 1521.76,863.611 1521.76,863.611 1521.75,863.611 1521.74,863.611 1521.74,863.612 1521.73,863.612 1521.73,863.612 1521.72,863.612 1521.72,863.613 1521.71,863.613 1521.7,863.613 1521.7,863.613 1521.69,863.614 1521.69,863.614 1521.68,863.614 1521.67,863.614 1521.67,863.614 1521.66,863.615 1521.66,863.615 1521.65,863.615 1521.65,863.615 1521.64,863.616 1521.63,863.616 1521.63,863.616 1521.62,863.616 1521.62,863.617 1521.61,863.617 1521.61,863.617 1521.6,863.617 1521.59,863.618 1521.59,863.618 1521.58,863.618 1521.58,863.618 1521.57,863.619 1521.56,863.619 1521.56,863.619 1521.55,863.619 1521.55,863.62 1521.54,863.62 1521.54,863.62 1521.53,863.62 1521.52,863.621 1521.52,863.621 1521.51,863.621 1521.51,863.621 1521.5,863.622 1521.49,863.622 1521.49,863.622 1521.48,863.622 1521.48,863.623 1521.47,863.623 1521.47,863.623 1521.46,863.623 1521.45,863.624 1521.45,863.624 1521.44,863.624 1521.44,863.624 1521.43,863.625 1521.42,863.625 1521.42,863.625 1521.41,863.625 1521.41,863.626 1521.4,863.626 1521.4,863.626 1521.39,863.626 1521.38,863.627 1521.38,863.627 1521.37,863.627 1521.37,863.627 1521.36,863.628 1521.36,863.628 1521.35,863.628 1521.34,863.628 1521.34,863.629 1521.33,863.629 1521.33,863.629 1521.32,863.629 1521.31,863.63 1521.31,863.63 1521.3,863.63 1521.3,863.631 1521.29,863.631 1521.29,863.631 1521.28,863.631 1521.27,863.632 1521.27,863.632 1521.26,863.632 1521.26,863.632 1521.25,863.633 1521.24,863.633 1521.24,863.633 1521.23,863.633 1521.23,863.634 1521.22,863.634 1521.22,863.634 1521.21,863.635 1521.2,863.635 1521.2,863.635 1521.19,863.635 1521.19,863.636 1521.18,863.636 1521.18,863.636 1521.17,863.636 1521.16,863.637 1521.16,863.637 1521.15,863.637 1521.15,863.638 1521.14,863.638 1521.13,863.638 1521.13,863.638 1521.12,863.639 1521.12,863.639 1521.11,863.639 1521.11,863.639 1521.1,863.64 1521.09,863.64 1521.09,863.64 1521.08,863.641 1521.08,863.641 1521.07,863.641 1521.07,863.641 1521.06,863.642 1521.05,863.642 1521.05,863.642 1521.04,863.643 1521.04,863.643 1521.03,863.643 1521.02,863.643 1521.02,863.644 1521.01,863.644 1521.01,863.644 1521,863.645 1521,863.645 1520.99,863.645 1520.98,863.645 1520.98,863.646 1520.97,863.646 1520.97,863.646 1520.96,863.647 1520.96,863.647 1520.95,863.647 1520.94,863.647 1520.94,863.648 1520.93,863.648 1520.93,863.648 1520.92,863.649 1520.92,863.649 1520.91,863.649 1520.9,863.649 1520.9,863.65 1520.89,863.65 1520.89,863.65 1520.88,863.651 1520.87,863.651 1520.87,863.651 1520.86,863.652 1520.86,863.652 1520.85,863.652 1520.85,863.652 1520.84,863.653 1520.83,863.653 1520.83,863.653 1520.82,863.654 1520.82,863.654 1520.81,863.654 1520.81,863.655 1520.8,863.655 1520.79,863.655 1520.79,863.655 1520.78,863.656 1520.78,863.656 1520.77,863.656 1520.77,863.657 1520.76,863.657 1520.75,863.657 1520.75,863.658 1520.74,863.658 1520.74,863.658 1520.73,863.658 1520.72,863.659 1520.72,863.659 1520.71,863.659 1520.71,863.66 1520.7,863.66 1520.7,863.66 1520.69,863.661 1520.68,863.661 1520.68,863.661 1520.67,863.662 1520.67,863.662 1520.66,863.662 1520.66,863.662 1520.65,863.663 1520.64,863.663 1520.64,863.663 1520.63,863.664 1520.63,863.664 1520.62,863.664 1520.62,863.665 1520.61,863.665 1520.6,863.665 1520.6,863.666 1520.59,863.666 1520.59,863.666 1520.58,863.667 1520.57,863.667 1520.57,863.667 1520.56,863.668 1520.56,863.668 1520.55,863.668 1520.55,863.669 1520.54,863.669 1520.53,863.669 1520.53,863.669 1520.52,863.67 1520.52,863.67 1520.51,863.67 1520.51,863.671 1520.5,863.671 1520.49,863.671 1520.49,863.672 1520.48,863.672 1520.48,863.672 1520.47,863.673 1520.47,863.673 1520.46,863.673 1520.45,863.674 1520.45,863.674 1520.44,863.674 1520.44,863.675 1520.43,863.675 1520.43,863.675 1520.42,863.676 1520.41,863.676 1520.41,863.676 1520.4,863.677 1520.4,863.677 1520.39,863.677 1520.39,863.678 1520.38,863.678 1520.37,863.678 1520.37,863.679 1520.36,863.679 1520.36,863.679 1520.35,863.68 1520.35,863.68 1520.34,863.68 1520.33,863.681 1520.33,863.681 1520.32,863.681 1520.32,863.682 1520.31,863.682 1520.3,863.682 1520.3,863.683 1520.29,863.683 1520.29,863.683 1520.28,863.684 1520.28,863.684 1520.27,863.684 1520.26,863.685 1520.26,863.685 1520.25,863.685 1520.25,863.686 1520.24,863.686 1520.24,863.687 1520.23,863.687 1520.22,863.687 1520.22,863.688 1520.21,863.688 1520.21,863.688 1520.2,863.689 1520.2,863.689 1520.19,863.689 1520.18,863.69 1520.18,863.69 1520.17,863.69 1520.17,863.691 1520.16,863.691 1520.16,863.691 1520.15,863.692 1520.14,863.692 1520.14,863.692 1520.13,863.693 1520.13,863.693 1520.12,863.694 1520.12,863.694 1520.11,863.694 1520.1,863.695 1520.1,863.695 1520.09,863.695 1520.09,863.696 1520.08,863.696 1520.08,863.696 1520.07,863.697 1520.06,863.697 1520.06,863.697 1520.05,863.698 1520.05,863.698 1520.04,863.699 1520.04,863.699 1520.03,863.699 1520.02,863.7 1520.02,863.7 1520.01,863.7 1520.01,863.701 1520,863.701 1520,863.701 1519.99,863.702 1519.98,863.702 1519.98,863.703 1519.97,863.703 1519.97,863.703 1519.96,863.704 1519.96,863.704 1519.95,863.704 1519.94,863.705 1519.94,863.705 1519.93,863.705 1519.93,863.706 1519.92,863.706 1519.92,863.707 1519.91,863.707 1519.9,863.707 1519.9,863.708 1519.89,863.708 1519.89,863.708 1519.88,863.709 1519.88,863.709 1519.87,863.71 1519.86,863.71 1519.86,863.71 1519.85,863.711 1519.85,863.711 1519.84,863.711 1519.84,863.712 1519.83,863.712 1519.82,863.713 1519.82,863.713 1519.81,863.713 1519.81,863.714 1519.8,863.714 1519.8,863.714 1519.79,863.715 1519.78,863.715 1519.78,863.716 1519.77,863.716 1519.77,863.716 1519.76,863.717 1519.76,863.717 1519.75,863.718 1519.74,863.718 1519.74,863.718 1519.73,863.719 1519.73,863.719 1519.72,863.719 1519.72,863.72 1519.71,863.72 1519.7,863.721 1519.7,863.721 1519.69,863.721 1519.69,863.722 1519.68,863.722 1519.68,863.723 1519.67,863.723 1519.66,863.723 1519.66,863.724 1519.65,863.724 1519.65,863.725 1519.64,863.725 1519.64,863.725 1519.63,863.726 1519.63,863.726 1519.62,863.727 1519.61,863.727 1519.61,863.727 1519.6,863.728 1519.6,863.728 1519.59,863.729 1519.59,863.729 1519.58,863.729 1519.57,863.73 1519.57,863.73 1519.56,863.731 1519.56,863.731 1519.55,863.731 1519.55,863.732 1519.54,863.732 1519.53,863.733 1519.53,863.733 1519.52,863.733 1519.52,863.734 1519.51,863.734 1519.51,863.735 1519.5,863.735 1519.49,863.735 1519.49,863.736 1519.48,863.736 1519.48,863.737 1519.47,863.737 1519.47,863.737 1519.46,863.738 1519.45,863.738 1519.45,863.739 1519.44,863.739 1519.44,863.739 1519.43,863.74 1519.43,863.74 1519.42,863.741 1519.41,863.741 1519.41,863.742 1519.4,863.742 1519.4,863.742 1519.39,863.743 1519.39,863.743 1519.38,863.744 1519.38,863.744 1519.37,863.744 1519.36,863.745 1519.36,863.745 1519.35,863.746 1519.35,863.746 1519.34,863.747 1519.34,863.747 1519.33,863.747 1519.32,863.748 1519.32,863.748 1519.31,863.749 1519.31,863.749 1519.3,863.749 1519.3,863.75 1519.29,863.75 1519.28,863.751 1519.28,863.751 1519.27,863.752 1519.27,863.752 1519.26,863.752 1519.26,863.753 1519.25,863.753 1519.24,863.754 1519.24,863.754 1519.23,863.755 1519.23,863.755 1519.22,863.755 1519.22,863.756 1519.21,863.756 1519.21,863.757 1519.2,863.757 1519.19,863.758 1519.19,863.758 1519.18,863.758 1519.18,863.759 1519.17,863.759 1519.17,863.76 1519.16,863.76 1519.15,863.761 1519.15,863.761 1519.14,863.761 1519.14,863.762 1519.13,863.762 1519.13,863.763 1519.12,863.763 1519.11,863.764 1519.11,863.764 1519.1,863.765 1519.1,863.765 1519.09,863.765 1519.09,863.766 1519.08,863.766 1519.08,863.767 1519.07,863.767 1519.06,863.768 1519.06,863.768 1519.05,863.769 1519.05,863.769 1519.04,863.769 1519.04,863.77 1519.03,863.77 1519.02,863.771 1519.02,863.771 1519.01,863.772 1519.01,863.772 1519,863.773 1519,863.773 1518.99,863.773 1518.98,863.774 1518.98,863.774 1518.97,863.775 1518.97,863.775 1518.96,863.776 1518.96,863.776 1518.95,863.777 1518.95,863.777 1518.94,863.778 1518.93,863.778 1518.93,863.778 1518.92,863.779 1518.92,863.779 1518.91,863.78 1518.91,863.78 1518.9,863.781 1518.89,863.781 1518.89,863.782 1518.88,863.782 1518.88,863.783 1518.87,863.783 1518.87,863.783 1518.86,863.784 1518.85,863.784 1518.85,863.785 1518.84,863.785 1518.84,863.786 1518.83,863.786 1518.83,863.787 1518.82,863.787 1518.82,863.788 1518.81,863.788 1518.8,863.789 1518.8,863.789 1518.79,863.789 1518.79,863.79 1518.78,863.79 1518.78,863.791 1518.77,863.791 1518.76,863.792 1518.76,863.792 1518.75,863.793 1518.75,863.793 1518.74,863.794 1518.74,863.794 1518.73,863.795 1518.73,863.795 1518.72,863.796 1518.71,863.796 1518.71,863.797 1518.7,863.797 1518.7,863.797 1518.69,863.798 1518.69,863.798 1518.68,863.799 1518.67,863.799 1518.67,863.8 1518.66,863.8 1518.66,863.801 1518.65,863.801 1518.65,863.802 1518.64,863.802 1518.64,863.803 1518.63,863.803 1518.62,863.804 1518.62,863.804 1518.61,863.805 1518.61,863.805 1518.6,863.806 1518.6,863.806 1518.59,863.807 1518.58,863.807 1518.58,863.808 1518.57,863.808 1518.57,863.809 1518.56,863.809 1518.56,863.81 1518.55,863.81 1518.55,863.811 1518.54,863.811 1518.53,863.811 1518.53,863.812 1518.52,863.812 1518.52,863.813 1518.51,863.813 1518.51,863.814 1518.5,863.814 1518.49,863.815 1518.49,863.815 1518.48,863.816 1518.48,863.816 1518.47,863.817 1518.47,863.817 1518.46,863.818 1518.46,863.818 1518.45,863.819 1518.44,863.819 1518.44,863.82 1518.43,863.82 1518.43,863.821 1518.42,863.821 1518.42,863.822 1518.41,863.822 1518.41,863.823 1518.4,863.823 1518.39,863.824 1518.39,863.824 1518.38,863.825 1518.38,863.825 1518.37,863.826 1518.37,863.826 1518.36,863.827 1518.35,863.827 1518.35,863.828 1518.34,863.828 1518.34,863.829 1518.33,863.829 1518.33,863.83 1518.32,863.83 1518.32,863.831 1518.31,863.832 1518.3,863.832 1518.3,863.833 1518.29,863.833 1518.29,863.834 1518.28,863.834 1518.28,863.835 1518.27,863.835 1518.27,863.836 1518.26,863.836 1518.25,863.837 1518.25,863.837 1518.24,863.838 1518.24,863.838 1518.23,863.839 1518.23,863.839 1518.22,863.84 1518.21,863.84 1518.21,863.841 1518.2,863.841 1518.2,863.842 1518.19,863.842 1518.19,863.843 1518.18,863.843 1518.18,863.844 1518.17,863.844 1518.16,863.845 1518.16,863.845 1518.15,863.846 1518.15,863.847 1518.14,863.847 1518.14,863.848 1518.13,863.848 1518.13,863.849 1518.12,863.849 1518.11,863.85 1518.11,863.85 1518.1,863.851 1518.1,863.851 1518.09,863.852 1518.09,863.852 1518.08,863.853 1518.08,863.853 1518.07,863.854 1518.06,863.854 1518.06,863.855 1518.05,863.856 1518.05,863.856 1518.04,863.857 1518.04,863.857 1518.03,863.858 1518.02,863.858 1518.02,863.859 1518.01,863.859 1518.01,863.86 1518,863.86 1518,863.861 1517.99,863.861 1517.99,863.862 1517.98,863.863 1517.97,863.863 1517.97,863.864 1517.96,863.864 1517.96,863.865 1517.95,863.865 1517.95,863.866 1517.94,863.866 1517.94,863.867 1517.93,863.867 1517.92,863.868 1517.92,863.869 1517.91,863.869 1517.91,863.87 1517.9,863.87 1517.9,863.871 1517.89,863.871 1517.89,863.872 1517.88,863.872 1517.87,863.873 1517.87,863.873 1517.86,863.874 1517.86,863.875 1517.85,863.875 1517.85,863.876 1517.84,863.876 1517.84,863.877 1517.83,863.877 1517.82,863.878 1517.82,863.878 1517.81,863.879 1517.81,863.88 1517.8,863.88 1517.8,863.881 1517.79,863.881 1517.79,863.882 1517.78,863.882 1517.77,863.883 1517.77,863.883 1517.76,863.884 1517.76,863.885 1517.75,863.885 1517.75,863.886 1517.74,863.886 1517.74,863.887 1517.73,863.887 1517.72,863.888 1517.72,863.889 1517.71,863.889 1517.71,863.89 1517.7,863.89 1517.7,863.891 1517.69,863.891 1517.69,863.892 1517.68,863.892 1517.67,863.893 1517.67,863.894 1517.66,863.894 1517.66,863.895 1517.65,863.895 1517.65,863.896 1517.64,863.896 1517.64,863.897 1517.63,863.898 1517.62,863.898 1517.62,863.899 1517.61,863.899 1517.61,863.9 1517.6,863.901 1517.6,863.901 1517.59,863.902 1517.59,863.902 1517.58,863.903 1517.57,863.903 1517.57,863.904 1517.56,863.905 1517.56,863.905 1517.55,863.906 1517.55,863.906 1517.54,863.907 1517.54,863.907 1517.53,863.908 1517.52,863.909 1517.52,863.909 1517.51,863.91 1517.51,863.91 1517.5,863.911 1517.5,863.912 1517.49,863.912 1517.49,863.913 1517.48,863.913 1517.47,863.914 1517.47,863.915 1517.46,863.915 1517.46,863.916 1517.45,863.916 1517.45,863.917 1517.44,863.917 1517.44,863.918 1517.43,863.919 1517.42,863.919 1517.42,863.92 1517.41,863.92 1517.41,863.921 1517.4,863.922 1517.4,863.922 1517.39,863.923 1517.39,863.923 1517.38,863.924 1517.38,863.925 1517.37,863.925 1517.36,863.926 1517.36,863.926 1517.35,863.927 1517.35,863.928 1517.34,863.928 1517.34,863.929 1517.33,863.929 1517.33,863.93 1517.32,863.931 1517.31,863.931 1517.31,863.932 1517.3,863.932 1517.3,863.933 1517.29,863.934 1517.29,863.934 1517.28,863.935 1517.28,863.936 1517.27,863.936 1517.26,863.937 1517.26,863.937 1517.25,863.938 1517.25,863.939 1517.24,863.939 1517.24,863.94 1517.23,863.94 1517.23,863.941 1517.22,863.942 1517.21,863.942 1517.21,863.943 1517.2,863.943 1517.2,863.944 1517.19,863.945 1517.19,863.945 1517.18,863.946 1517.18,863.947 1517.17,863.947 1517.17,863.948 1517.16,863.948 1517.15,863.949 1517.15,863.95 1517.14,863.95 1517.14,863.951 1517.13,863.952 1517.13,863.952 1517.12,863.953 1517.12,863.953 1517.11,863.954 1517.1,863.955 1517.1,863.955 1517.09,863.956 1517.09,863.957 1517.08,863.957 1517.08,863.958 1517.07,863.958 1517.07,863.959 1517.06,863.96 1517.06,863.96 1517.05,863.961 1517.04,863.962 1517.04,863.962 1517.03,863.963 1517.03,863.963 1517.02,863.964 1517.02,863.965 1517.01,863.965 1517.01,863.966 1517,863.967 1516.99,863.967 1516.99,863.968 1516.98,863.969 1516.98,863.969 1516.97,863.97 1516.97,863.97 1516.96,863.971 1516.96,863.972 1516.95,863.972 1516.95,863.973 1516.94,863.974 1516.93,863.974 1516.93,863.975 1516.92,863.976 1516.92,863.976 1516.91,863.977 1516.91,863.978 1516.9,863.978 1516.9,863.979 1516.89,863.979 1516.88,863.98 1516.88,863.981 1516.87,863.981 1516.87,863.982 1516.86,863.983 1516.86,863.983 1516.85,863.984 1516.85,863.985 1516.84,863.985 1516.84,863.986 1516.83,863.987 1516.82,863.987 1516.82,863.988 1516.81,863.989 1516.81,863.989 1516.8,863.99 1516.8,863.991 1516.79,863.991 1516.79,863.992 1516.78,863.993 1516.77,863.993 1516.77,863.994 1516.76,863.995 1516.76,863.995 1516.75,863.996 1516.75,863.997 1516.74,863.997 1516.74,863.998 1516.73,863.999 1516.73,863.999 1516.72,864 1516.71,864.001 1516.71,864.001 1516.7,864.002 1516.7,864.003 1516.69,864.003 1516.69,864.004 1516.68,864.005 1516.68,864.005 1516.67,864.006 1516.67,864.007 1516.66,864.007 1516.65,864.008 1516.65,864.009 1516.64,864.009 1516.64,864.01 1516.63,864.011 1516.63,864.011 1516.62,864.012 1516.62,864.013 1516.61,864.013 1516.6,864.014 1516.6,864.015 1516.59,864.015 1516.59,864.016 1516.58,864.017 1516.58,864.017 1516.57,864.018 1516.57,864.019 1516.56,864.019 1516.56,864.02 1516.55,864.021 1516.54,864.021 1516.54,864.022 1516.53,864.023 1516.53,864.023 1516.52,864.024 1516.52,864.025 1516.51,864.026 1516.51,864.026 1516.5,864.027 1516.5,864.028 1516.49,864.028 1516.48,864.029 1516.48,864.03 1516.47,864.03 1516.47,864.031 1516.46,864.032 1516.46,864.032 1516.45,864.033 1516.45,864.034 1516.44,864.035 1516.44,864.035 1516.43,864.036 1516.42,864.037 1516.42,864.037 1516.41,864.038 1516.41,864.039 1516.4,864.039 1516.4,864.04 1516.39,864.041 1516.39,864.041 1516.38,864.042 1516.38,864.043 1516.37,864.044 1516.36,864.044 1516.36,864.045 1516.35,864.046 1516.35,864.046 1516.34,864.047 1516.34,864.048 1516.33,864.049 1516.33,864.049 1516.32,864.05 1516.32,864.051 1516.31,864.051 1516.3,864.052 1516.3,864.053 1516.29,864.053 1516.29,864.054 1516.28,864.055 1516.28,864.056 1516.27,864.056 1516.27,864.057 1516.26,864.058 1516.26,864.058 1516.25,864.059 1516.24,864.06 1516.24,864.061 1516.23,864.061 1516.23,864.062 1516.22,864.063 1516.22,864.063 1516.21,864.064 1516.21,864.065 1516.2,864.066 1516.2,864.066 1516.19,864.067 1516.18,864.068 1516.18,864.069 1516.17,864.069 1516.17,864.07 1516.16,864.071 1516.16,864.071 1516.15,864.072 1516.15,864.073 1516.14,864.074 1516.14,864.074 1516.13,864.075 1516.13,864.076 1516.12,864.077 1516.11,864.077 1516.11,864.078 1516.1,864.079 1516.1,864.079 1516.09,864.08 1516.09,864.081 1516.08,864.082 1516.08,864.082 1516.07,864.083 1516.07,864.084 1516.06,864.085 1516.05,864.085 1516.05,864.086 1516.04,864.087 1516.04,864.088 1516.03,864.088 1516.03,864.089 1516.02,864.09 1516.02,864.09 1516.01,864.091 1516.01,864.092 1516,864.093 1515.99,864.093 1515.99,864.094 1515.98,864.095 1515.98,864.096 1515.97,864.096 1515.97,864.097 1515.96,864.098 1515.96,864.099 1515.95,864.099 1515.95,864.1 1515.94,864.101 1515.94,864.102 1515.93,864.102 1515.92,864.103 1515.92,864.104 1515.91,864.105 1515.91,864.105 1515.9,864.106 1515.9,864.107 1515.89,864.108 1515.89,864.108 1515.88,864.109 1515.88,864.11 1515.87,864.111 1515.86,864.111 1515.86,864.112 1515.85,864.113 1515.85,864.114 1515.84,864.114 1515.84,864.115 1515.83,864.116 1515.83,864.117 1515.82,864.118 1515.82,864.118 1515.81,864.119 1515.81,864.12 1515.8,864.121 1515.79,864.121 1515.79,864.122 1515.78,864.123 1515.78,864.124 1515.77,864.124 1515.77,864.125 1515.76,864.126 1515.76,864.127 1515.75,864.127 1515.75,864.128 1515.74,864.129 1515.73,864.13 1515.73,864.131 1515.72,864.131 1515.72,864.132 1515.71,864.133 1515.71,864.134 1515.7,864.134 1515.7,864.135 1515.69,864.136 1515.69,864.137 1515.68,864.138 1515.68,864.138 1515.67,864.139 1515.66,864.14 1515.66,864.141 1515.65,864.141 1515.65,864.142 1515.64,864.143 1515.64,864.144 1515.63,864.145 1515.63,864.145 1515.62,864.146 1515.62,864.147 1515.61,864.148 1515.61,864.148 1515.6,864.149 1515.59,864.15 1515.59,864.151 1515.58,864.152 1515.58,864.152 1515.57,864.153 1515.57,864.154 1515.56,864.155 1515.56,864.156 1515.55,864.156 1515.55,864.157 1515.54,864.158 1515.54,864.159 1515.53,864.16 1515.52,864.16 1515.52,864.161 1515.51,864.162 1515.51,864.163 1515.5,864.164 1515.5,864.164 1515.49,864.165 1515.49,864.166 1515.48,864.167 1515.48,864.167 1515.47,864.168 1515.47,864.169 1515.46,864.17 1515.45,864.171 1515.45,864.172 1515.44,864.172 1515.44,864.173 1515.43,864.174 1515.43,864.175 1515.42,864.176 1515.42,864.176 1515.41,864.177 1515.41,864.178 1515.4,864.179 1515.4,864.18 1515.39,864.18 1515.38,864.181 1515.38,864.182 1515.37,864.183 1515.37,864.184 1515.36,864.184 1515.36,864.185 1515.35,864.186 1515.35,864.187 1515.34,864.188 1515.34,864.189 1515.33,864.189 1515.33,864.19 1515.32,864.191 1515.31,864.192 1515.31,864.193 1515.3,864.193 1515.3,864.194 1515.29,864.195 1515.29,864.196 1515.28,864.197 1515.28,864.198 1515.27,864.198 1515.27,864.199 1515.26,864.2 1515.26,864.201 1515.25,864.202 1515.24,864.203 1515.24,864.203 1515.23,864.204 1515.23,864.205 1515.22,864.206 1515.22,864.207 1515.21,864.207 1515.21,864.208 1515.2,864.209 1515.2,864.21 1515.19,864.211 1515.19,864.212 1515.18,864.212 1515.18,864.213 1515.17,864.214 1515.16,864.215 1515.16,864.216 1515.15,864.217 1515.15,864.218 1515.14,864.218 1515.14,864.219 1515.13,864.22 1515.13,864.221 1515.12,864.222 1515.12,864.223 1515.11,864.223 1515.11,864.224 1515.1,864.225 1515.09,864.226 1515.09,864.227 1515.08,864.228 1515.08,864.228 1515.07,864.229 1515.07,864.23 1515.06,864.231 1515.06,864.232 1515.05,864.233 1515.05,864.234 1515.04,864.234 1515.04,864.235 1515.03,864.236 1515.03,864.237 1515.02,864.238 1515.01,864.239 1515.01,864.24 1515,864.24 1515,864.241 1514.99,864.242 1514.99,864.243 1514.98,864.244 1514.98,864.245 1514.97,864.246 1514.97,864.246 1514.96,864.247 1514.96,864.248 1514.95,864.249 1514.95,864.25 1514.94,864.251 1514.93,864.252 1514.93,864.252 1514.92,864.253 1514.92,864.254 1514.91,864.255 1514.91,864.256 1514.9,864.257 1514.9,864.258 1514.89,864.258 1514.89,864.259 1514.88,864.26 1514.88,864.261 1514.87,864.262 1514.87,864.263 1514.86,864.264 1514.85,864.265 1514.85,864.265 1514.84,864.266 1514.84,864.267 1514.83,864.268 1514.83,864.269 1514.82,864.27 1514.82,864.271 1514.81,864.272 1514.81,864.272 1514.8,864.273 1514.8,864.274 1514.79,864.275 1514.79,864.276 1514.78,864.277 1514.77,864.278 1514.77,864.279 1514.76,864.28 1514.76,864.28 1514.75,864.281 1514.75,864.282 1514.74,864.283 1514.74,864.284 1514.73,864.285 1514.73,864.286 1514.72,864.287 1514.72,864.288 1514.71,864.288 1514.71,864.289 1514.7,864.29 1514.69,864.291 1514.69,864.292 1514.68,864.293 1514.68,864.294 1514.67,864.295 1514.67,864.296 1514.66,864.296 1514.66,864.297 1514.65,864.298 1514.65,864.299 1514.64,864.3 1514.64,864.301 1514.63,864.302 1514.63,864.303 1514.62,864.304 1514.61,864.305 1514.61,864.305 1514.6,864.306 1514.6,864.307 1514.59,864.308 1514.59,864.309 1514.58,864.31 1514.58,864.311 1514.57,864.312 1514.57,864.313 1514.56,864.314 1514.56,864.315 1514.55,864.315 1514.55,864.316 1514.54,864.317 1514.54,864.318 1514.53,864.319 1514.52,864.32 1514.52,864.321 1514.51,864.322 1514.51,864.323 1514.5,864.324 1514.5,864.325 1514.49,864.326 1514.49,864.326 1514.48,864.327 1514.48,864.328 1514.47,864.329 1514.47,864.33 1514.46,864.331 1514.46,864.332 1514.45,864.333 1514.45,864.334 1514.44,864.335 1514.43,864.336 1514.43,864.337 1514.42,864.338 1514.42,864.338 1514.41,864.339 1514.41,864.34 1514.4,864.341 1514.4,864.342 1514.39,864.343 1514.39,864.344 1514.38,864.345 1514.38,864.346 1514.37,864.347 1514.37,864.348 1514.36,864.349 1514.36,864.35 1514.35,864.351 1514.34,864.351 1514.34,864.352 1514.33,864.353 1514.33,864.354 1514.32,864.355 1514.32,864.356 1514.31,864.357 1514.31,864.358 1514.3,864.359 1514.3,864.36 1514.29,864.361 1514.29,864.362 1514.28,864.363 1514.28,864.364 1514.27,864.365 1514.27,864.366 1514.26,864.367 1514.25,864.368 1514.25,864.368 1514.24,864.369 1514.24,864.37 1514.23,864.371 1514.23,864.372 1514.22,864.373 1514.22,864.374 1514.21,864.375 1514.21,864.376 1514.2,864.377 1514.2,864.378 1514.19,864.379 1514.19,864.38 1514.18,864.381 1514.18,864.382 1514.17,864.383 1514.17,864.384 1514.16,864.385 1514.15,864.386 1514.15,864.387 1514.14,864.388 1514.14,864.389 1514.13,864.389 1514.13,864.39 1514.12,864.391 1514.12,864.392 1514.11,864.393 1514.11,864.394 1514.1,864.395 1514.1,864.396 1514.09,864.397 1514.09,864.398 1514.08,864.399 1514.08,864.4 1514.07,864.401 1514.07,864.402 1514.06,864.403 1514.05,864.404 1514.05,864.405 1514.04,864.406 1514.04,864.407 1514.03,864.408 1514.03,864.409 1514.02,864.41 1514.02,864.411 1514.01,864.412 1514.01,864.413 1514,864.414 1514,864.415 1513.99,864.416 1513.99,864.417 1513.98,864.418 1513.98,864.419 1513.97,864.42 1513.97,864.421 1513.96,864.422 1513.95,864.423 1513.95,864.424 1513.94,864.425 1513.94,864.426 1513.93,864.427 1513.93,864.428 1513.92,864.429 1513.92,864.43 1513.91,864.431 1513.91,864.432 1513.9,864.433 1513.9,864.434 1513.89,864.435 1513.89,864.436 1513.88,864.437 1513.88,864.438 1513.87,864.439 1513.87,864.44 1513.86,864.441 1513.85,864.442 1513.85,864.443 1513.84,864.444 1513.84,864.445 1513.83,864.446 1513.83,864.447 1513.82,864.448 1513.82,864.449 1513.81,864.45 1513.81,864.451 1513.8,864.452 1513.8,864.453 1513.79,864.454 1513.79,864.455 1513.78,864.456 1513.78,864.457 1513.77,864.458 1513.77,864.459 1513.76,864.46 1513.76,864.461 1513.75,864.462 1513.74,864.463 1513.74,864.464 1513.73,864.465 1513.73,864.466 1513.72,864.467 1513.72,864.468 1513.71,864.469 1513.71,864.47 1513.7,864.471 1513.7,864.472 1513.69,864.473 1513.69,864.474 1513.68,864.475 1513.68,864.476 1513.67,864.477 1513.67,864.478 1513.66,864.479 1513.66,864.48 1513.65,864.481 1513.65,864.482 1513.64,864.483 1513.63,864.484 1513.63,864.485 1513.62,864.486 1513.62,864.487 1513.61,864.488 1513.61,864.489 1513.6,864.49 1513.6,864.491 1513.59,864.492 1513.59,864.493 1513.58,864.494 1513.58,864.495 1513.57,864.497 1513.57,864.498 1513.56,864.499 1513.56,864.5 1513.55,864.501 1513.55,864.502 1513.54,864.503 1513.54,864.504 1513.53,864.505 1513.53,864.506 1513.52,864.507 1513.51,864.508 1513.51,864.509 1513.5,864.51 1513.5,864.511 1513.49,864.512 1513.49,864.513 1513.48,864.514 1513.48,864.515 1513.47,864.516 1513.47,864.517 1513.46,864.518 1513.46,864.52 1513.45,864.521 1513.45,864.522 1513.44,864.523 1513.44,864.524 1513.43,864.525 1513.43,864.526 1513.42,864.527 1513.42,864.528 1513.41,864.529 1513.41,864.53 1513.4,864.531 1513.4,864.532 1513.39,864.533 1513.38,864.534 1513.38,864.535 1513.37,864.536 1513.37,864.538 1513.36,864.539 1513.36,864.54 1513.35,864.541 1513.35,864.542 1513.34,864.543 1513.34,864.544 1513.33,864.545 1513.33,864.546 1513.32,864.547 1513.32,864.548 1513.31,864.549 1513.31,864.55 1513.3,864.551 1513.3,864.553 1513.29,864.554 1513.29,864.555 1513.28,864.556 1513.28,864.557 1513.27,864.558 1513.27,864.559 1513.26,864.56 1513.25,864.561 1513.25,864.562 1513.24,864.563 1513.24,864.564 1513.23,864.565 1513.23,864.567 1513.22,864.568 1513.22,864.569 1513.21,864.57 1513.21,864.571 1513.2,864.572 1513.2,864.573 1513.19,864.574 1513.19,864.575 1513.18,864.576 1513.18,864.577 1513.17,864.579 1513.17,864.58 1513.16,864.581 1513.16,864.582 1513.15,864.583 1513.15,864.584 1513.14,864.585 1513.14,864.586 1513.13,864.587 1513.13,864.588 1513.12,864.59 1513.11,864.591 1513.11,864.592 1513.1,864.593 1513.1,864.594 1513.09,864.595 1513.09,864.596 1513.08,864.597 1513.08,864.598 1513.07,864.599 1513.07,864.601 1513.06,864.602 1513.06,864.603 1513.05,864.604 1513.05,864.605 1513.04,864.606 1513.04,864.607 1513.03,864.608 1513.03,864.609 1513.02,864.611 1513.02,864.612 1513.01,864.613 1513.01,864.614 1513,864.615 1513,864.616 1512.99,864.617 1512.99,864.618 1512.98,864.619 1512.98,864.621 1512.97,864.622 1512.96,864.623 1512.96,864.624 1512.95,864.625 1512.95,864.626 1512.94,864.627 1512.94,864.628 1512.93,864.63 1512.93,864.631 1512.92,864.632 1512.92,864.633 1512.91,864.634 1512.91,864.635 1512.9,864.636 1512.9,864.637 1512.89,864.639 1512.89,864.64 1512.88,864.641 1512.88,864.642 1512.87,864.643 1512.87,864.644 1512.86,864.645 1512.86,864.647 1512.85,864.648 1512.85,864.649 1512.84,864.65 1512.84,864.651 1512.83,864.652 1512.83,864.653 1512.82,864.655 1512.82,864.656 1512.81,864.657 1512.8,864.658 1512.8,864.659 1512.79,864.66 1512.79,864.661 1512.78,864.663 1512.78,864.664 1512.77,864.665 1512.77,864.666 1512.76,864.667 1512.76,864.668 1512.75,864.669 1512.75,864.671 1512.74,864.672 1512.74,864.673 1512.73,864.674 1512.73,864.675 1512.72,864.676 1512.72,864.678 1512.71,864.679 1512.71,864.68 1512.7,864.681 1512.7,864.682 1512.69,864.683 1512.69,864.684 1512.68,864.686 1512.68,864.687 1512.67,864.688 1512.67,864.689 1512.66,864.69 1512.66,864.691 1512.65,864.693 1512.65,864.694 1512.64,864.695 1512.64,864.696 1512.63,864.697 1512.62,864.698 1512.62,864.7 1512.61,864.701 1512.61,864.702 1512.6,864.703 1512.6,864.704 1512.59,864.706 1512.59,864.707 1512.58,864.708 1512.58,864.709 1512.57,864.71 1512.57,864.711 1512.56,864.713 1512.56,864.714 1512.55,864.715 1512.55,864.716 1512.54,864.717 1512.54,864.719 1512.53,864.72 1512.53,864.721 1512.52,864.722 1512.52,864.723 1512.51,864.724 1512.51,864.726 1512.5,864.727 1512.5,864.728 1512.49,864.729 1512.49,864.73 1512.48,864.732 1512.48,864.733 1512.47,864.734 1512.47,864.735 1512.46,864.736 1512.46,864.738 1512.45,864.739 1512.45,864.74 1512.44,864.741 1512.44,864.742 1512.43,864.744 1512.43,864.745 1512.42,864.746 1512.41,864.747 1512.41,864.748 1512.4,864.75 1512.4,864.751 1512.39,864.752 1512.39,864.753 1512.38,864.754 1512.38,864.756 1512.37,864.757 1512.37,864.758 1512.36,864.759 1512.36,864.76 1512.35,864.762 1512.35,864.763 1512.34,864.764 1512.34,864.765 1512.33,864.766 1512.33,864.768 1512.32,864.769 1512.32,864.77 1512.31,864.771 1512.31,864.773 1512.3,864.774 1512.3,864.775 1512.29,864.776 1512.29,864.777 1512.28,864.779 1512.28,864.78 1512.27,864.781 1512.27,864.782 1512.26,864.784 1512.26,864.785 1512.25,864.786 1512.25,864.787 1512.24,864.788 1512.24,864.79 1512.23,864.791 1512.23,864.792 1512.22,864.793 1512.22,864.795 1512.21,864.796 1512.21,864.797 1512.2,864.798 1512.2,864.8 1512.19,864.801 1512.19,864.802 1512.18,864.803 1512.18,864.805 1512.17,864.806 1512.17,864.807 1512.16,864.808 1512.15,864.809 1512.15,864.811 1512.14,864.812 1512.14,864.813 1512.13,864.814 1512.13,864.816 1512.12,864.817 1512.12,864.818 1512.11,864.819 1512.11,864.821 1512.1,864.822 1512.1,864.823 1512.09,864.824 1512.09,864.826 1512.08,864.827 1512.08,864.828 1512.07,864.829 1512.07,864.831 1512.06,864.832 1512.06,864.833 1512.05,864.834 1512.05,864.836 1512.04,864.837 1512.04,864.838 1512.03,864.84 1512.03,864.841 1512.02,864.842 1512.02,864.843 1512.01,864.845 1512.01,864.846 1512,864.847 1512,864.848 1511.99,864.85 1511.99,864.851 1511.98,864.852 1511.98,864.853 1511.97,864.855 1511.97,864.856 1511.96,864.857 1511.96,864.859 1511.95,864.86 1511.95,864.861 1511.94,864.862 1511.94,864.864 1511.93,864.865 1511.93,864.866 1511.92,864.867 1511.92,864.869 1511.91,864.87 1511.91,864.871 1511.9,864.873 1511.9,864.874 1511.89,864.875 1511.89,864.876 1511.88,864.878 1511.88,864.879 1511.87,864.88 1511.87,864.882 1511.86,864.883 1511.86,864.884 1511.85,864.885 1511.85,864.887 1511.84,864.888 1511.84,864.889 1511.83,864.891 1511.83,864.892 1511.82,864.893 1511.82,864.894 1511.81,864.896 1511.81,864.897 1511.8,864.898 1511.79,864.9 1511.79,864.901 1511.78,864.902 1511.78,864.904 1511.77,864.905 1511.77,864.906 1511.76,864.907 1511.76,864.909 1511.75,864.91 1511.75,864.911 1511.74,864.913 1511.74,864.914 1511.73,864.915 1511.73,864.917 1511.72,864.918 1511.72,864.919 1511.71,864.921 1511.71,864.922 1511.7,864.923 1511.7,864.924 1511.69,864.926 1511.69,864.927 1511.68,864.928 1511.68,864.93 1511.67,864.931 1511.67,864.932 1511.66,864.934 1511.66,864.935 1511.65,864.936 1511.65,864.938 1511.64,864.939 1511.64,864.94 1511.63,864.942 1511.63,864.943 1511.62,864.944 1511.62,864.946 1511.61,864.947 1511.61,864.948 1511.6,864.95 1511.6,864.951 1511.59,864.952 1511.59,864.954 1511.58,864.955 1511.58,864.956 1511.57,864.958 1511.57,864.959 1511.56,864.96 1511.56,864.962 1511.55,864.963 1511.55,864.964 1511.54,864.966 1511.54,864.967 1511.53,864.968 1511.53,864.97 1511.52,864.971 1511.52,864.972 1511.51,864.974 1511.51,864.975 1511.5,864.976 1511.5,864.978 1511.49,864.979 1511.49,864.98 1511.48,864.982 1511.48,864.983 1511.47,864.984 1511.47,864.986 1511.46,864.987 1511.46,864.988 1511.45,864.99 1511.45,864.991 1511.44,864.993 1511.44,864.994 1511.43,864.995 1511.43,864.997 1511.42,864.998 1511.42,864.999 1511.41,865.001 1511.41,865.002 1511.4,865.003 1511.4,865.005 1511.39,865.006 1511.39,865.007 1511.38,865.009 1511.38,865.01 1511.37,865.012 1511.37,865.013 1511.36,865.014 1511.36,865.016 1511.35,865.017 1511.35,865.018 1511.34,865.02 1511.34,865.021 1511.33,865.023 1511.33,865.024 1511.32,865.025 1511.32,865.027 1511.31,865.028 1511.31,865.029 1511.3,865.031 1511.3,865.032 1511.29,865.034 1511.29,865.035 1511.28,865.036 1511.28,865.038 1511.27,865.039 1511.27,865.04 1511.26,865.042 1511.26,865.043 1511.25,865.045 1511.25,865.046 1511.24,865.047 1511.24,865.049 1511.23,865.05 1511.23,865.052 1511.22,865.053 1511.22,865.054 1511.21,865.056 1511.21,865.057 1511.2,865.059 1511.2,865.06 1511.19,865.061 1511.19,865.063 1511.18,865.064 1511.18,865.066 1511.17,865.067 1511.17,865.068 1511.16,865.07 1511.16,865.071 1511.15,865.073 1511.15,865.074 1511.14,865.075 1511.14,865.077 1511.13,865.078 1511.13,865.08 1511.12,865.081 1511.12,865.082 1511.11,865.084 1511.11,865.085 1511.1,865.087 1511.1,865.088 1511.09,865.089 1511.09,865.091 1511.08,865.092 1511.08,865.094 1511.07,865.095 1511.07,865.097 1511.06,865.098 1511.06,865.099 1511.05,865.101 1511.05,865.102 1511.04,865.104 1511.04,865.105 1511.03,865.106 1511.03,865.108 1511.02,865.109 1511.02,865.111 1511.01,865.112 1511.01,865.114 1511,865.115 1511,865.116 1510.99,865.118 1510.99,865.119 1510.98,865.121 1510.98,865.122 1510.97,865.124 1510.97,865.125 1510.96,865.126 1510.96,865.128 1510.95,865.129 1510.95,865.131 1510.94,865.132 1510.94,865.134 1510.93,865.135 1510.93,865.137 1510.92,865.138 1510.92,865.139 1510.91,865.141 1510.91,865.142 1510.9,865.144 1510.9,865.145 1510.89,865.147 1510.89,865.148 1510.88,865.15 1510.88,865.151 1510.87,865.152 1510.87,865.154 1510.86,865.155 1510.86,865.157 1510.85,865.158 1510.85,865.16 1510.84,865.161 1510.84,865.163 1510.83,865.164 1510.83,865.166 1510.82,865.167 1510.82,865.168 1510.81,865.17 1510.81,865.171 1510.81,865.173 1510.8,865.174 1510.8,865.176 1510.79,865.177 1510.79,865.179 1510.78,865.18 1510.78,865.182 1510.77,865.183 1510.77,865.185 1510.76,865.186 1510.76,865.188 1510.75,865.189 1510.75,865.191 1510.74,865.192 1510.74,865.193 1510.73,865.195 1510.73,865.196 1510.72,865.198 1510.72,865.199 1510.71,865.201 1510.71,865.202 1510.7,865.204 1510.7,865.205 1510.69,865.207 1510.69,865.208 1510.68,865.21 1510.68,865.211 1510.67,865.213 1510.67,865.214 1510.66,865.216 1510.66,865.217 1510.65,865.219 1510.65,865.22 1510.64,865.222 1510.64,865.223 1510.63,865.225 1510.63,865.226 1510.62,865.228 1510.62,865.229 1510.61,865.231 1510.61,865.232 1510.6,865.234 1510.6,865.235 1510.59,865.237 1510.59,865.238 1510.58,865.24 1510.58,865.241 1510.57,865.243 1510.57,865.244 1510.56,865.246 1510.56,865.247 1510.55,865.249 1510.55,865.25 1510.54,865.252 1510.54,865.253 1510.53,865.255 1510.53,865.256 1510.52,865.258 1510.52,865.259 1510.51,865.261 1510.51,865.262 1510.5,865.264 1510.5,865.265 1510.49,865.267 1510.49,865.268 1510.48,865.27 1510.48,865.271 1510.47,865.273 1510.47,865.274 1510.46,865.276 1510.46,865.278 1510.46,865.279 1510.45,865.281 1510.45,865.282 1510.44,865.284 1510.44,865.285 1510.43,865.287 1510.43,865.288 1510.42,865.29 1510.42,865.291 1510.41,865.293 1510.41,865.294 1510.4,865.296 1510.4,865.297 1510.39,865.299 1510.39,865.3 1510.38,865.302 1510.38,865.304 1510.37,865.305 1510.37,865.307 1510.36,865.308 1510.36,865.31 1510.35,865.311 1510.35,865.313 1510.34,865.314 1510.34,865.316 1510.33,865.317 1510.33,865.319 1510.32,865.321 1510.32,865.322 1510.31,865.324 1510.31,865.325 1510.3,865.327 1510.3,865.328 1510.29,865.33 1510.29,865.331 1510.28,865.333 1510.28,865.335 1510.27,865.336 1510.27,865.338 1510.26,865.339 1510.26,865.341 1510.25,865.342 1510.25,865.344 1510.24,865.345 1510.24,865.347 1510.23,865.349 1510.23,865.35 1510.22,865.352 1510.22,865.353 1510.22,865.355 1510.21,865.356 1510.21,865.358 1510.2,865.36 1510.2,865.361 1510.19,865.363 1510.19,865.364 1510.18,865.366 1510.18,865.368 1510.17,865.369 1510.17,865.371 1510.16,865.372 1510.16,865.374 1510.15,865.375 1510.15,865.377 1510.14,865.379 1510.14,865.38 1510.13,865.382 1510.13,865.383 1510.12,865.385 1510.12,865.387 1510.11,865.388 1510.11,865.39 1510.1,865.391 1510.1,865.393 1510.09,865.394 1510.09,865.396 1510.08,865.398 1510.08,865.399 1510.07,865.401 1510.07,865.402 1510.06,865.404 1510.06,865.406 1510.05,865.407 1510.05,865.409 1510.04,865.41 1510.04,865.412 1510.03,865.414 1510.03,865.415 1510.03,865.417 1510.02,865.418 1510.02,865.42 1510.01,865.422 1510.01,865.423 1510,865.425 1510,865.427 1509.99,865.428 1509.99,865.43 1509.98,865.431 1509.98,865.433 1509.97,865.435 1509.97,865.436 1509.96,865.438 1509.96,865.439 1509.95,865.441 1509.95,865.443 1509.94,865.444 1509.94,865.446 1509.93,865.448 1509.93,865.449 1509.92,865.451 1509.92,865.452 1509.91,865.454 1509.91,865.456 1509.9,865.457 1509.9,865.459 1509.89,865.461 1509.89,865.462 1509.88,865.464 1509.88,865.465 1509.87,865.467 1509.87,865.469 1509.87,865.47 1509.86,865.472 1509.86,865.474 1509.85,865.475 1509.85,865.477 1509.84,865.479 1509.84,865.48 1509.83,865.482 1509.83,865.484 1509.82,865.485 1509.82,865.487 1509.81,865.488 1509.81,865.49 1509.8,865.492 1509.8,865.493 1509.79,865.495 1509.79,865.497 1509.78,865.498 1509.78,865.5 1509.77,865.502 1509.77,865.503 1509.76,865.505 1509.76,865.507 1509.75,865.508 1509.75,865.51 1509.74,865.512 1509.74,865.513 1509.73,865.515 1509.73,865.517 1509.72,865.518 1509.72,865.52 1509.72,865.522 1509.71,865.523 1509.71,865.525 1509.7,865.527 1509.7,865.528 1509.69,865.53 1509.69,865.532 1509.68,865.533 1509.68,865.535 1509.67,865.537 1509.67,865.538 1509.66,865.54 1509.66,865.542 1509.65,865.543 1509.65,865.545 1509.64,865.547 1509.64,865.548 1509.63,865.55 1509.63,865.552 1509.62,865.553 1509.62,865.555 1509.61,865.557 1509.61,865.558 1509.6,865.56 1509.6,865.562 1509.59,865.564 1509.59,865.565 1509.59,865.567 1509.58,865.569 1509.58,865.57 1509.57,865.572 1509.57,865.574 1509.56,865.575 1509.56,865.577 1509.55,865.579 1509.55,865.58 1509.54,865.582 1509.54,865.584 1509.53,865.586 1509.53,865.587 1509.52,865.589 1509.52,865.591 1509.51,865.592 1509.51,865.594 1509.5,865.596 1509.5,865.598 1509.49,865.599 1509.49,865.601 1509.48,865.603 1509.48,865.604 1509.47,865.606 1509.47,865.608 1509.47,865.61 1509.46,865.611 1509.46,865.613 1509.45,865.615 1509.45,865.616 1509.44,865.618 1509.44,865.62 1509.43,865.622 1509.43,865.623 1509.42,865.625 1509.42,865.627 1509.41,865.628 1509.41,865.63 1509.4,865.632 1509.4,865.634 1509.39,865.635 1509.39,865.637 1509.38,865.639 1509.38,865.641 1509.37,865.642 1509.37,865.644 1509.36,865.646 1509.36,865.648 1509.36,865.649 1509.35,865.651 1509.35,865.653 1509.34,865.654 1509.34,865.656 1509.33,865.658 1509.33,865.66 1509.32,865.661 1509.32,865.663 1509.31,865.665 1509.31,865.667 1509.3,865.668 1509.3,865.67 1509.29,865.672 1509.29,865.674 1509.28,865.675 1509.28,865.677 1509.27,865.679 1509.27,865.681 1509.26,865.682 1509.26,865.684 1509.25,865.686 1509.25,865.688 1509.25,865.69 1509.24,865.691 1509.24,865.693 1509.23,865.695 1509.23,865.697 1509.22,865.698 1509.22,865.7 1509.21,865.702 1509.21,865.704 1509.2,865.705 1509.2,865.707 1509.19,865.709 1509.19,865.711 1509.18,865.712 1509.18,865.714 1509.17,865.716 1509.17,865.718 1509.16,865.72 1509.16,865.721 1509.15,865.723 1509.15,865.725 1509.15,865.727 1509.14,865.728 1509.14,865.73 1509.13,865.732 1509.13,865.734 1509.12,865.736 1509.12,865.737 1509.11,865.739 1509.11,865.741 1509.1,865.743 1509.1,865.745 1509.09,865.746 1509.09,865.748 1509.08,865.75 1509.08,865.752 1509.07,865.754 1509.07,865.755 1509.06,865.757 1509.06,865.759 1509.06,865.761 1509.05,865.763 1509.05,865.764 1509.04,865.766 1509.04,865.768 1509.03,865.77 1509.03,865.772 1509.02,865.773 1509.02,865.775 1509.01,865.777 1509.01,865.779 1509,865.781 1509,865.782 1508.99,865.784 1508.99,865.786 1508.98,865.788 1508.98,865.79 1508.97,865.792 1508.97,865.793 1508.96,865.795 1508.96,865.797 1508.96,865.799 1508.95,865.801 1508.95,865.802 1508.94,865.804 1508.94,865.806 1508.93,865.808 1508.93,865.81 1508.92,865.812 1508.92,865.813 1508.91,865.815 1508.91,865.817 1508.9,865.819 1508.9,865.821 1508.89,865.823 1508.89,865.824 1508.88,865.826 1508.88,865.828 1508.88,865.83 1508.87,865.832 1508.87,865.834 1508.86,865.835 1508.86,865.837 1508.85,865.839 1508.85,865.841 1508.84,865.843 1508.84,865.845 1508.83,865.847 1508.83,865.848 1508.82,865.85 1508.82,865.852 1508.81,865.854 1508.81,865.856 1508.8,865.858 1508.8,865.859 1508.79,865.861 1508.79,865.863 1508.79,865.865 1508.78,865.867 1508.78,865.869 1508.77,865.871 1508.77,865.872 1508.76,865.874 1508.76,865.876 1508.75,865.878 1508.75,865.88 1508.74,865.882 1508.74,865.884 1508.73,865.886 1508.73,865.887 1508.72,865.889 1508.72,865.891 1508.71,865.893 1508.71,865.895 1508.71,865.897 1508.7,865.899 1508.7,865.901 1508.69,865.902 1508.69,865.904 1508.68,865.906 1508.68,865.908 1508.67,865.91 1508.67,865.912 1508.66,865.914 1508.66,865.916 1508.65,865.917 1508.65,865.919 1508.64,865.921 1508.64,865.923 1508.64,865.925 1508.63,865.927 1508.63,865.929 1508.62,865.931 1508.62,865.933 1508.61,865.935 1508.61,865.936 1508.6,865.938 1508.6,865.94 1508.59,865.942 1508.59,865.944 1508.58,865.946 1508.58,865.948 1508.57,865.95 1508.57,865.952 1508.56,865.954 1508.56,865.955 1508.56,865.957 1508.55,865.959 1508.55,865.961 1508.54,865.963 1508.54,865.965 1508.53,865.967 1508.53,865.969 1508.52,865.971 1508.52,865.973 1508.51,865.975 1508.51,865.976 1508.5,865.978 1508.5,865.98 1508.49,865.982 1508.49,865.984 1508.49,865.986 1508.48,865.988 1508.48,865.99 1508.47,865.992 1508.47,865.994 1508.46,865.996 1508.46,865.998 1508.45,866 1508.45,866.002 1508.44,866.003 1508.44,866.005 1508.43,866.007 1508.43,866.009 1508.42,866.011 1508.42,866.013 1508.42,866.015 1508.41,866.017 1508.41,866.019 1508.4,866.021 1508.4,866.023 1508.39,866.025 1508.39,866.027 1508.38,866.029 1508.38,866.031 1508.37,866.033 1508.37,866.035 1508.36,866.037 1508.36,866.038 1508.35,866.04 1508.35,866.042 1508.35,866.044 1508.34,866.046 1508.34,866.048 1508.33,866.05 1508.33,866.052 1508.32,866.054 1508.32,866.056 1508.31,866.058 1508.31,866.06 1508.3,866.062 1508.3,866.064 1508.29,866.066 1508.29,866.068 1508.28,866.07 1508.28,866.072 1508.28,866.074 1508.27,866.076 1508.27,866.078 1508.26,866.08 1508.26,866.082 1508.25,866.084 1508.25,866.086 1508.24,866.088 1508.24,866.09 1508.23,866.092 1508.23,866.094 1508.22,866.096 1508.22,866.098 1508.22,866.1 1508.21,866.102 1508.21,866.104 1508.2,866.106 1508.2,866.108 1508.19,866.109 1508.19,866.111 1508.18,866.113 1508.18,866.115 1508.17,866.117 1508.17,866.119 1508.16,866.121 1508.16,866.123 1508.16,866.125 1508.15,866.127 1508.15,866.129 1508.14,866.131 1508.14,866.133 1508.13,866.135 1508.13,866.137 1508.12,866.139 1508.12,866.142 1508.11,866.144 1508.11,866.146 1508.1,866.148 1508.1,866.15 1508.1,866.152 1508.09,866.154 1508.09,866.156 1508.08,866.158 1508.08,866.16 1508.07,866.162 1508.07,866.164 1508.06,866.166 1508.06,866.168 1508.05,866.17 1508.05,866.172 1508.04,866.174 1508.04,866.176 1508.04,866.178 1508.03,866.18 1508.03,866.182 1508.02,866.184 1508.02,866.186 1508.01,866.188 1508.01,866.19 1508,866.192 1508,866.194 1507.99,866.196 1507.99,866.198 1507.98,866.2 1507.98,866.202 1507.98,866.204 1507.97,866.206 1507.97,866.208 1507.96,866.21 1507.96,866.213 1507.95,866.215 1507.95,866.217 1507.94,866.219 1507.94,866.221 1507.93,866.223 1507.93,866.225 1507.92,866.227 1507.92,866.229 1507.92,866.231 1507.91,866.233 1507.91,866.235 1507.9,866.237 1507.9,866.239 1507.89,866.241 1507.89,866.243 1507.88,866.245 1507.88,866.247 1507.87,866.25 1507.87,866.252 1507.86,866.254 1507.86,866.256 1507.86,866.258 1507.85,866.26 1507.85,866.262 1507.84,866.264 1507.84,866.266 1507.83,866.268 1507.83,866.27 1507.82,866.272 1507.82,866.274 1507.81,866.277 1507.81,866.279 1507.81,866.281 1507.8,866.283 1507.8,866.285 1507.79,866.287 1507.79,866.289 1507.78,866.291 1507.78,866.293 1507.77,866.295 1507.77,866.297 1507.76,866.299 1507.76,866.302 1507.75,866.304 1507.75,866.306 1507.75,866.308 1507.74,866.31 1507.74,866.312 1507.73,866.314 1507.73,866.316 1507.72,866.318 1507.72,866.32 1507.71,866.323 1507.71,866.325 1507.7,866.327 1507.7,866.329 1507.7,866.331 1507.69,866.333 1507.69,866.335 1507.68,866.337 1507.68,866.339 1507.67,866.342 1507.67,866.344 1507.66,866.346 1507.66,866.348 1507.65,866.35 1507.65,866.352 1507.65,866.354 1507.64,866.356 1507.64,866.359 1507.63,866.361 1507.63,866.363 1507.62,866.365 1507.62,866.367 1507.61,866.369 1507.61,866.371 1507.6,866.373 1507.6,866.376 1507.6,866.378 1507.59,866.38 1507.59,866.382 1507.58,866.384 1507.58,866.386 1507.57,866.388 1507.57,866.391 1507.56,866.393 1507.56,866.395 1507.55,866.397 1507.55,866.399 1507.55,866.401 1507.54,866.403 1507.54,866.406 1507.53,866.408 1507.53,866.41 1507.52,866.412 1507.52,866.414 1507.51,866.416 1507.51,866.419 1507.5,866.421 1507.5,866.423 1507.5,866.425 1507.49,866.427 1507.49,866.429 1507.48,866.431 1507.48,866.434 1507.47,866.436 1507.47,866.438 1507.46,866.44 1507.46,866.442 1507.45,866.445 1507.45,866.447 1507.45,866.449 1507.44,866.451 1507.44,866.453 1507.43,866.455 1507.43,866.458 1507.42,866.46 1507.42,866.462 1507.41,866.464 1507.41,866.466 1507.4,866.468 1507.4,866.471 1507.4,866.473 1507.39,866.475 1507.39,866.477 1507.38,866.479 1507.38,866.482 1507.37,866.484 1507.37,866.486 1507.36,866.488 1507.36,866.49 1507.35,866.493 1507.35,866.495 1507.35,866.497 1507.34,866.499 1507.34,866.501 1507.33,866.504 1507.33,866.506 1507.32,866.508 1507.32,866.51 1507.31,866.512 1507.31,866.515 1507.31,866.517 1507.3,866.519 1507.3,866.521 1507.29,866.523 1507.29,866.526 1507.28,866.528 1507.28,866.53 1507.27,866.532 1507.27,866.534 1507.26,866.537 1507.26,866.539 1507.26,866.541 1507.25,866.543 1507.25,866.546 1507.24,866.548 1507.24,866.55 1507.23,866.552 1507.23,866.555 1507.22,866.557 1507.22,866.559 1507.22,866.561 1507.21,866.563 1507.21,866.566 1507.2,866.568 1507.2,866.57 1507.19,866.572 1507.19,866.575 1507.18,866.577 1507.18,866.579 1507.17,866.581 1507.17,866.584 1507.17,866.586 1507.16,866.588 1507.16,866.59 1507.15,866.593 1507.15,866.595 1507.14,866.597 1507.14,866.599 1507.13,866.602 1507.13,866.604 1507.13,866.606 1507.12,866.608 1507.12,866.611 1507.11,866.613 1507.11,866.615 1507.1,866.617 1507.1,866.62 1507.09,866.622 1507.09,866.624 1507.09,866.626 1507.08,866.629 1507.08,866.631 1507.07,866.633 1507.07,866.636 1507.06,866.638 1507.06,866.64 1507.05,866.642 1507.05,866.645 1507.04,866.647 1507.04,866.649 1507.04,866.651 1507.03,866.654 1507.03,866.656 1507.02,866.658 1507.02,866.661 1507.01,866.663 1507.01,866.665 1507,866.667 1507,866.67 1507,866.672 1506.99,866.674 1506.99,866.677 1506.98,866.679 1506.98,866.681 1506.97,866.684 1506.97,866.686 1506.96,866.688 1506.96,866.69 1506.96,866.693 1506.95,866.695 1506.95,866.697 1506.94,866.7 1506.94,866.702 1506.93,866.704 1506.93,866.707 1506.92,866.709 1506.92,866.711 1506.92,866.713 1506.91,866.716 1506.91,866.718 1506.9,866.72 1506.9,866.723 1506.89,866.725 1506.89,866.727 1506.88,866.73 1506.88,866.732 1506.88,866.734 1506.87,866.737 1506.87,866.739 1506.86,866.741 1506.86,866.744 1506.85,866.746 1506.85,866.748 1506.84,866.751 1506.84,866.753 1506.84,866.755 1506.83,866.758 1506.83,866.76 1506.82,866.762 1506.82,866.765 1506.81,866.767 1506.81,866.769 1506.8,866.772 1506.8,866.774 1506.8,866.776 1506.79,866.779 1506.79,866.781 1506.78,866.783 1506.78,866.786 1506.77,866.788 1506.77,866.79 1506.76,866.793 1506.76,866.795 1506.76,866.798 1506.75,866.8 1506.75,866.802 1506.74,866.805 1506.74,866.807 1506.73,866.809 1506.73,866.812 1506.72,866.814 1506.72,866.816 1506.72,866.819 1506.71,866.821 1506.71,866.823 1506.7,866.826 1506.7,866.828 1506.69,866.831 1506.69,866.833 1506.69,866.835 1506.68,866.838 1506.68,866.84 1506.67,866.842 1506.67,866.845 1506.66,866.847 1506.66,866.85 1506.65,866.852 1506.65,866.854 1506.65,866.857 1506.64,866.859 1506.64,866.862 1506.63,866.864 1506.63,866.866 1506.62,866.869 1506.62,866.871 1506.61,866.874 1506.61,866.876 1506.61,866.878 1506.6,866.881 1506.6,866.883 1506.59,866.886 1506.59,866.888 1506.58,866.89 1506.58,866.893 1506.57,866.895 1506.57,866.898 1506.57,866.9 1506.56,866.902 1506.56,866.905 1506.55,866.907 1506.55,866.91 1506.54,866.912 1506.54,866.914 1506.54,866.917 1506.53,866.919 1506.53,866.922 1506.52,866.924 1506.52,866.927 1506.51,866.929 1506.51,866.931 1506.5,866.934 1506.5,866.936 1506.5,866.939 1506.49,866.941 1506.49,866.944 1506.48,866.946 1506.48,866.948 1506.47,866.951 1506.47,866.953 1506.47,866.956 1506.46,866.958 1506.46,866.961 1506.45,866.963 1506.45,866.965 1506.44,866.968 1506.44,866.97 1506.43,866.973 1506.43,866.975 1506.43,866.978 1506.42,866.98 1506.42,866.983 1506.41,866.985 1506.41,866.988 1506.4,866.99 1506.4,866.992 1506.4,866.995 1506.39,866.997 1506.39,867 1506.38,867.002 1506.38,867.005 1506.37,867.007 1506.37,867.01 1506.36,867.012 1506.36,867.015 1506.36,867.017 1506.35,867.02 1506.35,867.022 1506.34,867.024 1506.34,867.027 1506.33,867.029 1506.33,867.032 1506.33,867.034 1506.32,867.037 1506.32,867.039 1506.31,867.042 1506.31,867.044 1506.3,867.047 1506.3,867.049 1506.29,867.052 1506.29,867.054 1506.29,867.057 1506.28,867.059 1506.28,867.062 1506.27,867.064 1506.27,867.067 1506.26,867.069 1506.26,867.072 1506.26,867.074 1506.25,867.077 1506.25,867.079 1506.24,867.082 1506.24,867.084 1506.23,867.087 1506.23,867.089 1506.23,867.092 1506.22,867.094 1506.22,867.097 1506.21,867.099 1506.21,867.102 1506.2,867.104 1506.2,867.107 1506.19,867.109 1506.19,867.112 1506.19,867.114 1506.18,867.117 1506.18,867.119 1506.17,867.122 1506.17,867.124 1506.16,867.127 1506.16,867.129 1506.16,867.132 1506.15,867.135 1506.15,867.137 1506.14,867.14 1506.14,867.142 1506.13,867.145 1506.13,867.147 1506.13,867.15 1506.12,867.152 1506.12,867.155 1506.11,867.157 1506.11,867.16 1506.1,867.162 1506.1,867.165 1506.1,867.168 1506.09,867.17 1506.09,867.173 1506.08,867.175 1506.08,867.178 1506.07,867.18 1506.07,867.183 1506.07,867.185 1506.06,867.188 1506.06,867.19 1506.05,867.193 1506.05,867.196 1506.04,867.198 1506.04,867.201 1506.03,867.203 1506.03,867.206 1506.03,867.208 1506.02,867.211 1506.02,867.214 1506.01,867.216 1506.01,867.219 1506,867.221 1506,867.224 1506,867.226 1505.99,867.229 1505.99,867.232 1505.98,867.234 1505.98,867.237 1505.97,867.239 1505.97,867.242 1505.97,867.245 1505.96,867.247 1505.96,867.25 1505.95,867.252 1505.95,867.255 1505.94,867.257 1505.94,867.26 1505.94,867.263 1505.93,867.265 1505.93,867.268 1505.92,867.27 1505.92,867.273 1505.91,867.276 1505.91,867.278 1505.91,867.281 1505.9,867.283 1505.9,867.286 1505.89,867.289 1505.89,867.291 1505.88,867.294 1505.88,867.296 1505.88,867.299 1505.87,867.302 1505.87,867.304 1505.86,867.307 1505.86,867.31 1505.85,867.312 1505.85,867.315 1505.85,867.317 1505.84,867.32 1505.84,867.323 1505.83,867.325 1505.83,867.328 1505.82,867.331 1505.82,867.333 1505.82,867.336 1505.81,867.338 1505.81,867.341 1505.8,867.344 1505.8,867.346 1505.79,867.349 1505.79,867.352 1505.79,867.354 1505.78,867.357 1505.78,867.36 1505.77,867.362 1505.77,867.365 1505.76,867.367 1505.76,867.37 1505.76,867.373 1505.75,867.375 1505.75,867.378 1505.74,867.381 1505.74,867.383 1505.73,867.386 1505.73,867.389 1505.73,867.391 1505.72,867.394 1505.72,867.397 1505.71,867.399 1505.71,867.402 1505.71,867.405 1505.7,867.407 1505.7,867.41 1505.69,867.413 1505.69,867.415 1505.68,867.418 1505.68,867.421 1505.68,867.423 1505.67,867.426 1505.67,867.429 1505.66,867.431 1505.66,867.434 1505.65,867.437 1505.65,867.439 1505.65,867.442 1505.64,867.445 1505.64,867.448 1505.63,867.45 1505.63,867.453 1505.62,867.456 1505.62,867.458 1505.62,867.461 1505.61,867.464 1505.61,867.466 1505.6,867.469 1505.6,867.472 1505.59,867.474 1505.59,867.477 1505.59,867.48 1505.58,867.483 1505.58,867.485 1505.57,867.488 1505.57,867.491 1505.57,867.493 1505.56,867.496 1505.56,867.499 1505.55,867.502 1505.55,867.504 1505.54,867.507 1505.54,867.51 1505.54,867.512 1505.53,867.515 1505.53,867.518 1505.52,867.521 1505.52,867.523 1505.51,867.526 1505.51,867.529 1505.51,867.532 1505.5,867.534 1505.5,867.537 1505.49,867.54 1505.49,867.542 1505.48,867.545 1505.48,867.548 1505.48,867.551 1505.47,867.553 1505.47,867.556 1505.46,867.559 1505.46,867.562 1505.46,867.564 1505.45,867.567 1505.45,867.57 1505.44,867.573 1505.44,867.575 1505.43,867.578 1505.43,867.581 1505.43,867.584 1505.42,867.586 1505.42,867.589 1505.41,867.592 1505.41,867.595 1505.4,867.597 1505.4,867.6 1505.4,867.603 1505.39,867.606 1505.39,867.609 1505.38,867.611 1505.38,867.614 1505.38,867.617 1505.37,867.62 1505.37,867.622 1505.36,867.625 1505.36,867.628 1505.35,867.631 1505.35,867.634 1505.35,867.636 1505.34,867.639 1505.34,867.642 1505.33,867.645 1505.33,867.647 1505.33,867.65 1505.32,867.653 1505.32,867.656 1505.31,867.659 1505.31,867.661 1505.3,867.664 1505.3,867.667 1505.3,867.67 1505.29,867.673 1505.29,867.675 1505.28,867.678 1505.28,867.681 1505.28,867.684 1505.27,867.687 1505.27,867.689 1505.26,867.692 1505.26,867.695 1505.25,867.698 1505.25,867.701 1505.25,867.704 1505.24,867.706 1505.24,867.709 1505.23,867.712 1505.23,867.715 1505.22,867.718 1505.22,867.72 1505.22,867.723 1505.21,867.726 1505.21,867.729 1505.2,867.732 1505.2,867.735 1505.2,867.737 1505.19,867.74 1505.19,867.743 1505.18,867.746 1505.18,867.749 1505.17,867.752 1505.17,867.754 1505.17,867.757 1505.16,867.76 1505.16,867.763 1505.15,867.766 1505.15,867.769 1505.15,867.772 1505.14,867.774 1505.14,867.777 1505.13,867.78 1505.13,867.783 1505.13,867.786 1505.12,867.789 1505.12,867.792 1505.11,867.794 1505.11,867.797 1505.1,867.8 1505.1,867.803 1505.1,867.806 1505.09,867.809 1505.09,867.812 1505.08,867.814 1505.08,867.817 1505.08,867.82 1505.07,867.823 1505.07,867.826 1505.06,867.829 1505.06,867.832 1505.05,867.835 1505.05,867.837 1505.05,867.84 1505.04,867.843 1505.04,867.846 1505.03,867.849 1505.03,867.852 1505.03,867.855 1505.02,867.858 1505.02,867.861 1505.01,867.863 1505.01,867.866 1505.01,867.869 1505,867.872 1505,867.875 1504.99,867.878 1504.99,867.881 1504.98,867.884 1504.98,867.887 1504.98,867.89 1504.97,867.893 1504.97,867.895 1504.96,867.898 1504.96,867.901 1504.96,867.904 1504.95,867.907 1504.95,867.91 1504.94,867.913 1504.94,867.916 1504.94,867.919 1504.93,867.922 1504.93,867.925 1504.92,867.928 1504.92,867.93 1504.91,867.933 1504.91,867.936 1504.91,867.939 1504.9,867.942 1504.9,867.945 1504.89,867.948 1504.89,867.951 1504.89,867.954 1504.88,867.957 1504.88,867.96 1504.87,867.963 1504.87,867.966 1504.87,867.969 1504.86,867.972 1504.86,867.975 1504.85,867.978 1504.85,867.981 1504.84,867.983 1504.84,867.986 1504.84,867.989 1504.83,867.992 1504.83,867.995 1504.82,867.998 1504.82,868.001 1504.82,868.004 1504.81,868.007 1504.81,868.01 1504.8,868.013 1504.8,868.016 1504.8,868.019 1504.79,868.022 1504.79,868.025 1504.78,868.028 1504.78,868.031 1504.78,868.034 1504.77,868.037 1504.77,868.04 1504.76,868.043 1504.76,868.046 1504.75,868.049 1504.75,868.052 1504.75,868.055 1504.74,868.058 1504.74,868.061 1504.73,868.064 1504.73,868.067 1504.73,868.07 1504.72,868.073 1504.72,868.076 1504.71,868.079 1504.71,868.082 1504.71,868.085 1504.7,868.088 1504.7,868.091 1504.69,868.094 1504.69,868.097 1504.69,868.1 1504.68,868.103 1504.68,868.106 1504.67,868.109 1504.67,868.112 1504.67,868.115 1504.66,868.118 1504.66,868.121 1504.65,868.124 1504.65,868.127 1504.64,868.13 1504.64,868.133 1504.64,868.136 1504.63,868.139 1504.63,868.142 1504.62,868.145 1504.62,868.148 1504.62,868.151 1504.61,868.154 1504.61,868.157 1504.6,868.16 1504.6,868.163 1504.6,868.167 1504.59,868.17 1504.59,868.173 1504.58,868.176 1504.58,868.179 1504.58,868.182 1504.57,868.185 1504.57,868.188 1504.56,868.191 1504.56,868.194 1504.56,868.197 1504.55,868.2 1504.55,868.203 1504.54,868.206 1504.54,868.209 1504.54,868.212 1504.53,868.215 1504.53,868.219 1504.52,868.222 1504.52,868.225 1504.52,868.228 1504.51,868.231 1504.51,868.234 1504.5,868.237 1504.5,868.24 1504.5,868.243 1504.49,868.246 1504.49,868.249 1504.48,868.252 1504.48,868.256 1504.48,868.259 1504.47,868.262 1504.47,868.265 1504.46,868.268 1504.46,868.271 1504.46,868.274 1504.45,868.277 1504.45,868.28 1504.44,868.283 1504.44,868.286 1504.43,868.29 1504.43,868.293 1504.43,868.296 1504.42,868.299 1504.42,868.302 1504.41,868.305 1504.41,868.308 1504.41,868.311 1504.4,868.314 1504.4,868.318 1504.39,868.321 1504.39,868.324 1504.39,868.327 1504.38,868.33 1504.38,868.333 1504.37,868.336 1504.37,868.339 1504.37,868.343 1504.36,868.346 1504.36,868.349 1504.35,868.352 1504.35,868.355 1504.35,868.358 1504.34,868.361 1504.34,868.365 1504.33,868.368 1504.33,868.371 1504.33,868.374 1504.32,868.377 1504.32,868.38 1504.31,868.383 1504.31,868.387 1504.31,868.39 1504.3,868.393 1504.3,868.396 1504.29,868.399 1504.29,868.402 1504.29,868.406 1504.28,868.409 1504.28,868.412 1504.27,868.415 1504.27,868.418 1504.27,868.421 1504.26,868.425 1504.26,868.428 1504.26,868.431 1504.25,868.434 1504.25,868.437 1504.24,868.44 1504.24,868.444 1504.24,868.447 1504.23,868.45 1504.23,868.453 1504.22,868.456 1504.22,868.46 1504.22,868.463 1504.21,868.466 1504.21,868.469 1504.2,868.472 1504.2,868.476 1504.2,868.479 1504.19,868.482 1504.19,868.485 1504.18,868.488 1504.18,868.492 1504.18,868.495 1504.17,868.498 1504.17,868.501 1504.16,868.504 1504.16,868.508 1504.16,868.511 1504.15,868.514 1504.15,868.517 1504.14,868.52 1504.14,868.524 1504.14,868.527 1504.13,868.53 1504.13,868.533 1504.12,868.537 1504.12,868.54 1504.12,868.543 1504.11,868.546 1504.11,868.55 1504.1,868.553 1504.1,868.556 1504.1,868.559 1504.09,868.562 1504.09,868.566 1504.08,868.569 1504.08,868.572 1504.08,868.575 1504.07,868.579 1504.07,868.582 1504.06,868.585 1504.06,868.588 1504.06,868.592 1504.05,868.595 1504.05,868.598 1504.05,868.601 1504.04,868.605 1504.04,868.608 1504.03,868.611 1504.03,868.615 1504.03,868.618 1504.02,868.621 1504.02,868.624 1504.01,868.628 1504.01,868.631 1504.01,868.634 1504,868.637 1504,868.641 1503.99,868.644 1503.99,868.647 1503.99,868.651 1503.98,868.654 1503.98,868.657 1503.97,868.66 1503.97,868.664 1503.97,868.667 1503.96,868.67 1503.96,868.674 1503.95,868.677 1503.95,868.68 1503.95,868.683 1503.94,868.687 1503.94,868.69 1503.94,868.693 1503.93,868.697 1503.93,868.7 1503.92,868.703 1503.92,868.707 1503.92,868.71 1503.91,868.713 1503.91,868.716 1503.9,868.72 1503.9,868.723 1503.9,868.726 1503.89,868.73 1503.89,868.733 1503.88,868.736 1503.88,868.74 1503.88,868.743 1503.87,868.746 1503.87,868.75 1503.87,868.753 1503.86,868.756 1503.86,868.76 1503.85,868.763 1503.85,868.766 1503.85,868.77 1503.84,868.773 1503.84,868.776 1503.83,868.78 1503.83,868.783 1503.83,868.786 1503.82,868.79 1503.82,868.793 1503.81,868.797 1503.81,868.8 1503.81,868.803 1503.8,868.807 1503.8,868.81 1503.8,868.813 1503.79,868.817 1503.79,868.82 1503.78,868.823 1503.78,868.827 1503.78,868.83 1503.77,868.833 1503.77,868.837 1503.76,868.84 1503.76,868.844 1503.76,868.847 1503.75,868.85 1503.75,868.854 1503.74,868.857 1503.74,868.861 1503.74,868.864 1503.73,868.867 1503.73,868.871 1503.73,868.874 1503.72,868.877 1503.72,868.881 1503.71,868.884 1503.71,868.888 1503.71,868.891 1503.7,868.894 1503.7,868.898 1503.69,868.901 1503.69,868.905 1503.69,868.908 1503.68,868.911 1503.68,868.915 1503.68,868.918 1503.67,868.922 1503.67,868.925 1503.66,868.929 1503.66,868.932 1503.66,868.935 1503.65,868.939 1503.65,868.942 1503.64,868.946 1503.64,868.949 1503.64,868.952 1503.63,868.956 1503.63,868.959 1503.63,868.963 1503.62,868.966 1503.62,868.97 1503.61,868.973 1503.61,868.977 1503.61,868.98 1503.6,868.983 1503.6,868.987 1503.59,868.99 1503.59,868.994 1503.59,868.997 1503.58,869.001 1503.58,869.004 1503.58,869.008 1503.57,869.011 1503.57,869.014 1503.56,869.018 1503.56,869.021 1503.56,869.025 1503.55,869.028 1503.55,869.032 1503.54,869.035 1503.54,869.039 1503.54,869.042 1503.53,869.046 1503.53,869.049 1503.53,869.053 1503.52,869.056 1503.52,869.06 1503.51,869.063 1503.51,869.067 1503.51,869.07 1503.5,869.074 1503.5,869.077 1503.5,869.08 1503.49,869.084 1503.49,869.087 1503.48,869.091 1503.48,869.094 1503.48,869.098 1503.47,869.101 1503.47,869.105 1503.46,869.108 1503.46,869.112 1503.46,869.115 1503.45,869.119 1503.45,869.122 1503.45,869.126 1503.44,869.13 1503.44,869.133 1503.43,869.137 1503.43,869.14 1503.43,869.144 1503.42,869.147 1503.42,869.151 1503.42,869.154 1503.41,869.158 1503.41,869.161 1503.4,869.165 1503.4,869.168 1503.4,869.172 1503.39,869.175 1503.39,869.179 1503.38,869.182 1503.38,869.186 1503.38,869.189 1503.37,869.193 1503.37,869.197 1503.37,869.2 1503.36,869.204 1503.36,869.207 1503.35,869.211 1503.35,869.214 1503.35,869.218 1503.34,869.221 1503.34,869.225 1503.34,869.229 1503.33,869.232 1503.33,869.236 1503.32,869.239 1503.32,869.243 1503.32,869.246 1503.31,869.25 1503.31,869.254 1503.31,869.257 1503.3,869.261 1503.3,869.264 1503.29,869.268 1503.29,869.271 1503.29,869.275 1503.28,869.279 1503.28,869.282 1503.28,869.286 1503.27,869.289 1503.27,869.293 1503.26,869.297 1503.26,869.3 1503.26,869.304 1503.25,869.307 1503.25,869.311 1503.25,869.315 1503.24,869.318 1503.24,869.322 1503.23,869.325 1503.23,869.329 1503.23,869.333 1503.22,869.336 1503.22,869.34 1503.22,869.343 1503.21,869.347 1503.21,869.351 1503.2,869.354 1503.2,869.358 1503.2,869.361 1503.19,869.365 1503.19,869.369 1503.19,869.372 1503.18,869.376 1503.18,869.38 1503.17,869.383 1503.17,869.387 1503.17,869.391 1503.16,869.394 1503.16,869.398 1503.16,869.401 1503.15,869.405 1503.15,869.409 1503.14,869.412 1503.14,869.416 1503.14,869.42 1503.13,869.423 1503.13,869.427 1503.13,869.431 1503.12,869.434 1503.12,869.438 1503.11,869.442 1503.11,869.445 1503.11,869.449 1503.1,869.453 1503.1,869.456 1503.1,869.46 1503.09,869.464 1503.09,869.467 1503.08,869.471 1503.08,869.475 1503.08,869.478 1503.07,869.482 1503.07,869.486 1503.07,869.489 1503.06,869.493 1503.06,869.497 1503.06,869.5 1503.05,869.504 1503.05,869.508 1503.04,869.512 1503.04,869.515 1503.04,869.519 1503.03,869.523 1503.03,869.526 1503.03,869.53 1503.02,869.534 1503.02,869.537 1503.01,869.541 1503.01,869.545 1503.01,869.549 1503,869.552 1503,869.556 1503,869.56 1502.99,869.563 1502.99,869.567 1502.98,869.571 1502.98,869.575 1502.98,869.578 1502.97,869.582 1502.97,869.586 1502.97,869.59 1502.96,869.593 1502.96,869.597 1502.96,869.601 1502.95,869.605 1502.95,869.608 1502.94,869.612 1502.94,869.616 1502.94,869.619 1502.93,869.623 1502.93,869.627 1502.93,869.631 1502.92,869.634 1502.92,869.638 1502.91,869.642 1502.91,869.646 1502.91,869.65 1502.9,869.653 1502.9,869.657 1502.9,869.661 1502.89,869.665 1502.89,869.668 1502.89,869.672 1502.88,869.676 1502.88,869.68 1502.87,869.683 1502.87,869.687 1502.87,869.691 1502.86,869.695 1502.86,869.699 1502.86,869.702 1502.85,869.706 1502.85,869.71 1502.85,869.714 1502.84,869.718 1502.84,869.721 1502.83,869.725 1502.83,869.729 1502.83,869.733 1502.82,869.737 1502.82,869.74 1502.82,869.744 1502.81,869.748 1502.81,869.752 1502.81,869.756 1502.8,869.759 1502.8,869.763 1502.79,869.767 1502.79,869.771 1502.79,869.775 1502.78,869.778 1502.78,869.782 1502.78,869.786 1502.77,869.79 1502.77,869.794 1502.77,869.798 1502.76,869.801 1502.76,869.805 1502.75,869.809 1502.75,869.813 1502.75,869.817 1502.74,869.821 1502.74,869.824 1502.74,869.828 1502.73,869.832 1502.73,869.836 1502.73,869.84 1502.72,869.844 1502.72,869.848 1502.71,869.851 1502.71,869.855 1502.71,869.859 1502.7,869.863 1502.7,869.867 1502.7,869.871 1502.69,869.875 1502.69,869.878 1502.69,869.882 1502.68,869.886 1502.68,869.89 1502.67,869.894 1502.67,869.898 1502.67,869.902 1502.66,869.906 1502.66,869.909 1502.66,869.913 1502.65,869.917 1502.65,869.921 1502.65,869.925 1502.64,869.929 1502.64,869.933 1502.64,869.937 1502.63,869.941 1502.63,869.944 1502.62,869.948 1502.62,869.952 1502.62,869.956 1502.61,869.96 1502.61,869.964 1502.61,869.968 1502.6,869.972 1502.6,869.976 1502.6,869.98 1502.59,869.984 1502.59,869.988 1502.58,869.991 1502.58,869.995 1502.58,869.999 1502.57,870.003 1502.57,870.007 1502.57,870.011 1502.56,870.015 1502.56,870.019 1502.56,870.023 1502.55,870.027 1502.55,870.031 1502.55,870.035 1502.54,870.039 1502.54,870.043 1502.53,870.047 1502.53,870.05 1502.53,870.054 1502.52,870.058 1502.52,870.062 1502.52,870.066 1502.51,870.07 1502.51,870.074 1502.51,870.078 1502.5,870.082 1502.5,870.086 1502.5,870.09 1502.49,870.094 1502.49,870.098 1502.48,870.102 1502.48,870.106 1502.48,870.11 1502.47,870.114 1502.47,870.118 1502.47,870.122 1502.46,870.126 1502.46,870.13 1502.46,870.134 1502.45,870.138 1502.45,870.142 1502.45,870.146 1502.44,870.15 1502.44,870.154 1502.43,870.158 1502.43,870.162 1502.43,870.166 1502.42,870.17 1502.42,870.174 1502.42,870.178 1502.41,870.182 1502.41,870.186 1502.41,870.19 1502.4,870.194 1502.4,870.198 1502.4,870.202 1502.39,870.206 1502.39,870.21 1502.39,870.214 1502.38,870.218 1502.38,870.222 1502.37,870.226 1502.37,870.23 1502.37,870.234 1502.36,870.238 1502.36,870.242 1502.36,870.246 1502.35,870.25 1502.35,870.254 1502.35,870.258 1502.34,870.262 1502.34,870.267 1502.34,870.271 1502.33,870.275 1502.33,870.279 1502.33,870.283 1502.32,870.287 1502.32,870.291 1502.32,870.295 1502.31,870.299 1502.31,870.303 1502.3,870.307 1502.3,870.311 1502.3,870.315 1502.29,870.319 1502.29,870.323 1502.29,870.328 1502.28,870.332 1502.28,870.336 1502.28,870.34 1502.27,870.344 1502.27,870.348 1502.27,870.352 1502.26,870.356 1502.26,870.36 1502.26,870.364 1502.25,870.368 1502.25,870.373 1502.24,870.377 1502.24,870.381 1502.24,870.385 1502.23,870.389 1502.23,870.393 1502.23,870.397 1502.22,870.401 1502.22,870.405 1502.22,870.41 1502.21,870.414 1502.21,870.418 1502.21,870.422 1502.2,870.426 1502.2,870.43 1502.2,870.434 1502.19,870.438 1502.19,870.443 1502.19,870.447 1502.18,870.451 1502.18,870.455 1502.18,870.459 1502.17,870.463 1502.17,870.467 1502.16,870.472 1502.16,870.476 1502.16,870.48 1502.15,870.484 1502.15,870.488 1502.15,870.492 1502.14,870.496 1502.14,870.501 1502.14,870.505 1502.13,870.509 1502.13,870.513 1502.13,870.517 1502.12,870.521 1502.12,870.526 1502.12,870.53 1502.11,870.534 1502.11,870.538 1502.11,870.542 1502.1,870.547 1502.1,870.551 1502.1,870.555 1502.09,870.559 1502.09,870.563 1502.09,870.567 1502.08,870.572 1502.08,870.576 1502.08,870.58 1502.07,870.584 1502.07,870.588 1502.06,870.593 1502.06,870.597 1502.06,870.601 1502.05,870.605 1502.05,870.609 1502.05,870.614 1502.04,870.618 1502.04,870.622 1502.04,870.626 1502.03,870.631 1502.03,870.635 1502.03,870.639 1502.02,870.643 1502.02,870.647 1502.02,870.652 1502.01,870.656 1502.01,870.66 1502.01,870.664 1502,870.669 1502,870.673 1502,870.677 1501.99,870.681 1501.99,870.686 1501.99,870.69 1501.98,870.694 1501.98,870.698 1501.98,870.703 1501.97,870.707 1501.97,870.711 1501.97,870.715 1501.96,870.72 1501.96,870.724 1501.96,870.728 1501.95,870.732 1501.95,870.737 1501.94,870.741 1501.94,870.745 1501.94,870.75 1501.93,870.754 1501.93,870.758 1501.93,870.762 1501.92,870.767 1501.92,870.771 1501.92,870.775 1501.91,870.78 1501.91,870.784 1501.91,870.788 1501.9,870.792 1501.9,870.797 1501.9,870.801 1501.89,870.805 1501.89,870.81 1501.89,870.814 1501.88,870.818 1501.88,870.823 1501.88,870.827 1501.87,870.831 1501.87,870.835 1501.87,870.84 1501.86,870.844 1501.86,870.848 1501.86,870.853 1501.85,870.857 1501.85,870.861 1501.85,870.866 1501.84,870.87 1501.84,870.874 1501.84,870.879 1501.83,870.883 1501.83,870.887 1501.83,870.892 1501.82,870.896 1501.82,870.9 1501.82,870.905 1501.81,870.909 1501.81,870.914 1501.81,870.918 1501.8,870.922 1501.8,870.927 1501.8,870.931 1501.79,870.935 1501.79,870.94 1501.79,870.944 1501.78,870.948 1501.78,870.953 1501.78,870.957 1501.77,870.962 1501.77,870.966 1501.77,870.97 1501.76,870.975 1501.76,870.979 1501.76,870.983 1501.75,870.988 1501.75,870.992 1501.75,870.997 1501.74,871.001 1501.74,871.005 1501.74,871.01 1501.73,871.014 1501.73,871.019 1501.73,871.023 1501.72,871.027 1501.72,871.032 1501.72,871.036 1501.71,871.041 1501.71,871.045 1501.71,871.049 1501.7,871.054 1501.7,871.058 1501.7,871.063 1501.69,871.067 1501.69,871.072 1501.69,871.076 1501.68,871.08 1501.68,871.085 1501.68,871.089 1501.67,871.094 1501.67,871.098 1501.67,871.103 1501.66,871.107 1501.66,871.111 1501.66,871.116 1501.65,871.12 1501.65,871.125 1501.65,871.129 1501.64,871.134 1501.64,871.138 1501.64,871.143 1501.63,871.147 1501.63,871.152 1501.63,871.156 1501.62,871.16 1501.62,871.165 1501.62,871.169 1501.61,871.174 1501.61,871.178 1501.61,871.183 1501.6,871.187 1501.6,871.192 1501.6,871.196 1501.59,871.201 1501.59,871.205 1501.59,871.21 1501.58,871.214 1501.58,871.219 1501.58,871.223 1501.57,871.228 1501.57,871.232 1501.57,871.237 1501.56,871.241 1501.56,871.246 1501.56,871.25 1501.55,871.255 1501.55,871.259 1501.55,871.264 1501.54,871.268 1501.54,871.273 1501.54,871.277 1501.53,871.282 1501.53,871.286 1501.53,871.291 1501.52,871.295 1501.52,871.3 1501.52,871.304 1501.51,871.309 1501.51,871.314 1501.51,871.318 1501.5,871.323 1501.5,871.327 1501.5,871.332 1501.49,871.336 1501.49,871.341 1501.49,871.345 1501.49,871.35 1501.48,871.354 1501.48,871.359 1501.48,871.364 1501.47,871.368 1501.47,871.373 1501.47,871.377 1501.46,871.382 1501.46,871.386 1501.46,871.391 1501.45,871.396 1501.45,871.4 1501.45,871.405 1501.44,871.409 1501.44,871.414 1501.44,871.418 1501.43,871.423 1501.43,871.428 1501.43,871.432 1501.42,871.437 1501.42,871.441 1501.42,871.446 1501.41,871.451 1501.41,871.455 1501.41,871.46 1501.4,871.464 1501.4,871.469 1501.4,871.474 1501.39,871.478 1501.39,871.483 1501.39,871.487 1501.38,871.492 1501.38,871.497 1501.38,871.501 1501.37,871.506 1501.37,871.511 1501.37,871.515 1501.37,871.52 1501.36,871.524 1501.36,871.529 1501.36,871.534 1501.35,871.538 1501.35,871.543 1501.35,871.548 1501.34,871.552 1501.34,871.557 1501.34,871.562 1501.33,871.566 1501.33,871.571 1501.33,871.576 1501.32,871.58 1501.32,871.585 1501.32,871.59 1501.31,871.594 1501.31,871.599 1501.31,871.604 1501.3,871.608 1501.3,871.613 1501.3,871.618 1501.29,871.622 1501.29,871.627 1501.29,871.632 1501.29,871.636 1501.28,871.641 1501.28,871.646 1501.28,871.65 1501.27,871.655 1501.27,871.66 1501.27,871.664 1501.26,871.669 1501.26,871.674 1501.26,871.679 1501.25,871.683 1501.25,871.688 1501.25,871.693 1501.24,871.697 1501.24,871.702 1501.24,871.707 1501.23,871.712 1501.23,871.716 1501.23,871.721 1501.22,871.726 1501.22,871.73 1501.22,871.735 1501.22,871.74 1501.21,871.745 1501.21,871.749 1501.21,871.754 1501.2,871.759 1501.2,871.764 1501.2,871.768 1501.19,871.773 1501.19,871.778 1501.19,871.783 1501.18,871.787 1501.18,871.792 1501.18,871.797 1501.17,871.802 1501.17,871.806 1501.17,871.811 1501.16,871.816 1501.16,871.821 1501.16,871.825 1501.16,871.83 1501.15,871.835 1501.15,871.84 1501.15,871.845 1501.14,871.849 1501.14,871.854 1501.14,871.859 1501.13,871.864 1501.13,871.869 1501.13,871.873 1501.12,871.878 1501.12,871.883 1501.12,871.888 1501.11,871.892 1501.11,871.897 1501.11,871.902 1501.11,871.907 1501.1,871.912 1501.1,871.917 1501.1,871.921 1501.09,871.926 1501.09,871.931 1501.09,871.936 1501.08,871.941 1501.08,871.945 1501.08,871.95 1501.07,871.955 1501.07,871.96 1501.07,871.965 1501.06,871.97 1501.06,871.974 1501.06,871.979 1501.06,871.984 1501.05,871.989 1501.05,871.994 1501.05,871.999 1501.04,872.004 1501.04,872.008 1501.04,872.013 1501.03,872.018 1501.03,872.023 1501.03,872.028 1501.02,872.033 1501.02,872.038 1501.02,872.042 1501.01,872.047 1501.01,872.052 1501.01,872.057 1501.01,872.062 1501,872.067 1501,872.072 1501,872.077 1500.99,872.081 1500.99,872.086 1500.99,872.091 1500.98,872.096 1500.98,872.101 1500.98,872.106 1500.97,872.111 1500.97,872.116 1500.97,872.121 1500.97,872.126 1500.96,872.13 1500.96,872.135 1500.96,872.14 1500.95,872.145 1500.95,872.15 1500.95,872.155 1500.94,872.16 1500.94,872.165 1500.94,872.17 1500.93,872.175 1500.93,872.18 1500.93,872.185 1500.93,872.19 1500.92,872.195 1500.92,872.199 1500.92,872.204 1500.91,872.209 1500.91,872.214 1500.91,872.219 1500.9,872.224 1500.9,872.229 1500.9,872.234 1500.9,872.239 1500.89,872.244 1500.89,872.249 1500.89,872.254 1500.88,872.259 1500.88,872.264 1500.88,872.269 1500.87,872.274 1500.87,872.279 1500.87,872.284 1500.86,872.289 1500.86,872.294 1500.86,872.299 1500.86,872.304 1500.85,872.309 1500.85,872.314 1500.85,872.319 1500.84,872.324 1500.84,872.329 1500.84,872.334 1500.83,872.339 1500.83,872.344 1500.83,872.349 1500.83,872.354 1500.82,872.359 1500.82,872.364 1500.82,872.369 1500.81,872.374 1500.81,872.379 1500.81,872.384 1500.8,872.389 1500.8,872.394 1500.8,872.399 1500.79,872.404 1500.79,872.409 1500.79,872.414 1500.79,872.419 1500.78,872.424 1500.78,872.429 1500.78,872.434 1500.77,872.439 1500.77,872.444 1500.77,872.449 1500.76,872.454 1500.76,872.46 1500.76,872.465 1500.76,872.47 1500.75,872.475 1500.75,872.48 1500.75,872.485 1500.74,872.49 1500.74,872.495 1500.74,872.5 1500.73,872.505 1500.73,872.51 1500.73,872.515 1500.73,872.52 1500.72,872.525 1500.72,872.531 1500.72,872.536 1500.71,872.541 1500.71,872.546 1500.71,872.551 1500.71,872.556 1500.7,872.561 1500.7,872.566 1500.7,872.571 1500.69,872.576 1500.69,872.582 1500.69,872.587 1500.68,872.592 1500.68,872.597 1500.68,872.602 1500.68,872.607 1500.67,872.612 1500.67,872.617 1500.67,872.623 1500.66,872.628 1500.66,872.633 1500.66,872.638 1500.65,872.643 1500.65,872.648 1500.65,872.653 1500.65,872.659 1500.64,872.664 1500.64,872.669 1500.64,872.674 1500.63,872.679 1500.63,872.684 1500.63,872.69 1500.63,872.695 1500.62,872.7 1500.62,872.705 1500.62,872.71 1500.61,872.715 1500.61,872.721 1500.61,872.726 1500.6,872.731 1500.6,872.736 1500.6,872.741 1500.6,872.746 1500.59,872.752 1500.59,872.757 1500.59,872.762 1500.58,872.767 1500.58,872.772 1500.58,872.778 1500.58,872.783 1500.57,872.788 1500.57,872.793 1500.57,872.798 1500.56,872.804 1500.56,872.809 1500.56,872.814 1500.55,872.819 1500.55,872.825 1500.55,872.83 1500.55,872.835 1500.54,872.84 1500.54,872.846 1500.54,872.851 1500.53,872.856 1500.53,872.861 1500.53,872.866 1500.53,872.872 1500.52,872.877 1500.52,872.882 1500.52,872.887 1500.51,872.893 1500.51,872.898 1500.51,872.903 1500.51,872.908 1500.5,872.914 1500.5,872.919 1500.5,872.924 1500.49,872.93 1500.49,872.935 1500.49,872.94 1500.49,872.945 1500.48,872.951 1500.48,872.956 1500.48,872.961 1500.47,872.967 1500.47,872.972 1500.47,872.977 1500.46,872.982 1500.46,872.988 1500.46,872.993 1500.46,872.998 1500.45,873.004 1500.45,873.009 1500.45,873.014 1500.44,873.02 1500.44,873.025 1500.44,873.03 1500.44,873.035 1500.43,873.041 1500.43,873.046 1500.43,873.051 1500.42,873.057 1500.42,873.062 1500.42,873.067 1500.42,873.073 1500.41,873.078 1500.41,873.083 1500.41,873.089 1500.4,873.094 1500.4,873.099 1500.4,873.105 1500.4,873.11 1500.39,873.116 1500.39,873.121 1500.39,873.126 1500.38,873.132 1500.38,873.137 1500.38,873.142 1500.38,873.148 1500.37,873.153 1500.37,873.158 1500.37,873.164 1500.36,873.169 1500.36,873.175 1500.36,873.18 1500.36,873.185 1500.35,873.191 1500.35,873.196 1500.35,873.202 1500.35,873.207 1500.34,873.212 1500.34,873.218 1500.34,873.223 1500.33,873.229 1500.33,873.234 1500.33,873.239 1500.33,873.245 1500.32,873.25 1500.32,873.256 1500.32,873.261 1500.31,873.266 1500.31,873.272 1500.31,873.277 1500.31,873.283 1500.3,873.288 1500.3,873.294 1500.3,873.299 1500.29,873.304 1500.29,873.31 1500.29,873.315 1500.29,873.321 1500.28,873.326 1500.28,873.332 1500.28,873.337 1500.27,873.343 1500.27,873.348 1500.27,873.354 1500.27,873.359 1500.26,873.364 1500.26,873.37 1500.26,873.375 1500.26,873.381 1500.25,873.386 1500.25,873.392 1500.25,873.397 1500.24,873.403 1500.24,873.408 1500.24,873.414 1500.24,873.419 1500.23,873.425 1500.23,873.43 1500.23,873.436 1500.22,873.441 1500.22,873.447 1500.22,873.452 1500.22,873.458 1500.21,873.463 1500.21,873.469 1500.21,873.474 1500.21,873.48 1500.2,873.485 1500.2,873.491 1500.2,873.496 1500.19,873.502 1500.19,873.507 1500.19,873.513 1500.19,873.519 1500.18,873.524 1500.18,873.53 1500.18,873.535 1500.17,873.541 1500.17,873.546 1500.17,873.552 1500.17,873.557 1500.16,873.563 1500.16,873.568 1500.16,873.574 1500.16,873.58 1500.15,873.585 1500.15,873.591 1500.15,873.596 1500.14,873.602 1500.14,873.607 1500.14,873.613 1500.14,873.619 1500.13,873.624 1500.13,873.63 1500.13,873.635 1500.13,873.641 1500.12,873.646 1500.12,873.652 1500.12,873.658 1500.11,873.663 1500.11,873.669 1500.11,873.674 1500.11,873.68 1500.1,873.686 1500.1,873.691 1500.1,873.697 1500.1,873.703 1500.09,873.708 1500.09,873.714 1500.09,873.719 1500.08,873.725 1500.08,873.731 1500.08,873.736 1500.08,873.742 1500.07,873.748 1500.07,873.753 1500.07,873.759 1500.07,873.764 1500.06,873.77 1500.06,873.776 1500.06,873.781 1500.06,873.787 1500.05,873.793 1500.05,873.798 1500.05,873.804 1500.04,873.81 1500.04,873.815 1500.04,873.821 1500.04,873.827 1500.03,873.832 1500.03,873.838 1500.03,873.844 1500.03,873.849 1500.02,873.855 1500.02,873.861 1500.02,873.867 1500.01,873.872 1500.01,873.878 1500.01,873.884 1500.01,873.889 1500,873.895 1500,873.901 1500,873.906 1500,873.912 1499.99,873.918 1499.99,873.924 1499.99,873.929 1499.99,873.935 1499.98,873.941 1499.98,873.946 1499.98,873.952 1499.97,873.958 1499.97,873.964 1499.97,873.969 1499.97,873.975 1499.96,873.981 1499.96,873.987 1499.96,873.992 1499.96,873.998 1499.95,874.004 1499.95,874.01 1499.95,874.015 1499.95,874.021 1499.94,874.027 1499.94,874.033 1499.94,874.038 1499.94,874.044 1499.93,874.05 1499.93,874.056 1499.93,874.061 1499.92,874.067 1499.92,874.073 1499.92,874.079 1499.92,874.085 1499.91,874.09 1499.91,874.096 1499.91,874.102 1499.91,874.108 1499.9,874.114 1499.9,874.119 1499.9,874.125 1499.9,874.131 1499.89,874.137 1499.89,874.143 1499.89,874.148 1499.89,874.154 1499.88,874.16 1499.88,874.166 1499.88,874.172 1499.87,874.178 1499.87,874.183 1499.87,874.189 1499.87,874.195 1499.86,874.201 1499.86,874.207 1499.86,874.213 1499.86,874.218 1499.85,874.224 1499.85,874.23 1499.85,874.236 1499.85,874.242 1499.84,874.248 1499.84,874.254 1499.84,874.259 1499.84,874.265 1499.83,874.271 1499.83,874.277 1499.83,874.283 1499.83,874.289 1499.82,874.295 1499.82,874.301 1499.82,874.306 1499.82,874.312 1499.81,874.318 1499.81,874.324 1499.81,874.33 1499.8,874.336 1499.8,874.342 1499.8,874.348 1499.8,874.354 1499.79,874.359 1499.79,874.365 1499.79,874.371 1499.79,874.377 1499.78,874.383 1499.78,874.389 1499.78,874.395 1499.78,874.401 1499.77,874.407 1499.77,874.413 1499.77,874.419 1499.77,874.425 1499.76,874.431 1499.76,874.437 1499.76,874.442 1499.76,874.448 1499.75,874.454 1499.75,874.46 1499.75,874.466 1499.75,874.472 1499.74,874.478 1499.74,874.484 1499.74,874.49 1499.74,874.496 1499.73,874.502 1499.73,874.508 1499.73,874.514 1499.73,874.52 1499.72,874.526 1499.72,874.532 1499.72,874.538 1499.72,874.544 1499.71,874.55 1499.71,874.556 1499.71,874.562 1499.71,874.568 1499.7,874.574 1499.7,874.58 1499.7,874.586 1499.7,874.592 1499.69,874.598 1499.69,874.604 1499.69,874.61 1499.69,874.616 1499.68,874.622 1499.68,874.628 1499.68,874.634 1499.68,874.64 1499.67,874.646 1499.67,874.652 1499.67,874.658 1499.67,874.664 1499.66,874.67 1499.66,874.676 1499.66,874.682 1499.66,874.688 1499.65,874.695 1499.65,874.701 1499.65,874.707 1499.65,874.713 1499.64,874.719 1499.64,874.725 1499.64,874.731 1499.64,874.737 1499.63,874.743 1499.63,874.749 1499.63,874.755 1499.63,874.761 1499.62,874.767 1499.62,874.774 1499.62,874.78 1499.62,874.786 1499.61,874.792 1499.61,874.798 1499.61,874.804 1499.61,874.81 1499.6,874.816 1499.6,874.822 1499.6,874.828 1499.6,874.835 1499.59,874.841 1499.59,874.847 1499.59,874.853 1499.59,874.859 1499.58,874.865 1499.58,874.871 1499.58,874.877 1499.58,874.884 1499.57,874.89 1499.57,874.896 1499.57,874.902 1499.57,874.908 1499.56,874.914 1499.56,874.92 1499.56,874.927 1499.56,874.933 1499.55,874.939 1499.55,874.945 1499.55,874.951 1499.55,874.957 1499.54,874.964 1499.54,874.97 1499.54,874.976 1499.54,874.982 1499.53,874.988 1499.53,874.995 1499.53,875.001 1499.53,875.007 1499.53,875.013 1499.52,875.019 1499.52,875.026 1499.52,875.032 1499.52,875.038 1499.51,875.044 1499.51,875.05 1499.51,875.057 1499.51,875.063 1499.5,875.069 1499.5,875.075 1499.5,875.081 1499.5,875.088 1499.49,875.094 1499.49,875.1 1499.49,875.106 1499.49,875.113 1499.48,875.119 1499.48,875.125 1499.48,875.131 1499.48,875.138 1499.47,875.144 1499.47,875.15 1499.47,875.156 1499.47,875.163 1499.46,875.169 1499.46,875.175 1499.46,875.181 1499.46,875.188 1499.46,875.194 1499.45,875.2 1499.45,875.207 1499.45,875.213 1499.45,875.219 1499.44,875.225 1499.44,875.232 1499.44,875.238 1499.44,875.244 1499.43,875.251 1499.43,875.257 1499.43,875.263 1499.43,875.27 1499.42,875.276 1499.42,875.282 1499.42,875.288 1499.42,875.295 1499.42,875.301 1499.41,875.307 1499.41,875.314 1499.41,875.32 1499.41,875.326 1499.4,875.333 1499.4,875.339 1499.4,875.345 1499.4,875.352 1499.39,875.358 1499.39,875.364 1499.39,875.371 1499.39,875.377 1499.38,875.384 1499.38,875.39 1499.38,875.396 1499.38,875.403 1499.38,875.409 1499.37,875.415 1499.37,875.422 1499.37,875.428 1499.37,875.435 1499.36,875.441 1499.36,875.447 1499.36,875.454 1499.36,875.46 1499.35,875.466 1499.35,875.473 1499.35,875.479 1499.35,875.486 1499.35,875.492 1499.34,875.498 1499.34,875.505 1499.34,875.511 1499.34,875.518 1499.33,875.524 1499.33,875.531 1499.33,875.537 1499.33,875.543 1499.32,875.55 1499.32,875.556 1499.32,875.563 1499.32,875.569 1499.32,875.576 1499.31,875.582 1499.31,875.589 1499.31,875.595 1499.31,875.601 1499.3,875.608 1499.3,875.614 1499.3,875.621 1499.3,875.627 1499.29,875.634 1499.29,875.64 1499.29,875.647 1499.29,875.653 1499.29,875.66 1499.28,875.666 1499.28,875.673 1499.28,875.679 1499.28,875.686 1499.27,875.692 1499.27,875.699 1499.27,875.705 1499.27,875.712 1499.26,875.718 1499.26,875.725 1499.26,875.731 1499.26,875.738 1499.26,875.744 1499.25,875.751 1499.25,875.757 1499.25,875.764 1499.25,875.77 1499.24,875.777 1499.24,875.783 1499.24,875.79 1499.24,875.796 1499.24,875.803 1499.23,875.809 1499.23,875.816 1499.23,875.823 1499.23,875.829 1499.22,875.836 1499.22,875.842 1499.22,875.849 1499.22,875.855 1499.22,875.862 1499.21,875.868 1499.21,875.875 1499.21,875.882 1499.21,875.888 1499.2,875.895 1499.2,875.901 1499.2,875.908 1499.2,875.915 1499.2,875.921 1499.19,875.928 1499.19,875.934 1499.19,875.941 1499.19,875.947 1499.18,875.954 1499.18,875.961 1499.18,875.967 1499.18,875.974 1499.18,875.981 1499.17,875.987 1499.17,875.994 1499.17,876 1499.17,876.007 1499.16,876.014 1499.16,876.02 1499.16,876.027 1499.16,876.034 1499.16,876.04 1499.15,876.047 1499.15,876.054 1499.15,876.06 1499.15,876.067 1499.14,876.074 1499.14,876.08 1499.14,876.087 1499.14,876.094 1499.14,876.1 1499.13,876.107 1499.13,876.114 1499.13,876.12 1499.13,876.127 1499.13,876.134 1499.12,876.14 1499.12,876.147 1499.12,876.154 1499.12,876.16 1499.11,876.167 1499.11,876.174 1499.11,876.18 1499.11,876.187 1499.11,876.194 1499.1,876.201 1499.1,876.207 1499.1,876.214 1499.1,876.221 1499.09,876.227 1499.09,876.234 1499.09,876.241 1499.09,876.248 1499.09,876.254 1499.08,876.261 1499.08,876.268 1499.08,876.275 1499.08,876.281 1499.08,876.288 1499.07,876.295 1499.07,876.302 1499.07,876.308 1499.07,876.315 1499.06,876.322 1499.06,876.329 1499.06,876.335 1499.06,876.342 1499.06,876.349 1499.05,876.356 1499.05,876.363 1499.05,876.369 1499.05,876.376 1499.05,876.383 1499.04,876.39 1499.04,876.397 1499.04,876.403 1499.04,876.41 1499.04,876.417 1499.03,876.424 1499.03,876.431 1499.03,876.437 1499.03,876.444 1499.02,876.451 1499.02,876.458 1499.02,876.465 1499.02,876.472 1499.02,876.478 1499.01,876.485 1499.01,876.492 1499.01,876.499 1499.01,876.506 1499.01,876.513 1499,876.519 1499,876.526 1499,876.533 1499,876.54 1499,876.547 1498.99,876.554 1498.99,876.561 1498.99,876.568 1498.99,876.574 1498.98,876.581 1498.98,876.588 1498.98,876.595 1498.98,876.602 1498.98,876.609 1498.97,876.616 1498.97,876.623 1498.97,876.629 1498.97,876.636 1498.97,876.643 1498.96,876.65 1498.96,876.657 1498.96,876.664 1498.96,876.671 1498.96,876.678 1498.95,876.685 1498.95,876.692 1498.95,876.699 1498.95,876.706 1498.95,876.713 1498.94,876.719 1498.94,876.726 1498.94,876.733 1498.94,876.74 1498.94,876.747 1498.93,876.754 1498.93,876.761 1498.93,876.768 1498.93,876.775 1498.93,876.782 1498.92,876.789 1498.92,876.796 1498.92,876.803 1498.92,876.81 1498.92,876.817 1498.91,876.824 1498.91,876.831 1498.91,876.838 1498.91,876.845 1498.91,876.852 1498.9,876.859 1498.9,876.866 1498.9,876.873 1498.9,876.88 1498.89,876.887 1498.89,876.894 1498.89,876.901 1498.89,876.908 1498.89,876.915 1498.88,876.922 1498.88,876.929 1498.88,876.936 1498.88,876.943 1498.88,876.95 1498.87,876.957 1498.87,876.964 1498.87,876.971 1498.87,876.978 1498.87,876.985 1498.86,876.992 1498.86,876.999 1498.86,877.007 1498.86,877.014 1498.86,877.021 1498.86,877.028 1498.85,877.035 1498.85,877.042 1498.85,877.049 1498.85,877.056 1498.85,877.063 1498.84,877.07 1498.84,877.077 1498.84,877.084 1498.84,877.092 1498.84,877.099 1498.83,877.106 1498.83,877.113 1498.83,877.12 1498.83,877.127 1498.83,877.134 1498.82,877.141 1498.82,877.148 1498.82,877.156 1498.82,877.163 1498.82,877.17 1498.81,877.177 1498.81,877.184 1498.81,877.191 1498.81,877.198 1498.81,877.206 1498.8,877.213 1498.8,877.22 1498.8,877.227 1498.8,877.234 1498.8,877.241 1498.79,877.248 1498.79,877.256 1498.79,877.263 1498.79,877.27 1498.79,877.277 1498.78,877.284 1498.78,877.292 1498.78,877.299 1498.78,877.306 1498.78,877.313 1498.78,877.32 1498.77,877.327 1498.77,877.335 1498.77,877.342 1498.77,877.349 1498.77,877.356 1498.76,877.364 1498.76,877.371 1498.76,877.378 1498.76,877.385 1498.76,877.392 1498.75,877.4 1498.75,877.407 1498.75,877.414 1498.75,877.421 1498.75,877.429 1498.74,877.436 1498.74,877.443 1498.74,877.45 1498.74,877.458 1498.74,877.465 1498.74,877.472 1498.73,877.479 1498.73,877.487 1498.73,877.494 1498.73,877.501 1498.73,877.509 1498.72,877.516 1498.72,877.523 1498.72,877.53 1498.72,877.538 1498.72,877.545 1498.71,877.552 1498.71,877.56 1498.71,877.567 1498.71,877.574 1498.71,877.581 1498.71,877.589 1498.7,877.596 1498.7,877.603 1498.7,877.611 1498.7,877.618 1498.7,877.625 1498.69,877.633 1498.69,877.64 1498.69,877.647 1498.69,877.655 1498.69,877.662 1498.69,877.669 1498.68,877.677 1498.68,877.684 1498.68,877.691 1498.68,877.699 1498.68,877.706 1498.67,877.714 1498.67,877.721 1498.67,877.728 1498.67,877.736 1498.67,877.743 1498.67,877.75 1498.66,877.758 1498.66,877.765 1498.66,877.773 1498.66,877.78 1498.66,877.787 1498.65,877.795 1498.65,877.802 1498.65,877.81 1498.65,877.817 1498.65,877.824 1498.65,877.832 1498.64,877.839 1498.64,877.847 1498.64,877.854 1498.64,877.862 1498.64,877.869 1498.63,877.876 1498.63,877.884 1498.63,877.891 1498.63,877.899 1498.63,877.906 1498.63,877.914 1498.62,877.921 1498.62,877.929 1498.62,877.936 1498.62,877.943 1498.62,877.951 1498.61,877.958 1498.61,877.966 1498.61,877.973 1498.61,877.981 1498.61,877.988 1498.61,877.996 1498.6,878.003 1498.6,878.011 1498.6,878.018 1498.6,878.026 1498.6,878.033 1498.6,878.041 1498.59,878.048 1498.59,878.056 1498.59,878.063 1498.59,878.071 1498.59,878.078 1498.58,878.086 1498.58,878.093 1498.58,878.101 1498.58,878.108 1498.58,878.116 1498.58,878.124 1498.57,878.131 1498.57,878.139 1498.57,878.146 1498.57,878.154 1498.57,878.161 1498.57,878.169 1498.56,878.176 1498.56,878.184 1498.56,878.192 1498.56,878.199 1498.56,878.207 1498.56,878.214 1498.55,878.222 1498.55,878.229 1498.55,878.237 1498.55,878.245 1498.55,878.252 1498.54,878.26 1498.54,878.267 1498.54,878.275 1498.54,878.283 1498.54,878.29 1498.54,878.298 1498.53,878.305 1498.53,878.313 1498.53,878.321 1498.53,878.328 1498.53,878.336 1498.53,878.344 1498.52,878.351 1498.52,878.359 1498.52,878.367 1498.52,878.374 1498.52,878.382 1498.52,878.389 1498.51,878.397 1498.51,878.405 1498.51,878.412 1498.51,878.42 1498.51,878.428 1498.51,878.435 1498.5,878.443 1498.5,878.451 1498.5,878.459 1498.5,878.466 1498.5,878.474 1498.5,878.482 1498.49,878.489 1498.49,878.497 1498.49,878.505 1498.49,878.512 1498.49,878.52 1498.49,878.528 1498.48,878.536 1498.48,878.543 1498.48,878.551 1498.48,878.559 1498.48,878.566 1498.48,878.574 1498.47,878.582 1498.47,878.59 1498.47,878.597 1498.47,878.605 1498.47,878.613 1498.47,878.621 1498.46,878.628 1498.46,878.636 1498.46,878.644 1498.46,878.652 1498.46,878.659 1498.46,878.667 1498.46,878.675 1498.45,878.683 1498.45,878.691 1498.45,878.698 1498.45,878.706 1498.45,878.714 1498.45,878.722 1498.44,878.73 1498.44,878.737 1498.44,878.745 1498.44,878.753 1498.44,878.761 1498.44,878.769 1498.43,878.776 1498.43,878.784 1498.43,878.792 1498.43,878.8 1498.43,878.808 1498.43,878.815 1498.42,878.823 1498.42,878.831 1498.42,878.839 1498.42,878.847 1498.42,878.855 1498.42,878.863 1498.41,878.87 1498.41,878.878 1498.41,878.886 1498.41,878.894 1498.41,878.902 1498.41,878.91 1498.41,878.918 1498.4,878.926 1498.4,878.933 1498.4,878.941 1498.4,878.949 1498.4,878.957 1498.4,878.965 1498.39,878.973 1498.39,878.981 1498.39,878.989 1498.39,878.997 1498.39,879.005 1498.39,879.012 1498.39,879.02 1498.38,879.028 1498.38,879.036 1498.38,879.044 1498.38,879.052 1498.38,879.06 1498.38,879.068 1498.37,879.076 1498.37,879.084 1498.37,879.092 1498.37,879.1 1498.37,879.108 1498.37,879.116 1498.37,879.124 1498.36,879.132 1498.36,879.14 1498.36,879.148 1498.36,879.156 1498.36,879.164 1498.36,879.172 1498.35,879.179 1498.35,879.187 1498.35,879.195 1498.35,879.203 1498.35,879.211 1498.35,879.219 1498.35,879.227 1498.34,879.236 1498.34,879.244 1498.34,879.252 1498.34,879.26 1498.34,879.268 1498.34,879.276 1498.34,879.284 1498.33,879.292 1498.33,879.3 1498.33,879.308 1498.33,879.316 1498.33,879.324 1498.33,879.332 1498.32,879.34 1498.32,879.348 1498.32,879.356 1498.32,879.364 1498.32,879.372 1498.32,879.38 1498.32,879.388 1498.31,879.396 1498.31,879.405 1498.31,879.413 1498.31,879.421 1498.31,879.429 1498.31,879.437 1498.31,879.445 1498.3,879.453 1498.3,879.461 1498.3,879.469 1498.3,879.477 1498.3,879.486 1498.3,879.494 1498.3,879.502 1498.29,879.51 1498.29,879.518 1498.29,879.526 1498.29,879.534 1498.29,879.542 1498.29,879.551 1498.29,879.559 1498.28,879.567 1498.28,879.575 1498.28,879.583 1498.28,879.591 1498.28,879.6 1498.28,879.608 1498.28,879.616 1498.27,879.624 1498.27,879.632 1498.27,879.64 1498.27,879.649 1498.27,879.657 1498.27,879.665 1498.27,879.673 1498.26,879.681 1498.26,879.69 1498.26,879.698 1498.26,879.706 1498.26,879.714 1498.26,879.722 1498.26,879.731 1498.25,879.739 1498.25,879.747 1498.25,879.755 1498.25,879.764 1498.25,879.772 1498.25,879.78 1498.25,879.788 1498.24,879.797 1498.24,879.805 1498.24,879.813 1498.24,879.821 1498.24,879.83 1498.24,879.838 1498.24,879.846 1498.24,879.854 1498.23,879.863 1498.23,879.871 1498.23,879.879 1498.23,879.888 1498.23,879.896 1498.23,879.904 1498.23,879.912 1498.22,879.921 1498.22,879.929 1498.22,879.937 1498.22,879.946 1498.22,879.954 1498.22,879.962 1498.22,879.971 1498.21,879.979 1498.21,879.987 1498.21,879.996 1498.21,880.004 1498.21,880.012 1498.21,880.021 1498.21,880.029 1498.21,880.037 1498.2,880.046 1498.2,880.054 1498.2,880.062 1498.2,880.071 1498.2,880.079 1498.2,880.087 1498.2,880.096 1498.19,880.104 1498.19,880.113 1498.19,880.121 1498.19,880.129 1498.19,880.138 1498.19,880.146 1498.19,880.155 1498.19,880.163 1498.18,880.171 1498.18,880.18 1498.18,880.188 1498.18,880.197 1498.18,880.205 1498.18,880.213 1498.18,880.222 1498.18,880.23 1498.17,880.239 1498.17,880.247 1498.17,880.256 1498.17,880.264 1498.17,880.273 1498.17,880.281 1498.17,880.289 1498.16,880.298 1498.16,880.306 1498.16,880.315 1498.16,880.323 1498.16,880.332 1498.16,880.34 1498.16,880.349 1498.16,880.357 1498.15,880.366 1498.15,880.374 1498.15,880.383 1498.15,880.391 1498.15,880.4 1498.15,880.408 1498.15,880.417 1498.15,880.425 1498.14,880.434 1498.14,880.442 1498.14,880.451 1498.14,880.459 1498.14,880.468 1498.14,880.476 1498.14,880.485 1498.14,880.493 1498.13,880.502 1498.13,880.51 1498.13,880.519 1498.13,880.528 1498.13,880.536 1498.13,880.545 1498.13,880.553 1498.13,880.562 1498.13,880.57 1498.12,880.579 1498.12,880.588 1498.12,880.596 1498.12,880.605 1498.12,880.613 1498.12,880.622 1498.12,880.631 1498.12,880.639 1498.11,880.648 1498.11,880.656 1498.11,880.665 1498.11,880.674 1498.11,880.682 1498.11,880.691 1498.11,880.699 1498.11,880.708 1498.1,880.717 1498.1,880.725 1498.1,880.734 1498.1,880.743 1498.1,880.751 1498.1,880.76 1498.1,880.769 1498.1,880.777 1498.1,880.786 1498.09,880.795 1498.09,880.803 1498.09,880.812 1498.09,880.821 1498.09,880.829 1498.09,880.838 1498.09,880.847 1498.09,880.855 1498.08,880.864 1498.08,880.873 1498.08,880.881 1498.08,880.89 1498.08,880.899 1498.08,880.908 1498.08,880.916 1498.08,880.925 1498.08,880.934 1498.07,880.942 1498.07,880.951 1498.07,880.96 1498.07,880.969 1498.07,880.977 1498.07,880.986 1498.07,880.995 1498.07,881.004 1498.07,881.012 1498.06,881.021 1498.06,881.03 1498.06,881.039 1498.06,881.047 1498.06,881.056 1498.06,881.065 1498.06,881.074 1498.06,881.083 1498.06,881.091 1498.05,881.1 1498.05,881.109 1498.05,881.118 1498.05,881.127 1498.05,881.135 1498.05,881.144 1498.05,881.153 1498.05,881.162 1498.05,881.171 1498.04,881.179 1498.04,881.188 1498.04,881.197 1498.04,881.206 1498.04,881.215 1498.04,881.224 1498.04,881.232 1498.04,881.241 1498.04,881.25 1498.03,881.259 1498.03,881.268 1498.03,881.277 1498.03,881.286 1498.03,881.295 1498.03,881.303 1498.03,881.312 1498.03,881.321 1498.03,881.33 1498.03,881.339 1498.02,881.348 1498.02,881.357 1498.02,881.366 1498.02,881.375 1498.02,881.383 1498.02,881.392 1498.02,881.401 1498.02,881.41 1498.02,881.419 1498.01,881.428 1498.01,881.437 1498.01,881.446 1498.01,881.455 1498.01,881.464 1498.01,881.473 1498.01,881.482 1498.01,881.491 1498.01,881.5 1498.01,881.509 1498,881.518 1498,881.527 1498,881.536 1498,881.544 1498,881.553 1498,881.562 1498,881.571 1498,881.58 1498,881.589 1498,881.598 1497.99,881.607 1497.99,881.616 1497.99,881.625 1497.99,881.634 1497.99,881.643 1497.99,881.653 1497.99,881.662 1497.99,881.671 1497.99,881.68 1497.99,881.689 1497.98,881.698 1497.98,881.707 1497.98,881.716 1497.98,881.725 1497.98,881.734 1497.98,881.743 1497.98,881.752 1497.98,881.761 1497.98,881.77 1497.98,881.779 1497.97,881.788 1497.97,881.797 1497.97,881.806 1497.97,881.816 1497.97,881.825 1497.97,881.834 1497.97,881.843 1497.97,881.852 1497.97,881.861 1497.97,881.87 1497.97,881.879 1497.96,881.888 1497.96,881.898 1497.96,881.907 1497.96,881.916 1497.96,881.925 1497.96,881.934 1497.96,881.943 1497.96,881.952 1497.96,881.962 1497.96,881.971 1497.95,881.98 1497.95,881.989 1497.95,881.998 1497.95,882.007 1497.95,882.016 1497.95,882.026 1497.95,882.035 1497.95,882.044 1497.95,882.053 1497.95,882.062 1497.95,882.072 1497.94,882.081 1497.94,882.09 1497.94,882.099 1497.94,882.108 1497.94,882.118 1497.94,882.127 1497.94,882.136 1497.94,882.145 1497.94,882.155 1497.94,882.164 1497.94,882.173 1497.94,882.182 1497.93,882.191 1497.93,882.201 1497.93,882.21 1497.93,882.219 1497.93,882.229 1497.93,882.238 1497.93,882.247 1497.93,882.256 1497.93,882.266 1497.93,882.275 1497.93,882.284 1497.92,882.293 1497.92,882.303 1497.92,882.312 1497.92,882.321 1497.92,882.331 1497.92,882.34 1497.92,882.349 1497.92,882.359 1497.92,882.368 1497.92,882.377 1497.92,882.387 1497.92,882.396 1497.91,882.405 1497.91,882.415 1497.91,882.424 1497.91,882.433 1497.91,882.443 1497.91,882.452 1497.91,882.461 1497.91,882.471 1497.91,882.48 1497.91,882.489 1497.91,882.499 1497.91,882.508 1497.9,882.517 1497.9,882.527 1497.9,882.536 1497.9,882.546 1497.9,882.555 1497.9,882.564 1497.9,882.574 1497.9,882.583 1497.9,882.593 1497.9,882.602 1497.9,882.611 1497.9,882.621 1497.9,882.63 1497.89,882.64 1497.89,882.649 1497.89,882.659 1497.89,882.668 1497.89,882.678 1497.89,882.687 1497.89,882.696 1497.89,882.706 1497.89,882.715 1497.89,882.725 1497.89,882.734 1497.89,882.744 1497.89,882.753 1497.88,882.763 1497.88,882.772 1497.88,882.782 1497.88,882.791 1497.88,882.801 1497.88,882.81 1497.88,882.82 1497.88,882.829 1497.88,882.839 1497.88,882.848 1497.88,882.858 1497.88,882.867 1497.88,882.877 1497.87,882.886 1497.87,882.896 1497.87,882.905 1497.87,882.915 1497.87,882.924 1497.87,882.934 1497.87,882.944 1497.87,882.953 1497.87,882.963 1497.87,882.972 1497.87,882.982 1497.87,882.991 1497.87,883.001 1497.87,883.011 1497.86,883.02 1497.86,883.03 1497.86,883.039 1497.86,883.049 1497.86,883.059 1497.86,883.068 1497.86,883.078 1497.86,883.087 1497.86,883.097 1497.86,883.107 1497.86,883.116 1497.86,883.126 1497.86,883.135 1497.86,883.145 1497.86,883.155 1497.85,883.164 1497.85,883.174 1497.85,883.184 1497.85,883.193 1497.85,883.203 1497.85,883.213 1497.85,883.222 1497.85,883.232 1497.85,883.242 1497.85,883.251 1497.85,883.261 1497.85,883.271 1497.85,883.28 1497.85,883.29 1497.85,883.3 1497.84,883.31 1497.84,883.319 1497.84,883.329 1497.84,883.339 1497.84,883.348 1497.84,883.358 1497.84,883.368 1497.84,883.378 1497.84,883.387 1497.84,883.397 1497.84,883.407 1497.84,883.417 1497.84,883.426 1497.84,883.436 1497.84,883.446 1497.84,883.456 1497.83,883.465 1497.83,883.475 1497.83,883.485 1497.83,883.495 1497.83,883.504 1497.83,883.514 1497.83,883.524 1497.83,883.534 1497.83,883.544 1497.83,883.553 1497.83,883.563 1497.83,883.573 1497.83,883.583 1497.83,883.593 1497.83,883.602 1497.83,883.612 1497.83,883.622 1497.82,883.632 1497.82,883.642 1497.82,883.652 1497.82,883.662 1497.82,883.671 1497.82,883.681 1497.82,883.691 1497.82,883.701 1497.82,883.711 1497.82,883.721 1497.82,883.731 1497.82,883.74 1497.82,883.75 1497.82,883.76 1497.82,883.77 1497.82,883.78 1497.82,883.79 1497.82,883.8 1497.81,883.81 1497.81,883.82 1497.81,883.83 1497.81,883.839 1497.81,883.849 1497.81,883.859 1497.81,883.869 1497.81,883.879 1497.81,883.889 1497.81,883.899 1497.81,883.909 1497.81,883.919 1497.81,883.929 1497.81,883.939 1497.81,883.949 1497.81,883.959 1497.81,883.969 1497.81,883.979 1497.81,883.989 1497.8,883.999 1497.8,884.009 1497.8,884.019 1497.8,884.029 1497.8,884.039 1497.8,884.049 1497.8,884.059 1497.8,884.069 1497.8,884.079 1497.8,884.089 1497.8,884.099 1497.8,884.109 1497.8,884.119 1497.8,884.129 1497.8,884.139 1497.8,884.149 1497.8,884.159 1497.8,884.169 1497.8,884.179 1497.8,884.189 1497.8,884.199 1497.8,884.209 1497.79,884.219 1497.79,884.23 1497.79,884.24 1497.79,884.25 1497.79,884.26 1497.79,884.27 1497.79,884.28 1497.79,884.29 1497.79,884.3 1497.79,884.31 1497.79,884.32 1497.79,884.331 1497.79,884.341 1497.79,884.351 1497.79,884.361 1497.79,884.371 1497.79,884.381 1497.79,884.391 1497.79,884.401 1497.79,884.412 1497.79,884.422 1497.79,884.432 1497.79,884.442 1497.78,884.452 1497.78,884.462 1497.78,884.473 1497.78,884.483 1497.78,884.493 1497.78,884.503 1497.78,884.513 1497.78,884.524 1497.78,884.534 1497.78,884.544 1497.78,884.554 1497.78,884.564 1497.78,884.575 1497.78,884.585 1497.78,884.595 1497.78,884.605 1497.78,884.616 1497.78,884.626 1497.78,884.636 1497.78,884.646 1497.78,884.657 1497.78,884.667 1497.78,884.677 1497.78,884.687 1497.78,884.698 1497.78,884.708 1497.77,884.718 1497.77,884.728 1497.77,884.739 1497.77,884.749 1497.77,884.759 1497.77,884.77 1497.77,884.78 1497.77,884.79 1497.77,884.8 1497.77,884.811 1497.77,884.821 1497.77,884.831 1497.77,884.842 1497.77,884.852 1497.77,884.862 1497.77,884.873 1497.77,884.883 1497.77,884.893 1497.77,884.904 1497.77,884.914 1497.77,884.925 1497.77,884.935 1497.77,884.945 1497.77,884.956 1497.77,884.966 1497.77,884.976 1497.77,884.987 1497.77,884.997 1497.77,885.008 1497.77,885.018 1497.77,885.028 1497.77,885.039 1497.76,885.049 1497.76,885.06 1497.76,885.07 1497.76,885.08 1497.76,885.091 1497.76,885.101 1497.76,885.112 1497.76,885.122 1497.76,885.133 1497.76,885.143 1497.76,885.154 1497.76,885.164 1497.76,885.174 1497.76,885.185 1497.76,885.195 1497.76,885.206 1497.76,885.216 1497.76,885.227 1497.76,885.237 1497.76,885.248 1497.76,885.258 1497.76,885.269 1497.76,885.279 1497.76,885.29 1497.76,885.3 1497.76,885.311 1497.76,885.321 1497.76,885.332 1497.76,885.342 1497.76,885.353 1497.76,885.363 1497.76,885.374 1497.76,885.385 1497.76,885.395 1497.76,885.406 1497.76,885.416 1497.76,885.427 1497.76,885.437 1497.76,885.448 1497.76,885.459 1497.76,885.469 1497.76,885.48 1497.76,885.49 1497.75,885.501 1497.75,885.511 1497.75,885.522 1497.75,885.533 1497.75,885.543 1497.75,885.554 1497.75,885.564 1497.75,885.575 1497.75,885.586 1497.75,885.596 1497.75,885.607 1497.75,885.618 1497.75,885.628 1497.75,885.639 1497.75,885.65 1497.75,885.66 1497.75,885.671 1497.75,885.682 1497.75,885.692 1497.75,885.703 1497.75,885.714 1497.75,885.724 1497.75,885.735 1497.75,885.746 1497.75,885.756 1497.75,885.767 1497.75,885.778 1497.75,885.788 1497.75,885.799 1497.75,885.81 1497.75,885.821 1497.75,885.831 1497.75,885.842 1497.75,885.853 1497.75,885.864 1497.75,885.874 1497.75,885.885 1497.75,885.896 1497.75,885.907 1497.75,885.917 1497.75,885.928 1497.75,885.939 1497.75,885.95 1497.75,885.96 1497.75,885.971 1497.75,885.982 1497.75,885.993 1497.75,886.004 1497.75,886.014 1497.75,886.025 1497.75,886.036 1497.75,886.047 1497.75,886.058 1497.75,886.068 1497.75,886.079 1497.75,886.09 1497.75,886.101 1497.75,886.112 1497.75,886.123 1497.75,886.133 1497.75,886.144 1497.75,886.155 1497.75,886.166 1497.75,886.177 1497.75,886.188 1497.75,886.199 1497.75,886.209 1497.75,886.22 1497.75,886.231 1497.75,886.242 1497.75,886.253 1497.75,886.264 1497.75,886.275 1497.75,886.286 1497.75,886.297 1497.75,886.308 1497.75,886.318 1497.75,886.329 1497.75,886.34 1497.75,886.351 1497.75,886.362 1497.75,886.373 1497.75,886.384 1497.75,886.395 1497.75,886.406 1497.75,886.417 1497.75,886.428 1497.75,886.439 1497.75,886.45 1497.75,886.461 1497.75,886.472 1497.75,886.483 1497.75,886.494 1497.75,886.505 1497.75,886.516 1497.75,886.527 1497.75,886.538 1497.75,886.549 1497.75,886.56 1497.75,886.571 1497.75,886.582 1497.75,886.593 1497.75,886.604 1497.75,886.616 1497.75,886.627 1497.75,886.638 1497.75,886.649 1497.75,886.66 1497.75,886.671 1497.75,886.682 1497.75,886.693 1497.75,886.705 1497.75,886.716 1497.75,886.727 1497.75,886.738 1497.75,886.749 1497.75,886.76 1497.75,886.772 1497.75,886.783 1497.75,886.794 1497.75,886.805 1497.75,886.816 1497.75,886.828 1497.75,886.839 1497.75,886.85 1497.75,886.861 1497.75,886.873 1497.75,886.884 1497.75,886.895 1497.75,886.907 1497.75,886.918 1497.75,886.929 1497.75,886.94 1497.75,886.952 1497.75,886.963 1497.75,886.974 1497.75,886.986 1497.75,886.997 1497.75,887.008 1497.75,887.02 1497.75,887.031 1497.75,887.043 1497.75,887.054 1497.75,887.065 1497.75,887.077 1497.75,887.088 1497.75,887.099 1497.75,887.111 1497.75,887.122 1497.75,887.134 1497.75,887.145 1497.75,887.157 1497.75,887.168 1497.75,887.18 1497.75,887.191 1497.75,887.202 1497.75,887.214 1497.75,887.225 1497.75,887.237 1497.75,887.248 1497.75,887.26 1497.75,887.272 1497.75,887.283 1497.75,887.295 1497.75,887.306 1497.75,887.318 1497.75,887.329 1497.75,887.341 1497.75,887.352 1497.75,887.364 1497.75,887.376 1497.75,887.387 1497.75,887.399 1497.75,887.41 1497.75,887.422 1497.75,887.434 1497.75,887.445 1497.75,887.457 1497.75,887.468 1497.75,887.48 1497.75,887.492 1497.75,887.503 1497.75,887.515 1497.75,887.527 1497.75,887.539 1497.75,887.55 1497.75,887.562 1497.75,887.574 1497.75,887.585 1497.75,887.597 1497.75,887.609 1497.75,887.621 1497.75,887.632 1497.75,887.644 1497.75,887.656 1497.75,887.668 1497.75,887.679 1497.75,887.691 1497.75,887.703 1497.75,887.715 1497.75,887.727 1497.75,887.738 1497.75,887.75 1497.75,887.762 1497.75,887.774 1497.75,887.786 1497.75,887.798 1497.75,887.809 1497.75,887.821 1497.75,887.833 1497.75,887.845 1497.75,887.857 1497.75,887.869 1497.75,887.881 1497.75,887.893 1497.75,887.905 1497.75,887.917 1497.75,887.929 1497.75,887.94 1497.75,887.952 1497.75,887.964 1497.75,887.976 1497.75,887.988 1497.75,888 1497.75,888.012 1497.75,888.024 1497.75,888.036 1497.75,888.048 1497.75,888.06 1497.75,888.072 1497.75,888.084 1497.75,888.096 1497.75,888.109 1497.75,888.121 1497.75,888.133 1497.75,888.145 1497.75,888.157 1497.75,888.169 1497.75,888.181 1497.75,888.193 1497.75,888.205 1497.75,888.217 1497.75,888.229 1497.75,888.242 1497.75,888.254 1497.75,888.266 1497.75,888.278 1497.75,888.29 1497.75,888.302 1497.75,888.315 1497.75,888.327 1497.75,888.339 1497.75,888.351 1497.75,888.363 1497.75,888.376 1497.75,888.388 1497.75,888.4 1497.75,888.412 1497.75,888.425 1497.75,888.437 1497.75,888.449 1497.75,888.461 1497.75,888.474 1497.75,888.486 1497.75,888.498 1497.75,888.511 1497.75,888.523 1497.75,888.535 1497.75,888.548 1497.75,888.56 1497.75,888.572 1497.75,888.585 1497.75,888.597 1497.75,888.609 1497.75,888.622 1497.75,888.634 1497.75,888.646 1497.75,888.659 1497.75,888.671 1497.75,888.684 1497.75,888.696 1497.75,888.708 1497.75,888.721 1497.75,888.733 1497.75,888.746 1497.75,888.758 1497.75,888.771 1497.75,888.783 1497.75,888.796 1497.75,888.808 1497.75,888.821 1497.75,888.833 1497.75,888.846 1497.75,888.858 1497.75,888.871 1497.75,888.883 1497.75,888.896 1497.75,888.908 1497.75,888.921 1497.75,888.933 1497.75,888.946 1497.75,888.959 1497.75,888.971 1497.75,888.984 1497.75,888.996 1497.75,889.009 1497.75,889.022 1497.75,889.034 1497.75,889.047 1497.75,889.06 1497.75,889.072 1497.75,889.085 1497.75,889.098 1497.75,889.11 1497.75,889.123 1497.75,889.136 1497.75,889.148 1497.75,889.161 1497.75,889.174 1497.75,889.186 1497.75,889.199 1497.75,889.212 1497.75,889.225 1497.75,889.237 1497.75,889.25 1497.75,889.263 1497.75,889.276 1497.75,889.288 1497.75,889.301 1497.75,889.314 1497.75,889.327 1497.75,889.34 1497.75,889.352 1497.75,889.365 1497.75,889.378 1497.75,889.391 1497.75,889.404 1497.75,889.417 1497.75,889.43 1497.75,889.442 1497.75,889.455 1497.75,889.468 1497.75,889.481 1497.75,889.494 1497.75,889.507 1497.75,889.52 1497.75,889.533 1497.75,889.546 1497.75,889.559 1497.75,889.572 1497.75,889.585 1497.75,889.598 1497.75,889.611 1497.75,889.624 1497.75,889.637 1497.75,889.65 1497.75,889.663 1497.75,889.676 1497.75,889.689 1497.75,889.702 1497.75,889.715 1497.75,889.728 1497.75,889.741 1497.75,889.754 1497.75,889.767 1497.75,889.78 1497.75,889.793 1497.75,889.806 1497.75,889.819 1497.75,889.832 1497.75,889.846 1497.75,889.859 1497.75,889.872 1497.75,889.885 1497.75,889.898 1497.75,889.911 1497.75,889.924 1497.75,889.938 1497.75,889.951 1497.75,889.964 1497.75,889.977 1497.75,889.99 1497.75,890.004 1497.75,890.017 1497.75,890.03 1497.75,890.043 1497.75,890.057 1497.75,890.07 1497.75,890.083 1497.75,890.096 1497.75,890.11 1497.75,890.123 1497.75,890.136 1497.75,890.149 1497.75,890.163 1497.75,890.176 1497.75,890.189 1497.75,890.203 1497.75,890.216 1497.75,890.229 1497.75,890.243 1497.75,890.256 1497.75,890.27 1497.75,890.283 1497.75,890.296 1497.75,890.31 1497.75,890.323 1497.75,890.337 1497.75,890.35 1497.75,890.363 1497.75,890.377 1497.75,890.39 1497.75,890.404 1497.75,890.417 1497.75,890.431 1497.75,890.444 1497.75,890.458 1497.75,890.471 1497.75,890.485 1497.75,890.498 1497.75,890.512 1497.75,890.525 1497.75,890.539 1497.75,890.552 1497.75,890.566 1497.75,890.579 1497.75,890.593 1497.75,890.607 1497.75,890.62 1497.75,890.634 1497.75,890.647 1497.75,890.661 1497.75,890.675 1497.75,890.688 1497.75,890.702 1497.75,890.715 1497.75,890.729 1497.75,890.743 1497.75,890.756 1497.75,890.77 1497.75,890.784 1497.75,890.797 1497.75,890.811 1497.75,890.825 1497.75,890.839 1497.75,890.852 1497.75,890.866 1497.75,890.88 1497.75,890.893 1497.75,890.907 1497.75,890.921 1497.75,890.935 1497.75,890.948 1497.75,890.962 1497.75,890.976 1497.75,890.99 1497.75,891.004 1497.75,891.017 1497.75,891.031 1497.75,891.045 1497.75,891.059 1497.75,891.073 1497.75,891.087 1497.75,891.101 1497.75,891.114 1497.75,891.128 1497.75,891.142 1497.75,891.156 1497.75,891.17 1497.75,891.184 1497.75,891.198 1497.75,891.212 1497.75,891.226 1497.75,891.24 1497.75,891.254 1497.75,891.268 1497.75,891.282 1497.75,891.296 1497.75,891.31 1497.75,891.324 1497.75,891.338 1497.75,891.352 1497.75,891.366 1497.75,891.38 1497.75,891.394 1497.75,891.408 1497.75,891.422 1497.75,891.436 1497.75,891.45 1497.75,891.464 1497.75,891.478 1497.75,891.492 1497.75,891.506 1497.75,891.52 1497.75,891.534 1497.75,891.549 1497.75,891.563 1497.75,891.577 1497.75,891.591 1497.75,891.605 1497.75,891.619 1497.75,891.633 1497.75,891.648 1497.75,891.662 1497.75,891.676 1497.75,891.69 1497.75,891.704 1497.75,891.719 1497.75,891.733 1497.75,891.747 1497.75,891.761 1497.75,891.776 1497.75,891.79 1497.75,891.804 1497.75,891.818 1497.75,891.833 1497.75,891.847 1497.75,891.861 1497.75,891.876 1497.75,891.89 1497.75,891.904 1497.75,891.919 1497.75,891.933 1497.75,891.947 1497.75,891.962 1497.75,891.976 1497.75,891.991 1497.75,892.005 1497.75,892.019 1497.75,892.034 1497.75,892.048 1497.75,892.063 1497.75,892.077 1497.75,892.091 1497.75,892.106 1497.75,892.12 1497.75,892.135 1497.75,892.149 1497.75,892.164 1497.75,892.178 1497.75,892.193 1497.75,892.207 1497.75,892.222 1497.75,892.236 1497.75,892.251 1497.75,892.265 1497.75,892.28 1497.75,892.294 1497.75,892.309 1497.75,892.324 1497.75,892.338 1497.75,892.353 1497.75,892.367 1497.75,892.382 1497.75,892.397 1497.75,892.411 1497.75,892.426 1497.75,892.44 1497.75,892.455 1497.75,892.47 1497.75,892.484 1497.75,892.499 1497.75,892.514 1497.75,892.528 1497.75,892.543 1497.75,892.558 1497.75,892.573 1497.75,892.587 1497.75,892.602 1497.75,892.617 1497.75,892.631 1497.75,892.646 1497.75,892.661 1497.75,892.676 1497.75,892.691 1497.75,892.705 1497.75,892.72 1497.75,892.735 1497.75,892.75 1497.75,892.765 1497.75,892.779 1497.75,892.794 1497.75,892.809 1497.75,892.824 1497.75,892.839 1497.75,892.854 1497.75,892.869 1497.75,892.883 1497.75,892.898 1497.75,892.913 1497.75,892.928 1497.75,892.943 1497.75,892.958 1497.75,892.973 1497.75,892.988 1497.75,893.003 1497.75,893.018 1497.75,893.033 1497.75,893.048 1497.75,893.063 1497.75,893.078 1497.75,893.093 1497.75,893.108 1497.75,893.123 1497.75,893.138 1497.75,893.153 1497.75,893.168 1497.75,893.183 1497.75,893.198 1497.75,893.213 1497.75,893.228 1497.75,893.243 1497.75,893.258 1497.75,893.273 1497.75,893.289 1497.75,893.304 1497.75,893.319 1497.75,893.334 1497.75,893.349 1497.75,893.364 1497.75,893.379 1497.75,893.395 1497.75,893.41 1497.75,893.425 1497.75,893.44 1497.75,893.455 1497.75,893.471 1497.75,893.486 1497.75,893.501 1497.75,893.516 1497.75,893.532 1497.75,893.547 1497.75,893.562 1497.75,893.577 1497.75,893.593 1497.75,893.608 1497.75,893.623 1497.75,893.639 1497.75,893.654 1497.75,893.669 1497.75,893.685 1497.75,893.7 1497.75,893.715 1497.75,893.731 1497.75,893.746 1497.75,893.761 1497.75,893.777 1497.75,893.792 1497.75,893.808 1497.75,893.823 1497.75,893.838 1497.75,893.854 1497.75,893.869 1497.75,893.885 1497.75,893.9 1497.75,893.916 1497.75,893.931 1497.75,893.947 1497.75,893.962 1497.75,893.978 1497.75,893.993 1497.75,894.009 1497.75,894.024 1497.75,894.04 1497.75,894.055 1497.75,894.071 1497.75,894.086 1497.75,894.102 1497.75,894.117 1497.75,894.133 1497.75,894.149 1497.75,894.164 1497.75,894.18 1497.75,894.195 1497.75,894.211 1497.75,894.227 1497.75,894.242 1497.75,894.258 1497.75,894.274 1497.75,894.289 1497.75,894.305 1497.75,894.321 1497.75,894.336 1497.75,894.352 1497.75,894.368 1497.75,894.384 1497.75,894.399 1497.75,894.415 1497.75,894.431 1497.75,894.447 1497.75,894.462 1497.75,894.478 1497.75,894.494 1497.75,894.51 1497.75,894.525 1497.75,894.541 1497.75,894.557 1497.75,894.573 1497.75,894.589 1497.75,894.605 1497.75,894.62 1497.75,894.636 1497.75,894.652 1497.75,894.668 1497.75,894.684 1497.75,894.7 1497.75,894.716 1497.75,894.732 1497.75,894.748 1497.75,894.764 1497.75,894.779 1497.75,894.795 1497.75,894.811 1497.75,894.827 1497.75,894.843 1497.75,894.859 1497.75,894.875 1497.75,894.891 1497.75,894.907 1497.75,894.923 1497.75,894.939 1497.75,894.955 1497.75,894.971 1497.75,894.987 1497.75,895.004 1497.75,895.02 1497.75,895.036 1497.75,895.052 1497.75,895.068 1497.75,895.084 1497.75,895.1 1497.75,895.116 1497.75,895.132 1497.75,895.148 1497.75,895.165 1497.75,895.181 1497.75,895.197 1497.75,895.213 1497.75,895.229 1497.75,895.245 1497.75,895.262 1497.75,895.278 1497.75,895.294 1497.75,895.31 1497.75,895.327 1497.75,895.343 1497.75,895.359 1497.75,895.375 1497.75,895.392 1497.75,895.408 1497.75,895.424 1497.75,895.44 1497.75,895.457 1497.75,895.473 1497.75,895.489 1497.75,895.506 1497.75,895.522 1497.75,895.538 1497.75,895.555 1497.75,895.571 1497.75,895.588 1497.75,895.604 1497.75,895.62 1497.75,895.637 1497.75,895.653 1497.75,895.67 1497.75,895.686 1497.75,895.702 1497.75,895.719 1497.75,895.735 1497.75,895.752 1497.75,895.768 1497.75,895.785 1497.75,895.801 1497.75,895.818 1497.75,895.834 1497.75,895.851 1497.75,895.867 1497.75,895.884 1497.75,895.9 1497.75,895.917 1497.75,895.933 1497.75,895.95 1497.75,895.967 1497.75,895.983 1497.75,896 1497.75,896.016 1497.75,896.033 1497.75,896.05 1497.75,896.066 1497.75,896.083 1497.75,896.1 1497.75,896.116 1497.75,896.133 1497.75,896.15 1497.75,896.166 1497.75,896.183 1497.75,896.2 1497.75,896.216 1497.75,896.233 1497.75,896.25 1497.75,896.267 1497.75,896.283 1497.75,896.3 1497.75,896.317 1497.75,896.334 1497.75,896.35 1497.75,896.367 1497.75,896.384 1497.75,896.401 1497.75,896.418 1497.75,896.434 1497.75,896.451 1497.75,896.468 1497.75,896.485 1497.75,896.502 1497.75,896.519 1497.75,896.536 1497.75,896.552 1497.75,896.569 1497.75,896.586 1497.75,896.603 1497.75,896.62 1497.75,896.637 1497.75,896.654 1497.75,896.671 1497.75,896.688 1497.75,896.705 1497.75,896.722 1497.75,896.739 1497.75,896.756 1497.75,896.773 1497.75,896.79 1497.75,896.807 1497.75,896.824 1497.75,896.841 1497.75,896.858 1497.75,896.875 1497.75,896.892 1497.75,896.909 1497.75,896.926 1497.75,896.943 1497.75,896.96 1497.75,896.978 1497.75,896.995 1497.75,897.012 1497.75,897.029 1497.75,897.046 1497.75,897.063 1497.75,897.08 1497.75,897.098 1497.75,897.115 1497.75,897.132 1497.75,897.149 1497.75,897.166 1497.75,897.184 1497.75,897.201 1497.75,897.218 1497.75,897.235 1497.75,897.253 1497.75,897.27 1497.75,897.287 1497.75,897.304 1497.75,897.322 1497.75,897.339 1497.75,897.356 1497.75,897.374 1497.75,897.391 1497.75,897.408 1497.75,897.426 1497.75,897.443 1497.75,897.46 1497.75,897.478 1497.75,897.495 1497.75,897.513 1497.75,897.53 1497.75,897.547 1497.75,897.565 1497.75,897.582 1497.75,897.6 1497.75,897.617 1497.75,897.635 1497.75,897.652 1497.75,897.67 1497.75,897.687 1497.75,897.705 1497.75,897.722 1497.75,897.74 1497.75,897.757 1497.75,897.775 1497.75,897.792 1497.75,897.81 1497.75,897.827 1497.75,897.845 1497.75,897.862 1497.75,897.88 1497.75,897.898 1497.75,897.915 1497.75,897.933 1497.75,897.95 1497.75,897.968 1497.75,897.986 1497.75,898.003 1497.75,898.021 1497.75,898.039 1497.75,898.056 1497.75,898.074 1497.75,898.092 1497.75,898.109 1497.75,898.127 1497.75,898.145 1497.75,898.163 1497.75,898.18 1497.75,898.198 1497.75,898.216 1497.75,898.234 1497.75,898.251 1497.75,898.269 1497.75,898.287 1497.75,898.305 1497.75,898.323 1497.75,898.34 1497.75,898.358 1497.75,898.376 1497.75,898.394 1497.75,898.412 1497.75,898.43 1497.75,898.447 1497.75,898.465 1497.75,898.483 1497.75,898.501 1497.75,898.519 1497.75,898.537 1497.75,898.555 1497.75,898.573 1497.75,898.591 1497.75,898.609 1497.75,898.627 1497.75,898.645 1497.75,898.663 1497.75,898.681 1497.75,898.699 1497.75,898.717 1497.75,898.735 1497.75,898.753 1497.75,898.771 1497.75,898.789 1497.75,898.807 1497.75,898.825 1497.75,898.843 1497.75,898.861 1497.75,898.879 1497.75,898.897 1497.75,898.916 1497.75,898.934 1497.75,898.952 1497.75,898.97 1497.75,898.988 1497.75,899.006 1497.75,899.024 1497.75,899.043 1497.75,899.061 1497.75,899.079 1497.75,899.097 1497.75,899.115 1497.75,899.134 1497.75,899.152 1497.75,899.17 1497.75,899.188 1497.75,899.207 1497.75,899.225 1497.75,899.243 1497.75,899.261 1497.75,899.28 1497.75,899.298 1497.75,899.316 1497.75,899.335 1497.75,899.353 1497.75,899.371 1497.75,899.39 1497.75,899.408 1497.75,899.427 1497.75,899.445 1497.75,899.463 1497.75,899.482 1497.75,899.5 1497.75,899.519 1497.75,899.537 1497.75,899.555 1497.75,899.574 1497.75,899.592 1497.75,899.611 1497.75,899.629 1497.75,899.648 1497.75,899.666 1497.75,899.685 1497.75,899.703 1497.75,899.722 1497.75,899.74 1497.75,899.759 1497.75,899.777 1497.75,899.796 1497.75,899.815 1497.75,899.833 1497.75,899.852 1497.75,899.87 1497.75,899.889 1497.75,899.908 1497.75,899.926 1497.75,899.945 1497.75,899.963 1497.75,899.982 1497.75,900.001 1497.75,900.019 1497.75,900.038 1497.75,900.057 1497.75,900.076 1497.75,900.094 1497.75,900.113 1497.75,900.132 1497.75,900.15 1497.75,900.169 1497.75,900.188 1497.75,900.207 1497.75,900.225 1497.75,900.244 1497.75,900.263 1497.75,900.282 1497.75,900.301 1497.75,900.32 1497.75,900.338 1497.75,900.357 1497.75,900.376 1497.75,900.395 1497.75,900.414 1497.75,900.433 1497.75,900.452 1497.75,900.47 1497.75,900.489 1497.75,900.508 1497.75,900.527 1497.75,900.546 1497.75,900.565 1497.75,900.584 1497.75,900.603 1497.75,900.622 1497.75,900.641 1497.75,900.66 1497.75,900.679 1497.75,900.698 1497.75,900.717 1497.75,900.736 1497.75,900.755 1497.75,900.774 1497.75,900.793 1497.75,900.812 1497.75,900.831 1497.75,900.85 1497.75,900.87 1497.75,900.889 1497.75,900.908 1497.75,900.927 1497.75,900.946 1497.75,900.965 1497.75,900.984 1497.75,901.003 1497.75,901.023 1497.75,901.042 1497.75,901.061 1497.75,901.08 1497.75,901.099 1497.75,901.119 1497.75,901.138 1497.75,901.157 1497.75,901.176 1497.75,901.196 1497.75,901.215 1497.75,901.234 1497.75,901.253 1497.75,901.273 1497.75,901.292 1497.75,901.311 1497.75,901.331 1497.75,901.35 1497.75,901.369 1497.75,901.389 1497.75,901.408 1497.75,901.428 1497.75,901.447 1497.75,901.466 1497.75,901.486 1497.75,901.505 1497.75,901.525 1497.75,901.544 1497.75,901.563 1497.75,901.583 1497.75,901.602 1497.75,901.622 1497.75,901.641 1497.75,901.661 1497.75,901.68 1497.75,901.7 1497.75,901.719 1497.75,901.739 1497.75,901.758 1497.75,901.778 1497.75,901.797 1497.75,901.817 1497.75,901.837 1497.75,901.856 1497.75,901.876 1497.75,901.895 1497.75,901.915 1497.75,901.935 1497.75,901.954 1497.75,901.974 1497.75,901.994 1497.75,902.013 1497.75,902.033 1497.75,902.053 1497.75,902.072 1497.75,902.092 1497.75,902.112 1497.75,902.131 1497.75,902.151 1497.75,902.171 1497.75,902.191 1497.75,902.21 1497.75,902.23 1497.75,902.25 1497.75,902.27 1497.75,902.289 1497.75,902.309 1497.75,902.329 1497.75,902.349 1497.75,902.369 1497.75,902.389 1497.75,902.408 1497.75,902.428 1497.75,902.448 1497.75,902.468 1497.75,902.488 1497.75,902.508 1497.75,902.528 1497.75,902.548 1497.75,902.568 1497.75,902.588 1497.75,902.607 1497.75,902.627 1497.75,902.647 1497.75,902.667 1497.75,902.687 1497.75,902.707 1497.75,902.727 1497.75,902.747 1497.75,902.767 1497.75,902.787 1497.75,902.808 1497.75,902.828 1497.75,902.848 1497.75,902.868 1497.75,902.888 1497.75,902.908 1497.75,902.928 1497.75,902.948 1497.75,902.968 1497.75,902.988 1497.75,903.008 1497.75,903.029 1497.75,903.049 1497.75,903.069 1497.75,903.089 1497.75,903.109 1497.75,903.13 1497.75,903.15 1497.75,903.17 1497.75,903.19 1497.75,903.21 1497.75,903.231 1497.75,903.251 1497.75,903.271 1497.75,903.292 1497.75,903.312 1497.75,903.332 1497.75,903.352 1497.75,903.373 1497.75,903.393 1497.75,903.413 1497.75,903.434 1497.75,903.454 1497.75,903.474 1497.75,903.495 1497.75,903.515 1497.75,903.536 1497.75,903.556 1497.75,903.576 1497.75,903.597 1497.75,903.617 1497.75,903.638 1497.75,903.658 1497.75,903.679 1497.75,903.699 1497.75,903.72 1497.75,903.74 1497.75,903.761 1497.75,903.781 1497.75,903.802 1497.75,903.822 1497.75,903.843 1497.75,903.863 1497.75,903.884 1497.75,903.904 1497.75,903.925 1497.75,903.946 1497.75,903.966 1497.75,903.987 1497.75,904.007 1497.75,904.028 1497.75,904.049 1497.75,904.069 1497.75,904.09 1497.75,904.111 1497.75,904.131 1497.75,904.152 1497.75,904.173 1497.75,904.194 1497.75,904.214 1497.75,904.235 1497.75,904.256 1497.75,904.276 1497.75,904.297 1497.75,904.318 1497.75,904.339 1497.75,904.36 1497.75,904.38 1497.75,904.401 1497.75,904.422 1497.75,904.443 1497.75,904.464 1497.75,904.484 1497.75,904.505 1497.75,904.526 1497.75,904.547 1497.75,904.568 1497.75,904.589 1497.75,904.61 1497.75,904.631 1497.75,904.652 1497.75,904.673 1497.75,904.694 1497.75,904.714 1497.75,904.735 1497.75,904.756 1497.75,904.777 1497.75,904.798 1497.75,904.819 1497.75,904.84 1497.75,904.861 1497.75,904.882 1497.75,904.904 1497.75,904.925 1497.75,904.946 1497.75,904.967 1497.75,904.988 1497.75,905.009 1497.75,905.03 1497.75,905.051 1497.75,905.072 1497.75,905.093 1497.75,905.115 1497.75,905.136 1497.75,905.157 1497.75,905.178 1497.75,905.199 1497.75,905.22 1497.75,905.242 1497.75,905.263 1497.75,905.284 1497.75,905.305 1497.75,905.327 1497.75,905.348 1497.75,905.369 1497.75,905.39 1497.75,905.412 1497.75,905.433 1497.75,905.454 1497.75,905.476 1497.75,905.497 1497.75,905.518 1497.75,905.54 1497.75,905.561 1497.75,905.582 1497.75,905.604 1497.75,905.625 1497.75,905.646 1497.75,905.668 1497.75,905.689 1497.75,905.711 1497.75,905.732 1497.75,905.754 1497.75,905.775 1497.75,905.796 1497.75,905.818 1497.75,905.839 1497.75,905.861 1497.75,905.882 1497.75,905.904 1497.75,905.925 1497.75,905.947 1497.75,905.968 1497.75,905.99 1497.75,906.012 1497.75,906.033 1497.75,906.055 1497.75,906.076 1497.75,906.098 1497.75,906.12 1497.75,906.141 1497.75,906.163 1497.75,906.184 1497.75,906.206 1497.75,906.228 1497.75,906.249 1497.75,906.271 1497.75,906.293 1497.75,906.315 1497.75,906.336 1497.75,906.358 1497.75,906.38 1497.75,906.401 1497.75,906.423 1497.75,906.445 1497.75,906.467 1497.75,906.489 1497.75,906.51 1497.75,906.532 1497.75,906.554 1497.75,906.576 1497.75,906.598 1497.75,906.619 1497.75,906.641 1497.75,906.663 1497.75,906.685 1497.75,906.707 1497.75,906.729 1497.75,906.751 1497.75,906.773 1497.75,906.795 1497.75,906.817 1497.75,906.838 1497.75,906.86 1497.75,906.882 1497.75,906.904 1497.75,906.926 1497.75,906.948 1497.75,906.97 1497.75,906.992 1497.75,907.014 1497.75,907.036 1497.75,907.058 1497.75,907.081 1497.75,907.103 1497.75,907.125 1497.75,907.147 1497.75,907.169 1497.75,907.191 1497.75,907.213 1497.75,907.235 1497.75,907.257 1497.75,907.28 1497.75,907.302 1497.75,907.324 1497.75,907.346 1497.75,907.368 1497.75,907.39 1497.75,907.413 1497.75,907.435 1497.75,907.457 1497.75,907.479 1497.75,907.502 1497.75,907.524 1497.75,907.546 1497.75,907.568 1497.75,907.591 1497.75,907.613 1497.75,907.635 1497.75,907.658 1497.75,907.68 1497.75,907.702 1497.75,907.725 1497.75,907.747 1497.75,907.769 1497.75,907.792 1497.75,907.814 1497.75,907.837 1497.75,907.859 1497.75,907.881 1497.75,907.904 1497.75,907.926 1497.75,907.949 1497.75,907.971 1497.75,907.994 1497.75,908.016 1497.75,908.039 1497.75,908.061 1497.75,908.084 1497.75,908.106 1497.75,908.129 1497.75,908.151 1497.75,908.174 1497.75,908.196 1497.75,908.219 1497.75,908.242 1497.75,908.264 1497.75,908.287 1497.75,908.309 1497.75,908.332 1497.75,908.355 1497.75,908.377 1497.75,908.4 1497.75,908.423 1497.75,908.445 1497.75,908.468 1497.75,908.491 1497.75,908.513 1497.75,908.536 1497.75,908.559 1497.75,908.582 1497.75,908.604 1497.75,908.627 1497.75,908.65 1497.75,908.673 1497.75,908.695 1497.75,908.718 1497.75,908.741 1497.75,908.764 1497.75,908.787 1497.75,908.809 1497.75,908.832 1497.75,908.855 1497.75,908.878 1497.75,908.901 1497.75,908.924 1497.75,908.947 1497.75,908.97 1497.75,908.993 1497.75,909.016 1497.75,909.038 1497.75,909.061 1497.75,909.084 1497.75,909.107 1497.75,909.13 1497.75,909.153 1497.75,909.176 1497.75,909.199 1497.75,909.222 1497.75,909.245 1497.75,909.268 1497.75,909.292 1497.75,909.315 1497.75,909.338 1497.75,909.361 1497.75,909.384 1497.75,909.407 1497.75,909.43 1497.75,909.453 1497.75,909.476 1497.75,909.5 1497.75,909.523 1497.75,909.546 1497.75,909.569 1497.75,909.592 1497.75,909.615 1497.75,909.639 1497.75,909.662 1497.75,909.685 1497.75,909.708 1497.75,909.732 1497.75,909.755 1497.75,909.778 1497.75,909.801 1497.75,909.825 1497.75,909.848 1497.75,909.871 1497.75,909.895 1497.75,909.918 1497.75,909.941 1497.75,909.965 1497.75,909.988 1497.75,910.011 1497.75,910.035 1497.75,910.058 1497.75,910.082 1497.75,910.105 1497.75,910.129 1497.75,910.152 1497.75,910.175 1497.75,910.199 1497.75,910.222 1497.75,910.246 1497.75,910.269 1497.75,910.293 1497.75,910.316 1497.75,910.34 1497.75,910.363 1497.75,910.387 1497.75,910.411 1497.75,910.434 1497.75,910.458 1497.75,910.481 1497.75,910.505 1497.75,910.528 1497.75,910.552 1497.75,910.576 1497.75,910.599 1497.75,910.623 1497.75,910.647 1497.75,910.67 1497.75,910.694 1497.75,910.718 1497.75,910.741 1497.75,910.765 1497.75,910.789 1497.75,910.813 1497.75,910.836 1497.75,910.86 1497.75,910.884 1497.75,910.908 1497.75,910.931 1497.75,910.955 1497.75,910.979 1497.75,911.003 1497.75,911.027 1497.75,911.05 1497.75,911.074 1497.75,911.098 1497.75,911.122 1497.75,911.146 1497.75,911.17 1497.75,911.194 1497.75,911.218 1497.75,911.242 1497.75,911.265 1497.75,911.289 1497.75,911.313 1497.75,911.337 1497.75,911.361 1497.75,911.385 1497.75,911.409 1497.75,911.433 1497.75,911.457 1497.75,911.481 1497.75,911.505 1497.75,911.529 1497.75,911.553 1497.75,911.578 1497.75,911.602 1497.75,911.626 1497.75,911.65 1497.75,911.674 1497.75,911.698 1497.75,911.722 1497.75,911.746 1497.75,911.77 1497.75,911.795 1497.75,911.819 1497.75,911.843 1497.75,911.867 1497.75,911.891 1497.75,911.916 1497.75,911.94 1497.75,911.964 1497.75,911.988 1497.75,912.013 1497.75,912.037 1497.75,912.061 1497.75,912.085 1497.75,912.11 1497.75,912.134 1497.75,912.158 1497.75,912.183 1497.75,912.207 1497.75,912.231 1497.75,912.256 1497.75,912.28 1497.75,912.304 1497.75,912.329 1497.75,912.353 1497.75,912.378 1497.75,912.402 1497.75,912.427 1497.75,912.451 1497.75,912.475 1497.75,912.5 1497.75,912.524 1497.75,912.549 1497.75,912.573 1497.75,912.598 1497.75,912.622 1497.75,912.647 1497.75,912.671 1497.75,912.696 1497.75,912.721 1497.75,912.745 1497.75,912.77 1497.75,912.794 1497.75,912.819 1497.75,912.844 1497.75,912.868 1497.75,912.893 1497.75,912.918 1497.75,912.942 1497.75,912.967 1497.75,912.992 1497.75,913.016 1497.75,913.041 1497.75,913.066 1497.75,913.09 1497.75,913.115 1497.75,913.14 1497.75,913.165 1497.75,913.189 1497.75,913.214 1497.75,913.239 1497.75,913.264 1497.75,913.289 1497.75,913.313 1497.75,913.338 1497.75,913.363 1497.75,913.388 1497.75,913.413 1497.75,913.438 1497.75,913.462 1497.75,913.487 1497.75,913.512 1497.75,913.537 1497.75,913.562 1497.75,913.587 1497.75,913.612 1497.75,913.637 1497.75,913.662 1497.75,913.687 1497.75,913.712 1497.75,913.737 1497.75,913.762 1497.75,913.787 1497.75,913.812 1497.75,913.837 1497.75,913.862 1497.75,913.887 1497.75,913.912 1497.75,913.937 1497.75,913.962 1497.75,913.987 1497.75,914.013 1497.75,914.038 1497.75,914.063 1497.75,914.088 1497.75,914.113 1497.75,914.138 1497.75,914.163 1497.75,914.189 1497.75,914.214 1497.75,914.239 1497.75,914.264 1497.75,914.29 1497.75,914.315 1497.75,914.34 1497.75,914.365 1497.75,914.391 1497.75,914.416 1497.75,914.441 1497.75,914.467 1497.75,914.492 1497.75,914.517 1497.75,914.542 1497.75,914.568 1497.75,914.593 1497.75,914.619 1497.75,914.644 1497.75,914.669 1497.75,914.695 1497.75,914.72 1497.75,914.746 1497.75,914.771 1497.75,914.797 1497.75,914.822 1497.75,914.847 1497.75,914.873 1497.75,914.898 1497.75,914.924 1497.75,914.949 1497.75,914.975 1497.75,915 1497.75,915.026 1497.75,915.052 1497.75,915.077 1497.75,915.103 1497.75,915.128 1497.75,915.154 1497.75,915.18 1497.75,915.205 1497.75,915.231 1497.75,915.256 1497.75,915.282 1497.75,915.308 1497.75,915.333 1497.75,915.359 1497.75,915.385 1497.75,915.411 1497.75,915.436 1497.75,915.462 1497.75,915.488 1497.75,915.513 1497.75,915.539 1497.75,915.565 1497.75,915.591 1497.75,915.617 1497.75,915.642 1497.75,915.668 1497.75,915.694 1497.75,915.72 1497.75,915.746 1497.75,915.772 1497.75,915.797 1497.75,915.823 1497.75,915.849 1497.75,915.875 1497.75,915.901 1497.75,915.927 1497.75,915.953 1497.75,915.979 1497.75,916.005 1497.75,916.031 1497.75,916.057 1497.75,916.083 1497.75,916.109 1497.75,916.135 1497.75,916.161 1497.75,916.187 1497.75,916.213 1497.75,916.239 1497.75,916.265 1497.75,916.291 1497.75,916.317 1497.75,916.343 1497.75,916.369 1497.75,916.395 1497.75,916.422 1497.75,916.448 1497.75,916.474 1497.75,916.5 1497.75,916.526 1497.75,916.552 1497.75,916.579 1497.75,916.605 1497.75,916.631 1497.75,916.657 1497.75,916.683 1497.75,916.71 1497.75,916.736 1497.75,916.762 1497.75,916.788 1497.75,916.815 1497.75,916.841 1497.75,916.867 1497.75,916.894 1497.75,916.92 1497.75,916.946 1497.75,916.973 1497.75,916.999 1497.75,917.026 1497.75,917.052 1497.75,917.078 1497.75,917.105 1497.75,917.131 1497.75,917.158 1497.75,917.184 1497.75,917.21 1497.75,917.237 1497.75,917.263 1497.75,917.29 1497.75,917.316 1497.75,917.343 1497.75,917.369 1497.75,917.396 1497.75,917.423 1497.75,917.449 1497.75,917.476 1497.75,917.502 1497.75,917.529 1497.75,917.555 1497.75,917.582 1497.75,917.609 1497.75,917.635 1497.75,917.662 1497.75,917.689 1497.75,917.715 1497.75,917.742 1497.75,917.769 1497.75,917.795 1497.75,917.822 1497.75,917.849 1497.75,917.875 1497.75,917.902 1497.75,917.929 1497.75,917.956 1497.75,917.982 1497.75,918.009 1497.75,918.036 1497.75,918.063 1497.75,918.09 1497.75,918.116 1497.75,918.143 1497.75,918.17 1497.75,918.197 1497.75,918.224 1497.75,918.251 1497.75,918.278 1497.75,918.305 1497.75,918.331 1497.75,918.358 1497.75,918.385 1497.75,918.412 1497.75,918.439 1497.75,918.466 1497.75,918.493 1497.75,918.52 1497.75,918.547 1497.75,918.574 1497.75,918.601 1497.75,918.628 1497.75,918.655 1497.75,918.682 1497.75,918.709 1497.75,918.737 1497.75,918.764 1497.75,918.791 1497.75,918.818 1497.75,918.845 1497.75,918.872 1497.75,918.899 1497.75,918.926 1497.75,918.954 1497.75,918.981 1497.75,919.008 1497.75,919.035 1497.75,919.062 1497.75,919.09 1497.75,919.117 1497.75,919.144 1497.75,919.171 1497.75,919.199 1497.75,919.226 1497.75,919.253 1497.75,919.28 1497.75,919.308 1497.75,919.335 1497.75,919.362 1497.75,919.39 1497.75,919.417 1497.75,919.444 1497.75,919.472 1497.75,919.499 1497.75,919.527 1497.75,919.554 1497.75,919.581 1497.75,919.609 1497.75,919.636 1497.75,919.664 1497.75,919.691 1497.75,919.719 1497.75,919.746 1497.75,919.774 1497.75,919.801 1497.75,919.829 1497.75,919.856 1497.75,919.884 1497.75,919.911 1497.75,919.939 1497.75,919.967 1497.75,919.994 1497.75,920.022 1497.75,920.049 1497.75,920.077 1497.75,920.105 1497.75,920.132 1497.75,920.16 1497.75,920.188 1497.75,920.215 1497.75,920.243 1497.75,920.271 1497.75,920.298 1497.75,920.326 1497.75,920.354 1497.75,920.382 1497.75,920.409 1497.75,920.437 1497.75,920.465 1497.75,920.493 1497.75,920.52 1497.75,920.548 1497.75,920.576 1497.75,920.604 1497.75,920.632 1497.75,920.66 1497.75,920.687 1497.75,920.715 1497.75,920.743 1497.75,920.771 1497.75,920.799 1497.75,920.827 1497.75,920.855 1497.75,920.883 1497.75,920.911 1497.75,920.939 1497.75,920.967 1497.75,920.995 1497.75,921.023 1497.75,921.051 1497.75,921.079 1497.75,921.107 1497.75,921.135 1497.75,921.163 1497.75,921.191 1497.75,921.219 1497.75,921.247 1497.75,921.275 1497.75,921.303 1497.75,921.331 1497.75,921.36 1497.75,921.388 1497.75,921.416 1497.75,921.444 1497.75,921.472 1497.75,921.5 1497.75,921.529 1497.75,921.557 1497.75,921.585 1497.75,921.613 1497.75,921.641 1497.75,921.67 1497.75,921.698 1497.75,921.726 1497.75,921.755 1497.75,921.783 1497.75,921.811 1497.75,921.839 1497.75,921.868 1497.75,921.896 1497.75,921.924 1497.75,921.953 1497.75,921.981 1497.75,922.01 1497.75,922.038 1497.75,922.066 1497.75,922.095 1497.75,922.123 1497.75,922.152 1497.75,922.18 1497.75,922.209 1497.75,922.237 1497.75,922.266 1497.75,922.294 1497.75,922.323 1497.75,922.351 1497.75,922.38 1497.75,922.408 1497.75,922.437 1497.75,922.465 1497.75,922.494 1497.75,922.523 1497.75,922.551 1497.75,922.58 1497.75,922.608 1497.75,922.637 1497.75,922.666 1497.75,922.694 1497.75,922.723 1497.75,922.752 1497.75,922.78 1497.75,922.809 1497.75,922.838 1497.75,922.866 1497.75,922.895 1497.75,922.924 1497.75,922.953 1497.75,922.981 1497.75,923.01 1497.75,923.039 1497.75,923.068 1497.75,923.097 1497.75,923.126 1497.75,923.154 1497.75,923.183 1497.75,923.212 1497.75,923.241 1497.75,923.27 1497.75,923.299 1497.75,923.328 1497.75,923.357 1497.75,923.385 1497.75,923.414 1497.75,923.443 1497.75,923.472 1497.75,923.501 1497.75,923.53 1497.75,923.559 1497.75,923.588 1497.75,923.617 1497.75,923.646 1497.75,923.675 1497.75,923.704 1497.75,923.733 1497.75,923.763 1497.75,923.792 1497.75,923.821 1497.75,923.85 1497.75,923.879 1497.75,923.908 1497.75,923.937 1497.75,923.966 1497.75,923.996 1497.75,924.025 1497.75,924.054 1497.75,924.083 1497.75,924.112 1497.75,924.141 1497.75,924.171 1497.75,924.2 1497.75,924.229 1497.75,924.258 1497.75,924.288 1497.75,924.317 1497.75,924.346 1497.75,924.376 1497.75,924.405 1497.75,924.434 1497.75,924.464 1497.75,924.493 1497.75,924.522 1497.75,924.552 1497.75,924.581 1497.75,924.611 1497.75,924.64 1497.75,924.669 1497.75,924.699 1497.75,924.728 1497.75,924.758 1497.75,924.787 1497.75,924.817 1497.75,924.846 1497.75,924.876 1497.75,924.905 1497.75,924.935 1497.75,924.964 1497.75,924.994 1497.75,925.023 1497.75,925.053 1497.75,925.082 1497.75,925.112 1497.75,925.142 1497.75,925.171 1497.75,925.201 1497.75,925.231 1497.75,925.26 1497.75,925.29 1497.75,925.32 1497.75,925.349 1497.75,925.379 1497.75,925.409 1497.75,925.438 1497.75,925.468 1497.75,925.498 1497.75,925.528 1497.75,925.557 1497.75,925.587 1497.75,925.617 1497.75,925.647 1497.75,925.676 1497.75,925.706 1497.75,925.736 1497.75,925.766 1497.75,925.796 1497.75,925.826 1497.75,925.856 1497.75,925.885 1497.75,925.915 1497.75,925.945 1497.75,925.975 1497.75,926.005 1497.75,926.035 1497.75,926.065 1497.75,926.095 1497.75,926.125 1497.75,926.155 1497.75,926.185 1497.75,926.215 1497.75,926.245 1497.75,926.275 1497.75,926.305 1497.75,926.335 1497.75,926.365 1497.75,926.395 1497.75,926.425 1497.75,926.455 1497.75,926.486 1497.75,926.516 1497.75,926.546 1497.75,926.576 1497.75,926.606 1497.75,926.636 1497.75,926.667 1497.75,926.697 1497.75,926.727 1497.75,926.757 1497.75,926.787 1497.75,926.818 1497.75,926.848 1497.75,926.878 1497.75,926.908 1497.75,926.939 1497.75,926.969 1497.75,926.999 1497.75,927.03 1497.75,927.06 1497.75,927.09 1497.75,927.121 1497.75,927.151 1497.75,927.181 1497.75,927.212 1497.75,927.242 1497.75,927.273 1497.75,927.303 1497.75,927.333 1497.75,927.364 1497.75,927.394 1497.75,927.425 1497.75,927.455 1497.75,927.486 1497.75,927.516 1497.75,927.547 1497.75,927.577 1497.75,927.608 1497.75,927.638 1497.75,927.669 1497.75,927.7 1497.75,927.73 1497.75,927.761 1497.75,927.791 1497.75,927.822 1497.75,927.853 1497.75,927.883 1497.75,927.914 1497.75,927.945 1497.75,927.975 1497.75,928.006 1497.75,928.037 1497.75,928.067 1497.75,928.098 1497.75,928.129 1497.75,928.16 1497.75,928.19 1497.75,928.221 1497.75,928.252 1497.75,928.283 1497.75,928.313 1497.75,928.344 1497.75,928.375 1497.75,928.406 1497.75,928.437 1497.75,928.468 1497.75,928.498 1497.75,928.529 1497.75,928.56 1497.75,928.591 1497.75,928.622 1497.75,928.653 1497.75,928.684 1497.75,928.715 1497.75,928.746 1497.75,928.777 1497.75,928.808 1497.75,928.839 1497.75,928.87 1497.75,928.901 1497.75,928.932 1497.75,928.963 1497.75,928.994 1497.75,929.025 1497.75,929.056 1497.75,929.087 1497.75,929.118 1497.75,929.149 1497.75,929.18 1497.75,929.212 1497.75,929.243 1497.75,929.274 1497.75,929.305 1497.75,929.336 1497.75,929.367 1497.75,929.399 1497.75,929.43 1497.75,929.461 1497.75,929.492 1497.75,929.524 1497.75,929.555 1497.75,929.586 1497.75,929.617 1497.75,929.649 1497.75,929.68 1497.75,929.711 1497.75,929.743 1497.75,929.774 1497.75,929.805 1497.75,929.837 1497.75,929.868 1497.75,929.899 1497.75,929.931 1497.75,929.962 1497.75,929.994 1497.75,930.025 1497.75,930.057 1497.75,930.088 1497.75,930.119 1497.75,930.151 1497.75,930.182 1497.75,930.214 1497.75,930.245 1497.75,930.277 1497.75,930.309 1497.75,930.34 1497.75,930.372 1497.75,930.403 1497.75,930.435 1497.75,930.466 1497.75,930.498 1497.75,930.53 1497.75,930.561 1497.75,930.593 1497.75,930.625 1497.75,930.656 1497.75,930.688 1497.75,930.72 1497.75,930.751 1497.75,930.783 1497.75,930.815 1497.75,930.846 1497.75,930.878 1497.75,930.91 1497.75,930.942 1497.75,930.973 1497.75,931.005 1497.75,931.037 1497.75,931.069 1497.75,931.101 1497.75,931.133 1497.75,931.164 1497.75,931.196 1497.75,931.228 1497.75,931.26 1497.75,931.292 1497.75,931.324 1497.75,931.356 1497.75,931.388 1497.75,931.42 1497.75,931.451 1497.75,931.483 1497.75,931.515 1497.75,931.547 1497.75,931.579 1497.75,931.611 1497.75,931.643 1497.75,931.675 1497.75,931.708 1497.75,931.74 1497.75,931.772 1497.75,931.804 1497.75,931.836 1497.75,931.868 1497.75,931.9 1497.75,931.932 1497.75,931.964 1497.75,931.996 1497.75,932.029 1497.75,932.061 1497.75,932.093 1497.75,932.125 1497.75,932.157 1497.75,932.19 1497.75,932.222 1497.75,932.254 1497.75,932.286 1497.75,932.319 1497.75,932.351 1497.75,932.383 1497.75,932.415 1497.75,932.448 1497.75,932.48 1497.75,932.512 1497.75,932.545 1497.75,932.577 1497.75,932.609 1497.75,932.642 1497.75,932.674 1497.75,932.707 1497.75,932.739 1497.75,932.771 1497.75,932.804 1497.75,932.836 1497.75,932.869 1497.75,932.901 1497.75,932.934 1497.75,932.966 1497.75,932.999 1497.75,933.031 1497.75,933.064 1497.75,933.096 1497.75,933.129 1497.75,933.162 1497.75,933.194 1497.75,933.227 1497.75,933.259 1497.75,933.292 1497.75,933.325 1497.75,933.357 1497.75,933.39 1497.75,933.422 1497.75,933.455 1497.75,933.488 1497.75,933.521 1497.75,933.553 1497.75,933.586 1497.75,933.619 1497.75,933.651 1497.75,933.684 1497.75,933.717 1497.75,933.75 1497.75,933.782 1497.75,933.815 1497.75,933.848 1497.75,933.881 1497.75,933.914 1497.75,933.947 1497.75,933.979 1497.75,934.012 1497.75,934.045 1497.75,934.078 1497.75,934.111 1497.75,934.144 1497.75,934.177 1497.75,934.21 1497.75,934.243 1497.75,934.276 1497.75,934.309 1497.75,934.342 1497.75,934.375 1497.75,934.408 1497.75,934.441 1497.75,934.474 1497.75,934.507 1497.75,934.54 1497.75,934.573 1497.75,934.606 1497.75,934.639 1497.75,934.672 1497.75,934.705 1497.75,934.738 1497.75,934.771 1497.75,934.805 1497.75,934.838 1497.75,934.871 1497.75,934.904 1497.75,934.937 1497.75,934.971 1497.75,935.004 1497.75,935.037 1497.75,935.07 1497.75,935.103 1497.75,935.137 1497.75,935.17 1497.75,935.203 1497.75,935.237 1497.75,935.27 1497.75,935.303 1497.75,935.337 1497.75,935.37 1497.75,935.403 1497.75,935.437 1497.75,935.47 1497.75,935.503 1497.75,935.537 1497.75,935.57 1497.75,935.604 1497.75,935.637 1497.75,935.671 1497.75,935.704 1497.75,935.738 1497.75,935.771 1497.75,935.804 1497.75,935.838 1497.75,935.872 1497.75,935.905 1497.75,935.939 1497.75,935.972 1497.75,936.006 1497.75,936.039 1497.75,936.073 1497.75,936.107 1497.75,936.14 1497.75,936.174 1497.75,936.207 1497.75,936.241 1497.75,936.275 1497.75,936.308 1497.75,936.342 1497.75,936.376 1497.75,936.409 1497.75,936.443 1497.75,936.477 1497.75,936.511 1497.75,936.544 1497.75,936.578 1497.75,936.612 1497.75,936.646 1497.75,936.68 1497.75,936.713 1497.75,936.747 1497.75,936.781 1497.75,936.815 1497.75,936.849 1497.75,936.883 1497.75,936.916 1497.75,936.95 1497.75,936.984 1497.75,937.018 1497.75,937.052 1497.75,937.086 1497.75,937.12 1497.75,937.154 1497.75,937.188 1497.75,937.222 1497.75,937.256 1497.75,937.29 1497.75,937.324 1497.75,937.358 1497.75,937.392 1497.75,937.426 1497.75,937.46 1497.75,937.494 1497.75,937.528 1497.75,937.562 1497.75,937.597 1497.75,937.631 1497.75,937.665 1497.75,937.699 1497.75,937.733 1497.75,937.767 1497.75,937.802 1497.75,937.836 1497.75,937.87 1497.75,937.904 1497.75,937.938 1497.75,937.973 1497.75,938.007 1497.75,938.041 1497.75,938.075 1497.75,938.11 1497.75,938.144 1497.75,938.178 1497.75,938.213 1497.75,938.247 1497.75,938.281 1497.75,938.316 1497.75,938.35 1497.75,938.385 1497.75,938.419 1497.75,938.453 1497.75,938.488 1497.75,938.522 1497.75,938.557 1497.75,938.591 1497.75,938.626 1497.75,938.66 1497.75,938.695 1497.75,938.729 1497.75,938.764 1497.75,938.798 1497.75,938.833 1497.75,938.867 1497.75,938.902 1497.75,938.936 1497.75,938.971 1497.75,939.006 1497.75,939.04 1497.75,939.075 1497.75,939.109 1497.75,939.144 1497.75,939.179 1497.75,939.213 1497.75,939.248 1497.75,939.283 1497.75,939.317 1497.75,939.352 1497.75,939.387 1497.75,939.422 1497.75,939.456 1497.75,939.491 1497.75,939.526 1497.75,939.561 1497.75,939.596 1497.75,939.63 1497.75,939.665 1497.75,939.7 1497.75,939.735 1497.75,939.77 1497.75,939.805 1497.75,939.839 1497.75,939.874 1497.75,939.909 1497.75,939.944 1497.75,939.979 1497.75,940.014 1497.75,940.049 1497.75,940.084 1497.75,940.119 1497.75,940.154 1497.75,940.189 1497.75,940.224 1497.75,940.259 1497.75,940.294 1497.75,940.329 1497.75,940.364 1497.75,940.399 1497.75,940.434 1497.75,940.469 1497.75,940.504 1497.75,940.54 1497.75,940.575 1497.75,940.61 1497.75,940.645 1497.75,940.68 1497.75,940.715 1497.75,940.75 1497.75,940.786 1497.75,940.821 1497.75,940.856 1497.75,940.891 1497.75,940.927 1497.75,940.962 1497.75,940.997 1497.75,941.032 1497.75,941.068 1497.75,941.103 1497.75,941.138 1497.75,941.174 1497.75,941.209 1497.75,941.244 1497.75,941.28 1497.75,941.315 1497.75,941.35 1497.75,941.386 1497.75,941.421 1497.75,941.457 1497.75,941.492 1497.75,941.528 1497.75,941.563 1497.75,941.598 1497.75,941.634 1497.75,941.669 1497.75,941.705 1497.75,941.74 1497.75,941.776 1497.75,941.812 1497.75,941.847 1497.75,941.883 1497.75,941.918 1497.75,941.954 1497.75,941.989 1497.75,942.025 1497.75,942.061 1497.75,942.096 1497.75,942.132 1497.75,942.168 1497.75,942.203 1497.75,942.239 1497.75,942.275 1497.75,942.31 1497.75,942.346 1497.75,942.382 1497.75,942.417 1497.75,942.453 1497.75,942.489 1497.75,942.525 1497.75,942.561 1497.75,942.596 1497.75,942.632 1497.75,942.668 1497.75,942.704 1497.75,942.74 1497.75,942.776 1497.75,942.811 1497.75,942.847 1497.75,942.883 1497.75,942.919 1497.75,942.955 1497.75,942.991 1497.75,943.027 1497.75,943.063 1497.75,943.099 1497.75,943.135 1497.75,943.171 1497.75,943.207 1497.75,943.243 1497.75,943.279 1497.75,943.315 1497.75,943.351 1497.75,943.387 1497.75,943.423 1497.75,943.459 1497.75,943.495 1497.75,943.531 1497.75,943.567 1497.75,943.604 1497.75,943.64 1497.75,943.676 1497.75,943.712 1497.75,943.748 1497.75,943.784 1497.75,943.821 1497.75,943.857 1497.75,943.893 1497.75,943.929 1497.75,943.965 1497.75,944.002 1497.75,944.038 1497.75,944.074 1497.75,944.111 1497.75,944.147 1497.75,944.183 1497.75,944.22 1497.75,944.256 1497.75,944.292 1497.75,944.329 1497.75,944.365 1497.75,944.401 1497.75,944.438 1497.75,944.474 1497.75,944.511 1497.75,944.547 1497.75,944.583 1497.75,944.62 1497.75,944.656 1497.75,944.693 1497.75,944.729 1497.75,944.766 1497.75,944.802 1497.75,944.839 1497.75,944.875 1497.75,944.912 1497.75,944.949 1497.75,944.985 1497.75,945.022 1497.75,945.058 1497.75,945.095 1497.75,945.132 1497.75,945.168 1497.75,945.205 1497.75,945.242 1497.75,945.278 1497.75,945.315 1497.75,945.352 1497.75,945.388 1497.75,945.425 1497.75,945.462 1497.75,945.499 1497.75,945.535 1497.75,945.572 1497.75,945.609 1497.75,945.646 1497.75,945.682 1497.75,945.719 1497.75,945.756 1497.75,945.793 1497.75,945.83 1497.75,945.867 1497.75,945.903 1497.75,945.94 1497.75,945.977 1497.75,946.014 1497.75,946.051 1497.75,946.088 1497.75,946.125 1497.75,946.162 1497.75,946.199 1497.75,946.236 1497.75,946.273 1497.75,946.31 1497.75,946.347 1497.75,946.384 1497.75,946.421 1497.75,946.458 1497.75,946.495 1497.75,946.532 1497.75,946.569 1497.75,946.606 1497.75,946.643 1497.75,946.681 1497.75,946.718 1497.75,946.755 1497.75,946.792 1497.75,946.829 1497.75,946.866 1497.75,946.903 1497.75,946.941 1497.75,946.978 1497.75,947.015 1497.75,947.052 1497.75,947.09 1497.75,947.127 1497.75,947.164 1497.75,947.201 1497.75,947.239 1497.75,947.276 1497.75,947.313 1497.75,947.351 1497.75,947.388 1497.75,947.425 1497.75,947.463 1497.75,947.5 1497.75,947.538 1497.75,947.575 1497.75,947.612 1497.75,947.65 1497.75,947.687 1497.75,947.725 1497.75,947.762 1497.75,947.8 1497.75,947.837 1497.75,947.875 1497.75,947.912 1497.75,947.95 1497.75,947.987 1497.75,948.025 1497.75,948.062 1497.75,948.1 1497.75,948.137 1497.75,948.175 1497.75,948.213 1497.75,948.25 1497.75,948.288 1497.75,948.326 1497.75,948.363 1497.75,948.401 1497.75,948.439 1497.75,948.476 1497.75,948.514 1497.75,948.552 1497.75,948.589 1497.75,948.627 1497.75,948.665 1497.75,948.703 1497.75,948.74 1497.75,948.778 1497.75,948.816 1497.75,948.854 1497.75,948.892 1497.75,948.929 1497.75,948.967 1497.75,949.005 1497.75,949.043 1497.75,949.081 1497.75,949.119 1497.75,949.157 1497.75,949.195 1497.75,949.232 1497.75,949.27 1497.75,949.308 1497.75,949.346 1497.75,949.384 1497.75,949.422 1497.75,949.46 1497.75,949.498 1497.75,949.536 1497.75,949.574 1497.75,949.612 1497.75,949.65 1497.75,949.688 1497.75,949.727 1497.75,949.765 1497.75,949.803 1497.75,949.841 1497.75,949.879 1497.75,949.917 1497.75,949.955 1497.75,949.993 1497.75,950.032 1497.75,950.07 1497.75,950.108 1497.75,950.146 1497.75,950.184 1497.75,950.223 1497.75,950.261 1497.75,950.299 1497.75,950.337 1497.75,950.376 1497.75,950.414 1497.75,950.452 1497.75,950.491 1497.75,950.529 1497.75,950.567 1497.75,950.606 1497.75,950.644 1497.75,950.682 1497.75,950.721 1497.75,950.759 1497.75,950.798 1497.75,950.836 1497.75,950.874 1497.75,950.913 1497.75,950.951 1497.75,950.99 1497.75,951.028 1497.75,951.067 1497.75,951.105 1497.75,951.144 1497.75,951.182 1497.75,951.221 1497.75,951.259 1497.75,951.298 1497.75,951.336 1497.75,951.375 1497.75,951.414 1497.75,951.452 1497.75,951.491 1497.75,951.53 1497.75,951.568 1497.75,951.607 1497.75,951.646 1497.75,951.684 1497.75,951.723 1497.75,951.762 1497.75,951.8 1497.75,951.839 1497.75,951.878 1497.75,951.917 1497.75,951.955 1497.75,951.994 1497.75,952.033 1497.75,952.072 1497.75,952.11 1497.75,952.149 1497.75,952.188 1497.75,952.227 1497.75,952.266 1497.75,952.305 1497.75,952.344 1497.75,952.382 1497.75,952.421 1497.75,952.46 1497.75,952.499 1497.75,952.538 1497.75,952.577 1497.75,952.616 1497.75,952.655 1497.75,952.694 1497.75,952.733 1497.75,952.772 1497.75,952.811 1497.75,952.85 1497.75,952.889 1497.75,952.928 1497.75,952.967 1497.75,953.006 1497.75,953.045 1497.75,953.085 1497.75,953.124 1497.75,953.163 1497.75,953.202 1497.75,953.241 1497.75,953.28 1497.75,953.319 1497.75,953.359 1497.75,953.398 1497.75,953.437 1497.75,953.476 1497.75,953.516 1497.75,953.555 1497.75,953.594 1497.75,953.633 1497.75,953.673 1497.75,953.712 1497.75,953.751 1497.75,953.79 1497.75,953.83 1497.75,953.869 1497.75,953.909 1497.75,953.948 1497.75,953.987 1497.75,954.027 1497.75,954.066 1497.75,954.105 1497.75,954.145 1497.75,954.184 1497.75,954.224 1497.75,954.263 1497.75,954.303 1497.75,954.342 1497.75,954.382 1497.75,954.421 1497.75,954.461 1497.75,954.5 1497.75,954.54 1497.75,954.579 1497.75,954.619 1497.75,954.658 1497.75,954.698 1497.75,954.738 1497.75,954.777 1497.75,954.817 1497.75,954.857 1497.75,954.896 1497.75,954.936 1497.75,954.976 1497.75,955.015 1497.75,955.055 1497.75,955.095 1497.75,955.134 1497.75,955.174 1497.75,955.214 1497.75,955.254 1497.75,955.293 1497.75,955.333 1497.75,955.373 1497.75,955.413 1497.75,955.452 1497.75,955.492 1497.75,955.532 1497.75,955.572 1497.75,955.612 1497.75,955.652 1497.75,955.692 1497.75,955.732 1497.75,955.771 1497.75,955.811 1497.75,955.851 1497.75,955.891 1497.75,955.931 1497.75,955.971 1497.75,956.011 1497.75,956.051 1497.75,956.091 1497.75,956.131 1497.75,956.171 1497.75,956.211 1497.75,956.251 1497.75,956.291 1497.75,956.331 1497.75,956.371 1497.75,956.412 1497.75,956.452 1497.75,956.492 1497.75,956.532 1497.75,956.572 1497.75,956.612 1497.75,956.652 1497.75,956.693 1497.75,956.733 1497.75,956.773 1497.75,956.813 1497.75,956.853 1497.75,956.894 1497.75,956.934 1497.75,956.974 1497.75,957.014 1497.75,957.055 1497.75,957.095 1497.75,957.135 1497.75,957.176 1497.75,957.216 1497.75,957.256 1497.75,957.297 1497.75,957.337 1497.75,957.377 1497.75,957.418 1497.75,957.458 1497.75,957.499 1497.75,957.539 1497.75,957.579 1497.75,957.62 1497.75,957.66 1497.75,957.701 1497.75,957.741 1497.75,957.782 1497.75,957.822 1497.75,957.863 1497.75,957.903 1497.75,957.944 1497.75,957.984 1497.75,958.025 1497.75,958.066 1497.75,958.106 1497.75,958.147 1497.75,958.187 1497.75,958.228 1497.75,958.269 1497.75,958.309 1497.75,958.35 1497.75,958.391 1497.75,958.431 1497.75,958.472 1497.75,958.513 1497.75,958.553 1497.75,958.594 1497.75,958.635 1497.75,958.676 1497.75,958.716 1497.75,958.757 1497.75,958.798 1497.75,958.839 1497.75,958.88 1497.75,958.92 1497.75,958.961 1497.75,959.002 1497.75,959.043 1497.75,959.084 1497.75,959.125 1497.75,959.166 1497.75,959.207 1497.75,959.247 1497.75,959.288 1497.75,959.329 1497.75,959.37 1497.75,959.411 1497.75,959.452 1497.75,959.493 1497.75,959.534 1497.75,959.575 1497.75,959.616 1497.75,959.657 1497.75,959.698 1497.75,959.739 1497.75,959.78 1497.75,959.822 1497.75,959.863 1497.75,959.904 1497.75,959.945 1497.75,959.986 1497.75,960.027 1497.75,960.068 1497.75,960.109 1497.75,960.151 1497.75,960.192 1497.75,960.233 1497.75,960.274 1497.75,960.315 1497.75,960.357 1497.75,960.398 1497.75,960.439 1497.75,960.48 1497.75,960.522 1497.75,960.563 1497.75,960.604 1497.75,960.646 1497.75,960.687 1497.75,960.728 1497.75,960.77 1497.75,960.811 1497.75,960.852 1497.75,960.894 1497.75,960.935 1497.75,960.977 1497.75,961.018 1497.75,961.059 1497.75,961.101 1497.75,961.142 1497.75,961.184 1497.75,961.225 1497.75,961.267 1497.75,961.308 1497.75,961.35 1497.75,961.391 1497.75,961.433 1497.75,961.474 1497.75,961.516 1497.75,961.558 1497.75,961.599 1497.75,961.641 1497.75,961.682 1497.75,961.724 1497.75,961.766 1497.75,961.807 1497.75,961.849 1497.75,961.891 1497.75,961.932 1497.75,961.974 1497.75,962.016 1497.75,962.057 1497.75,962.099 1497.75,962.141 1497.75,962.183 1497.75,962.224 1497.75,962.266 1497.75,962.308 1497.75,962.35 1497.75,962.392 1497.75,962.433 1497.75,962.475 1497.75,962.517 1497.75,962.559 1497.75,962.601 1497.75,962.643 1497.75,962.685 1497.75,962.726 1497.75,962.768 1497.75,962.81 1497.75,962.852 1497.75,962.894 1497.75,962.936 1497.75,962.978 1497.75,963.02 1497.75,963.062 1497.75,963.104 1497.75,963.146 1497.75,963.188 1497.75,963.23 1497.75,963.272 1497.75,963.314 1497.75,963.356 1497.75,963.398 1497.75,963.441 1497.75,963.483 1497.75,963.525 1497.75,963.567 1497.75,963.609 1497.75,963.651 1497.75,963.693 1497.75,963.736 1497.75,963.778 1497.75,963.82 1497.75,963.862 1497.75,963.904 1497.75,963.947 1497.75,963.989 1497.75,964.031 1497.75,964.073 1497.75,964.116 1497.75,964.158 1497.75,964.2 1497.75,964.243 1497.75,964.285 1497.75,964.327 1497.75,964.37 1497.75,964.412 1497.75,964.454 1497.75,964.497 1497.75,964.539 1497.75,964.582 1497.75,964.624 1497.75,964.666 1497.75,964.709 1497.75,964.751 1497.75,964.794 1497.75,964.836 1497.75,964.879 1497.75,964.921 1497.75,964.964 1497.75,965.006 1497.75,965.049 1497.75,965.091 1497.75,965.134 1497.75,965.177 1497.75,965.219 1497.75,965.262 1497.75,965.304 1497.75,965.347 1497.75,965.39 1497.75,965.432 1497.75,965.475 1497.75,965.518 1497.75,965.56 1497.75,965.603 1497.75,965.646 1497.75,965.688 1497.75,965.731 1497.75,965.774 1497.75,965.817 1497.75,965.859 1497.75,965.902 1497.75,965.945 1497.75,965.988 1497.75,966.031 1497.75,966.073 1497.75,966.116 1497.75,966.159 1497.75,966.202 1497.75,966.245 1497.75,966.288 1497.75,966.331 1497.75,966.373 1497.75,966.416 1497.75,966.459 1497.75,966.502 1497.75,966.545 1497.75,966.588 1497.75,966.631 1497.75,966.674 1497.75,966.717 1497.75,966.76 1497.75,966.803 1497.75,966.846 1497.75,966.889 1497.75,966.932 1497.75,966.975 1497.75,967.018 1497.75,967.061 1497.75,967.105 1497.75,967.148 1497.75,967.191 1497.75,967.234 1497.75,967.277 1497.75,967.32 1497.75,967.363 1497.75,967.407 1497.75,967.45 1497.75,967.493 1497.75,967.536 1497.75,967.579 1497.75,967.623 1497.75,967.666 1497.75,967.709 1497.75,967.752 1497.75,967.796 1497.75,967.839 1497.75,967.882 1497.75,967.926 1497.75,967.969 1497.75,968.012 1497.75,968.056 1497.75,968.099 1497.75,968.142 1497.75,968.186 1497.75,968.229 1497.75,968.273 1497.75,968.316 1497.75,968.359 1497.75,968.403 1497.75,968.446 1497.75,968.49 1497.75,968.533 1497.75,968.577 1497.75,968.62 1497.75,968.664 1497.75,968.707 1497.75,968.751 1497.75,968.794 1497.75,968.838 1497.75,968.882 1497.75,968.925 1497.75,968.969 1497.75,969.012 1497.75,969.056 1497.75,969.1 1497.75,969.143 1497.75,969.187 1497.75,969.231 1497.75,969.274 1497.75,969.318 1497.75,969.362 1497.75,969.405 1497.75,969.449 1497.75,969.493 1497.75,969.536 1497.75,969.58 1497.75,969.624 1497.75,969.668 1497.75,969.712 1497.75,969.755 1497.75,969.799 1497.75,969.843 1497.75,969.887 1497.75,969.931 1497.75,969.975 1497.75,970.018 1497.75,970.062 1497.75,970.106 1497.75,970.15 1497.75,970.194 1497.75,970.238 1497.75,970.282 1497.75,970.326 1497.75,970.37 1497.75,970.414 1497.75,970.458 1497.75,970.502 1497.75,970.546 1497.75,970.59 1497.75,970.634 1497.75,970.678 1497.75,970.722 1497.75,970.766 1497.75,970.81 1497.75,970.854 1497.75,970.898 1497.75,970.942 1497.75,970.986 1497.75,971.031 1497.75,971.075 1497.75,971.119 1497.75,971.163 1497.75,971.207 1497.75,971.251 1497.75,971.296 1497.75,971.34 1497.75,971.384 1497.75,971.428 1497.75,971.473 1497.75,971.517 1497.75,971.561 1497.75,971.605 1497.75,971.65 1497.75,971.694 1497.75,971.738 1497.75,971.783 1497.75,971.827 1497.75,971.871 1497.75,971.916 1497.75,971.96 1497.75,972.004 1497.75,972.049 1497.75,972.093 1497.75,972.138 1497.75,972.182 1497.75,972.227 1497.75,972.271 1497.75,972.315 1497.75,972.36 1497.75,972.404 1497.75,972.449 1497.75,972.493 1497.75,972.538 1497.75,972.582 1497.75,972.627 1497.75,972.672 1497.75,972.716 1497.75,972.761 1497.75,972.805 1497.75,972.85 1497.75,972.895 1497.75,972.939 1497.75,972.984 1497.75,973.028 1497.75,973.073 1497.75,973.118 1497.75,973.162 1497.75,973.207 1497.75,973.252 1497.75,973.297 1497.75,973.341 1497.75,973.386 1497.75,973.431 1497.75,973.476 1497.75,973.52 1497.75,973.565 1497.75,973.61 1497.75,973.655 1497.75,973.7 1497.75,973.744 1497.75,973.789 1497.75,973.834 1497.75,973.879 1497.75,973.924 1497.75,973.969 1497.75,974.014 1497.75,974.058 1497.75,974.103 1497.75,974.148 1497.75,974.193 1497.75,974.238 1497.75,974.283 1497.75,974.328 1497.75,974.373 1497.75,974.418 1497.75,974.463 1497.75,974.508 1497.75,974.553 1497.75,974.598 1497.75,974.643 1497.75,974.688 1497.75,974.733 1497.75,974.779 1497.75,974.824 1497.75,974.869 1497.75,974.914 1497.75,974.959 1497.75,975.004 1497.75,975.049 1497.75,975.095 1497.75,975.14 1497.75,975.185 1497.75,975.23 1497.75,975.275 1497.75,975.321 1497.75,975.366 1497.75,975.411 1497.75,975.456 1497.75,975.502 1497.75,975.547 1497.75,975.592 1497.75,975.637 1497.75,975.683 1497.75,975.728 1497.75,975.773 1497.75,975.819 1497.75,975.864 1497.75,975.91 1497.75,975.955 1497.75,976 1497.75,976.046 1497.75,976.091 1497.75,976.137 1497.75,976.182 1497.75,976.227 1497.75,976.273 1497.75,976.318 1497.75,976.364 1497.75,976.409 1497.75,976.455 1497.75,976.5 1497.75,976.546 1497.75,976.591 1497.75,976.637 1497.75,976.683 1497.75,976.728 1497.75,976.774 1497.75,976.819 1497.75,976.865 1497.75,976.911 1497.75,976.956 1497.75,977.002 1497.75,977.048 1497.75,977.093 1497.75,977.139 1497.75,977.185 1497.75,977.23 1497.75,977.276 1497.75,977.322 1497.75,977.367 1497.75,977.413 1497.75,977.459 1497.75,977.505 1497.75,977.55 1497.75,977.596 1497.75,977.642 1497.75,977.688 1497.75,977.734 1497.75,977.78 1497.75,977.825 1497.75,977.871 1497.75,977.917 1497.75,977.963 1497.75,978.009 1497.75,978.055 1497.75,978.101 1497.75,978.147 1497.75,978.193 1497.75,978.238 1497.75,978.284 1497.75,978.33 1497.75,978.376 1497.75,978.422 1497.75,978.468 1497.75,978.514 1497.75,978.56 1497.75,978.606 1497.75,978.653 1497.75,978.699 1497.75,978.745 1497.75,978.791 1497.75,978.837 1497.75,978.883 1497.75,978.929 1497.75,978.975 1497.75,979.021 1497.75,979.067 1497.75,979.114 1497.75,979.16 1497.75,979.206 1497.75,979.252 1497.75,979.298 1497.75,979.345 1497.75,979.391 1497.75,979.437 1497.75,979.483 1497.75,979.53 1497.75,979.576 1497.75,979.622 1497.75,979.668 1497.75,979.715 1497.75,979.761 1497.75,979.807 1497.75,979.854 1497.75,979.9 1497.75,979.946 1497.75,979.993 1497.75,980.039 1497.75,980.086 1497.75,980.132 1497.75,980.178 1497.75,980.225 1497.75,980.271 1497.75,980.318 1497.75,980.364 1497.75,980.411 1497.75,980.457 1497.75,980.504 1497.75,980.55 1497.75,980.597 1497.75,980.643 1497.75,980.69 1497.75,980.736 1497.75,980.783 1497.75,980.829 1497.75,980.876 1497.75,980.922 1497.75,980.969 1497.75,981.016 1497.75,981.062 1497.75,981.109 1497.75,981.156 1497.75,981.202 1497.75,981.249 1497.75,981.296 1497.75,981.342 1497.75,981.389 1497.75,981.436 1497.75,981.482 1497.75,981.529 1497.75,981.576 1497.75,981.623 1497.75,981.669 1497.75,981.716 1497.75,981.763 1497.75,981.81 1497.75,981.857 1497.75,981.903 1497.75,981.95 1497.75,981.997 1497.75,982.044 1497.75,982.091 1497.75,982.138 1497.75,982.185 1497.75,982.232 1497.75,982.278 1497.75,982.325 1497.75,982.372 1497.75,982.419 1497.75,982.466 1497.75,982.513 1497.75,982.56 1497.75,982.607 1497.75,982.654 1497.75,982.701 1497.75,982.748 1497.75,982.795 1497.75,982.842 1497.75,982.889 1497.75,982.936 1497.75,982.984 1497.75,983.031 1497.75,983.078 1497.75,983.125 1497.75,983.172 1497.75,983.219 1497.75,983.266 1497.75,983.313 1497.75,983.361 1497.75,983.408 1497.75,983.455 1497.75,983.502 1497.75,983.549 1497.75,983.597 1497.75,983.644 1497.75,983.691 1497.75,983.738 1497.75,983.786 1497.75,983.833 1497.75,983.88 1497.75,983.927 1497.75,983.975 1497.75,984.022 1497.75,984.069 1497.75,984.117 1497.75,984.164 1497.75,984.211 1497.75,984.259 1497.75,984.306 1497.75,984.354 1497.75,984.401 1497.75,984.448 1497.75,984.496 1497.75,984.543 1497.75,984.591 1497.75,984.638 1497.75,984.686 1497.75,984.733 1497.75,984.781 1497.75,984.828 1497.75,984.876 1497.75,984.923 1497.75,984.971 1497.75,985.018 1497.75,985.066 1497.75,985.113 1497.75,985.161 1497.75,985.209 1497.75,985.256 1497.75,985.304 1497.75,985.351 1497.75,985.399 1497.75,985.447 1497.75,985.494 1497.75,985.542 1497.75,985.59 1497.75,985.637 1497.75,985.685 1497.75,985.733 1497.75,985.781 1497.75,985.828 1497.75,985.876 1497.75,985.924 1497.75,985.972 1497.75,986.019 1497.75,986.067 1497.75,986.115 1497.75,986.163 1497.75,986.211 1497.75,986.258 1497.75,986.306 1497.75,986.354 1497.75,986.402 1497.75,986.45 1497.75,986.498 1497.75,986.546 1497.75,986.593 1497.75,986.641 1497.75,986.689 1497.75,986.737 1497.75,986.785 1497.75,986.833 1497.75,986.881 1497.75,986.929 1497.75,986.977 1497.75,987.025 1497.75,987.073 1497.75,987.121 1497.75,987.169 1497.75,987.217 1497.75,987.265 1497.75,987.313 1497.75,987.361 1497.75,987.41 1497.75,987.458 1497.75,987.506 1497.75,987.554 1497.75,987.602 1497.75,987.65 1497.75,987.698 1497.75,987.747 1497.75,987.795 1497.75,987.843 1497.75,987.891 1497.75,987.939 1497.75,987.988 1497.75,988.036 1497.75,988.084 1497.75,988.132 1497.75,988.181 1497.75,988.229 1497.75,988.277 1497.75,988.325 1497.75,988.374 1497.75,988.422 1497.75,988.47 1497.75,988.519 1497.75,988.567 1497.75,988.615 1497.75,988.664 1497.75,988.712 1497.75,988.761 1497.75,988.809 1497.75,988.857 1497.75,988.906 1497.75,988.954 1497.75,989.003 1497.75,989.051 1497.75,989.1 1497.75,989.148 1497.75,989.197 1497.75,989.245 1497.75,989.294 1497.75,989.342 1497.75,989.391 1497.75,989.439 1497.75,989.488 1497.75,989.536 1497.75,989.585 1497.75,989.633 1497.75,989.682 1497.75,989.731 1497.75,989.779 1497.75,989.828 1497.75,989.877 1497.75,989.925 1497.75,989.974 1497.75,990.022 1497.75,990.071 1497.75,990.12 1497.75,990.169 1497.75,990.217 1497.75,990.266 1497.75,990.315 1497.75,990.363 1497.75,990.412 1497.75,990.461 1497.75,990.51 1497.75,990.559 1497.75,990.607 1497.75,990.656 1497.75,990.705 1497.75,990.754 1497.75,990.803 1497.75,990.852 1497.75,990.9 1497.75,990.949 1497.75,990.998 1497.75,991.047 1497.75,991.096 1497.75,991.145 1497.75,991.194 1497.75,991.243 1497.75,991.292 1497.75,991.341 1497.75,991.39 1497.75,991.439 1497.75,991.488 1497.75,991.537 1497.75,991.586 1497.75,991.635 1497.75,991.684 1497.75,991.733 1497.75,991.782 1497.75,991.831 1497.75,991.88 1497.75,991.929 1497.75,991.978 1497.75,992.027 1497.75,992.076 1497.75,992.125 1497.75,992.175 1497.75,992.224 1497.75,992.273 1497.75,992.322 1497.75,992.371 1497.75,992.42 1497.75,992.47 1497.75,992.519 1497.75,992.568 1497.75,992.617 1497.75,992.666 1497.75,992.716 1497.75,992.765 1497.75,992.814 1497.75,992.864 1497.75,992.913 1497.75,992.962 1497.75,993.011 1497.75,993.061 1497.75,993.11 1497.75,993.159 1497.75,993.209 1497.75,993.258 1497.75,993.308 1497.75,993.357 1497.75,993.406 1497.75,993.456 1497.75,993.505 1497.75,993.555 1497.75,993.604 1497.75,993.654 1497.75,993.703 1497.75,993.752 1497.75,993.802 1497.75,993.851 1497.75,993.901 1497.75,993.95 1497.75,994 1497.75,994.05 1497.75,994.099 1497.75,994.149 1497.75,994.198 1497.75,994.248 1497.75,994.297 1497.75,994.347 1497.75,994.397 1497.75,994.446 1497.75,994.496 1497.75,994.545 1497.75,994.595 1497.75,994.645 1497.75,994.694 1497.75,994.744 1497.75,994.794 1497.75,994.844 1497.75,994.893 1497.75,994.943 1497.75,994.993 1497.75,995.042 1497.75,995.092 1497.75,995.142 1497.75,995.192 1497.75,995.242 1497.75,995.291 1497.75,995.341 1497.75,995.391 1497.75,995.441 1497.75,995.491 1497.75,995.54 1497.75,995.59 1497.75,995.64 1497.75,995.69 1497.75,995.74 1497.75,995.79 1497.75,995.84 1497.75,995.89 1497.75,995.94 1497.75,995.99 1497.75,996.039 1497.75,996.089 1497.75,996.139 1497.75,996.189 1497.75,996.239 1497.75,996.289 1497.75,996.339 1497.75,996.389 1497.75,996.439 1497.75,996.49 1497.75,996.54 1497.75,996.59 1497.75,996.64 1497.75,996.69 1497.75,996.74 1497.75,996.79 1497.75,996.84 1497.75,996.89 1497.75,996.94 1497.75,996.991 1497.75,997.041 1497.75,997.091 1497.75,997.141 1497.75,997.191 1497.75,997.241 1497.75,997.292 1497.75,997.342 1497.75,997.392 1497.75,997.442 1497.75,997.493 1497.75,997.543 1497.75,997.593 1497.75,997.643 1497.75,997.694 1497.75,997.744 1497.75,997.794 1497.75,997.845 1497.75,997.895 1497.75,997.945 1497.75,997.996 1497.75,998.046 1497.75,998.096 1497.75,998.147 1497.75,998.197 1497.75,998.248 1497.75,998.298 1497.75,998.348 1497.75,998.399 1497.75,998.449 1497.75,998.5 1497.75,998.55 1497.75,998.601 1497.75,998.651 1497.75,998.702 1497.75,998.752 1497.75,998.803 1497.75,998.853 1497.75,998.904 1497.75,998.954 1497.75,999.005 1497.75,999.055 1497.75,999.106 1497.75,999.157 1497.75,999.207 1497.75,999.258 1497.75,999.308 1497.75,999.359 1497.75,999.41 1497.75,999.46 1497.75,999.511 1497.75,999.562 1497.75,999.612 1497.75,999.663 1497.75,999.714 1497.75,999.764 1497.75,999.815 1497.75,999.866 1497.75,999.917 1497.75,999.967 1497.75,1000.02 1497.75,1000.07 1497.75,1000.12 1497.75,1000.17 1497.75,1000.22 1497.75,1000.27 1497.75,1000.32 1497.75,1000.37 1497.75,1000.42 1497.75,1000.48 1497.75,1000.53 1497.75,1000.58 1497.75,1000.63 1497.75,1000.68 1497.75,1000.73 1497.75,1000.78 1497.75,1000.83 1497.75,1000.88 1497.75,1000.93 1497.75,1000.98 1497.75,1001.04 1497.75,1001.09 1497.75,1001.14 1497.75,1001.19 1497.75,1001.24 1497.75,1001.29 1497.75,1001.34 1497.75,1001.39 1497.75,1001.44 1497.75,1001.49 1497.75,1001.55 1497.75,1001.6 1497.75,1001.65 1497.75,1001.7 1497.75,1001.75 1497.75,1001.8 1497.75,1001.85 1497.75,1001.9 1497.75,1001.95 1497.75,1002.01 1497.75,1002.06 1497.75,1002.11 1497.75,1002.16 1497.75,1002.21 1497.75,1002.26 1497.75,1002.31 1497.75,1002.36 1497.75,1002.41 1497.75,1002.47 1497.75,1002.52 1497.75,1002.57 1497.75,1002.62 1497.75,1002.67 1497.75,1002.72 1497.75,1002.77 1497.75,1002.83 1497.75,1002.88 1497.75,1002.93 1497.75,1002.98 1497.75,1003.03 1497.75,1003.08 1497.75,1003.13 1497.75,1003.18 1497.75,1003.24 1497.75,1003.29 1497.75,1003.34 1497.75,1003.39 1497.75,1003.44 1497.75,1003.49 1497.75,1003.54 1497.75,1003.6 1497.75,1003.65 1497.75,1003.7 1497.75,1003.75 1497.75,1003.8 1497.75,1003.85 1497.75,1003.9 1497.75,1003.96 1497.75,1004.01 1497.75,1004.06 1497.75,1004.11 1497.75,1004.16 1497.75,1004.21 1497.75,1004.27 1497.75,1004.32 1497.75,1004.37 1497.75,1004.42 1497.75,1004.47 1497.75,1004.52 1497.75,1004.58 1497.75,1004.63 1497.75,1004.68 1497.75,1004.73 1497.75,1004.78 1497.75,1004.83 1497.75,1004.89 1497.75,1004.94 1497.75,1004.99 1497.75,1005.04 1497.75,1005.09 1497.75,1005.14 1497.75,1005.2 1497.75,1005.25 1497.75,1005.3 1497.75,1005.35 1497.75,1005.4 1497.75,1005.45 1497.75,1005.51 1497.75,1005.56 1497.75,1005.61 1497.75,1005.66 1497.75,1005.71 1497.75,1005.77 1497.75,1005.82 1497.75,1005.87 1497.75,1005.92 1497.75,1005.97 1497.75,1006.03 1497.75,1006.08 1497.75,1006.13 1497.75,1006.18 1497.75,1006.23 1497.75,1006.29 1497.75,1006.34 1497.75,1006.39 1497.75,1006.44 1497.75,1006.49 1497.75,1006.55 1497.75,1006.6 1497.75,1006.65 1497.75,1006.7 1497.75,1006.75 1497.75,1006.81 1497.75,1006.86 1497.75,1006.91 1497.75,1006.96 1497.75,1007.01 1497.75,1007.07 1497.75,1007.12 1497.75,1007.17 1497.75,1007.22 1497.75,1007.27 1497.75,1007.33 1497.75,1007.38 1497.75,1007.43 1497.75,1007.48 1497.75,1007.54 1497.75,1007.59 1497.75,1007.64 1497.75,1007.69 1497.75,1007.74 1497.75,1007.8 1497.75,1007.85 1497.75,1007.9 1497.75,1007.95 1497.75,1008.01 1497.75,1008.06 1497.75,1008.11 1497.75,1008.16 1497.75,1008.21 1497.75,1008.27 1497.75,1008.32 1497.75,1008.37 1497.75,1008.42 1497.75,1008.48 1497.75,1008.53 1497.75,1008.58 1497.75,1008.63 1497.75,1008.69 1497.75,1008.74 1497.75,1008.79 1497.75,1008.84 1497.75,1008.9 1497.75,1008.95 1497.75,1009 1497.75,1009.05 1497.75,1009.11 1497.75,1009.16 1497.75,1009.21 1497.75,1009.26 1497.75,1009.32 1497.75,1009.37 1497.75,1009.42 1497.75,1009.47 1497.75,1009.53 1497.75,1009.58 1497.75,1009.63 1497.75,1009.68 1497.75,1009.74 1497.75,1009.79 1497.75,1009.84 1497.75,1009.89 1497.75,1009.95 1497.75,1010 1497.75,1010.05 1497.75,1010.1 1497.75,1010.16 1497.75,1010.21 1497.75,1010.26 1497.75,1010.32 1497.75,1010.37 1497.75,1010.42 1497.75,1010.47 1497.75,1010.53 1497.75,1010.58 1497.75,1010.63 1497.75,1010.68 1497.75,1010.74 1497.75,1010.79 1497.75,1010.84 1497.75,1010.9 1497.75,1010.95 1497.75,1011 1497.75,1011.05 1497.75,1011.11 1497.75,1011.16 1497.75,1011.21 1497.75,1011.27 1497.75,1011.32 1497.75,1011.37 1497.75,1011.42 1497.75,1011.48 1497.75,1011.53 1497.75,1011.58 1497.75,1011.64 1497.75,1011.69 1497.75,1011.74 1497.75,1011.79 1497.75,1011.85 1497.75,1011.9 1497.75,1011.95 1497.75,1012.01 1497.75,1012.06 1497.75,1012.11 1497.75,1012.17 1497.75,1012.22 1497.75,1012.27 1497.75,1012.33 1497.75,1012.38 1497.75,1012.43 1497.75,1012.48 1497.75,1012.54 1497.75,1012.59 1497.75,1012.64 1497.75,1012.7 1497.75,1012.75 1497.75,1012.8 1497.75,1012.86 1497.75,1012.91 1497.75,1012.96 1497.75,1013.02 1497.75,1013.07 1497.75,1013.12 1497.75,1013.18 1497.75,1013.23 1497.75,1013.28 1497.75,1013.33 1497.75,1013.39 1497.75,1013.44 1497.75,1013.49 1497.75,1013.55 1497.75,1013.6 1497.75,1013.65 1497.75,1013.71 1497.75,1013.76 1497.75,1013.81 1497.75,1013.87 1497.75,1013.92 1497.75,1013.97 1497.75,1014.03 1497.75,1014.08 1497.75,1014.13 1497.75,1014.19 1497.75,1014.24 1497.75,1014.29 1497.75,1014.35 1497.75,1014.4 1497.75,1014.45 1497.75,1014.51 1497.75,1014.56 1497.75,1014.62 1497.75,1014.67 1497.75,1014.72 1497.75,1014.78 1497.75,1014.83 1497.75,1014.88 1497.75,1014.94 1497.75,1014.99 1497.75,1015.04 1497.75,1015.1 1497.75,1015.15 1497.75,1015.2 1497.75,1015.26 1497.75,1015.31 1497.75,1015.36 1497.75,1015.42 1497.75,1015.47 1497.75,1015.53 1497.75,1015.58 1497.75,1015.63 1497.75,1015.69 1497.75,1015.74 1497.75,1015.79 1497.75,1015.85 1497.75,1015.9 1497.75,1015.95 1497.75,1016.01 1497.75,1016.06 1497.75,1016.12 1497.75,1016.17 1497.75,1016.22 1497.75,1016.28 1497.75,1016.33 1497.75,1016.38 1497.75,1016.44 1497.75,1016.49 1497.75,1016.55 1497.75,1016.6 1497.75,1016.65 1497.75,1016.71 1497.75,1016.76 1497.75,1016.81 1497.75,1016.87 1497.75,1016.92 1497.75,1016.98 1497.75,1017.03 1497.75,1017.08 1497.75,1017.14 1497.75,1017.19 1497.75,1017.25 1497.75,1017.3 1497.75,1017.35 1497.75,1017.41 1497.75,1017.46 1497.75,1017.52 1497.75,1017.57 1497.75,1017.62 1497.75,1017.68 1497.75,1017.73 1497.75,1017.79 1497.75,1017.84 1497.75,1017.89 1497.75,1017.95 1497.75,1018 1497.75,1018.06 1497.75,1018.11 1497.75,1018.16 1497.75,1018.22 1497.75,1018.27 1497.75,1018.33 1497.75,1018.38 1497.75,1018.43 1497.75,1018.49 1497.75,1018.54 1497.75,1018.6 1497.75,1018.65 1497.75,1018.7 1497.75,1018.76 1497.75,1018.81 1497.75,1018.87 1497.75,1018.92 1497.75,1018.97 1497.75,1019.03 1497.75,1019.08 1497.75,1019.14 1497.75,1019.19 1497.75,1019.25 1497.75,1019.3 1497.75,1019.35 1497.75,1019.41 1497.75,1019.46 1497.75,1019.52 1497.75,1019.57 1497.75,1019.63 1497.75,1019.68 1497.75,1019.73 1497.75,1019.79 1497.75,1019.84 1497.75,1019.9 1497.75,1019.95 1497.75,1020.01 1497.75,1020.06 1497.75,1020.11 1497.75,1020.17 1497.75,1020.22 1497.75,1020.28 1497.75,1020.33 1497.75,1020.39 1497.75,1020.44 1497.75,1020.5 1497.75,1020.55 1497.75,1020.6 1497.75,1020.66 1497.75,1020.71 1497.75,1020.77 1497.75,1020.82 1497.75,1020.88 1497.75,1020.93 1497.75,1020.99 1497.75,1021.04 1497.75,1021.09 1497.75,1021.15 1497.75,1021.2 1497.75,1021.26 1497.75,1021.31 1497.75,1021.37 1497.75,1021.42 1497.75,1021.48 1497.75,1021.53 1497.75,1021.59 1497.75,1021.64 1497.75,1021.69 1497.75,1021.75 1497.75,1021.8 1497.75,1021.86 1497.75,1021.91 1497.75,1021.97 1497.75,1022.02 1497.75,1022.08 1497.75,1022.13 1497.75,1022.19 1497.75,1022.24 1497.75,1022.3 1497.75,1022.35 1497.75,1022.41 1497.75,1022.46 1497.75,1022.52 1497.75,1022.57 1497.75,1022.62 1497.75,1022.68 1497.75,1022.73 1497.75,1022.79 1497.75,1022.84 1497.75,1022.9 1497.75,1022.95 1497.75,1023.01 1497.75,1023.06 1497.75,1023.12 1497.75,1023.17 1497.75,1023.23 1497.75,1023.28 1497.75,1023.34 1497.75,1023.39 1497.75,1023.45 1497.75,1023.5 1497.75,1023.56 1497.75,1023.61 1497.75,1023.67 1497.75,1023.72 1497.75,1023.78 1497.75,1023.83 1497.75,1023.89 1497.75,1023.94 1497.75,1024 1497.75,1024.05 1497.75,1024.11 1497.75,1024.16 1497.75,1024.22 1497.75,1024.27 1497.75,1024.33 1497.75,1024.38 1497.75,1024.44 1497.75,1024.49 1497.75,1024.55 1497.75,1024.6 1497.75,1024.66 1497.75,1024.71 1497.75,1024.77 1497.75,1024.82 1497.75,1024.88 1497.75,1024.93 1497.75,1024.99 1497.75,1025.04 1497.75,1025.1 1497.75,1025.15 1497.75,1025.21 1497.75,1025.26 1497.75,1025.32 1497.75,1025.37 1497.75,1025.43 1497.75,1025.48 1497.75,1025.54 1497.75,1025.59 1497.75,1025.65 1497.75,1025.7 1497.75,1025.76 1497.75,1025.82 1497.75,1025.87 1497.75,1025.93 1497.75,1025.98 1497.75,1026.04 1497.75,1026.09 1497.75,1026.15 1497.75,1026.2 1497.75,1026.26 1497.75,1026.31 1497.75,1026.37 1497.75,1026.42 1497.75,1026.48 1497.75,1026.53 1497.75,1026.59 1497.75,1026.64 1497.75,1026.7 1497.75,1026.76 1497.75,1026.81 1497.75,1026.87 1497.75,1026.92 1497.75,1026.98 1497.75,1027.03 1497.75,1027.09 1497.75,1027.14 1497.75,1027.2 1497.75,1027.25 1497.75,1027.31 1497.75,1027.37 1497.75,1027.42 1497.75,1027.48 1497.75,1027.53 1497.75,1027.59 1497.75,1027.64 1497.75,1027.7 1497.75,1027.75 1497.75,1027.81 1497.75,1027.87 1497.75,1027.92 1497.75,1027.98 1497.75,1028.03 1497.75,1028.09 1497.75,1028.14 1497.75,1028.2 1497.75,1028.25 1497.75,1028.31 1497.75,1028.37 1497.75,1028.42 1497.75,1028.48 1497.75,1028.53 1497.75,1028.59 1497.75,1028.64 1497.75,1028.7 1497.75,1028.76 1497.75,1028.81 1497.75,1028.87 1497.75,1028.92 1497.75,1028.98 1497.75,1029.03 1497.75,1029.09 1497.75,1029.15 1497.75,1029.2 1497.75,1029.26 1497.75,1029.31 1497.75,1029.37 1497.75,1029.42 1497.75,1029.48 1497.75,1029.54 1497.75,1029.59 1497.75,1029.65 1497.75,1029.7 1497.75,1029.76 1497.75,1029.81 1497.75,1029.87 1497.75,1029.93 1497.75,1029.98 1497.75,1030.04 1497.75,1030.09 1497.75,1030.15 1497.75,1030.21 1497.75,1030.26 1497.75,1030.32 1497.75,1030.37 1497.75,1030.43 1497.75,1030.49 1497.75,1030.54 1497.75,1030.6 1497.75,1030.65 1497.75,1030.71 1497.75,1030.76 1497.75,1030.82 1497.75,1030.88 1497.75,1030.93 1497.75,1030.99 1497.75,1031.04 1497.75,1031.1 1497.75,1031.16 1497.75,1031.21 1497.75,1031.27 1497.75,1031.32 1497.75,1031.38 1497.75,1031.44 1497.75,1031.49 1497.75,1031.55 1497.75,1031.61 1497.75,1031.66 1497.75,1031.72 1497.75,1031.77 1497.75,1031.83 1497.75,1031.89 1497.75,1031.94 1497.75,1032 1497.75,1032.05 1497.75,1032.11 1497.75,1032.17 1497.75,1032.22 1497.75,1032.28 1497.75,1032.34 1497.75,1032.39 1497.75,1032.45 1497.75,1032.5 1497.75,1032.56 1497.75,1032.62 1497.75,1032.67 1497.75,1032.73 1497.75,1032.78 1497.75,1032.84 1497.75,1032.9 1497.75,1032.95 1497.75,1033.01 1497.75,1033.07 1497.75,1033.12 1497.75,1033.18 1497.75,1033.24 1497.75,1033.29 1497.75,1033.35 1497.75,1033.4 1497.75,1033.46 1497.75,1033.52 1497.75,1033.57 1497.75,1033.63 1497.75,1033.69 1497.75,1033.74 1497.75,1033.8 1497.75,1033.85 1497.75,1033.91 1497.75,1033.97 1497.75,1034.02 1497.75,1034.08 1497.75,1034.14 1497.75,1034.19 1497.75,1034.25 1497.75,1034.31 1497.75,1034.36 1497.75,1034.42 1497.75,1034.48 1497.75,1034.53 1497.75,1034.59 1497.75,1034.65 1497.75,1034.7 1497.75,1034.76 1497.75,1034.81 1497.75,1034.87 1497.75,1034.93 1497.75,1034.98 1497.75,1035.04 1497.75,1035.1 1497.75,1035.15 1497.75,1035.21 1497.75,1035.27 1497.75,1035.32 1497.75,1035.38 1497.75,1035.44 1497.75,1035.49 1497.75,1035.55 1497.75,1035.61 1497.75,1035.66 1497.75,1035.72 1497.75,1035.78 1497.75,1035.83 1497.75,1035.89 1497.75,1035.95 1497.75,1036 1497.75,1036.06 1497.75,1036.12 1497.75,1036.17 1497.75,1036.23 1497.75,1036.29 1497.75,1036.34 1497.75,1036.4 1497.75,1036.46 1497.75,1036.51 1497.75,1036.57 1497.75,1036.63 1497.75,1036.68 1497.75,1036.74 1497.75,1036.8 1497.75,1036.85 1497.75,1036.91 1497.75,1036.97 1497.75,1037.02 1497.75,1037.08 1497.75,1037.14 1497.75,1037.2 1497.75,1037.25 1497.75,1037.31 1497.75,1037.37 1497.75,1037.42 1497.75,1037.48 1497.75,1037.54 1497.75,1037.59 1497.75,1037.65 1497.75,1037.71 1497.75,1037.76 1497.75,1037.82 1497.75,1037.88 1497.75,1037.93 1497.75,1037.99 1497.75,1038.05 1497.75,1038.11 1497.75,1038.16 1497.75,1038.22 1497.75,1038.28 1497.75,1038.33 1497.75,1038.39 1497.75,1038.45 1497.75,1038.5 1497.75,1038.56 1497.75,1038.62 1497.75,1038.68 1497.75,1038.73 1497.75,1038.79 1497.75,1038.85 1497.75,1038.9 1497.75,1038.96 1497.75,1039.02 1497.75,1039.08 1497.75,1039.13 1497.75,1039.19 1497.75,1039.25 1497.75,1039.3 1497.75,1039.36 1497.75,1039.42 1497.75,1039.47 1497.75,1039.53 1497.75,1039.59 1497.75,1039.65 1497.75,1039.7 1497.75,1039.76 1497.75,1039.82 1497.75,1039.87 1497.75,1039.93 1497.75,1039.99 1497.75,1040.05 1497.75,1040.1 1497.75,1040.16 1497.75,1040.22 1497.75,1040.28 1497.75,1040.33 1497.75,1040.39 1497.75,1040.45 1497.75,1040.5 1497.75,1040.56 1497.75,1040.62 1497.75,1040.68 1497.75,1040.73 1497.75,1040.79 1497.75,1040.85 1497.75,1040.91 1497.75,1040.96 1497.75,1041.02 1497.75,1041.08 1497.75,1041.13 1497.75,1041.19 1497.75,1041.25 1497.75,1041.31 1497.75,1041.36 1497.75,1041.42 1497.75,1041.48 1497.75,1041.54 1497.75,1041.59 1497.75,1041.65 1497.75,1041.71 1497.75,1041.77 1497.75,1041.82 1497.75,1041.88 1497.75,1041.94 1497.75,1042 1497.75,1042.05 1497.75,1042.11 1497.75,1042.17 1497.75,1042.22 1497.75,1042.28 1497.75,1042.34 1497.75,1042.4 1497.75,1042.45 1497.75,1042.51 1497.75,1042.57 1497.75,1042.63 1497.75,1042.68 1497.75,1042.74 1497.75,1042.8 1497.75,1042.86 1497.75,1042.92 1497.75,1042.97 1497.75,1043.03 1497.75,1043.09 1497.75,1043.15 1497.75,1043.2 1497.75,1043.26 1497.75,1043.32 1497.75,1043.38 1497.75,1043.43 1497.75,1043.49 1497.75,1043.55 1497.75,1043.61 1497.75,1043.66 1497.75,1043.72 1497.75,1043.78 1497.75,1043.84 1497.75,1043.89 1497.75,1043.95 1497.75,1044.01 1497.75,1044.07 1497.75,1044.13 1497.75,1044.18 1497.75,1044.24 1497.75,1044.3 1497.75,1044.36 1497.75,1044.41 1497.75,1044.47 1497.75,1044.53 1497.75,1044.59 1497.75,1044.64 1497.75,1044.7 1497.75,1044.76 1497.75,1044.82 1497.75,1044.88 1497.75,1044.93 1497.75,1044.99 1497.75,1045.05 1497.75,1045.11 1497.75,1045.16 1497.75,1045.22 1497.75,1045.28 1497.75,1045.34 1497.75,1045.4 1497.75,1045.45 1497.75,1045.51 1497.75,1045.57 1497.75,1045.63 1497.75,1045.69 1497.75,1045.74 1497.75,1045.8 1497.75,1045.86 1497.75,1045.92 1497.75,1045.97 1497.75,1046.03 1497.75,1046.09 1497.75,1046.15 1497.75,1046.21 1497.75,1046.26 1497.75,1046.32 1497.75,1046.38 1497.75,1046.44 1497.75,1046.5 1497.75,1046.55 1497.75,1046.61 1497.75,1046.67 1497.75,1046.73 1497.75,1046.79 1497.75,1046.84 1497.75,1046.9 1497.75,1046.96 1497.75,1047.02 1497.75,1047.08 1497.75,1047.13 1497.75,1047.19 1497.75,1047.25 1497.75,1047.31 1497.75,1047.37 1497.75,1047.42 1497.75,1047.48 1497.75,1047.54 1497.75,1047.6 1497.75,1047.66 1497.75,1047.71 1497.75,1047.77 1497.75,1047.83 1497.75,1047.89 1497.75,1047.95 1497.75,1048.01 1497.75,1048.06 1497.75,1048.12 1497.75,1048.18 1497.75,1048.24 1497.75,1048.3 1497.75,1048.35 1497.75,1048.41 1497.75,1048.47 1497.75,1048.53 1497.75,1048.59 1497.75,1048.64 1497.75,1048.7 1497.75,1048.76 1497.75,1048.82 1497.75,1048.88 1497.75,1048.94 1497.75,1048.99 1497.75,1049.05 1497.75,1049.11 1497.75,1049.17 1497.75,1049.23 1497.75,1049.29 1497.75,1049.34 1497.75,1049.4 1497.75,1049.46 1497.75,1049.52 1497.75,1049.58 1497.75,1049.64 1497.75,1049.69 1497.75,1049.75 1497.75,1049.81 1497.75,1049.87 1497.75,1049.93 1497.75,1049.99 1497.75,1050.04 1497.75,1050.1 1497.75,1050.16 1497.75,1050.22 1497.75,1050.28 1497.75,1050.34 1497.75,1050.39 1497.75,1050.45 1497.75,1050.51 1497.75,1050.57 1497.75,1050.63 1497.75,1050.69 1497.75,1050.74 1497.75,1050.8 1497.75,1050.86 1497.75,1050.92 1497.75,1050.98 1497.75,1051.04 1497.75,1051.09 1497.75,1051.15 1497.75,1051.21 1497.75,1051.27 1497.75,1051.33 1497.75,1051.39 1497.75,1051.45 1497.75,1051.5 1497.75,1051.56 1497.75,1051.62 1497.75,1051.68 1497.75,1051.74 1497.75,1051.8 1497.75,1051.86 1497.75,1051.91 1497.75,1051.97 1497.75,1052.03 1497.75,1052.09 1497.75,1052.15 1497.75,1052.21 1497.75,1052.27 1497.75,1052.32 1497.75,1052.38 1497.75,1052.44 1497.75,1052.5 1497.75,1052.56 1497.75,1052.62 1497.75,1052.68 1497.75,1052.73 1497.75,1052.79 1497.75,1052.85 1497.75,1052.91 1497.75,1052.97 1497.75,1053.03 1497.75,1053.09 1497.75,1053.14 1497.75,1053.2 1497.75,1053.26 1497.75,1053.32 1497.75,1053.38 1497.75,1053.44 1497.75,1053.5 1497.75,1053.56 1497.75,1053.61 1497.75,1053.67 1497.75,1053.73 1497.75,1053.79 1497.75,1053.85 1497.75,1053.91 1497.75,1053.97 1497.75,1054.03 1497.75,1054.08 1497.75,1054.14 1497.75,1054.2 1497.75,1054.26 1497.75,1054.32 1497.75,1054.38 1497.75,1054.44 1497.75,1054.5 1497.75,1054.55 1497.75,1054.61 1497.75,1054.67 1497.75,1054.73 1497.75,1054.79 1497.75,1054.85 1497.75,1054.91 1497.75,1054.97 1497.75,1055.03 1497.75,1055.08 1497.75,1055.14 1497.75,1055.2 1497.75,1055.26 1497.75,1055.32 1497.75,1055.38 1497.75,1055.44 1497.75,1055.5 1497.75,1055.56 1497.75,1055.61 1497.75,1055.67 1497.75,1055.73 1497.75,1055.79 1497.75,1055.85 1497.75,1055.91 1497.75,1055.97 1497.75,1056.03 1497.75,1056.09 1497.75,1056.14 1497.75,1056.2 1497.75,1056.26 1497.75,1056.32 1497.75,1056.38 1497.75,1056.44 1497.75,1056.5 1497.75,1056.56 1497.75,1056.62 1497.75,1056.68 1497.75,1056.73 1497.75,1056.79 1497.75,1056.85 1497.75,1056.91 1497.75,1056.97 1497.75,1057.03 1497.75,1057.09 1497.75,1057.15 1497.75,1057.21 1497.75,1057.27 1497.75,1057.32 1497.75,1057.38 1497.75,1057.44 1497.75,1057.5 1497.75,1057.56 1497.75,1057.62 1497.75,1057.68 1497.75,1057.74 1497.75,1057.8 1497.75,1057.86 1497.75,1057.92 1497.75,1057.98 1497.75,1058.03 1497.75,1058.09 1497.75,1058.15 1497.75,1058.21 1497.75,1058.27 1497.75,1058.33 1497.75,1058.39 1497.75,1058.45 1497.75,1058.51 1497.75,1058.57 1497.75,1058.63 1497.75,1058.69 1497.75,1058.74 1497.75,1058.8 1497.75,1058.86 1497.75,1058.92 1497.75,1058.98 1497.75,1059.04 1497.75,1059.1 1497.75,1059.16 1497.75,1059.22 1497.75,1059.28 1497.75,1059.34 1497.75,1059.4 1497.75,1059.46 1497.75,1059.51 1497.75,1059.57 1497.75,1059.63 1497.75,1059.69 1497.75,1059.75 1497.75,1059.81 1497.75,1059.87 1497.75,1059.93 1497.75,1059.99 1497.75,1060.05 1497.75,1060.11 1497.75,1060.17 1497.75,1060.23 1497.75,1060.29 1497.75,1060.35 1497.75,1060.4 1497.75,1060.46 1497.75,1060.52 1497.75,1060.58 1497.75,1060.64 1497.75,1060.7 1497.75,1060.76 1497.75,1060.82 1497.75,1060.88 1497.75,1060.94 1497.75,1061 1497.75,1061.06 1497.75,1061.12 1497.75,1061.18 1497.75,1061.24 1497.75,1061.3 1497.75,1061.35 1497.75,1061.41 1497.75,1061.47 1497.75,1061.53 1497.75,1061.59 1497.75,1061.65 1497.75,1061.71 1497.75,1061.77 1497.75,1061.83 1497.75,1061.89 1497.75,1061.95 1497.75,1062.01 1497.75,1062.07 1497.75,1062.13 1497.75,1062.19 1497.75,1062.25 1497.75,1062.31 1497.75,1062.37 1497.75,1062.43 1497.75,1062.49 1497.75,1062.54 1497.75,1062.6 1497.75,1062.66 1497.75,1062.72 1497.75,1062.78 1497.75,1062.84 1497.75,1062.9 1497.75,1062.96 1497.75,1063.02 1497.75,1063.08 1497.75,1063.14 1497.75,1063.2 1497.75,1063.26 1497.75,1063.32 1497.75,1063.38 1497.75,1063.44 1497.75,1063.5 1497.75,1063.56 1497.75,1063.62 1497.75,1063.68 1497.75,1063.74 1497.75,1063.8 1497.75,1063.86 1497.75,1063.92 1497.75,1063.98 1497.75,1064.03 1497.75,1064.09 1497.75,1064.15 1497.75,1064.21 1497.75,1064.27 1497.75,1064.33 1497.75,1064.39 1497.75,1064.45 1497.75,1064.51 1497.75,1064.57 1497.75,1064.63 1497.75,1064.69 1497.75,1064.75 1497.75,1064.81 1497.75,1064.87 1497.75,1064.93 1497.75,1064.99 1497.75,1065.05 1497.75,1065.11 1497.75,1065.17 1497.75,1065.23 1497.75,1065.29 1497.75,1065.35 1497.75,1065.41 1497.75,1065.47 1497.75,1065.53 1497.75,1065.59 1497.75,1065.65 1497.75,1065.71 1497.75,1065.77 1497.75,1065.83 1497.75,1065.89 1497.75,1065.95 1497.75,1066.01 1497.75,1066.07 1497.75,1066.13 1497.75,1066.19 1497.75,1066.25 1497.75,1066.31 1497.75,1066.37 1497.75,1066.43 1497.75,1066.49 1497.75,1066.55 1497.75,1066.61 1497.75,1066.67 1497.75,1066.73 1497.75,1066.78 1497.75,1066.84 1497.75,1066.9 1497.75,1066.96 1497.75,1067.02 1497.75,1067.08 1497.75,1067.14 1497.75,1067.2 1497.75,1067.26 1497.75,1067.32 1497.75,1067.38 1497.75,1067.44 1497.75,1067.5 1497.75,1067.56 1497.75,1067.62 1497.75,1067.68 1497.75,1067.74 1497.75,1067.8 1497.75,1067.86 1497.75,1067.92 1497.75,1067.98 1497.75,1068.04 1497.75,1068.1 1497.75,1068.16 1497.75,1068.22 1497.75,1068.28 1497.75,1068.34 1497.75,1068.4 1497.75,1068.46 1497.75,1068.52 1497.75,1068.58 1497.75,1068.64 1497.75,1068.7 1497.75,1068.76 1497.75,1068.82 1497.75,1068.88 1497.75,1068.94 1497.75,1069 1497.75,1069.06 1497.75,1069.12 1497.75,1069.18 1497.75,1069.24 1497.75,1069.3 1497.75,1069.36 1497.75,1069.42 1497.75,1069.48 1497.75,1069.54 1497.75,1069.6 1497.75,1069.66 1497.75,1069.73 1497.75,1069.79 1497.75,1069.85 1497.75,1069.91 1497.75,1069.97 1497.75,1070.03 1497.75,1070.09 1497.75,1070.15 1497.75,1070.21 1497.75,1070.27 1497.75,1070.33 1497.75,1070.39 1497.75,1070.45 1497.75,1070.51 1497.75,1070.57 1497.75,1070.63 1497.75,1070.69 1497.75,1070.75 1497.75,1070.81 1497.75,1070.87 1497.75,1070.93 1497.75,1070.99 1497.75,1071.05 1497.75,1071.11 1497.75,1071.17 1497.75,1071.23 1497.75,1071.29 1497.75,1071.35 1497.75,1071.41 1497.75,1071.47 1497.75,1071.53 1497.75,1071.59 1497.75,1071.65 1497.75,1071.71 1497.75,1071.77 1497.75,1071.83 1497.75,1071.89 1497.75,1071.95 1497.75,1072.01 1497.75,1072.07 1497.75,1072.13 1497.75,1072.19 1497.75,1072.25 1497.75,1072.31 1497.75,1072.37 1497.75,1072.43 1497.75,1072.49 1497.75,1072.55 1497.75,1072.62 1497.75,1072.68 1497.75,1072.74 1497.75,1072.8 1497.75,1072.86 1497.75,1072.92 1497.75,1072.98 1497.75,1073.04 1497.75,1073.1 1497.75,1073.16 1497.75,1073.22 1497.75,1073.28 1497.75,1073.34 1497.75,1073.4 1497.75,1073.46 1497.75,1073.52 1497.75,1073.58 1497.75,1073.64 1497.75,1073.7 1497.75,1073.76 1497.75,1073.82 1497.75,1073.88 1497.75,1073.94 1497.75,1074 1497.75,1074.06 1497.75,1074.12 1497.75,1074.18 1497.75,1074.25 1497.75,1074.31 1497.75,1074.37 1497.75,1074.43 1497.75,1074.49 1497.75,1074.55 1497.75,1074.61 1497.75,1074.67 1497.75,1074.73 1497.75,1074.79 1497.75,1074.85 1497.75,1074.91 1497.75,1074.97 1497.75,1075.03 1497.75,1075.09 1497.75,1075.15 1497.75,1075.21 1497.75,1075.27 1497.75,1075.33 1497.75,1075.39 1497.75,1075.45 1497.75,1075.51 1497.75,1075.58 1497.75,1075.64 1497.75,1075.7 1497.75,1075.76 1497.75,1075.82 1497.75,1075.88 1497.75,1075.94 1497.75,1076 1497.75,1076.06 1497.75,1076.12 1497.75,1076.18 1497.75,1076.24 1497.75,1076.3 1497.75,1076.36 1497.75,1076.42 1497.75,1076.48 1497.75,1076.54 1497.75,1076.6 1497.75,1076.67 1497.75,1076.73 1497.75,1076.79 1497.75,1076.85 1497.75,1076.91 1497.75,1076.97 1497.75,1077.03 1497.75,1077.09 1497.75,1077.15 1497.75,1077.21 1497.75,1077.27 1497.75,1077.33 1497.75,1077.39 1497.75,1077.45 1497.75,1077.51 1497.75,1077.57 1497.75,1077.63 1497.75,1077.7 1497.75,1077.76 1497.75,1077.82 1497.75,1077.88 1497.75,1077.94 1497.75,1078 1497.75,1078.06 1497.75,1078.12 1497.75,1078.18 1497.75,1078.24 1497.75,1078.3 1497.75,1078.36 1497.75,1078.42 1497.75,1078.48 1497.75,1078.54 1497.75,1078.61 1497.75,1078.67 1497.75,1078.73 1497.75,1078.79 1497.75,1078.85 1497.75,1078.91 1497.75,1078.97 1497.75,1079.03 1497.75,1079.09 1497.75,1079.15 1497.75,1079.21 1497.75,1079.27 1497.75,1079.33 1497.75,1079.39 1497.75,1079.46 1497.75,1079.52 1497.75,1079.58 1497.75,1079.64 1497.75,1079.7 1497.75,1079.76 1497.75,1079.82 1497.75,1079.88 1497.75,1079.94 1497.75,1080 1497.75,1080.06 1497.75,1080.12 1497.75,1080.18 1497.75,1080.25 1497.75,1080.31 1497.75,1080.37 1497.75,1080.43 1497.75,1080.49 1497.75,1080.55 1497.75,1080.61 1497.75,1080.67 1497.75,1080.73 1497.75,1080.79 1497.75,1080.85 1497.75,1080.91 1497.75,1080.98 1497.75,1081.04 1497.75,1081.1 1497.75,1081.16 1497.75,1081.22 1497.75,1081.28 1497.75,1081.34 1497.75,1081.4 1497.75,1081.46 1497.75,1081.52 1497.75,1081.58 1497.75,1081.64 1497.75,1081.71 1497.75,1081.77 1497.75,1081.83 1497.75,1081.89 1497.75,1081.95 1497.75,1082.01 1497.75,1082.07 1497.75,1082.13 1497.75,1082.19 1497.75,1082.25 1497.75,1082.31 1497.75,1082.37 1497.75,1082.44 1497.75,1082.5 1497.75,1082.56 1497.75,1082.62 1497.75,1082.68 1497.75,1082.74 1497.75,1082.8 1497.75,1082.86 1497.75,1082.92 1497.75,1082.98 1497.75,1083.04 1497.75,1083.11 1497.75,1083.17 1497.75,1083.23 1497.75,1083.29 1497.75,1083.35 1497.75,1083.41 1497.75,1083.47 1497.75,1083.53 1497.75,1083.59 1497.75,1083.65 1497.75,1083.72 1497.75,1083.78 1497.75,1083.84 1497.75,1083.9 1497.75,1083.96 1497.75,1084.02 1497.75,1084.08 1497.75,1084.14 1497.75,1084.2 1497.75,1084.26 1497.75,1084.33 1497.75,1084.39 1497.75,1084.45 1497.75,1084.51 1497.75,1084.57 1497.75,1084.63 1497.75,1084.69 1497.75,1084.75 1497.75,1084.81 1497.75,1084.87 1497.75,1084.94 1497.75,1085 1497.75,1085.06 1497.75,1085.12 1497.75,1085.18 1497.75,1085.24 1497.75,1085.3 1497.75,1085.36 1497.75,1085.42 1497.75,1085.48 1497.75,1085.55 1497.75,1085.61 1497.75,1085.67 1497.75,1085.73 1497.75,1085.79 1497.75,1085.85 1497.75,1085.91 1497.75,1085.97 1497.75,1086.03 1497.75,1086.1 1497.75,1086.16 1497.75,1086.22 1497.75,1086.28 1497.75,1086.34 1497.75,1086.4 1497.75,1086.46 1497.75,1086.52 1497.75,1086.58 1497.75,1086.65 1497.75,1086.71 1497.75,1086.77 1497.75,1086.83 1497.75,1086.89 1497.75,1086.95 1497.75,1087.01 1497.75,1087.07 1497.75,1087.13 1497.75,1087.2 1497.75,1087.26 1497.75,1087.32 1497.75,1087.38 1497.75,1087.44 1497.75,1087.5 1497.75,1087.56 1497.75,1087.62 1497.75,1087.68 1497.75,1087.75 1497.75,1087.81 1497.75,1087.87 1497.75,1087.93 1497.75,1087.99 1497.75,1088.05 1497.75,1088.11 1497.75,1088.17 1497.75,1088.23 1497.75,1088.3 1497.75,1088.36 1497.75,1088.42 1497.75,1088.48 1497.75,1088.54 1497.75,1088.6 1497.75,1088.66 1497.75,1088.72 1497.75,1088.79 1497.75,1088.85 1497.75,1088.91 1497.75,1088.97 1497.75,1089.03 1497.75,1089.09 1497.75,1089.15 1497.75,1089.21 1497.75,1089.27 1497.75,1089.34 1497.75,1089.4 1497.75,1089.46 1497.75,1089.52 1497.75,1089.58 1497.75,1089.64 1497.75,1089.7 1497.75,1089.76 1497.75,1089.83 1497.75,1089.89 1497.75,1089.95 1497.75,1090.01 1497.75,1090.07 1497.75,1090.13 1497.75,1090.19 1497.75,1090.25 1497.75,1090.32 1497.75,1090.38 1497.75,1090.44 1497.75,1090.5 1497.75,1090.56 1497.75,1090.62 1497.75,1090.68 1497.75,1090.74 1497.75,1090.81 1497.75,1090.87 1497.75,1090.93 1497.75,1090.99 1497.75,1091.05 1497.75,1091.11 1497.75,1091.17 1497.75,1091.24 1497.75,1091.3 1497.75,1091.36 1497.75,1091.42 1497.75,1091.48 1497.75,1091.54 1497.75,1091.6 1497.75,1091.66 1497.75,1091.73 1497.75,1091.79 1497.75,1091.85 1497.75,1091.91 1497.75,1091.97 1497.75,1092.03 1497.75,1092.09 1497.75,1092.15 1497.75,1092.22 1497.75,1092.28 1497.75,1092.34 1497.75,1092.4 1497.75,1092.46 1497.75,1092.52 1497.75,1092.58 1497.75,1092.65 1497.75,1092.71 1497.75,1092.77 1497.75,1092.83 1497.75,1092.89 1497.75,1092.95 1497.75,1093.01 1497.75,1093.07 1497.75,1093.14 1497.75,1093.2 1497.75,1093.26 1497.75,1093.32 1497.75,1093.38 1497.75,1093.44 1497.75,1093.5 1497.75,1093.57 1497.75,1093.63 1497.75,1093.69 1497.75,1093.75 1497.75,1093.81 1497.75,1093.87 1497.75,1093.93 1497.75,1094 1497.75,1094.06 1497.75,1094.12 1497.75,1094.18 1497.75,1094.24 1497.75,1094.3 1497.75,1094.36 1497.75,1094.43 1497.75,1094.49 1497.75,1094.55 1497.75,1094.61 1497.75,1094.67 1497.75,1094.73 1497.75,1094.79 1497.75,1094.85 1497.75,1094.92 1497.75,1094.98 1497.75,1095.04 1497.75,1095.1 1497.75,1095.16 1497.75,1095.22 1497.75,1095.28 1497.75,1095.35 1497.75,1095.41 1497.75,1095.47 1497.75,1095.53 1497.75,1095.59 1497.75,1095.65 1497.75,1095.71 1497.75,1095.78 1497.75,1095.84 1497.75,1095.9 1497.75,1095.96 1497.75,1096.02 1497.75,1096.08 1497.75,1096.15 1497.75,1096.21 1497.75,1096.27 1497.75,1096.33 1497.75,1096.39 1497.75,1096.45 1497.75,1096.51 1497.75,1096.58 1497.75,1096.64 1497.75,1096.7 1497.75,1096.76 1497.75,1096.82 1497.75,1096.88 1497.75,1096.94 1497.75,1097.01 1497.75,1097.07 1497.75,1097.13 1497.75,1097.19 1497.75,1097.25 1497.75,1097.31 1497.75,1097.37 1497.75,1097.44 1497.75,1097.5 1497.75,1097.56 1497.75,1097.62 1497.75,1097.68 1497.75,1097.74 1497.75,1097.8 1497.75,1097.87 1497.75,1097.93 1497.75,1097.99 1497.75,1098.05 1497.75,1098.11 1497.75,1098.17 1497.75,1098.24 1497.75,1098.3 1497.75,1098.36 1497.75,1098.42 1497.75,1098.48 1497.75,1098.54 1497.75,1098.6 1497.75,1098.67 1497.75,1098.73 1497.75,1098.79 1497.75,1098.85 1497.75,1098.91 1497.75,1098.97 1497.75,1099.04 1497.75,1099.1 1497.75,1099.16 1497.75,1099.22 1497.75,1099.28 1497.75,1099.34 1497.75,1099.4 1497.75,1099.47 1497.75,1099.53 1497.75,1099.59 1497.75,1099.65 1497.75,1099.71 1497.75,1099.77 1497.75,1099.84 1497.75,1099.9 1497.75,1099.96 1497.75,1100.02 1497.75,1100.08 1497.75,1100.14 1497.75,1100.2 1497.75,1100.27 1497.75,1100.33 1497.75,1100.39 1497.75,1100.45 1497.75,1100.51 1497.75,1100.57 1497.75,1100.64 1497.75,1100.7 1497.75,1100.76 1497.75,1100.82 1497.75,1100.88 1497.75,1100.94 1497.75,1101.01 1497.75,1101.07 1497.75,1101.13 1497.75,1101.19 1497.75,1101.25 1497.75,1101.31 1497.75,1101.37 1497.75,1101.44 1497.75,1101.5 1497.75,1101.56 1497.75,1101.62 1497.75,1101.68 1497.75,1101.74 1497.75,1101.81 1497.75,1101.87 1497.75,1101.93 1497.75,1101.99 1497.75,1102.05 1497.75,1102.11 1497.75,1102.18 1497.75,1102.24 1497.75,1102.3 1497.75,1102.36 1497.75,1102.42 1497.75,1102.48 1497.75,1102.54 1497.75,1102.61 1497.75,1102.67 1497.75,1102.73 1497.75,1102.79 1497.75,1102.85 1497.75,1102.91 1497.75,1102.98 1497.75,1103.04 1497.75,1103.1 1497.75,1103.16 1497.75,1103.22 1497.75,1103.28 1497.75,1103.35 1497.75,1103.41 1497.75,1103.47 1497.75,1103.53 1497.75,1103.59 1497.75,1103.65 1497.75,1103.72 1497.75,1103.78 1497.75,1103.84 1497.75,1103.9 1497.75,1103.96 1497.75,1104.02 1497.75,1104.09 1497.75,1104.15 1497.75,1104.21 1497.75,1104.27 1497.75,1104.33 1497.75,1104.39 1497.75,1104.46 1497.75,1104.52 1497.75,1104.58 1497.75,1104.64 1497.75,1104.7 1497.75,1104.76 1497.75,1104.83 1497.75,1104.89 1497.75,1104.95 1497.75,1105.01 1497.75,1105.07 1497.75,1105.13 1497.75,1105.19 1497.75,1105.26 1497.75,1105.32 1497.75,1105.38 1497.75,1105.44 1497.75,1105.5 1497.75,1105.56 1497.75,1105.63 1497.75,1105.69 1497.75,1105.75 1497.75,1105.81 1497.75,1105.87 1497.75,1105.93 1497.75,1106 1497.75,1106.06 1497.75,1106.12 1497.75,1106.18 1497.75,1106.24 1497.75,1106.3 1497.75,1106.37 1497.75,1106.43 1497.75,1106.49 1497.75,1106.55 1497.75,1106.61 1497.75,1106.67 1497.75,1106.74 1497.75,1106.8 1497.75,1106.86 1497.75,1106.92 1497.75,1106.98 1497.75,1107.04 1497.75,1107.11 1497.75,1107.17 1497.75,1107.23 1497.75,1107.29 1497.75,1107.35 1497.75,1107.41 1497.75,1107.48 1497.75,1107.54 1497.75,1107.6 1497.75,1107.66 1497.75,1107.72 1497.75,1107.78 1497.75,1107.85 1497.75,1107.91 1497.75,1107.97 1497.75,1108.03 1497.75,1108.09 1497.75,1108.16 1497.75,1108.22 1497.75,1108.28 1497.75,1108.34 1497.75,1108.4 1497.75,1108.46 1497.75,1108.53 1497.75,1108.59 1497.75,1108.65 1497.75,1108.71 1497.75,1108.77 1497.75,1108.83 1497.75,1108.9 1497.75,1108.96 1497.75,1109.02 1497.75,1109.08 1497.75,1109.14 1497.75,1109.2 1497.75,1109.27 1497.75,1109.33 1497.75,1109.39 1497.75,1109.45 1497.75,1109.51 1497.75,1109.57 1497.75,1109.64 1497.75,1109.7 1497.75,1109.76 1497.75,1109.82 1497.75,1109.88 1497.75,1109.94 1497.75,1110.01 1497.75,1110.07 1497.75,1110.13 1497.75,1110.19 1497.75,1110.25 1497.75,1110.31 1497.75,1110.38 1497.75,1110.44 1497.75,1110.5 1497.75,1110.56 1497.75,1110.62 1497.75,1110.68 1497.75,1110.75 1497.75,1110.81 1497.75,1110.87 1497.75,1110.93 1497.75,1110.99 1497.75,1111.05 1497.75,1111.12 1497.75,1111.18 1497.75,1111.24 1497.75,1111.3 1497.75,1111.36 1497.75,1111.43 1497.75,1111.49 1497.75,1111.55 1497.75,1111.61 1497.75,1111.67 1497.75,1111.73 1497.75,1111.8 1497.75,1111.86 1497.75,1111.92 1497.75,1111.98 1497.75,1112.04 1497.75,1112.1 1497.75,1112.17 1497.75,1112.23 1497.75,1112.29 1497.75,1112.35 1497.75,1112.41 1497.75,1112.47 1497.75,1112.54 1497.75,1112.6 1497.75,1112.66 1497.75,1112.72 1497.75,1112.78 1497.75,1112.84 1497.75,1112.91 1497.75,1112.97 1497.75,1113.03 1497.75,1113.09 1497.75,1113.15 1497.75,1113.21 1497.75,1113.28 1497.75,1113.34 1497.75,1113.4 1497.75,1113.46 1497.75,1113.52 1497.75,1113.59 1497.75,1113.65 1497.75,1113.71 1497.75,1113.77 1497.75,1113.83 1497.75,1113.89 1497.75,1113.96 1497.75,1114.02 1497.75,1114.08 1497.75,1114.14 1497.75,1114.2 1497.75,1114.26 1497.75,1114.33 1497.75,1114.39 1497.75,1114.45 1497.75,1114.51 1497.75,1114.57 1497.75,1114.63 1497.75,1114.7 1497.75,1114.76 1497.75,1114.82 1497.75,1114.88 1497.75,1114.94 1497.75,1115 1497.75,1115.07 1497.75,1115.13 1497.75,1115.19 1497.75,1115.25 1497.75,1115.31 1497.75,1115.38 1497.75,1115.44 1497.75,1115.5 1497.75,1115.56 1497.75,1115.62 1497.75,1115.68 1497.75,1115.75 1497.75,1115.81 1497.75,1115.87 1497.75,1115.93 1497.75,1115.99 1497.75,1116.05 1497.75,1116.12 1497.75,1116.18 1497.75,1116.24 1497.75,1116.3 1497.75,1116.36 1497.75,1116.42 1497.75,1116.49 1497.75,1116.55 1497.75,1116.61 1497.75,1116.67 1497.75,1116.73 1497.75,1116.79 1497.75,1116.86 1497.75,1116.92 1497.75,1116.98 1497.75,1117.04 1497.75,1117.1 1497.75,1117.16 1497.75,1117.23 1497.75,1117.29 1497.75,1117.35 1497.75,1117.41 1497.75,1117.47 1497.75,1117.54 1497.75,1117.6 1497.75,1117.66 1497.75,1117.72 1497.75,1117.78 1497.75,1117.84 1497.75,1117.91 1497.75,1117.97 1497.75,1118.03 1497.75,1118.09 1497.75,1118.15 1497.75,1118.21 1497.75,1118.28 1497.75,1118.34 1497.75,1118.4 1497.75,1118.46 1497.75,1118.52 1497.75,1118.58 1497.75,1118.65 1497.75,1118.71 1497.75,1118.77 1497.75,1118.83 1497.75,1118.89 1497.75,1118.95 1497.75,1119.02 1497.75,1119.08 1497.75,1119.14 1497.75,1119.2 1497.75,1119.26 1497.75,1119.32 1497.75,1119.39 1497.75,1119.45 1497.75,1119.51 1497.75,1119.57 1497.75,1119.63 1497.75,1119.69 1497.75,1119.76 1497.75,1119.82 1497.75,1119.88 1497.75,1119.94 1497.75,1120 1497.75,1120.06 1497.75,1120.13 1497.75,1120.19 1497.75,1120.25 1497.75,1120.31 1497.75,1120.37 1497.75,1120.43 1497.75,1120.5 1497.75,1120.56 1497.75,1120.62 1497.75,1120.68 1497.75,1120.74 1497.75,1120.81 1497.75,1120.87 1497.75,1120.93 1497.75,1120.99 1497.75,1121.05 1497.75,1121.11 1497.75,1121.18 1497.75,1121.24 1497.75,1121.3 1497.75,1121.36 1497.75,1121.42 1497.75,1121.48 1497.75,1121.55 1497.75,1121.61 1497.75,1121.67 1497.75,1121.73 1497.75,1121.79 1497.75,1121.85 1497.75,1121.92 1497.75,1121.98 1497.75,1122.04 1497.75,1122.1 1497.75,1122.16 1497.75,1122.22 1497.75,1122.29 1497.75,1122.35 1497.75,1122.41 1497.75,1122.47 1497.75,1122.53 1497.75,1122.59 1497.75,1122.66 1497.75,1122.72 1497.75,1122.78 1497.75,1122.84 1497.75,1122.9 1497.75,1122.96 1497.75,1123.03 1497.75,1123.09 1497.75,1123.15 1497.75,1123.21 1497.75,1123.27 1497.75,1123.33 1497.75,1123.4 1497.75,1123.46 1497.75,1123.52 1497.75,1123.58 1497.75,1123.64 1497.75,1123.7 1497.75,1123.77 1497.75,1123.83 1497.75,1123.89 1497.75,1123.95 1497.75,1124.01 1497.75,1124.07 1497.75,1124.14 1497.75,1124.2 1497.75,1124.26 1497.75,1124.32 1497.75,1124.38 1497.75,1124.44 1497.75,1124.5 1497.75,1124.57 1497.75,1124.63 1497.75,1124.69 1497.75,1124.75 1497.75,1124.81 1497.75,1124.87 1497.75,1124.94 1497.75,1125 1497.75,1125.06 1497.75,1125.12 1497.75,1125.18 1497.75,1125.24 1497.75,1125.31 1497.75,1125.37 1497.75,1125.43 1497.75,1125.49 1497.75,1125.55 1497.75,1125.61 1497.75,1125.68 1497.75,1125.74 1497.75,1125.8 1497.75,1125.86 1497.75,1125.92 1497.75,1125.98 1497.75,1126.05 1497.75,1126.11 1497.75,1126.17 1497.75,1126.23 1497.75,1126.29 1497.75,1126.35 1497.75,1126.42 1497.75,1126.48 1497.75,1126.54 1497.75,1126.6 1497.75,1126.66 1497.75,1126.72 1497.75,1126.78 1497.75,1126.85 1497.75,1126.91 1497.75,1126.97 1497.75,1127.03 1497.75,1127.09 1497.75,1127.15 1497.75,1127.22 1497.75,1127.28 1497.75,1127.34 1497.75,1127.4 1497.75,1127.46 1497.75,1127.52 1497.75,1127.59 1497.75,1127.65 1497.75,1127.71 1497.75,1127.77 1497.75,1127.83 1497.75,1127.89 1497.75,1127.95 1497.75,1128.02 1497.75,1128.08 1497.75,1128.14 1497.75,1128.2 1497.75,1128.26 1497.75,1128.32 1497.75,1128.39 1497.75,1128.45 1497.75,1128.51 1497.75,1128.57 1497.75,1128.63 1497.75,1128.69 1497.75,1128.76 1497.75,1128.82 1497.75,1128.88 1497.75,1128.94 1497.75,1129 1497.75,1129.06 1497.75,1129.12 1497.75,1129.19 1497.75,1129.25 1497.75,1129.31 1497.75,1129.37 1497.75,1129.43 1497.75,1129.49 1497.75,1129.56 1497.75,1129.62 1497.75,1129.68 1497.75,1129.74 1497.75,1129.8 1497.75,1129.86 1497.75,1129.92 1497.75,1129.99 1497.75,1130.05 1497.75,1130.11 1497.75,1130.17 1497.75,1130.23 1497.75,1130.29 1497.75,1130.36 1497.75,1130.42 1497.75,1130.48 1497.75,1130.54 1497.75,1130.6 1497.75,1130.66 1497.75,1130.72 1497.75,1130.79 1497.75,1130.85 1497.75,1130.91 1497.75,1130.97 1497.75,1131.03 1497.75,1131.09 1497.75,1131.15 1497.75,1131.22 1497.75,1131.28 1497.75,1131.34 1497.75,1131.4 1497.75,1131.46 1497.75,1131.52 1497.75,1131.59 1497.75,1131.65 1497.75,1131.71 1497.75,1131.77 1497.75,1131.83 1497.75,1131.89 1497.75,1131.95 1497.75,1132.02 1497.75,1132.08 1497.75,1132.14 1497.75,1132.2 1497.75,1132.26 1497.75,1132.32 1497.75,1132.38 1497.75,1132.45 1497.75,1132.51 1497.75,1132.57 1497.75,1132.63 1497.75,1132.69 1497.75,1132.75 1497.75,1132.81 1497.75,1132.88 1497.75,1132.94 1497.75,1133 1497.75,1133.06 1497.75,1133.12 1497.75,1133.18 1497.75,1133.24 1497.75,1133.31 1497.75,1133.37 1497.75,1133.43 1497.75,1133.49 1497.75,1133.55 1497.75,1133.61 1497.75,1133.67 1497.75,1133.74 1497.75,1133.8 1497.75,1133.86 1497.75,1133.92 1497.75,1133.98 1497.75,1134.04 1497.75,1134.1 1497.75,1134.17 1497.75,1134.23 1497.75,1134.29 1497.75,1134.35 1497.75,1134.41 1497.75,1134.47 1497.75,1134.53 1497.75,1134.6 1497.75,1134.66 1497.75,1134.72 1497.75,1134.78 1497.75,1134.84 1497.75,1134.9 1497.75,1134.96 1497.75,1135.03 1497.75,1135.09 1497.75,1135.15 1497.75,1135.21 1497.75,1135.27 1497.75,1135.33 1497.75,1135.39 1497.75,1135.46 1497.75,1135.52 1497.75,1135.58 1497.75,1135.64 1497.75,1135.7 1497.75,1135.76 1497.75,1135.82 1497.75,1135.88 1497.75,1135.95 1497.75,1136.01 1497.75,1136.07 1497.75,1136.13 1497.75,1136.19 1497.75,1136.25 1497.75,1136.31 1497.75,1136.38 1497.75,1136.44 1497.75,1136.5 1497.75,1136.56 1497.75,1136.62 1497.75,1136.68 1497.75,1136.74 1497.75,1136.8 1497.75,1136.87 1497.75,1136.93 1497.75,1136.99 1497.75,1137.05 1497.75,1137.11 1497.75,1137.17 1497.75,1137.23 1497.75,1137.3 1497.75,1137.36 1497.75,1137.42 1497.75,1137.48 1497.75,1137.54 1497.75,1137.6 1497.75,1137.66 1497.75,1137.72 1497.75,1137.79 1497.75,1137.85 1497.75,1137.91 1497.75,1137.97 1497.75,1138.03 1497.75,1138.09 1497.75,1138.15 1497.75,1138.21 1497.75,1138.28 1497.75,1138.34 1497.75,1138.4 1497.75,1138.46 1497.75,1138.52 1497.75,1138.58 1497.75,1138.64 1497.75,1138.7 1497.75,1138.77 1497.75,1138.83 1497.75,1138.89 1497.75,1138.95 1497.75,1139.01 1497.75,1139.07 1497.75,1139.13 1497.75,1139.19 1497.75,1139.26 1497.75,1139.32 1497.75,1139.38 1497.75,1139.44 1497.75,1139.5 1497.75,1139.56 1497.75,1139.62 1497.75,1139.68 1497.75,1139.75 1497.75,1139.81 1497.75,1139.87 1497.75,1139.93 1497.75,1139.99 1497.75,1140.05 1497.75,1140.11 1497.75,1140.17 1497.75,1140.24 1497.75,1140.3 1497.75,1140.36 1497.75,1140.42 1497.75,1140.48 1497.75,1140.54 1497.75,1140.6 1497.75,1140.66 1497.75,1140.73 1497.75,1140.79 1497.75,1140.85 1497.75,1140.91 1497.75,1140.97 1497.75,1141.03 1497.75,1141.09 1497.75,1141.15 1497.75,1141.21 1497.75,1141.28 1497.75,1141.34 1497.75,1141.4 1497.75,1141.46 1497.75,1141.52 1497.75,1141.58 1497.75,1141.64 1497.75,1141.7 1497.75,1141.76 1497.75,1141.83 1497.75,1141.89 1497.75,1141.95 1497.75,1142.01 1497.75,1142.07 1497.75,1142.13 1497.75,1142.19 1497.75,1142.25 1497.75,1142.31 1497.75,1142.38 1497.75,1142.44 1497.75,1142.5 1497.75,1142.56 1497.75,1142.62 1497.75,1142.68 1497.75,1142.74 1497.75,1142.8 1497.75,1142.86 1497.75,1142.93 1497.75,1142.99 1497.75,1143.05 1497.75,1143.11 1497.75,1143.17 1497.75,1143.23 1497.75,1143.29 1497.75,1143.35 1497.75,1143.41 1497.75,1143.48 1497.75,1143.54 1497.75,1143.6 1497.75,1143.66 1497.75,1143.72 1497.75,1143.78 1497.75,1143.84 1497.75,1143.9 1497.75,1143.96 1497.75,1144.02 1497.75,1144.09 1497.75,1144.15 1497.75,1144.21 1497.75,1144.27 1497.75,1144.33 1497.75,1144.39 1497.75,1144.45 1497.75,1144.51 1497.75,1144.57 1497.75,1144.63 1497.75,1144.7 1497.75,1144.76 1497.75,1144.82 1497.75,1144.88 1497.75,1144.94 1497.75,1145 1497.75,1145.06 1497.75,1145.12 1497.75,1145.18 1497.75,1145.24 1497.75,1145.31 1497.75,1145.37 1497.75,1145.43 1497.75,1145.49 1497.75,1145.55 1497.75,1145.61 1497.75,1145.67 1497.75,1145.73 1497.75,1145.79 1497.75,1145.85 1497.75,1145.92 1497.75,1145.98 1497.75,1146.04 1497.75,1146.1 1497.75,1146.16 1497.75,1146.22 1497.75,1146.28 1497.75,1146.34 1497.75,1146.4 1497.75,1146.46 1497.75,1146.52 1497.75,1146.59 1497.75,1146.65 1497.75,1146.71 1497.75,1146.77 1497.75,1146.83 1497.75,1146.89 1497.75,1146.95 1497.75,1147.01 1497.75,1147.07 1497.75,1147.13 1497.75,1147.19 1497.75,1147.26 1497.75,1147.32 1497.75,1147.38 1497.75,1147.44 1497.75,1147.5 1497.75,1147.56 1497.75,1147.62 1497.75,1147.68 1497.75,1147.74 1497.75,1147.8 1497.75,1147.86 1497.75,1147.92 1497.75,1147.99 1497.75,1148.05 1497.75,1148.11 1497.75,1148.17 1497.75,1148.23 1497.75,1148.29 1497.75,1148.35 1497.75,1148.41 1497.75,1148.47 1497.75,1148.53 1497.75,1148.59 1497.75,1148.65 1497.75,1148.72 1497.75,1148.78 1497.75,1148.84 1497.75,1148.9 1497.75,1148.96 1497.75,1149.02 1497.75,1149.08 1497.75,1149.14 1497.75,1149.2 1497.75,1149.26 1497.75,1149.32 1497.75,1149.38 1497.75,1149.44 1497.75,1149.51 1497.75,1149.57 1497.75,1149.63 1497.75,1149.69 1497.75,1149.75 1497.75,1149.81 1497.75,1149.87 1497.75,1149.93 1497.75,1149.99 1497.75,1150.05 1497.75,1150.11 1497.75,1150.17 1497.75,1150.23 1497.75,1150.3 1497.75,1150.36 1497.75,1150.42 1497.75,1150.48 1497.75,1150.54 1497.75,1150.6 1497.75,1150.66 1497.75,1150.72 1497.75,1150.78 1497.75,1150.84 1497.75,1150.9 1497.75,1150.96 1497.75,1151.02 1497.75,1151.08 1497.75,1151.14 1497.75,1151.21 1497.75,1151.27 1497.75,1151.33 1497.75,1151.39 1497.75,1151.45 1497.75,1151.51 1497.75,1151.57 1497.75,1151.63 1497.75,1151.69 1497.75,1151.75 1497.75,1151.81 1497.75,1151.87 1497.75,1151.93 1497.75,1151.99 1497.75,1152.05 1497.75,1152.11 1497.75,1152.18 1497.75,1152.24 1497.75,1152.3 1497.75,1152.36 1497.75,1152.42 1497.75,1152.48 1497.75,1152.54 1497.75,1152.6 1497.75,1152.66 1497.75,1152.72 1497.75,1152.78 1497.75,1152.84 1497.75,1152.9 1497.75,1152.96 1497.75,1153.02 1497.75,1153.08 1497.75,1153.14 1497.75,1153.21 1497.75,1153.27 1497.75,1153.33 1497.75,1153.39 1497.75,1153.45 1497.75,1153.51 1497.75,1153.57 1497.75,1153.63 1497.75,1153.69 1497.75,1153.75 1497.75,1153.81 1497.75,1153.87 1497.75,1153.93 1497.75,1153.99 1497.75,1154.05 1497.75,1154.11 1497.75,1154.17 1497.75,1154.23 1497.75,1154.29 1497.75,1154.36 1497.75,1154.42 1497.75,1154.48 1497.75,1154.54 1497.75,1154.6 1497.75,1154.66 1497.75,1154.72 1497.75,1154.78 1497.75,1154.84 1497.75,1154.9 1497.75,1154.96 1497.75,1155.02 1497.75,1155.08 1497.75,1155.14 1497.75,1155.2 1497.75,1155.26 1497.75,1155.32 1497.75,1155.38 1497.75,1155.44 1497.75,1155.5 1497.75,1155.56 1497.75,1155.62 1497.75,1155.68 1497.75,1155.75 1497.75,1155.81 1497.75,1155.87 1497.75,1155.93 1497.75,1155.99 1497.75,1156.05 1497.75,1156.11 1497.75,1156.17 1497.75,1156.23 1497.75,1156.29 1497.75,1156.35 1497.75,1156.41 1497.75,1156.47 1497.75,1156.53 1497.75,1156.59 1497.75,1156.65 1497.75,1156.71 1497.75,1156.77 1497.75,1156.83 1497.75,1156.89 1497.75,1156.95 1497.75,1157.01 1497.75,1157.07 1497.75,1157.13 1497.75,1157.19 1497.75,1157.25 1497.75,1157.31 1497.75,1157.37 1497.75,1157.43 1497.75,1157.49 1497.75,1157.55 1497.75,1157.62 1497.75,1157.68 1497.75,1157.74 1497.75,1157.8 1497.75,1157.86 1497.75,1157.92 1497.75,1157.98 1497.75,1158.04 1497.75,1158.1 1497.75,1158.16 1497.75,1158.22 1497.75,1158.28 1497.75,1158.34 1497.75,1158.4 1497.75,1158.46 1497.75,1158.52 1497.75,1158.58 1497.75,1158.64 1497.75,1158.7 1497.75,1158.76 1497.75,1158.82 1497.75,1158.88 1497.75,1158.94 1497.75,1159 1497.75,1159.06 1497.75,1159.12 1497.75,1159.18 1497.75,1159.24 1497.75,1159.3 1497.75,1159.36 1497.75,1159.42 1497.75,1159.48 1497.75,1159.54 1497.75,1159.6 1497.75,1159.66 1497.75,1159.72 1497.75,1159.78 1497.75,1159.84 1497.75,1159.9 1497.75,1159.96 1497.75,1160.02 1497.75,1160.08 1497.75,1160.14 1497.75,1160.2 1497.75,1160.26 1497.75,1160.32 1497.75,1160.38 1497.75,1160.44 1497.75,1160.5 1497.75,1160.56 1497.75,1160.62 1497.75,1160.68 1497.75,1160.74 1497.75,1160.8 1497.75,1160.86 1497.75,1160.92 1497.75,1160.98 1497.75,1161.04 1497.75,1161.1 1497.75,1161.16 1497.75,1161.22 1497.75,1161.28 1497.75,1161.34 1497.75,1161.4 1497.75,1161.46 1497.75,1161.52 1497.75,1161.58 1497.75,1161.64 1497.75,1161.7 1497.75,1161.76 1497.75,1161.82 1497.75,1161.88 1497.75,1161.94 1497.75,1162 1497.75,1162.06 1497.75,1162.12 1497.75,1162.18 1497.75,1162.24 1497.75,1162.3 1497.75,1162.36 1497.75,1162.42 1497.75,1162.48 1497.75,1162.54 1497.75,1162.6 1497.75,1162.66 1497.75,1162.72 1497.75,1162.78 1497.75,1162.84 1497.75,1162.9 1497.75,1162.96 1497.75,1163.02 1497.75,1163.08 1497.75,1163.14 1497.75,1163.2 1497.75,1163.26 1497.75,1163.32 1497.75,1163.38 1497.75,1163.44 1497.75,1163.5 1497.75,1163.56 1497.75,1163.62 1497.75,1163.68 1497.75,1163.74 1497.75,1163.8 1497.75,1163.86 1497.75,1163.92 1497.75,1163.98 1497.75,1164.04 1497.75,1164.1 1497.75,1164.16 1497.75,1164.22 1497.75,1164.28 1497.75,1164.34 1497.75,1164.4 1497.75,1164.46 1497.75,1164.52 1497.75,1164.58 1497.75,1164.64 1497.75,1164.7 1497.75,1164.76 1497.75,1164.82 1497.75,1164.88 1497.75,1164.94 1497.75,1165 1497.75,1165.06 1497.75,1165.12 1497.75,1165.18 1497.75,1165.24 1497.75,1165.29 1497.75,1165.35 1497.75,1165.41 1497.75,1165.47 1497.75,1165.53 1497.75,1165.59 1497.75,1165.65 1497.75,1165.71 1497.75,1165.77 1497.75,1165.83 1497.75,1165.89 1497.75,1165.95 1497.75,1166.01 1497.75,1166.07 1497.75,1166.13 1497.75,1166.19 1497.75,1166.25 1497.75,1166.31 1497.75,1166.37 1497.75,1166.43 1497.75,1166.49 1497.75,1166.55 1497.75,1166.61 1497.75,1166.67 1497.75,1166.73 1497.75,1166.79 1497.75,1166.85 1497.75,1166.91 1497.75,1166.96 1497.75,1167.02 1497.75,1167.08 1497.75,1167.14 1497.75,1167.2 1497.75,1167.26 1497.75,1167.32 1497.75,1167.38 1497.75,1167.44 1497.75,1167.5 1497.75,1167.56 1497.75,1167.62 1497.75,1167.68 1497.75,1167.74 1497.75,1167.8 1497.75,1167.86 1497.75,1167.92 1497.75,1167.98 1497.75,1168.04 1497.75,1168.1 1497.75,1168.16 1497.75,1168.22 1497.75,1168.27 1497.75,1168.33 1497.75,1168.39 1497.75,1168.45 1497.75,1168.51 1497.75,1168.57 1497.75,1168.63 1497.75,1168.69 1497.75,1168.75 1497.75,1168.81 1497.75,1168.87 1497.75,1168.93 1497.75,1168.99 1497.75,1169.05 1497.75,1169.11 1497.75,1169.17 1497.75,1169.23 1497.75,1169.28 1497.75,1169.34 1497.75,1169.4 1497.75,1169.46 1497.75,1169.52 1497.75,1169.58 1497.75,1169.64 1497.75,1169.7 1497.75,1169.76 1497.75,1169.82 1497.75,1169.88 1497.75,1169.94 1497.75,1170 1497.75,1170.06 1497.75,1170.12 1497.75,1170.18 1497.75,1170.23 1497.75,1170.29 1497.75,1170.35 1497.75,1170.41 1497.75,1170.47 1497.75,1170.53 1497.75,1170.59 1497.75,1170.65 1497.75,1170.71 1497.75,1170.77 1497.75,1170.83 1497.75,1170.89 1497.75,1170.95 1497.75,1171.01 1497.75,1171.06 1497.75,1171.12 1497.75,1171.18 1497.75,1171.24 1497.75,1171.3 1497.75,1171.36 1497.75,1171.42 1497.75,1171.48 1497.75,1171.54 1497.75,1171.6 1497.75,1171.66 1497.75,1171.72 1497.75,1171.77 1497.75,1171.83 1497.75,1171.89 1497.75,1171.95 1497.75,1172.01 1497.75,1172.07 1497.75,1172.13 1497.75,1172.19 1497.75,1172.25 1497.75,1172.31 1497.75,1172.37 1497.75,1172.43 1497.75,1172.48 1497.75,1172.54 1497.75,1172.6 1497.75,1172.66 1497.75,1172.72 1497.75,1172.78 1497.75,1172.84 1497.75,1172.9 1497.75,1172.96 1497.75,1173.02 1497.75,1173.08 1497.75,1173.13 1497.75,1173.19 1497.75,1173.25 1497.75,1173.31 1497.75,1173.37 1497.75,1173.43 1497.75,1173.49 1497.75,1173.55 1497.75,1173.61 1497.75,1173.67 1497.75,1173.72 1497.75,1173.78 1497.75,1173.84 1497.75,1173.9 1497.75,1173.96 1497.75,1174.02 1497.75,1174.08 1497.75,1174.14 1497.75,1174.2 1497.75,1174.26 1497.75,1174.31 1497.75,1174.37 1497.75,1174.43 1497.75,1174.49 1497.75,1174.55 1497.75,1174.61 1497.75,1174.67 1497.75,1174.73 1497.75,1174.79 1497.75,1174.84 1497.75,1174.9 1497.75,1174.96 1497.75,1175.02 1497.75,1175.08 1497.75,1175.14 1497.75,1175.2 1497.75,1175.26 1497.75,1175.32 1497.75,1175.37 1497.75,1175.43 1497.75,1175.49 1497.75,1175.55 1497.75,1175.61 1497.75,1175.67 1497.75,1175.73 1497.75,1175.79 1497.75,1175.85 1497.75,1175.9 1497.75,1175.96 1497.75,1176.02 1497.75,1176.08 1497.75,1176.14 1497.75,1176.2 1497.75,1176.26 1497.75,1176.32 1497.75,1176.37 1497.75,1176.43 1497.75,1176.49 1497.75,1176.55 1497.75,1176.61 1497.75,1176.67 1497.75,1176.73 1497.75,1176.79 1497.75,1176.84 1497.75,1176.9 1497.75,1176.96 1497.75,1177.02 1497.75,1177.08 1497.75,1177.14 1497.75,1177.2 1497.75,1177.26 1497.75,1177.31 1497.75,1177.37 1497.75,1177.43 1497.75,1177.49 1497.75,1177.55 1497.75,1177.61 1497.75,1177.67 1497.75,1177.72 1497.75,1177.78 1497.75,1177.84 1497.75,1177.9 1497.75,1177.96 1497.75,1178.02 1497.75,1178.08 1497.75,1178.13 1497.75,1178.19 1497.75,1178.25 1497.75,1178.31 1497.75,1178.37 1497.75,1178.43 1497.75,1178.49 1497.75,1178.54 1497.75,1178.6 1497.75,1178.66 1497.75,1178.72 1497.75,1178.78 1497.75,1178.84 1497.75,1178.9 1497.75,1178.95 1497.75,1179.01 1497.75,1179.07 1497.75,1179.13 1497.75,1179.19 1497.75,1179.25 1497.75,1179.31 1497.75,1179.36 1497.75,1179.42 1497.75,1179.48 1497.75,1179.54 1497.75,1179.6 1497.75,1179.66 1497.75,1179.71 1497.75,1179.77 1497.75,1179.83 1497.75,1179.89 1497.75,1179.95 1497.75,1180.01 1497.75,1180.06 1497.75,1180.12 1497.75,1180.18 1497.75,1180.24 1497.75,1180.3 1497.75,1180.36 1497.75,1180.42 1497.75,1180.47 1497.75,1180.53 1497.75,1180.59 1497.75,1180.65 1497.75,1180.71 1497.75,1180.77 1497.75,1180.82 1497.75,1180.88 1497.75,1180.94 1497.75,1181 1497.75,1181.06 1497.75,1181.12 1497.75,1181.17 1497.75,1181.23 1497.75,1181.29 1497.75,1181.35 1497.75,1181.41 1497.75,1181.46 1497.75,1181.52 1497.75,1181.58 1497.75,1181.64 1497.75,1181.7 1497.75,1181.76 1497.75,1181.81 1497.75,1181.87 1497.75,1181.93 1497.75,1181.99 1497.75,1182.05 1497.75,1182.11 1497.75,1182.16 1497.75,1182.22 1497.75,1182.28 1497.75,1182.34 1497.75,1182.4 1497.75,1182.45 1497.75,1182.51 1497.75,1182.57 1497.75,1182.63 1497.75,1182.69 1497.75,1182.74 1497.75,1182.8 1497.75,1182.86 1497.75,1182.92 1497.75,1182.98 1497.75,1183.04 1497.75,1183.09 1497.75,1183.15 1497.75,1183.21 1497.75,1183.27 1497.75,1183.33 1497.75,1183.38 1497.75,1183.44 1497.75,1183.5 1497.75,1183.56 1497.75,1183.62 1497.75,1183.67 1497.75,1183.73 1497.75,1183.79 1497.75,1183.85 1497.75,1183.91 1497.75,1183.96 1497.75,1184.02 1497.75,1184.08 1497.75,1184.14 1497.75,1184.2 1497.75,1184.25 1497.75,1184.31 1497.75,1184.37 1497.75,1184.43 1497.75,1184.49 1497.75,1184.54 1497.75,1184.6 1497.75,1184.66 1497.75,1184.72 1497.75,1184.78 1497.75,1184.83 1497.75,1184.89 1497.75,1184.95 1497.75,1185.01 1497.75,1185.07 1497.75,1185.12 1497.75,1185.18 1497.75,1185.24 1497.75,1185.3 1497.75,1185.35 1497.75,1185.41 1497.75,1185.47 1497.75,1185.53 1497.75,1185.59 1497.75,1185.64 1497.75,1185.7 1497.75,1185.76 1497.75,1185.82 1497.75,1185.87 1497.75,1185.93 1497.75,1185.99 1497.75,1186.05 1497.75,1186.11 1497.75,1186.16 1497.75,1186.22 1497.75,1186.28 1497.75,1186.34 1497.75,1186.39 1497.75,1186.45 1497.75,1186.51 1497.75,1186.57 1497.75,1186.63 1497.75,1186.68 1497.75,1186.74 1497.75,1186.8 1497.75,1186.86 1497.75,1186.91 1497.75,1186.97 1497.75,1187.03 1497.75,1187.09 1497.75,1187.14 1497.75,1187.2 1497.75,1187.26 1497.75,1187.32 1497.75,1187.38 1497.75,1187.43 1497.75,1187.49 1497.75,1187.55 1497.75,1187.61 1497.75,1187.66 1497.75,1187.72 1497.75,1187.78 1497.75,1187.84 1497.75,1187.89 1497.75,1187.95 1497.75,1188.01 1497.75,1188.07 1497.75,1188.12 1497.75,1188.18 1497.75,1188.24 1497.75,1188.3 1497.75,1188.35 1497.75,1188.41 1497.75,1188.47 1497.75,1188.53 1497.75,1188.58 1497.75,1188.64 1497.75,1188.7 1497.75,1188.76 1497.75,1188.81 1497.75,1188.87 1497.75,1188.93 1497.75,1188.99 1497.75,1189.04 1497.75,1189.1 1497.75,1189.16 1497.75,1189.22 1497.75,1189.27 1497.75,1189.33 1497.75,1189.39 1497.75,1189.45 1497.75,1189.5 1497.75,1189.56 1497.75,1189.62 1497.75,1189.68 1497.75,1189.73 1497.75,1189.79 1497.75,1189.85 1497.75,1189.9 1497.75,1189.96 1497.75,1190.02 1497.75,1190.08 1497.75,1190.13 1497.75,1190.19 1497.75,1190.25 1497.75,1190.31 1497.75,1190.36 1497.75,1190.42 1497.75,1190.48 1497.75,1190.54 1497.75,1190.59 1497.75,1190.65 1497.75,1190.71 1497.75,1190.76 1497.75,1190.82 1497.75,1190.88 1497.75,1190.94 1497.75,1190.99 1497.75,1191.05 1497.75,1191.11 1497.75,1191.17 1497.75,1191.22 1497.75,1191.28 1497.75,1191.34 1497.75,1191.39 1497.75,1191.45 1497.75,1191.51 1497.75,1191.57 1497.75,1191.62 1497.75,1191.68 1497.75,1191.74 1497.75,1191.79 1497.75,1191.85 1497.75,1191.91 1497.75,1191.97 1497.75,1192.02 1497.75,1192.08 1497.75,1192.14 1497.75,1192.19 1497.75,1192.25 1497.75,1192.31 1497.75,1192.36 1497.75,1192.42 1497.75,1192.48 1497.75,1192.54 1497.75,1192.59 1497.75,1192.65 1497.75,1192.71 1497.75,1192.76 1497.75,1192.82 1497.75,1192.88 1497.75,1192.94 1497.75,1192.99 1497.75,1193.05 1497.75,1193.11 1497.75,1193.16 1497.75,1193.22 1497.75,1193.28 1497.75,1193.33 1497.75,1193.39 1497.75,1193.45 1497.75,1193.5 1497.75,1193.56 1497.75,1193.62 1497.75,1193.68 1497.75,1193.73 1497.75,1193.79 1497.75,1193.85 1497.75,1193.9 1497.75,1193.96 1497.75,1194.02 1497.75,1194.07 1497.75,1194.13 1497.75,1194.19 1497.75,1194.24 1497.75,1194.3 1497.75,1194.36 1497.75,1194.41 1497.75,1194.47 1497.75,1194.53 1497.75,1194.59 1497.75,1194.64 1497.75,1194.7 1497.75,1194.76 1497.75,1194.81 1497.75,1194.87 1497.75,1194.93 1497.75,1194.98 1497.75,1195.04 1497.75,1195.1 1497.75,1195.15 1497.75,1195.21 1497.75,1195.27 1497.75,1195.32 1497.75,1195.38 1497.75,1195.44 1497.75,1195.49 1497.75,1195.55 1497.75,1195.61 1497.75,1195.66 1497.75,1195.72 1497.75,1195.78 1497.75,1195.83 1497.75,1195.89 1497.75,1195.95 1497.75,1196 1497.75,1196.06 1497.75,1196.12 1497.75,1196.17 1497.75,1196.23 1497.75,1196.29 1497.75,1196.34 1497.75,1196.4 1497.75,1196.46 1497.75,1196.51 1497.75,1196.57 1497.75,1196.63 1497.75,1196.68 1497.75,1196.74 1497.75,1196.79 1497.75,1196.85 1497.75,1196.91 1497.75,1196.96 1497.75,1197.02 1497.75,1197.08 1497.75,1197.13 1497.75,1197.19 1497.75,1197.25 1497.75,1197.3 1497.75,1197.36 1497.75,1197.42 1497.75,1197.47 1497.75,1197.53 1497.75,1197.59 1497.75,1197.64 1497.75,1197.7 1497.75,1197.75 1497.75,1197.81 1497.75,1197.87 1497.75,1197.92 1497.75,1197.98 1497.75,1198.04 1497.75,1198.09 1497.75,1198.15 1497.75,1198.21 1497.75,1198.26 1497.75,1198.32 1497.75,1198.37 1497.75,1198.43 1497.75,1198.49 1497.75,1198.54 1497.75,1198.6 1497.75,1198.66 1497.75,1198.71 1497.75,1198.77 1497.75,1198.83 1497.75,1198.88 1497.75,1198.94 1497.75,1198.99 1497.75,1199.05 1497.75,1199.11 1497.75,1199.16 1497.75,1199.22 1497.75,1199.28 1497.75,1199.33 1497.75,1199.39 1497.75,1199.44 1497.75,1199.5 1497.75,1199.56 1497.75,1199.61 1497.75,1199.67 1497.75,1199.72 1497.75,1199.78 1497.75,1199.84 1497.75,1199.89 1497.75,1199.95 1497.75,1200.01 1497.75,1200.06 1497.75,1200.12 1497.75,1200.17 1497.75,1200.23 1497.75,1200.29 1497.75,1200.34 1497.75,1200.4 1497.75,1200.45 1497.75,1200.51 1497.75,1200.57 1497.75,1200.62 1497.75,1200.68 1497.75,1200.73 1497.75,1200.79 1497.75,1200.85 1497.75,1200.9 1497.75,1200.96 1497.75,1201.01 1497.75,1201.07 1497.75,1201.13 1497.75,1201.18 1497.75,1201.24 1497.75,1201.29 1497.75,1201.35 1497.75,1201.41 1497.75,1201.46 1497.75,1201.52 1497.75,1201.57 1497.75,1201.63 1497.75,1201.69 1497.75,1201.74 1497.75,1201.8 1497.75,1201.85 1497.75,1201.91 1497.75,1201.97 1497.75,1202.02 1497.75,1202.08 1497.75,1202.13 1497.75,1202.19 1497.75,1202.24 1497.75,1202.3 1497.75,1202.36 1497.75,1202.41 1497.75,1202.47 1497.75,1202.52 1497.75,1202.58 1497.75,1202.64 1497.75,1202.69 1497.75,1202.75 1497.75,1202.8 1497.75,1202.86 1497.75,1202.91 1497.75,1202.97 1497.75,1203.03 1497.75,1203.08 1497.75,1203.14 1497.75,1203.19 1497.75,1203.25 1497.75,1203.3 1497.75,1203.36 1497.75,1203.42 1497.75,1203.47 1497.75,1203.53 1497.75,1203.58 1497.75,1203.64 1497.75,1203.69 1497.75,1203.75 1497.75,1203.8 1497.75,1203.86 1497.75,1203.92 1497.75,1203.97 1497.75,1204.03 1497.75,1204.08 1497.75,1204.14 1497.75,1204.19 1497.75,1204.25 1497.75,1204.31 1497.75,1204.36 1497.75,1204.42 1497.75,1204.47 1497.75,1204.53 1497.75,1204.58 1497.75,1204.64 1497.75,1204.69 1497.75,1204.75 1497.75,1204.8 1497.75,1204.86 1497.75,1204.92 1497.75,1204.97 1497.75,1205.03 1497.75,1205.08 1497.75,1205.14 1497.75,1205.19 1497.75,1205.25 1497.75,1205.3 1497.75,1205.36 1497.75,1205.41 1497.75,1205.47 1497.75,1205.53 1497.75,1205.58 1497.75,1205.64 1497.75,1205.69 1497.75,1205.75 1497.75,1205.8 1497.75,1205.86 1497.75,1205.91 1497.75,1205.97 1497.75,1206.02 1497.75,1206.08 1497.75,1206.13 1497.75,1206.19 1497.75,1206.24 1497.75,1206.3 1497.75,1206.36 1497.75,1206.41 1497.75,1206.47 1497.75,1206.52 1497.75,1206.58 1497.75,1206.63 1497.75,1206.69 1497.75,1206.74 1497.75,1206.8 1497.75,1206.85 1497.75,1206.91 1497.75,1206.96 1497.75,1207.02 1497.75,1207.07 1497.75,1207.13 1497.75,1207.18 1497.75,1207.24 1497.75,1207.29 1497.75,1207.35 1497.75,1207.4 1497.75,1207.46 1497.75,1207.51 1497.75,1207.57 1497.75,1207.62 1497.75,1207.68 1497.75,1207.73 1497.75,1207.79 1497.75,1207.85 1497.75,1207.9 1497.75,1207.96 1497.75,1208.01 1497.75,1208.07 1497.75,1208.12 1497.75,1208.18 1497.75,1208.23 1497.75,1208.29 1497.75,1208.34 1497.75,1208.4 1497.75,1208.45 1497.75,1208.51 1497.75,1208.56 1497.75,1208.62 1497.75,1208.67 1497.75,1208.73 1497.75,1208.78 1497.75,1208.84 1497.75,1208.89 1497.75,1208.94 1497.75,1209 1497.75,1209.05 1497.75,1209.11 1497.75,1209.16 1497.75,1209.22 1497.75,1209.27 1497.75,1209.33 1497.75,1209.38 1497.75,1209.44 1497.75,1209.49 1497.75,1209.55 1497.75,1209.6 1497.75,1209.66 1497.75,1209.71 1497.75,1209.77 1497.75,1209.82 1497.75,1209.88 1497.75,1209.93 1497.75,1209.99 1497.75,1210.04 1497.75,1210.1 1497.75,1210.15 1497.75,1210.21 1497.75,1210.26 1497.75,1210.32 1497.75,1210.37 1497.75,1210.42 1497.75,1210.48 1497.75,1210.53 1497.75,1210.59 1497.75,1210.64 1497.75,1210.7 1497.75,1210.75 1497.75,1210.81 1497.75,1210.86 1497.75,1210.92 1497.75,1210.97 1497.75,1211.03 1497.75,1211.08 1497.75,1211.14 1497.75,1211.19 1497.75,1211.24 1497.75,1211.3 1497.75,1211.35 1497.75,1211.41 1497.75,1211.46 1497.75,1211.52 1497.75,1211.57 1497.75,1211.63 1497.75,1211.68 1497.75,1211.74 1497.75,1211.79 1497.75,1211.84 1497.75,1211.9 1497.75,1211.95 1497.75,1212.01 1497.75,1212.06 1497.75,1212.12 1497.75,1212.17 1497.75,1212.23 1497.75,1212.28 1497.75,1212.33 1497.75,1212.39 1497.75,1212.44 1497.75,1212.5 1497.75,1212.55 1497.75,1212.61 1497.75,1212.66 1497.75,1212.72 1497.75,1212.77 1497.75,1212.82 1497.75,1212.88 1497.75,1212.93 1497.75,1212.99 1497.75,1213.04 1497.75,1213.1 1497.75,1213.15 1497.75,1213.2 1497.75,1213.26 1497.75,1213.31 1497.75,1213.37 1497.75,1213.42 1497.75,1213.48 1497.75,1213.53 1497.75,1213.58 1497.75,1213.64 1497.75,1213.69 1497.75,1213.75 1497.75,1213.8 1497.75,1213.86 1497.75,1213.91 1497.75,1213.96 1497.75,1214.02 1497.75,1214.07 1497.75,1214.13 1497.75,1214.18 1497.75,1214.23 1497.75,1214.29 1497.75,1214.34 1497.75,1214.4 1497.75,1214.45 1497.75,1214.51 1497.75,1214.56 1497.75,1214.61 1497.75,1214.67 1497.75,1214.72 1497.75,1214.78 1497.75,1214.83 1497.75,1214.88 1497.75,1214.94 1497.75,1214.99 1497.75,1215.05 1497.75,1215.1 1497.75,1215.15 1497.75,1215.21 1497.75,1215.26 1497.75,1215.32 1497.75,1215.37 1497.75,1215.42 1497.75,1215.48 1497.75,1215.53 1497.75,1215.59 1497.75,1215.64 1497.75,1215.69 1497.75,1215.75 1497.75,1215.8 1497.75,1215.86 1497.75,1215.91 1497.75,1215.96 1497.75,1216.02 1497.75,1216.07 1497.75,1216.12 1497.75,1216.18 1497.75,1216.23 1497.75,1216.29 1497.75,1216.34 1497.75,1216.39 1497.75,1216.45 1497.75,1216.5 1497.75,1216.56 1497.75,1216.61 1497.75,1216.66 1497.75,1216.72 1497.75,1216.77 1497.75,1216.82 1497.75,1216.88 1497.75,1216.93 1497.75,1216.99 1497.75,1217.04 1497.75,1217.09 1497.75,1217.15 1497.75,1217.2 1497.75,1217.25 1497.75,1217.31 1497.75,1217.36 1497.75,1217.42 1497.75,1217.47 1497.75,1217.52 1497.75,1217.58 1497.75,1217.63 1497.75,1217.68 1497.75,1217.74 1497.75,1217.79 1497.75,1217.84 1497.75,1217.9 1497.75,1217.95 1497.75,1218.01 1497.75,1218.06 1497.75,1218.11 1497.75,1218.17 1497.75,1218.22 1497.75,1218.27 1497.75,1218.33 1497.75,1218.38 1497.75,1218.43 1497.75,1218.49 1497.75,1218.54 1497.75,1218.59 1497.75,1218.65 1497.75,1218.7 1497.75,1218.75 1497.75,1218.81 1497.75,1218.86 1497.75,1218.91 1497.75,1218.97 1497.75,1219.02 1497.75,1219.08 1497.75,1219.13 1497.75,1219.18 1497.75,1219.24 1497.75,1219.29 1497.75,1219.34 1497.75,1219.4 1497.75,1219.45 1497.75,1219.5 1497.75,1219.56 1497.75,1219.61 1497.75,1219.66 1497.75,1219.72 1497.75,1219.77 1497.75,1219.82 1497.75,1219.88 1497.75,1219.93 1497.75,1219.98 1497.75,1220.04 1497.75,1220.09 1497.75,1220.14 1497.75,1220.19 1497.75,1220.25 1497.75,1220.3 1497.75,1220.35 1497.75,1220.41 1497.75,1220.46 1497.75,1220.51 1497.75,1220.57 1497.75,1220.62 1497.75,1220.67 1497.75,1220.73 1497.75,1220.78 1497.75,1220.83 1497.75,1220.89 1497.75,1220.94 1497.75,1220.99 1497.75,1221.05 1497.75,1221.1 1497.75,1221.15 1497.75,1221.2 1497.75,1221.26 1497.75,1221.31 1497.75,1221.36 1497.75,1221.42 1497.75,1221.47 1497.75,1221.52 1497.75,1221.58 1497.75,1221.63 1497.75,1221.68 1497.75,1221.74 1497.75,1221.79 1497.75,1221.84 1497.75,1221.89 1497.75,1221.95 1497.75,1222 1497.75,1222.05 1497.75,1222.11 1497.75,1222.16 1497.75,1222.21 1497.75,1222.26 1497.75,1222.32 1497.75,1222.37 1497.75,1222.42 1497.75,1222.48 1497.75,1222.53 1497.75,1222.58 1497.75,1222.63 1497.75,1222.69 1497.75,1222.74 1497.75,1222.79 1497.75,1222.85 1497.75,1222.9 1497.75,1222.95 1497.75,1223 1497.75,1223.06 1497.75,1223.11 1497.75,1223.16 1497.75,1223.22 1497.75,1223.27 1497.75,1223.32 1497.75,1223.37 1497.75,1223.43 1497.75,1223.48 1497.75,1223.53 1497.75,1223.58 1497.75,1223.64 1497.75,1223.69 1497.75,1223.74 1497.75,1223.8 1497.75,1223.85 1497.75,1223.9 1497.75,1223.95 1497.75,1224.01 1497.75,1224.06 1497.75,1224.11 1497.75,1224.16 1497.75,1224.22 1497.75,1224.27 1497.75,1224.32 1497.75,1224.37 1497.75,1224.43 1497.75,1224.48 1497.75,1224.53 1497.75,1224.58 1497.75,1224.64 1497.75,1224.69 1497.75,1224.74 1497.75,1224.79 1497.75,1224.85 1497.75,1224.9 1497.75,1224.95 1497.75,1225 1497.75,1225.06 1497.75,1225.11 1497.75,1225.16 1497.75,1225.21 1497.75,1225.27 1497.75,1225.32 1497.75,1225.37 1497.75,1225.42 1497.75,1225.48 1497.75,1225.53 1497.75,1225.58 1497.75,1225.63 1497.75,1225.69 1497.75,1225.74 1497.75,1225.79 1497.75,1225.84 1497.75,1225.89 1497.75,1225.95 1497.75,1226 1497.75,1226.05 1497.75,1226.1 1497.75,1226.16 1497.75,1226.21 1497.75,1226.26 1497.75,1226.31 1497.75,1226.37 1497.75,1226.42 1497.75,1226.47 1497.75,1226.52 1497.75,1226.57 1497.75,1226.63 1497.75,1226.68 1497.75,1226.73 1497.75,1226.78 1497.75,1226.84 1497.75,1226.89 1497.75,1226.94 1497.75,1226.99 1497.75,1227.04 1497.75,1227.1 1497.75,1227.15 1497.75,1227.2 1497.75,1227.25 1497.75,1227.3 1497.75,1227.36 1497.75,1227.41 1497.75,1227.46 1497.75,1227.51 1497.75,1227.56 1497.75,1227.62 1497.75,1227.67 1497.75,1227.72 1497.75,1227.77 1497.75,1227.82 1497.75,1227.88 1497.75,1227.93 1497.75,1227.98 1497.75,1228.03 1497.75,1228.08 1497.75,1228.14 1497.75,1228.19 1497.75,1228.24 1497.75,1228.29 1497.75,1228.34 1497.75,1228.4 1497.75,1228.45 1497.75,1228.5 1497.75,1228.55 1497.75,1228.6 1497.75,1228.66 1497.75,1228.71 1497.75,1228.76 1497.75,1228.81 1497.75,1228.86 1497.75,1228.91 1497.75,1228.97 1497.75,1229.02 1497.75,1229.07 1497.75,1229.12 1497.75,1229.17 1497.75,1229.23 1497.75,1229.28 1497.75,1229.33 1497.75,1229.38 1497.75,1229.43 1497.75,1229.48 1497.75,1229.54 1497.75,1229.59 1497.75,1229.64 1497.75,1229.69 1497.75,1229.74 1497.75,1229.79 1497.75,1229.85 1497.75,1229.9 1497.75,1229.95 1497.75,1230 1497.75,1230.05 1497.75,1230.1 1497.75,1230.16 1497.75,1230.21 1497.75,1230.26 1497.75,1230.31 1497.75,1230.36 1497.75,1230.41 1497.75,1230.47 1497.75,1230.52 1497.75,1230.57 1497.75,1230.62 1497.75,1230.67 1497.75,1230.72 1497.75,1230.77 1497.75,1230.83 1497.75,1230.88 1497.75,1230.93 1497.75,1230.98 1497.75,1231.03 1497.75,1231.08 1497.75,1231.13 1497.75,1231.19 1497.75,1231.24 1497.75,1231.29 1497.75,1231.34 1497.75,1231.39 1497.75,1231.44 1497.75,1231.49 1497.75,1231.55 1497.75,1231.6 1497.75,1231.65 1497.75,1231.7 1497.75,1231.75 1497.75,1231.8 1497.75,1231.85 1497.75,1231.91 1497.75,1231.96 1497.75,1232.01 1497.75,1232.06 1497.75,1232.11 1497.75,1232.16 1497.75,1232.21 1497.75,1232.26 1497.75,1232.32 1497.75,1232.37 1497.75,1232.42 1497.75,1232.47 1497.75,1232.52 1497.75,1232.57 1497.75,1232.62 1497.75,1232.67 1497.75,1232.72 1497.75,1232.78 1497.75,1232.83 1497.75,1232.88 1497.75,1232.93 1497.75,1232.98 1497.75,1233.03 1497.75,1233.08 1497.75,1233.13 1497.75,1233.18 1497.75,1233.24 1497.75,1233.29 1497.75,1233.34 1497.75,1233.39 1497.75,1233.44 1497.75,1233.49 1497.75,1233.54 1497.75,1233.59 1497.75,1233.64 1497.75,1233.7 1497.75,1233.75 1497.75,1233.8 1497.75,1233.85 1497.75,1233.9 1497.75,1233.95 1497.75,1234 1497.75,1234.05 1497.75,1234.1 1497.75,1234.15 1497.75,1234.2 1497.75,1234.26 1497.75,1234.31 1497.75,1234.36 1497.75,1234.41 1497.75,1234.46 1497.75,1234.51 1497.75,1234.56 1497.75,1234.61 1497.75,1234.66 1497.75,1234.71 1497.75,1234.76 1497.75,1234.81 1497.75,1234.87 1497.75,1234.92 1497.75,1234.97 1497.75,1235.02 1497.75,1235.07 1497.75,1235.12 1497.75,1235.17 1497.75,1235.22 1497.75,1235.27 1497.75,1235.32 1497.75,1235.37 1497.75,1235.42 1497.75,1235.47 1497.75,1235.52 1497.75,1235.58 1497.75,1235.63 1497.75,1235.68 1497.75,1235.73 1497.75,1235.78 1497.75,1235.83 1497.75,1235.88 1497.75,1235.93 1497.75,1235.98 1497.75,1236.03 1497.75,1236.08 1497.75,1236.13 1497.75,1236.18 1497.75,1236.23 1497.75,1236.28 1497.75,1236.33 1497.75,1236.38 1497.75,1236.44 1497.75,1236.49 1497.75,1236.54 1497.75,1236.59 1497.75,1236.64 1497.75,1236.69 1497.75,1236.74 1497.75,1236.79 1497.75,1236.84 1497.75,1236.89 1497.75,1236.94 1497.75,1236.99 1497.75,1237.04 1497.75,1237.09 1497.75,1237.14 1497.75,1237.19 1497.75,1237.24 1497.75,1237.29 1497.75,1237.34 1497.75,1237.39 1497.75,1237.44 1497.75,1237.49 1497.75,1237.54 1497.75,1237.59 1497.75,1237.64 1497.75,1237.7 1497.75,1237.75 1497.75,1237.8 1497.75,1237.85 1497.75,1237.9 1497.75,1237.95 1497.75,1238 1497.75,1238.05 1497.75,1238.1 1497.75,1238.15 1497.75,1238.2 1497.75,1238.25 1497.75,1238.3 1497.75,1238.35 1497.75,1238.4 1497.75,1238.45 1497.75,1238.5 1497.75,1238.55 1497.75,1238.6 1497.75,1238.65 1497.75,1238.7 1497.75,1238.75 1497.75,1238.8 1497.75,1238.85 1497.75,1238.9 1497.75,1238.95 1497.75,1239 1497.75,1239.05 1497.75,1239.1 1497.75,1239.15 1497.75,1239.2 1497.75,1239.25 1497.75,1239.3 1497.75,1239.35 1497.75,1239.4 1497.75,1239.45 1497.75,1239.5 1497.75,1239.55 1497.75,1239.6 1497.75,1239.65 1497.75,1239.7 1497.75,1239.75 1497.75,1239.8 1497.75,1239.85 1497.75,1239.9 1497.75,1239.95 1497.75,1240 1497.75,1240.05 1497.75,1240.1 1497.75,1240.15 1497.75,1240.2 1497.75,1240.25 1497.75,1240.3 1497.75,1240.35 1497.75,1240.4 1497.75,1240.45 1497.75,1240.5 1497.75,1240.55 1497.75,1240.6 1497.75,1240.65 1497.75,1240.7 1497.75,1240.74 1497.75,1240.79 1497.75,1240.84 1497.75,1240.89 1497.75,1240.94 1497.75,1240.99 1497.75,1241.04 1497.75,1241.09 1497.75,1241.14 1497.75,1241.19 1497.75,1241.24 1497.75,1241.29 1497.75,1241.34 1497.75,1241.39 1497.75,1241.44 1497.75,1241.49 1497.75,1241.54 1497.75,1241.59 1497.75,1241.64 1497.75,1241.69 1497.75,1241.74 1497.75,1241.79 1497.75,1241.84 1497.75,1241.89 1497.75,1241.94 1497.75,1241.98 1497.75,1242.03 1497.75,1242.08 1497.75,1242.13 1497.75,1242.18 1497.75,1242.23 1497.75,1242.28 1497.75,1242.33 1497.75,1242.38 1497.75,1242.43 1497.75,1242.48 1497.75,1242.53 1497.75,1242.58 1497.75,1242.63 1497.75,1242.68 1497.75,1242.73 1497.75,1242.78 1497.75,1242.82 1497.75,1242.87 1497.75,1242.92 1497.75,1242.97 1497.75,1243.02 1497.75,1243.07 1497.75,1243.12 1497.75,1243.17 1497.75,1243.22 1497.75,1243.27 1497.75,1243.32 1497.75,1243.37 1497.75,1243.42 1497.75,1243.47 1497.75,1243.51 1497.75,1243.56 1497.75,1243.61 1497.75,1243.66 1497.75,1243.71 1497.75,1243.76 1497.75,1243.81 1497.75,1243.86 1497.75,1243.91 1497.75,1243.96 1497.75,1244.01 1497.75,1244.05 1497.75,1244.1 1497.75,1244.15 1497.75,1244.2 1497.75,1244.25 1497.75,1244.3 1497.75,1244.35 1497.75,1244.4 1497.75,1244.45 1497.75,1244.5 1497.75,1244.55 1497.75,1244.59 1497.75,1244.64 1497.75,1244.69 1497.75,1244.74 1497.75,1244.79 1497.75,1244.84 1497.75,1244.89 1497.75,1244.94 1497.75,1244.99 1497.75,1245.03 1497.75,1245.08 1497.75,1245.13 1497.75,1245.18 1497.75,1245.23 1497.75,1245.28 1497.75,1245.33 1497.75,1245.38 1497.75,1245.43 1497.75,1245.47 1497.75,1245.52 1497.75,1245.57 1497.75,1245.62 1497.75,1245.67 1497.75,1245.72 1497.75,1245.77 1497.75,1245.82 1497.75,1245.87 1497.75,1245.91 1497.75,1245.96 1497.75,1246.01 1497.75,1246.06 1497.75,1246.11 1497.75,1246.16 1497.75,1246.21 1497.75,1246.25 1497.75,1246.3 1497.75,1246.35 1497.75,1246.4 1497.75,1246.45 1497.75,1246.5 1497.75,1246.55 1497.75,1246.6 1497.75,1246.64 1497.75,1246.69 1497.75,1246.74 1497.75,1246.79 1497.75,1246.84 1497.75,1246.89 1497.75,1246.94 1497.75,1246.98 1497.75,1247.03 1497.75,1247.08 1497.75,1247.13 1497.75,1247.18 1497.75,1247.23 1497.75,1247.27 1497.75,1247.32 1497.75,1247.37 1497.75,1247.42 1497.75,1247.47 1497.75,1247.52 1497.75,1247.57 1497.75,1247.61 1497.75,1247.66 1497.75,1247.71 1497.75,1247.76 1497.75,1247.81 1497.75,1247.86 1497.75,1247.9 1497.75,1247.95 1497.75,1248 1497.75,1248.05 1497.75,1248.1 1497.75,1248.15 1497.75,1248.19 1497.75,1248.24 1497.75,1248.29 1497.75,1248.34 1497.75,1248.39 1497.75,1248.44 1497.75,1248.48 1497.75,1248.53 1497.75,1248.58 1497.75,1248.63 1497.75,1248.68 1497.75,1248.72 1497.75,1248.77 1497.75,1248.82 1497.75,1248.87 1497.75,1248.92 1497.75,1248.97 1497.75,1249.01 1497.75,1249.06 1497.75,1249.11 1497.75,1249.16 1497.75,1249.21 1497.75,1249.25 1497.75,1249.3 1497.75,1249.35 1497.75,1249.4 1497.75,1249.45 1497.75,1249.49 1497.75,1249.54 1497.75,1249.59 1497.75,1249.64 1497.75,1249.69 1497.75,1249.73 1497.75,1249.78 1497.75,1249.83 1497.75,1249.88 1497.75,1249.93 1497.75,1249.97 1497.75,1250.02 1497.75,1250.07 1497.75,1250.12 1497.75,1250.17 1497.75,1250.21 1497.75,1250.26 1497.75,1250.31 1497.75,1250.36 1497.75,1250.41 1497.75,1250.45 1497.75,1250.5 1497.75,1250.55 1497.75,1250.6 1497.75,1250.64 1497.75,1250.69 1497.75,1250.74 1497.75,1250.79 1497.75,1250.84 1497.75,1250.88 1497.75,1250.93 1497.75,1250.98 1497.75,1251.03 1497.75,1251.07 1497.75,1251.12 1497.75,1251.17 1497.75,1251.22 1497.75,1251.27 1497.75,1251.31 1497.75,1251.36 1497.75,1251.41 1497.75,1251.46 1497.75,1251.5 1497.75,1251.55 1497.75,1251.6 1497.75,1251.65 1497.75,1251.69 1497.75,1251.74 1497.75,1251.79 1497.75,1251.84 1497.75,1251.88 1497.75,1251.93 1497.75,1251.98 1497.75,1252.03 1497.75,1252.08 1497.75,1252.12 1497.75,1252.17 1497.75,1252.22 1497.75,1252.27 1497.75,1252.31 1497.75,1252.36 1497.75,1252.41 1497.75,1252.45 1497.75,1252.5 1497.75,1252.55 1497.75,1252.6 1497.75,1252.64 1497.75,1252.69 1497.75,1252.74 1497.75,1252.79 1497.75,1252.83 1497.75,1252.88 1497.75,1252.93 1497.75,1252.98 1497.75,1253.02 1497.75,1253.07 1497.75,1253.12 1497.75,1253.17 1497.75,1253.21 1497.75,1253.26 1497.75,1253.31 1497.75,1253.35 1497.75,1253.4 1497.75,1253.45 1497.75,1253.5 1497.75,1253.54 1497.75,1253.59 1497.75,1253.64 1497.75,1253.69 1497.75,1253.73 1497.75,1253.78 1497.75,1253.83 1497.75,1253.87 1497.75,1253.92 1497.75,1253.97 1497.75,1254.02 1497.75,1254.06 1497.75,1254.11 1497.75,1254.16 1497.75,1254.2 1497.75,1254.25 1497.75,1254.3 1497.75,1254.35 1497.75,1254.39 1497.75,1254.44 1497.75,1254.49 1497.75,1254.53 1497.75,1254.58 1497.75,1254.63 1497.75,1254.67 1497.75,1254.72 1497.75,1254.77 1497.75,1254.82 1497.75,1254.86 1497.75,1254.91 1497.75,1254.96 1497.75,1255 1497.75,1255.05 1497.75,1255.1 1497.75,1255.14 1497.75,1255.19 1497.75,1255.24 1497.75,1255.28 1497.75,1255.33 1497.75,1255.38 1497.75,1255.43 1497.75,1255.47 1497.75,1255.52 1497.75,1255.57 1497.75,1255.61 1497.75,1255.66 1497.75,1255.71 1497.75,1255.75 1497.75,1255.8 1497.75,1255.85 1497.75,1255.89 1497.75,1255.94 1497.75,1255.99 1497.75,1256.03 1497.75,1256.08 1497.75,1256.13 1497.75,1256.17 1497.75,1256.22 1497.75,1256.27 1497.75,1256.31 1497.75,1256.36 1497.75,1256.41 1497.75,1256.45 1497.75,1256.5 1497.75,1256.55 1497.75,1256.59 1497.75,1256.64 1497.75,1256.69 1497.75,1256.73 1497.75,1256.78 1497.75,1256.83 1497.75,1256.87 1497.75,1256.92 1497.75,1256.97 1497.75,1257.01 1497.75,1257.06 1497.75,1257.11 1497.75,1257.15 1497.75,1257.2 1497.75,1257.25 1497.75,1257.29 1497.75,1257.34 1497.75,1257.38 1497.75,1257.43 1497.75,1257.48 1497.75,1257.52 1497.75,1257.57 1497.75,1257.62 1497.75,1257.66 1497.75,1257.71 1497.75,1257.76 1497.75,1257.8 1497.75,1257.85 1497.75,1257.89 1497.75,1257.94 1497.75,1257.99 1497.75,1258.03 1497.75,1258.08 1497.75,1258.13 1497.75,1258.17 1497.75,1258.22 1497.75,1258.27 1497.75,1258.31 1497.75,1258.36 1497.75,1258.4 1497.75,1258.45 1497.75,1258.5 1497.75,1258.54 1497.75,1258.59 1497.75,1258.63 1497.75,1258.68 1497.75,1258.73 1497.75,1258.77 1497.75,1258.82 1497.75,1258.87 1497.75,1258.91 1497.75,1258.96 1497.75,1259 1497.75,1259.05 1497.75,1259.1 1497.75,1259.14 1497.75,1259.19 1497.75,1259.23 1497.75,1259.28 1497.75,1259.33 1497.75,1259.37 1497.75,1259.42 1497.75,1259.46 1497.75,1259.51 1497.75,1259.56 1497.75,1259.6 1497.75,1259.65 1497.75,1259.69 1497.75,1259.74 1497.75,1259.79 1497.75,1259.83 1497.75,1259.88 1497.75,1259.92 1497.75,1259.97 1497.75,1260.02 1497.75,1260.06 1497.75,1260.11 1497.75,1260.15 1497.75,1260.2 1497.75,1260.25 1497.75,1260.29 1497.75,1260.34 1497.75,1260.38 1497.75,1260.43 1497.75,1260.47 1497.75,1260.52 1497.75,1260.57 1497.75,1260.61 1497.75,1260.66 1497.75,1260.7 1497.75,1260.75 1497.75,1260.79 1497.75,1260.84 1497.75,1260.89 1497.75,1260.93 1497.75,1260.98 1497.75,1261.02 1497.75,1261.07 1497.75,1261.11 1497.75,1261.16 1497.75,1261.21 1497.75,1261.25 1497.75,1261.3 1497.75,1261.34 1497.75,1261.39 1497.75,1261.43 1497.75,1261.48 1497.75,1261.53 1497.75,1261.57 1497.75,1261.62 1497.75,1261.66 1497.75,1261.71 1497.75,1261.75 1497.75,1261.8 1497.75,1261.84 1497.75,1261.89 1497.75,1261.93 1497.75,1261.98 1497.75,1262.03 1497.75,1262.07 1497.75,1262.12 1497.75,1262.16 1497.75,1262.21 1497.75,1262.25 1497.75,1262.3 1497.75,1262.34 1497.75,1262.39 1497.75,1262.43 1497.75,1262.48 1497.75,1262.53 1497.75,1262.57 1497.75,1262.62 1497.75,1262.66 1497.75,1262.71 1497.75,1262.75 1497.75,1262.8 1497.75,1262.84 1497.75,1262.89 1497.75,1262.93 1497.75,1262.98 1497.75,1263.02 1497.75,1263.07 1497.75,1263.11 1497.75,1263.16 1497.75,1263.2 1497.75,1263.25 1497.75,1263.29 1497.75,1263.34 1497.75,1263.39 1497.75,1263.43 1497.75,1263.48 1497.75,1263.52 1497.75,1263.57 1497.75,1263.61 1497.75,1263.66 1497.75,1263.7 1497.75,1263.75 1497.75,1263.79 1497.75,1263.84 1497.75,1263.88 1497.75,1263.93 1497.75,1263.97 1497.75,1264.02 1497.75,1264.06 1497.75,1264.11 1497.75,1264.15 1497.75,1264.2 1497.75,1264.24 1497.75,1264.29 1497.75,1264.33 1497.75,1264.38 1497.75,1264.42 1497.75,1264.47 1497.75,1264.51 1497.75,1264.56 1497.75,1264.6 1497.75,1264.65 1497.75,1264.69 1497.75,1264.74 1497.75,1264.78 1497.75,1264.83 1497.75,1264.87 1497.75,1264.92 1497.75,1264.96 1497.75,1265.01 1497.75,1265.05 1497.75,1265.09 1497.75,1265.14 1497.75,1265.18 1497.75,1265.23 1497.75,1265.27 1497.75,1265.32 1497.75,1265.36 1497.75,1265.41 1497.75,1265.45 1497.75,1265.5 1497.75,1265.54 1497.75,1265.59 1497.75,1265.63 1497.75,1265.68 1497.75,1265.72 1497.75,1265.77 1497.75,1265.81 1497.75,1265.85 1497.75,1265.9 1497.75,1265.94 1497.75,1265.99 1497.75,1266.03 1497.75,1266.08 1497.75,1266.12 1497.75,1266.17 1497.75,1266.21 1497.75,1266.26 1497.75,1266.3 1497.75,1266.35 1497.75,1266.39 1497.75,1266.43 1497.75,1266.48 1497.75,1266.52 1497.75,1266.57 1497.75,1266.61 1497.75,1266.66 1497.75,1266.7 1497.75,1266.75 1497.75,1266.79 1497.75,1266.83 1497.75,1266.88 1497.75,1266.92 1497.75,1266.97 1497.75,1267.01 1497.75,1267.06 1497.75,1267.1 1497.75,1267.15 1497.75,1267.19 1497.75,1267.23 1497.75,1267.28 1497.75,1267.32 1497.75,1267.37 1497.75,1267.41 1497.75,1267.46 1497.75,1267.5 1497.75,1267.54 1497.75,1267.59 1497.75,1267.63 1497.75,1267.68 1497.75,1267.72 1497.75,1267.77 1497.75,1267.81 1497.75,1267.85 1497.75,1267.9 1497.75,1267.94 1497.75,1267.99 1497.75,1268.03 1497.75,1268.07 1497.75,1268.12 1497.75,1268.16 1497.75,1268.21 1497.75,1268.25 1497.75,1268.3 1497.75,1268.34 1497.75,1268.38 1497.75,1268.43 1497.75,1268.47 1497.75,1268.52 1497.75,1268.56 1497.75,1268.6 1497.75,1268.65 1497.75,1268.69 1497.75,1268.74 1497.75,1268.78 1497.75,1268.82 1497.75,1268.87 1497.75,1268.91 1497.75,1268.96 1497.75,1269 1497.75,1269.04 1497.75,1269.09 1497.75,1269.13 1497.75,1269.18 1497.75,1269.22 1497.75,1269.26 1497.75,1269.31 1497.75,1269.35 1497.75,1269.39 1497.75,1269.44 1497.75,1269.48 1497.75,1269.53 1497.75,1269.57 1497.75,1269.61 1497.75,1269.66 1497.75,1269.7 1497.75,1269.74 1497.75,1269.79 1497.75,1269.83 1497.75,1269.88 1497.75,1269.92 1497.75,1269.96 1497.75,1270.01 1497.75,1270.05 1497.75,1270.09 1497.75,1270.14 1497.75,1270.18 1497.75,1270.23 1497.75,1270.27 1497.75,1270.31 1497.75,1270.36 1497.75,1270.4 1497.75,1270.44 1497.75,1270.49 1497.75,1270.53 1497.75,1270.57 1497.75,1270.62 1497.75,1270.66 1497.75,1270.71 1497.75,1270.75 1497.75,1270.79 1497.75,1270.84 1497.75,1270.88 1497.75,1270.92 1497.75,1270.97 1497.75,1271.01 1497.75,1271.05 1497.75,1271.1 1497.75,1271.14 1497.75,1271.18 1497.75,1271.23 1497.75,1271.27 1497.75,1271.31 1497.75,1271.36 1497.75,1271.4 1497.75,1271.44 1497.75,1271.49 1497.75,1271.53 1497.75,1271.57 1497.75,1271.62 1497.75,1271.66 1497.75,1271.7 1497.75,1271.75 1497.75,1271.79 1497.75,1271.83 1497.75,1271.88 1497.75,1271.92 1497.75,1271.96 1497.75,1272.01 1497.75,1272.05 1497.75,1272.09 1497.75,1272.14 1497.75,1272.18 1497.75,1272.22 1497.75,1272.27 1497.75,1272.31 1497.75,1272.35 1497.75,1272.4 1497.75,1272.44 1497.75,1272.48 1497.75,1272.53 1497.75,1272.57 1497.75,1272.61 1497.75,1272.66 1497.75,1272.7 1497.75,1272.74 1497.75,1272.78 1497.75,1272.83 1497.75,1272.87 1497.75,1272.91 1497.75,1272.96 1497.75,1273 1497.75,1273.04 1497.75,1273.09 1497.75,1273.13 1497.75,1273.17 1497.75,1273.22 1497.75,1273.26 1497.75,1273.3 1497.75,1273.34 1497.75,1273.39 1497.75,1273.43 1497.75,1273.47 1497.75,1273.52 1497.75,1273.56 1497.75,1273.6 1497.75,1273.64 1497.75,1273.69 1497.75,1273.73 1497.75,1273.77 1497.75,1273.82 1497.75,1273.86 1497.75,1273.9 1497.75,1273.94 1497.75,1273.99 1497.75,1274.03 1497.75,1274.07 1497.75,1274.12 1497.75,1274.16 1497.75,1274.2 1497.75,1274.24 1497.75,1274.29 1497.75,1274.33 1497.75,1274.37 1497.75,1274.42 1497.75,1274.46 1497.75,1274.5 1497.75,1274.54 1497.75,1274.59 1497.75,1274.63 1497.75,1274.67 1497.75,1274.71 1497.75,1274.76 1497.75,1274.8 1497.75,1274.84 1497.75,1274.88 1497.75,1274.93 1497.75,1274.97 1497.75,1275.01 1497.75,1275.05 1497.75,1275.1 1497.75,1275.14 1497.75,1275.18 1497.75,1275.22 1497.75,1275.27 1497.75,1275.31 1497.75,1275.35 1497.75,1275.39 1497.75,1275.44 1497.75,1275.48 1497.75,1275.52 1497.75,1275.56 1497.75,1275.61 1497.75,1275.65 1497.75,1275.69 1497.75,1275.73 1497.75,1275.78 1497.75,1275.82 1497.75,1275.86 1497.75,1275.9 1497.75,1275.95 1497.75,1275.99 1497.75,1276.03 1497.75,1276.07 1497.75,1276.12 1497.75,1276.16 1497.75,1276.2 1497.75,1276.24 1497.75,1276.28 1497.75,1276.33 1497.75,1276.37 1497.75,1276.41 1497.75,1276.45 1497.75,1276.5 1497.75,1276.54 1497.75,1276.58 1497.75,1276.62 1497.75,1276.67 1497.75,1276.71 1497.75,1276.75 1497.75,1276.79 1497.75,1276.83 1497.75,1276.88 1497.75,1276.92 1497.75,1276.96 1497.75,1277 1497.75,1277.04 1497.75,1277.09 1497.75,1277.13 1497.75,1277.17 1497.75,1277.21 1497.75,1277.25 1497.75,1277.3 1497.75,1277.34 1497.75,1277.38 1497.75,1277.42 1497.75,1277.46 1497.75,1277.51 1497.75,1277.55 1497.75,1277.59 1497.75,1277.63 1497.75,1277.67 1497.75,1277.72 1497.75,1277.76 1497.75,1277.8 1497.75,1277.84 1497.75,1277.88 1497.75,1277.93 1497.75,1277.97 1497.75,1278.01 1497.75,1278.05 1497.75,1278.09 1497.75,1278.14 1497.75,1278.18 1497.75,1278.22 1497.75,1278.26 1497.75,1278.3 1497.75,1278.34 1497.75,1278.39 1497.75,1278.43 1497.75,1278.47 1497.75,1278.51 1497.75,1278.55 1497.75,1278.6 1497.75,1278.64 1497.75,1278.68 1497.75,1278.72 1497.75,1278.76 1497.75,1278.8 1497.75,1278.85 1497.75,1278.89 1497.75,1278.93 1497.75,1278.97 1497.75,1279.01 1497.75,1279.05 1497.75,1279.1 1497.75,1279.14 1497.75,1279.18 1497.75,1279.22 1497.75,1279.26 1497.75,1279.3 1497.75,1279.35 1497.75,1279.39 1497.75,1279.43 1497.75,1279.47 1497.75,1279.51 1497.75,1279.55 1497.75,1279.59 1497.75,1279.64 1497.75,1279.68 1497.75,1279.72 1497.75,1279.76 1497.75,1279.8 1497.75,1279.84 1497.75,1279.88 1497.75,1279.93 1497.75,1279.97 1497.75,1280.01 1497.75,1280.05 1497.75,1280.09 1497.75,1280.13 1497.75,1280.17 1497.75,1280.22 1497.75,1280.26 1497.75,1280.3 1497.75,1280.34 1497.75,1280.38 1497.75,1280.42 1497.75,1280.46 1497.75,1280.51 1497.75,1280.55 1497.75,1280.59 1497.75,1280.63 1497.75,1280.67 1497.75,1280.71 1497.75,1280.75 1497.75,1280.79 1497.75,1280.84 1497.75,1280.88 1497.75,1280.92 1497.75,1280.96 1497.75,1281 1497.75,1281.04 1497.75,1281.08 1497.75,1281.12 1497.75,1281.16 1497.75,1281.21 1497.75,1281.25 1497.75,1281.29 1497.75,1281.33 1497.75,1281.37 1497.75,1281.41 1497.75,1281.45 1497.75,1281.49 1497.75,1281.53 1497.75,1281.58 1497.75,1281.62 1497.75,1281.66 1497.75,1281.7 1497.75,1281.74 1497.75,1281.78 1497.75,1281.82 1497.75,1281.86 1497.75,1281.9 1497.75,1281.94 1497.75,1281.98 1497.75,1282.03 1497.75,1282.07 1497.75,1282.11 1497.75,1282.15 1497.75,1282.19 1497.75,1282.23 1497.75,1282.27 1497.75,1282.31 1497.75,1282.35 1497.75,1282.39 1497.75,1282.43 1497.75,1282.48 1497.75,1282.52 1497.75,1282.56 1497.75,1282.6 1497.75,1282.64 1497.75,1282.68 1497.75,1282.72 1497.75,1282.76 1497.75,1282.8 1497.75,1282.84 1497.75,1282.88 1497.75,1282.92 1497.75,1282.96 1497.75,1283.01 1497.75,1283.05 1497.75,1283.09 1497.75,1283.13 1497.75,1283.17 1497.75,1283.21 1497.75,1283.25 1497.75,1283.29 1497.75,1283.33 1497.75,1283.37 1497.75,1283.41 1497.75,1283.45 1497.75,1283.49 1497.75,1283.53 1497.75,1283.57 1497.75,1283.61 1497.75,1283.65 1497.75,1283.7 1497.75,1283.74 1497.75,1283.78 1497.75,1283.82 1497.75,1283.86 1497.75,1283.9 1497.75,1283.94 1497.75,1283.98 1497.75,1284.02 1497.75,1284.06 1497.75,1284.1 1497.75,1284.14 1497.75,1284.18 1497.75,1284.22 1497.75,1284.26 1497.75,1284.3 1497.75,1284.34 1497.75,1284.38 1497.75,1284.42 1497.75,1284.46 1497.75,1284.5 1497.75,1284.54 1497.75,1284.58 1497.75,1284.62 1497.75,1284.67 1497.75,1284.71 1497.75,1284.75 1497.75,1284.79 1497.75,1284.83 1497.75,1284.87 1497.75,1284.91 1497.75,1284.95 1497.75,1284.99 1497.75,1285.03 1497.75,1285.07 1497.75,1285.11 1497.75,1285.15 1497.75,1285.19 1497.75,1285.23 1497.75,1285.27 1497.75,1285.31 1497.75,1285.35 1497.75,1285.39 1497.75,1285.43 1497.75,1285.47 1497.75,1285.51 1497.75,1285.55 1497.75,1285.59 1497.75,1285.63 1497.75,1285.67 1497.75,1285.71 1497.75,1285.75 1497.75,1285.79 1497.75,1285.83 1497.75,1285.87 1497.75,1285.91 1497.75,1285.95 1497.75,1285.99 1497.75,1286.03 1497.75,1286.07 1497.75,1286.11 1497.75,1286.15 1497.75,1286.19 1497.75,1286.23 1497.75,1286.27 1497.75,1286.31 1497.75,1286.35 1497.75,1286.39 1497.75,1286.43 1497.75,1286.47 1497.75,1286.51 1497.75,1286.55 1497.75,1286.59 1497.75,1286.63 1497.75,1286.67 1497.75,1286.71 1497.75,1286.75 1497.75,1286.79 1497.75,1286.83 1497.75,1286.87 1497.75,1286.91 1497.75,1286.95 1497.75,1286.99 1497.75,1287.02 1497.75,1287.06 1497.75,1287.1 1497.75,1287.14 1497.75,1287.18 1497.75,1287.22 1497.75,1287.26 1497.75,1287.3 1497.75,1287.34 1497.75,1287.38 1497.75,1287.42 1497.75,1287.46 1497.75,1287.5 1497.75,1287.54 1497.75,1287.58 1497.75,1287.62 1497.75,1287.66 1497.75,1287.7 1497.75,1287.74 1497.75,1287.78 1497.75,1287.82 1497.75,1287.86 1497.75,1287.9 1497.75,1287.94 1497.75,1287.98 1497.75,1288.01 1497.75,1288.05 1497.75,1288.09 1497.75,1288.13 1497.75,1288.17 1497.75,1288.21 1497.75,1288.25 1497.75,1288.29 1497.75,1288.33 1497.75,1288.37 1497.75,1288.41 1497.75,1288.45 1497.75,1288.49 1497.75,1288.53 1497.75,1288.57 1497.75,1288.61 1497.75,1288.64 1497.75,1288.68 1497.75,1288.72 1497.75,1288.76 1497.75,1288.8 1497.75,1288.84 1497.75,1288.88 1497.75,1288.92 1497.75,1288.96 1497.75,1289 1497.75,1289.04 1497.75,1289.08 1497.75,1289.12 1497.75,1289.15 1497.75,1289.19 1497.75,1289.23 1497.75,1289.27 1497.75,1289.31 1497.75,1289.35 1497.75,1289.39 1497.75,1289.43 1497.75,1289.47 1497.75,1289.51 1497.75,1289.55 1497.75,1289.59 1497.75,1289.62 1497.75,1289.66 1497.75,1289.7 1497.75,1289.74 1497.75,1289.78 1497.75,1289.82 1497.75,1289.86 1497.75,1289.9 1497.75,1289.94 1497.75,1289.98 1497.75,1290.01 1497.75,1290.05 1497.75,1290.09 1497.75,1290.13 1497.75,1290.17 1497.75,1290.21 1497.75,1290.25 1497.75,1290.29 1497.75,1290.33 1497.75,1290.36 1497.75,1290.4 1497.75,1290.44 1497.75,1290.48 1497.75,1290.52 1497.75,1290.56 1497.75,1290.6 1497.75,1290.64 1497.75,1290.68 1497.75,1290.71 1497.75,1290.75 1497.75,1290.79 1497.75,1290.83 1497.75,1290.87 1497.75,1290.91 1497.75,1290.95 1497.75,1290.99 1497.75,1291.02 1497.75,1291.06 1497.75,1291.1 1497.75,1291.14 1497.75,1291.18 1497.75,1291.22 1497.75,1291.26 1497.75,1291.3 1497.75,1291.33 1497.75,1291.37 1497.75,1291.41 1497.75,1291.45 1497.75,1291.49 1497.75,1291.53 1497.75,1291.57 1497.75,1291.6 1497.75,1291.64 1497.75,1291.68 1497.75,1291.72 1497.75,1291.76 1497.75,1291.8 1497.75,1291.84 1497.75,1291.87 1497.75,1291.91 1497.75,1291.95 1497.75,1291.99 1497.75,1292.03 1497.75,1292.07 1497.75,1292.1 1497.75,1292.14 1497.75,1292.18 1497.75,1292.22 1497.75,1292.26 1497.75,1292.3 1497.75,1292.33 1497.75,1292.37 1497.75,1292.41 1497.75,1292.45 1497.75,1292.49 1497.75,1292.53 1497.75,1292.57 1497.75,1292.6 1497.75,1292.64 1497.75,1292.68 1497.75,1292.72 1497.75,1292.76 1497.75,1292.79 1497.75,1292.83 1497.75,1292.87 1497.75,1292.91 1497.75,1292.95 1497.75,1292.99 1497.75,1293.02 1497.75,1293.06 1497.75,1293.1 1497.75,1293.14 1497.75,1293.18 1497.75,1293.22 1497.75,1293.25 1497.75,1293.29 1497.75,1293.33 1497.75,1293.37 1497.75,1293.41 1497.75,1293.44 1497.75,1293.48 1497.75,1293.52 1497.75,1293.56 1497.75,1293.6 1497.75,1293.63 1497.75,1293.67 1497.75,1293.71 1497.75,1293.75 1497.75,1293.79 1497.75,1293.82 1497.75,1293.86 1497.75,1293.9 1497.75,1293.94 1497.75,1293.98 1497.75,1294.01 1497.75,1294.05 1497.75,1294.09 1497.75,1294.13 1497.75,1294.17 1497.75,1294.2 1497.75,1294.24 1497.75,1294.28 1497.75,1294.32 1497.75,1294.36 1497.75,1294.39 1497.75,1294.43 1497.75,1294.47 1497.75,1294.51 1497.75,1294.54 1497.75,1294.58 1497.75,1294.62 1497.75,1294.66 1497.75,1294.7 1497.75,1294.73 1497.75,1294.77 1497.75,1294.81 1497.75,1294.85 1497.75,1294.88 1497.75,1294.92 1497.75,1294.96 1497.75,1295 1497.75,1295.04 1497.75,1295.07 1497.75,1295.11 1497.75,1295.15 1497.75,1295.19 1497.75,1295.22 1497.75,1295.26 1497.75,1295.3 1497.75,1295.34 1497.75,1295.37 1497.75,1295.41 1497.75,1295.45 1497.75,1295.49 1497.75,1295.52 1497.75,1295.56 1497.75,1295.6 1497.75,1295.64 1497.75,1295.67 1497.75,1295.71 1497.75,1295.75 1497.75,1295.79 1497.75,1295.82 1497.75,1295.86 1497.75,1295.9 1497.75,1295.94 1497.75,1295.97 1497.75,1296.01 1497.75,1296.05 1497.75,1296.09 1497.75,1296.12 1497.75,1296.16 1497.75,1296.2 1497.75,1296.24 1497.75,1296.27 1497.75,1296.31 1497.75,1296.35 1497.75,1296.39 1497.75,1296.42 1497.75,1296.46 1497.75,1296.5 1497.75,1296.54 1497.75,1296.57 1497.75,1296.61 1497.75,1296.65 1497.75,1296.68 1497.75,1296.72 1497.75,1296.76 1497.75,1296.8 1497.75,1296.83 1497.75,1296.87 1497.75,1296.91 1497.75,1296.95 1497.75,1296.98 1497.75,1297.02 1497.75,1297.06 1497.75,1297.09 1497.75,1297.13 1497.75,1297.17 1497.75,1297.21 1497.75,1297.24 1497.75,1297.28 1497.75,1297.32 1497.75,1297.35 1497.75,1297.39 1497.75,1297.43 1497.75,1297.47 1497.75,1297.5 1497.75,1297.54 1497.75,1297.58 1497.75,1297.61 1497.75,1297.65 1497.75,1297.69 1497.75,1297.72 1497.75,1297.76 1497.75,1297.8 1497.75,1297.84 1497.75,1297.87 1497.75,1297.91 1497.75,1297.95 1497.75,1297.98 1497.75,1298.02 1497.75,1298.06 1497.75,1298.09 1497.75,1298.13 1497.75,1298.17 1497.75,1298.2 1497.75,1298.24 1497.75,1298.28 1497.75,1298.32 1497.75,1298.35 1497.75,1298.39 1497.75,1298.43 1497.75,1298.46 1497.75,1298.5 1497.75,1298.54 1497.75,1298.57 1497.75,1298.61 1497.75,1298.65 1497.75,1298.68 1497.75,1298.72 1497.75,1298.76 1497.75,1298.79 1497.75,1298.83 1497.75,1298.87 1497.75,1298.9 1497.75,1298.94 1497.75,1298.98 1497.75,1299.01 1497.75,1299.05 1497.75,1299.09 1497.75,1299.12 1497.75,1299.16 1497.75,1299.2 1497.75,1299.23 1497.75,1299.27 1497.75,1299.31 1497.75,1299.34 1497.75,1299.38 1497.75,1299.42 1497.75,1299.45 1497.75,1299.49 1497.75,1299.53 1497.75,1299.56 1497.75,1299.6 1497.75,1299.64 1497.75,1299.67 1497.75,1299.71 1497.75,1299.74 1497.75,1299.78 1497.75,1299.82 1497.75,1299.85 1497.75,1299.89 1497.75,1299.93 1497.75,1299.96 1497.75,1300 1497.75,1300.04 1497.75,1300.07 1497.75,1300.11 1497.75,1300.15 1497.75,1300.18 1497.75,1300.22 1497.75,1300.25 1497.75,1300.29 1497.75,1300.33 1497.75,1300.36 1497.75,1300.4 1497.75,1300.44 1497.75,1300.47 1497.75,1300.51 1497.75,1300.55 1497.75,1300.58 1497.75,1300.62 1497.75,1300.65 1497.75,1300.69 1497.75,1300.73 1497.75,1300.76 1497.75,1300.8 1497.75,1300.83 1497.75,1300.87 1497.75,1300.91 1497.75,1300.94 1497.75,1300.98 1497.75,1301.02 1497.75,1301.05 1497.75,1301.09 1497.75,1301.12 1497.75,1301.16 1497.75,1301.2 1497.75,1301.23 1497.75,1301.27 1497.75,1301.3 1497.75,1301.34 1497.75,1301.38 1497.75,1301.41 1497.75,1301.45 1497.75,1301.48 1497.75,1301.52 1497.75,1301.56 1497.75,1301.59 1497.75,1301.63 1497.75,1301.66 1497.75,1301.7 1497.75,1301.74 1497.75,1301.77 1497.75,1301.81 1497.75,1301.84 1497.75,1301.88 1497.75,1301.92 1497.75,1301.95 1497.75,1301.99 1497.75,1302.02 1497.75,1302.06 1497.75,1302.1 1497.75,1302.13 1497.75,1302.17 1497.75,1302.2 1497.75,1302.24 1497.75,1302.27 1497.75,1302.31 1497.75,1302.35 1497.75,1302.38 1497.75,1302.42 1497.75,1302.45 1497.75,1302.49 1497.75,1302.53 1497.75,1302.56 1497.75,1302.6 1497.75,1302.63 1497.75,1302.67 1497.75,1302.7 1497.75,1302.74 1497.75,1302.77 1497.75,1302.81 1497.75,1302.85 1497.75,1302.88 1497.75,1302.92 1497.75,1302.95 1497.75,1302.99 1497.75,1303.02 1497.75,1303.06 1497.75,1303.1 1497.75,1303.13 1497.75,1303.17 1497.75,1303.2 1497.75,1303.24 1497.75,1303.27 1497.75,1303.31 1497.75,1303.34 1497.75,1303.38 1497.75,1303.42 1497.75,1303.45 1497.75,1303.49 1497.75,1303.52 1497.75,1303.56 1497.75,1303.59 1497.75,1303.63 1497.75,1303.66 1497.75,1303.7 1497.75,1303.73 1497.75,1303.77 1497.75,1303.81 1497.75,1303.84 1497.75,1303.88 1497.75,1303.91 1497.75,1303.95 1497.75,1303.98 1497.75,1304.02 1497.75,1304.05 1497.75,1304.09 1497.75,1304.12 1497.75,1304.16 1497.75,1304.19 1497.75,1304.23 1497.75,1304.26 1497.75,1304.3 1497.75,1304.34 1497.75,1304.37 1497.75,1304.41 1497.75,1304.44 1497.75,1304.48 1497.75,1304.51 1497.75,1304.55 1497.75,1304.58 1497.75,1304.62 1497.75,1304.65 1497.75,1304.69 1497.75,1304.72 1497.75,1304.76 1497.75,1304.79 1497.75,1304.83 1497.75,1304.86 1497.75,1304.9 1497.75,1304.93 1497.75,1304.97 1497.75,1305 1497.75,1305.04 1497.75,1305.07 1497.75,1305.11 1497.75,1305.14 1497.75,1305.18 1497.75,1305.21 1497.75,1305.25 1497.75,1305.28 1497.75,1305.32 1497.75,1305.35 1497.75,1305.39 1497.75,1305.42 1497.75,1305.46 1497.75,1305.49 1497.75,1305.53 1497.75,1305.56 1497.75,1305.6 1497.75,1305.63 1497.75,1305.67 1497.75,1305.7 1497.75,1305.74 1497.75,1305.77 1497.75,1305.81 1497.75,1305.84 1497.75,1305.88 1497.75,1305.91 1497.75,1305.95 1497.75,1305.98 1497.75,1306.02 1497.75,1306.05 1497.75,1306.09 1497.75,1306.12 1497.75,1306.16 1497.75,1306.19 1497.75,1306.23 1497.75,1306.26 1497.75,1306.29 1497.75,1306.33 1497.75,1306.36 1497.75,1306.4 1497.75,1306.43 1497.75,1306.47 1497.75,1306.5 1497.75,1306.54 1497.75,1306.57 1497.75,1306.61 1497.75,1306.64 1497.75,1306.68 1497.75,1306.71 1497.75,1306.75 1497.75,1306.78 1497.75,1306.81 1497.75,1306.85 1497.75,1306.88 1497.75,1306.92 1497.75,1306.95 1497.75,1306.99 1497.75,1307.02 1497.75,1307.06 1497.75,1307.09 1497.75,1307.13 1497.75,1307.16 1497.75,1307.19 1497.75,1307.23 1497.75,1307.26 1497.75,1307.3 1497.75,1307.33 1497.75,1307.37 1497.75,1307.4 1497.75,1307.44 1497.75,1307.47 1497.75,1307.5 1497.75,1307.54 1497.75,1307.57 1497.75,1307.61 1497.75,1307.64 1497.75,1307.68 1497.75,1307.71 1497.75,1307.75 1497.75,1307.78 1497.75,1307.81 1497.75,1307.85 1497.75,1307.88 1497.75,1307.92 1497.75,1307.95 1497.75,1307.99 1497.75,1308.02 1497.75,1308.05 1497.75,1308.09 1497.75,1308.12 1497.75,1308.16 1497.75,1308.19 1497.75,1308.23 1497.75,1308.26 1497.75,1308.29 1497.75,1308.33 1497.75,1308.36 1497.75,1308.4 1497.75,1308.43 1497.75,1308.46 1497.75,1308.5 1497.75,1308.53 1497.75,1308.57 1497.75,1308.6 1497.75,1308.63 1497.75,1308.67 1497.75,1308.7 1497.75,1308.74 1497.75,1308.77 1497.75,1308.81 1497.75,1308.84 1497.75,1308.87 1497.75,1308.91 1497.75,1308.94 1497.75,1308.98 1497.75,1309.01 1497.75,1309.04 1497.75,1309.08 1497.75,1309.11 1497.75,1309.15 1497.75,1309.18 1497.75,1309.21 1497.75,1309.25 1497.75,1309.28 1497.75,1309.31 1497.75,1309.35 1497.75,1309.38 1497.75,1309.42 1497.75,1309.45 1497.75,1309.48 1497.75,1309.52 1497.75,1309.55 1497.75,1309.59 1497.75,1309.62 1497.75,1309.65 1497.75,1309.69 1497.75,1309.72 1497.75,1309.75 1497.75,1309.79 1497.75,1309.82 1497.75,1309.86 1497.75,1309.89 1497.75,1309.92 1497.75,1309.96 1497.75,1309.99 1497.75,1310.02 1497.75,1310.06 1497.75,1310.09 1497.75,1310.13 1497.75,1310.16 1497.75,1310.19 1497.75,1310.23 1497.75,1310.26 1497.75,1310.29 1497.75,1310.33 1497.75,1310.36 1497.75,1310.4 1497.75,1310.43 1497.75,1310.46 1497.75,1310.5 1497.75,1310.53 1497.75,1310.56 1497.75,1310.6 1497.75,1310.63 1497.75,1310.66 1497.75,1310.7 1497.75,1310.73 1497.75,1310.76 1497.75,1310.8 1497.75,1310.83 1497.75,1310.86 1497.75,1310.9 1497.75,1310.93 1497.75,1310.97 1497.75,1311 1497.75,1311.03 1497.75,1311.07 1497.75,1311.1 1497.75,1311.13 1497.75,1311.17 1497.75,1311.2 1497.75,1311.23 1497.75,1311.27 1497.75,1311.3 1497.75,1311.33 1497.75,1311.37 1497.75,1311.4 1497.75,1311.43 1497.75,1311.47 1497.75,1311.5 1497.75,1311.53 1497.75,1311.57 1497.75,1311.6 1497.75,1311.63 1497.75,1311.67 1497.75,1311.7 1497.75,1311.73 1497.75,1311.77 1497.75,1311.8 1497.75,1311.83 1497.75,1311.86 1497.75,1311.9 1497.75,1311.93 1497.75,1311.96 1497.75,1312 1497.75,1312.03 1497.75,1312.06 1497.75,1312.1 1497.75,1312.13 1497.75,1312.16 1497.75,1312.2 1497.75,1312.23 1497.75,1312.26 1497.75,1312.3 1497.75,1312.33 1497.75,1312.36 1497.75,1312.4 1497.75,1312.43 1497.75,1312.46 1497.75,1312.49 1497.75,1312.53 1497.75,1312.56 1497.75,1312.59 1497.75,1312.63 1497.75,1312.66 1497.75,1312.69 1497.75,1312.73 1497.75,1312.76 1497.75,1312.79 1497.75,1312.82 1497.75,1312.86 1497.75,1312.89 1497.75,1312.92 1497.75,1312.96 1497.75,1312.99 1497.75,1313.02 1497.75,1313.05 1497.75,1313.09 1497.75,1313.12 1497.75,1313.15 1497.75,1313.19 1497.75,1313.22 1497.75,1313.25 1497.75,1313.28 1497.75,1313.32 1497.75,1313.35 1497.75,1313.38 1497.75,1313.42 1497.75,1313.45 1497.75,1313.48 1497.75,1313.51 1497.75,1313.55 1497.75,1313.58 1497.75,1313.61 1497.75,1313.64 1497.75,1313.68 1497.75,1313.71 1497.75,1313.74 1497.75,1313.78 1497.75,1313.81 1497.75,1313.84 1497.75,1313.87 1497.75,1313.91 1497.75,1313.94 1497.75,1313.97 1497.75,1314 1497.75,1314.04 1497.75,1314.07 1497.75,1314.1 1497.75,1314.13 1497.75,1314.17 1497.75,1314.2 1497.75,1314.23 1497.75,1314.26 1497.75,1314.3 1497.75,1314.33 1497.75,1314.36 1497.75,1314.39 1497.75,1314.43 1497.75,1314.46 1497.75,1314.49 1497.75,1314.52 1497.75,1314.56 1497.75,1314.59 1497.75,1314.62 1497.75,1314.65 1497.75,1314.69 1497.75,1314.72 1497.75,1314.75 1497.75,1314.78 1497.75,1314.82 1497.75,1314.85 1497.75,1314.88 1497.75,1314.91 1497.75,1314.95 1497.75,1314.98 1497.75,1315.01 1497.75,1315.04 1497.75,1315.07 1497.75,1315.11 1497.75,1315.14 1497.75,1315.17 1497.75,1315.2 1497.75,1315.24 1497.75,1315.27 1497.75,1315.3 1497.75,1315.33 1497.75,1315.37 1497.75,1315.4 1497.75,1315.43 1497.75,1315.46 1497.75,1315.49 1497.75,1315.53 1497.75,1315.56 1497.75,1315.59 1497.75,1315.62 1497.75,1315.66 1497.75,1315.69 1497.75,1315.72 1497.75,1315.75 1497.75,1315.78 1497.75,1315.82 1497.75,1315.85 1497.75,1315.88 1497.75,1315.91 1497.75,1315.94 1497.75,1315.98 1497.75,1316.01 1497.75,1316.04 1497.75,1316.07 1497.75,1316.1 1497.75,1316.14 1497.75,1316.17 1497.75,1316.2 1497.75,1316.23 1497.75,1316.26 1497.75,1316.3 1497.75,1316.33 1497.75,1316.36 1497.75,1316.39 1497.75,1316.42 1497.75,1316.46 1497.75,1316.49 1497.75,1316.52 1497.75,1316.55 1497.75,1316.58 1497.75,1316.62 1497.75,1316.65 1497.75,1316.68 1497.75,1316.71 1497.75,1316.74 1497.75,1316.77 1497.75,1316.81 1497.75,1316.84 1497.75,1316.87 1497.75,1316.9 1497.75,1316.93 1497.75,1316.97 1497.75,1317 1497.75,1317.03 1497.75,1317.06 1497.75,1317.09 1497.75,1317.12 1497.75,1317.16 1497.75,1317.19 1497.75,1317.22 1497.75,1317.25 1497.75,1317.28 1497.75,1317.31 1497.75,1317.35 1497.75,1317.38 1497.75,1317.41 1497.75,1317.44 1497.75,1317.47 1497.75,1317.5 1497.75,1317.54 1497.75,1317.57 1497.75,1317.6 1497.75,1317.63 1497.75,1317.66 1497.75,1317.69 1497.75,1317.73 1497.75,1317.76 1497.75,1317.79 1497.75,1317.82 1497.75,1317.85 1497.75,1317.88 1497.75,1317.91 1497.75,1317.95 1497.75,1317.98 1497.75,1318.01 1497.75,1318.04 1497.75,1318.07 1497.75,1318.1 1497.75,1318.13 1497.75,1318.17 1497.75,1318.2 1497.75,1318.23 1497.75,1318.26 1497.75,1318.29 1497.75,1318.32 1497.75,1318.35 1497.75,1318.39 1497.75,1318.42 1497.75,1318.45 1497.75,1318.48 1497.75,1318.51 1497.75,1318.54 1497.75,1318.57 1497.75,1318.61 1497.75,1318.64 1497.75,1318.67 1497.75,1318.7 1497.75,1318.73 1497.75,1318.76 1497.75,1318.79 1497.75,1318.82 1497.75,1318.86 1497.75,1318.89 1497.75,1318.92 1497.75,1318.95 1497.75,1318.98 1497.75,1319.01 1497.75,1319.04 1497.75,1319.07 1497.75,1319.11 1497.75,1319.14 1497.75,1319.17 1497.75,1319.2 1497.75,1319.23 1497.75,1319.26 1497.75,1319.29 1497.75,1319.32 1497.75,1319.35 1497.75,1319.39 1497.75,1319.42 1497.75,1319.45 1497.75,1319.48 1497.75,1319.51 1497.75,1319.54 1497.75,1319.57 1497.75,1319.6 1497.75,1319.63 1497.75,1319.66 1497.75,1319.7 1497.75,1319.73 1497.75,1319.76 1497.75,1319.79 1497.75,1319.82 1497.75,1319.85 1497.75,1319.88 1497.75,1319.91 1497.75,1319.94 1497.75,1319.97 1497.75,1320.01 1497.75,1320.04 1497.75,1320.07 1497.75,1320.1 1497.75,1320.13 1497.75,1320.16 1497.75,1320.19 1497.75,1320.22 1497.75,1320.25 1497.75,1320.28 1497.75,1320.31 1497.75,1320.34 1497.75,1320.38 1497.75,1320.41 1497.75,1320.44 1497.75,1320.47 1497.75,1320.5 1497.75,1320.53 1497.75,1320.56 1497.75,1320.59 1497.75,1320.62 1497.75,1320.65 1497.75,1320.68 1497.75,1320.71 1497.75,1320.74 1497.75,1320.78 1497.75,1320.81 1497.75,1320.84 1497.75,1320.87 1497.75,1320.9 1497.75,1320.93 1497.75,1320.96 1497.75,1320.99 1497.75,1321.02 1497.75,1321.05 1497.75,1321.08 1497.75,1321.11 1497.75,1321.14 1497.75,1321.17 1497.75,1321.2 1497.75,1321.23 1497.75,1321.27 1497.75,1321.3 1497.75,1321.33 1497.75,1321.36 1497.75,1321.39 1497.75,1321.42 1497.75,1321.45 1497.75,1321.48 1497.75,1321.51 1497.75,1321.54 1497.75,1321.57 1497.75,1321.6 1497.75,1321.63 1497.75,1321.66 1497.75,1321.69 1497.75,1321.72 1497.75,1321.75 1497.75,1321.78 1497.75,1321.81 1497.75,1321.84 1497.75,1321.87 1497.75,1321.9 1497.75,1321.94 1497.75,1321.97 1497.75,1322 1497.75,1322.03 1497.75,1322.06 1497.75,1322.09 1497.75,1322.12 1497.75,1322.15 1497.75,1322.18 1497.75,1322.21 1497.75,1322.24 1497.75,1322.27 1497.75,1322.3 1497.75,1322.33 1497.75,1322.36 1497.75,1322.39 1497.75,1322.42 1497.75,1322.45 1497.75,1322.48 1497.75,1322.51 1497.75,1322.54 1497.75,1322.57 1497.75,1322.6 1497.75,1322.63 1497.75,1322.66 1497.75,1322.69 1497.75,1322.72 1497.75,1322.75 1497.75,1322.78 1497.75,1322.81 1497.75,1322.84 1497.75,1322.87 1497.75,1322.9 1497.75,1322.93 1497.75,1322.96 1497.75,1322.99 1497.75,1323.02 1497.75,1323.05 1497.75,1323.08 1497.75,1323.11 1497.75,1323.14 1497.75,1323.17 1497.75,1323.2 1497.75,1323.23 1497.75,1323.26 1497.75,1323.29 1497.75,1323.32 1497.75,1323.35 1497.75,1323.38 1497.75,1323.41 1497.75,1323.44 1497.75,1323.47 1497.75,1323.5 1497.75,1323.53 1497.75,1323.56 1497.75,1323.59 1497.75,1323.62 1497.75,1323.65 1497.75,1323.68 1497.75,1323.71 1497.75,1323.74 1497.75,1323.77 1497.75,1323.8 1497.75,1323.83 1497.75,1323.86 1497.75,1323.89 1497.75,1323.92 1497.75,1323.95 1497.75,1323.98 1497.75,1324.01 1497.75,1324.04 1497.75,1324.07 1497.75,1324.1 1497.75,1324.13 1497.75,1324.16 1497.75,1324.19 1497.75,1324.22 1497.75,1324.25 1497.75,1324.28 1497.75,1324.31 1497.75,1324.34 1497.75,1324.37 1497.75,1324.39 1497.75,1324.42 1497.75,1324.45 1497.75,1324.48 1497.75,1324.51 1497.75,1324.54 1497.75,1324.57 1497.75,1324.6 1497.75,1324.63 1497.75,1324.66 1497.75,1324.69 1497.75,1324.72 1497.75,1324.75 1497.75,1324.78 1497.75,1324.81 1497.75,1324.84 1497.75,1324.87 1497.75,1324.9 1497.75,1324.93 1497.75,1324.96 1497.75,1324.99 1497.75,1325.02 1497.75,1325.04 1497.75,1325.07 1497.75,1325.1 1497.75,1325.13 1497.75,1325.16 1497.75,1325.19 1497.75,1325.22 1497.75,1325.25 1497.75,1325.28 1497.75,1325.31 1497.75,1325.34 1497.75,1325.37 1497.75,1325.4 1497.75,1325.43 1497.75,1325.46 1497.75,1325.49 1497.75,1325.51 1497.75,1325.54 1497.75,1325.57 1497.75,1325.6 1497.75,1325.63 1497.75,1325.66 1497.75,1325.69 1497.75,1325.72 1497.75,1325.75 1497.75,1325.78 1497.75,1325.81 1497.75,1325.84 1497.75,1325.87 1497.75,1325.9 1497.75,1325.92 1497.75,1325.95 1497.75,1325.98 1497.75,1326.01 1497.75,1326.04 1497.75,1326.07 1497.75,1326.1 1497.75,1326.13 1497.75,1326.16 1497.75,1326.19 1497.75,1326.22 1497.75,1326.25 1497.75,1326.27 1497.75,1326.3 1497.75,1326.33 1497.75,1326.36 1497.75,1326.39 1497.75,1326.42 1497.75,1326.45 1497.75,1326.48 1497.75,1326.51 1497.75,1326.54 1497.75,1326.56 1497.75,1326.59 1497.75,1326.62 1497.75,1326.65 1497.75,1326.68 1497.75,1326.71 1497.75,1326.74 1497.75,1326.77 1497.75,1326.8 1497.75,1326.83 1497.75,1326.85 1497.75,1326.88 1497.75,1326.91 1497.75,1326.94 1497.75,1326.97 1497.75,1327 1497.75,1327.03 1497.75,1327.06 1497.75,1327.09 1497.75,1327.11 1497.75,1327.14 1497.75,1327.17 1497.75,1327.2 1497.75,1327.23 1497.75,1327.26 1497.75,1327.29 1497.75,1327.32 1497.75,1327.34 1497.75,1327.37 1497.75,1327.4 1497.75,1327.43 1497.75,1327.46 1497.75,1327.49 1497.75,1327.52 1497.75,1327.55 1497.75,1327.57 1497.75,1327.6 1497.75,1327.63 1497.75,1327.66 1497.75,1327.69 1497.75,1327.72 1497.75,1327.75 1497.75,1327.78 1497.75,1327.8 1497.75,1327.83 1497.75,1327.86 1497.75,1327.89 1497.75,1327.92 1497.75,1327.95 1497.75,1327.98 1497.75,1328 1497.75,1328.03 1497.75,1328.06 1497.75,1328.09 1497.75,1328.12 1497.75,1328.15 1497.75,1328.18 1497.75,1328.2 1497.75,1328.23 1497.75,1328.26 1497.75,1328.29 1497.75,1328.32 1497.75,1328.35 1497.75,1328.38 1497.75,1328.4 1497.75,1328.43 1497.75,1328.46 1497.75,1328.49 1497.75,1328.52 1497.75,1328.55 1497.75,1328.57 1497.75,1328.6 1497.75,1328.63 1497.75,1328.66 1497.75,1328.69 1497.75,1328.72 1497.75,1328.74 1497.75,1328.77 1497.75,1328.8 1497.75,1328.83 1497.75,1328.86 1497.75,1328.89 1497.75,1328.91 1497.75,1328.94 1497.75,1328.97 1497.75,1329 1497.75,1329.03 1497.75,1329.06 1497.75,1329.08 1497.75,1329.11 1497.75,1329.14 1497.75,1329.17 1497.75,1329.2 1497.75,1329.23 1497.75,1329.25 1497.75,1329.28 1497.75,1329.31 1497.75,1329.34 1497.75,1329.37 1497.75,1329.39 1497.75,1329.42 1497.75,1329.45 1497.75,1329.48 1497.75,1329.51 1497.75,1329.54 1497.75,1329.56 1497.75,1329.59 1497.75,1329.62 1497.75,1329.65 1497.75,1329.68 1497.75,1329.7 1497.75,1329.73 1497.75,1329.76 1497.75,1329.79 1497.75,1329.82 1497.75,1329.84 1497.75,1329.87 1497.75,1329.9 1497.75,1329.93 1497.75,1329.96 1497.75,1329.98 1497.75,1330.01 1497.75,1330.04 1497.75,1330.07 1497.75,1330.1 1497.75,1330.12 1497.75,1330.15 1497.75,1330.18 1497.75,1330.21 1497.75,1330.24 1497.75,1330.26 1497.75,1330.29 1497.75,1330.32 1497.75,1330.35 1497.75,1330.38 1497.75,1330.4 1497.75,1330.43 1497.75,1330.46 1497.75,1330.49 1497.75,1330.51 1497.75,1330.54 1497.75,1330.57 1497.75,1330.6 1497.75,1330.63 1497.75,1330.65 1497.75,1330.68 1497.75,1330.71 1497.75,1330.74 1497.75,1330.76 1497.75,1330.79 1497.75,1330.82 1497.75,1330.85 1497.75,1330.88 1497.75,1330.9 1497.75,1330.93 1497.75,1330.96 1497.75,1330.99 1497.75,1331.01 1497.75,1331.04 1497.75,1331.07 1497.75,1331.1 1497.75,1331.12 1497.75,1331.15 1497.75,1331.18 1497.75,1331.21 1497.75,1331.24 1497.75,1331.26 1497.75,1331.29 1497.75,1331.32 1497.75,1331.35 1497.75,1331.37 1497.75,1331.4 1497.75,1331.43 1497.75,1331.46 1497.75,1331.48 1497.75,1331.51 1497.75,1331.54 1497.75,1331.57 1497.75,1331.59 1497.75,1331.62 1497.75,1331.65 1497.75,1331.68 1497.75,1331.7 1497.75,1331.73 1497.75,1331.76 1497.75,1331.79 1497.75,1331.81 1497.75,1331.84 1497.75,1331.87 1497.75,1331.9 1497.75,1331.92 1497.75,1331.95 1497.75,1331.98 1497.75,1332.01 1497.75,1332.03 1497.75,1332.06 1497.75,1332.09 1497.75,1332.11 1497.75,1332.14 1497.75,1332.17 1497.75,1332.2 1497.75,1332.22 1497.75,1332.25 1497.75,1332.28 1497.75,1332.31 1497.75,1332.33 1497.75,1332.36 1497.75,1332.39 1497.75,1332.42 1497.75,1332.44 1497.75,1332.47 1497.75,1332.5 1497.75,1332.52 1497.75,1332.55 1497.75,1332.58 1497.75,1332.61 1497.75,1332.63 1497.75,1332.66 1497.75,1332.69 1497.75,1332.71 1497.75,1332.74 1497.75,1332.77 1497.75,1332.8 1497.75,1332.82 1497.75,1332.85 1497.75,1332.88 1497.75,1332.9 1497.75,1332.93 1497.75,1332.96 1497.75,1332.99 1497.75,1333.01 1497.75,1333.04 1497.75,1333.07 1497.75,1333.09 1497.75,1333.12 1497.75,1333.15 1497.75,1333.18 1497.75,1333.2 1497.75,1333.23 1497.75,1333.26 1497.75,1333.28 1497.75,1333.31 1497.75,1333.34 1497.75,1333.36 1497.75,1333.39 1497.75,1333.42 1497.75,1333.45 1497.75,1333.47 1497.75,1333.5 1497.75,1333.53 1497.75,1333.55 1497.75,1333.58 1497.75,1333.61 1497.75,1333.63 1497.75,1333.66 1497.75,1333.69 1497.75,1333.71 1497.75,1333.74 1497.75,1333.77 1497.75,1333.79 1497.75,1333.82 1497.75,1333.85 1497.75,1333.88 1497.75,1333.9 1497.75,1333.93 1497.75,1333.96 1497.75,1333.98 1497.75,1334.01 1497.75,1334.04 1497.75,1334.06 1497.75,1334.09 1497.75,1334.12 1497.75,1334.14 1497.75,1334.17 1497.75,1334.2 1497.75,1334.22 1497.75,1334.25 1497.75,1334.28 1497.75,1334.3 1497.75,1334.33 1497.75,1334.36 1497.75,1334.38 1497.75,1334.41 1497.75,1334.44 1497.75,1334.46 1497.75,1334.49 1497.75,1334.52 1497.75,1334.54 1497.75,1334.57 1497.75,1334.6 1497.75,1334.62 1497.75,1334.65 1497.75,1334.68 1497.75,1334.7 1497.75,1334.73 1497.75,1334.76 1497.75,1334.78 1497.75,1334.81 1497.75,1334.84 1497.75,1334.86 1497.75,1334.89 1497.75,1334.92 1497.75,1334.94 1497.75,1334.97 1497.75,1334.99 1497.75,1335.02 1497.75,1335.05 1497.75,1335.07 1497.75,1335.1 1497.75,1335.13 1497.75,1335.15 1497.75,1335.18 1497.75,1335.21 1497.75,1335.23 1497.75,1335.26 1497.75,1335.29 1497.75,1335.31 1497.75,1335.34 1497.75,1335.36 1497.75,1335.39 1497.75,1335.42 1497.75,1335.44 1497.75,1335.47 1497.75,1335.5 1497.75,1335.52 1497.75,1335.55 1497.75,1335.58 1497.75,1335.6 1497.75,1335.63 1497.75,1335.65 1497.75,1335.68 1497.75,1335.71 1497.75,1335.73 1497.75,1335.76 1497.75,1335.79 1497.75,1335.81 1497.75,1335.84 1497.75,1335.86 1497.75,1335.89 1497.75,1335.92 1497.75,1335.94 1497.75,1335.97 1497.75,1336 1497.75,1336.02 1497.75,1336.05 1497.75,1336.07 1497.75,1336.1 1497.75,1336.13 1497.75,1336.15 1497.75,1336.18 1497.75,1336.2 1497.75,1336.23 1497.75,1336.26 1497.75,1336.28 1497.75,1336.31 1497.75,1336.33 1497.75,1336.36 1497.75,1336.39 1497.75,1336.41 1497.75,1336.44 1497.75,1336.47 1497.75,1336.49 1497.75,1336.52 1497.75,1336.54 1497.75,1336.57 1497.75,1336.6 1497.75,1336.62 1497.75,1336.65 1497.75,1336.67 1497.75,1336.7 1497.75,1336.73 1497.75,1336.75 1497.75,1336.78 1497.75,1336.8 1497.75,1336.83 1497.75,1336.85 1497.75,1336.88 1497.75,1336.91 1497.75,1336.93 1497.75,1336.96 1497.75,1336.98 1497.75,1337.01 1497.75,1337.04 1497.75,1337.06 1497.75,1337.09 1497.75,1337.11 1497.75,1337.14 1497.75,1337.17 1497.75,1337.19 1497.75,1337.22 1497.75,1337.24 1497.75,1337.27 1497.75,1337.29 1497.75,1337.32 1497.75,1337.35 1497.75,1337.37 1497.75,1337.4 1497.75,1337.42 1497.75,1337.45 1497.75,1337.47 1497.75,1337.5 1497.75,1337.53 1497.75,1337.55 1497.75,1337.58 1497.75,1337.6 1497.75,1337.63 1497.75,1337.65 1497.75,1337.68 1497.75,1337.71 1497.75,1337.73 1497.75,1337.76 1497.75,1337.78 1497.75,1337.81 1497.75,1337.83 1497.75,1337.86 1497.75,1337.88 1497.75,1337.91 1497.75,1337.94 1497.75,1337.96 1497.75,1337.99 1497.75,1338.01 1497.75,1338.04 1497.75,1338.06 1497.75,1338.09 1497.75,1338.12 1497.75,1338.14 1497.75,1338.17 1497.75,1338.19 1497.75,1338.22 1497.75,1338.24 1497.75,1338.27 1497.75,1338.29 1497.75,1338.32 1497.75,1338.34 1497.75,1338.37 1497.75,1338.4 1497.75,1338.42 1497.75,1338.45 1497.75,1338.47 1497.75,1338.5 1497.75,1338.52 1497.75,1338.55 1497.75,1338.57 1497.75,1338.6 1497.75,1338.62 1497.75,1338.65 1497.75,1338.67 1497.75,1338.7 1497.75,1338.73 1497.75,1338.75 1497.75,1338.78 1497.75,1338.8 1497.75,1338.83 1497.75,1338.85 1497.75,1338.88 1497.75,1338.9 1497.75,1338.93 1497.75,1338.95 1497.75,1338.98 1497.75,1339 1497.75,1339.03 1497.75,1339.05 1497.75,1339.08 1497.75,1339.1 1497.75,1339.13 1497.75,1339.16 1497.75,1339.18 1497.75,1339.21 1497.75,1339.23 1497.75,1339.26 1497.75,1339.28 1497.75,1339.31 1497.75,1339.33 1497.75,1339.36 1497.75,1339.38 1497.75,1339.41 1497.75,1339.43 1497.75,1339.46 1497.75,1339.48 1497.75,1339.51 1497.75,1339.53 1497.75,1339.56 1497.75,1339.58 1497.75,1339.61 1497.75,1339.63 1497.75,1339.66 1497.75,1339.68 1497.75,1339.71 1497.75,1339.73 1497.75,1339.76 1497.75,1339.78 1497.75,1339.81 1497.75,1339.83 1497.75,1339.86 1497.75,1339.88 1497.75,1339.91 1497.75,1339.93 1497.75,1339.96 1497.75,1339.98 1497.75,1340.01 1497.75,1340.03 1497.75,1340.06 1497.75,1340.08 1497.75,1340.11 1497.75,1340.13 1497.75,1340.16 1497.75,1340.18 1497.75,1340.21 1497.75,1340.23 1497.75,1340.26 1497.75,1340.28 1497.75,1340.31 1497.75,1340.33 1497.75,1340.36 1497.75,1340.38 1497.75,1340.41 1497.75,1340.43 1497.75,1340.46 1497.75,1340.48 1497.75,1340.51 1497.75,1340.53 1497.75,1340.55 1497.75,1340.58 1497.75,1340.6 1497.75,1340.63 1497.75,1340.65 1497.75,1340.68 1497.75,1340.7 1497.75,1340.73 1497.75,1340.75 1497.75,1340.78 1497.75,1340.8 1497.75,1340.83 1497.75,1340.85 1497.75,1340.88 1497.75,1340.9 1497.75,1340.93 1497.75,1340.95 1497.75,1340.97 1497.75,1341 1497.75,1341.02 1497.75,1341.05 1497.75,1341.07 1497.75,1341.1 1497.75,1341.12 1497.75,1341.15 1497.75,1341.17 1497.75,1341.2 1497.75,1341.22 1497.75,1341.25 1497.75,1341.27 1497.75,1341.29 1497.75,1341.32 1497.75,1341.34 1497.75,1341.37 1497.75,1341.39 1497.75,1341.42 1497.75,1341.44 1497.75,1341.47 1497.75,1341.49 1497.75,1341.52 1497.75,1341.54 1497.75,1341.56 1497.75,1341.59 1497.75,1341.61 1497.75,1341.64 1497.75,1341.66 1497.75,1341.69 1497.75,1341.71 1497.75,1341.74 1497.75,1341.76 1497.75,1341.78 1497.75,1341.81 1497.75,1341.83 1497.75,1341.86 1497.75,1341.88 1497.75,1341.91 1497.75,1341.93 1497.75,1341.95 1497.75,1341.98 1497.75,1342 1497.75,1342.03 1497.75,1342.05 1497.75,1342.08 1497.75,1342.1 1497.75,1342.12 1497.75,1342.15 1497.75,1342.17 1497.75,1342.2 1497.75,1342.22 1497.75,1342.25 1497.75,1342.27 1497.75,1342.29 1497.75,1342.32 1497.75,1342.34 1497.75,1342.37 1497.75,1342.39 1497.75,1342.42 1497.75,1342.44 1497.75,1342.46 1497.75,1342.49 1497.75,1342.51 1497.75,1342.54 1497.75,1342.56 1497.75,1342.58 1497.75,1342.61 1497.75,1342.63 1497.75,1342.66 1497.75,1342.68 1497.75,1342.71 1497.75,1342.73 1497.75,1342.75 1497.75,1342.78 1497.75,1342.8 1497.75,1342.83 1497.75,1342.85 1497.75,1342.87 1497.75,1342.9 1497.75,1342.92 1497.75,1342.95 1497.75,1342.97 1497.75,1342.99 1497.75,1343.02 1497.75,1343.04 1497.75,1343.07 1497.75,1343.09 1497.75,1343.11 1497.75,1343.14 1497.75,1343.16 1497.75,1343.19 1497.75,1343.21 1497.75,1343.23 1497.75,1343.26 1497.75,1343.28 1497.75,1343.31 1497.75,1343.33 1497.75,1343.35 1497.75,1343.38 1497.75,1343.4 1497.75,1343.43 1497.75,1343.45 1497.75,1343.47 1497.75,1343.5 1497.75,1343.52 1497.75,1343.54 1497.75,1343.57 1497.75,1343.59 1497.75,1343.62 1497.75,1343.64 1497.75,1343.66 1497.75,1343.69 1497.75,1343.71 1497.75,1343.73 1497.75,1343.76 1497.75,1343.78 1497.75,1343.81 1497.75,1343.83 1497.75,1343.85 1497.75,1343.88 1497.75,1343.9 1497.75,1343.92 1497.75,1343.95 1497.75,1343.97 1497.75,1344 1497.75,1344.02 1497.75,1344.04 1497.75,1344.07 1497.75,1344.09 1497.75,1344.11 1497.75,1344.14 1497.75,1344.16 1497.75,1344.19 1497.75,1344.21 1497.75,1344.23 1497.75,1344.26 1497.75,1344.28 1497.75,1344.3 1497.75,1344.33 1497.75,1344.35 1497.75,1344.37 1497.75,1344.4 1497.75,1344.42 1497.75,1344.45 1497.75,1344.47 1497.75,1344.49 1497.75,1344.52 1497.75,1344.54 1497.75,1344.56 1497.75,1344.59 1497.75,1344.61 1497.75,1344.63 1497.75,1344.66 1497.75,1344.68 1497.75,1344.7 1497.75,1344.73 1497.75,1344.75 1497.75,1344.77 1497.75,1344.8 1497.75,1344.82 1497.75,1344.84 1497.75,1344.87 1497.75,1344.89 1497.75,1344.91 1497.75,1344.94 1497.75,1344.96 1497.75,1344.98 1497.75,1345.01 1497.75,1345.03 1497.75,1345.06 1497.75,1345.08 1497.75,1345.1 1497.75,1345.13 1497.75,1345.15 1497.75,1345.17 1497.75,1345.2 1497.75,1345.22 1497.75,1345.24 1497.75,1345.27 1497.75,1345.29 1497.75,1345.31 1497.75,1345.34 1497.75,1345.36 1497.75,1345.38 1497.75,1345.4 1497.75,1345.43 1497.75,1345.45 1497.75,1345.47 1497.75,1345.5 1497.75,1345.52 1497.75,1345.54 1497.75,1345.57 1497.75,1345.59 1497.75,1345.61 1497.75,1345.64 1497.75,1345.66 1497.75,1345.68 1497.75,1345.71 1497.75,1345.73 1497.75,1345.75 1497.75,1345.78 1497.75,1345.8 1497.75,1345.82 1497.75,1345.85 1497.75,1345.87 1497.75,1345.89 1497.75,1345.91 1497.75,1345.94 1497.75,1345.96 1497.75,1345.98 1497.75,1346.01 1497.75,1346.03 1497.75,1346.05 1497.75,1346.08 1497.75,1346.1 1497.75,1346.12 1497.75,1346.15 1497.75,1346.17 1497.75,1346.19 1497.75,1346.21 1497.75,1346.24 1497.75,1346.26 1497.75,1346.28 1497.75,1346.31 1497.75,1346.33 1497.75,1346.35 1497.75,1346.38 1497.75,1346.4 1497.75,1346.42 1497.75,1346.44 1497.75,1346.47 1497.75,1346.49 1497.75,1346.51 1497.75,1346.54 1497.75,1346.56 1497.75,1346.58 1497.75,1346.6 1497.75,1346.63 1497.75,1346.65 1497.75,1346.67 1497.75,1346.7 1497.75,1346.72 1497.75,1346.74 1497.75,1346.76 1497.75,1346.79 1497.75,1346.81 1497.75,1346.83 1497.75,1346.86 1497.75,1346.88 1497.75,1346.9 1497.75,1346.92 1497.75,1346.95 1497.75,1346.97 1497.75,1346.99 1497.75,1347.02 1497.75,1347.04 1497.75,1347.06 1497.75,1347.08 1497.75,1347.11 1497.75,1347.13 1497.75,1347.15 1497.75,1347.17 1497.75,1347.2 1497.75,1347.22 1497.75,1347.24 1497.75,1347.26 1497.75,1347.29 1497.75,1347.31 1497.75,1347.33 1497.75,1347.36 1497.75,1347.38 1497.75,1347.4 1497.75,1347.42 1497.75,1347.45 1497.75,1347.47 1497.75,1347.49 1497.75,1347.51 1497.75,1347.54 1497.75,1347.56 1497.75,1347.58 1497.75,1347.6 1497.75,1347.63 1497.75,1347.65 1497.75,1347.67 1497.75,1347.69 1497.75,1347.72 1497.75,1347.74 1497.75,1347.76 1497.75,1347.78 1497.75,1347.81 1497.75,1347.83 1497.75,1347.85 1497.75,1347.87 1497.75,1347.9 1497.75,1347.92 1497.75,1347.94 1497.75,1347.96 1497.75,1347.99 1497.75,1348.01 1497.75,1348.03 1497.75,1348.05 1497.75,1348.08 1497.75,1348.1 1497.75,1348.12 1497.75,1348.14 1497.75,1348.17 1497.75,1348.19 1497.75,1348.21 1497.75,1348.23 1497.75,1348.26 1497.75,1348.28 1497.75,1348.3 1497.75,1348.32 1497.75,1348.34 1497.75,1348.37 1497.75,1348.39 1497.75,1348.41 1497.75,1348.43 1497.75,1348.46 1497.75,1348.48 1497.75,1348.5 1497.75,1348.52 1497.75,1348.55 1497.75,1348.57 1497.75,1348.59 1497.75,1348.61 1497.75,1348.63 1497.75,1348.66 1497.75,1348.68 1497.75,1348.7 1497.75,1348.72 1497.75,1348.75 1497.75,1348.77 1497.75,1348.79 1497.75,1348.81 1497.75,1348.83 1497.75,1348.86 1497.75,1348.88 1497.75,1348.9 1497.75,1348.92 1497.75,1348.95 1497.75,1348.97 1497.75,1348.99 1497.75,1349.01 1497.75,1349.03 1497.75,1349.06 1497.75,1349.08 1497.75,1349.1 1497.75,1349.12 1497.75,1349.14 1497.75,1349.17 1497.75,1349.19 1497.75,1349.21 1497.75,1349.23 1497.75,1349.25 1497.75,1349.28 1497.75,1349.3 1497.75,1349.32 1497.75,1349.34 1497.75,1349.36 1497.75,1349.39 1497.75,1349.41 1497.75,1349.43 1497.75,1349.45 1497.75,1349.47 1497.75,1349.5 1497.75,1349.52 1497.75,1349.54 1497.75,1349.56 1497.75,1349.58 1497.75,1349.61 1497.75,1349.63 1497.75,1349.65 1497.75,1349.67 1497.75,1349.69 1497.75,1349.72 1497.75,1349.74 1497.75,1349.76 1497.75,1349.78 1497.75,1349.8 1497.75,1349.82 1497.75,1349.85 1497.75,1349.87 1497.75,1349.89 1497.75,1349.91 1497.75,1349.93 1497.75,1349.96 1497.75,1349.98 1497.75,1350 1497.75,1350.02 1497.75,1350.04 1497.75,1350.06 1497.75,1350.09 1497.75,1350.11 1497.75,1350.13 1497.75,1350.15 1497.75,1350.17 1497.75,1350.2 1497.75,1350.22 1497.75,1350.24 1497.75,1350.26 1497.75,1350.28 1497.75,1350.3 1497.75,1350.33 1497.75,1350.35 1497.75,1350.37 1497.75,1350.39 1497.75,1350.41 1497.75,1350.43 1497.75,1350.46 1497.75,1350.48 1497.75,1350.5 1497.75,1350.52 1497.75,1350.54 1497.75,1350.56 1497.75,1350.59 1497.75,1350.61 1497.75,1350.63 1497.75,1350.65 1497.75,1350.67 1497.75,1350.69 1497.75,1350.72 1497.75,1350.74 1497.75,1350.76 1497.75,1350.78 1497.75,1350.8 1497.75,1350.82 1497.75,1350.84 1497.75,1350.87 1497.75,1350.89 1497.75,1350.91 1497.75,1350.93 1497.75,1350.95 1497.75,1350.97 1497.75,1350.99 1497.75,1351.02 1497.75,1351.04 1497.75,1351.06 1497.75,1351.08 1497.75,1351.1 1497.75,1351.12 1497.75,1351.15 1497.75,1351.17 1497.75,1351.19 1497.75,1351.21 1497.75,1351.23 1497.75,1351.25 1497.75,1351.27 1497.75,1351.29 1497.75,1351.32 1497.75,1351.34 1497.75,1351.36 1497.75,1351.38 1497.75,1351.4 1497.75,1351.42 1497.75,1351.44 1497.75,1351.47 1497.75,1351.49 1497.75,1351.51 1497.75,1351.53 1497.75,1351.55 1497.75,1351.57 1497.75,1351.59 1497.75,1351.61 1497.75,1351.64 1497.75,1351.66 1497.75,1351.68 1497.75,1351.7 1497.75,1351.72 1497.75,1351.74 1497.75,1351.76 1497.75,1351.78 1497.75,1351.81 1497.75,1351.83 1497.75,1351.85 1497.75,1351.87 1497.75,1351.89 1497.75,1351.91 1497.75,1351.93 1497.75,1351.95 1497.75,1351.98 1497.75,1352 1497.75,1352.02 1497.75,1352.04 1497.75,1352.06 1497.75,1352.08 1497.75,1352.1 1497.75,1352.12 1497.75,1352.14 1497.75,1352.17 1497.75,1352.19 1497.75,1352.21 1497.75,1352.23 1497.75,1352.25 1497.75,1352.27 1497.75,1352.29 1497.75,1352.31 1497.75,1352.33 1497.75,1352.36 1497.75,1352.38 1497.75,1352.4 1497.75,1352.42 1497.75,1352.44 1497.75,1352.46 1497.75,1352.48 1497.75,1352.5 1497.75,1352.52 1497.75,1352.54 1497.75,1352.57 1497.75,1352.59 1497.75,1352.61 1497.75,1352.63 1497.75,1352.65 1497.75,1352.67 1497.75,1352.69 1497.75,1352.71 1497.75,1352.73 1497.75,1352.75 1497.75,1352.77 1497.75,1352.8 1497.75,1352.82 1497.75,1352.84 1497.75,1352.86 1497.75,1352.88 1497.75,1352.9 1497.75,1352.92 1497.75,1352.94 1497.75,1352.96 1497.75,1352.98 1497.75,1353 1497.75,1353.03 1497.75,1353.05 1497.75,1353.07 1497.75,1353.09 1497.75,1353.11 1497.75,1353.13 1497.75,1353.15 1497.75,1353.17 1497.75,1353.19 1497.75,1353.21 1497.75,1353.23 1497.75,1353.25 1497.75,1353.27 1497.75,1353.3 1497.75,1353.32 1497.75,1353.34 1497.75,1353.36 1497.75,1353.38 1497.75,1353.4 1497.75,1353.42 1497.75,1353.44 1497.75,1353.46 1497.75,1353.48 1497.75,1353.5 1497.75,1353.52 1497.75,1353.54 1497.75,1353.56 1497.75,1353.59 1497.75,1353.61 1497.75,1353.63 1497.75,1353.65 1497.75,1353.67 1497.75,1353.69 1497.75,1353.71 1497.75,1353.73 1497.75,1353.75 1497.75,1353.77 1497.75,1353.79 1497.75,1353.81 1497.75,1353.83 1497.75,1353.85 1497.75,1353.87 1497.75,1353.89 1497.75,1353.91 1497.75,1353.94 1497.75,1353.96 1497.75,1353.98 1497.75,1354 1497.75,1354.02 1497.75,1354.04 1497.75,1354.06 1497.75,1354.08 1497.75,1354.1 1497.75,1354.12 1497.75,1354.14 1497.75,1354.16 1497.75,1354.18 1497.75,1354.2 1497.75,1354.22 1497.75,1354.24 1497.75,1354.26 1497.75,1354.28 1497.75,1354.3 1497.75,1354.32 1497.75,1354.34 1497.75,1354.36 1497.75,1354.39 1497.75,1354.41 1497.75,1354.43 1497.75,1354.45 1497.75,1354.47 1497.75,1354.49 1497.75,1354.51 1497.75,1354.53 1497.75,1354.55 1497.75,1354.57 1497.75,1354.59 1497.75,1354.61 1497.75,1354.63 1497.75,1354.65 1497.75,1354.67 1497.75,1354.69 1497.75,1354.71 1497.75,1354.73 1497.75,1354.75 1497.75,1354.77 1497.75,1354.79 1497.75,1354.81 1497.75,1354.83 1497.75,1354.85 1497.75,1354.87 1497.75,1354.89 1497.75,1354.91 1497.75,1354.93 1497.75,1354.95 1497.75,1354.97 1497.75,1354.99 1497.75,1355.01 1497.75,1355.03 1497.75,1355.05 1497.75,1355.07 1497.75,1355.09 1497.75,1355.11 1497.75,1355.13 1497.75,1355.16 1497.75,1355.18 1497.75,1355.2 1497.75,1355.22 1497.75,1355.24 1497.75,1355.26 1497.75,1355.28 1497.75,1355.3 1497.75,1355.32 1497.75,1355.34 1497.75,1355.36 1497.75,1355.38 1497.75,1355.4 1497.75,1355.42 1497.75,1355.44 1497.75,1355.46 1497.75,1355.48 1497.75,1355.5 1497.75,1355.52 1497.75,1355.54 1497.75,1355.56 1497.75,1355.58 1497.75,1355.6 1497.75,1355.62 1497.75,1355.64 1497.75,1355.66 1497.75,1355.68 1497.75,1355.7 1497.75,1355.72 1497.75,1355.74 1497.75,1355.76 1497.75,1355.78 1497.75,1355.8 1497.75,1355.82 1497.75,1355.84 1497.75,1355.86 1497.75,1355.88 1497.75,1355.9 1497.75,1355.92 1497.75,1355.94 1497.75,1355.96 1497.75,1355.98 1497.75,1355.99 1497.75,1356.01 1497.75,1356.03 1497.75,1356.05 1497.75,1356.07 1497.75,1356.09 1497.75,1356.11 1497.75,1356.13 1497.75,1356.15 1497.75,1356.17 1497.75,1356.19 1497.75,1356.21 1497.75,1356.23 1497.75,1356.25 1497.75,1356.27 1497.75,1356.29 1497.75,1356.31 1497.75,1356.33 1497.75,1356.35 1497.75,1356.37 1497.75,1356.39 1497.75,1356.41 1497.75,1356.43 1497.75,1356.45 1497.75,1356.47 1497.75,1356.49 1497.75,1356.51 1497.75,1356.53 1497.75,1356.55 1497.75,1356.57 1497.75,1356.59 1497.75,1356.61 1497.75,1356.63 1497.75,1356.65 1497.75,1356.67 1497.75,1356.69 1497.75,1356.71 1497.75,1356.73 1497.75,1356.75 1497.75,1356.76 1497.75,1356.78 1497.75,1356.8 1497.75,1356.82 1497.75,1356.84 1497.75,1356.86 1497.75,1356.88 1497.75,1356.9 1497.75,1356.92 1497.75,1356.94 1497.75,1356.96 1497.75,1356.98 1497.75,1357 1497.75,1357.02 1497.75,1357.04 1497.75,1357.06 1497.75,1357.08 1497.75,1357.1 1497.75,1357.12 1497.75,1357.14 1497.75,1357.16 1497.75,1357.18 1497.75,1357.19 1497.75,1357.21 1497.75,1357.23 1497.75,1357.25 1497.75,1357.27 1497.75,1357.29 1497.75,1357.31 1497.75,1357.33 1497.75,1357.35 1497.75,1357.37 1497.75,1357.39 1497.75,1357.41 1497.75,1357.43 1497.75,1357.45 1497.75,1357.47 1497.75,1357.49 1497.75,1357.51 1497.75,1357.52 1497.75,1357.54 1497.75,1357.56 1497.75,1357.58 1497.75,1357.6 1497.75,1357.62 1497.75,1357.64 1497.75,1357.66 1497.75,1357.68 1497.75,1357.7 1497.75,1357.72 1497.75,1357.74 1497.75,1357.76 1497.75,1357.78 1497.75,1357.79 1497.75,1357.81 1497.75,1357.83 1497.75,1357.85 1497.75,1357.87 1497.75,1357.89 1497.75,1357.91 1497.75,1357.93 1497.75,1357.95 1497.75,1357.97 1497.75,1357.99 1497.75,1358.01 1497.75,1358.03 1497.75,1358.04 1497.75,1358.06 1497.75,1358.08 1497.75,1358.1 1497.75,1358.12 1497.75,1358.14 1497.75,1358.16 1497.75,1358.18 1497.75,1358.2 1497.75,1358.22 1497.75,1358.24 1497.75,1358.26 1497.75,1358.27 1497.75,1358.29 1497.75,1358.31 1497.75,1358.33 1497.75,1358.35 1497.75,1358.37 1497.75,1358.39 1497.75,1358.41 1497.75,1358.43 1497.75,1358.45 1497.75,1358.47 1497.75,1358.48 1497.75,1358.5 1497.75,1358.52 1497.75,1358.54 1497.75,1358.56 1497.75,1358.58 1497.75,1358.6 1497.75,1358.62 1497.75,1358.64 1497.75,1358.66 1497.75,1358.67 1497.75,1358.69 1497.75,1358.71 1497.75,1358.73 1497.75,1358.75 1497.75,1358.77 1497.75,1358.79 1497.75,1358.81 1497.75,1358.83 1497.75,1358.85 1497.75,1358.86 1497.75,1358.88 1497.75,1358.9 1497.75,1358.92 1497.75,1358.94 1497.75,1358.96 1497.75,1358.98 1497.75,1359 1497.75,1359.02 1497.75,1359.03 1497.75,1359.05 1497.75,1359.07 1497.75,1359.09 1497.75,1359.11 1497.75,1359.13 1497.75,1359.15 1497.75,1359.17 1497.75,1359.19 1497.75,1359.2 1497.75,1359.22 1497.75,1359.24 1497.75,1359.26 1497.75,1359.28 1497.75,1359.3 1497.75,1359.32 1497.75,1359.34 1497.75,1359.35 1497.75,1359.37 1497.75,1359.39 1497.75,1359.41 1497.75,1359.43 1497.75,1359.45 1497.75,1359.47 1497.75,1359.49 1497.75,1359.5 1497.75,1359.52 1497.75,1359.54 1497.75,1359.56 1497.75,1359.58 1497.75,1359.6 1497.75,1359.62 1497.75,1359.63 1497.75,1359.65 1497.75,1359.67 1497.75,1359.69 1497.75,1359.71 1497.75,1359.73 1497.75,1359.75 1497.75,1359.77 1497.75,1359.78 1497.75,1359.8 1497.75,1359.82 1497.75,1359.84 1497.75,1359.86 1497.75,1359.88 1497.75,1359.9 1497.75,1359.91 1497.75,1359.93 1497.75,1359.95 1497.75,1359.97 1497.75,1359.99 1497.75,1360.01 1497.75,1360.03 1497.75,1360.04 1497.75,1360.06 1497.75,1360.08 1497.75,1360.1 1497.75,1360.12 1497.75,1360.14 1497.75,1360.16 1497.75,1360.17 1497.75,1360.19 1497.75,1360.21 1497.75,1360.23 1497.75,1360.25 1497.75,1360.27 1497.75,1360.28 1497.75,1360.3 1497.75,1360.32 1497.75,1360.34 1497.75,1360.36 1497.75,1360.38 1497.75,1360.4 1497.75,1360.41 1497.75,1360.43 1497.75,1360.45 1497.75,1360.47 1497.75,1360.49 1497.75,1360.51 1497.75,1360.52 1497.75,1360.54 1497.75,1360.56 1497.75,1360.58 1497.75,1360.6 1497.75,1360.62 1497.75,1360.63 1497.75,1360.65 1497.75,1360.67 1497.75,1360.69 1497.75,1360.71 1497.75,1360.73 1497.75,1360.74 1497.75,1360.76 1497.75,1360.78 1497.75,1360.8 1497.75,1360.82 1497.75,1360.84 1497.75,1360.85 1497.75,1360.87 1497.75,1360.89 1497.75,1360.91 1497.75,1360.93 1497.75,1360.94 1497.75,1360.96 1497.75,1360.98 1497.75,1361 1497.75,1361.02 1497.75,1361.04 1497.75,1361.05 1497.75,1361.07 1497.75,1361.09 1497.75,1361.11 1497.75,1361.13 1497.75,1361.15 1497.75,1361.16 1497.75,1361.18 1497.75,1361.2 1497.75,1361.22 1497.75,1361.24 1497.75,1361.25 1497.75,1361.27 1497.75,1361.29 1497.75,1361.31 1497.75,1361.33 1497.75,1361.34 1497.75,1361.36 1497.75,1361.38 1497.75,1361.4 1497.75,1361.42 1497.75,1361.43 1497.75,1361.45 1497.75,1361.47 1497.75,1361.49 1497.75,1361.51 1497.75,1361.53 1497.75,1361.54 1497.75,1361.56 1497.75,1361.58 1497.75,1361.6 1497.75,1361.62 1497.75,1361.63 1497.75,1361.65 1497.75,1361.67 1497.75,1361.69 1497.75,1361.71 1497.75,1361.72 1497.75,1361.74 1497.75,1361.76 1497.75,1361.78 1497.75,1361.8 1497.75,1361.81 1497.75,1361.83 1497.75,1361.85 1497.75,1361.87 1497.75,1361.88 1497.75,1361.9 1497.75,1361.92 1497.75,1361.94 1497.75,1361.96 1497.75,1361.97 1497.75,1361.99 1497.75,1362.01 1497.75,1362.03 1497.75,1362.05 1497.75,1362.06 1497.75,1362.08 1497.75,1362.1 1497.75,1362.12 1497.75,1362.14 1497.75,1362.15 1497.75,1362.17 1497.75,1362.19 1497.75,1362.21 1497.75,1362.22 1497.75,1362.24 1497.75,1362.26 1497.75,1362.28 1497.75,1362.3 1497.75,1362.31 1497.75,1362.33 1497.75,1362.35 1497.75,1362.37 1497.75,1362.38 1497.75,1362.4 1497.75,1362.42 1497.75,1362.44 1497.75,1362.46 1497.75,1362.47 1497.75,1362.49 1497.75,1362.51 1497.75,1362.53 1497.75,1362.54 1497.75,1362.56 1497.75,1362.58 1497.75,1362.6 1497.75,1362.61 1497.75,1362.63 1497.75,1362.65 1497.75,1362.67 1497.75,1362.69 1497.75,1362.7 1497.75,1362.72 1497.75,1362.74 1497.75,1362.76 1497.75,1362.77 1497.75,1362.79 1497.75,1362.81 1497.75,1362.83 1497.75,1362.84 1497.75,1362.86 1497.75,1362.88 1497.75,1362.9 1497.75,1362.91 1497.75,1362.93 1497.75,1362.95 1497.75,1362.97 1497.75,1362.98 1497.75,1363 1497.75,1363.02 1497.75,1363.04 1497.75,1363.05 1497.75,1363.07 1497.75,1363.09 1497.75,1363.11 1497.75,1363.12 1497.75,1363.14 1497.75,1363.16 1497.75,1363.18 1497.75,1363.19 1497.75,1363.21 1497.75,1363.23 1497.75,1363.25 1497.75,1363.26 1497.75,1363.28 1497.75,1363.3 1497.75,1363.32 1497.75,1363.33 1497.75,1363.35 1497.75,1363.37 1497.75,1363.39 1497.75,1363.4 1497.75,1363.42 1497.75,1363.44 1497.75,1363.46 1497.75,1363.47 1497.75,1363.49 1497.75,1363.51 1497.75,1363.53 1497.75,1363.54 1497.75,1363.56 1497.75,1363.58 1497.75,1363.6 1497.75,1363.61 1497.75,1363.63 1497.75,1363.65 1497.75,1363.66 1497.75,1363.68 1497.75,1363.7 1497.75,1363.72 1497.75,1363.73 1497.75,1363.75 1497.75,1363.77 1497.75,1363.79 1497.75,1363.8 1497.75,1363.82 1497.75,1363.84 1497.75,1363.86 1497.75,1363.87 1497.75,1363.89 1497.75,1363.91 1497.75,1363.92 1497.75,1363.94 1497.75,1363.96 1497.75,1363.98 1497.75,1363.99 1497.75,1364.01 1497.75,1364.03 1497.75,1364.04 1497.75,1364.06 1497.75,1364.08 1497.75,1364.1 1497.75,1364.11 1497.75,1364.13 1497.75,1364.15 1497.75,1364.17 1497.75,1364.18 1497.75,1364.2 1497.75,1364.22 1497.75,1364.23 1497.75,1364.25 1497.75,1364.27 1497.75,1364.29 1497.75,1364.3 1497.75,1364.32 1497.75,1364.34 1497.75,1364.35 1497.75,1364.37 1497.75,1364.39 1497.75,1364.4 1497.75,1364.42 1497.75,1364.44 1497.75,1364.46 1497.75,1364.47 1497.75,1364.49 1497.75,1364.51 1497.75,1364.52 1497.75,1364.54 1497.75,1364.56 1497.75,1364.58 1497.75,1364.59 1497.75,1364.61 1497.75,1364.63 1497.75,1364.64 1497.75,1364.66 1497.75,1364.68 1497.75,1364.69 1497.75,1364.71 1497.75,1364.73 1497.75,1364.75 1497.75,1364.76 1497.75,1364.78 1497.75,1364.8 1497.75,1364.81 1497.75,1364.83 1497.75,1364.85 1497.75,1364.86 1497.75,1364.88 1497.75,1364.9 1497.75,1364.91 1497.75,1364.93 1497.75,1364.95 1497.75,1364.97 1497.75,1364.98 1497.75,1365 1497.75,1365.02 1497.75,1365.03 1497.75,1365.05 1497.75,1365.07 1497.75,1365.08 1497.75,1365.1 1497.75,1365.12 1497.75,1365.13 1497.75,1365.15 1497.75,1365.17 1497.75,1365.18 1497.75,1365.2 1497.75,1365.22 1497.75,1365.24 1497.75,1365.25 1497.75,1365.27 1497.75,1365.29 1497.75,1365.3 1497.75,1365.32 1497.75,1365.34 1497.75,1365.35 1497.75,1365.37 1497.75,1365.39 1497.75,1365.4 1497.75,1365.42 1497.75,1365.44 1497.75,1365.45 1497.75,1365.47 1497.75,1365.49 1497.75,1365.5 1497.75,1365.52 1497.75,1365.54 1497.75,1365.55 1497.75,1365.57 1497.75,1365.59 1497.75,1365.6 1497.75,1365.62 1497.75,1365.64 1497.75,1365.65 1497.75,1365.67 1497.75,1365.69 1497.75,1365.7 1497.75,1365.72 1497.75,1365.74 1497.75,1365.75 1497.75,1365.77 1497.75,1365.79 1497.75,1365.8 1497.75,1365.82 1497.75,1365.84 1497.75,1365.85 1497.75,1365.87 1497.75,1365.89 1497.75,1365.9 1497.75,1365.92 1497.75,1365.94 1497.75,1365.95 1497.75,1365.97 1497.75,1365.99 1497.75,1366 1497.75,1366.02 1497.75,1366.04 1497.75,1366.05 1497.75,1366.07 1497.75,1366.08 1497.75,1366.1 1497.75,1366.12 1497.75,1366.13 1497.75,1366.15 1497.75,1366.17 1497.75,1366.18 1497.75,1366.2 1497.75,1366.22 1497.75,1366.23 1497.75,1366.25 1497.75,1366.27 1497.75,1366.28 1497.75,1366.3 1497.75,1366.32 1497.75,1366.33 1497.75,1366.35 1497.75,1366.36 1497.75,1366.38 1497.75,1366.4 1497.75,1366.41 1497.75,1366.43 1497.75,1366.45 1497.75,1366.46 1497.75,1366.48 1497.75,1366.5 1497.75,1366.51 1497.75,1366.53 1497.75,1366.55 1497.75,1366.56 1497.75,1366.58 1497.75,1366.59 1497.75,1366.61 1497.75,1366.63 1497.75,1366.64 1497.75,1366.66 1497.75,1366.68 1497.75,1366.69 1497.75,1366.71 1497.75,1366.72 1497.75,1366.74 1497.75,1366.76 1497.75,1366.77 1497.75,1366.79 1497.75,1366.81 1497.75,1366.82 1497.75,1366.84 1497.75,1366.86 1497.75,1366.87 1497.75,1366.89 1497.75,1366.9 1497.75,1366.92 1497.75,1366.94 1497.75,1366.95 1497.75,1366.97 1497.75,1366.98 1497.75,1367 1497.75,1367.02 1497.75,1367.03 1497.75,1367.05 1497.75,1367.07 1497.75,1367.08 1497.75,1367.1 1497.75,1367.11 1497.75,1367.13 1497.75,1367.15 1497.75,1367.16 1497.75,1367.18 1497.75,1367.2 1497.75,1367.21 1497.75,1367.23 1497.75,1367.24 1497.75,1367.26 1497.75,1367.28 1497.75,1367.29 1497.75,1367.31 1497.75,1367.32 1497.75,1367.34 1497.75,1367.36 1497.75,1367.37 1497.75,1367.39 1497.75,1367.4 1497.75,1367.42 1497.75,1367.44 1497.75,1367.45 1497.75,1367.47 1497.75,1367.49 1497.75,1367.5 1497.75,1367.52 1497.75,1367.53 1497.75,1367.55 1497.75,1367.57 1497.75,1367.58 1497.75,1367.6 1497.75,1367.61 1497.75,1367.63 1497.75,1367.65 1497.75,1367.66 1497.75,1367.68 1497.75,1367.69 1497.75,1367.71 1497.75,1367.73 1497.75,1367.74 1497.75,1367.76 1497.75,1367.77 1497.75,1367.79 1497.75,1367.8 1497.75,1367.82 1497.75,1367.84 1497.75,1367.85 1497.75,1367.87 1497.75,1367.88 1497.75,1367.9 1497.75,1367.92 1497.75,1367.93 1497.75,1367.95 1497.75,1367.96 1497.75,1367.98 1497.75,1368 1497.75,1368.01 1497.75,1368.03 1497.75,1368.04 1497.75,1368.06 1497.75,1368.08 1497.75,1368.09 1497.75,1368.11 1497.75,1368.12 1497.75,1368.14 1497.75,1368.15 1497.75,1368.17 1497.75,1368.19 1497.75,1368.2 1497.75,1368.22 1497.75,1368.23 1497.75,1368.25 1497.75,1368.26 1497.75,1368.28 1497.75,1368.3 1497.75,1368.31 1497.75,1368.33 1497.75,1368.34 1497.75,1368.36 1497.75,1368.38 1497.75,1368.39 1497.75,1368.41 1497.75,1368.42 1497.75,1368.44 1497.75,1368.45 1497.75,1368.47 1497.75,1368.49 1497.75,1368.5 1497.75,1368.52 1497.75,1368.53 1497.75,1368.55 1497.75,1368.56 1497.75,1368.58 1497.75,1368.6 1497.75,1368.61 1497.75,1368.63 1497.75,1368.64 1497.75,1368.66 1497.75,1368.67 1497.75,1368.69 1497.75,1368.7 1497.75,1368.72 1497.75,1368.74 1497.75,1368.75 1497.75,1368.77 1497.75,1368.78 1497.75,1368.8 1497.75,1368.81 1497.75,1368.83 1497.75,1368.85 1497.75,1368.86 1497.75,1368.88 1497.75,1368.89 1497.75,1368.91 1497.75,1368.92 1497.75,1368.94 1497.75,1368.95 1497.75,1368.97 1497.75,1368.99 1497.75,1369 1497.75,1369.02 1497.75,1369.03 1497.75,1369.05 1497.75,1369.06 1497.75,1369.08 1497.75,1369.09 1497.75,1369.11 1497.75,1369.13 1497.75,1369.14 1497.75,1369.16 1497.75,1369.17 1497.75,1369.19 1497.75,1369.2 1497.75,1369.22 1497.75,1369.23 1497.75,1369.25 1497.75,1369.26 1497.75,1369.28 1497.75,1369.3 1497.75,1369.31 1497.75,1369.33 1497.75,1369.34 1497.75,1369.36 1497.75,1369.37 1497.75,1369.39 1497.75,1369.4 1497.75,1369.42 1497.75,1369.43 1497.75,1369.45 1497.75,1369.46 1497.75,1369.48 1497.75,1369.5 1497.75,1369.51 1497.75,1369.53 1497.75,1369.54 1497.75,1369.56 1497.75,1369.57 1497.75,1369.59 1497.75,1369.6 1497.75,1369.62 1497.75,1369.63 1497.75,1369.65 1497.75,1369.66 1497.75,1369.68 1497.75,1369.69 1497.75,1369.71 1497.75,1369.73 1497.75,1369.74 1497.75,1369.76 1497.75,1369.77 1497.75,1369.79 1497.75,1369.8 1497.75,1369.82 1497.75,1369.83 1497.75,1369.85 1497.75,1369.86 1497.75,1369.88 1497.75,1369.89 1497.75,1369.91 1497.75,1369.92 1497.75,1369.94 1497.75,1369.95 1497.75,1369.97 1497.75,1369.98 1497.75,1370 1497.75,1370.01 1497.75,1370.03 1497.75,1370.05 1497.75,1370.06 1497.75,1370.08 1497.75,1370.09 1497.75,1370.11 1497.75,1370.12 1497.75,1370.14 1497.75,1370.15 1497.75,1370.17 1497.75,1370.18 1497.75,1370.2 1497.75,1370.21 1497.75,1370.23 1497.75,1370.24 1497.75,1370.26 1497.75,1370.27 1497.75,1370.29 1497.75,1370.3 1497.75,1370.32 1497.75,1370.33 1497.75,1370.35 1497.75,1370.36 1497.75,1370.38 1497.75,1370.39 1497.75,1370.41 1497.75,1370.42 1497.75,1370.44 1497.75,1370.45 1497.75,1370.47 1497.75,1370.48 1497.75,1370.5 1497.75,1370.51 1497.75,1370.53 1497.75,1370.54 1497.75,1370.56 1497.75,1370.57 1497.75,1370.59 1497.75,1370.6 1497.75,1370.62 1497.75,1370.63 1497.75,1370.65 1497.75,1370.66 1497.75,1370.68 1497.75,1370.69 1497.75,1370.71 1497.75,1370.72 1497.75,1370.74 1497.75,1370.75 1497.75,1370.77 1497.75,1370.78 1497.75,1370.8 1497.75,1370.81 1497.75,1370.83 1497.75,1370.84 1497.75,1370.86 1497.75,1370.87 1497.75,1370.89 1497.75,1370.9 1497.75,1370.92 1497.75,1370.93 1497.75,1370.95 1497.75,1370.96 1497.75,1370.98 1497.75,1370.99 1497.75,1371.01 1497.75,1371.02 1497.75,1371.04 1497.75,1371.05 1497.75,1371.07 1497.75,1371.08 1497.75,1371.1 1497.75,1371.11 1497.75,1371.13 1497.75,1371.14 1497.75,1371.15 1497.75,1371.17 1497.75,1371.18 1497.75,1371.2 1497.75,1371.21 1497.75,1371.23 1497.75,1371.24 1497.75,1371.26 1497.75,1371.27 1497.75,1371.29 1497.75,1371.3 1497.75,1371.32 1497.75,1371.33 1497.75,1371.35 1497.75,1371.36 1497.75,1371.38 1497.75,1371.39 1497.75,1371.41 1497.75,1371.42 1497.75,1371.44 1497.75,1371.45 1497.75,1371.46 1497.75,1371.48 1497.75,1371.49 1497.75,1371.51 1497.75,1371.52 1497.75,1371.54 1497.75,1371.55 1497.75,1371.57 1497.75,1371.58 1497.75,1371.6 1497.75,1371.61 1497.75,1371.63 1497.75,1371.64 1497.75,1371.66 1497.75,1371.67 1497.75,1371.68 1497.75,1371.7 1497.75,1371.71 1497.75,1371.73 1497.75,1371.74 1497.75,1371.76 1497.75,1371.77 1497.75,1371.79 1497.75,1371.8 1497.75,1371.82 1497.75,1371.83 1497.75,1371.85 1497.75,1371.86 1497.75,1371.87 1497.75,1371.89 1497.75,1371.9 1497.75,1371.92 1497.75,1371.93 1497.75,1371.95 1497.75,1371.96 1497.75,1371.98 1497.75,1371.99 1497.75,1372.01 1497.75,1372.02 1497.75,1372.03 1497.75,1372.05 1497.75,1372.06 1497.75,1372.08 1497.75,1372.09 1497.75,1372.11 1497.75,1372.12 1497.75,1372.14 1497.75,1372.15 1497.75,1372.16 1497.75,1372.18 1497.75,1372.19 1497.75,1372.21 1497.75,1372.22 1497.75,1372.24 1497.75,1372.25 1497.75,1372.27 1497.75,1372.28 1497.75,1372.29 1497.75,1372.31 1497.75,1372.32 1497.75,1372.34 1497.75,1372.35 1497.75,1372.37 1497.75,1372.38 1497.75,1372.4 1497.75,1372.41 1497.75,1372.42 1497.75,1372.44 1497.75,1372.45 1497.75,1372.47 1497.75,1372.48 1497.75,1372.5 1497.75,1372.51 1497.75,1372.52 1497.75,1372.54 1497.75,1372.55 1497.75,1372.57 1497.75,1372.58 1497.75,1372.6 1497.75,1372.61 1497.75,1372.62 1497.75,1372.64 1497.75,1372.65 1497.75,1372.67 1497.75,1372.68 1497.75,1372.7 1497.75,1372.71 1497.75,1372.72 1497.75,1372.74 1497.75,1372.75 1497.75,1372.77 1497.75,1372.78 1497.75,1372.8 1497.75,1372.81 1497.75,1372.82 1497.75,1372.84 1497.75,1372.85 1497.75,1372.87 1497.75,1372.88 1497.75,1372.9 1497.75,1372.91 1497.75,1372.92 1497.75,1372.94 1497.75,1372.95 1497.75,1372.97 1497.75,1372.98 1497.75,1372.99 1497.75,1373.01 1497.75,1373.02 1497.75,1373.04 1497.75,1373.05 1497.75,1373.07 1497.75,1373.08 1497.75,1373.09 1497.75,1373.11 1497.75,1373.12 1497.75,1373.14 1497.75,1373.15 1497.75,1373.16 1497.75,1373.18 1497.75,1373.19 1497.75,1373.21 1497.75,1373.22 1497.75,1373.24 1497.75,1373.25 1497.75,1373.26 1497.75,1373.28 1497.75,1373.29 1497.75,1373.31 1497.75,1373.32 1497.75,1373.33 1497.75,1373.35 1497.75,1373.36 1497.75,1373.38 1497.75,1373.39 1497.75,1373.4 1497.75,1373.42 1497.75,1373.43 1497.75,1373.45 1497.75,1373.46 1497.75,1373.47 1497.75,1373.49 1497.75,1373.5 1497.75,1373.52 1497.75,1373.53 1497.75,1373.54 1497.75,1373.56 1497.75,1373.57 1497.75,1373.59 1497.75,1373.6 1497.75,1373.61 1497.75,1373.63 1497.75,1373.64 1497.75,1373.66 1497.75,1373.67 1497.75,1373.68 1497.75,1373.7 1497.75,1373.71 1497.75,1373.73 1497.75,1373.74 1497.75,1373.75 1497.75,1373.77 1497.75,1373.78 1497.75,1373.8 1497.75,1373.81 1497.75,1373.82 1497.75,1373.84 1497.75,1373.85 1497.75,1373.86 1497.75,1373.88 1497.75,1373.89 1497.75,1373.91 1497.75,1373.92 1497.75,1373.93 1497.75,1373.95 1497.75,1373.96 1497.75,1373.98 1497.75,1373.99 1497.75,1374 1497.75,1374.02 1497.75,1374.03 1497.75,1374.04 1497.75,1374.06 1497.75,1374.07 1497.75,1374.09 1497.75,1374.1 1497.75,1374.11 1497.75,1374.13 1497.75,1374.14 1497.75,1374.15 1497.75,1374.17 1497.75,1374.18 1497.75,1374.2 1497.75,1374.21 1497.75,1374.22 1497.75,1374.24 1497.75,1374.25 1497.75,1374.27 1497.75,1374.28 1497.75,1374.29 1497.75,1374.31 1497.75,1374.32 1497.75,1374.33 1497.75,1374.35 1497.75,1374.36 1497.75,1374.37 1497.75,1374.39 1497.75,1374.4 1497.75,1374.42 1497.75,1374.43 1497.75,1374.44 1497.75,1374.46 1497.75,1374.47 1497.75,1374.48 1497.75,1374.5 1497.75,1374.51 1497.75,1374.53 1497.75,1374.54 1497.75,1374.55 1497.75,1374.57 1497.75,1374.58 1497.75,1374.59 1497.75,1374.61 1497.75,1374.62 1497.75,1374.63 1497.75,1374.65 1497.75,1374.66 1497.75,1374.68 1497.75,1374.69 1497.75,1374.7 1497.75,1374.72 1497.75,1374.73 1497.75,1374.74 1497.75,1374.76 1497.75,1374.77 1497.75,1374.78 1497.75,1374.8 1497.75,1374.81 1497.75,1374.82 1497.75,1374.84 1497.75,1374.85 1497.75,1374.87 1497.75,1374.88 1497.75,1374.89 1497.75,1374.91 1497.75,1374.92 1497.75,1374.93 1497.75,1374.95 1497.75,1374.96 1497.75,1374.97 1497.75,1374.99 1497.75,1375 1497.75,1375.01 1497.75,1375.03 1497.75,1375.04 1497.75,1375.05 1497.75,1375.07 1497.75,1375.08 1497.75,1375.09 1497.75,1375.11 1497.75,1375.12 1497.75,1375.13 1497.75,1375.15 1497.75,1375.16 1497.75,1375.18 1497.75,1375.19 1497.75,1375.2 1497.75,1375.22 1497.75,1375.23 1497.75,1375.24 1497.75,1375.26 1497.75,1375.27 1497.75,1375.28 1497.75,1375.3 1497.75,1375.31 1497.75,1375.32 1497.75,1375.34 1497.75,1375.35 1497.75,1375.36 1497.75,1375.38 1497.75,1375.39 1497.75,1375.4 1497.75,1375.42 1497.75,1375.43 1497.75,1375.44 1497.75,1375.46 1497.75,1375.47 1497.75,1375.48 1497.75,1375.5 1497.75,1375.51 1497.75,1375.52 1497.75,1375.54 1497.75,1375.55 1497.75,1375.56 1497.75,1375.58 1497.75,1375.59 1497.75,1375.6 1497.75,1375.62 1497.75,1375.63 1497.75,1375.64 1497.75,1375.66 1497.75,1375.67 1497.75,1375.68 1497.75,1375.7 1497.75,1375.71 1497.75,1375.72 1497.75,1375.74 1497.75,1375.75 1497.75,1375.76 1497.75,1375.77 1497.75,1375.79 1497.75,1375.8 1497.75,1375.81 1497.75,1375.83 1497.75,1375.84 1497.75,1375.85 1497.75,1375.87 1497.75,1375.88 1497.75,1375.89 1497.75,1375.91 1497.75,1375.92 1497.75,1375.93 1497.75,1375.95 1497.75,1375.96 1497.75,1375.97 1497.75,1375.99 1497.75,1376 1497.75,1376.01 1497.75,1376.03 1497.75,1376.04 1497.75,1376.05 1497.75,1376.06 1497.75,1376.08 1497.75,1376.09 1497.75,1376.1 1497.75,1376.12 1497.75,1376.13 1497.75,1376.14 1497.75,1376.16 1497.75,1376.17 1497.75,1376.18 1497.75,1376.2 1497.75,1376.21 1497.75,1376.22 1497.75,1376.23 1497.75,1376.25 1497.75,1376.26 1497.75,1376.27 1497.75,1376.29 1497.75,1376.3 1497.75,1376.31 1497.75,1376.33 1497.75,1376.34 1497.75,1376.35 1497.75,1376.37 1497.75,1376.38 1497.75,1376.39 1497.75,1376.4 1497.75,1376.42 1497.75,1376.43 1497.75,1376.44 1497.75,1376.46 1497.75,1376.47 1497.75,1376.48 1497.75,1376.5 1497.75,1376.51 1497.75,1376.52 1497.75,1376.53 1497.75,1376.55 1497.75,1376.56 1497.75,1376.57 1497.75,1376.59 1497.75,1376.6 1497.75,1376.61 1497.75,1376.62 1497.75,1376.64 1497.75,1376.65 1497.75,1376.66 1497.75,1376.68 1497.75,1376.69 1497.75,1376.7 1497.75,1376.72 1497.75,1376.73 1497.75,1376.74 1497.75,1376.75 1497.75,1376.77 1497.75,1376.78 1497.75,1376.79 1497.75,1376.81 1497.75,1376.82 1497.75,1376.83 1497.75,1376.84 1497.75,1376.86 1497.75,1376.87 1497.75,1376.88 1497.75,1376.9 1497.75,1376.91 1497.75,1376.92 1497.75,1376.93 1497.75,1376.95 1497.75,1376.96 1497.75,1376.97 1497.75,1376.99 1497.75,1377 1497.75,1377.01 1497.75,1377.02 1497.75,1377.04 1497.75,1377.05 1497.75,1377.06 1497.75,1377.07 1497.75,1377.09 1497.75,1377.1 1497.75,1377.11 1497.75,1377.13 1497.75,1377.14 1497.75,1377.15 1497.75,1377.16 1497.75,1377.18 1497.75,1377.19 1497.75,1377.2 1497.75,1377.21 1497.75,1377.23 1497.75,1377.24 1497.75,1377.25 1497.75,1377.27 1497.75,1377.28 1497.75,1377.29 1497.75,1377.3 1497.75,1377.32 1497.75,1377.33 1497.75,1377.34 1497.75,1377.35 1497.75,1377.37 1497.75,1377.38 1497.75,1377.39 1497.75,1377.41 1497.75,1377.42 1497.75,1377.43 1497.75,1377.44 1497.75,1377.46 1497.75,1377.47 1497.75,1377.48 1497.75,1377.49 1497.75,1377.51 1497.75,1377.52 1497.75,1377.53 1497.75,1377.54 1497.75,1377.56 1497.75,1377.57 1497.75,1377.58 1497.75,1377.59 1497.75,1377.61 1497.75,1377.62 1497.75,1377.63 1497.75,1377.64 1497.75,1377.66 1497.75,1377.67 1497.75,1377.68 1497.75,1377.7 1497.75,1377.71 1497.75,1377.72 1497.75,1377.73 1497.75,1377.75 1497.75,1377.76 1497.75,1377.77 1497.75,1377.78 1497.75,1377.8 1497.75,1377.81 1497.75,1377.82 1497.75,1377.83 1497.75,1377.85 1497.75,1377.86 1497.75,1377.87 1497.75,1377.88 1497.75,1377.9 1497.75,1377.91 1497.75,1377.92 1497.75,1377.93 1497.75,1377.95 1497.75,1377.96 1497.75,1377.97 1497.75,1377.98 1497.75,1378 1497.75,1378.01 1497.75,1378.02 1497.75,1378.03 1497.75,1378.05 1497.75,1378.06 1497.75,1378.07 1497.75,1378.08 1497.75,1378.09 1497.75,1378.11 1497.75,1378.12 1497.75,1378.13 1497.75,1378.14 1497.75,1378.16 1497.75,1378.17 1497.75,1378.18 1497.75,1378.19 1497.75,1378.21 1497.75,1378.22 1497.75,1378.23 1497.75,1378.24 1497.75,1378.26 1497.75,1378.27 1497.75,1378.28 1497.75,1378.29 1497.75,1378.31 1497.75,1378.32 1497.75,1378.33 1497.75,1378.34 1497.75,1378.35 1497.75,1378.37 1497.75,1378.38 1497.75,1378.39 1497.75,1378.4 1497.75,1378.42 1497.75,1378.43 1497.75,1378.44 1497.75,1378.45 1497.75,1378.47 1497.75,1378.48 1497.75,1378.49 1497.75,1378.5 1497.75,1378.51 1497.75,1378.53 1497.75,1378.54 1497.75,1378.55 1497.75,1378.56 1497.75,1378.58 1497.75,1378.59 1497.75,1378.6 1497.75,1378.61 1497.75,1378.63 1497.75,1378.64 1497.75,1378.65 1497.75,1378.66 1497.75,1378.67 1497.75,1378.69 1497.75,1378.7 1497.75,1378.71 1497.75,1378.72 1497.75,1378.74 1497.75,1378.75 1497.75,1378.76 1497.75,1378.77 1497.75,1378.78 1497.75,1378.8 1497.75,1378.81 1497.75,1378.82 1497.75,1378.83 1497.75,1378.84 1497.75,1378.86 1497.75,1378.87 1497.75,1378.88 1497.75,1378.89 1497.75,1378.91 1497.75,1378.92 1497.75,1378.93 1497.75,1378.94 1497.75,1378.95 1497.75,1378.97 1497.75,1378.98 1497.75,1378.99 1497.75,1379 1497.75,1379.01 1497.75,1379.03 1497.75,1379.04 1497.75,1379.05 1497.75,1379.06 1497.75,1379.08 1497.75,1379.09 1497.75,1379.1 1497.75,1379.11 1497.75,1379.12 1497.75,1379.14 1497.75,1379.15 1497.75,1379.16 1497.75,1379.17 1497.75,1379.18 1497.75,1379.2 1497.75,1379.21 1497.75,1379.22 1497.75,1379.23 1497.75,1379.24 1497.75,1379.26 1497.75,1379.27 1497.75,1379.28 1497.75,1379.29 1497.75,1379.3 1497.75,1379.32 1497.75,1379.33 1497.75,1379.34 1497.75,1379.35 1497.75,1379.36 1497.75,1379.38 1497.75,1379.39 1497.75,1379.4 1497.75,1379.41 1497.75,1379.42 1497.75,1379.44 1497.75,1379.45 1497.75,1379.46 1497.75,1379.47 1497.75,1379.48 1497.75,1379.5 1497.75,1379.51 1497.75,1379.52 1497.75,1379.53 1497.75,1379.54 1497.75,1379.55 1497.75,1379.57 1497.75,1379.58 1497.75,1379.59 1497.75,1379.6 1497.75,1379.61 1497.75,1379.63 1497.75,1379.64 1497.75,1379.65 1497.75,1379.66 1497.75,1379.67 1497.75,1379.69 1497.75,1379.7 1497.75,1379.71 1497.75,1379.72 1497.75,1379.73 1497.75,1379.75 1497.75,1379.76 1497.75,1379.77 1497.75,1379.78 1497.75,1379.79 1497.75,1379.8 1497.75,1379.82 1497.75,1379.83 1497.75,1379.84 1497.75,1379.85 1497.75,1379.86 1497.75,1379.88 1497.75,1379.89 1497.75,1379.9 1497.75,1379.91 1497.75,1379.92 1497.75,1379.93 1497.75,1379.95 1497.75,1379.96 1497.75,1379.97 1497.75,1379.98 1497.75,1379.99 1497.75,1380 1497.75,1380.02 1497.75,1380.03 1497.75,1380.04 1497.75,1380.05 1497.75,1380.06 1497.75,1380.08 1497.75,1380.09 1497.75,1380.1 1497.75,1380.11 1497.75,1380.12 1497.75,1380.13 1497.75,1380.15 1497.75,1380.16 1497.75,1380.17 1497.75,1380.18 1497.75,1380.19 1497.75,1380.2 1497.75,1380.22 1497.75,1380.23 1497.75,1380.24 1497.75,1380.25 1497.75,1380.26 1497.75,1380.27 1497.75,1380.29 1497.75,1380.3 1497.75,1380.31 1497.75,1380.32 1497.75,1380.33 1497.75,1380.34 1497.75,1380.36 1497.75,1380.37 1497.75,1380.38 1497.75,1380.39 1497.75,1380.4 1497.75,1380.41 1497.75,1380.43 1497.75,1380.44 1497.75,1380.45 1497.75,1380.46 1497.75,1380.47 1497.75,1380.48 1497.75,1380.5 1497.75,1380.51 1497.75,1380.52 1497.75,1380.53 1497.75,1380.54 1497.75,1380.55 1497.75,1380.56 1497.75,1380.58 1497.75,1380.59 1497.75,1380.6 1497.75,1380.61 1497.75,1380.62 1497.75,1380.63 1497.75,1380.65 1497.75,1380.66 1497.75,1380.67 1497.75,1380.68 1497.75,1380.69 1497.75,1380.7 1497.75,1380.71 1497.75,1380.73 1497.75,1380.74 1497.75,1380.75 1497.75,1380.76 1497.75,1380.77 1497.75,1380.78 1497.75,1380.8 1497.75,1380.81 1497.75,1380.82 1497.75,1380.83 1497.75,1380.84 1497.75,1380.85 1497.75,1380.86 1497.75,1380.88 1497.75,1380.89 1497.75,1380.9 1497.75,1380.91 1497.75,1380.92 1497.75,1380.93 1497.75,1380.94 1497.75,1380.96 1497.75,1380.97 1497.75,1380.98 1497.75,1380.99 1497.75,1381 1497.75,1381.01 1497.75,1381.02 1497.75,1381.04 1497.75,1381.05 1497.75,1381.06 1497.75,1381.07 1497.75,1381.08 1497.75,1381.09 1497.75,1381.1 1497.75,1381.12 1497.75,1381.13 1497.75,1381.14 1497.75,1381.15 1497.75,1381.16 1497.75,1381.17 1497.75,1381.18 1497.75,1381.19 1497.75,1381.21 1497.75,1381.22 1497.75,1381.23 1497.75,1381.24 1497.75,1381.25 1497.75,1381.26 1497.75,1381.27 1497.75,1381.29 1497.75,1381.3 1497.75,1381.31 1497.75,1381.32 1497.75,1381.33 1497.75,1381.34 1497.75,1381.35 1497.75,1381.36 1497.75,1381.38 1497.75,1381.39 1497.75,1381.4 1497.75,1381.41 1497.75,1381.42 1497.75,1381.43 1497.75,1381.44 1497.75,1381.45 1497.75,1381.47 1497.75,1381.48 1497.75,1381.49 1497.75,1381.5 1497.75,1381.51 1497.75,1381.52 1497.75,1381.53 1497.75,1381.54 1497.75,1381.56 1497.75,1381.57 1497.75,1381.58 1497.75,1381.59 1497.75,1381.6 1497.75,1381.61 1497.75,1381.62 1497.75,1381.63 1497.75,1381.65 1497.75,1381.66 1497.75,1381.67 1497.75,1381.68 1497.75,1381.69 1497.75,1381.7 1497.75,1381.71 1497.75,1381.72 1497.75,1381.73 1497.75,1381.75 1497.75,1381.76 1497.75,1381.77 1497.75,1381.78 1497.75,1381.79 1497.75,1381.8 1497.75,1381.81 1497.75,1381.82 1497.75,1381.83 1497.75,1381.85 1497.75,1381.86 1497.75,1381.87 1497.75,1381.88 1497.75,1381.89 1497.75,1381.9 1497.75,1381.91 1497.75,1381.92 1497.75,1381.93 1497.75,1381.95 1497.75,1381.96 1497.75,1381.97 1497.75,1381.98 1497.75,1381.99 1497.75,1382 1497.75,1382.01 1497.75,1382.02 1497.75,1382.03 1497.75,1382.05 1497.75,1382.06 1497.75,1382.07 1497.75,1382.08 1497.75,1382.09 1497.75,1382.1 1497.75,1382.11 1497.75,1382.12 1497.75,1382.13 1497.75,1382.14 1497.75,1382.16 1497.75,1382.17 1497.75,1382.18 1497.75,1382.19 1497.75,1382.2 1497.75,1382.21 1497.75,1382.22 1497.75,1382.23 1497.75,1382.24 1497.75,1382.25 1497.75,1382.27 1497.75,1382.28 1497.75,1382.29 1497.75,1382.3 1497.75,1382.31 1497.75,1382.32 1497.75,1382.33 1497.75,1382.34 1497.75,1382.35 1497.75,1382.36 1497.75,1382.38 1497.75,1382.39 1497.75,1382.4 1497.75,1382.41 1497.75,1382.42 1497.75,1382.43 1497.75,1382.44 1497.75,1382.45 1497.75,1382.46 1497.75,1382.47 1497.75,1382.48 1497.75,1382.5 1497.75,1382.51 1497.75,1382.52 1497.75,1382.53 1497.75,1382.54 1497.75,1382.55 1497.75,1382.56 1497.75,1382.57 1497.75,1382.58 1497.75,1382.59 1497.75,1382.6 1497.75,1382.61 1497.75,1382.63 1497.75,1382.64 1497.75,1382.65 1497.75,1382.66 1497.75,1382.67 1497.75,1382.68 1497.75,1382.69 1497.75,1382.7 1497.75,1382.71 1497.75,1382.72 1497.75,1382.73 1497.75,1382.74 1497.75,1382.76 1497.75,1382.77 1497.75,1382.78 1497.75,1382.79 1497.75,1382.8 1497.75,1382.81 1497.75,1382.82 1497.75,1382.83 1497.75,1382.84 1497.75,1382.85 1497.75,1382.86 1497.75,1382.87 1497.75,1382.88 1497.75,1382.9 1497.75,1382.91 1497.75,1382.92 1497.75,1382.93 1497.75,1382.94 1497.75,1382.95 1497.75,1382.96 1497.75,1382.97 1497.75,1382.98 1497.75,1382.99 1497.75,1383 1497.75,1383.01 1497.75,1383.02 1497.75,1383.04 1497.75,1383.05 1497.75,1383.06 1497.75,1383.07 1497.75,1383.08 1497.75,1383.09 1497.75,1383.1 1497.75,1383.11 1497.75,1383.12 1497.75,1383.13 1497.75,1383.14 1497.75,1383.15 1497.75,1383.16 1497.75,1383.17 1497.75,1383.18 1497.75,1383.2 1497.75,1383.21 1497.75,1383.22 1497.75,1383.23 1497.75,1383.24 1497.75,1383.25 1497.75,1383.26 1497.75,1383.27 1497.75,1383.28 1497.75,1383.29 1497.75,1383.3 1497.75,1383.31 1497.75,1383.32 1497.75,1383.33 1497.75,1383.34 1497.75,1383.35 1497.75,1383.36 1497.75,1383.38 1497.75,1383.39 1497.75,1383.4 1497.75,1383.41 1497.75,1383.42 1497.75,1383.43 1497.75,1383.44 1497.75,1383.45 1497.75,1383.46 1497.75,1383.47 1497.75,1383.48 1497.75,1383.49 1497.75,1383.5 1497.75,1383.51 1497.75,1383.52 1497.75,1383.53 1497.75,1383.54 1497.75,1383.55 1497.75,1383.57 1497.75,1383.58 1497.75,1383.59 1497.75,1383.6 1497.75,1383.61 1497.75,1383.62 1497.75,1383.63 1497.75,1383.64 1497.75,1383.65 1497.75,1383.66 1497.75,1383.67 1497.75,1383.68 1497.75,1383.69 1497.75,1383.7 1497.75,1383.71 1497.75,1383.72 1497.75,1383.73 1497.75,1383.74 1497.75,1383.75 1497.75,1383.76 1497.75,1383.78 1497.75,1383.79 1497.75,1383.8 1497.75,1383.81 1497.75,1383.82 1497.75,1383.83 1497.75,1383.84 1497.75,1383.85 1497.75,1383.86 1497.75,1383.87 1497.75,1383.88 1497.75,1383.89 1497.75,1383.9 1497.75,1383.91 1497.75,1383.92 1497.75,1383.93 1497.75,1383.94 1497.75,1383.95 1497.75,1383.96 1497.75,1383.97 1497.75,1383.98 1497.75,1383.99 1497.75,1384 1497.75,1384.01 1497.75,1384.02 1497.75,1384.04 1497.75,1384.05 1497.75,1384.06 1497.75,1384.07 1497.75,1384.08 1497.75,1384.09 1497.75,1384.1 1497.75,1384.11 1497.75,1384.12 1497.75,1384.13 1497.75,1384.14 1497.75,1384.15 1497.75,1384.16 1497.75,1384.17 1497.75,1384.18 1497.75,1384.19 1497.75,1384.2 1497.75,1384.21 1497.75,1384.22 1497.75,1384.23 1497.75,1384.24 1497.75,1384.25 1497.75,1384.26 1497.75,1384.27 1497.75,1384.28 1497.75,1384.29 1497.75,1384.3 1497.75,1384.31 1497.75,1384.32 1497.75,1384.33 1497.75,1384.34 1497.75,1384.35 1497.75,1384.36 1497.75,1384.37 1497.75,1384.38 1497.75,1384.39 1497.75,1384.41 1497.75,1384.42 1497.75,1384.43 1497.75,1384.44 1497.75,1384.45 1497.75,1384.46 1497.75,1384.47 1497.75,1384.48 1497.75,1384.49 1497.75,1384.5 1497.75,1384.51 1497.75,1384.52 1497.76,1384.53 1497.76,1384.54 1497.76,1384.55 1497.76,1384.56 1497.76,1384.57 1497.76,1384.58 1497.76,1384.59 1497.76,1384.6 1497.76,1384.61 1497.76,1384.62 1497.76,1384.63 1497.76,1384.64 1497.76,1384.65 1497.76,1384.66 1497.76,1384.67 1497.76,1384.68 1497.77,1384.69 1497.77,1384.7 1497.77,1384.71 1497.77,1384.72 1497.77,1384.73 1497.77,1384.74 1497.77,1384.75 1497.77,1384.76 1497.77,1384.77 1497.77,1384.78 1497.77,1384.79 1497.78,1384.8 1497.78,1384.81 1497.78,1384.82 1497.78,1384.83 1497.78,1384.84 1497.78,1384.85 1497.78,1384.86 1497.78,1384.87 1497.78,1384.88 1497.78,1384.89 1497.79,1384.9 1497.79,1384.91 1497.79,1384.92 1497.79,1384.93 1497.79,1384.94 1497.79,1384.95 1497.79,1384.96 1497.79,1384.97 1497.8,1384.98 1497.8,1384.99 1497.8,1385 1497.8,1385.01 1497.8,1385.02 1497.8,1385.03 1497.8,1385.04 1497.81,1385.05 1497.81,1385.06 1497.81,1385.07 1497.81,1385.08 1497.81,1385.09 1497.81,1385.1 1497.81,1385.11 1497.82,1385.12 1497.82,1385.13 1497.82,1385.14 1497.82,1385.15 1497.82,1385.16 1497.82,1385.17 1497.82,1385.17 1497.83,1385.18 1497.83,1385.19 1497.83,1385.2 1497.83,1385.21 1497.83,1385.22 1497.83,1385.23 1497.84,1385.24 1497.84,1385.25 1497.84,1385.26 1497.84,1385.27 1497.84,1385.28 1497.85,1385.29 1497.85,1385.3 1497.85,1385.31 1497.85,1385.32 1497.85,1385.33 1497.85,1385.34 1497.86,1385.35 1497.86,1385.36 1497.86,1385.37 1497.86,1385.38 1497.86,1385.39 1497.87,1385.4 1497.87,1385.41 1497.87,1385.42 1497.87,1385.43 1497.87,1385.44 1497.88,1385.45 1497.88,1385.46 1497.88,1385.47 1497.88,1385.48 1497.88,1385.49 1497.89,1385.5 1497.89,1385.51 1497.89,1385.51 1497.89,1385.52 1497.9,1385.53 1497.9,1385.54 1497.9,1385.55 1497.9,1385.56 1497.9,1385.57 1497.91,1385.58 1497.91,1385.59 1497.91,1385.6 1497.91,1385.61 1497.92,1385.62 1497.92,1385.63 1497.92,1385.64 1497.92,1385.65 1497.93,1385.66 1497.93,1385.67 1497.93,1385.68 1497.93,1385.69 1497.94,1385.7 1497.94,1385.71 1497.94,1385.72 1497.94,1385.73 1497.95,1385.74 1497.95,1385.74 1497.95,1385.75 1497.95,1385.76 1497.96,1385.77 1497.96,1385.78 1497.96,1385.79 1497.96,1385.8 1497.97,1385.81 1497.97,1385.82 1497.97,1385.83 1497.97,1385.84 1497.98,1385.85 1497.98,1385.86 1497.98,1385.87 1497.99,1385.88 1497.99,1385.89 1497.99,1385.9 1497.99,1385.91 1498,1385.92 1498,1385.92 1498,1385.93 1498.01,1385.94 1498.01,1385.95 1498.01,1385.96 1498.01,1385.97 1498.02,1385.98 1498.02,1385.99 1498.02,1386 1498.03,1386.01 1498.03,1386.02 1498.03,1386.03 1498.03,1386.04 1498.04,1386.05 1498.04,1386.06 1498.04,1386.07 1498.05,1386.07 1498.05,1386.08 1498.05,1386.09 1498.06,1386.1 1498.06,1386.11 1498.06,1386.12 1498.07,1386.13 1498.07,1386.14 1498.07,1386.15 1498.08,1386.16 1498.08,1386.17 1498.08,1386.18 1498.09,1386.19 1498.09,1386.2 1498.09,1386.21 1498.1,1386.21 1498.1,1386.22 1498.1,1386.23 1498.11,1386.24 1498.11,1386.25 1498.11,1386.26 1498.12,1386.27 1498.12,1386.28 1498.12,1386.29 1498.13,1386.3 1498.13,1386.31 1498.13,1386.32 1498.14,1386.33 1498.14,1386.33 1498.14,1386.34 1498.15,1386.35 1498.15,1386.36 1498.15,1386.37 1498.16,1386.38 1498.16,1386.39 1498.17,1386.4 1498.17,1386.41 1498.17,1386.42 1498.18,1386.43 1498.18,1386.44 1498.18,1386.45 1498.19,1386.45 1498.19,1386.46 1498.2,1386.47 1498.2,1386.48 1498.2,1386.49 1498.21,1386.5 1498.21,1386.51 1498.21,1386.52 1498.22,1386.53 1498.22,1386.54 1498.23,1386.55 1498.23,1386.55 1498.23,1386.56 1498.24,1386.57 1498.24,1386.58 1498.25,1386.59 1498.25,1386.6 1498.25,1386.61 1498.26,1386.62 1498.26,1386.63 1498.27,1386.64 1498.27,1386.65 1498.27,1386.65 1498.28,1386.66 1498.28,1386.67 1498.29,1386.68 1498.29,1386.69 1498.29,1386.7 1498.3,1386.71 1498.3,1386.72 1498.31,1386.73 1498.31,1386.74 1498.31,1386.75 1498.32,1386.75 1498.32,1386.76 1498.33,1386.77 1498.33,1386.78 1498.34,1386.79 1498.34,1386.8 1498.34,1386.81 1498.35,1386.82 1498.35,1386.83 1498.36,1386.84 1498.36,1386.84 1498.37,1386.85 1498.37,1386.86 1498.38,1386.87 1498.38,1386.88 1498.38,1386.89 1498.39,1386.9 1498.39,1386.91 1498.4,1386.92 1498.4,1386.92 1498.41,1386.93 1498.41,1386.94 1498.42,1386.95 1498.42,1386.96 1498.42,1386.97 1498.43,1386.98 1498.43,1386.99 1498.44,1387 1498.44,1387.01 1498.45,1387.01 1498.45,1387.02 1498.46,1387.03 1498.46,1387.04 1498.47,1387.05 1498.47,1387.06 1498.48,1387.07 1498.48,1387.08 1498.49,1387.09 1498.49,1387.09 1498.5,1387.1 1498.5,1387.11 1498.5,1387.12 1498.51,1387.13 1498.51,1387.14 1498.52,1387.15 1498.52,1387.16 1498.53,1387.16 1498.53,1387.17 1498.54,1387.18 1498.54,1387.19 1498.55,1387.2 1498.55,1387.21 1498.56,1387.22 1498.56,1387.23 1498.57,1387.23 1498.57,1387.24 1498.58,1387.25 1498.58,1387.26 1498.59,1387.27 1498.59,1387.28 1498.6,1387.29 1498.6,1387.3 1498.61,1387.31 1498.61,1387.31 1498.62,1387.32 1498.62,1387.33 1498.63,1387.34 1498.64,1387.35 1498.64,1387.36 1498.65,1387.37 1498.65,1387.37 1498.66,1387.38 1498.66,1387.39 1498.67,1387.4 1498.67,1387.41 1498.68,1387.42 1498.68,1387.43 1498.69,1387.44 1498.69,1387.44 1498.7,1387.45 1498.7,1387.46 1498.71,1387.47 1498.71,1387.48 1498.72,1387.49 1498.73,1387.5 1498.73,1387.51 1498.74,1387.51 1498.74,1387.52 1498.75,1387.53 1498.75,1387.54 1498.76,1387.55 1498.76,1387.56 1498.77,1387.57 1498.78,1387.57 1498.78,1387.58 1498.79,1387.59 1498.79,1387.6 1498.8,1387.61 1498.8,1387.62 1498.81,1387.63 1498.81,1387.63 1498.82,1387.64 1498.83,1387.65 1498.83,1387.66 1498.84,1387.67 1498.84,1387.68 1498.85,1387.69 1498.85,1387.69 1498.86,1387.7 1498.87,1387.71 1498.87,1387.72 1498.88,1387.73 1498.88,1387.74 1498.89,1387.75 1498.9,1387.75 1498.9,1387.76 1498.91,1387.77 1498.91,1387.78 1498.92,1387.79 1498.92,1387.8 1498.93,1387.81 1498.94,1387.81 1498.94,1387.82 1498.95,1387.83 1498.95,1387.84 1498.96,1387.85 1498.97,1387.86 1498.97,1387.86 1498.98,1387.87 1498.98,1387.88 1498.99,1387.89 1499,1387.9 1499,1387.91 1499.01,1387.92 1499.02,1387.92 1499.02,1387.93 1499.03,1387.94 1499.03,1387.95 1499.04,1387.96 1499.05,1387.97 1499.05,1387.97 1499.06,1387.98 1499.06,1387.99 1499.07,1388 1499.08,1388.01 1499.08,1388.02 1499.09,1388.02 1499.1,1388.03 1499.1,1388.04 1499.11,1388.05 1499.12,1388.06 1499.12,1388.07 1499.13,1388.08 1499.13,1388.08 1499.14,1388.09 1499.15,1388.1 1499.15,1388.11 1499.16,1388.12 1499.17,1388.13 1499.17,1388.13 1499.18,1388.14 1499.19,1388.15 1499.19,1388.16 1499.2,1388.17 1499.21,1388.18 1499.21,1388.18 1499.22,1388.19 1499.22,1388.2 1499.23,1388.21 1499.24,1388.22 1499.24,1388.23 1499.25,1388.23 1499.26,1388.24 1499.26,1388.25 1499.27,1388.26 1499.28,1388.27 1499.28,1388.28 1499.29,1388.28 1499.3,1388.29 1499.3,1388.3 1499.31,1388.31 1499.32,1388.32 1499.33,1388.32 1499.33,1388.33 1499.34,1388.34 1499.35,1388.35 1499.35,1388.36 1499.36,1388.37 1499.37,1388.37 1499.37,1388.38 1499.38,1388.39 1499.39,1388.4 1499.39,1388.41 1499.4,1388.42 1499.41,1388.42 1499.41,1388.43 1499.42,1388.44 1499.43,1388.45 1499.44,1388.46 1499.44,1388.46 1499.45,1388.47 1499.46,1388.48 1499.46,1388.49 1499.47,1388.5 1499.48,1388.51 1499.48,1388.51 1499.49,1388.52 1499.5,1388.53 1499.51,1388.54 1499.51,1388.55 1499.52,1388.55 1499.53,1388.56 1499.53,1388.57 1499.54,1388.58 1499.55,1388.59 1499.56,1388.59 1499.56,1388.6 1499.57,1388.61 1499.58,1388.62 1499.58,1388.63 1499.59,1388.64 1499.6,1388.64 1499.61,1388.65 1499.61,1388.66 1499.62,1388.67 1499.63,1388.68 1499.64,1388.68 1499.64,1388.69 1499.65,1388.7 1499.66,1388.71 1499.67,1388.72 1499.67,1388.72 1499.68,1388.73 1499.69,1388.74 1499.7,1388.75 1499.7,1388.76 1499.71,1388.76 1499.72,1388.77 1499.73,1388.78 1499.73,1388.79 1499.74,1388.8 1499.75,1388.8 1499.76,1388.81 1499.76,1388.82 1499.77,1388.83 1499.78,1388.84 1499.79,1388.84 1499.79,1388.85 1499.8,1388.86 1499.81,1388.87 1499.82,1388.88 1499.82,1388.88 1499.83,1388.89 1499.84,1388.9 1499.85,1388.91 1499.85,1388.92 1499.86,1388.92 1499.87,1388.93 1499.88,1388.94 1499.89,1388.95 1499.89,1388.96 1499.9,1388.96 1499.91,1388.97 1499.92,1388.98 1499.92,1388.99 1499.93,1389 1499.94,1389 1499.95,1389.01 1499.96,1389.02 1499.96,1389.03 1499.97,1389.04 1499.98,1389.04 1499.99,1389.05 1500,1389.06 1500,1389.07 1500.01,1389.08 1500.02,1389.08 1500.03,1389.09 1500.04,1389.1 1500.04,1389.11 1500.05,1389.11 1500.06,1389.12 1500.07,1389.13 1500.08,1389.14 1500.08,1389.15 1500.09,1389.15 1500.1,1389.16 1500.11,1389.17 1500.12,1389.18 1500.12,1389.19 1500.13,1389.19 1500.14,1389.2 1500.15,1389.21 1500.16,1389.22 1500.16,1389.22 1500.17,1389.23 1500.18,1389.24 1500.19,1389.25 1500.2,1389.26 1500.21,1389.26 1500.21,1389.27 1500.22,1389.28 1500.23,1389.29 1500.24,1389.3 1500.25,1389.3 1500.26,1389.31 1500.26,1389.32 1500.27,1389.33 1500.28,1389.33 1500.29,1389.34 1500.3,1389.35 1500.31,1389.36 1500.31,1389.37 1500.32,1389.37 1500.33,1389.38 1500.34,1389.39 1500.35,1389.4 1500.36,1389.4 1500.37,1389.41 1500.37,1389.42 1500.38,1389.43 1500.39,1389.43 1500.4,1389.44 1500.41,1389.45 1500.42,1389.46 1500.43,1389.47 1500.43,1389.47 1500.44,1389.48 1500.45,1389.49 1500.46,1389.5 1500.47,1389.5 1500.48,1389.51 1500.49,1389.52 1500.49,1389.53 1500.5,1389.53 1500.51,1389.54 1500.52,1389.55 1500.53,1389.56 1500.54,1389.57 1500.55,1389.57 1500.56,1389.58 1500.56,1389.59 1500.57,1389.6 1500.58,1389.6 1500.59,1389.61 1500.6,1389.62 1500.61,1389.63 1500.62,1389.63 1500.63,1389.64 1500.63,1389.65 1500.64,1389.66 1500.65,1389.66 1500.66,1389.67 1500.67,1389.68 1500.68,1389.69 1500.69,1389.7 1500.7,1389.7 1500.71,1389.71 1500.72,1389.72 1500.72,1389.73 1500.73,1389.73 1500.74,1389.74 1500.75,1389.75 1500.76,1389.76 1500.77,1389.76 1500.78,1389.77 1500.79,1389.78 1500.8,1389.79 1500.81,1389.79 1500.81,1389.8 1500.82,1389.81 1500.83,1389.82 1500.84,1389.82 1500.85,1389.83 1500.86,1389.84 1500.87,1389.85 1500.88,1389.85 1500.89,1389.86 1500.9,1389.87 1500.91,1389.88 1500.92,1389.88 1500.92,1389.89 1500.93,1389.9 1500.94,1389.91 1500.95,1389.91 1500.96,1389.92 1500.97,1389.93 1500.98,1389.94 1500.99,1389.94 1501,1389.95 1501.01,1389.96 1501.02,1389.97 1501.03,1389.97 1501.04,1389.98 1501.05,1389.99 1501.06,1390 1501.06,1390 1501.07,1390.01 1501.08,1390.02 1501.09,1390.03 1501.1,1390.03 1501.11,1390.04 1501.12,1390.05 1501.13,1390.06 1501.14,1390.06 1501.15,1390.07 1501.16,1390.08 1501.17,1390.09 1501.18,1390.09 1501.19,1390.1 1501.2,1390.11 1501.21,1390.12 1501.22,1390.12 1501.23,1390.13 1501.24,1390.14 1501.25,1390.15 1501.26,1390.15 1501.27,1390.16 1501.27,1390.17 1501.28,1390.17 1501.29,1390.18 1501.3,1390.19 1501.31,1390.2 1501.32,1390.2 1501.33,1390.21 1501.34,1390.22 1501.35,1390.23 1501.36,1390.23 1501.37,1390.24 1501.38,1390.25 1501.39,1390.26 1501.4,1390.26 1501.41,1390.27 1501.42,1390.28 1501.43,1390.29 1501.44,1390.29 1501.45,1390.3 1501.46,1390.31 1501.47,1390.31 1501.48,1390.32 1501.49,1390.33 1501.5,1390.34 1501.51,1390.34 1501.52,1390.35 1501.53,1390.36 1501.54,1390.37 1501.55,1390.37 1501.56,1390.38 1501.57,1390.39 1501.58,1390.39 1501.59,1390.4 1501.6,1390.41 1501.61,1390.42 1501.62,1390.42 1501.63,1390.43 1501.64,1390.44 1501.65,1390.45 1501.66,1390.45 1501.67,1390.46 1501.68,1390.47 1501.69,1390.47 1501.7,1390.48 1501.71,1390.49 1501.72,1390.5 1501.73,1390.5 1501.74,1390.51 1501.75,1390.52 1501.76,1390.53 1501.77,1390.53 1501.78,1390.54 1501.79,1390.55 1501.8,1390.55 1501.81,1390.56 1501.82,1390.57 1501.83,1390.58 1501.84,1390.58 1501.85,1390.59 1501.87,1390.6 1501.88,1390.6 1501.89,1390.61 1501.9,1390.62 1501.91,1390.63 1501.92,1390.63 1501.93,1390.64 1501.94,1390.65 1501.95,1390.65 1501.96,1390.66 1501.97,1390.67 1501.98,1390.68 1501.99,1390.68 1502,1390.69 1502.01,1390.7 1502.02,1390.7 1502.03,1390.71 1502.04,1390.72 1502.05,1390.73 1502.06,1390.73 1502.07,1390.74 1502.08,1390.75 1502.1,1390.75 1502.11,1390.76 1502.12,1390.77 1502.13,1390.78 1502.14,1390.78 1502.15,1390.79 1502.16,1390.8 1502.17,1390.8 1502.18,1390.81 1502.19,1390.82 1502.2,1390.83 1502.21,1390.83 1502.22,1390.84 1502.23,1390.85 1502.24,1390.85 1502.26,1390.86 1502.27,1390.87 1502.28,1390.87 1502.29,1390.88 1502.3,1390.89 1502.31,1390.9 1502.32,1390.9 1502.33,1390.91 1502.34,1390.92 1502.35,1390.92 1502.36,1390.93 1502.37,1390.94 1502.38,1390.95 1502.4,1390.95 1502.41,1390.96 1502.42,1390.97 1502.43,1390.97 1502.44,1390.98 1502.45,1390.99 1502.46,1390.99 1502.47,1391 1502.48,1391.01 1502.49,1391.02 1502.5,1391.02 1502.52,1391.03 1502.53,1391.04 1502.54,1391.04 1502.55,1391.05 1502.56,1391.06 1502.57,1391.06 1502.58,1391.07 1502.59,1391.08 1502.6,1391.09 1502.62,1391.09 1502.63,1391.1 1502.64,1391.11 1502.65,1391.11 1502.66,1391.12 1502.67,1391.13 1502.68,1391.13 1502.69,1391.14 1502.7,1391.15 1502.72,1391.15 1502.73,1391.16 1502.74,1391.17 1502.75,1391.18 1502.76,1391.18 1502.77,1391.19 1502.78,1391.2 1502.79,1391.2 1502.81,1391.21 1502.82,1391.22 1502.83,1391.22 1502.84,1391.23 1502.85,1391.24 1502.86,1391.24 1502.87,1391.25 1502.88,1391.26 1502.9,1391.26 1502.91,1391.27 1502.92,1391.28 1502.93,1391.29 1502.94,1391.29 1502.95,1391.3 1502.96,1391.31 1502.98,1391.31 1502.99,1391.32 1503,1391.33 1503.01,1391.33 1503.02,1391.34 1503.03,1391.35 1503.04,1391.35 1503.06,1391.36 1503.07,1391.37 1503.08,1391.37 1503.09,1391.38 1503.1,1391.39 1503.11,1391.4 1503.12,1391.4 1503.14,1391.41 1503.15,1391.42 1503.16,1391.42 1503.17,1391.43 1503.18,1391.44 1503.19,1391.44 1503.21,1391.45 1503.22,1391.46 1503.23,1391.46 1503.24,1391.47 1503.25,1391.48 1503.26,1391.48 1503.28,1391.49 1503.29,1391.5 1503.3,1391.5 1503.31,1391.51 1503.32,1391.52 1503.33,1391.52 1503.35,1391.53 1503.36,1391.54 1503.37,1391.54 1503.38,1391.55 1503.39,1391.56 1503.41,1391.56 1503.42,1391.57 1503.43,1391.58 1503.44,1391.58 1503.45,1391.59 1503.46,1391.6 1503.48,1391.6 1503.49,1391.61 1503.5,1391.62 1503.51,1391.63 1503.52,1391.63 1503.54,1391.64 1503.55,1391.65 1503.56,1391.65 1503.57,1391.66 1503.58,1391.67 1503.6,1391.67 1503.61,1391.68 1503.62,1391.69 1503.63,1391.69 1503.64,1391.7 1503.66,1391.71 1503.67,1391.71 1503.68,1391.72 1503.69,1391.73 1503.7,1391.73 1503.72,1391.74 1503.73,1391.75 1503.74,1391.75 1503.75,1391.76 1503.76,1391.77 1503.78,1391.77 1503.79,1391.78 1503.8,1391.79 1503.81,1391.79 1503.82,1391.8 1503.84,1391.81 1503.85,1391.81 1503.86,1391.82 1503.87,1391.83 1503.89,1391.83 1503.9,1391.84 1503.91,1391.85 1503.92,1391.85 1503.93,1391.86 1503.95,1391.86 1503.96,1391.87 1503.97,1391.88 1503.98,1391.88 1504,1391.89 1504.01,1391.9 1504.02,1391.9 1504.03,1391.91 1504.04,1391.92 1504.06,1391.92 1504.07,1391.93 1504.08,1391.94 1504.09,1391.94 1504.11,1391.95 1504.12,1391.96 1504.13,1391.96 1504.14,1391.97 1504.16,1391.98 1504.17,1391.98 1504.18,1391.99 1504.19,1392 1504.21,1392 1504.22,1392.01 1504.23,1392.02 1504.24,1392.02 1504.26,1392.03 1504.27,1392.04 1504.28,1392.04 1504.29,1392.05 1504.31,1392.06 1504.32,1392.06 1504.33,1392.07 1504.34,1392.07 1504.36,1392.08 1504.37,1392.09 1504.38,1392.09 1504.39,1392.1 1504.41,1392.11 1504.42,1392.11 1504.43,1392.12 1504.44,1392.13 1504.46,1392.13 1504.47,1392.14 1504.48,1392.15 1504.49,1392.15 1504.51,1392.16 1504.52,1392.17 1504.53,1392.17 1504.55,1392.18 1504.56,1392.18 1504.57,1392.19 1504.58,1392.2 1504.6,1392.2 1504.61,1392.21 1504.62,1392.22 1504.63,1392.22 1504.65,1392.23 1504.66,1392.24 1504.67,1392.24 1504.69,1392.25 1504.7,1392.26 1504.71,1392.26 1504.72,1392.27 1504.74,1392.28 1504.75,1392.28 1504.76,1392.29 1504.78,1392.29 1504.79,1392.3 1504.8,1392.31 1504.81,1392.31 1504.83,1392.32 1504.84,1392.33 1504.85,1392.33 1504.87,1392.34 1504.88,1392.35 1504.89,1392.35 1504.9,1392.36 1504.92,1392.36 1504.93,1392.37 1504.94,1392.38 1504.96,1392.38 1504.97,1392.39 1504.98,1392.4 1505,1392.4 1505.01,1392.41 1505.02,1392.42 1505.04,1392.42 1505.05,1392.43 1505.06,1392.43 1505.07,1392.44 1505.09,1392.45 1505.1,1392.45 1505.11,1392.46 1505.13,1392.47 1505.14,1392.47 1505.15,1392.48 1505.17,1392.49 1505.18,1392.49 1505.19,1392.5 1505.21,1392.5 1505.22,1392.51 1505.23,1392.52 1505.25,1392.52 1505.26,1392.53 1505.27,1392.54 1505.28,1392.54 1505.3,1392.55 1505.31,1392.55 1505.32,1392.56 1505.34,1392.57 1505.35,1392.57 1505.36,1392.58 1505.38,1392.59 1505.39,1392.59 1505.4,1392.6 1505.42,1392.61 1505.43,1392.61 1505.44,1392.62 1505.46,1392.62 1505.47,1392.63 1505.48,1392.64 1505.5,1392.64 1505.51,1392.65 1505.52,1392.66 1505.54,1392.66 1505.55,1392.67 1505.57,1392.67 1505.58,1392.68 1505.59,1392.69 1505.61,1392.69 1505.62,1392.7 1505.63,1392.71 1505.65,1392.71 1505.66,1392.72 1505.67,1392.72 1505.69,1392.73 1505.7,1392.74 1505.71,1392.74 1505.73,1392.75 1505.74,1392.75 1505.75,1392.76 1505.77,1392.77 1505.78,1392.77 1505.79,1392.78 1505.81,1392.79 1505.82,1392.79 1505.84,1392.8 1505.85,1392.8 1505.86,1392.81 1505.88,1392.82 1505.89,1392.82 1505.9,1392.83 1505.92,1392.84 1505.93,1392.84 1505.94,1392.85 1505.96,1392.85 1505.97,1392.86 1505.99,1392.87 1506,1392.87 1506.01,1392.88 1506.03,1392.88 1506.04,1392.89 1506.05,1392.9 1506.07,1392.9 1506.08,1392.91 1506.1,1392.92 1506.11,1392.92 1506.12,1392.93 1506.14,1392.93 1506.15,1392.94 1506.16,1392.95 1506.18,1392.95 1506.19,1392.96 1506.21,1392.96 1506.22,1392.97 1506.23,1392.98 1506.25,1392.98 1506.26,1392.99 1506.28,1392.99 1506.29,1393 1506.3,1393.01 1506.32,1393.01 1506.33,1393.02 1506.35,1393.03 1506.36,1393.03 1506.37,1393.04 1506.39,1393.04 1506.4,1393.05 1506.42,1393.06 1506.43,1393.06 1506.44,1393.07 1506.46,1393.07 1506.47,1393.08 1506.49,1393.09 1506.5,1393.09 1506.51,1393.1 1506.53,1393.1 1506.54,1393.11 1506.56,1393.12 1506.57,1393.12 1506.58,1393.13 1506.6,1393.13 1506.61,1393.14 1506.63,1393.15 1506.64,1393.15 1506.65,1393.16 1506.67,1393.16 1506.68,1393.17 1506.7,1393.18 1506.71,1393.18 1506.72,1393.19 1506.74,1393.19 1506.75,1393.2 1506.77,1393.21 1506.78,1393.21 1506.8,1393.22 1506.81,1393.22 1506.82,1393.23 1506.84,1393.24 1506.85,1393.24 1506.87,1393.25 1506.88,1393.25 1506.9,1393.26 1506.91,1393.27 1506.92,1393.27 1506.94,1393.28 1506.95,1393.28 1506.97,1393.29 1506.98,1393.3 1507,1393.3 1507.01,1393.31 1507.02,1393.31 1507.04,1393.32 1507.05,1393.33 1507.07,1393.33 1507.08,1393.34 1507.1,1393.34 1507.11,1393.35 1507.12,1393.36 1507.14,1393.36 1507.15,1393.37 1507.17,1393.37 1507.18,1393.38 1507.2,1393.39 1507.21,1393.39 1507.23,1393.4 1507.24,1393.4 1507.25,1393.41 1507.27,1393.42 1507.28,1393.42 1507.3,1393.43 1507.31,1393.43 1507.33,1393.44 1507.34,1393.44 1507.36,1393.45 1507.37,1393.46 1507.39,1393.46 1507.4,1393.47 1507.41,1393.47 1507.43,1393.48 1507.44,1393.49 1507.46,1393.49 1507.47,1393.5 1507.49,1393.5 1507.5,1393.51 1507.52,1393.52 1507.53,1393.52 1507.55,1393.53 1507.56,1393.53 1507.58,1393.54 1507.59,1393.54 1507.61,1393.55 1507.62,1393.56 1507.63,1393.56 1507.65,1393.57 1507.66,1393.57 1507.68,1393.58 1507.69,1393.59 1507.71,1393.59 1507.72,1393.6 1507.74,1393.6 1507.75,1393.61 1507.77,1393.61 1507.78,1393.62 1507.8,1393.63 1507.81,1393.63 1507.83,1393.64 1507.84,1393.64 1507.86,1393.65 1507.87,1393.66 1507.89,1393.66 1507.9,1393.67 1507.92,1393.67 1507.93,1393.68 1507.94,1393.68 1507.96,1393.69 1507.97,1393.7 1507.99,1393.7 1508,1393.71 1508.02,1393.71 1508.03,1393.72 1508.05,1393.72 1508.06,1393.73 1508.08,1393.74 1508.09,1393.74 1508.11,1393.75 1508.12,1393.75 1508.14,1393.76 1508.15,1393.77 1508.17,1393.77 1508.18,1393.78 1508.2,1393.78 1508.21,1393.79 1508.23,1393.79 1508.24,1393.8 1508.26,1393.81 1508.27,1393.81 1508.29,1393.82 1508.3,1393.82 1508.32,1393.83 1508.33,1393.83 1508.35,1393.84 1508.36,1393.85 1508.38,1393.85 1508.39,1393.86 1508.41,1393.86 1508.43,1393.87 1508.44,1393.87 1508.46,1393.88 1508.47,1393.89 1508.49,1393.89 1508.5,1393.9 1508.52,1393.9 1508.53,1393.91 1508.55,1393.91 1508.56,1393.92 1508.58,1393.93 1508.59,1393.93 1508.61,1393.94 1508.62,1393.94 1508.64,1393.95 1508.65,1393.95 1508.67,1393.96 1508.68,1393.97 1508.7,1393.97 1508.71,1393.98 1508.73,1393.98 1508.74,1393.99 1508.76,1393.99 1508.78,1394 1508.79,1394 1508.81,1394.01 1508.82,1394.02 1508.84,1394.02 1508.85,1394.03 1508.87,1394.03 1508.88,1394.04 1508.9,1394.04 1508.91,1394.05 1508.93,1394.06 1508.94,1394.06 1508.96,1394.07 1508.97,1394.07 1508.99,1394.08 1509.01,1394.08 1509.02,1394.09 1509.04,1394.1 1509.05,1394.1 1509.07,1394.11 1509.08,1394.11 1509.1,1394.12 1509.11,1394.12 1509.13,1394.13 1509.14,1394.13 1509.16,1394.14 1509.18,1394.15 1509.19,1394.15 1509.21,1394.16 1509.22,1394.16 1509.24,1394.17 1509.25,1394.17 1509.27,1394.18 1509.28,1394.18 1509.3,1394.19 1509.32,1394.2 1509.33,1394.2 1509.35,1394.21 1509.36,1394.21 1509.38,1394.22 1509.39,1394.22 1509.41,1394.23 1509.43,1394.23 1509.44,1394.24 1509.46,1394.25 1509.47,1394.25 1509.49,1394.26 1509.5,1394.26 1509.52,1394.27 1509.53,1394.27 1509.55,1394.28 1509.57,1394.28 1509.58,1394.29 1509.6,1394.3 1509.61,1394.3 1509.63,1394.31 1509.64,1394.31 1509.66,1394.32 1509.68,1394.32 1509.69,1394.33 1509.71,1394.33 1509.72,1394.34 1509.74,1394.35 1509.76,1394.35 1509.77,1394.36 1509.79,1394.36 1509.8,1394.37 1509.82,1394.37 1509.83,1394.38 1509.85,1394.38 1509.87,1394.39 1509.88,1394.39 1509.9,1394.4 1509.91,1394.41 1509.93,1394.41 1509.95,1394.42 1509.96,1394.42 1509.98,1394.43 1509.99,1394.43 1510.01,1394.44 1510.02,1394.44 1510.04,1394.45 1510.06,1394.45 1510.07,1394.46 1510.09,1394.47 1510.1,1394.47 1510.12,1394.48 1510.14,1394.48 1510.15,1394.49 1510.17,1394.49 1510.18,1394.5 1510.2,1394.5 1510.22,1394.51 1510.23,1394.51 1510.25,1394.52 1510.26,1394.53 1510.28,1394.53 1510.3,1394.54 1510.31,1394.54 1510.33,1394.55 1510.34,1394.55 1510.36,1394.56 1510.38,1394.56 1510.39,1394.57 1510.41,1394.57 1510.43,1394.58 1510.44,1394.59 1510.46,1394.59 1510.47,1394.6 1510.49,1394.6 1510.51,1394.61 1510.52,1394.61 1510.54,1394.62 1510.55,1394.62 1510.57,1394.63 1510.59,1394.63 1510.6,1394.64 1510.62,1394.64 1510.64,1394.65 1510.65,1394.66 1510.67,1394.66 1510.68,1394.67 1510.7,1394.67 1510.72,1394.68 1510.73,1394.68 1510.75,1394.69 1510.77,1394.69 1510.78,1394.7 1510.8,1394.7 1510.81,1394.71 1510.83,1394.71 1510.85,1394.72 1510.86,1394.72 1510.88,1394.73 1510.9,1394.74 1510.91,1394.74 1510.93,1394.75 1510.94,1394.75 1510.96,1394.76 1510.98,1394.76 1510.99,1394.77 1511.01,1394.77 1511.03,1394.78 1511.04,1394.78 1511.06,1394.79 1511.08,1394.79 1511.09,1394.8 1511.11,1394.8 1511.12,1394.81 1511.14,1394.82 1511.16,1394.82 1511.17,1394.83 1511.19,1394.83 1511.21,1394.84 1511.22,1394.84 1511.24,1394.85 1511.26,1394.85 1511.27,1394.86 1511.29,1394.86 1511.31,1394.87 1511.32,1394.87 1511.34,1394.88 1511.36,1394.88 1511.37,1394.89 1511.39,1394.89 1511.4,1394.9 1511.42,1394.91 1511.44,1394.91 1511.45,1394.92 1511.47,1394.92 1511.49,1394.93 1511.5,1394.93 1511.52,1394.94 1511.54,1394.94 1511.55,1394.95 1511.57,1394.95 1511.59,1394.96 1511.6,1394.96 1511.62,1394.97 1511.64,1394.97 1511.65,1394.98 1511.67,1394.98 1511.69,1394.99 1511.7,1394.99 1511.72,1395 1511.74,1395 1511.75,1395.01 1511.77,1395.02 1511.79,1395.02 1511.8,1395.03 1511.82,1395.03 1511.84,1395.04 1511.85,1395.04 1511.87,1395.05 1511.89,1395.05 1511.9,1395.06 1511.92,1395.06 1511.94,1395.07 1511.95,1395.07 1511.97,1395.08 1511.99,1395.08 1512,1395.09 1512.02,1395.09 1512.04,1395.1 1512.06,1395.1 1512.07,1395.11 1512.09,1395.11 1512.11,1395.12 1512.12,1395.12 1512.14,1395.13 1512.16,1395.13 1512.17,1395.14 1512.19,1395.14 1512.21,1395.15 1512.22,1395.16 1512.24,1395.16 1512.26,1395.17 1512.27,1395.17 1512.29,1395.18 1512.31,1395.18 1512.32,1395.19 1512.34,1395.19 1512.36,1395.2 1512.38,1395.2 1512.39,1395.21 1512.41,1395.21 1512.43,1395.22 1512.44,1395.22 1512.46,1395.23 1512.48,1395.23 1512.49,1395.24 1512.51,1395.24 1512.53,1395.25 1512.55,1395.25 1512.56,1395.26 1512.58,1395.26 1512.6,1395.27 1512.61,1395.27 1512.63,1395.28 1512.65,1395.28 1512.66,1395.29 1512.68,1395.29 1512.7,1395.3 1512.72,1395.3 1512.73,1395.31 1512.75,1395.31 1512.77,1395.32 1512.78,1395.32 1512.8,1395.33 1512.82,1395.33 1512.84,1395.34 1512.85,1395.34 1512.87,1395.35 1512.89,1395.35 1512.9,1395.36 1512.92,1395.36 1512.94,1395.37 1512.96,1395.38 1512.97,1395.38 1512.99,1395.39 1513.01,1395.39 1513.02,1395.4 1513.04,1395.4 1513.06,1395.41 1513.08,1395.41 1513.09,1395.42 1513.11,1395.42 1513.13,1395.43 1513.14,1395.43 1513.16,1395.44 1513.18,1395.44 1513.2,1395.45 1513.21,1395.45 1513.23,1395.46 1513.25,1395.46 1513.27,1395.47 1513.28,1395.47 1513.3,1395.48 1513.32,1395.48 1513.33,1395.49 1513.35,1395.49 1513.37,1395.5 1513.39,1395.5 1513.4,1395.51 1513.42,1395.51 1513.44,1395.52 1513.46,1395.52 1513.47,1395.53 1513.49,1395.53 1513.51,1395.54 1513.53,1395.54 1513.54,1395.55 1513.56,1395.55 1513.58,1395.56 1513.6,1395.56 1513.61,1395.57 1513.63,1395.57 1513.65,1395.58 1513.66,1395.58 1513.68,1395.59 1513.7,1395.59 1513.72,1395.6 1513.73,1395.6 1513.75,1395.61 1513.77,1395.61 1513.79,1395.62 1513.8,1395.62 1513.82,1395.63 1513.84,1395.63 1513.86,1395.64 1513.87,1395.64 1513.89,1395.65 1513.91,1395.65 1513.93,1395.66 1513.94,1395.66 1513.96,1395.67 1513.98,1395.67 1514,1395.67 1514.01,1395.68 1514.03,1395.68 1514.05,1395.69 1514.07,1395.69 1514.09,1395.7 1514.1,1395.7 1514.12,1395.71 1514.14,1395.71 1514.16,1395.72 1514.17,1395.72 1514.19,1395.73 1514.21,1395.73 1514.23,1395.74 1514.24,1395.74 1514.26,1395.75 1514.28,1395.75 1514.3,1395.76 1514.31,1395.76 1514.33,1395.77 1514.35,1395.77 1514.37,1395.78 1514.39,1395.78 1514.4,1395.79 1514.42,1395.79 1514.44,1395.8 1514.46,1395.8 1514.47,1395.81 1514.49,1395.81 1514.51,1395.82 1514.53,1395.82 1514.54,1395.83 1514.56,1395.83 1514.58,1395.84 1514.6,1395.84 1514.62,1395.85 1514.63,1395.85 1514.65,1395.86 1514.67,1395.86 1514.69,1395.87 1514.7,1395.87 1514.72,1395.88 1514.74,1395.88 1514.76,1395.89 1514.78,1395.89 1514.79,1395.89 1514.81,1395.9 1514.83,1395.9 1514.85,1395.91 1514.87,1395.91 1514.88,1395.92 1514.9,1395.92 1514.92,1395.93 1514.94,1395.93 1514.95,1395.94 1514.97,1395.94 1514.99,1395.95 1515.01,1395.95 1515.03,1395.96 1515.04,1395.96 1515.06,1395.97 1515.08,1395.97 1515.1,1395.98 1515.12,1395.98 1515.13,1395.99 1515.15,1395.99 1515.17,1396 1515.19,1396 1515.21,1396.01 1515.22,1396.01 1515.24,1396.02 1515.26,1396.02 1515.28,1396.02 1515.3,1396.03 1515.31,1396.03 1515.33,1396.04 1515.35,1396.04 1515.37,1396.05 1515.39,1396.05 1515.4,1396.06 1515.42,1396.06 1515.44,1396.07 1515.46,1396.07 1515.48,1396.08 1515.49,1396.08 1515.51,1396.09 1515.53,1396.09 1515.55,1396.1 1515.57,1396.1 1515.58,1396.11 1515.6,1396.11 1515.62,1396.12 1515.64,1396.12 1515.66,1396.12 1515.68,1396.13 1515.69,1396.13 1515.71,1396.14 1515.73,1396.14 1515.75,1396.15 1515.77,1396.15 1515.78,1396.16 1515.8,1396.16 1515.82,1396.17 1515.84,1396.17 1515.86,1396.18 1515.88,1396.18 1515.89,1396.19 1515.91,1396.19 1515.93,1396.2 1515.95,1396.2 1515.97,1396.21 1515.98,1396.21 1516,1396.21 1516.02,1396.22 1516.04,1396.22 1516.06,1396.23 1516.08,1396.23 1516.09,1396.24 1516.11,1396.24 1516.13,1396.25 1516.15,1396.25 1516.17,1396.26 1516.19,1396.26 1516.2,1396.27 1516.22,1396.27 1516.24,1396.28 1516.26,1396.28 1516.28,1396.29 1516.3,1396.29 1516.31,1396.29 1516.33,1396.3 1516.35,1396.3 1516.37,1396.31 1516.39,1396.31 1516.41,1396.32 1516.42,1396.32 1516.44,1396.33 1516.46,1396.33 1516.48,1396.34 1516.5,1396.34 1516.52,1396.35 1516.53,1396.35 1516.55,1396.36 1516.57,1396.36 1516.59,1396.36 1516.61,1396.37 1516.63,1396.37 1516.64,1396.38 1516.66,1396.38 1516.68,1396.39 1516.7,1396.39 1516.72,1396.4 1516.74,1396.4 1516.76,1396.41 1516.77,1396.41 1516.79,1396.42 1516.81,1396.42 1516.83,1396.42 1516.85,1396.43 1516.87,1396.43 1516.89,1396.44 1516.9,1396.44 1516.92,1396.45 1516.94,1396.45 1516.96,1396.46 1516.98,1396.46 1517,1396.47 1517.01,1396.47 1517.03,1396.48 1517.05,1396.48 1517.07,1396.48 1517.09,1396.49 1517.11,1396.49 1517.13,1396.5 1517.15,1396.5 1517.16,1396.51 1517.18,1396.51 1517.2,1396.52 1517.22,1396.52 1517.24,1396.53 1517.26,1396.53 1517.28,1396.53 1517.29,1396.54 1517.31,1396.54 1517.33,1396.55 1517.35,1396.55 1517.37,1396.56 1517.39,1396.56 1517.41,1396.57 1517.42,1396.57 1517.44,1396.58 1517.46,1396.58 1517.48,1396.59 1517.5,1396.59 1517.52,1396.59 1517.54,1396.6 1517.56,1396.6 1517.57,1396.61 1517.59,1396.61 1517.61,1396.62 1517.63,1396.62 1517.65,1396.63 1517.67,1396.63 1517.69,1396.63 1517.71,1396.64 1517.72,1396.64 1517.74,1396.65 1517.76,1396.65 1517.78,1396.66 1517.8,1396.66 1517.82,1396.67 1517.84,1396.67 1517.86,1396.68 1517.87,1396.68 1517.89,1396.68 1517.91,1396.69 1517.93,1396.69 1517.95,1396.7 1517.97,1396.7 1517.99,1396.71 1518.01,1396.71 1518.03,1396.72 1518.04,1396.72 1518.06,1396.73 1518.08,1396.73 1518.1,1396.73 1518.12,1396.74 1518.14,1396.74 1518.16,1396.75 1518.18,1396.75 1518.2,1396.76 1518.21,1396.76 1518.23,1396.77 1518.25,1396.77 1518.27,1396.77 1518.29,1396.78 1518.31,1396.78 1518.33,1396.79 1518.35,1396.79 1518.37,1396.8 1518.38,1396.8 1518.4,1396.81 1518.42,1396.81 1518.44,1396.81 1518.46,1396.82 1518.48,1396.82 1518.5,1396.83 1518.52,1396.83 1518.54,1396.84 1518.56,1396.84 1518.57,1396.85 1518.59,1396.85 1518.61,1396.85 1518.63,1396.86 1518.65,1396.86 1518.67,1396.87 1518.69,1396.87 1518.71,1396.88 1518.73,1396.88 1518.75,1396.89 1518.77,1396.89 1518.78,1396.89 1518.8,1396.9 1518.82,1396.9 1518.84,1396.91 1518.86,1396.91 1518.88,1396.92 1518.9,1396.92 1518.92,1396.93 1518.94,1396.93 1518.96,1396.93 1518.98,1396.94 1518.99,1396.94 1519.01,1396.95 1519.03,1396.95 1519.05,1396.96 1519.07,1396.96 1519.09,1396.97 1519.11,1396.97 1519.13,1396.97 1519.15,1396.98 1519.17,1396.98 1519.19,1396.99 1519.21,1396.99 1519.22,1397 1519.24,1397 1519.26,1397 1519.28,1397.01 1519.3,1397.01 1519.32,1397.02 1519.34,1397.02 1519.36,1397.03 1519.38,1397.03 1519.4,1397.04 1519.42,1397.04 1519.44,1397.04 1519.46,1397.05 1519.47,1397.05 1519.49,1397.06 1519.51,1397.06 1519.53,1397.07 1519.55,1397.07 1519.57,1397.07 1519.59,1397.08 1519.61,1397.08 1519.63,1397.09 1519.65,1397.09 1519.67,1397.1 1519.69,1397.1 1519.71,1397.1 1519.73,1397.11 1519.74,1397.11 1519.76,1397.12 1519.78,1397.12 1519.8,1397.13 1519.82,1397.13 1519.84,1397.13 1519.86,1397.14 1519.88,1397.14 1519.9,1397.15 1519.92,1397.15 1519.94,1397.16 1519.96,1397.16 1519.98,1397.17 1520,1397.17 1520.02,1397.17 1520.04,1397.18 1520.06,1397.18 1520.07,1397.19 1520.09,1397.19 1520.11,1397.2 1520.13,1397.2 1520.15,1397.2 1520.17,1397.21 1520.19,1397.21 1520.21,1397.22 1520.23,1397.22 1520.25,1397.23 1520.27,1397.23 1520.29,1397.23 1520.31,1397.24 1520.33,1397.24 1520.35,1397.25 1520.37,1397.25 1520.39,1397.26 1520.41,1397.26 1520.43,1397.26 1520.44,1397.27 1520.46,1397.27 1520.48,1397.28 1520.5,1397.28 1520.52,1397.29 1520.54,1397.29 1520.56,1397.29 1520.58,1397.3 1520.6,1397.3 1520.62,1397.31 1520.64,1397.31 1520.66,1397.31 1520.68,1397.32 1520.7,1397.32 1520.72,1397.33 1520.74,1397.33 1520.76,1397.34 1520.78,1397.34 1520.8,1397.34 1520.82,1397.35 1520.84,1397.35 1520.86,1397.36 1520.88,1397.36 1520.89,1397.37 1520.91,1397.37 1520.93,1397.37 1520.95,1397.38 1520.97,1397.38 1520.99,1397.39 1521.01,1397.39 1521.03,1397.4 1521.05,1397.4 1521.07,1397.4 1521.09,1397.41 1521.11,1397.41 1521.13,1397.42 1521.15,1397.42 1521.17,1397.42 1521.19,1397.43 1521.21,1397.43 1521.23,1397.44 1521.25,1397.44 1521.27,1397.45 1521.29,1397.45 1521.31,1397.45 1521.33,1397.46 1521.35,1397.46 1521.37,1397.47 1521.39,1397.47 1521.41,1397.47 1521.43,1397.48 1521.45,1397.48 1521.47,1397.49 1521.49,1397.49 1521.51,1397.5 1521.53,1397.5 1521.55,1397.5 1521.57,1397.51 1521.59,1397.51 1521.61,1397.52 1521.62,1397.52 1521.64,1397.52 1521.66,1397.53 1521.68,1397.53 1521.7,1397.54 1521.72,1397.54 1521.74,1397.55 1521.76,1397.55 1521.78,1397.55 1521.8,1397.56 1521.82,1397.56 1521.84,1397.57 1521.86,1397.57 1521.88,1397.57 1521.9,1397.58 1521.92,1397.58 1521.94,1397.59 1521.96,1397.59 1521.98,1397.6 1522,1397.6 1522.02,1397.6 1522.04,1397.61 1522.06,1397.61 1522.08,1397.62 1522.1,1397.62 1522.12,1397.62 1522.14,1397.63 1522.16,1397.63 1522.18,1397.64 1522.2,1397.64 1522.22,1397.64 1522.24,1397.65 1522.26,1397.65 1522.28,1397.66 1522.3,1397.66 1522.32,1397.67 1522.34,1397.67 1522.36,1397.67 1522.38,1397.68 1522.4,1397.68 1522.42,1397.69 1522.44,1397.69 1522.46,1397.69 1522.48,1397.7 1522.5,1397.7 1522.52,1397.71 1522.54,1397.71 1522.56,1397.71 1522.58,1397.72 1522.6,1397.72 1522.62,1397.73 1522.64,1397.73 1522.66,1397.73 1522.68,1397.74 1522.7,1397.74 1522.72,1397.75 1522.74,1397.75 1522.76,1397.76 1522.78,1397.76 1522.8,1397.76 1522.82,1397.77 1522.84,1397.77 1522.86,1397.78 1522.88,1397.78 1522.9,1397.78 1522.92,1397.79 1522.94,1397.79 1522.96,1397.8 1522.98,1397.8 1523,1397.8 1523.02,1397.81 1523.04,1397.81 1523.06,1397.82 1523.08,1397.82 1523.1,1397.82 1523.12,1397.83 1523.14,1397.83 1523.16,1397.84 1523.19,1397.84 1523.21,1397.84 1523.23,1397.85 1523.25,1397.85 1523.27,1397.86 1523.29,1397.86 1523.31,1397.86 1523.33,1397.87 1523.35,1397.87 1523.37,1397.88 1523.39,1397.88 1523.41,1397.88 1523.43,1397.89 1523.45,1397.89 1523.47,1397.9 1523.49,1397.9 1523.51,1397.9 1523.53,1397.91 1523.55,1397.91 1523.57,1397.92 1523.59,1397.92 1523.61,1397.92 1523.63,1397.93 1523.65,1397.93 1523.67,1397.94 1523.69,1397.94 1523.71,1397.94 1523.73,1397.95 1523.75,1397.95 1523.77,1397.96 1523.79,1397.96 1523.81,1397.96 1523.83,1397.97 1523.85,1397.97 1523.87,1397.98 1523.89,1397.98 1523.91,1397.98 1523.93,1397.99 1523.96,1397.99 1523.98,1398 1524,1398 1524.02,1398 1524.04,1398.01 1524.06,1398.01 1524.08,1398.02 1524.1,1398.02 1524.12,1398.02 1524.14,1398.03 1524.16,1398.03 1524.18,1398.04 1524.2,1398.04 1524.22,1398.04 1524.24,1398.05 1524.26,1398.05 1524.28,1398.06 1524.3,1398.06 1524.32,1398.06 1524.34,1398.07 1524.36,1398.07 1524.38,1398.07 1524.4,1398.08 1524.42,1398.08 1524.44,1398.09 1524.47,1398.09 1524.49,1398.09 1524.51,1398.1 1524.53,1398.1 1524.55,1398.11 1524.57,1398.11 1524.59,1398.11 1524.61,1398.12 1524.63,1398.12 1524.65,1398.13 1524.67,1398.13 1524.69,1398.13 1524.71,1398.14 1524.73,1398.14 1524.75,1398.15 1524.77,1398.15 1524.79,1398.15 1524.81,1398.16 1524.83,1398.16 1524.85,1398.17 1524.88,1398.17 1524.9,1398.17 1524.92,1398.18 1524.94,1398.18 1524.96,1398.18 1524.98,1398.19 1525,1398.19 1525.02,1398.2 1525.04,1398.2 1525.06,1398.2 1525.08,1398.21 1525.1,1398.21 1525.12,1398.22 1525.14,1398.22 1525.16,1398.22 1525.18,1398.23 1525.2,1398.23 1525.23,1398.23 1525.25,1398.24 1525.27,1398.24 1525.29,1398.25 1525.31,1398.25 1525.33,1398.25 1525.35,1398.26 1525.37,1398.26 1525.39,1398.27 1525.41,1398.27 1525.43,1398.27 1525.45,1398.28 1525.47,1398.28 1525.49,1398.28 1525.51,1398.29 1525.54,1398.29 1525.56,1398.3 1525.58,1398.3 1525.6,1398.3 1525.62,1398.31 1525.64,1398.31 1525.66,1398.32 1525.68,1398.32 1525.7,1398.32 1525.72,1398.33 1525.74,1398.33 1525.76,1398.33 1525.78,1398.34 1525.8,1398.34 1525.83,1398.35 1525.85,1398.35 1525.87,1398.35 1525.89,1398.36 1525.91,1398.36 1525.93,1398.37 1525.95,1398.37 1525.97,1398.37 1525.99,1398.38 1526.01,1398.38 1526.03,1398.38 1526.05,1398.39 1526.07,1398.39 1526.1,1398.4 1526.12,1398.4 1526.14,1398.4 1526.16,1398.41 1526.18,1398.41 1526.2,1398.41 1526.22,1398.42 1526.24,1398.42 1526.26,1398.43 1526.28,1398.43 1526.3,1398.43 1526.32,1398.44 1526.34,1398.44 1526.37,1398.45 1526.39,1398.45 1526.41,1398.45 1526.43,1398.46 1526.45,1398.46 1526.47,1398.46 1526.49,1398.47 1526.51,1398.47 1526.53,1398.48 1526.55,1398.48 1526.57,1398.48 1526.6,1398.49 1526.62,1398.49 1526.64,1398.49 1526.66,1398.5 1526.68,1398.5 1526.7,1398.51 1526.72,1398.51 1526.74,1398.51 1526.76,1398.52 1526.78,1398.52 1526.8,1398.52 1526.83,1398.53 1526.85,1398.53 1526.87,1398.54 1526.89,1398.54 1526.91,1398.54 1526.93,1398.55 1526.95,1398.55 1526.97,1398.55 1526.99,1398.56 1527.01,1398.56 1527.03,1398.57 1527.06,1398.57 1527.08,1398.57 1527.1,1398.58 1527.12,1398.58 1527.14,1398.58 1527.16,1398.59 1527.18,1398.59 1527.2,1398.6 1527.22,1398.6 1527.24,1398.6 1527.27,1398.61 1527.29,1398.61 1527.31,1398.61 1527.33,1398.62 1527.35,1398.62 1527.37,1398.62 1527.39,1398.63 1527.41,1398.63 1527.43,1398.64 1527.46,1398.64 1527.48,1398.64 1527.5,1398.65 1527.52,1398.65 1527.54,1398.65 1527.56,1398.66 1527.58,1398.66 1527.6,1398.67 1527.62,1398.67 1527.64,1398.67 1527.67,1398.68 1527.69,1398.68 1527.71,1398.68 1527.73,1398.69 1527.75,1398.69 1527.77,1398.69 1527.79,1398.7 1527.81,1398.7 1527.83,1398.71 1527.86,1398.71 1527.88,1398.71 1527.9,1398.72 1527.92,1398.72 1527.94,1398.72 1527.96,1398.73 1527.98,1398.73 1528,1398.74 1528.02,1398.74 1528.05,1398.74 1528.07,1398.75 1528.09,1398.75 1528.11,1398.75 1528.13,1398.76 1528.15,1398.76 1528.17,1398.76 1528.19,1398.77 1528.22,1398.77 1528.24,1398.78 1528.26,1398.78 1528.28,1398.78 1528.3,1398.79 1528.32,1398.79 1528.34,1398.79 1528.36,1398.8 1528.39,1398.8 1528.41,1398.8 1528.43,1398.81 1528.45,1398.81 1528.47,1398.82 1528.49,1398.82 1528.51,1398.82 1528.53,1398.83 1528.56,1398.83 1528.58,1398.83 1528.6,1398.84 1528.62,1398.84 1528.64,1398.84 1528.66,1398.85 1528.68,1398.85 1528.7,1398.86 1528.73,1398.86 1528.75,1398.86 1528.77,1398.87 1528.79,1398.87 1528.81,1398.87 1528.83,1398.88 1528.85,1398.88 1528.87,1398.88 1528.9,1398.89 1528.92,1398.89 1528.94,1398.9 1528.96,1398.9 1528.98,1398.9 1529,1398.91 1529.02,1398.91 1529.04,1398.91 1529.07,1398.92 1529.09,1398.92 1529.11,1398.92 1529.13,1398.93 1529.15,1398.93 1529.17,1398.93 1529.19,1398.94 1529.22,1398.94 1529.24,1398.95 1529.26,1398.95 1529.28,1398.95 1529.3,1398.96 1529.32,1398.96 1529.34,1398.96 1529.37,1398.97 1529.39,1398.97 1529.41,1398.97 1529.43,1398.98 1529.45,1398.98 1529.47,1398.98 1529.49,1398.99 1529.52,1398.99 1529.54,1399 1529.56,1399 1529.58,1399 1529.6,1399.01 1529.62,1399.01 1529.64,1399.01 1529.67,1399.02 1529.69,1399.02 1529.71,1399.02 1529.73,1399.03 1529.75,1399.03 1529.77,1399.03 1529.79,1399.04 1529.82,1399.04 1529.84,1399.04 1529.86,1399.05 1529.88,1399.05 1529.9,1399.06 1529.92,1399.06 1529.94,1399.06 1529.97,1399.07 1529.99,1399.07 1530.01,1399.07 1530.03,1399.08 1530.05,1399.08 1530.07,1399.08 1530.09,1399.09 1530.12,1399.09 1530.14,1399.09 1530.16,1399.1 1530.18,1399.1 1530.2,1399.1 1530.22,1399.11 1530.25,1399.11 1530.27,1399.12 1530.29,1399.12 1530.31,1399.12 1530.33,1399.13 1530.35,1399.13 1530.37,1399.13 1530.4,1399.14 1530.42,1399.14 1530.44,1399.14 1530.46,1399.15 1530.48,1399.15 1530.5,1399.15 1530.53,1399.16 1530.55,1399.16 1530.57,1399.16 1530.59,1399.17 1530.61,1399.17 1530.63,1399.17 1530.66,1399.18 1530.68,1399.18 1530.7,1399.19 1530.72,1399.19 1530.74,1399.19 1530.76,1399.2 1530.78,1399.2 1530.81,1399.2 1530.83,1399.21 1530.85,1399.21 1530.87,1399.21 1530.89,1399.22 1530.91,1399.22 1530.94,1399.22 1530.96,1399.23 1530.98,1399.23 1531,1399.23 1531.02,1399.24 1531.04,1399.24 1531.07,1399.24 1531.09,1399.25 1531.11,1399.25 1531.13,1399.25 1531.15,1399.26 1531.17,1399.26 1531.2,1399.26 1531.22,1399.27 1531.24,1399.27 1531.26,1399.28 1531.28,1399.28 1531.3,1399.28 1531.33,1399.29 1531.35,1399.29 1531.37,1399.29 1531.39,1399.3 1531.41,1399.3 1531.43,1399.3 1531.46,1399.31 1531.48,1399.31 1531.5,1399.31 1531.52,1399.32 1531.54,1399.32 1531.57,1399.32 1531.59,1399.33 1531.61,1399.33 1531.63,1399.33 1531.65,1399.34 1531.67,1399.34 1531.7,1399.34 1531.72,1399.35 1531.74,1399.35 1531.76,1399.35 1531.78,1399.36 1531.8,1399.36 1531.83,1399.36 1531.85,1399.37 1531.87,1399.37 1531.89,1399.37 1531.91,1399.38 1531.94,1399.38 1531.96,1399.38 1531.98,1399.39 1532,1399.39 1532.02,1399.39 1532.04,1399.4 1532.07,1399.4 1532.09,1399.4 1532.11,1399.41 1532.13,1399.41 1532.15,1399.41 1532.18,1399.42 1532.2,1399.42 1532.22,1399.43 1532.24,1399.43 1532.26,1399.43 1532.28,1399.44 1532.31,1399.44 1532.33,1399.44 1532.35,1399.45 1532.37,1399.45 1532.39,1399.45 1532.42,1399.46 1532.44,1399.46 1532.46,1399.46 1532.48,1399.47 1532.5,1399.47 1532.53,1399.47 1532.55,1399.48 1532.57,1399.48 1532.59,1399.48 1532.61,1399.49 1532.63,1399.49 1532.66,1399.49 1532.68,1399.5 1532.7,1399.5 1532.72,1399.5 1532.74,1399.51 1532.77,1399.51 1532.79,1399.51 1532.81,1399.52 1532.83,1399.52 1532.85,1399.52 1532.88,1399.53 1532.9,1399.53 1532.92,1399.53 1532.94,1399.54 1532.96,1399.54 1532.99,1399.54 1533.01,1399.55 1533.03,1399.55 1533.05,1399.55 1533.07,1399.56 1533.1,1399.56 1533.12,1399.56 1533.14,1399.57 1533.16,1399.57 1533.18,1399.57 1533.21,1399.58 1533.23,1399.58 1533.25,1399.58 1533.27,1399.59 1533.29,1399.59 1533.32,1399.59 1533.34,1399.6 1533.36,1399.6 1533.38,1399.6 1533.4,1399.61 1533.43,1399.61 1533.45,1399.61 1533.47,1399.62 1533.49,1399.62 1533.51,1399.62 1533.54,1399.63 1533.56,1399.63 1533.58,1399.63 1533.6,1399.64 1533.62,1399.64 1533.65,1399.64 1533.67,1399.65 1533.69,1399.65 1533.71,1399.65 1533.73,1399.66 1533.76,1399.66 1533.78,1399.66 1533.8,1399.67 1533.82,1399.67 1533.84,1399.67 1533.87,1399.67 1533.89,1399.68 1533.91,1399.68 1533.93,1399.68 1533.95,1399.69 1533.98,1399.69 1534,1399.69 1534.02,1399.7 1534.04,1399.7 1534.07,1399.7 1534.09,1399.71 1534.11,1399.71 1534.13,1399.71 1534.15,1399.72 1534.18,1399.72 1534.2,1399.72 1534.22,1399.73 1534.24,1399.73 1534.26,1399.73 1534.29,1399.74 1534.31,1399.74 1534.33,1399.74 1534.35,1399.75 1534.38,1399.75 1534.4,1399.75 1534.42,1399.76 1534.44,1399.76 1534.46,1399.76 1534.49,1399.77 1534.51,1399.77 1534.53,1399.77 1534.55,1399.78 1534.57,1399.78 1534.6,1399.78 1534.62,1399.79 1534.64,1399.79 1534.66,1399.79 1534.69,1399.8 1534.71,1399.8 1534.73,1399.8 1534.75,1399.8 1534.77,1399.81 1534.8,1399.81 1534.82,1399.81 1534.84,1399.82 1534.86,1399.82 1534.89,1399.82 1534.91,1399.83 1534.93,1399.83 1534.95,1399.83 1534.97,1399.84 1535,1399.84 1535.02,1399.84 1535.04,1399.85 1535.06,1399.85 1535.09,1399.85 1535.11,1399.86 1535.13,1399.86 1535.15,1399.86 1535.17,1399.87 1535.2,1399.87 1535.22,1399.87 1535.24,1399.88 1535.26,1399.88 1535.29,1399.88 1535.31,1399.89 1535.33,1399.89 1535.35,1399.89 1535.37,1399.89 1535.4,1399.9 1535.42,1399.9 1535.44,1399.9 1535.46,1399.91 1535.49,1399.91 1535.51,1399.91 1535.53,1399.92 1535.55,1399.92 1535.58,1399.92 1535.6,1399.93 1535.62,1399.93 1535.64,1399.93 1535.66,1399.94 1535.69,1399.94 1535.71,1399.94 1535.73,1399.95 1535.75,1399.95 1535.78,1399.95 1535.8,1399.96 1535.82,1399.96 1535.84,1399.96 1535.87,1399.96 1535.89,1399.97 1535.91,1399.97 1535.93,1399.97 1535.96,1399.98 1535.98,1399.98 1536,1399.98 1536.02,1399.99 1536.04,1399.99 1536.07,1399.99 1536.09,1400 1536.11,1400 1536.13,1400 1536.16,1400.01 1536.18,1400.01 1536.2,1400.01 1536.22,1400.02 1536.25,1400.02 1536.27,1400.02 1536.29,1400.02 1536.31,1400.03 1536.34,1400.03 1536.36,1400.03 1536.38,1400.04 1536.4,1400.04 1536.43,1400.04 1536.45,1400.05 1536.47,1400.05 1536.49,1400.05 1536.51,1400.06 1536.54,1400.06 1536.56,1400.06 1536.58,1400.07 1536.6,1400.07 1536.63,1400.07 1536.65,1400.07 1536.67,1400.08 1536.69,1400.08 1536.72,1400.08 1536.74,1400.09 1536.76,1400.09 1536.78,1400.09 1536.81,1400.1 1536.83,1400.1 1536.85,1400.1 1536.87,1400.11 1536.9,1400.11 1536.92,1400.11 1536.94,1400.12 1536.96,1400.12 1536.99,1400.12 1537.01,1400.12 1537.03,1400.13 1537.05,1400.13 1537.08,1400.13 1537.1,1400.14 1537.12,1400.14 1537.14,1400.14 1537.17,1400.15 1537.19,1400.15 1537.21,1400.15 1537.23,1400.16 1537.26,1400.16 1537.28,1400.16 1537.3,1400.16 1537.32,1400.17 1537.35,1400.17 1537.37,1400.17 1537.39,1400.18 1537.41,1400.18 1537.44,1400.18 1537.46,1400.19 1537.48,1400.19 1537.5,1400.19 1537.53,1400.2 1537.55,1400.2 1537.57,1400.2 1537.59,1400.2 1537.62,1400.21 1537.64,1400.21 1537.66,1400.21 1537.68,1400.22 1537.71,1400.22 1537.73,1400.22 1537.75,1400.23 1537.78,1400.23 1537.8,1400.23 1537.82,1400.24 1537.84,1400.24 1537.87,1400.24 1537.89,1400.24 1537.91,1400.25 1537.93,1400.25 1537.96,1400.25 1537.98,1400.26 1538,1400.26 1538.02,1400.26 1538.05,1400.27 1538.07,1400.27 1538.09,1400.27 1538.11,1400.27 1538.14,1400.28 1538.16,1400.28 1538.18,1400.28 1538.2,1400.29 1538.23,1400.29 1538.25,1400.29 1538.27,1400.3 1538.3,1400.3 1538.32,1400.3 1538.34,1400.3 1538.36,1400.31 1538.39,1400.31 1538.41,1400.31 1538.43,1400.32 1538.45,1400.32 1538.48,1400.32 1538.5,1400.33 1538.52,1400.33 1538.54,1400.33 1538.57,1400.34 1538.59,1400.34 1538.61,1400.34 1538.63,1400.34 1538.66,1400.35 1538.68,1400.35 1538.7,1400.35 1538.73,1400.36 1538.75,1400.36 1538.77,1400.36 1538.79,1400.37 1538.82,1400.37 1538.84,1400.37 1538.86,1400.37 1538.88,1400.38 1538.91,1400.38 1538.93,1400.38 1538.95,1400.39 1538.98,1400.39 1539,1400.39 1539.02,1400.4 1539.04,1400.4 1539.07,1400.4 1539.09,1400.4 1539.11,1400.41 1539.13,1400.41 1539.16,1400.41 1539.18,1400.42 1539.2,1400.42 1539.23,1400.42 1539.25,1400.43 1539.27,1400.43 1539.29,1400.43 1539.32,1400.43 1539.34,1400.44 1539.36,1400.44 1539.38,1400.44 1539.41,1400.45 1539.43,1400.45 1539.45,1400.45 1539.48,1400.45 1539.5,1400.46 1539.52,1400.46 1539.54,1400.46 1539.57,1400.47 1539.59,1400.47 1539.61,1400.47 1539.64,1400.48 1539.66,1400.48 1539.68,1400.48 1539.7,1400.48 1539.73,1400.49 1539.75,1400.49 1539.77,1400.49 1539.79,1400.5 1539.82,1400.5 1539.84,1400.5 1539.86,1400.5 1539.89,1400.51 1539.91,1400.51 1539.93,1400.51 1539.95,1400.52 1539.98,1400.52 1540,1400.52 1540.02,1400.53 1540.05,1400.53 1540.07,1400.53 1540.09,1400.53 1540.11,1400.54 1540.14,1400.54 1540.16,1400.54 1540.18,1400.55 1540.21,1400.55 1540.23,1400.55 1540.25,1400.55 1540.27,1400.56 1540.3,1400.56 1540.32,1400.56 1540.34,1400.57 1540.37,1400.57 1540.39,1400.57 1540.41,1400.58 1540.43,1400.58 1540.46,1400.58 1540.48,1400.58 1540.5,1400.59 1540.53,1400.59 1540.55,1400.59 1540.57,1400.6 1540.59,1400.6 1540.62,1400.6 1540.64,1400.6 1540.66,1400.61 1540.69,1400.61 1540.71,1400.61 1540.73,1400.62 1540.75,1400.62 1540.78,1400.62 1540.8,1400.62 1540.82,1400.63 1540.85,1400.63 1540.87,1400.63 1540.89,1400.64 1540.91,1400.64 1540.94,1400.64 1540.96,1400.64 1540.98,1400.65 1541.01,1400.65 1541.03,1400.65 1541.05,1400.66 1541.08,1400.66 1541.1,1400.66 1541.12,1400.67 1541.14,1400.67 1541.17,1400.67 1541.19,1400.67 1541.21,1400.68 1541.24,1400.68 1541.26,1400.68 1541.28,1400.69 1541.3,1400.69 1541.33,1400.69 1541.35,1400.69 1541.37,1400.7 1541.4,1400.7 1541.42,1400.7 1541.44,1400.71 1541.47,1400.71 1541.49,1400.71 1541.51,1400.71 1541.53,1400.72 1541.56,1400.72 1541.58,1400.72 1541.6,1400.73 1541.63,1400.73 1541.65,1400.73 1541.67,1400.73 1541.7,1400.74 1541.72,1400.74 1541.74,1400.74 1541.76,1400.75 1541.79,1400.75 1541.81,1400.75 1541.83,1400.75 1541.86,1400.76 1541.88,1400.76 1541.9,1400.76 1541.93,1400.77 1541.95,1400.77 1541.97,1400.77 1541.99,1400.77 1542.02,1400.78 1542.04,1400.78 1542.06,1400.78 1542.09,1400.79 1542.11,1400.79 1542.13,1400.79 1542.16,1400.79 1542.18,1400.8 1542.2,1400.8 1542.22,1400.8 1542.25,1400.8 1542.27,1400.81 1542.29,1400.81 1542.32,1400.81 1542.34,1400.82 1542.36,1400.82 1542.39,1400.82 1542.41,1400.82 1542.43,1400.83 1542.46,1400.83 1542.48,1400.83 1542.5,1400.84 1542.52,1400.84 1542.55,1400.84 1542.57,1400.84 1542.59,1400.85 1542.62,1400.85 1542.64,1400.85 1542.66,1400.86 1542.69,1400.86 1542.71,1400.86 1542.73,1400.86 1542.76,1400.87 1542.78,1400.87 1542.8,1400.87 1542.82,1400.88 1542.85,1400.88 1542.87,1400.88 1542.89,1400.88 1542.92,1400.89 1542.94,1400.89 1542.96,1400.89 1542.99,1400.89 1543.01,1400.9 1543.03,1400.9 1543.06,1400.9 1543.08,1400.91 1543.1,1400.91 1543.13,1400.91 1543.15,1400.91 1543.17,1400.92 1543.19,1400.92 1543.22,1400.92 1543.24,1400.93 1543.26,1400.93 1543.29,1400.93 1543.31,1400.93 1543.33,1400.94 1543.36,1400.94 1543.38,1400.94 1543.4,1400.94 1543.43,1400.95 1543.45,1400.95 1543.47,1400.95 1543.5,1400.96 1543.52,1400.96 1543.54,1400.96 1543.57,1400.96 1543.59,1400.97 1543.61,1400.97 1543.63,1400.97 1543.66,1400.98 1543.68,1400.98 1543.7,1400.98 1543.73,1400.98 1543.75,1400.99 1543.77,1400.99 1543.8,1400.99 1543.82,1400.99 1543.84,1401 1543.87,1401 1543.89,1401 1543.91,1401.01 1543.94,1401.01 1543.96,1401.01 1543.98,1401.01 1544.01,1401.02 1544.03,1401.02 1544.05,1401.02 1544.08,1401.02 1544.1,1401.03 1544.12,1401.03 1544.14,1401.03 1544.17,1401.04 1544.19,1401.04 1544.21,1401.04 1544.24,1401.04 1544.26,1401.05 1544.28,1401.05 1544.31,1401.05 1544.33,1401.05 1544.35,1401.06 1544.38,1401.06 1544.4,1401.06 1544.42,1401.07 1544.45,1401.07 1544.47,1401.07 1544.49,1401.07 1544.52,1401.08 1544.54,1401.08 1544.56,1401.08 1544.59,1401.08 1544.61,1401.09 1544.63,1401.09 1544.66,1401.09 1544.68,1401.1 1544.7,1401.1 1544.73,1401.1 1544.75,1401.1 1544.77,1401.11 1544.8,1401.11 1544.82,1401.11 1544.84,1401.11 1544.87,1401.12 1544.89,1401.12 1544.91,1401.12 1544.94,1401.12 1544.96,1401.13 1544.98,1401.13 1545.01,1401.13 1545.03,1401.14 1545.05,1401.14 1545.08,1401.14 1545.1,1401.14 1545.12,1401.15 1545.15,1401.15 1545.17,1401.15 1545.19,1401.15 1545.22,1401.16 1545.24,1401.16 1545.26,1401.16 1545.29,1401.17 1545.31,1401.17 1545.33,1401.17 1545.36,1401.17 1545.38,1401.18 1545.4,1401.18 1545.43,1401.18 1545.45,1401.18 1545.47,1401.19 1545.5,1401.19 1545.52,1401.19 1545.54,1401.19 1545.57,1401.2 1545.59,1401.2 1545.61,1401.2 1545.64,1401.21 1545.66,1401.21 1545.68,1401.21 1545.71,1401.21 1545.73,1401.22 1545.75,1401.22 1545.78,1401.22 1545.8,1401.22 1545.82,1401.23 1545.85,1401.23 1545.87,1401.23 1545.89,1401.23 1545.92,1401.24 1545.94,1401.24 1545.96,1401.24 1545.99,1401.25 1546.01,1401.25 1546.03,1401.25 1546.06,1401.25 1546.08,1401.26 1546.1,1401.26 1546.13,1401.26 1546.15,1401.26 1546.17,1401.27 1546.2,1401.27 1546.22,1401.27 1546.24,1401.27 1546.27,1401.28 1546.29,1401.28 1546.31,1401.28 1546.34,1401.28 1546.36,1401.29 1546.38,1401.29 1546.41,1401.29 1546.43,1401.3 1546.45,1401.3 1546.48,1401.3 1546.5,1401.3 1546.52,1401.31 1546.55,1401.31 1546.57,1401.31 1546.59,1401.31 1546.62,1401.32 1546.64,1401.32 1546.66,1401.32 1546.69,1401.32 1546.71,1401.33 1546.73,1401.33 1546.76,1401.33 1546.78,1401.33 1546.8,1401.34 1546.83,1401.34 1546.85,1401.34 1546.88,1401.34 1546.9,1401.35 1546.92,1401.35 1546.95,1401.35 1546.97,1401.36 1546.99,1401.36 1547.02,1401.36 1547.04,1401.36 1547.06,1401.37 1547.09,1401.37 1547.11,1401.37 1547.13,1401.37 1547.16,1401.38 1547.18,1401.38 1547.2,1401.38 1547.23,1401.38 1547.25,1401.39 1547.27,1401.39 1547.3,1401.39 1547.32,1401.39 1547.34,1401.4 1547.37,1401.4 1547.39,1401.4 1547.41,1401.4 1547.44,1401.41 1547.46,1401.41 1547.49,1401.41 1547.51,1401.41 1547.53,1401.42 1547.56,1401.42 1547.58,1401.42 1547.6,1401.43 1547.63,1401.43 1547.65,1401.43 1547.67,1401.43 1547.7,1401.44 1547.72,1401.44 1547.74,1401.44 1547.77,1401.44 1547.79,1401.45 1547.81,1401.45 1547.84,1401.45 1547.86,1401.45 1547.88,1401.46 1547.91,1401.46 1547.93,1401.46 1547.96,1401.46 1547.98,1401.47 1548,1401.47 1548.03,1401.47 1548.05,1401.47 1548.07,1401.48 1548.1,1401.48 1548.12,1401.48 1548.14,1401.48 1548.17,1401.49 1548.19,1401.49 1548.21,1401.49 1548.24,1401.49 1548.26,1401.5 1548.28,1401.5 1548.31,1401.5 1548.33,1401.5 1548.36,1401.51 1548.38,1401.51 1548.4,1401.51 1548.43,1401.51 1548.45,1401.52 1548.47,1401.52 1548.5,1401.52 1548.52,1401.52 1548.54,1401.53 1548.57,1401.53 1548.59,1401.53 1548.61,1401.53 1548.64,1401.54 1548.66,1401.54 1548.69,1401.54 1548.71,1401.55 1548.73,1401.55 1548.76,1401.55 1548.78,1401.55 1548.8,1401.56 1548.83,1401.56 1548.85,1401.56 1548.87,1401.56 1548.9,1401.57 1548.92,1401.57 1548.94,1401.57 1548.97,1401.57 1548.99,1401.58 1549.02,1401.58 1549.04,1401.58 1549.06,1401.58 1549.09,1401.59 1549.11,1401.59 1549.13,1401.59 1549.16,1401.59 1549.18,1401.6 1549.2,1401.6 1549.23,1401.6 1549.25,1401.6 1549.28,1401.61 1549.3,1401.61 1549.32,1401.61 1549.35,1401.61 1549.37,1401.62 1549.39,1401.62 1549.42,1401.62 1549.44,1401.62 1549.46,1401.63 1549.49,1401.63 1549.51,1401.63 1549.53,1401.63 1549.56,1401.64 1549.58,1401.64 1549.61,1401.64 1549.63,1401.64 1549.65,1401.65 1549.68,1401.65 1549.7,1401.65 1549.72,1401.65 1549.75,1401.66 1549.77,1401.66 1549.79,1401.66 1549.82,1401.66 1549.84,1401.67 1549.87,1401.67 1549.89,1401.67 1549.91,1401.67 1549.94,1401.68 1549.96,1401.68 1549.98,1401.68 1550.01,1401.68 1550.03,1401.68 1550.06,1401.69 1550.08,1401.69 1550.1,1401.69 1550.13,1401.69 1550.15,1401.7 1550.17,1401.7 1550.2,1401.7 1550.22,1401.7 1550.24,1401.71 1550.27,1401.71 1550.29,1401.71 1550.32,1401.71 1550.34,1401.72 1550.36,1401.72 1550.39,1401.72 1550.41,1401.72 1550.43,1401.73 1550.46,1401.73 1550.48,1401.73 1550.51,1401.73 1550.53,1401.74 1550.55,1401.74 1550.58,1401.74 1550.6,1401.74 1550.62,1401.75 1550.65,1401.75 1550.67,1401.75 1550.69,1401.75 1550.72,1401.76 1550.74,1401.76 1550.77,1401.76 1550.79,1401.76 1550.81,1401.77 1550.84,1401.77 1550.86,1401.77 1550.88,1401.77 1550.91,1401.78 1550.93,1401.78 1550.96,1401.78 1550.98,1401.78 1551,1401.79 1551.03,1401.79 1551.05,1401.79 1551.07,1401.79 1551.1,1401.8 1551.12,1401.8 1551.15,1401.8 1551.17,1401.8 1551.19,1401.8 1551.22,1401.81 1551.24,1401.81 1551.26,1401.81 1551.29,1401.81 1551.31,1401.82 1551.34,1401.82 1551.36,1401.82 1551.38,1401.82 1551.41,1401.83 1551.43,1401.83 1551.45,1401.83 1551.48,1401.83 1551.5,1401.84 1551.53,1401.84 1551.55,1401.84 1551.57,1401.84 1551.6,1401.85 1551.62,1401.85 1551.64,1401.85 1551.67,1401.85 1551.69,1401.86 1551.72,1401.86 1551.74,1401.86 1551.76,1401.86 1551.79,1401.87 1551.81,1401.87 1551.83,1401.87 1551.86,1401.87 1551.88,1401.87 1551.91,1401.88 1551.93,1401.88 1551.95,1401.88 1551.98,1401.88 1552,1401.89 1552.02,1401.89 1552.05,1401.89 1552.07,1401.89 1552.1,1401.9 1552.12,1401.9 1552.14,1401.9 1552.17,1401.9 1552.19,1401.91 1552.21,1401.91 1552.24,1401.91 1552.26,1401.91 1552.29,1401.92 1552.31,1401.92 1552.33,1401.92 1552.36,1401.92 1552.38,1401.92 1552.41,1401.93 1552.43,1401.93 1552.45,1401.93 1552.48,1401.93 1552.5,1401.94 1552.52,1401.94 1552.55,1401.94 1552.57,1401.94 1552.6,1401.95 1552.62,1401.95 1552.64,1401.95 1552.67,1401.95 1552.69,1401.96 1552.71,1401.96 1552.74,1401.96 1552.76,1401.96 1552.79,1401.96 1552.81,1401.97 1552.83,1401.97 1552.86,1401.97 1552.88,1401.97 1552.91,1401.98 1552.93,1401.98 1552.95,1401.98 1552.98,1401.98 1553,1401.99 1553.02,1401.99 1553.05,1401.99 1553.07,1401.99 1553.1,1402 1553.12,1402 1553.14,1402 1553.17,1402 1553.19,1402 1553.22,1402.01 1553.24,1402.01 1553.26,1402.01 1553.29,1402.01 1553.31,1402.02 1553.33,1402.02 1553.36,1402.02 1553.38,1402.02 1553.41,1402.03 1553.43,1402.03 1553.45,1402.03 1553.48,1402.03 1553.5,1402.04 1553.53,1402.04 1553.55,1402.04 1553.57,1402.04 1553.6,1402.04 1553.62,1402.05 1553.64,1402.05 1553.67,1402.05 1553.69,1402.05 1553.72,1402.06 1553.74,1402.06 1553.76,1402.06 1553.79,1402.06 1553.81,1402.07 1553.84,1402.07 1553.86,1402.07 1553.88,1402.07 1553.91,1402.07 1553.93,1402.08 1553.96,1402.08 1553.98,1402.08 1554,1402.08 1554.03,1402.09 1554.05,1402.09 1554.07,1402.09 1554.1,1402.09 1554.12,1402.1 1554.15,1402.1 1554.17,1402.1 1554.19,1402.1 1554.22,1402.1 1554.24,1402.11 1554.27,1402.11 1554.29,1402.11 1554.31,1402.11 1554.34,1402.12 1554.36,1402.12 1554.39,1402.12 1554.41,1402.12 1554.43,1402.13 1554.46,1402.13 1554.48,1402.13 1554.51,1402.13 1554.53,1402.13 1554.55,1402.14 1554.58,1402.14 1554.6,1402.14 1554.62,1402.14 1554.65,1402.15 1554.67,1402.15 1554.7,1402.15 1554.72,1402.15 1554.74,1402.16 1554.77,1402.16 1554.79,1402.16 1554.82,1402.16 1554.84,1402.16 1554.86,1402.17 1554.89,1402.17 1554.91,1402.17 1554.94,1402.17 1554.96,1402.18 1554.98,1402.18 1555.01,1402.18 1555.03,1402.18 1555.06,1402.18 1555.08,1402.19 1555.1,1402.19 1555.13,1402.19 1555.15,1402.19 1555.18,1402.2 1555.2,1402.2 1555.22,1402.2 1555.25,1402.2 1555.27,1402.2 1555.29,1402.21 1555.32,1402.21 1555.34,1402.21 1555.37,1402.21 1555.39,1402.22 1555.41,1402.22 1555.44,1402.22 1555.46,1402.22 1555.49,1402.23 1555.51,1402.23 1555.53,1402.23 1555.56,1402.23 1555.58,1402.23 1555.61,1402.24 1555.63,1402.24 1555.65,1402.24 1555.68,1402.24 1555.7,1402.25 1555.73,1402.25 1555.75,1402.25 1555.77,1402.25 1555.8,1402.25 1555.82,1402.26 1555.85,1402.26 1555.87,1402.26 1555.89,1402.26 1555.92,1402.27 1555.94,1402.27 1555.97,1402.27 1555.99,1402.27 1556.01,1402.27 1556.04,1402.28 1556.06,1402.28 1556.09,1402.28 1556.11,1402.28 1556.13,1402.29 1556.16,1402.29 1556.18,1402.29 1556.21,1402.29 1556.23,1402.29 1556.25,1402.3 1556.28,1402.3 1556.3,1402.3 1556.33,1402.3 1556.35,1402.31 1556.37,1402.31 1556.4,1402.31 1556.42,1402.31 1556.45,1402.31 1556.47,1402.32 1556.49,1402.32 1556.52,1402.32 1556.54,1402.32 1556.57,1402.33 1556.59,1402.33 1556.61,1402.33 1556.64,1402.33 1556.66,1402.33 1556.69,1402.34 1556.71,1402.34 1556.73,1402.34 1556.76,1402.34 1556.78,1402.35 1556.81,1402.35 1556.83,1402.35 1556.85,1402.35 1556.88,1402.35 1556.9,1402.36 1556.93,1402.36 1556.95,1402.36 1556.97,1402.36 1557,1402.37 1557.02,1402.37 1557.05,1402.37 1557.07,1402.37 1557.09,1402.37 1557.12,1402.38 1557.14,1402.38 1557.17,1402.38 1557.19,1402.38 1557.22,1402.39 1557.24,1402.39 1557.26,1402.39 1557.29,1402.39 1557.31,1402.39 1557.34,1402.4 1557.36,1402.4 1557.38,1402.4 1557.41,1402.4 1557.43,1402.4 1557.46,1402.41 1557.48,1402.41 1557.5,1402.41 1557.53,1402.41 1557.55,1402.42 1557.58,1402.42 1557.6,1402.42 1557.62,1402.42 1557.65,1402.42 1557.67,1402.43 1557.7,1402.43 1557.72,1402.43 1557.74,1402.43 1557.77,1402.44 1557.79,1402.44 1557.82,1402.44 1557.84,1402.44 1557.86,1402.44 1557.89,1402.45 1557.91,1402.45 1557.94,1402.45 1557.96,1402.45 1557.98,1402.45 1558.01,1402.46 1558.03,1402.46 1558.06,1402.46 1558.08,1402.46 1558.11,1402.47 1558.13,1402.47 1558.15,1402.47 1558.18,1402.47 1558.2,1402.47 1558.23,1402.48 1558.25,1402.48 1558.27,1402.48 1558.3,1402.48 1558.32,1402.48 1558.35,1402.49 1558.37,1402.49 1558.39,1402.49 1558.42,1402.49 1558.44,1402.5 1558.47,1402.5 1558.49,1402.5 1558.51,1402.5 1558.54,1402.5 1558.56,1402.51 1558.59,1402.51 1558.61,1402.51 1558.64,1402.51 1558.66,1402.51 1558.68,1402.52 1558.71,1402.52 1558.73,1402.52 1558.76,1402.52 1558.78,1402.53 1558.8,1402.53 1558.83,1402.53 1558.85,1402.53 1558.88,1402.53 1558.9,1402.54 1558.92,1402.54 1558.95,1402.54 1558.97,1402.54 1559,1402.54 1559.02,1402.55 1559.05,1402.55 1559.07,1402.55 1559.09,1402.55 1559.12,1402.56 1559.14,1402.56 1559.17,1402.56 1559.19,1402.56 1559.21,1402.56 1559.24,1402.57 1559.26,1402.57 1559.29,1402.57 1559.31,1402.57 1559.33,1402.57 1559.36,1402.58 1559.38,1402.58 1559.41,1402.58 1559.43,1402.58 1559.46,1402.58 1559.48,1402.59 1559.5,1402.59 1559.53,1402.59 1559.55,1402.59 1559.58,1402.6 1559.6,1402.6 1559.62,1402.6 1559.65,1402.6 1559.67,1402.6 1559.7,1402.61 1559.72,1402.61 1559.74,1402.61 1559.77,1402.61 1559.79,1402.61 1559.82,1402.62 1559.84,1402.62 1559.87,1402.62 1559.89,1402.62 1559.91,1402.62 1559.94,1402.63 1559.96,1402.63 1559.99,1402.63 1560.01,1402.63 1560.03,1402.64 1560.06,1402.64 1560.08,1402.64 1560.11,1402.64 1560.13,1402.64 1560.16,1402.65 1560.18,1402.65 1560.2,1402.65 1560.23,1402.65 1560.25,1402.65 1560.28,1402.66 1560.3,1402.66 1560.32,1402.66 1560.35,1402.66 1560.37,1402.66 1560.4,1402.67 1560.42,1402.67 1560.45,1402.67 1560.47,1402.67 1560.49,1402.67 1560.52,1402.68 1560.54,1402.68 1560.57,1402.68 1560.59,1402.68 1560.61,1402.68 1560.64,1402.69 1560.66,1402.69 1560.69,1402.69 1560.71,1402.69 1560.74,1402.7 1560.76,1402.7 1560.78,1402.7 1560.81,1402.7 1560.83,1402.7 1560.86,1402.71 1560.88,1402.71 1560.9,1402.71 1560.93,1402.71 1560.95,1402.71 1560.98,1402.72 1561,1402.72 1561.03,1402.72 1561.05,1402.72 1561.07,1402.72 1561.1,1402.73 1561.12,1402.73 1561.15,1402.73 1561.17,1402.73 1561.19,1402.73 1561.22,1402.74 1561.24,1402.74 1561.27,1402.74 1561.29,1402.74 1561.32,1402.74 1561.34,1402.75 1561.36,1402.75 1561.39,1402.75 1561.41,1402.75 1561.44,1402.75 1561.46,1402.76 1561.48,1402.76 1561.51,1402.76 1561.53,1402.76 1561.56,1402.76 1561.58,1402.77 1561.61,1402.77 1561.63,1402.77 1561.65,1402.77 1561.68,1402.78 1561.7,1402.78 1561.73,1402.78 1561.75,1402.78 1561.78,1402.78 1561.8,1402.79 1561.82,1402.79 1561.85,1402.79 1561.87,1402.79 1561.9,1402.79 1561.92,1402.8 1561.94,1402.8 1561.97,1402.8 1561.99,1402.8 1562.02,1402.8 1562.04,1402.81 1562.07,1402.81 1562.09,1402.81 1562.11,1402.81 1562.14,1402.81 1562.16,1402.82 1562.19,1402.82 1562.21,1402.82 1562.24,1402.82 1562.26,1402.82 1562.28,1402.83 1562.31,1402.83 1562.33,1402.83 1562.36,1402.83 1562.38,1402.83 1562.4,1402.84 1562.43,1402.84 1562.45,1402.84 1562.48,1402.84 1562.5,1402.84 1562.53,1402.85 1562.55,1402.85 1562.57,1402.85 1562.6,1402.85 1562.62,1402.85 1562.65,1402.86 1562.67,1402.86 1562.7,1402.86 1562.72,1402.86 1562.74,1402.86 1562.77,1402.87 1562.79,1402.87 1562.82,1402.87 1562.84,1402.87 1562.87,1402.87 1562.89,1402.88 1562.91,1402.88 1562.94,1402.88 1562.96,1402.88 1562.99,1402.88 1563.01,1402.89 1563.04,1402.89 1563.06,1402.89 1563.08,1402.89 1563.11,1402.89 1563.13,1402.9 1563.16,1402.9 1563.18,1402.9 1563.2,1402.9 1563.23,1402.9 1563.25,1402.91 1563.28,1402.91 1563.3,1402.91 1563.33,1402.91 1563.35,1402.91 1563.37,1402.92 1563.4,1402.92 1563.42,1402.92 1563.45,1402.92 1563.47,1402.92 1563.5,1402.93 1563.52,1402.93 1563.54,1402.93 1563.57,1402.93 1563.59,1402.93 1563.62,1402.93 1563.64,1402.94 1563.67,1402.94 1563.69,1402.94 1563.71,1402.94 1563.74,1402.94 1563.76,1402.95 1563.79,1402.95 1563.81,1402.95 1563.84,1402.95 1563.86,1402.95 1563.88,1402.96 1563.91,1402.96 1563.93,1402.96 1563.96,1402.96 1563.98,1402.96 1564.01,1402.97 1564.03,1402.97 1564.05,1402.97 1564.08,1402.97 1564.1,1402.97 1564.13,1402.98 1564.15,1402.98 1564.18,1402.98 1564.2,1402.98 1564.22,1402.98 1564.25,1402.99 1564.27,1402.99 1564.3,1402.99 1564.32,1402.99 1564.34,1402.99 1564.37,1403 1564.39,1403 1564.42,1403 1564.44,1403 1564.47,1403 1564.49,1403.01 1564.51,1403.01 1564.54,1403.01 1564.56,1403.01 1564.59,1403.01 1564.61,1403.01 1564.64,1403.02 1564.66,1403.02 1564.68,1403.02 1564.71,1403.02 1564.73,1403.02 1564.76,1403.03 1564.78,1403.03 1564.81,1403.03 1564.83,1403.03 1564.85,1403.03 1564.88,1403.04 1564.9,1403.04 1564.93,1403.04 1564.95,1403.04 1564.98,1403.04 1565,1403.05 1565.02,1403.05 1565.05,1403.05 1565.07,1403.05 1565.1,1403.05 1565.12,1403.06 1565.15,1403.06 1565.17,1403.06 1565.19,1403.06 1565.22,1403.06 1565.24,1403.06 1565.27,1403.07 1565.29,1403.07 1565.32,1403.07 1565.34,1403.07 1565.37,1403.07 1565.39,1403.08 1565.41,1403.08 1565.44,1403.08 1565.46,1403.08 1565.49,1403.08 1565.51,1403.09 1565.54,1403.09 1565.56,1403.09 1565.58,1403.09 1565.61,1403.09 1565.63,1403.1 1565.66,1403.1 1565.68,1403.1 1565.71,1403.1 1565.73,1403.1 1565.75,1403.1 1565.78,1403.11 1565.8,1403.11 1565.83,1403.11 1565.85,1403.11 1565.88,1403.11 1565.9,1403.12 1565.92,1403.12 1565.95,1403.12 1565.97,1403.12 1566,1403.12 1566.02,1403.13 1566.05,1403.13 1566.07,1403.13 1566.09,1403.13 1566.12,1403.13 1566.14,1403.13 1566.17,1403.14 1566.19,1403.14 1566.22,1403.14 1566.24,1403.14 1566.26,1403.14 1566.29,1403.15 1566.31,1403.15 1566.34,1403.15 1566.36,1403.15 1566.39,1403.15 1566.41,1403.16 1566.43,1403.16 1566.46,1403.16 1566.48,1403.16 1566.51,1403.16 1566.53,1403.16 1566.56,1403.17 1566.58,1403.17 1566.6,1403.17 1566.63,1403.17 1566.65,1403.17 1566.68,1403.18 1566.7,1403.18 1566.73,1403.18 1566.75,1403.18 1566.78,1403.18 1566.8,1403.19 1566.82,1403.19 1566.85,1403.19 1566.87,1403.19 1566.9,1403.19 1566.92,1403.19 1566.95,1403.2 1566.97,1403.2 1566.99,1403.2 1567.02,1403.2 1567.04,1403.2 1567.07,1403.21 1567.09,1403.21 1567.12,1403.21 1567.14,1403.21 1567.16,1403.21 1567.19,1403.22 1567.21,1403.22 1567.24,1403.22 1567.26,1403.22 1567.29,1403.22 1567.31,1403.22 1567.33,1403.23 1567.36,1403.23 1567.38,1403.23 1567.41,1403.23 1567.43,1403.23 1567.46,1403.24 1567.48,1403.24 1567.51,1403.24 1567.53,1403.24 1567.55,1403.24 1567.58,1403.24 1567.6,1403.25 1567.63,1403.25 1567.65,1403.25 1567.68,1403.25 1567.7,1403.25 1567.72,1403.26 1567.75,1403.26 1567.77,1403.26 1567.8,1403.26 1567.82,1403.26 1567.85,1403.26 1567.87,1403.27 1567.89,1403.27 1567.92,1403.27 1567.94,1403.27 1567.97,1403.27 1567.99,1403.28 1568.02,1403.28 1568.04,1403.28 1568.06,1403.28 1568.09,1403.28 1568.11,1403.29 1568.14,1403.29 1568.16,1403.29 1568.19,1403.29 1568.21,1403.29 1568.24,1403.29 1568.26,1403.3 1568.28,1403.3 1568.31,1403.3 1568.33,1403.3 1568.36,1403.3 1568.38,1403.31 1568.41,1403.31 1568.43,1403.31 1568.45,1403.31 1568.48,1403.31 1568.5,1403.31 1568.53,1403.32 1568.55,1403.32 1568.58,1403.32 1568.6,1403.32 1568.63,1403.32 1568.65,1403.32 1568.67,1403.33 1568.7,1403.33 1568.72,1403.33 1568.75,1403.33 1568.77,1403.33 1568.8,1403.34 1568.82,1403.34 1568.84,1403.34 1568.87,1403.34 1568.89,1403.34 1568.92,1403.34 1568.94,1403.35 1568.97,1403.35 1568.99,1403.35 1569.01,1403.35 1569.04,1403.35 1569.06,1403.36 1569.09,1403.36 1569.11,1403.36 1569.14,1403.36 1569.16,1403.36 1569.19,1403.36 1569.21,1403.37 1569.23,1403.37 1569.26,1403.37 1569.28,1403.37 1569.31,1403.37 1569.33,1403.38 1569.36,1403.38 1569.38,1403.38 1569.4,1403.38 1569.43,1403.38 1569.45,1403.38 1569.48,1403.39 1569.5,1403.39 1569.53,1403.39 1569.55,1403.39 1569.58,1403.39 1569.6,1403.39 1569.62,1403.4 1569.65,1403.4 1569.67,1403.4 1569.7,1403.4 1569.72,1403.4 1569.75,1403.41 1569.77,1403.41 1569.79,1403.41 1569.82,1403.41 1569.84,1403.41 1569.87,1403.41 1569.89,1403.42 1569.92,1403.42 1569.94,1403.42 1569.97,1403.42 1569.99,1403.42 1570.01,1403.42 1570.04,1403.43 1570.06,1403.43 1570.09,1403.43 1570.11,1403.43 1570.14,1403.43 1570.16,1403.44 1570.18,1403.44 1570.21,1403.44 1570.23,1403.44 1570.26,1403.44 1570.28,1403.44 1570.31,1403.45 1570.33,1403.45 1570.36,1403.45 1570.38,1403.45 1570.4,1403.45 1570.43,1403.45 1570.45,1403.46 1570.48,1403.46 1570.5,1403.46 1570.53,1403.46 1570.55,1403.46 1570.57,1403.47 1570.6,1403.47 1570.62,1403.47 1570.65,1403.47 1570.67,1403.47 1570.7,1403.47 1570.72,1403.48 1570.75,1403.48 1570.77,1403.48 1570.79,1403.48 1570.82,1403.48 1570.84,1403.48 1570.87,1403.49 1570.89,1403.49 1570.92,1403.49 1570.94,1403.49 1570.96,1403.49 1570.99,1403.49 1571.01,1403.5 1571.04,1403.5 1571.06,1403.5 1571.09,1403.5 1571.11,1403.5 1571.14,1403.51 1571.16,1403.51 1571.18,1403.51 1571.21,1403.51 1571.23,1403.51 1571.26,1403.51 1571.28,1403.52 1571.31,1403.52 1571.33,1403.52 1571.35,1403.52 1571.38,1403.52 1571.4,1403.52 1571.43,1403.53 1571.45,1403.53 1571.48,1403.53 1571.5,1403.53 1571.53,1403.53 1571.55,1403.53 1571.57,1403.54 1571.6,1403.54 1571.62,1403.54 1571.65,1403.54 1571.67,1403.54 1571.7,1403.54 1571.72,1403.55 1571.74,1403.55 1571.77,1403.55 1571.79,1403.55 1571.82,1403.55 1571.84,1403.56 1571.87,1403.56 1571.89,1403.56 1571.92,1403.56 1571.94,1403.56 1571.96,1403.56 1571.99,1403.57 1572.01,1403.57 1572.04,1403.57 1572.06,1403.57 1572.09,1403.57 1572.11,1403.57 1572.14,1403.58 1572.16,1403.58 1572.18,1403.58 1572.21,1403.58 1572.23,1403.58 1572.26,1403.58 1572.28,1403.59 1572.31,1403.59 1572.33,1403.59 1572.35,1403.59 1572.38,1403.59 1572.4,1403.59 1572.43,1403.6 1572.45,1403.6 1572.48,1403.6 1572.5,1403.6 1572.53,1403.6 1572.55,1403.6 1572.57,1403.61 1572.6,1403.61 1572.62,1403.61 1572.65,1403.61 1572.67,1403.61 1572.7,1403.61 1572.72,1403.62 1572.74,1403.62 1572.77,1403.62 1572.79,1403.62 1572.82,1403.62 1572.84,1403.62 1572.87,1403.63 1572.89,1403.63 1572.92,1403.63 1572.94,1403.63 1572.96,1403.63 1572.99,1403.63 1573.01,1403.64 1573.04,1403.64 1573.06,1403.64 1573.09,1403.64 1573.11,1403.64 1573.14,1403.64 1573.16,1403.65 1573.18,1403.65 1573.21,1403.65 1573.23,1403.65 1573.26,1403.65 1573.28,1403.65 1573.31,1403.66 1573.33,1403.66 1573.35,1403.66 1573.38,1403.66 1573.4,1403.66 1573.43,1403.66 1573.45,1403.67 1573.48,1403.67 1573.5,1403.67 1573.53,1403.67 1573.55,1403.67 1573.57,1403.67 1573.6,1403.68 1573.62,1403.68 1573.65,1403.68 1573.67,1403.68 1573.7,1403.68 1573.72,1403.68 1573.75,1403.69 1573.77,1403.69 1573.79,1403.69 1573.82,1403.69 1573.84,1403.69 1573.87,1403.69 1573.89,1403.7 1573.92,1403.7 1573.94,1403.7 1573.96,1403.7 1573.99,1403.7 1574.01,1403.7 1574.04,1403.71 1574.06,1403.71 1574.09,1403.71 1574.11,1403.71 1574.14,1403.71 1574.16,1403.71 1574.18,1403.72 1574.21,1403.72 1574.23,1403.72 1574.26,1403.72 1574.28,1403.72 1574.31,1403.72 1574.33,1403.73 1574.36,1403.73 1574.38,1403.73 1574.4,1403.73 1574.43,1403.73 1574.45,1403.73 1574.48,1403.74 1574.5,1403.74 1574.53,1403.74 1574.55,1403.74 1574.57,1403.74 1574.6,1403.74 1574.62,1403.75 1574.65,1403.75 1574.67,1403.75 1574.7,1403.75 1574.72,1403.75 1574.75,1403.75 1574.77,1403.76 1574.79,1403.76 1574.82,1403.76 1574.84,1403.76 1574.87,1403.76 1574.89,1403.76 1574.92,1403.77 1574.94,1403.77 1574.97,1403.77 1574.99,1403.77 1575.01,1403.77 1575.04,1403.77 1575.06,1403.78 1575.09,1403.78 1575.11,1403.78 1575.14,1403.78 1575.16,1403.78 1575.19,1403.78 1575.21,1403.78 1575.23,1403.79 1575.26,1403.79 1575.28,1403.79 1575.31,1403.79 1575.33,1403.79 1575.36,1403.79 1575.38,1403.8 1575.4,1403.8 1575.43,1403.8 1575.45,1403.8 1575.48,1403.8 1575.5,1403.8 1575.53,1403.81 1575.55,1403.81 1575.58,1403.81 1575.6,1403.81 1575.62,1403.81 1575.65,1403.81 1575.67,1403.82 1575.7,1403.82 1575.72,1403.82 1575.75,1403.82 1575.77,1403.82 1575.8,1403.82 1575.82,1403.83 1575.84,1403.83 1575.87,1403.83 1575.89,1403.83 1575.92,1403.83 1575.94,1403.83 1575.97,1403.83 1575.99,1403.84 1576.01,1403.84 1576.04,1403.84 1576.06,1403.84 1576.09,1403.84 1576.11,1403.84 1576.14,1403.85 1576.16,1403.85 1576.19,1403.85 1576.21,1403.85 1576.23,1403.85 1576.26,1403.85 1576.28,1403.86 1576.31,1403.86 1576.33,1403.86 1576.36,1403.86 1576.38,1403.86 1576.41,1403.86 1576.43,1403.86 1576.45,1403.87 1576.48,1403.87 1576.5,1403.87 1576.53,1403.87 1576.55,1403.87 1576.58,1403.87 1576.6,1403.88 1576.62,1403.88 1576.65,1403.88 1576.67,1403.88 1576.7,1403.88 1576.72,1403.88 1576.75,1403.89 1576.77,1403.89 1576.8,1403.89 1576.82,1403.89 1576.84,1403.89 1576.87,1403.89 1576.89,1403.89 1576.92,1403.9 1576.94,1403.9 1576.97,1403.9 1576.99,1403.9 1577.02,1403.9 1577.04,1403.9 1577.06,1403.91 1577.09,1403.91 1577.11,1403.91 1577.14,1403.91 1577.16,1403.91 1577.19,1403.91 1577.21,1403.92 1577.23,1403.92 1577.26,1403.92 1577.28,1403.92 1577.31,1403.92 1577.33,1403.92 1577.36,1403.92 1577.38,1403.93 1577.41,1403.93 1577.43,1403.93 1577.45,1403.93 1577.48,1403.93 1577.5,1403.93 1577.53,1403.94 1577.55,1403.94 1577.58,1403.94 1577.6,1403.94 1577.63,1403.94 1577.65,1403.94 1577.67,1403.94 1577.7,1403.95 1577.72,1403.95 1577.75,1403.95 1577.77,1403.95 1577.8,1403.95 1577.82,1403.95 1577.84,1403.96 1577.87,1403.96 1577.89,1403.96 1577.92,1403.96 1577.94,1403.96 1577.97,1403.96 1577.99,1403.96 1578.02,1403.97 1578.04,1403.97 1578.06,1403.97 1578.09,1403.97 1578.11,1403.97 1578.14,1403.97 1578.16,1403.98 1578.19,1403.98 1578.21,1403.98 1578.24,1403.98 1578.26,1403.98 1578.28,1403.98 1578.31,1403.98 1578.33,1403.99 1578.36,1403.99 1578.38,1403.99 1578.41,1403.99 1578.43,1403.99 1578.45,1403.99 1578.48,1404 1578.5,1404 1578.53,1404 1578.55,1404 1578.58,1404 1578.6,1404 1578.63,1404 1578.65,1404.01 1578.67,1404.01 1578.7,1404.01 1578.72,1404.01 1578.75,1404.01 1578.77,1404.01 1578.8,1404.02 1578.82,1404.02 1578.85,1404.02 1578.87,1404.02 1578.89,1404.02 1578.92,1404.02 1578.94,1404.02 1578.97,1404.03 1578.99,1404.03 1579.02,1404.03 1579.04,1404.03 1579.06,1404.03 1579.09,1404.03 1579.11,1404.04 1579.14,1404.04 1579.16,1404.04 1579.19,1404.04 1579.21,1404.04 1579.24,1404.04 1579.26,1404.04 1579.28,1404.05 1579.31,1404.05 1579.33,1404.05 1579.36,1404.05 1579.38,1404.05 1579.41,1404.05 1579.43,1404.05 1579.46,1404.06 1579.48,1404.06 1579.5,1404.06 1579.53,1404.06 1579.55,1404.06 1579.58,1404.06 1579.6,1404.07 1579.63,1404.07 1579.65,1404.07 1579.67,1404.07 1579.7,1404.07 1579.72,1404.07 1579.75,1404.07 1579.77,1404.08 1579.8,1404.08 1579.82,1404.08 1579.85,1404.08 1579.87,1404.08 1579.89,1404.08 1579.92,1404.08 1579.94,1404.09 1579.97,1404.09 1579.99,1404.09 1580.02,1404.09 1580.04,1404.09 1580.06,1404.09 1580.09,1404.1 1580.11,1404.1 1580.14,1404.1 1580.16,1404.1 1580.19,1404.1 1580.21,1404.1 1580.24,1404.1 1580.26,1404.11 1580.28,1404.11 1580.31,1404.11 1580.33,1404.11 1580.36,1404.11 1580.38,1404.11 1580.41,1404.11 1580.43,1404.12 1580.46,1404.12 1580.48,1404.12 1580.5,1404.12 1580.53,1404.12 1580.55,1404.12 1580.58,1404.12 1580.6,1404.13 1580.63,1404.13 1580.65,1404.13 1580.67,1404.13 1580.7,1404.13 1580.72,1404.13 1580.75,1404.13 1580.77,1404.14 1580.8,1404.14 1580.82,1404.14 1580.85,1404.14 1580.87,1404.14 1580.89,1404.14 1580.92,1404.15 1580.94,1404.15 1580.97,1404.15 1580.99,1404.15 1581.02,1404.15 1581.04,1404.15 1581.06,1404.15 1581.09,1404.16 1581.11,1404.16 1581.14,1404.16 1581.16,1404.16 1581.19,1404.16 1581.21,1404.16 1581.24,1404.16 1581.26,1404.17 1581.28,1404.17 1581.31,1404.17 1581.33,1404.17 1581.36,1404.17 1581.38,1404.17 1581.41,1404.17 1581.43,1404.18 1581.45,1404.18 1581.48,1404.18 1581.5,1404.18 1581.53,1404.18 1581.55,1404.18 1581.58,1404.18 1581.6,1404.19 1581.63,1404.19 1581.65,1404.19 1581.67,1404.19 1581.7,1404.19 1581.72,1404.19 1581.75,1404.19 1581.77,1404.2 1581.8,1404.2 1581.82,1404.2 1581.84,1404.2 1581.87,1404.2 1581.89,1404.2 1581.92,1404.2 1581.94,1404.21 1581.97,1404.21 1581.99,1404.21 1582.02,1404.21 1582.04,1404.21 1582.06,1404.21 1582.09,1404.21 1582.11,1404.22 1582.14,1404.22 1582.16,1404.22 1582.19,1404.22 1582.21,1404.22 1582.23,1404.22 1582.26,1404.22 1582.28,1404.23 1582.31,1404.23 1582.33,1404.23 1582.36,1404.23 1582.38,1404.23 1582.41,1404.23 1582.43,1404.23 1582.45,1404.24 1582.48,1404.24 1582.5,1404.24 1582.53,1404.24 1582.55,1404.24 1582.58,1404.24 1582.6,1404.24 1582.62,1404.25 1582.65,1404.25 1582.67,1404.25 1582.7,1404.25 1582.72,1404.25 1582.75,1404.25 1582.77,1404.25 1582.79,1404.26 1582.82,1404.26 1582.84,1404.26 1582.87,1404.26 1582.89,1404.26 1582.92,1404.26 1582.94,1404.26 1582.97,1404.27 1582.99,1404.27 1583.01,1404.27 1583.04,1404.27 1583.06,1404.27 1583.09,1404.27 1583.11,1404.27 1583.14,1404.28 1583.16,1404.28 1583.18,1404.28 1583.21,1404.28 1583.23,1404.28 1583.26,1404.28 1583.28,1404.28 1583.31,1404.29 1583.33,1404.29 1583.36,1404.29 1583.38,1404.29 1583.4,1404.29 1583.43,1404.29 1583.45,1404.29 1583.48,1404.3 1583.5,1404.3 1583.53,1404.3 1583.55,1404.3 1583.57,1404.3 1583.6,1404.3 1583.62,1404.3 1583.65,1404.31 1583.67,1404.31 1583.7,1404.31 1583.72,1404.31 1583.74,1404.31 1583.77,1404.31 1583.79,1404.31 1583.82,1404.32 1583.84,1404.32 1583.87,1404.32 1583.89,1404.32 1583.92,1404.32 1583.94,1404.32 1583.96,1404.32 1583.99,1404.33 1584.01,1404.33 1584.04,1404.33 1584.06,1404.33 1584.09,1404.33 1584.11,1404.33 1584.13,1404.33 1584.16,1404.33 1584.18,1404.34 1584.21,1404.34 1584.23,1404.34 1584.26,1404.34 1584.28,1404.34 1584.3,1404.34 1584.33,1404.34 1584.35,1404.35 1584.38,1404.35 1584.4,1404.35 1584.43,1404.35 1584.45,1404.35 1584.48,1404.35 1584.5,1404.35 1584.52,1404.36 1584.55,1404.36 1584.57,1404.36 1584.6,1404.36 1584.62,1404.36 1584.65,1404.36 1584.67,1404.36 1584.69,1404.37 1584.72,1404.37 1584.74,1404.37 1584.77,1404.37 1584.79,1404.37 1584.82,1404.37 1584.84,1404.37 1584.86,1404.37 1584.89,1404.38 1584.91,1404.38 1584.94,1404.38 1584.96,1404.38 1584.99,1404.38 1585.01,1404.38 1585.03,1404.38 1585.06,1404.39 1585.08,1404.39 1585.11,1404.39 1585.13,1404.39 1585.16,1404.39 1585.18,1404.39 1585.2,1404.39 1585.23,1404.4 1585.25,1404.4 1585.28,1404.4 1585.3,1404.4 1585.33,1404.4 1585.35,1404.4 1585.38,1404.4 1585.4,1404.4 1585.42,1404.41 1585.45,1404.41 1585.47,1404.41 1585.5,1404.41 1585.52,1404.41 1585.55,1404.41 1585.57,1404.41 1585.59,1404.42 1585.62,1404.42 1585.64,1404.42 1585.67,1404.42 1585.69,1404.42 1585.72,1404.42 1585.74,1404.42 1585.76,1404.43 1585.79,1404.43 1585.81,1404.43 1585.84,1404.43 1585.86,1404.43 1585.89,1404.43 1585.91,1404.43 1585.93,1404.43 1585.96,1404.44 1585.98,1404.44 1586.01,1404.44 1586.03,1404.44 1586.06,1404.44 1586.08,1404.44 1586.1,1404.44 1586.13,1404.45 1586.15,1404.45 1586.18,1404.45 1586.2,1404.45 1586.23,1404.45 1586.25,1404.45 1586.27,1404.45 1586.3,1404.45 1586.32,1404.46 1586.35,1404.46 1586.37,1404.46 1586.4,1404.46 1586.42,1404.46 1586.45,1404.46 1586.47,1404.46 1586.49,1404.47 1586.52,1404.47 1586.54,1404.47 1586.57,1404.47 1586.59,1404.47 1586.62,1404.47 1586.64,1404.47 1586.66,1404.47 1586.69,1404.48 1586.71,1404.48 1586.74,1404.48 1586.76,1404.48 1586.79,1404.48 1586.81,1404.48 1586.83,1404.48 1586.86,1404.49 1586.88,1404.49 1586.91,1404.49 1586.93,1404.49 1586.96,1404.49 1586.98,1404.49 1587,1404.49 1587.03,1404.49 1587.05,1404.5 1587.08,1404.5 1587.1,1404.5 1587.13,1404.5 1587.15,1404.5 1587.17,1404.5 1587.2,1404.5 1587.22,1404.5 1587.25,1404.51 1587.27,1404.51 1587.3,1404.51 1587.32,1404.51 1587.34,1404.51 1587.37,1404.51 1587.39,1404.51 1587.42,1404.52 1587.44,1404.52 1587.47,1404.52 1587.49,1404.52 1587.51,1404.52 1587.54,1404.52 1587.56,1404.52 1587.59,1404.52 1587.61,1404.53 1587.64,1404.53 1587.66,1404.53 1587.68,1404.53 1587.71,1404.53 1587.73,1404.53 1587.76,1404.53 1587.78,1404.54 1587.81,1404.54 1587.83,1404.54 1587.85,1404.54 1587.88,1404.54 1587.9,1404.54 1587.93,1404.54 1587.95,1404.54 1587.98,1404.55 1588,1404.55 1588.02,1404.55 1588.05,1404.55 1588.07,1404.55 1588.1,1404.55 1588.12,1404.55 1588.15,1404.55 1588.17,1404.56 1588.19,1404.56 1588.22,1404.56 1588.24,1404.56 1588.27,1404.56 1588.29,1404.56 1588.32,1404.56 1588.34,1404.56 1588.36,1404.57 1588.39,1404.57 1588.41,1404.57 1588.44,1404.57 1588.46,1404.57 1588.49,1404.57 1588.51,1404.57 1588.53,1404.58 1588.56,1404.58 1588.58,1404.58 1588.61,1404.58 1588.63,1404.58 1588.66,1404.58 1588.68,1404.58 1588.7,1404.58 1588.73,1404.59 1588.75,1404.59 1588.78,1404.59 1588.8,1404.59 1588.82,1404.59 1588.85,1404.59 1588.87,1404.59 1588.9,1404.59 1588.92,1404.6 1588.95,1404.6 1588.97,1404.6 1588.99,1404.6 1589.02,1404.6 1589.04,1404.6 1589.07,1404.6 1589.09,1404.6 1589.12,1404.61 1589.14,1404.61 1589.16,1404.61 1589.19,1404.61 1589.21,1404.61 1589.24,1404.61 1589.26,1404.61 1589.29,1404.61 1589.31,1404.62 1589.33,1404.62 1589.36,1404.62 1589.38,1404.62 1589.41,1404.62 1589.43,1404.62 1589.46,1404.62 1589.48,1404.62 1589.5,1404.63 1589.53,1404.63 1589.55,1404.63 1589.58,1404.63 1589.6,1404.63 1589.63,1404.63 1589.65,1404.63 1589.67,1404.63 1589.7,1404.64 1589.72,1404.64 1589.75,1404.64 1589.77,1404.64 1589.79,1404.64 1589.82,1404.64 1589.84,1404.64 1589.87,1404.64 1589.89,1404.65 1589.92,1404.65 1589.94,1404.65 1589.96,1404.65 1589.99,1404.65 1590.01,1404.65 1590.04,1404.65 1590.06,1404.65 1590.09,1404.66 1590.11,1404.66 1590.13,1404.66 1590.16,1404.66 1590.18,1404.66 1590.21,1404.66 1590.23,1404.66 1590.26,1404.66 1590.28,1404.67 1590.3,1404.67 1590.33,1404.67 1590.35,1404.67 1590.38,1404.67 1590.4,1404.67 1590.42,1404.67 1590.45,1404.67 1590.47,1404.68 1590.5,1404.68 1590.52,1404.68 1590.55,1404.68 1590.57,1404.68 1590.59,1404.68 1590.62,1404.68 1590.64,1404.68 1590.67,1404.69 1590.69,1404.69 1590.72,1404.69 1590.74,1404.69 1590.76,1404.69 1590.79,1404.69 1590.81,1404.69 1590.84,1404.69 1590.86,1404.7 1590.88,1404.7 1590.91,1404.7 1590.93,1404.7 1590.96,1404.7 1590.98,1404.7 1591.01,1404.7 1591.03,1404.7 1591.05,1404.71 1591.08,1404.71 1591.1,1404.71 1591.13,1404.71 1591.15,1404.71 1591.18,1404.71 1591.2,1404.71 1591.22,1404.71 1591.25,1404.72 1591.27,1404.72 1591.3,1404.72 1591.32,1404.72 1591.34,1404.72 1591.37,1404.72 1591.39,1404.72 1591.42,1404.72 1591.44,1404.73 1591.47,1404.73 1591.49,1404.73 1591.51,1404.73 1591.54,1404.73 1591.56,1404.73 1591.59,1404.73 1591.61,1404.73 1591.64,1404.74 1591.66,1404.74 1591.68,1404.74 1591.71,1404.74 1591.73,1404.74 1591.76,1404.74 1591.78,1404.74 1591.8,1404.74 1591.83,1404.74 1591.85,1404.75 1591.88,1404.75 1591.9,1404.75 1591.93,1404.75 1591.95,1404.75 1591.97,1404.75 1592,1404.75 1592.02,1404.75 1592.05,1404.76 1592.07,1404.76 1592.09,1404.76 1592.12,1404.76 1592.14,1404.76 1592.17,1404.76 1592.19,1404.76 1592.22,1404.76 1592.24,1404.77 1592.26,1404.77 1592.29,1404.77 1592.31,1404.77 1592.34,1404.77 1592.36,1404.77 1592.39,1404.77 1592.41,1404.77 1592.43,1404.77 1592.46,1404.78 1592.48,1404.78 1592.51,1404.78 1592.53,1404.78 1592.55,1404.78 1592.58,1404.78 1592.6,1404.78 1592.63,1404.78 1592.65,1404.79 1592.68,1404.79 1592.7,1404.79 1592.72,1404.79 1592.75,1404.79 1592.77,1404.79 1592.8,1404.79 1592.82,1404.79 1592.84,1404.8 1592.87,1404.8 1592.89,1404.8 1592.92,1404.8 1592.94,1404.8 1592.97,1404.8 1592.99,1404.8 1593.01,1404.8 1593.04,1404.8 1593.06,1404.81 1593.09,1404.81 1593.11,1404.81 1593.13,1404.81 1593.16,1404.81 1593.18,1404.81 1593.21,1404.81 1593.23,1404.81 1593.25,1404.82 1593.28,1404.82 1593.3,1404.82 1593.33,1404.82 1593.35,1404.82 1593.38,1404.82 1593.4,1404.82 1593.42,1404.82 1593.45,1404.82 1593.47,1404.83 1593.5,1404.83 1593.52,1404.83 1593.54,1404.83 1593.57,1404.83 1593.59,1404.83 1593.62,1404.83 1593.64,1404.83 1593.67,1404.84 1593.69,1404.84 1593.71,1404.84 1593.74,1404.84 1593.76,1404.84 1593.79,1404.84 1593.81,1404.84 1593.83,1404.84 1593.86,1404.84 1593.88,1404.85 1593.91,1404.85 1593.93,1404.85 1593.96,1404.85 1593.98,1404.85 1594,1404.85 1594.03,1404.85 1594.05,1404.85 1594.08,1404.86 1594.1,1404.86 1594.12,1404.86 1594.15,1404.86 1594.17,1404.86 1594.2,1404.86 1594.22,1404.86 1594.24,1404.86 1594.27,1404.86 1594.29,1404.87 1594.32,1404.87 1594.34,1404.87 1594.37,1404.87 1594.39,1404.87 1594.41,1404.87 1594.44,1404.87 1594.46,1404.87 1594.49,1404.87 1594.51,1404.88 1594.53,1404.88 1594.56,1404.88 1594.58,1404.88 1594.61,1404.88 1594.63,1404.88 1594.65,1404.88 1594.68,1404.88 1594.7,1404.89 1594.73,1404.89 1594.75,1404.89 1594.78,1404.89 1594.8,1404.89 1594.82,1404.89 1594.85,1404.89 1594.87,1404.89 1594.9,1404.89 1594.92,1404.9 1594.94,1404.9 1594.97,1404.9 1594.99,1404.9 1595.02,1404.9 1595.04,1404.9 1595.06,1404.9 1595.09,1404.9 1595.11,1404.9 1595.14,1404.91 1595.16,1404.91 1595.18,1404.91 1595.21,1404.91 1595.23,1404.91 1595.26,1404.91 1595.28,1404.91 1595.31,1404.91 1595.33,1404.91 1595.35,1404.92 1595.38,1404.92 1595.4,1404.92 1595.43,1404.92 1595.45,1404.92 1595.47,1404.92 1595.5,1404.92 1595.52,1404.92 1595.55,1404.93 1595.57,1404.93 1595.59,1404.93 1595.62,1404.93 1595.64,1404.93 1595.67,1404.93 1595.69,1404.93 1595.71,1404.93 1595.74,1404.93 1595.76,1404.94 1595.79,1404.94 1595.81,1404.94 1595.84,1404.94 1595.86,1404.94 1595.88,1404.94 1595.91,1404.94 1595.93,1404.94 1595.96,1404.94 1595.98,1404.95 1596,1404.95 1596.03,1404.95 1596.05,1404.95 1596.08,1404.95 1596.1,1404.95 1596.12,1404.95 1596.15,1404.95 1596.17,1404.95 1596.2,1404.96 1596.22,1404.96 1596.24,1404.96 1596.27,1404.96 1596.29,1404.96 1596.32,1404.96 1596.34,1404.96 1596.36,1404.96 1596.39,1404.96 1596.41,1404.97 1596.44,1404.97 1596.46,1404.97 1596.48,1404.97 1596.51,1404.97 1596.53,1404.97 1596.56,1404.97 1596.58,1404.97 1596.61,1404.97 1596.63,1404.98 1596.65,1404.98 1596.68,1404.98 1596.7,1404.98 1596.73,1404.98 1596.75,1404.98 1596.77,1404.98 1596.8,1404.98 1596.82,1404.98 1596.85,1404.99 1596.87,1404.99 1596.89,1404.99 1596.92,1404.99 1596.94,1404.99 1596.97,1404.99 1596.99,1404.99 1597.01,1404.99 1597.04,1404.99 1597.06,1405 1597.09,1405 1597.11,1405 1597.13,1405 1597.16,1405 1597.18,1405 1597.21,1405 1597.23,1405 1597.25,1405 1597.28,1405.01 1597.3,1405.01 1597.33,1405.01 1597.35,1405.01 1597.37,1405.01 1597.4,1405.01 1597.42,1405.01 1597.45,1405.01 1597.47,1405.01 1597.49,1405.02 1597.52,1405.02 1597.54,1405.02 1597.57,1405.02 1597.59,1405.02 1597.61,1405.02 1597.64,1405.02 1597.66,1405.02 1597.69,1405.02 1597.71,1405.03 1597.73,1405.03 1597.76,1405.03 1597.78,1405.03 1597.81,1405.03 1597.83,1405.03 1597.85,1405.03 1597.88,1405.03 1597.9,1405.03 1597.93,1405.03 1597.95,1405.04 1597.97,1405.04 1598,1405.04 1598.02,1405.04 1598.05,1405.04 1598.07,1405.04 1598.1,1405.04 1598.12,1405.04 1598.14,1405.04 1598.17,1405.05 1598.19,1405.05 1598.22,1405.05 1598.24,1405.05 1598.26,1405.05 1598.29,1405.05 1598.31,1405.05 1598.33,1405.05 1598.36,1405.05 1598.38,1405.06 1598.41,1405.06 1598.43,1405.06 1598.45,1405.06 1598.48,1405.06 1598.5,1405.06 1598.53,1405.06 1598.55,1405.06 1598.57,1405.06 1598.6,1405.07 1598.62,1405.07 1598.65,1405.07 1598.67,1405.07 1598.69,1405.07 1598.72,1405.07 1598.74,1405.07 1598.77,1405.07 1598.79,1405.07 1598.81,1405.07 1598.84,1405.08 1598.86,1405.08 1598.89,1405.08 1598.91,1405.08 1598.93,1405.08 1598.96,1405.08 1598.98,1405.08 1599.01,1405.08 1599.03,1405.08 1599.05,1405.09 1599.08,1405.09 1599.1,1405.09 1599.13,1405.09 1599.15,1405.09 1599.17,1405.09 1599.2,1405.09 1599.22,1405.09 1599.25,1405.09 1599.27,1405.09 1599.29,1405.1 1599.32,1405.1 1599.34,1405.1 1599.37,1405.1 1599.39,1405.1 1599.41,1405.1 1599.44,1405.1 1599.46,1405.1 1599.49,1405.1 1599.51,1405.11 1599.53,1405.11 1599.56,1405.11 1599.58,1405.11 1599.61,1405.11 1599.63,1405.11 1599.65,1405.11 1599.68,1405.11 1599.7,1405.11 1599.73,1405.11 1599.75,1405.12 1599.77,1405.12 1599.8,1405.12 1599.82,1405.12 1599.85,1405.12 1599.87,1405.12 1599.89,1405.12 1599.92,1405.12 1599.94,1405.12 1599.96,1405.13 1599.99,1405.13 1600.01,1405.13 1600.04,1405.13 1600.06,1405.13 1600.08,1405.13 1600.11,1405.13 1600.13,1405.13 1600.16,1405.13 1600.18,1405.13 1600.2,1405.14 1600.23,1405.14 1600.25,1405.14 1600.28,1405.14 1600.3,1405.14 1600.32,1405.14 1600.35,1405.14 1600.37,1405.14 1600.4,1405.14 1600.42,1405.15 1600.44,1405.15 1600.47,1405.15 1600.49,1405.15 1600.52,1405.15 1600.54,1405.15 1600.56,1405.15 1600.59,1405.15 1600.61,1405.15 1600.63,1405.15 1600.66,1405.16 1600.68,1405.16 1600.71,1405.16 1600.73,1405.16 1600.75,1405.16 1600.78,1405.16 1600.8,1405.16 1600.83,1405.16 1600.85,1405.16 1600.87,1405.16 1600.9,1405.17 1600.92,1405.17 1600.95,1405.17 1600.97,1405.17 1600.99,1405.17 1601.02,1405.17 1601.04,1405.17 1601.07,1405.17 1601.09,1405.17 1601.11,1405.17 1601.14,1405.18 1601.16,1405.18 1601.18,1405.18 1601.21,1405.18 1601.23,1405.18 1601.26,1405.18 1601.28,1405.18 1601.3,1405.18 1601.33,1405.18 1601.35,1405.19 1601.38,1405.19 1601.4,1405.19 1601.42,1405.19 1601.45,1405.19 1601.47,1405.19 1601.5,1405.19 1601.52,1405.19 1601.54,1405.19 1601.57,1405.19 1601.59,1405.2 1601.61,1405.2 1601.64,1405.2 1601.66,1405.2 1601.69,1405.2 1601.71,1405.2 1601.73,1405.2 1601.76,1405.2 1601.78,1405.2 1601.81,1405.2 1601.83,1405.21 1601.85,1405.21 1601.88,1405.21 1601.9,1405.21 1601.92,1405.21 1601.95,1405.21 1601.97,1405.21 1602,1405.21 1602.02,1405.21 1602.04,1405.21 1602.07,1405.22 1602.09,1405.22 1602.12,1405.22 1602.14,1405.22 1602.16,1405.22 1602.19,1405.22 1602.21,1405.22 1602.24,1405.22 1602.26,1405.22 1602.28,1405.22 1602.31,1405.23 1602.33,1405.23 1602.35,1405.23 1602.38,1405.23 1602.4,1405.23 1602.43,1405.23 1602.45,1405.23 1602.47,1405.23 1602.5,1405.23 1602.52,1405.23 1602.55,1405.24 1602.57,1405.24 1602.59,1405.24 1602.62,1405.24 1602.64,1405.24 1602.66,1405.24 1602.69,1405.24 1602.71,1405.24 1602.74,1405.24 1602.76,1405.24 1602.78,1405.25 1602.81,1405.25 1602.83,1405.25 1602.85,1405.25 1602.88,1405.25 1602.9,1405.25 1602.93,1405.25 1602.95,1405.25 1602.97,1405.25 1603,1405.25 1603.02,1405.26 1603.05,1405.26 1603.07,1405.26 1603.09,1405.26 1603.12,1405.26 1603.14,1405.26 1603.16,1405.26 1603.19,1405.26 1603.21,1405.26 1603.24,1405.26 1603.26,1405.27 1603.28,1405.27 1603.31,1405.27 1603.33,1405.27 1603.36,1405.27 1603.38,1405.27 1603.4,1405.27 1603.43,1405.27 1603.45,1405.27 1603.47,1405.27 1603.5,1405.27 1603.52,1405.28 1603.55,1405.28 1603.57,1405.28 1603.59,1405.28 1603.62,1405.28 1603.64,1405.28 1603.66,1405.28 1603.69,1405.28 1603.71,1405.28 1603.74,1405.28 1603.76,1405.29 1603.78,1405.29 1603.81,1405.29 1603.83,1405.29 1603.85,1405.29 1603.88,1405.29 1603.9,1405.29 1603.93,1405.29 1603.95,1405.29 1603.97,1405.29 1604,1405.3 1604.02,1405.3 1604.05,1405.3 1604.07,1405.3 1604.09,1405.3 1604.12,1405.3 1604.14,1405.3 1604.16,1405.3 1604.19,1405.3 1604.21,1405.3 1604.24,1405.3 1604.26,1405.31 1604.28,1405.31 1604.31,1405.31 1604.33,1405.31 1604.35,1405.31 1604.38,1405.31 1604.4,1405.31 1604.43,1405.31 1604.45,1405.31 1604.47,1405.31 1604.5,1405.32 1604.52,1405.32 1604.54,1405.32 1604.57,1405.32 1604.59,1405.32 1604.62,1405.32 1604.64,1405.32 1604.66,1405.32 1604.69,1405.32 1604.71,1405.32 1604.73,1405.33 1604.76,1405.33 1604.78,1405.33 1604.81,1405.33 1604.83,1405.33 1604.85,1405.33 1604.88,1405.33 1604.9,1405.33 1604.92,1405.33 1604.95,1405.33 1604.97,1405.33 1605,1405.34 1605.02,1405.34 1605.04,1405.34 1605.07,1405.34 1605.09,1405.34 1605.11,1405.34 1605.14,1405.34 1605.16,1405.34 1605.19,1405.34 1605.21,1405.34 1605.23,1405.35 1605.26,1405.35 1605.28,1405.35 1605.3,1405.35 1605.33,1405.35 1605.35,1405.35 1605.38,1405.35 1605.4,1405.35 1605.42,1405.35 1605.45,1405.35 1605.47,1405.35 1605.49,1405.36 1605.52,1405.36 1605.54,1405.36 1605.57,1405.36 1605.59,1405.36 1605.61,1405.36 1605.64,1405.36 1605.66,1405.36 1605.68,1405.36 1605.71,1405.36 1605.73,1405.36 1605.76,1405.37 1605.78,1405.37 1605.8,1405.37 1605.83,1405.37 1605.85,1405.37 1605.87,1405.37 1605.9,1405.37 1605.92,1405.37 1605.94,1405.37 1605.97,1405.37 1605.99,1405.38 1606.02,1405.38 1606.04,1405.38 1606.06,1405.38 1606.09,1405.38 1606.11,1405.38 1606.13,1405.38 1606.16,1405.38 1606.18,1405.38 1606.21,1405.38 1606.23,1405.38 1606.25,1405.39 1606.28,1405.39 1606.3,1405.39 1606.32,1405.39 1606.35,1405.39 1606.37,1405.39 1606.39,1405.39 1606.42,1405.39 1606.44,1405.39 1606.47,1405.39 1606.49,1405.39 1606.51,1405.4 1606.54,1405.4 1606.56,1405.4 1606.58,1405.4 1606.61,1405.4 1606.63,1405.4 1606.66,1405.4 1606.68,1405.4 1606.7,1405.4 1606.73,1405.4 1606.75,1405.4 1606.77,1405.41 1606.8,1405.41 1606.82,1405.41 1606.84,1405.41 1606.87,1405.41 1606.89,1405.41 1606.92,1405.41 1606.94,1405.41 1606.96,1405.41 1606.99,1405.41 1607.01,1405.41 1607.03,1405.42 1607.06,1405.42 1607.08,1405.42 1607.11,1405.42 1607.13,1405.42 1607.15,1405.42 1607.18,1405.42 1607.2,1405.42 1607.22,1405.42 1607.25,1405.42 1607.27,1405.42 1607.29,1405.43 1607.32,1405.43 1607.34,1405.43 1607.37,1405.43 1607.39,1405.43 1607.41,1405.43 1607.44,1405.43 1607.46,1405.43 1607.48,1405.43 1607.51,1405.43 1607.53,1405.43 1607.55,1405.44 1607.58,1405.44 1607.6,1405.44 1607.63,1405.44 1607.65,1405.44 1607.67,1405.44 1607.7,1405.44 1607.72,1405.44 1607.74,1405.44 1607.77,1405.44 1607.79,1405.44 1607.81,1405.45 1607.84,1405.45 1607.86,1405.45 1607.89,1405.45 1607.91,1405.45 1607.93,1405.45 1607.96,1405.45 1607.98,1405.45 1608,1405.45 1608.03,1405.45 1608.05,1405.45 1608.07,1405.46 1608.1,1405.46 1608.12,1405.46 1608.14,1405.46 1608.17,1405.46 1608.19,1405.46 1608.22,1405.46 1608.24,1405.46 1608.26,1405.46 1608.29,1405.46 1608.31,1405.46 1608.33,1405.47 1608.36,1405.47 1608.38,1405.47 1608.4,1405.47 1608.43,1405.47 1608.45,1405.47 1608.48,1405.47 1608.5,1405.47 1608.52,1405.47 1608.55,1405.47 1608.57,1405.47 1608.59,1405.48 1608.62,1405.48 1608.64,1405.48 1608.66,1405.48 1608.69,1405.48 1608.71,1405.48 1608.73,1405.48 1608.76,1405.48 1608.78,1405.48 1608.81,1405.48 1608.83,1405.48 1608.85,1405.48 1608.88,1405.49 1608.9,1405.49 1608.92,1405.49 1608.95,1405.49 1608.97,1405.49 1608.99,1405.49 1609.02,1405.49 1609.04,1405.49 1609.06,1405.49 1609.09,1405.49 1609.11,1405.49 1609.14,1405.5 1609.16,1405.5 1609.18,1405.5 1609.21,1405.5 1609.23,1405.5 1609.25,1405.5 1609.28,1405.5 1609.3,1405.5 1609.32,1405.5 1609.35,1405.5 1609.37,1405.5 1609.39,1405.5 1609.42,1405.51 1609.44,1405.51 1609.47,1405.51 1609.49,1405.51 1609.51,1405.51 1609.54,1405.51 1609.56,1405.51 1609.58,1405.51 1609.61,1405.51 1609.63,1405.51 1609.65,1405.51 1609.68,1405.52 1609.7,1405.52 1609.72,1405.52 1609.75,1405.52 1609.77,1405.52 1609.79,1405.52 1609.82,1405.52 1609.84,1405.52 1609.87,1405.52 1609.89,1405.52 1609.91,1405.52 1609.94,1405.52 1609.96,1405.53 1609.98,1405.53 1610.01,1405.53 1610.03,1405.53 1610.05,1405.53 1610.08,1405.53 1610.1,1405.53 1610.12,1405.53 1610.15,1405.53 1610.17,1405.53 1610.19,1405.53 1610.22,1405.54 1610.24,1405.54 1610.27,1405.54 1610.29,1405.54 1610.31,1405.54 1610.34,1405.54 1610.36,1405.54 1610.38,1405.54 1610.41,1405.54 1610.43,1405.54 1610.45,1405.54 1610.48,1405.54 1610.5,1405.55 1610.52,1405.55 1610.55,1405.55 1610.57,1405.55 1610.59,1405.55 1610.62,1405.55 1610.64,1405.55 1610.66,1405.55 1610.69,1405.55 1610.71,1405.55 1610.74,1405.55 1610.76,1405.55 1610.78,1405.56 1610.81,1405.56 1610.83,1405.56 1610.85,1405.56 1610.88,1405.56 1610.9,1405.56 1610.92,1405.56 1610.95,1405.56 1610.97,1405.56 1610.99,1405.56 1611.02,1405.56 1611.04,1405.56 1611.06,1405.57 1611.09,1405.57 1611.11,1405.57 1611.13,1405.57 1611.16,1405.57 1611.18,1405.57 1611.2,1405.57 1611.23,1405.57 1611.25,1405.57 1611.27,1405.57 1611.3,1405.57 1611.32,1405.58 1611.35,1405.58 1611.37,1405.58 1611.39,1405.58 1611.42,1405.58 1611.44,1405.58 1611.46,1405.58 1611.49,1405.58 1611.51,1405.58 1611.53,1405.58 1611.56,1405.58 1611.58,1405.58 1611.6,1405.59 1611.63,1405.59 1611.65,1405.59 1611.67,1405.59 1611.7,1405.59 1611.72,1405.59 1611.74,1405.59 1611.77,1405.59 1611.79,1405.59 1611.81,1405.59 1611.84,1405.59 1611.86,1405.59 1611.88,1405.6 1611.91,1405.6 1611.93,1405.6 1611.95,1405.6 1611.98,1405.6 1612,1405.6 1612.03,1405.6 1612.05,1405.6 1612.07,1405.6 1612.1,1405.6 1612.12,1405.6 1612.14,1405.6 1612.17,1405.61 1612.19,1405.61 1612.21,1405.61 1612.24,1405.61 1612.26,1405.61 1612.28,1405.61 1612.31,1405.61 1612.33,1405.61 1612.35,1405.61 1612.38,1405.61 1612.4,1405.61 1612.42,1405.61 1612.45,1405.61 1612.47,1405.62 1612.49,1405.62 1612.52,1405.62 1612.54,1405.62 1612.56,1405.62 1612.59,1405.62 1612.61,1405.62 1612.63,1405.62 1612.66,1405.62 1612.68,1405.62 1612.7,1405.62 1612.73,1405.62 1612.75,1405.63 1612.77,1405.63 1612.8,1405.63 1612.82,1405.63 1612.84,1405.63 1612.87,1405.63 1612.89,1405.63 1612.91,1405.63 1612.94,1405.63 1612.96,1405.63 1612.98,1405.63 1613.01,1405.63 1613.03,1405.64 1613.05,1405.64 1613.08,1405.64 1613.1,1405.64 1613.12,1405.64 1613.15,1405.64 1613.17,1405.64 1613.19,1405.64 1613.22,1405.64 1613.24,1405.64 1613.26,1405.64 1613.29,1405.64 1613.31,1405.65 1613.34,1405.65 1613.36,1405.65 1613.38,1405.65 1613.41,1405.65 1613.43,1405.65 1613.45,1405.65 1613.48,1405.65 1613.5,1405.65 1613.52,1405.65 1613.55,1405.65 1613.57,1405.65 1613.59,1405.65 1613.62,1405.66 1613.64,1405.66 1613.66,1405.66 1613.69,1405.66 1613.71,1405.66 1613.73,1405.66 1613.76,1405.66 1613.78,1405.66 1613.8,1405.66 1613.83,1405.66 1613.85,1405.66 1613.87,1405.66 1613.9,1405.67 1613.92,1405.67 1613.94,1405.67 1613.97,1405.67 1613.99,1405.67 1614.01,1405.67 1614.04,1405.67 1614.06,1405.67 1614.08,1405.67 1614.11,1405.67 1614.13,1405.67 1614.15,1405.67 1614.18,1405.67 1614.2,1405.68 1614.22,1405.68 1614.25,1405.68 1614.27,1405.68 1614.29,1405.68 1614.32,1405.68 1614.34,1405.68 1614.36,1405.68 1614.39,1405.68 1614.41,1405.68 1614.43,1405.68 1614.45,1405.68 1614.48,1405.68 1614.5,1405.69 1614.52,1405.69 1614.55,1405.69 1614.57,1405.69 1614.59,1405.69 1614.62,1405.69 1614.64,1405.69 1614.66,1405.69 1614.69,1405.69 1614.71,1405.69 1614.73,1405.69 1614.76,1405.69 1614.78,1405.7 1614.8,1405.7 1614.83,1405.7 1614.85,1405.7 1614.87,1405.7 1614.9,1405.7 1614.92,1405.7 1614.94,1405.7 1614.97,1405.7 1614.99,1405.7 1615.01,1405.7 1615.04,1405.7 1615.06,1405.7 1615.08,1405.71 1615.11,1405.71 1615.13,1405.71 1615.15,1405.71 1615.18,1405.71 1615.2,1405.71 1615.22,1405.71 1615.25,1405.71 1615.27,1405.71 1615.29,1405.71 1615.32,1405.71 1615.34,1405.71 1615.36,1405.71 1615.39,1405.72 1615.41,1405.72 1615.43,1405.72 1615.46,1405.72 1615.48,1405.72 1615.5,1405.72 1615.53,1405.72 1615.55,1405.72 1615.57,1405.72 1615.6,1405.72 1615.62,1405.72 1615.64,1405.72 1615.67,1405.72 1615.69,1405.73 1615.71,1405.73 1615.73,1405.73 1615.76,1405.73 1615.78,1405.73 1615.8,1405.73 1615.83,1405.73 1615.85,1405.73 1615.87,1405.73 1615.9,1405.73 1615.92,1405.73 1615.94,1405.73 1615.97,1405.73 1615.99,1405.74 1616.01,1405.74 1616.04,1405.74 1616.06,1405.74 1616.08,1405.74 1616.11,1405.74 1616.13,1405.74 1616.15,1405.74 1616.18,1405.74 1616.2,1405.74 1616.22,1405.74 1616.25,1405.74 1616.27,1405.74 1616.29,1405.75 1616.32,1405.75 1616.34,1405.75 1616.36,1405.75 1616.38,1405.75 1616.41,1405.75 1616.43,1405.75 1616.45,1405.75 1616.48,1405.75 1616.5,1405.75 1616.52,1405.75 1616.55,1405.75 1616.57,1405.75 1616.59,1405.76 1616.62,1405.76 1616.64,1405.76 1616.66,1405.76 1616.69,1405.76 1616.71,1405.76 1616.73,1405.76 1616.76,1405.76 1616.78,1405.76 1616.8,1405.76 1616.83,1405.76 1616.85,1405.76 1616.87,1405.76 1616.9,1405.76 1616.92,1405.77 1616.94,1405.77 1616.96,1405.77 1616.99,1405.77 1617.01,1405.77 1617.03,1405.77 1617.06,1405.77 1617.08,1405.77 1617.1,1405.77 1617.13,1405.77 1617.15,1405.77 1617.17,1405.77 1617.2,1405.77 1617.22,1405.78 1617.24,1405.78 1617.27,1405.78 1617.29,1405.78 1617.31,1405.78 1617.34,1405.78 1617.36,1405.78 1617.38,1405.78 1617.4,1405.78 1617.43,1405.78 1617.45,1405.78 1617.47,1405.78 1617.5,1405.78 1617.52,1405.78 1617.54,1405.79 1617.57,1405.79 1617.59,1405.79 1617.61,1405.79 1617.64,1405.79 1617.66,1405.79 1617.68,1405.79 1617.71,1405.79 1617.73,1405.79 1617.75,1405.79 1617.77,1405.79 1617.8,1405.79 1617.82,1405.79 1617.84,1405.8 1617.87,1405.8 1617.89,1405.8 1617.91,1405.8 1617.94,1405.8 1617.96,1405.8 1617.98,1405.8 1618.01,1405.8 1618.03,1405.8 1618.05,1405.8 1618.08,1405.8 1618.1,1405.8 1618.12,1405.8 1618.14,1405.8 1618.17,1405.81 1618.19,1405.81 1618.21,1405.81 1618.24,1405.81 1618.26,1405.81 1618.28,1405.81 1618.31,1405.81 1618.33,1405.81 1618.35,1405.81 1618.38,1405.81 1618.4,1405.81 1618.42,1405.81 1618.44,1405.81 1618.47,1405.81 1618.49,1405.82 1618.51,1405.82 1618.54,1405.82 1618.56,1405.82 1618.58,1405.82 1618.61,1405.82 1618.63,1405.82 1618.65,1405.82 1618.68,1405.82 1618.7,1405.82 1618.72,1405.82 1618.74,1405.82 1618.77,1405.82 1618.79,1405.83 1618.81,1405.83 1618.84,1405.83 1618.86,1405.83 1618.88,1405.83 1618.91,1405.83 1618.93,1405.83 1618.95,1405.83 1618.98,1405.83 1619,1405.83 1619.02,1405.83 1619.04,1405.83 1619.07,1405.83 1619.09,1405.83 1619.11,1405.84 1619.14,1405.84 1619.16,1405.84 1619.18,1405.84 1619.21,1405.84 1619.23,1405.84 1619.25,1405.84 1619.28,1405.84 1619.3,1405.84 1619.32,1405.84 1619.34,1405.84 1619.37,1405.84 1619.39,1405.84 1619.41,1405.84 1619.44,1405.85 1619.46,1405.85 1619.48,1405.85 1619.51,1405.85 1619.53,1405.85 1619.55,1405.85 1619.57,1405.85 1619.6,1405.85 1619.62,1405.85 1619.64,1405.85 1619.67,1405.85 1619.69,1405.85 1619.71,1405.85 1619.74,1405.85 1619.76,1405.86 1619.78,1405.86 1619.8,1405.86 1619.83,1405.86 1619.85,1405.86 1619.87,1405.86 1619.9,1405.86 1619.92,1405.86 1619.94,1405.86 1619.97,1405.86 1619.99,1405.86 1620.01,1405.86 1620.04,1405.86 1620.06,1405.86 1620.08,1405.86 1620.1,1405.87 1620.13,1405.87 1620.15,1405.87 1620.17,1405.87 1620.2,1405.87 1620.22,1405.87 1620.24,1405.87 1620.26,1405.87 1620.29,1405.87 1620.31,1405.87 1620.33,1405.87 1620.36,1405.87 1620.38,1405.87 1620.4,1405.87 1620.43,1405.88 1620.45,1405.88 1620.47,1405.88 1620.49,1405.88 1620.52,1405.88 1620.54,1405.88 1620.56,1405.88 1620.59,1405.88 1620.61,1405.88 1620.63,1405.88 1620.66,1405.88 1620.68,1405.88 1620.7,1405.88 1620.72,1405.88 1620.75,1405.89 1620.77,1405.89 1620.79,1405.89 1620.82,1405.89 1620.84,1405.89 1620.86,1405.89 1620.89,1405.89 1620.91,1405.89 1620.93,1405.89 1620.95,1405.89 1620.98,1405.89 1621,1405.89 1621.02,1405.89 1621.05,1405.89 1621.07,1405.89 1621.09,1405.9 1621.11,1405.9 1621.14,1405.9 1621.16,1405.9 1621.18,1405.9 1621.21,1405.9 1621.23,1405.9 1621.25,1405.9 1621.28,1405.9 1621.3,1405.9 1621.32,1405.9 1621.34,1405.9 1621.37,1405.9 1621.39,1405.9 1621.41,1405.9 1621.44,1405.91 1621.46,1405.91 1621.48,1405.91 1621.5,1405.91 1621.53,1405.91 1621.55,1405.91 1621.57,1405.91 1621.6,1405.91 1621.62,1405.91 1621.64,1405.91 1621.66,1405.91 1621.69,1405.91 1621.71,1405.91 1621.73,1405.91 1621.76,1405.92 1621.78,1405.92 1621.8,1405.92 1621.83,1405.92 1621.85,1405.92 1621.87,1405.92 1621.89,1405.92 1621.92,1405.92 1621.94,1405.92 1621.96,1405.92 1621.99,1405.92 1622.01,1405.92 1622.03,1405.92 1622.05,1405.92 1622.08,1405.92 1622.1,1405.93 1622.12,1405.93 1622.15,1405.93 1622.17,1405.93 1622.19,1405.93 1622.21,1405.93 1622.24,1405.93 1622.26,1405.93 1622.28,1405.93 1622.31,1405.93 1622.33,1405.93 1622.35,1405.93 1622.37,1405.93 1622.4,1405.93 1622.42,1405.93 1622.44,1405.94 1622.47,1405.94 1622.49,1405.94 1622.51,1405.94 1622.53,1405.94 1622.56,1405.94 1622.58,1405.94 1622.6,1405.94 1622.63,1405.94 1622.65,1405.94 1622.67,1405.94 1622.69,1405.94 1622.72,1405.94 1622.74,1405.94 1622.76,1405.94 1622.79,1405.95 1622.81,1405.95 1622.83,1405.95 1622.85,1405.95 1622.88,1405.95 1622.9,1405.95 1622.92,1405.95 1622.95,1405.95 1622.97,1405.95 1622.99,1405.95 1623.01,1405.95 1623.04,1405.95 1623.06,1405.95 1623.08,1405.95 1623.11,1405.95 1623.13,1405.96 1623.15,1405.96 1623.17,1405.96 1623.2,1405.96 1623.22,1405.96 1623.24,1405.96 1623.27,1405.96 1623.29,1405.96 1623.31,1405.96 1623.33,1405.96 1623.36,1405.96 1623.38,1405.96 1623.4,1405.96 1623.42,1405.96 1623.45,1405.96 1623.47,1405.96 1623.49,1405.97 1623.52,1405.97 1623.54,1405.97 1623.56,1405.97 1623.58,1405.97 1623.61,1405.97 1623.63,1405.97 1623.65,1405.97 1623.68,1405.97 1623.7,1405.97 1623.72,1405.97 1623.74,1405.97 1623.77,1405.97 1623.79,1405.97 1623.81,1405.97 1623.83,1405.98 1623.86,1405.98 1623.88,1405.98 1623.9,1405.98 1623.93,1405.98 1623.95,1405.98 1623.97,1405.98 1623.99,1405.98 1624.02,1405.98 1624.04,1405.98 1624.06,1405.98 1624.09,1405.98 1624.11,1405.98 1624.13,1405.98 1624.15,1405.98 1624.18,1405.98 1624.2,1405.99 1624.22,1405.99 1624.24,1405.99 1624.27,1405.99 1624.29,1405.99 1624.31,1405.99 1624.34,1405.99 1624.36,1405.99 1624.38,1405.99 1624.4,1405.99 1624.43,1405.99 1624.45,1405.99 1624.47,1405.99 1624.5,1405.99 1624.52,1405.99 1624.54,1406 1624.56,1406 1624.59,1406 1624.61,1406 1624.63,1406 1624.65,1406 1624.68,1406 1624.7,1406 1624.72,1406 1624.75,1406 1624.77,1406 1624.79,1406 1624.81,1406 1624.84,1406 1624.86,1406 1624.88,1406 1624.9,1406.01 1624.93,1406.01 1624.95,1406.01 1624.97,1406.01 1624.99,1406.01 1625.02,1406.01 1625.04,1406.01 1625.06,1406.01 1625.09,1406.01 1625.11,1406.01 1625.13,1406.01 1625.15,1406.01 1625.18,1406.01 1625.2,1406.01 1625.22,1406.01 1625.24,1406.01 1625.27,1406.02 1625.29,1406.02 1625.31,1406.02 1625.34,1406.02 1625.36,1406.02 1625.38,1406.02 1625.4,1406.02 1625.43,1406.02 1625.45,1406.02 1625.47,1406.02 1625.49,1406.02 1625.52,1406.02 1625.54,1406.02 1625.56,1406.02 1625.58,1406.02 1625.61,1406.02 1625.63,1406.03 1625.65,1406.03 1625.68,1406.03 1625.7,1406.03 1625.72,1406.03 1625.74,1406.03 1625.77,1406.03 1625.79,1406.03 1625.81,1406.03 1625.83,1406.03 1625.86,1406.03 1625.88,1406.03 1625.9,1406.03 1625.92,1406.03 1625.95,1406.03 1625.97,1406.03 1625.99,1406.04 1626.02,1406.04 1626.04,1406.04 1626.06,1406.04 1626.08,1406.04 1626.11,1406.04 1626.13,1406.04 1626.15,1406.04 1626.17,1406.04 1626.2,1406.04 1626.22,1406.04 1626.24,1406.04 1626.26,1406.04 1626.29,1406.04 1626.31,1406.04 1626.33,1406.04 1626.36,1406.05 1626.38,1406.05 1626.4,1406.05 1626.42,1406.05 1626.45,1406.05 1626.47,1406.05 1626.49,1406.05 1626.51,1406.05 1626.54,1406.05 1626.56,1406.05 1626.58,1406.05 1626.6,1406.05 1626.63,1406.05 1626.65,1406.05 1626.67,1406.05 1626.69,1406.05 1626.72,1406.05 1626.74,1406.06 1626.76,1406.06 1626.78,1406.06 1626.81,1406.06 1626.83,1406.06 1626.85,1406.06 1626.88,1406.06 1626.9,1406.06 1626.92,1406.06 1626.94,1406.06 1626.97,1406.06 1626.99,1406.06 1627.01,1406.06 1627.03,1406.06 1627.06,1406.06 1627.08,1406.06 1627.1,1406.07 1627.12,1406.07 1627.15,1406.07 1627.17,1406.07 1627.19,1406.07 1627.21,1406.07 1627.24,1406.07 1627.26,1406.07 1627.28,1406.07 1627.3,1406.07 1627.33,1406.07 1627.35,1406.07 1627.37,1406.07 1627.39,1406.07 1627.42,1406.07 1627.44,1406.07 1627.46,1406.07 1627.48,1406.08 1627.51,1406.08 1627.53,1406.08 1627.55,1406.08 1627.57,1406.08 1627.6,1406.08 1627.62,1406.08 1627.64,1406.08 1627.66,1406.08 1627.69,1406.08 1627.71,1406.08 1627.73,1406.08 1627.76,1406.08 1627.78,1406.08 1627.8,1406.08 1627.82,1406.08 1627.85,1406.08 1627.87,1406.09 1627.89,1406.09 1627.91,1406.09 1627.94,1406.09 1627.96,1406.09 1627.98,1406.09 1628,1406.09 1628.03,1406.09 1628.05,1406.09 1628.07,1406.09 1628.09,1406.09 1628.12,1406.09 1628.14,1406.09 1628.16,1406.09 1628.18,1406.09 1628.21,1406.09 1628.23,1406.09 1628.25,1406.1 1628.27,1406.1 1628.3,1406.1 1628.32,1406.1 1628.34,1406.1 1628.36,1406.1 1628.39,1406.1 1628.41,1406.1 1628.43,1406.1 1628.45,1406.1 1628.48,1406.1 1628.5,1406.1 1628.52,1406.1 1628.54,1406.1 1628.57,1406.1 1628.59,1406.1 1628.61,1406.1 1628.63,1406.11 1628.66,1406.11 1628.68,1406.11 1628.7,1406.11 1628.72,1406.11 1628.75,1406.11 1628.77,1406.11 1628.79,1406.11 1628.81,1406.11 1628.84,1406.11 1628.86,1406.11 1628.88,1406.11 1628.9,1406.11 1628.93,1406.11 1628.95,1406.11 1628.97,1406.11 1628.99,1406.11 1629.02,1406.12 1629.04,1406.12 1629.06,1406.12 1629.08,1406.12 1629.1,1406.12 1629.13,1406.12 1629.15,1406.12 1629.17,1406.12 1629.19,1406.12 1629.22,1406.12 1629.24,1406.12 1629.26,1406.12 1629.28,1406.12 1629.31,1406.12 1629.33,1406.12 1629.35,1406.12 1629.37,1406.12 1629.4,1406.12 1629.42,1406.13 1629.44,1406.13 1629.46,1406.13 1629.49,1406.13 1629.51,1406.13 1629.53,1406.13 1629.55,1406.13 1629.58,1406.13 1629.6,1406.13 1629.62,1406.13 1629.64,1406.13 1629.67,1406.13 1629.69,1406.13 1629.71,1406.13 1629.73,1406.13 1629.76,1406.13 1629.78,1406.13 1629.8,1406.14 1629.82,1406.14 1629.85,1406.14 1629.87,1406.14 1629.89,1406.14 1629.91,1406.14 1629.93,1406.14 1629.96,1406.14 1629.98,1406.14 1630,1406.14 1630.02,1406.14 1630.05,1406.14 1630.07,1406.14 1630.09,1406.14 1630.11,1406.14 1630.14,1406.14 1630.16,1406.14 1630.18,1406.14 1630.2,1406.15 1630.23,1406.15 1630.25,1406.15 1630.27,1406.15 1630.29,1406.15 1630.32,1406.15 1630.34,1406.15 1630.36,1406.15 1630.38,1406.15 1630.4,1406.15 1630.43,1406.15 1630.45,1406.15 1630.47,1406.15 1630.49,1406.15 1630.52,1406.15 1630.54,1406.15 1630.56,1406.15 1630.58,1406.15 1630.61,1406.16 1630.63,1406.16 1630.65,1406.16 1630.67,1406.16 1630.7,1406.16 1630.72,1406.16 1630.74,1406.16 1630.76,1406.16 1630.78,1406.16 1630.81,1406.16 1630.83,1406.16 1630.85,1406.16 1630.87,1406.16 1630.9,1406.16 1630.92,1406.16 1630.94,1406.16 1630.96,1406.16 1630.99,1406.16 1631.01,1406.17 1631.03,1406.17 1631.05,1406.17 1631.08,1406.17 1631.1,1406.17 1631.12,1406.17 1631.14,1406.17 1631.16,1406.17 1631.19,1406.17 1631.21,1406.17 1631.23,1406.17 1631.25,1406.17 1631.28,1406.17 1631.3,1406.17 1631.32,1406.17 1631.34,1406.17 1631.37,1406.17 1631.39,1406.17 1631.41,1406.17 1631.43,1406.18 1631.45,1406.18 1631.48,1406.18 1631.5,1406.18 1631.52,1406.18 1631.54,1406.18 1631.57,1406.18 1631.59,1406.18 1631.61,1406.18 1631.63,1406.18 1631.65,1406.18 1631.68,1406.18 1631.7,1406.18 1631.72,1406.18 1631.74,1406.18 1631.77,1406.18 1631.79,1406.18 1631.81,1406.18 1631.83,1406.19 1631.86,1406.19 1631.88,1406.19 1631.9,1406.19 1631.92,1406.19 1631.94,1406.19 1631.97,1406.19 1631.99,1406.19 1632.01,1406.19 1632.03,1406.19 1632.06,1406.19 1632.08,1406.19 1632.1,1406.19 1632.12,1406.19 1632.14,1406.19 1632.17,1406.19 1632.19,1406.19 1632.21,1406.19 1632.23,1406.19 1632.26,1406.2 1632.28,1406.2 1632.3,1406.2 1632.32,1406.2 1632.35,1406.2 1632.37,1406.2 1632.39,1406.2 1632.41,1406.2 1632.43,1406.2 1632.46,1406.2 1632.48,1406.2 1632.5,1406.2 1632.52,1406.2 1632.55,1406.2 1632.57,1406.2 1632.59,1406.2 1632.61,1406.2 1632.63,1406.2 1632.66,1406.2 1632.68,1406.21 1632.7,1406.21 1632.72,1406.21 1632.75,1406.21 1632.77,1406.21 1632.79,1406.21 1632.81,1406.21 1632.83,1406.21 1632.86,1406.21 1632.88,1406.21 1632.9,1406.21 1632.92,1406.21 1632.95,1406.21 1632.97,1406.21 1632.99,1406.21 1633.01,1406.21 1633.03,1406.21 1633.06,1406.21 1633.08,1406.21 1633.1,1406.22 1633.12,1406.22 1633.14,1406.22 1633.17,1406.22 1633.19,1406.22 1633.21,1406.22 1633.23,1406.22 1633.26,1406.22 1633.28,1406.22 1633.3,1406.22 1633.32,1406.22 1633.34,1406.22 1633.37,1406.22 1633.39,1406.22 1633.41,1406.22 1633.43,1406.22 1633.46,1406.22 1633.48,1406.22 1633.5,1406.22 1633.52,1406.23 1633.54,1406.23 1633.57,1406.23 1633.59,1406.23 1633.61,1406.23 1633.63,1406.23 1633.65,1406.23 1633.68,1406.23 1633.7,1406.23 1633.72,1406.23 1633.74,1406.23 1633.77,1406.23 1633.79,1406.23 1633.81,1406.23 1633.83,1406.23 1633.85,1406.23 1633.88,1406.23 1633.9,1406.23 1633.92,1406.23 1633.94,1406.24 1633.96,1406.24 1633.99,1406.24 1634.01,1406.24 1634.03,1406.24 1634.05,1406.24 1634.08,1406.24 1634.1,1406.24 1634.12,1406.24 1634.14,1406.24 1634.16,1406.24 1634.19,1406.24 1634.21,1406.24 1634.23,1406.24 1634.25,1406.24 1634.27,1406.24 1634.3,1406.24 1634.32,1406.24 1634.34,1406.24 1634.36,1406.24 1634.38,1406.25 1634.41,1406.25 1634.43,1406.25 1634.45,1406.25 1634.47,1406.25 1634.5,1406.25 1634.52,1406.25 1634.54,1406.25 1634.56,1406.25 1634.58,1406.25 1634.61,1406.25 1634.63,1406.25 1634.65,1406.25 1634.67,1406.25 1634.69,1406.25 1634.72,1406.25 1634.74,1406.25 1634.76,1406.25 1634.78,1406.25 1634.8,1406.25 1634.83,1406.26 1634.85,1406.26 1634.87,1406.26 1634.89,1406.26 1634.91,1406.26 1634.94,1406.26 1634.96,1406.26 1634.98,1406.26 1635,1406.26 1635.03,1406.26 1635.05,1406.26 1635.07,1406.26 1635.09,1406.26 1635.11,1406.26 1635.14,1406.26 1635.16,1406.26 1635.18,1406.26 1635.2,1406.26 1635.22,1406.26 1635.25,1406.26 1635.27,1406.27 1635.29,1406.27 1635.31,1406.27 1635.33,1406.27 1635.36,1406.27 1635.38,1406.27 1635.4,1406.27 1635.42,1406.27 1635.44,1406.27 1635.47,1406.27 1635.49,1406.27 1635.51,1406.27 1635.53,1406.27 1635.55,1406.27 1635.58,1406.27 1635.6,1406.27 1635.62,1406.27 1635.64,1406.27 1635.66,1406.27 1635.69,1406.27 1635.71,1406.28 1635.73,1406.28 1635.75,1406.28 1635.77,1406.28 1635.8,1406.28 1635.82,1406.28 1635.84,1406.28 1635.86,1406.28 1635.88,1406.28 1635.91,1406.28 1635.93,1406.28 1635.95,1406.28 1635.97,1406.28 1635.99,1406.28 1636.02,1406.28 1636.04,1406.28 1636.06,1406.28 1636.08,1406.28 1636.1,1406.28 1636.13,1406.28 1636.15,1406.28 1636.17,1406.29 1636.19,1406.29 1636.21,1406.29 1636.24,1406.29 1636.26,1406.29 1636.28,1406.29 1636.3,1406.29 1636.32,1406.29 1636.35,1406.29 1636.37,1406.29 1636.39,1406.29 1636.41,1406.29 1636.43,1406.29 1636.46,1406.29 1636.48,1406.29 1636.5,1406.29 1636.52,1406.29 1636.54,1406.29 1636.57,1406.29 1636.59,1406.29 1636.61,1406.29 1636.63,1406.3 1636.65,1406.3 1636.68,1406.3 1636.7,1406.3 1636.72,1406.3 1636.74,1406.3 1636.76,1406.3 1636.79,1406.3 1636.81,1406.3 1636.83,1406.3 1636.85,1406.3 1636.87,1406.3 1636.89,1406.3 1636.92,1406.3 1636.94,1406.3 1636.96,1406.3 1636.98,1406.3 1637,1406.3 1637.03,1406.3 1637.05,1406.3 1637.07,1406.3 1637.09,1406.31 1637.11,1406.31 1637.14,1406.31 1637.16,1406.31 1637.18,1406.31 1637.2,1406.31 1637.22,1406.31 1637.25,1406.31 1637.27,1406.31 1637.29,1406.31 1637.31,1406.31 1637.33,1406.31 1637.35,1406.31 1637.38,1406.31 1637.4,1406.31 1637.42,1406.31 1637.44,1406.31 1637.46,1406.31 1637.49,1406.31 1637.51,1406.31 1637.53,1406.31 1637.55,1406.32 1637.57,1406.32 1637.6,1406.32 1637.62,1406.32 1637.64,1406.32 1637.66,1406.32 1637.68,1406.32 1637.71,1406.32 1637.73,1406.32 1637.75,1406.32 1637.77,1406.32 1637.79,1406.32 1637.81,1406.32 1637.84,1406.32 1637.86,1406.32 1637.88,1406.32 1637.9,1406.32 1637.92,1406.32 1637.95,1406.32 1637.97,1406.32 1637.99,1406.32 1638.01,1406.33 1638.03,1406.33 1638.05,1406.33 1638.08,1406.33 1638.1,1406.33 1638.12,1406.33 1638.14,1406.33 1638.16,1406.33 1638.19,1406.33 1638.21,1406.33 1638.23,1406.33 1638.25,1406.33 1638.27,1406.33 1638.3,1406.33 1638.32,1406.33 1638.34,1406.33 1638.36,1406.33 1638.38,1406.33 1638.4,1406.33 1638.43,1406.33 1638.45,1406.33 1638.47,1406.33 1638.49,1406.34 1638.51,1406.34 1638.54,1406.34 1638.56,1406.34 1638.58,1406.34 1638.6,1406.34 1638.62,1406.34 1638.64,1406.34 1638.67,1406.34 1638.69,1406.34 1638.71,1406.34 1638.73,1406.34 1638.75,1406.34 1638.77,1406.34 1638.8,1406.34 1638.82,1406.34 1638.84,1406.34 1638.86,1406.34 1638.88,1406.34 1638.91,1406.34 1638.93,1406.34 1638.95,1406.34 1638.97,1406.35 1638.99,1406.35 1639.01,1406.35 1639.04,1406.35 1639.06,1406.35 1639.08,1406.35 1639.1,1406.35 1639.12,1406.35 1639.15,1406.35 1639.17,1406.35 1639.19,1406.35 1639.21,1406.35 1639.23,1406.35 1639.25,1406.35 1639.28,1406.35 1639.3,1406.35 1639.32,1406.35 1639.34,1406.35 1639.36,1406.35 1639.38,1406.35 1639.41,1406.35 1639.43,1406.35 1639.45,1406.35 1639.47,1406.36 1639.49,1406.36 1639.52,1406.36 1639.54,1406.36 1639.56,1406.36 1639.58,1406.36 1639.6,1406.36 1639.62,1406.36 1639.65,1406.36 1639.67,1406.36 1639.69,1406.36 1639.71,1406.36 1639.73,1406.36 1639.75,1406.36 1639.78,1406.36 1639.8,1406.36 1639.82,1406.36 1639.84,1406.36 1639.86,1406.36 1639.88,1406.36 1639.91,1406.36 1639.93,1406.36 1639.95,1406.37 1639.97,1406.37 1639.99,1406.37 1640.01,1406.37 1640.04,1406.37 1640.06,1406.37 1640.08,1406.37 1640.1,1406.37 1640.12,1406.37 1640.14,1406.37 1640.17,1406.37 1640.19,1406.37 1640.21,1406.37 1640.23,1406.37 1640.25,1406.37 1640.28,1406.37 1640.3,1406.37 1640.32,1406.37 1640.34,1406.37 1640.36,1406.37 1640.38,1406.37 1640.41,1406.37 1640.43,1406.37 1640.45,1406.38 1640.47,1406.38 1640.49,1406.38 1640.51,1406.38 1640.54,1406.38 1640.56,1406.38 1640.58,1406.38 1640.6,1406.38 1640.62,1406.38 1640.64,1406.38 1640.67,1406.38 1640.69,1406.38 1640.71,1406.38 1640.73,1406.38 1640.75,1406.38 1640.77,1406.38 1640.8,1406.38 1640.82,1406.38 1640.84,1406.38 1640.86,1406.38 1640.88,1406.38 1640.9,1406.38 1640.93,1406.38 1640.95,1406.39 1640.97,1406.39 1640.99,1406.39 1641.01,1406.39 1641.03,1406.39 1641.05,1406.39 1641.08,1406.39 1641.1,1406.39 1641.12,1406.39 1641.14,1406.39 1641.16,1406.39 1641.18,1406.39 1641.21,1406.39 1641.23,1406.39 1641.25,1406.39 1641.27,1406.39 1641.29,1406.39 1641.31,1406.39 1641.34,1406.39 1641.36,1406.39 1641.38,1406.39 1641.4,1406.39 1641.42,1406.39 1641.44,1406.39 1641.47,1406.4 1641.49,1406.4 1641.51,1406.4 1641.53,1406.4 1641.55,1406.4 1641.57,1406.4 1641.6,1406.4 1641.62,1406.4 1641.64,1406.4 1641.66,1406.4 1641.68,1406.4 1641.7,1406.4 1641.72,1406.4 1641.75,1406.4 1641.77,1406.4 1641.79,1406.4 1641.81,1406.4 1641.83,1406.4 1641.85,1406.4 1641.88,1406.4 1641.9,1406.4 1641.92,1406.4 1641.94,1406.4 1641.96,1406.4 1641.98,1406.41 1642.01,1406.41 1642.03,1406.41 1642.05,1406.41 1642.07,1406.41 1642.09,1406.41 1642.11,1406.41 1642.13,1406.41 1642.16,1406.41 1642.18,1406.41 1642.2,1406.41 1642.22,1406.41 1642.24,1406.41 1642.26,1406.41 1642.29,1406.41 1642.31,1406.41 1642.33,1406.41 1642.35,1406.41 1642.37,1406.41 1642.39,1406.41 1642.41,1406.41 1642.44,1406.41 1642.46,1406.41 1642.48,1406.41 1642.5,1406.42 1642.52,1406.42 1642.54,1406.42 1642.57,1406.42 1642.59,1406.42 1642.61,1406.42 1642.63,1406.42 1642.65,1406.42 1642.67,1406.42 1642.69,1406.42 1642.72,1406.42 1642.74,1406.42 1642.76,1406.42 1642.78,1406.42 1642.8,1406.42 1642.82,1406.42 1642.84,1406.42 1642.87,1406.42 1642.89,1406.42 1642.91,1406.42 1642.93,1406.42 1642.95,1406.42 1642.97,1406.42 1643,1406.42 1643.02,1406.43 1643.04,1406.43 1643.06,1406.43 1643.08,1406.43 1643.1,1406.43 1643.12,1406.43 1643.15,1406.43 1643.17,1406.43 1643.19,1406.43 1643.21,1406.43 1643.23,1406.43 1643.25,1406.43 1643.27,1406.43 1643.3,1406.43 1643.32,1406.43 1643.34,1406.43 1643.36,1406.43 1643.38,1406.43 1643.4,1406.43 1643.42,1406.43 1643.45,1406.43 1643.47,1406.43 1643.49,1406.43 1643.51,1406.43 1643.53,1406.43 1643.55,1406.44 1643.57,1406.44 1643.6,1406.44 1643.62,1406.44 1643.64,1406.44 1643.66,1406.44 1643.68,1406.44 1643.7,1406.44 1643.72,1406.44 1643.75,1406.44 1643.77,1406.44 1643.79,1406.44 1643.81,1406.44 1643.83,1406.44 1643.85,1406.44 1643.87,1406.44 1643.9,1406.44 1643.92,1406.44 1643.94,1406.44 1643.96,1406.44 1643.98,1406.44 1644,1406.44 1644.02,1406.44 1644.05,1406.44 1644.07,1406.44 1644.09,1406.45 1644.11,1406.45 1644.13,1406.45 1644.15,1406.45 1644.17,1406.45 1644.2,1406.45 1644.22,1406.45 1644.24,1406.45 1644.26,1406.45 1644.28,1406.45 1644.3,1406.45 1644.32,1406.45 1644.35,1406.45 1644.37,1406.45 1644.39,1406.45 1644.41,1406.45 1644.43,1406.45 1644.45,1406.45 1644.47,1406.45 1644.5,1406.45 1644.52,1406.45 1644.54,1406.45 1644.56,1406.45 1644.58,1406.45 1644.6,1406.45 1644.62,1406.45 1644.65,1406.46 1644.67,1406.46 1644.69,1406.46 1644.71,1406.46 1644.73,1406.46 1644.75,1406.46 1644.77,1406.46 1644.79,1406.46 1644.82,1406.46 1644.84,1406.46 1644.86,1406.46 1644.88,1406.46 1644.9,1406.46 1644.92,1406.46 1644.94,1406.46 1644.97,1406.46 1644.99,1406.46 1645.01,1406.46 1645.03,1406.46 1645.05,1406.46 1645.07,1406.46 1645.09,1406.46 1645.11,1406.46 1645.14,1406.46 1645.16,1406.46 1645.18,1406.46 1645.2,1406.47 1645.22,1406.47 1645.24,1406.47 1645.26,1406.47 1645.29,1406.47 1645.31,1406.47 1645.33,1406.47 1645.35,1406.47 1645.37,1406.47 1645.39,1406.47 1645.41,1406.47 1645.43,1406.47 1645.46,1406.47 1645.48,1406.47 1645.5,1406.47 1645.52,1406.47 1645.54,1406.47 1645.56,1406.47 1645.58,1406.47 1645.6,1406.47 1645.63,1406.47 1645.65,1406.47 1645.67,1406.47 1645.69,1406.47 1645.71,1406.47 1645.73,1406.47 1645.75,1406.47 1645.78,1406.48 1645.8,1406.48 1645.82,1406.48 1645.84,1406.48 1645.86,1406.48 1645.88,1406.48 1645.9,1406.48 1645.92,1406.48 1645.95,1406.48 1645.97,1406.48 1645.99,1406.48 1646.01,1406.48 1646.03,1406.48 1646.05,1406.48 1646.07,1406.48 1646.09,1406.48 1646.12,1406.48 1646.14,1406.48 1646.16,1406.48 1646.18,1406.48 1646.2,1406.48 1646.22,1406.48 1646.24,1406.48 1646.26,1406.48 1646.29,1406.48 1646.31,1406.48 1646.33,1406.49 1646.35,1406.49 1646.37,1406.49 1646.39,1406.49 1646.41,1406.49 1646.43,1406.49 1646.46,1406.49 1646.48,1406.49 1646.5,1406.49 1646.52,1406.49 1646.54,1406.49 1646.56,1406.49 1646.58,1406.49 1646.6,1406.49 1646.63,1406.49 1646.65,1406.49 1646.67,1406.49 1646.69,1406.49 1646.71,1406.49 1646.73,1406.49 1646.75,1406.49 1646.77,1406.49 1646.79,1406.49 1646.82,1406.49 1646.84,1406.49 1646.86,1406.49 1646.88,1406.49 1646.9,1406.49 1646.92,1406.5 1646.94,1406.5 1646.96,1406.5 1646.99,1406.5 1647.01,1406.5 1647.03,1406.5 1647.05,1406.5 1647.07,1406.5 1647.09,1406.5 1647.11,1406.5 1647.13,1406.5 1647.15,1406.5 1647.18,1406.5 1647.2,1406.5 1647.22,1406.5 1647.24,1406.5 1647.26,1406.5 1647.28,1406.5 1647.3,1406.5 1647.32,1406.5 1647.35,1406.5 1647.37,1406.5 1647.39,1406.5 1647.41,1406.5 1647.43,1406.5 1647.45,1406.5 1647.47,1406.5 1647.49,1406.5 1647.51,1406.51 1647.54,1406.51 1647.56,1406.51 1647.58,1406.51 1647.6,1406.51 1647.62,1406.51 1647.64,1406.51 1647.66,1406.51 1647.68,1406.51 1647.7,1406.51 1647.73,1406.51 1647.75,1406.51 1647.77,1406.51 1647.79,1406.51 1647.81,1406.51 1647.83,1406.51 1647.85,1406.51 1647.87,1406.51 1647.89,1406.51 1647.92,1406.51 1647.94,1406.51 1647.96,1406.51 1647.98,1406.51 1648,1406.51 1648.02,1406.51 1648.04,1406.51 1648.06,1406.51 1648.08,1406.51 1648.11,1406.52 1648.13,1406.52 1648.15,1406.52 1648.17,1406.52 1648.19,1406.52 1648.21,1406.52 1648.23,1406.52 1648.25,1406.52 1648.27,1406.52 1648.3,1406.52 1648.32,1406.52 1648.34,1406.52 1648.36,1406.52 1648.38,1406.52 1648.4,1406.52 1648.42,1406.52 1648.44,1406.52 1648.46,1406.52 1648.49,1406.52 1648.51,1406.52 1648.53,1406.52 1648.55,1406.52 1648.57,1406.52 1648.59,1406.52 1648.61,1406.52 1648.63,1406.52 1648.65,1406.52 1648.68,1406.52 1648.7,1406.52 1648.72,1406.53 1648.74,1406.53 1648.76,1406.53 1648.78,1406.53 1648.8,1406.53 1648.82,1406.53 1648.84,1406.53 1648.86,1406.53 1648.89,1406.53 1648.91,1406.53 1648.93,1406.53 1648.95,1406.53 1648.97,1406.53 1648.99,1406.53 1649.01,1406.53 1649.03,1406.53 1649.05,1406.53 1649.07,1406.53 1649.1,1406.53 1649.12,1406.53 1649.14,1406.53 1649.16,1406.53 1649.18,1406.53 1649.2,1406.53 1649.22,1406.53 1649.24,1406.53 1649.26,1406.53 1649.29,1406.53 1649.31,1406.53 1649.33,1406.54 1649.35,1406.54 1649.37,1406.54 1649.39,1406.54 1649.41,1406.54 1649.43,1406.54 1649.45,1406.54 1649.47,1406.54 1649.5,1406.54 1649.52,1406.54 1649.54,1406.54 1649.56,1406.54 1649.58,1406.54 1649.6,1406.54 1649.62,1406.54 1649.64,1406.54 1649.66,1406.54 1649.68,1406.54 1649.7,1406.54 1649.73,1406.54 1649.75,1406.54 1649.77,1406.54 1649.79,1406.54 1649.81,1406.54 1649.83,1406.54 1649.85,1406.54 1649.87,1406.54 1649.89,1406.54 1649.91,1406.54 1649.94,1406.54 1649.96,1406.55 1649.98,1406.55 1650,1406.55 1650.02,1406.55 1650.04,1406.55 1650.06,1406.55 1650.08,1406.55 1650.1,1406.55 1650.12,1406.55 1650.15,1406.55 1650.17,1406.55 1650.19,1406.55 1650.21,1406.55 1650.23,1406.55 1650.25,1406.55 1650.27,1406.55 1650.29,1406.55 1650.31,1406.55 1650.33,1406.55 1650.35,1406.55 1650.38,1406.55 1650.4,1406.55 1650.42,1406.55 1650.44,1406.55 1650.46,1406.55 1650.48,1406.55 1650.5,1406.55 1650.52,1406.55 1650.54,1406.55 1650.56,1406.55 1650.58,1406.56 1650.61,1406.56 1650.63,1406.56 1650.65,1406.56 1650.67,1406.56 1650.69,1406.56 1650.71,1406.56 1650.73,1406.56 1650.75,1406.56 1650.77,1406.56 1650.79,1406.56 1650.81,1406.56 1650.84,1406.56 1650.86,1406.56 1650.88,1406.56 1650.9,1406.56 1650.92,1406.56 1650.94,1406.56 1650.96,1406.56 1650.98,1406.56 1651,1406.56 1651.02,1406.56 1651.04,1406.56 1651.06,1406.56 1651.09,1406.56 1651.11,1406.56 1651.13,1406.56 1651.15,1406.56 1651.17,1406.56 1651.19,1406.56 1651.21,1406.56 1651.23,1406.57 1651.25,1406.57 1651.27,1406.57 1651.29,1406.57 1651.32,1406.57 1651.34,1406.57 1651.36,1406.57 1651.38,1406.57 1651.4,1406.57 1651.42,1406.57 1651.44,1406.57 1651.46,1406.57 1651.48,1406.57 1651.5,1406.57 1651.52,1406.57 1651.54,1406.57 1651.57,1406.57 1651.59,1406.57 1651.61,1406.57 1651.63,1406.57 1651.65,1406.57 1651.67,1406.57 1651.69,1406.57 1651.71,1406.57 1651.73,1406.57 1651.75,1406.57 1651.77,1406.57 1651.79,1406.57 1651.82,1406.57 1651.84,1406.57 1651.86,1406.57 1651.88,1406.57 1651.9,1406.58 1651.92,1406.58 1651.94,1406.58 1651.96,1406.58 1651.98,1406.58 1652,1406.58 1652.02,1406.58 1652.04,1406.58 1652.06,1406.58 1652.09,1406.58 1652.11,1406.58 1652.13,1406.58 1652.15,1406.58 1652.17,1406.58 1652.19,1406.58 1652.21,1406.58 1652.23,1406.58 1652.25,1406.58 1652.27,1406.58 1652.29,1406.58 1652.31,1406.58 1652.33,1406.58 1652.36,1406.58 1652.38,1406.58 1652.4,1406.58 1652.42,1406.58 1652.44,1406.58 1652.46,1406.58 1652.48,1406.58 1652.5,1406.58 1652.52,1406.58 1652.54,1406.58 1652.56,1406.58 1652.58,1406.59 1652.6,1406.59 1652.63,1406.59 1652.65,1406.59 1652.67,1406.59 1652.69,1406.59 1652.71,1406.59 1652.73,1406.59 1652.75,1406.59 1652.77,1406.59 1652.79,1406.59 1652.81,1406.59 1652.83,1406.59 1652.85,1406.59 1652.87,1406.59 1652.89,1406.59 1652.92,1406.59 1652.94,1406.59 1652.96,1406.59 1652.98,1406.59 1653,1406.59 1653.02,1406.59 1653.04,1406.59 1653.06,1406.59 1653.08,1406.59 1653.1,1406.59 1653.12,1406.59 1653.14,1406.59 1653.16,1406.59 1653.18,1406.59 1653.21,1406.59 1653.23,1406.59 1653.25,1406.59 1653.27,1406.6 1653.29,1406.6 1653.31,1406.6 1653.33,1406.6 1653.35,1406.6 1653.37,1406.6 1653.39,1406.6 1653.41,1406.6 1653.43,1406.6 1653.45,1406.6 1653.47,1406.6 1653.5,1406.6 1653.52,1406.6 1653.54,1406.6 1653.56,1406.6 1653.58,1406.6 1653.6,1406.6 1653.62,1406.6 1653.64,1406.6 1653.66,1406.6 1653.68,1406.6 1653.7,1406.6 1653.72,1406.6 1653.74,1406.6 1653.76,1406.6 1653.78,1406.6 1653.8,1406.6 1653.83,1406.6 1653.85,1406.6 1653.87,1406.6 1653.89,1406.6 1653.91,1406.6 1653.93,1406.6 1653.95,1406.61 1653.97,1406.61 1653.99,1406.61 1654.01,1406.61 1654.03,1406.61 1654.05,1406.61 1654.07,1406.61 1654.09,1406.61 1654.11,1406.61 1654.14,1406.61 1654.16,1406.61 1654.18,1406.61 1654.2,1406.61 1654.22,1406.61 1654.24,1406.61 1654.26,1406.61 1654.28,1406.61 1654.3,1406.61 1654.32,1406.61 1654.34,1406.61 1654.36,1406.61 1654.38,1406.61 1654.4,1406.61 1654.42,1406.61 1654.44,1406.61 1654.46,1406.61 1654.49,1406.61 1654.51,1406.61 1654.53,1406.61 1654.55,1406.61 1654.57,1406.61 1654.59,1406.61 1654.61,1406.61 1654.63,1406.61 1654.65,1406.61 1654.67,1406.62 1654.69,1406.62 1654.71,1406.62 1654.73,1406.62 1654.75,1406.62 1654.77,1406.62 1654.79,1406.62 1654.81,1406.62 1654.84,1406.62 1654.86,1406.62 1654.88,1406.62 1654.9,1406.62 1654.92,1406.62 1654.94,1406.62 1654.96,1406.62 1654.98,1406.62 1655,1406.62 1655.02,1406.62 1655.04,1406.62 1655.06,1406.62 1655.08,1406.62 1655.1,1406.62 1655.12,1406.62 1655.14,1406.62 1655.16,1406.62 1655.18,1406.62 1655.21,1406.62 1655.23,1406.62 1655.25,1406.62 1655.27,1406.62 1655.29,1406.62 1655.31,1406.62 1655.33,1406.62 1655.35,1406.62 1655.37,1406.62 1655.39,1406.63 1655.41,1406.63 1655.43,1406.63 1655.45,1406.63 1655.47,1406.63 1655.49,1406.63 1655.51,1406.63 1655.53,1406.63 1655.55,1406.63 1655.57,1406.63 1655.59,1406.63 1655.62,1406.63 1655.64,1406.63 1655.66,1406.63 1655.68,1406.63 1655.7,1406.63 1655.72,1406.63 1655.74,1406.63 1655.76,1406.63 1655.78,1406.63 1655.8,1406.63 1655.82,1406.63 1655.84,1406.63 1655.86,1406.63 1655.88,1406.63 1655.9,1406.63 1655.92,1406.63 1655.94,1406.63 1655.96,1406.63 1655.98,1406.63 1656,1406.63 1656.03,1406.63 1656.05,1406.63 1656.07,1406.63 1656.09,1406.63 1656.11,1406.63 1656.13,1406.63 1656.15,1406.64 1656.17,1406.64 1656.19,1406.64 1656.21,1406.64 1656.23,1406.64 1656.25,1406.64 1656.27,1406.64 1656.29,1406.64 1656.31,1406.64 1656.33,1406.64 1656.35,1406.64 1656.37,1406.64 1656.39,1406.64 1656.41,1406.64 1656.43,1406.64 1656.45,1406.64 1656.48,1406.64 1656.5,1406.64 1656.52,1406.64 1656.54,1406.64 1656.56,1406.64 1656.58,1406.64 1656.6,1406.64 1656.62,1406.64 1656.64,1406.64 1656.66,1406.64 1656.68,1406.64 1656.7,1406.64 1656.72,1406.64 1656.74,1406.64 1656.76,1406.64 1656.78,1406.64 1656.8,1406.64 1656.82,1406.64 1656.84,1406.64 1656.86,1406.64 1656.88,1406.64 1656.9,1406.65 1656.92,1406.65 1656.94,1406.65 1656.96,1406.65 1656.99,1406.65 1657.01,1406.65 1657.03,1406.65 1657.05,1406.65 1657.07,1406.65 1657.09,1406.65 1657.11,1406.65 1657.13,1406.65 1657.15,1406.65 1657.17,1406.65 1657.19,1406.65 1657.21,1406.65 1657.23,1406.65 1657.25,1406.65 1657.27,1406.65 1657.29,1406.65 1657.31,1406.65 1657.33,1406.65 1657.35,1406.65 1657.37,1406.65 1657.39,1406.65 1657.41,1406.65 1657.43,1406.65 1657.45,1406.65 1657.47,1406.65 1657.49,1406.65 1657.51,1406.65 1657.54,1406.65 1657.56,1406.65 1657.58,1406.65 1657.6,1406.65 1657.62,1406.65 1657.64,1406.65 1657.66,1406.65 1657.68,1406.66 1657.7,1406.66 1657.72,1406.66 1657.74,1406.66 1657.76,1406.66 1657.78,1406.66 1657.8,1406.66 1657.82,1406.66 1657.84,1406.66 1657.86,1406.66 1657.88,1406.66 1657.9,1406.66 1657.92,1406.66 1657.94,1406.66 1657.96,1406.66 1657.98,1406.66 1658,1406.66 1658.02,1406.66 1658.04,1406.66 1658.06,1406.66 1658.08,1406.66 1658.1,1406.66 1658.12,1406.66 1658.14,1406.66 1658.16,1406.66 1658.19,1406.66 1658.21,1406.66 1658.23,1406.66 1658.25,1406.66 1658.27,1406.66 1658.29,1406.66 1658.31,1406.66 1658.33,1406.66 1658.35,1406.66 1658.37,1406.66 1658.39,1406.66 1658.41,1406.66 1658.43,1406.66 1658.45,1406.66 1658.47,1406.66 1658.49,1406.67 1658.51,1406.67 1658.53,1406.67 1658.55,1406.67 1658.57,1406.67 1658.59,1406.67 1658.61,1406.67 1658.63,1406.67 1658.65,1406.67 1658.67,1406.67 1658.69,1406.67 1658.71,1406.67 1658.73,1406.67 1658.75,1406.67 1658.77,1406.67 1658.79,1406.67 1658.81,1406.67 1658.83,1406.67 1658.85,1406.67 1658.87,1406.67 1658.89,1406.67 1658.91,1406.67 1658.93,1406.67 1658.95,1406.67 1658.98,1406.67 1659,1406.67 1659.02,1406.67 1659.04,1406.67 1659.06,1406.67 1659.08,1406.67 1659.1,1406.67 1659.12,1406.67 1659.14,1406.67 1659.16,1406.67 1659.18,1406.67 1659.2,1406.67 1659.22,1406.67 1659.24,1406.67 1659.26,1406.67 1659.28,1406.67 1659.3,1406.68 1659.32,1406.68 1659.34,1406.68 1659.36,1406.68 1659.38,1406.68 1659.4,1406.68 1659.42,1406.68 1659.44,1406.68 1659.46,1406.68 1659.48,1406.68 1659.5,1406.68 1659.52,1406.68 1659.54,1406.68 1659.56,1406.68 1659.58,1406.68 1659.6,1406.68 1659.62,1406.68 1659.64,1406.68 1659.66,1406.68 1659.68,1406.68 1659.7,1406.68 1659.72,1406.68 1659.74,1406.68 1659.76,1406.68 1659.78,1406.68 1659.8,1406.68 1659.82,1406.68 1659.84,1406.68 1659.86,1406.68 1659.88,1406.68 1659.9,1406.68 1659.92,1406.68 1659.94,1406.68 1659.96,1406.68 1659.98,1406.68 1660,1406.68 1660.02,1406.68 1660.04,1406.68 1660.06,1406.68 1660.08,1406.68 1660.1,1406.68 1660.13,1406.68 1660.15,1406.69 1660.17,1406.69 1660.19,1406.69 1660.21,1406.69 1660.23,1406.69 1660.25,1406.69 1660.27,1406.69 1660.29,1406.69 1660.31,1406.69 1660.33,1406.69 1660.35,1406.69 1660.37,1406.69 1660.39,1406.69 1660.41,1406.69 1660.43,1406.69 1660.45,1406.69 1660.47,1406.69 1660.49,1406.69 1660.51,1406.69 1660.53,1406.69 1660.55,1406.69 1660.57,1406.69 1660.59,1406.69 1660.61,1406.69 1660.63,1406.69 1660.65,1406.69 1660.67,1406.69 1660.69,1406.69 1660.71,1406.69 1660.73,1406.69 1660.75,1406.69 1660.77,1406.69 1660.79,1406.69 1660.81,1406.69 1660.83,1406.69 1660.85,1406.69 1660.87,1406.69 1660.89,1406.69 1660.91,1406.69 1660.93,1406.69 1660.95,1406.69 1660.97,1406.69 1660.99,1406.69 1661.01,1406.7 1661.03,1406.7 1661.05,1406.7 1661.07,1406.7 1661.09,1406.7 1661.11,1406.7 1661.13,1406.7 1661.15,1406.7 1661.17,1406.7 1661.19,1406.7 1661.21,1406.7 1661.23,1406.7 1661.25,1406.7 1661.27,1406.7 1661.29,1406.7 1661.31,1406.7 1661.33,1406.7 1661.35,1406.7 1661.37,1406.7 1661.39,1406.7 1661.41,1406.7 1661.43,1406.7 1661.45,1406.7 1661.47,1406.7 1661.49,1406.7 1661.51,1406.7 1661.53,1406.7 1661.55,1406.7 1661.57,1406.7 1661.59,1406.7 1661.61,1406.7 1661.63,1406.7 1661.65,1406.7 1661.67,1406.7 1661.69,1406.7 1661.71,1406.7 1661.73,1406.7 1661.75,1406.7 1661.77,1406.7 1661.79,1406.7 1661.81,1406.7 1661.83,1406.7 1661.85,1406.7 1661.87,1406.7 1661.89,1406.7 1661.91,1406.71 1661.93,1406.71 1661.95,1406.71 1661.97,1406.71 1661.99,1406.71 1662.01,1406.71 1662.03,1406.71 1662.05,1406.71 1662.07,1406.71 1662.09,1406.71 1662.11,1406.71 1662.13,1406.71 1662.15,1406.71 1662.17,1406.71 1662.19,1406.71 1662.21,1406.71 1662.23,1406.71 1662.25,1406.71 1662.27,1406.71 1662.29,1406.71 1662.31,1406.71 1662.33,1406.71 1662.35,1406.71 1662.37,1406.71 1662.39,1406.71 1662.41,1406.71 1662.43,1406.71 1662.45,1406.71 1662.47,1406.71 1662.49,1406.71 1662.51,1406.71 1662.53,1406.71 1662.55,1406.71 1662.57,1406.71 1662.59,1406.71 1662.61,1406.71 1662.63,1406.71 1662.65,1406.71 1662.67,1406.71 1662.69,1406.71 1662.71,1406.71 1662.73,1406.71 1662.75,1406.71 1662.77,1406.71 1662.79,1406.71 1662.81,1406.71 1662.83,1406.72 1662.85,1406.72 1662.87,1406.72 1662.89,1406.72 1662.91,1406.72 1662.93,1406.72 1662.95,1406.72 1662.97,1406.72 1662.99,1406.72 1663.01,1406.72 1663.03,1406.72 1663.05,1406.72 1663.07,1406.72 1663.08,1406.72 1663.1,1406.72 1663.12,1406.72 1663.14,1406.72 1663.16,1406.72 1663.18,1406.72 1663.2,1406.72 1663.22,1406.72 1663.24,1406.72 1663.26,1406.72 1663.28,1406.72 1663.3,1406.72 1663.32,1406.72 1663.34,1406.72 1663.36,1406.72 1663.38,1406.72 1663.4,1406.72 1663.42,1406.72 1663.44,1406.72 1663.46,1406.72 1663.48,1406.72 1663.5,1406.72 1663.52,1406.72 1663.54,1406.72 1663.56,1406.72 1663.58,1406.72 1663.6,1406.72 1663.62,1406.72 1663.64,1406.72 1663.66,1406.72 1663.68,1406.72 1663.7,1406.72 1663.72,1406.72 1663.74,1406.72 1663.76,1406.72 1663.78,1406.73 1663.8,1406.73 1663.82,1406.73 1663.84,1406.73 1663.86,1406.73 1663.88,1406.73 1663.9,1406.73 1663.92,1406.73 1663.94,1406.73 1663.96,1406.73 1663.98,1406.73 1664,1406.73 1664.02,1406.73 1664.04,1406.73 1664.06,1406.73 1664.08,1406.73 1664.1,1406.73 1664.12,1406.73 1664.14,1406.73 1664.16,1406.73 1664.18,1406.73 1664.2,1406.73 1664.21,1406.73 1664.23,1406.73 1664.25,1406.73 1664.27,1406.73 1664.29,1406.73 1664.31,1406.73 1664.33,1406.73 1664.35,1406.73 1664.37,1406.73 1664.39,1406.73 1664.41,1406.73 1664.43,1406.73 1664.45,1406.73 1664.47,1406.73 1664.49,1406.73 1664.51,1406.73 1664.53,1406.73 1664.55,1406.73 1664.57,1406.73 1664.59,1406.73 1664.61,1406.73 1664.63,1406.73 1664.65,1406.73 1664.67,1406.73 1664.69,1406.73 1664.71,1406.73 1664.73,1406.73 1664.75,1406.73 1664.77,1406.74 1664.79,1406.74 1664.81,1406.74 1664.83,1406.74 1664.85,1406.74 1664.87,1406.74 1664.89,1406.74 1664.91,1406.74 1664.93,1406.74 1664.95,1406.74 1664.97,1406.74 1664.98,1406.74 1665,1406.74 1665.02,1406.74 1665.04,1406.74 1665.06,1406.74 1665.08,1406.74 1665.1,1406.74 1665.12,1406.74 1665.14,1406.74 1665.16,1406.74 1665.18,1406.74 1665.2,1406.74 1665.22,1406.74 1665.24,1406.74 1665.26,1406.74 1665.28,1406.74 1665.3,1406.74 1665.32,1406.74 1665.34,1406.74 1665.36,1406.74 1665.38,1406.74 1665.4,1406.74 1665.42,1406.74 1665.44,1406.74 1665.46,1406.74 1665.48,1406.74 1665.5,1406.74 1665.52,1406.74 1665.54,1406.74 1665.56,1406.74 1665.58,1406.74 1665.59,1406.74 1665.61,1406.74 1665.63,1406.74 1665.65,1406.74 1665.67,1406.74 1665.69,1406.74 1665.71,1406.74 1665.73,1406.74 1665.75,1406.74 1665.77,1406.74 1665.79,1406.75 1665.81,1406.75 1665.83,1406.75 1665.85,1406.75 1665.87,1406.75 1665.89,1406.75 1665.91,1406.75 1665.93,1406.75 1665.95,1406.75 1665.97,1406.75 1665.99,1406.75 1666.01,1406.75 1666.03,1406.75 1666.05,1406.75 1666.07,1406.75 1666.09,1406.75 1666.11,1406.75 1666.12,1406.75 1666.14,1406.75 1666.16,1406.75 1666.18,1406.75 1666.2,1406.75 1666.22,1406.75 1666.24,1406.75 1666.26,1406.75 1666.28,1406.75 1666.3,1406.75 1666.32,1406.75 1666.34,1406.75 1666.36,1406.75 1666.38,1406.75 1666.4,1406.75 1666.42,1406.75 1666.44,1406.75 1666.46,1406.75 1666.48,1406.75 1666.5,1406.75 1666.52,1406.75 1666.54,1406.75 1666.56,1406.75 1666.58,1406.75 1666.6,1406.75 1666.61,1406.75 1666.63,1406.75 1666.65,1406.75 1666.67,1406.75 1666.69,1406.75 1666.71,1406.75 1666.73,1406.75 1666.75,1406.75 1666.77,1406.75 1666.79,1406.75 1666.81,1406.75 1666.83,1406.75 1666.85,1406.76 1666.87,1406.76 1666.89,1406.76 1666.91,1406.76 1666.93,1406.76 1666.95,1406.76 1666.97,1406.76 1666.99,1406.76 1667.01,1406.76 1667.03,1406.76 1667.04,1406.76 1667.06,1406.76 1667.08,1406.76 1667.1,1406.76 1667.12,1406.76 1667.14,1406.76 1667.16,1406.76 1667.18,1406.76 1667.2,1406.76 1667.22,1406.76 1667.24,1406.76 1667.26,1406.76 1667.28,1406.76 1667.3,1406.76 1667.32,1406.76 1667.34,1406.76 1667.36,1406.76 1667.38,1406.76 1667.4,1406.76 1667.42,1406.76 1667.43,1406.76 1667.45,1406.76 1667.47,1406.76 1667.49,1406.76 1667.51,1406.76 1667.53,1406.76 1667.55,1406.76 1667.57,1406.76 1667.59,1406.76 1667.61,1406.76 1667.63,1406.76 1667.65,1406.76 1667.67,1406.76 1667.69,1406.76 1667.71,1406.76 1667.73,1406.76 1667.75,1406.76 1667.77,1406.76 1667.79,1406.76 1667.8,1406.76 1667.82,1406.76 1667.84,1406.76 1667.86,1406.76 1667.88,1406.76 1667.9,1406.76 1667.92,1406.76 1667.94,1406.76 1667.96,1406.77 1667.98,1406.77 1668,1406.77 1668.02,1406.77 1668.04,1406.77 1668.06,1406.77 1668.08,1406.77 1668.1,1406.77 1668.12,1406.77 1668.14,1406.77 1668.15,1406.77 1668.17,1406.77 1668.19,1406.77 1668.21,1406.77 1668.23,1406.77 1668.25,1406.77 1668.27,1406.77 1668.29,1406.77 1668.31,1406.77 1668.33,1406.77 1668.35,1406.77 1668.37,1406.77 1668.39,1406.77 1668.41,1406.77 1668.43,1406.77 1668.45,1406.77 1668.47,1406.77 1668.49,1406.77 1668.5,1406.77 1668.52,1406.77 1668.54,1406.77 1668.56,1406.77 1668.58,1406.77 1668.6,1406.77 1668.62,1406.77 1668.64,1406.77 1668.66,1406.77 1668.68,1406.77 1668.7,1406.77 1668.72,1406.77 1668.74,1406.77 1668.76,1406.77 1668.78,1406.77 1668.8,1406.77 1668.81,1406.77 1668.83,1406.77 1668.85,1406.77 1668.87,1406.77 1668.89,1406.77 1668.91,1406.77 1668.93,1406.77 1668.95,1406.77 1668.97,1406.77 1668.99,1406.77 1669.01,1406.77 1669.03,1406.77 1669.05,1406.77 1669.07,1406.77 1669.09,1406.77 1669.1,1406.77 1669.12,1406.78 1669.14,1406.78 1669.16,1406.78 1669.18,1406.78 1669.2,1406.78 1669.22,1406.78 1669.24,1406.78 1669.26,1406.78 1669.28,1406.78 1669.3,1406.78 1669.32,1406.78 1669.34,1406.78 1669.36,1406.78 1669.38,1406.78 1669.39,1406.78 1669.41,1406.78 1669.43,1406.78 1669.45,1406.78 1669.47,1406.78 1669.49,1406.78 1669.51,1406.78 1669.53,1406.78 1669.55,1406.78 1669.57,1406.78 1669.59,1406.78 1669.61,1406.78 1669.63,1406.78 1669.65,1406.78 1669.67,1406.78 1669.68,1406.78 1669.7,1406.78 1669.72,1406.78 1669.74,1406.78 1669.76,1406.78 1669.78,1406.78 1669.8,1406.78 1669.82,1406.78 1669.84,1406.78 1669.86,1406.78 1669.88,1406.78 1669.9,1406.78 1669.92,1406.78 1669.94,1406.78 1669.95,1406.78 1669.97,1406.78 1669.99,1406.78 1670.01,1406.78 1670.03,1406.78 1670.05,1406.78 1670.07,1406.78 1670.09,1406.78 1670.11,1406.78 1670.13,1406.78 1670.15,1406.78 1670.17,1406.78 1670.19,1406.78 1670.2,1406.78 1670.22,1406.78 1670.24,1406.78 1670.26,1406.78 1670.28,1406.78 1670.3,1406.78 1670.32,1406.78 1670.34,1406.79 1670.36,1406.79 1670.38,1406.79 1670.4,1406.79 1670.42,1406.79 1670.44,1406.79 1670.45,1406.79 1670.47,1406.79 1670.49,1406.79 1670.51,1406.79 1670.53,1406.79 1670.55,1406.79 1670.57,1406.79 1670.59,1406.79 1670.61,1406.79 1670.63,1406.79 1670.65,1406.79 1670.67,1406.79 1670.69,1406.79 1670.7,1406.79 1670.72,1406.79 1670.74,1406.79 1670.76,1406.79 1670.78,1406.79 1670.8,1406.79 1670.82,1406.79 1670.84,1406.79 1670.86,1406.79 1670.88,1406.79 1670.9,1406.79 1670.92,1406.79 1670.94,1406.79 1670.95,1406.79 1670.97,1406.79 1670.99,1406.79 1671.01,1406.79 1671.03,1406.79 1671.05,1406.79 1671.07,1406.79 1671.09,1406.79 1671.11,1406.79 1671.13,1406.79 1671.15,1406.79 1671.17,1406.79 1671.18,1406.79 1671.2,1406.79 1671.22,1406.79 1671.24,1406.79 1671.26,1406.79 1671.28,1406.79 1671.3,1406.79 1671.32,1406.79 1671.34,1406.79 1671.36,1406.79 1671.38,1406.79 1671.39,1406.79 1671.41,1406.79 1671.43,1406.79 1671.45,1406.79 1671.47,1406.79 1671.49,1406.79 1671.51,1406.79 1671.53,1406.79 1671.55,1406.79 1671.57,1406.79 1671.59,1406.79 1671.61,1406.79 1671.62,1406.79 1671.64,1406.8 1671.66,1406.8 1671.68,1406.8 1671.7,1406.8 1671.72,1406.8 1671.74,1406.8 1671.76,1406.8 1671.78,1406.8 1671.8,1406.8 1671.82,1406.8 1671.83,1406.8 1671.85,1406.8 1671.87,1406.8 1671.89,1406.8 1671.91,1406.8 1671.93,1406.8 1671.95,1406.8 1671.97,1406.8 1671.99,1406.8 1672.01,1406.8 1672.03,1406.8 1672.04,1406.8 1672.06,1406.8 1672.08,1406.8 1672.1,1406.8 1672.12,1406.8 1672.14,1406.8 1672.16,1406.8 1672.18,1406.8 1672.2,1406.8 1672.22,1406.8 1672.24,1406.8 1672.25,1406.8 1672.27,1406.8 1672.29,1406.8 1672.31,1406.8 1672.33,1406.8 1672.35,1406.8 1672.37,1406.8 1672.39,1406.8 1672.41,1406.8 1672.43,1406.8 1672.45,1406.8 1672.46,1406.8 1672.48,1406.8 1672.5,1406.8 1672.52,1406.8 1672.54,1406.8 1672.56,1406.8 1672.58,1406.8 1672.6,1406.8 1672.62,1406.8 1672.64,1406.8 1672.65,1406.8 1672.67,1406.8 1672.69,1406.8 1672.71,1406.8 1672.73,1406.8 1672.75,1406.8 1672.77,1406.8 1672.79,1406.8 1672.81,1406.8 1672.83,1406.8 1672.84,1406.8 1672.86,1406.8 1672.88,1406.8 1672.9,1406.8 1672.92,1406.8 1672.94,1406.8 1672.96,1406.8 1672.98,1406.8 1673,1406.8 1673.02,1406.8 1673.03,1406.81 1673.05,1406.81 1673.07,1406.81 1673.09,1406.81 1673.11,1406.81 1673.13,1406.81 1673.15,1406.81 1673.17,1406.81 1673.19,1406.81 1673.21,1406.81 1673.22,1406.81 1673.24,1406.81 1673.26,1406.81 1673.28,1406.81 1673.3,1406.81 1673.32,1406.81 1673.34,1406.81 1673.36,1406.81 1673.38,1406.81 1673.4,1406.81 1673.41,1406.81 1673.43,1406.81 1673.45,1406.81 1673.47,1406.81 1673.49,1406.81 1673.51,1406.81 1673.53,1406.81 1673.55,1406.81 1673.57,1406.81 1673.58,1406.81 1673.6,1406.81 1673.62,1406.81 1673.64,1406.81 1673.66,1406.81 1673.68,1406.81 1673.7,1406.81 1673.72,1406.81 1673.74,1406.81 1673.76,1406.81 1673.77,1406.81 1673.79,1406.81 1673.81,1406.81 1673.83,1406.81 1673.85,1406.81 1673.87,1406.81 1673.89,1406.81 1673.91,1406.81 1673.93,1406.81 1673.94,1406.81 1673.96,1406.81 1673.98,1406.81 1674,1406.81 1674.02,1406.81 1674.04,1406.81 1674.06,1406.81 1674.08,1406.81 1674.1,1406.81 1674.11,1406.81 1674.13,1406.81 1674.15,1406.81 1674.17,1406.81 1674.19,1406.81 1674.21,1406.81 1674.23,1406.81 1674.25,1406.81 1674.27,1406.81 1674.28,1406.81 1674.3,1406.81 1674.32,1406.81 1674.34,1406.81 1674.36,1406.81 1674.38,1406.81 1674.4,1406.81 1674.42,1406.81 1674.44,1406.81 1674.45,1406.81 1674.47,1406.81 1674.49,1406.81 1674.51,1406.82 1674.53,1406.82 1674.55,1406.82 1674.57,1406.82 1674.59,1406.82 1674.61,1406.82 1674.62,1406.82 1674.64,1406.82 1674.66,1406.82 1674.68,1406.82 1674.7,1406.82 1674.72,1406.82 1674.74,1406.82 1674.76,1406.82 1674.77,1406.82 1674.79,1406.82 1674.81,1406.82 1674.83,1406.82 1674.85,1406.82 1674.87,1406.82 1674.89,1406.82 1674.91,1406.82 1674.93,1406.82 1674.94,1406.82 1674.96,1406.82 1674.98,1406.82 1675,1406.82 1675.02,1406.82 1675.04,1406.82 1675.06,1406.82 1675.08,1406.82 1675.09,1406.82 1675.11,1406.82 1675.13,1406.82 1675.15,1406.82 1675.17,1406.82 1675.19,1406.82 1675.21,1406.82 1675.23,1406.82 1675.24,1406.82 1675.26,1406.82 1675.28,1406.82 1675.3,1406.82 1675.32,1406.82 1675.34,1406.82 1675.36,1406.82 1675.38,1406.82 1675.4,1406.82 1675.41,1406.82 1675.43,1406.82 1675.45,1406.82 1675.47,1406.82 1675.49,1406.82 1675.51,1406.82 1675.53,1406.82 1675.55,1406.82 1675.56,1406.82 1675.58,1406.82 1675.6,1406.82 1675.62,1406.82 1675.64,1406.82 1675.66,1406.82 1675.68,1406.82 1675.7,1406.82 1675.71,1406.82 1675.73,1406.82 1675.75,1406.82 1675.77,1406.82 1675.79,1406.82 1675.81,1406.82 1675.83,1406.82 1675.85,1406.82 1675.86,1406.82 1675.88,1406.82 1675.9,1406.82 1675.92,1406.82 1675.94,1406.82 1675.96,1406.82 1675.98,1406.82 1676,1406.82 1676.01,1406.82 1676.03,1406.82 1676.05,1406.82 1676.07,1406.82 1676.09,1406.82 1676.11,1406.83 1676.13,1406.83 1676.14,1406.83 1676.16,1406.83 1676.18,1406.83 1676.2,1406.83 1676.22,1406.83 1676.24,1406.83 1676.26,1406.83 1676.28,1406.83 1676.29,1406.83 1676.31,1406.83 1676.33,1406.83 1676.35,1406.83 1676.37,1406.83 1676.39,1406.83 1676.41,1406.83 1676.43,1406.83 1676.44,1406.83 1676.46,1406.83 1676.48,1406.83 1676.5,1406.83 1676.52,1406.83 1676.54,1406.83 1676.56,1406.83 1676.57,1406.83 1676.59,1406.83 1676.61,1406.83 1676.63,1406.83 1676.65,1406.83 1676.67,1406.83 1676.69,1406.83 1676.71,1406.83 1676.72,1406.83 1676.74,1406.83 1676.76,1406.83 1676.78,1406.83 1676.8,1406.83 1676.82,1406.83 1676.84,1406.83 1676.85,1406.83 1676.87,1406.83 1676.89,1406.83 1676.91,1406.83 1676.93,1406.83 1676.95,1406.83 1676.97,1406.83 1676.98,1406.83 1677,1406.83 1677.02,1406.83 1677.04,1406.83 1677.06,1406.83 1677.08,1406.83 1677.1,1406.83 1677.12,1406.83 1677.13,1406.83 1677.15,1406.83 1677.17,1406.83 1677.19,1406.83 1677.21,1406.83 1677.23,1406.83 1677.25,1406.83 1677.26,1406.83 1677.28,1406.83 1677.3,1406.83 1677.32,1406.83 1677.34,1406.83 1677.36,1406.83 1677.38,1406.83 1677.39,1406.83 1677.41,1406.83 1677.43,1406.83 1677.45,1406.83 1677.47,1406.83 1677.49,1406.83 1677.51,1406.83 1677.52,1406.83 1677.54,1406.83 1677.56,1406.83 1677.58,1406.83 1677.6,1406.83 1677.62,1406.83 1677.64,1406.83 1677.65,1406.83 1677.67,1406.83 1677.69,1406.83 1677.71,1406.83 1677.73,1406.83 1677.75,1406.83 1677.77,1406.83 1677.78,1406.83 1677.8,1406.83 1677.82,1406.83 1677.84,1406.83 1677.86,1406.83 1677.88,1406.84 1677.9,1406.84 1677.91,1406.84 1677.93,1406.84 1677.95,1406.84 1677.97,1406.84 1677.99,1406.84 1678.01,1406.84 1678.03,1406.84 1678.04,1406.84 1678.06,1406.84 1678.08,1406.84 1678.1,1406.84 1678.12,1406.84 1678.14,1406.84 1678.16,1406.84 1678.17,1406.84 1678.19,1406.84 1678.21,1406.84 1678.23,1406.84 1678.25,1406.84 1678.27,1406.84 1678.28,1406.84 1678.3,1406.84 1678.32,1406.84 1678.34,1406.84 1678.36,1406.84 1678.38,1406.84 1678.4,1406.84 1678.41,1406.84 1678.43,1406.84 1678.45,1406.84 1678.47,1406.84 1678.49,1406.84 1678.51,1406.84 1678.53,1406.84 1678.54,1406.84 1678.56,1406.84 1678.58,1406.84 1678.6,1406.84 1678.62,1406.84 1678.64,1406.84 1678.65,1406.84 1678.67,1406.84 1678.69,1406.84 1678.71,1406.84 1678.73,1406.84 1678.75,1406.84 1678.77,1406.84 1678.78,1406.84 1678.8,1406.84 1678.82,1406.84 1678.84,1406.84 1678.86,1406.84 1678.88,1406.84 1678.89,1406.84 1678.91,1406.84 1678.93,1406.84 1678.95,1406.84 1678.97,1406.84 1678.99,1406.84 1679.01,1406.84 1679.02,1406.84 1679.04,1406.84 1679.06,1406.84 1679.08,1406.84 1679.1,1406.84 1679.12,1406.84 1679.13,1406.84 1679.15,1406.84 1679.17,1406.84 1679.19,1406.84 1679.21,1406.84 1679.23,1406.84 1679.25,1406.84 1679.26,1406.84 1679.28,1406.84 1679.3,1406.84 1679.32,1406.84 1679.34,1406.84 1679.36,1406.84 1679.37,1406.84 1679.39,1406.84 1679.41,1406.84 1679.43,1406.84 1679.45,1406.84 1679.47,1406.84 1679.48,1406.84 1679.5,1406.84 1679.52,1406.84 1679.54,1406.84 1679.56,1406.84 1679.58,1406.84 1679.59,1406.84 1679.61,1406.84 1679.63,1406.84 1679.65,1406.84 1679.67,1406.84 1679.69,1406.84 1679.7,1406.84 1679.72,1406.84 1679.74,1406.84 1679.76,1406.84 1679.78,1406.84 1679.8,1406.84 1679.82,1406.84 1679.83,1406.84 1679.85,1406.84 1679.87,1406.85 1679.89,1406.85 1679.91,1406.85 1679.93,1406.85 1679.94,1406.85 1679.96,1406.85 1679.98,1406.85 1680,1406.85 1680.02,1406.85 1680.04,1406.85 1680.05,1406.85 1680.07,1406.85 1680.09,1406.85 1680.11,1406.85 1680.13,1406.85 1680.15,1406.85 1680.16,1406.85 1680.18,1406.85 1680.2,1406.85 1680.22,1406.85 1680.24,1406.85 1680.26,1406.85 1680.27,1406.85 1680.29,1406.85 1680.31,1406.85 1680.33,1406.85 1680.35,1406.85 1680.37,1406.85 1680.38,1406.85 1680.4,1406.85 1680.42,1406.85 1680.44,1406.85 1680.46,1406.85 1680.48,1406.85 1680.49,1406.85 1680.51,1406.85 1680.53,1406.85 1680.55,1406.85 1680.57,1406.85 1680.59,1406.85 1680.6,1406.85 1680.62,1406.85 1680.64,1406.85 1680.66,1406.85 1680.68,1406.85 1680.69,1406.85 1680.71,1406.85 1680.73,1406.85 1680.75,1406.85 1680.77,1406.85 1680.79,1406.85 1680.8,1406.85 1680.82,1406.85 1680.84,1406.85 1680.86,1406.85 1680.88,1406.85 1680.9,1406.85 1680.91,1406.85 1680.93,1406.85 1680.95,1406.85 1680.97,1406.85 1680.99,1406.85 1681.01,1406.85 1681.02,1406.85 1681.04,1406.85 1681.06,1406.85 1681.08,1406.85 1681.1,1406.85 1681.11,1406.85 1681.13,1406.85 1681.15,1406.85 1681.17,1406.85 1681.19,1406.85 1681.21,1406.85 1681.22,1406.85 1681.24,1406.85 1681.26,1406.85 1681.28,1406.85 1681.3,1406.85 1681.32,1406.85 1681.33,1406.85 1681.35,1406.85 1681.37,1406.85 1681.39,1406.85 1681.41,1406.85 1681.42,1406.85 1681.44,1406.85 1681.46,1406.85 1681.48,1406.85 1681.5,1406.85 1681.52,1406.85 1681.53,1406.85 1681.55,1406.85 1681.57,1406.85 1681.59,1406.85 1681.61,1406.85 1681.63,1406.85 1681.64,1406.85 1681.66,1406.85 1681.68,1406.85 1681.7,1406.85 1681.72,1406.85 1681.73,1406.85 1681.75,1406.85 1681.77,1406.85 1681.79,1406.85 1681.81,1406.85 1681.83,1406.85 1681.84,1406.85 1681.86,1406.85 1681.88,1406.85 1681.9,1406.85 1681.92,1406.85 1681.93,1406.85 1681.95,1406.85 1681.97,1406.85 1681.99,1406.85 1682.01,1406.85 1682.02,1406.85 1682.04,1406.85 1682.06,1406.85 1682.08,1406.85 1682.1,1406.85 1682.12,1406.85 1682.13,1406.85 1682.15,1406.85 1682.17,1406.85 1682.19,1406.86 1682.21,1406.86 1682.22,1406.86 1682.24,1406.86 1682.26,1406.86 1682.28,1406.86 1682.3,1406.86 1682.32,1406.86 1682.33,1406.86 1682.35,1406.86 1682.37,1406.86 1682.39,1406.86 1682.41,1406.86 1682.42,1406.86 1682.44,1406.86 1682.46,1406.86 1682.48,1406.86 1682.5,1406.86 1682.51,1406.86 1682.53,1406.86 1682.55,1406.86 1682.57,1406.86 1682.59,1406.86 1682.61,1406.86 1682.62,1406.86 1682.64,1406.86 1682.66,1406.86 1682.68,1406.86 1682.7,1406.86 1682.71,1406.86 1682.73,1406.86 1682.75,1406.86 1682.77,1406.86 1682.79,1406.86 1682.8,1406.86 1682.82,1406.86 1682.84,1406.86 1682.86,1406.86 1682.88,1406.86 1682.89,1406.86 1682.91,1406.86 1682.93,1406.86 1682.95,1406.86 1682.97,1406.86 1682.98,1406.86 1683,1406.86 1683.02,1406.86 1683.04,1406.86 1683.06,1406.86 1683.08,1406.86 1683.09,1406.86 1683.11,1406.86 1683.13,1406.86 1683.15,1406.86 1683.17,1406.86 1683.18,1406.86 1683.2,1406.86 1683.22,1406.86 1683.24,1406.86 1683.26,1406.86 1683.27,1406.86 1683.29,1406.86 1683.31,1406.86 1683.33,1406.86 1683.35,1406.86 1683.36,1406.86 1683.38,1406.86 1683.4,1406.86 1683.42,1406.86 1683.44,1406.86 1683.45,1406.86 1683.47,1406.86 1683.49,1406.86 1683.51,1406.86 1683.53,1406.86 1683.54,1406.86 1683.56,1406.86 1683.58,1406.86 1683.6,1406.86 1683.62,1406.86 1683.63,1406.86 1683.65,1406.86 1683.67,1406.86 1683.69,1406.86 1683.71,1406.86 1683.72,1406.86 1683.74,1406.86 1683.76,1406.86 1683.78,1406.86 1683.8,1406.86 1683.81,1406.86 1683.83,1406.86 1683.85,1406.86 1683.87,1406.86 1683.89,1406.86 1683.9,1406.86 1683.92,1406.86 1683.94,1406.86 1683.96,1406.86 1683.98,1406.86 1683.99,1406.86 1684.01,1406.86 1684.03,1406.86 1684.05,1406.86 1684.07,1406.86 1684.08,1406.86 1684.1,1406.86 1684.12,1406.86 1684.14,1406.86 1684.16,1406.86 1684.17,1406.86 1684.19,1406.86 1684.21,1406.86 1684.23,1406.86 1684.25,1406.86 1684.26,1406.86 1684.28,1406.86 1684.3,1406.86 1684.32,1406.86 1684.34,1406.86 1684.35,1406.86 1684.37,1406.86 1684.39,1406.86 1684.41,1406.86 1684.42,1406.86 1684.44,1406.86 1684.46,1406.86 1684.48,1406.86 1684.5,1406.86 1684.51,1406.86 1684.53,1406.86 1684.55,1406.86 1684.57,1406.86 1684.59,1406.86 1684.6,1406.86 1684.62,1406.86 1684.64,1406.86 1684.66,1406.86 1684.68,1406.86 1684.69,1406.86 1684.71,1406.86 1684.73,1406.86 1684.75,1406.86 1684.77,1406.86 1684.78,1406.86 1684.8,1406.86 1684.82,1406.86 1684.84,1406.86 1684.85,1406.86 1684.87,1406.86 1684.89,1406.86 1684.91,1406.86 1684.93,1406.86 1684.94,1406.86 1684.96,1406.86 1684.98,1406.86 1685,1406.86 1685.02,1406.86 1685.03,1406.86 1685.05,1406.86 1685.07,1406.87 1685.09,1406.87 1685.1,1406.87 1685.12,1406.87 1685.14,1406.87 1685.16,1406.87 1685.18,1406.87 1685.19,1406.87 1685.21,1406.87 1685.23,1406.87 1685.25,1406.87 1685.27,1406.87 1685.28,1406.87 1685.3,1406.87 1685.32,1406.87 1685.34,1406.87 1685.35,1406.87 1685.37,1406.87 1685.39,1406.87 1685.41,1406.87 1685.43,1406.87 1685.44,1406.87 1685.46,1406.87 1685.48,1406.87 1685.5,1406.87 1685.52,1406.87 1685.53,1406.87 1685.55,1406.87 1685.57,1406.87 1685.59,1406.87 1685.6,1406.87 1685.62,1406.87 1685.64,1406.87 1685.66,1406.87 1685.68,1406.87 1685.69,1406.87 1685.71,1406.87 1685.73,1406.87 1685.75,1406.87 1685.76,1406.87 1685.78,1406.87 1685.8,1406.87 1685.82,1406.87 1685.84,1406.87 1685.85,1406.87 1685.87,1406.87 1685.89,1406.87 1685.91,1406.87 1685.92,1406.87 1685.94,1406.87 1685.96,1406.87 1685.98,1406.87 1686,1406.87 1686.01,1406.87 1686.03,1406.87 1686.05,1406.87 1686.07,1406.87 1686.08,1406.87 1686.1,1406.87 1686.12,1406.87 1686.14,1406.87 1686.16,1406.87 1686.17,1406.87 1686.19,1406.87 1686.21,1406.87 1686.23,1406.87 1686.24,1406.87 1686.26,1406.87 1686.28,1406.87 1686.3,1406.87 1686.32,1406.87 1686.33,1406.87 1686.35,1406.87 1686.37,1406.87 1686.39,1406.87 1686.4,1406.87 1686.42,1406.87 1686.44,1406.87 1686.46,1406.87 1686.48,1406.87 1686.49,1406.87 1686.51,1406.87 1686.53,1406.87 1686.55,1406.87 1686.56,1406.87 1686.58,1406.87 1686.6,1406.87 1686.62,1406.87 1686.64,1406.87 1686.65,1406.87 1686.67,1406.87 1686.69,1406.87 1686.71,1406.87 1686.72,1406.87 1686.74,1406.87 1686.76,1406.87 1686.78,1406.87 1686.79,1406.87 1686.81,1406.87 1686.83,1406.87 1686.85,1406.87 1686.87,1406.87 1686.88,1406.87 1686.9,1406.87 1686.92,1406.87 1686.94,1406.87 1686.95,1406.87 1686.97,1406.87 1686.99,1406.87 1687.01,1406.87 1687.02,1406.87 1687.04,1406.87 1687.06,1406.87 1687.08,1406.87 1687.1,1406.87 1687.11,1406.87 1687.13,1406.87 1687.15,1406.87 1687.17,1406.87 1687.18,1406.87 1687.2,1406.87 1687.22,1406.87 1687.24,1406.87 1687.25,1406.87 1687.27,1406.87 1687.29,1406.87 1687.31,1406.87 1687.32,1406.87 1687.34,1406.87 1687.36,1406.87 1687.38,1406.87 1687.4,1406.87 1687.41,1406.87 1687.43,1406.87 1687.45,1406.87 1687.47,1406.87 1687.48,1406.87 1687.5,1406.87 1687.52,1406.87 1687.54,1406.87 1687.55,1406.87 1687.57,1406.87 1687.59,1406.87 1687.61,1406.87 1687.62,1406.87 1687.64,1406.87 1687.66,1406.87 1687.68,1406.87 1687.7,1406.87 1687.71,1406.87 1687.73,1406.87 1687.75,1406.87 1687.77,1406.87 1687.78,1406.87 1687.8,1406.87 1687.82,1406.87 1687.84,1406.87 1687.85,1406.87 1687.87,1406.87 1687.89,1406.87 1687.91,1406.87 1687.92,1406.87 1687.94,1406.87 1687.96,1406.87 1687.98,1406.87 1687.99,1406.87 1688.01,1406.87 1688.03,1406.87 1688.05,1406.87 1688.06,1406.87 1688.08,1406.87 1688.1,1406.87 1688.12,1406.87 1688.13,1406.87 1688.15,1406.87 1688.17,1406.87 1688.19,1406.87 1688.21,1406.87 1688.22,1406.87 1688.24,1406.87 1688.26,1406.87 1688.28,1406.87 1688.29,1406.87 1688.31,1406.87 1688.33,1406.87 1688.35,1406.87 1688.36,1406.87 1688.38,1406.87 1688.4,1406.87 1688.42,1406.87 1688.43,1406.87 1688.45,1406.87 1688.47,1406.87 1688.49,1406.87 1688.5,1406.87 1688.52,1406.87 1688.54,1406.87 1688.56,1406.87 1688.57,1406.87 1688.59,1406.87 1688.61,1406.87 1688.63,1406.87 1688.64,1406.87 1688.66,1406.87 1688.68,1406.87 1688.7,1406.87 1688.71,1406.87 1688.73,1406.87 1688.75,1406.87 1688.77,1406.87 1688.78,1406.87 1688.8,1406.87 1688.82,1406.87 1688.84,1406.87 1688.85,1406.87 1688.87,1406.87 1688.89,1406.87 1688.91,1406.87 1688.92,1406.87 1688.94,1406.87 1688.96,1406.87 1688.98,1406.87 1688.99,1406.87 1689.01,1406.87 1689.03,1406.87 1689.05,1406.87 1689.06,1406.87 1689.08,1406.87 1689.1,1406.87 1689.12,1406.87 1689.13,1406.87 1689.15,1406.87 1689.17,1406.87 1689.19,1406.87 1689.2,1406.87 1689.22,1406.87 1689.24,1406.87 1689.26,1406.87 1689.27,1406.87 1689.29,1406.87 1689.31,1406.88 1689.33,1406.88 1689.34,1406.88 1689.36,1406.88 1689.38,1406.88 1689.4,1406.88 1689.41,1406.88 1689.43,1406.88 1689.45,1406.88 1689.47,1406.88 1689.48,1406.88 1689.5,1406.88 1689.52,1406.88 1689.54,1406.88 1689.55,1406.88 1689.57,1406.88 1689.59,1406.88 1689.61,1406.88 1689.62,1406.88 1689.64,1406.88 1689.66,1406.88 1689.67,1406.88 1689.69,1406.88 1689.71,1406.88 1689.73,1406.88 1689.74,1406.88 1689.76,1406.88 1689.78,1406.88 1689.8,1406.88 1689.81,1406.88 1689.83,1406.88 1689.85,1406.88 1689.87,1406.88 1689.88,1406.88 1689.9,1406.88 1689.92,1406.88 1689.94,1406.88 1689.95,1406.88 1689.97,1406.88 1689.99,1406.88 1690.01,1406.88 1690.02,1406.88 1690.04,1406.88 1690.06,1406.88 1690.08,1406.88 1690.09,1406.88 1690.11,1406.88 1690.13,1406.88 1690.14,1406.88 1690.16,1406.88 1690.18,1406.88 1690.2,1406.88 1690.21,1406.88 1690.23,1406.88 1690.25,1406.88 1690.27,1406.88 1690.28,1406.88 1690.3,1406.88 1690.32,1406.88 1690.34,1406.88 1690.35,1406.88 1690.37,1406.88 1690.39,1406.88 1690.41,1406.88 1690.42,1406.88 1690.44,1406.88 1690.46,1406.88 1690.47,1406.88 1690.49,1406.88 1690.51,1406.88 1690.53,1406.88 1690.54,1406.88 1690.56,1406.88 1690.58,1406.88 1690.6,1406.88 1690.61,1406.88 1690.63,1406.88 1690.65,1406.88 1690.67,1406.88 1690.68,1406.88 1690.7,1406.88 1690.72,1406.88 1690.73,1406.88 1690.75,1406.88 1690.77,1406.88 1690.79,1406.88 1690.8,1406.88 1690.82,1406.88 1690.84,1406.88 1690.86,1406.88 1690.87,1406.88 1690.89,1406.88 1690.91,1406.88 1690.92,1406.88 1690.94,1406.88 1690.96,1406.88 1690.98,1406.88 1690.99,1406.88 1691.01,1406.88 1691.03,1406.88 1691.05,1406.88 1691.06,1406.88 1691.08,1406.88 1691.1,1406.88 1691.12,1406.88 1691.13,1406.88 1691.15,1406.88 1691.17,1406.88 1691.18,1406.88 1691.2,1406.88 1691.22,1406.88 1691.24,1406.88 1691.25,1406.88 1691.27,1406.88 1691.29,1406.88 1691.31,1406.88 1691.32,1406.88 1691.34,1406.88 1691.36,1406.88 1691.37,1406.88 1691.39,1406.88 1691.41,1406.88 1691.43,1406.88 1691.44,1406.88 1691.46,1406.88 1691.48,1406.88 1691.49,1406.88 1691.51,1406.88 1691.53,1406.88 1691.55,1406.88 1691.56,1406.88 1691.58,1406.88 1691.6,1406.88 1691.62,1406.88 1691.63,1406.88 1691.65,1406.88 1691.67,1406.88 1691.68,1406.88 1691.7,1406.88 1691.72,1406.88 1691.74,1406.88 1691.75,1406.88 1691.77,1406.88 1691.79,1406.88 1691.8,1406.88 1691.82,1406.88 1691.84,1406.88 1691.86,1406.88 1691.87,1406.88 1691.89,1406.88 1691.91,1406.88 1691.93,1406.88 1691.94,1406.88 1691.96,1406.88 1691.98,1406.88 1691.99,1406.88 1692.01,1406.88 1692.03,1406.88 1692.05,1406.88 1692.06,1406.88 1692.08,1406.88 1692.1,1406.88 1692.11,1406.88 1692.13,1406.88 1692.15,1406.88 1692.17,1406.88 1692.18,1406.88 1692.2,1406.88 1692.22,1406.88 1692.23,1406.88 1692.25,1406.88 1692.27,1406.88 1692.29,1406.88 1692.3,1406.88 1692.32,1406.88 1692.34,1406.88 1692.36,1406.88 1692.37,1406.88 1692.39,1406.88 1692.41,1406.88 1692.42,1406.88 1692.44,1406.88 1692.46,1406.88 1692.48,1406.88 1692.49,1406.88 1692.51,1406.88 1692.53,1406.88 1692.54,1406.88 1692.56,1406.88 1692.58,1406.88 1692.6,1406.88 1692.61,1406.88 1692.63,1406.88 1692.65,1406.88 1692.66,1406.88 1692.68,1406.88 1692.7,1406.88 1692.72,1406.88 1692.73,1406.88 1692.75,1406.88 1692.77,1406.88 1692.78,1406.88 1692.8,1406.88 1692.82,1406.88 1692.83,1406.88 1692.85,1406.88 1692.87,1406.88 1692.89,1406.88 1692.9,1406.88 1692.92,1406.88 1692.94,1406.88 1692.95,1406.88 1692.97,1406.88 1692.99,1406.88 1693.01,1406.88 1693.02,1406.88 1693.04,1406.88 1693.06,1406.88 1693.07,1406.88 1693.09,1406.88 1693.11,1406.88 1693.13,1406.88 1693.14,1406.88 1693.16,1406.88 1693.18,1406.88 1693.19,1406.88 1693.21,1406.88 1693.23,1406.88 1693.25,1406.88 1693.26,1406.88 1693.28,1406.88 1693.3,1406.88 1693.31,1406.88 1693.33,1406.88 1693.35,1406.88 1693.36,1406.88 1693.38,1406.88 1693.4,1406.88 1693.42,1406.88 1693.43,1406.88 1693.45,1406.88 1693.47,1406.88 1693.48,1406.88 1693.5,1406.88 1693.52,1406.88 1693.54,1406.88 1693.55,1406.88 1693.57,1406.88 1693.59,1406.88 1693.6,1406.88 1693.62,1406.88 1693.64,1406.88 1693.65,1406.88 1693.67,1406.88 1693.69,1406.88 1693.71,1406.88 1693.72,1406.88 1693.74,1406.88 1693.76,1406.88 1693.77,1406.88 1693.79,1406.88 1693.81,1406.88 1693.82,1406.88 1693.84,1406.88 1693.86,1406.88 1693.88,1406.88 1693.89,1406.88 1693.91,1406.88 1693.93,1406.88 1693.94,1406.88 1693.96,1406.88 1693.98,1406.88 1693.99,1406.88 1694.01,1406.88 1694.03,1406.88 1694.05,1406.88 1694.06,1406.88 1694.08,1406.88 1694.1,1406.88 1694.11,1406.88 1694.13,1406.88 1694.15,1406.88 1694.16,1406.88 1694.18,1406.88 1694.2,1406.88 1694.22,1406.88 1694.23,1406.88 1694.25,1406.88 1694.27,1406.88 1694.28,1406.88 1694.3,1406.88 1694.32,1406.88 1694.33,1406.88 1694.35,1406.88 1694.37,1406.88 1694.39,1406.88 1694.4,1406.88 1694.42,1406.88 1694.44,1406.88 1694.45,1406.88 1694.47,1406.88 1694.49,1406.88 1694.5,1406.88 1694.52,1406.88 1694.54,1406.88 1694.55,1406.88 1694.57,1406.88 1694.59,1406.88 1694.61,1406.88 1694.62,1406.88 1694.64,1406.88 1694.66,1406.88 1694.67,1406.88 1694.69,1406.88 1694.71,1406.88 1694.72,1406.88 1694.74,1406.88 1694.76,1406.88 1694.77,1406.88 1694.79,1406.88 1694.81,1406.88 1694.83,1406.88 1694.84,1406.88 1694.86,1406.88 1694.88,1406.88 1694.89,1406.88 1694.91,1406.88 1694.93,1406.88 1694.94,1406.88 1694.96,1406.88 1694.98,1406.88 1694.99,1406.88 1695.01,1406.88 1695.03,1406.88 1695.05,1406.88 1695.06,1406.88 1695.08,1406.88 1695.1,1406.88 1695.11,1406.88 1695.13,1406.88 1695.15,1406.88 1695.16,1406.88 1695.18,1406.88 1695.2,1406.88 1695.21,1406.88 1695.23,1406.88 1695.25,1406.88 1695.26,1406.88 1695.28,1406.88 1695.3,1406.88 1695.32,1406.88 1695.33,1406.88 1695.35,1406.88 1695.37,1406.88 1695.38,1406.88 1695.4,1406.88 1695.42,1406.88 1695.43,1406.88 1695.45,1406.88 1695.47,1406.88 1695.48,1406.88 1695.5,1406.88 1695.52,1406.88 1695.53,1406.88 1695.55,1406.88 1695.57,1406.88 1695.59,1406.88 1695.6,1406.88 1695.62,1406.88 1695.64,1406.88 1695.65,1406.88 1695.67,1406.88 1695.69,1406.88 1695.7,1406.88 1695.72,1406.88 1695.74,1406.88 1695.75,1406.88 1695.77,1406.88 1695.79,1406.88 1695.8,1406.88 1695.82,1406.88 1695.84,1406.88 1695.85,1406.88 1695.87,1406.88 1695.89,1406.88 1695.9,1406.88 1695.92,1406.88 1695.94,1406.88 1695.96,1406.88 1695.97,1406.88 1695.99,1406.88 1696.01,1406.88 1696.02,1406.88 1696.04,1406.88 1696.06,1406.88 1696.07,1406.88 1696.09,1406.88 1696.11,1406.88 1696.12,1406.88 1696.14,1406.88 1696.16,1406.88 1696.17,1406.88 1696.19,1406.88 1696.21,1406.88 1696.22,1406.88 1696.24,1406.88 1696.26,1406.88 1696.27,1406.88 1696.29,1406.88 1696.31,1406.88 1696.32,1406.88 1696.34,1406.88 1696.36,1406.88 1696.37,1406.88 1696.39,1406.88 1696.41,1406.88 1696.43,1406.88 1696.44,1406.88 1696.46,1406.88 1696.48,1406.88 1696.49,1406.88 1696.51,1406.88 1696.53,1406.88 1696.54,1406.88 1696.56,1406.88 1696.58,1406.88 1696.59,1406.88 1696.61,1406.88 1696.63,1406.88 1696.64,1406.88 1696.66,1406.88 1696.68,1406.88 1696.69,1406.88 1696.71,1406.88 1696.73,1406.88 1696.74,1406.88 1696.76,1406.88 1696.78,1406.88 1696.79,1406.88 1696.81,1406.88 1696.83,1406.88 1696.84,1406.88 1696.86,1406.88 1696.88,1406.88 1696.89,1406.88 1696.91,1406.88 1696.93,1406.88 1696.94,1406.88 1696.96,1406.88 1696.98,1406.88 1696.99,1406.88 1697.01,1406.88 1697.03,1406.88 1697.04,1406.88 1697.06,1406.88 1697.08,1406.88 1697.09,1406.88 1697.11,1406.88 1697.13,1406.88 1697.14,1406.88 1697.16,1406.88 1697.18,1406.88 1697.19,1406.88 1697.21,1406.88 1697.23,1406.88 1697.24,1406.88 1697.26,1406.88 1697.28,1406.88 1697.29,1406.88 1697.31,1406.88 1697.33,1406.88 1697.34,1406.88 1697.36,1406.88 1697.38,1406.88 1697.39,1406.88 1697.41,1406.88 1697.43,1406.88 1697.44,1406.88 1697.46,1406.88 1697.48,1406.88 1697.49,1406.88 1697.51,1406.88 1697.53,1406.88 1697.54,1406.88 1697.56,1406.88 1697.58,1406.88 1697.59,1406.88 1697.61,1406.88 1697.63,1406.88 1697.64,1406.88 1697.66,1406.88 1697.68,1406.88 1697.69,1406.88 1697.71,1406.88 1697.73,1406.88 1697.74,1406.88 1697.76,1406.88 1697.78,1406.88 1697.79,1406.88 1697.81,1406.88 1697.83,1406.88 1697.84,1406.88 1697.86,1406.88 1697.88,1406.88 1697.89,1406.88 1697.91,1406.88 1697.93,1406.88 1697.94,1406.88 1697.96,1406.88 1697.98,1406.88 1697.99,1406.88 1698.01,1406.88 1698.03,1406.88 1698.04,1406.88 1698.06,1406.88 1698.08,1406.88 1698.09,1406.88 1698.11,1406.88 1698.13,1406.88 1698.14,1406.88 1698.16,1406.88 1698.18,1406.88 1698.19,1406.88 1698.21,1406.88 1698.23,1406.88 1698.24,1406.88 1698.26,1406.88 1698.28,1406.88 1698.29,1406.88 1698.31,1406.88 1698.32,1406.88 1698.34,1406.88 1698.36,1406.88 1698.37,1406.88 1698.39,1406.88 1698.41,1406.88 1698.42,1406.88 1698.44,1406.88 1698.46,1406.88 1698.47,1406.88 1698.49,1406.88 1698.51,1406.88 1698.52,1406.88 1698.54,1406.88 1698.56,1406.88 1698.57,1406.88 1698.59,1406.88 1698.61,1406.88 1698.62,1406.88 1698.64,1406.88 1698.66,1406.88 1698.67,1406.88 1698.69,1406.88 1698.71,1406.88 1698.72,1406.88 1698.74,1406.88 1698.76,1406.88 1698.77,1406.88 1698.79,1406.88 1698.8,1406.88 1698.82,1406.88 1698.84,1406.88 1698.85,1406.88 1698.87,1406.88 1698.89,1406.88 1698.9,1406.88 1698.92,1406.88 1698.94,1406.88 1698.95,1406.88 1698.97,1406.88 1698.99,1406.88 1699,1406.88 1699.02,1406.88 1699.04,1406.88 1699.05,1406.88 1699.07,1406.88 1699.09,1406.88 1699.1,1406.88 1699.12,1406.88 1699.13,1406.88 1699.15,1406.88 1699.17,1406.88 1699.18,1406.88 1699.2,1406.88 1699.22,1406.88 1699.23,1406.88 1699.25,1406.88 1699.27,1406.88 1699.28,1406.88 1699.3,1406.88 1699.32,1406.88 1699.33,1406.88 1699.35,1406.88 1699.37,1406.88 1699.38,1406.88 1699.4,1406.88 1699.41,1406.88 1699.43,1406.88 1699.45,1406.88 1699.46,1406.88 1699.48,1406.88 1699.5,1406.88 1699.51,1406.88 1699.53,1406.88 1699.55,1406.88 1699.56,1406.88 1699.58,1406.88 1699.6,1406.88 1699.61,1406.88 1699.63,1406.88 1699.64,1406.88 1699.66,1406.88 1699.68,1406.88 1699.69,1406.88 1699.71,1406.88 1699.73,1406.88 1699.74,1406.88 1699.76,1406.88 1699.78,1406.88 1699.79,1406.88 1699.81,1406.88 1699.83,1406.88 1699.84,1406.88 1699.86,1406.88 1699.87,1406.88 1699.89,1406.88 1699.91,1406.88 1699.92,1406.88 1699.94,1406.88 1699.96,1406.88 1699.97,1406.88 1699.99,1406.88 1700.01,1406.88 1700.02,1406.88 1700.04,1406.88 1700.06,1406.88 1700.07,1406.88 1700.09,1406.88 1700.1,1406.88 1700.12,1406.88 1700.14,1406.88 1700.15,1406.88 1700.17,1406.88 1700.19,1406.88 1700.2,1406.88 1700.22,1406.88 1700.24,1406.88 1700.25,1406.88 1700.27,1406.88 1700.28,1406.88 1700.3,1406.88 1700.32,1406.88 1700.33,1406.88 1700.35,1406.88 1700.37,1406.88 1700.38,1406.88 1700.4,1406.88 1700.42,1406.88 1700.43,1406.88 1700.45,1406.88 1700.46,1406.88 1700.48,1406.88 1700.5,1406.88 1700.51,1406.88 1700.53,1406.88 1700.55,1406.88 1700.56,1406.88 1700.58,1406.88 1700.6,1406.88 1700.61,1406.88 1700.63,1406.88 1700.64,1406.88 1700.66,1406.88 1700.68,1406.88 1700.69,1406.88 1700.71,1406.87 1700.73,1406.87 1700.74,1406.87 1700.76,1406.87 1700.78,1406.87 1700.79,1406.87 1700.81,1406.87 1700.82,1406.87 1700.84,1406.87 1700.86,1406.87 1700.87,1406.87 1700.89,1406.87 1700.91,1406.87 1700.92,1406.87 1700.94,1406.87 1700.95,1406.87 1700.97,1406.87 1700.99,1406.87 1701,1406.87 1701.02,1406.87 1701.04,1406.87 1701.05,1406.87 1701.07,1406.87 1701.08,1406.87 1701.1,1406.87 1701.12,1406.87 1701.13,1406.87 1701.15,1406.87 1701.17,1406.87 1701.18,1406.87 1701.2,1406.87 1701.22,1406.87 1701.23,1406.87 1701.25,1406.87 1701.26,1406.87 1701.28,1406.87 1701.3,1406.87 1701.31,1406.87 1701.33,1406.87 1701.35,1406.87 1701.36,1406.87 1701.38,1406.87 1701.39,1406.87 1701.41,1406.87 1701.43,1406.87 1701.44,1406.87 1701.46,1406.87 1701.48,1406.87 1701.49,1406.87 1701.51,1406.87 1701.52,1406.87 1701.54,1406.87 1701.56,1406.87 1701.57,1406.87 1701.59,1406.87 1701.61,1406.87 1701.62,1406.87 1701.64,1406.87 1701.65,1406.87 1701.67,1406.87 1701.69,1406.87 1701.7,1406.87 1701.72,1406.87 1701.74,1406.87 1701.75,1406.87 1701.77,1406.87 1701.78,1406.87 1701.8,1406.87 1701.82,1406.87 1701.83,1406.87 1701.85,1406.87 1701.86,1406.87 1701.88,1406.87 1701.9,1406.87 1701.91,1406.87 1701.93,1406.87 1701.95,1406.87 1701.96,1406.87 1701.98,1406.87 1701.99,1406.87 1702.01,1406.87 1702.03,1406.87 1702.04,1406.87 1702.06,1406.87 1702.08,1406.87 1702.09,1406.87 1702.11,1406.87 1702.12,1406.87 1702.14,1406.87 1702.16,1406.87 1702.17,1406.87 1702.19,1406.87 1702.2,1406.87 1702.22,1406.87 1702.24,1406.87 1702.25,1406.87 1702.27,1406.87 1702.29,1406.87 1702.3,1406.87 1702.32,1406.87 1702.33,1406.87 1702.35,1406.87 1702.37,1406.87 1702.38,1406.87 1702.4,1406.87 1702.42,1406.87 1702.43,1406.87 1702.45,1406.87 1702.46,1406.87 1702.48,1406.87 1702.5,1406.87 1702.51,1406.87 1702.53,1406.87 1702.54,1406.87 1702.56,1406.87 1702.58,1406.87 1702.59,1406.87 1702.61,1406.87 1702.63,1406.87 1702.64,1406.87 1702.66,1406.87 1702.67,1406.87 1702.69,1406.87 1702.71,1406.87 1702.72,1406.87 1702.74,1406.87 1702.75,1406.87 1702.77,1406.87 1702.79,1406.87 1702.8,1406.87 1702.82,1406.87 1702.83,1406.87 1702.85,1406.87 1702.87,1406.87 1702.88,1406.87 1702.9,1406.87 1702.92,1406.87 1702.93,1406.87 1702.95,1406.87 1702.96,1406.87 1702.98,1406.87 1703,1406.87 1703.01,1406.87 1703.03,1406.87 1703.04,1406.87 1703.06,1406.87 1703.08,1406.87 1703.09,1406.87 1703.11,1406.87 1703.12,1406.87 1703.14,1406.87 1703.16,1406.87 1703.17,1406.87 1703.19,1406.87 1703.2,1406.87 1703.22,1406.87 1703.24,1406.87 1703.25,1406.87 1703.27,1406.87 1703.29,1406.87 1703.3,1406.87 1703.32,1406.87 1703.33,1406.87 1703.35,1406.87 1703.37,1406.87 1703.38,1406.87 1703.4,1406.87 1703.41,1406.87 1703.43,1406.87 1703.45,1406.87 1703.46,1406.87 1703.48,1406.87 1703.49,1406.87 1703.51,1406.87 1703.53,1406.87 1703.54,1406.87 1703.56,1406.87 1703.57,1406.87 1703.59,1406.87 1703.61,1406.87 1703.62,1406.87 1703.64,1406.87 1703.65,1406.87 1703.67,1406.87 1703.69,1406.87 1703.7,1406.87 1703.72,1406.87 1703.73,1406.87 1703.75,1406.87 1703.77,1406.87 1703.78,1406.87 1703.8,1406.87 1703.81,1406.87 1703.83,1406.87 1703.85,1406.87 1703.86,1406.87 1703.88,1406.87 1703.89,1406.87 1703.91,1406.87 1703.93,1406.87 1703.94,1406.87 1703.96,1406.87 1703.97,1406.87 1703.99,1406.87 1704.01,1406.87 1704.02,1406.87 1704.04,1406.87 1704.05,1406.87 1704.07,1406.87 1704.09,1406.87 1704.1,1406.87 1704.12,1406.87 1704.13,1406.87 1704.15,1406.87 1704.17,1406.87 1704.18,1406.87 1704.2,1406.87 1704.21,1406.87 1704.23,1406.87 1704.25,1406.87 1704.26,1406.87 1704.28,1406.87 1704.29,1406.87 1704.31,1406.87 1704.33,1406.87 1704.34,1406.87 1704.36,1406.87 1704.37,1406.87 1704.39,1406.87 1704.41,1406.87 1704.42,1406.87 1704.44,1406.87 1704.45,1406.87 1704.47,1406.87 1704.49,1406.87 1704.5,1406.87 1704.52,1406.87 1704.53,1406.87 1704.55,1406.87 1704.57,1406.87 1704.58,1406.87 1704.6,1406.87 1704.61,1406.87 1704.63,1406.87 1704.64,1406.87 1704.66,1406.87 1704.68,1406.87 1704.69,1406.87 1704.71,1406.87 1704.72,1406.87 1704.74,1406.87 1704.76,1406.87 1704.77,1406.87 1704.79,1406.87 1704.8,1406.87 1704.82,1406.87 1704.84,1406.87 1704.85,1406.87 1704.87,1406.87 1704.88,1406.87 1704.9,1406.87 1704.92,1406.87 1704.93,1406.87 1704.95,1406.87 1704.96,1406.87 1704.98,1406.87 1705,1406.87 1705.01,1406.87 1705.03,1406.87 1705.04,1406.87 1705.06,1406.87 1705.07,1406.87 1705.09,1406.87 1705.11,1406.86 1705.12,1406.86 1705.14,1406.86 1705.15,1406.86 1705.17,1406.86 1705.19,1406.86 1705.2,1406.86 1705.22,1406.86 1705.23,1406.86 1705.25,1406.86 1705.26,1406.86 1705.28,1406.86 1705.3,1406.86 1705.31,1406.86 1705.33,1406.86 1705.34,1406.86 1705.36,1406.86 1705.38,1406.86 1705.39,1406.86 1705.41,1406.86 1705.42,1406.86 1705.44,1406.86 1705.46,1406.86 1705.47,1406.86 1705.49,1406.86 1705.5,1406.86 1705.52,1406.86 1705.53,1406.86 1705.55,1406.86 1705.57,1406.86 1705.58,1406.86 1705.6,1406.86 1705.61,1406.86 1705.63,1406.86 1705.65,1406.86 1705.66,1406.86 1705.68,1406.86 1705.69,1406.86 1705.71,1406.86 1705.72,1406.86 1705.74,1406.86 1705.76,1406.86 1705.77,1406.86 1705.79,1406.86 1705.8,1406.86 1705.82,1406.86 1705.84,1406.86 1705.85,1406.86 1705.87,1406.86 1705.88,1406.86 1705.9,1406.86 1705.91,1406.86 1705.93,1406.86 1705.95,1406.86 1705.96,1406.86 1705.98,1406.86 1705.99,1406.86 1706.01,1406.86 1706.02,1406.86 1706.04,1406.86 1706.06,1406.86 1706.07,1406.86 1706.09,1406.86 1706.1,1406.86 1706.12,1406.86 1706.14,1406.86 1706.15,1406.86 1706.17,1406.86 1706.18,1406.86 1706.2,1406.86 1706.21,1406.86 1706.23,1406.86 1706.25,1406.86 1706.26,1406.86 1706.28,1406.86 1706.29,1406.86 1706.31,1406.86 1706.32,1406.86 1706.34,1406.86 1706.36,1406.86 1706.37,1406.86 1706.39,1406.86 1706.4,1406.86 1706.42,1406.86 1706.43,1406.86 1706.45,1406.86 1706.47,1406.86 1706.48,1406.86 1706.5,1406.86 1706.51,1406.86 1706.53,1406.86 1706.54,1406.86 1706.56,1406.86 1706.58,1406.86 1706.59,1406.86 1706.61,1406.86 1706.62,1406.86 1706.64,1406.86 1706.65,1406.86 1706.67,1406.86 1706.69,1406.86 1706.7,1406.86 1706.72,1406.86 1706.73,1406.86 1706.75,1406.86 1706.76,1406.86 1706.78,1406.86 1706.8,1406.86 1706.81,1406.86 1706.83,1406.86 1706.84,1406.86 1706.86,1406.86 1706.87,1406.86 1706.89,1406.86 1706.91,1406.86 1706.92,1406.86 1706.94,1406.86 1706.95,1406.86 1706.97,1406.86 1706.98,1406.86 1707,1406.86 1707.02,1406.86 1707.03,1406.86 1707.05,1406.86 1707.06,1406.86 1707.08,1406.86 1707.09,1406.86 1707.11,1406.86 1707.13,1406.86 1707.14,1406.86 1707.16,1406.86 1707.17,1406.86 1707.19,1406.86 1707.2,1406.86 1707.22,1406.86 1707.24,1406.86 1707.25,1406.86 1707.27,1406.86 1707.28,1406.86 1707.3,1406.86 1707.31,1406.86 1707.33,1406.86 1707.35,1406.86 1707.36,1406.86 1707.38,1406.86 1707.39,1406.86 1707.41,1406.86 1707.42,1406.86 1707.44,1406.86 1707.45,1406.86 1707.47,1406.86 1707.49,1406.86 1707.5,1406.86 1707.52,1406.86 1707.53,1406.86 1707.55,1406.86 1707.56,1406.86 1707.58,1406.86 1707.6,1406.86 1707.61,1406.86 1707.63,1406.86 1707.64,1406.86 1707.66,1406.86 1707.67,1406.86 1707.69,1406.86 1707.7,1406.86 1707.72,1406.86 1707.74,1406.86 1707.75,1406.86 1707.77,1406.86 1707.78,1406.86 1707.8,1406.86 1707.81,1406.86 1707.83,1406.86 1707.85,1406.86 1707.86,1406.86 1707.88,1406.86 1707.89,1406.86 1707.91,1406.86 1707.92,1406.86 1707.94,1406.86 1707.95,1406.86 1707.97,1406.86 1707.99,1406.86 1708,1406.86 1708.02,1406.86 1708.03,1406.86 1708.05,1406.86 1708.06,1406.86 1708.08,1406.86 1708.09,1406.86 1708.11,1406.86 1708.13,1406.86 1708.14,1406.85 1708.16,1406.85 1708.17,1406.85 1708.19,1406.85 1708.2,1406.85 1708.22,1406.85 1708.23,1406.85 1708.25,1406.85 1708.27,1406.85 1708.28,1406.85 1708.3,1406.85 1708.31,1406.85 1708.33,1406.85 1708.34,1406.85 1708.36,1406.85 1708.37,1406.85 1708.39,1406.85 1708.41,1406.85 1708.42,1406.85 1708.44,1406.85 1708.45,1406.85 1708.47,1406.85 1708.48,1406.85 1708.5,1406.85 1708.51,1406.85 1708.53,1406.85 1708.55,1406.85 1708.56,1406.85 1708.58,1406.85 1708.59,1406.85 1708.61,1406.85 1708.62,1406.85 1708.64,1406.85 1708.65,1406.85 1708.67,1406.85 1708.69,1406.85 1708.7,1406.85 1708.72,1406.85 1708.73,1406.85 1708.75,1406.85 1708.76,1406.85 1708.78,1406.85 1708.79,1406.85 1708.81,1406.85 1708.82,1406.85 1708.84,1406.85 1708.86,1406.85 1708.87,1406.85 1708.89,1406.85 1708.9,1406.85 1708.92,1406.85 1708.93,1406.85 1708.95,1406.85 1708.96,1406.85 1708.98,1406.85 1709,1406.85 1709.01,1406.85 1709.03,1406.85 1709.04,1406.85 1709.06,1406.85 1709.07,1406.85 1709.09,1406.85 1709.1,1406.85 1709.12,1406.85 1709.13,1406.85 1709.15,1406.85 1709.17,1406.85 1709.18,1406.85 1709.2,1406.85 1709.21,1406.85 1709.23,1406.85 1709.24,1406.85 1709.26,1406.85 1709.27,1406.85 1709.29,1406.85 1709.3,1406.85 1709.32,1406.85 1709.34,1406.85 1709.35,1406.85 1709.37,1406.85 1709.38,1406.85 1709.4,1406.85 1709.41,1406.85 1709.43,1406.85 1709.44,1406.85 1709.46,1406.85 1709.47,1406.85 1709.49,1406.85 1709.51,1406.85 1709.52,1406.85 1709.54,1406.85 1709.55,1406.85 1709.57,1406.85 1709.58,1406.85 1709.6,1406.85 1709.61,1406.85 1709.63,1406.85 1709.64,1406.85 1709.66,1406.85 1709.67,1406.85 1709.69,1406.85 1709.71,1406.85 1709.72,1406.85 1709.74,1406.85 1709.75,1406.85 1709.77,1406.85 1709.78,1406.85 1709.8,1406.85 1709.81,1406.85 1709.83,1406.85 1709.84,1406.85 1709.86,1406.85 1709.88,1406.85 1709.89,1406.85 1709.91,1406.85 1709.92,1406.85 1709.94,1406.85 1709.95,1406.85 1709.97,1406.85 1709.98,1406.85 1710,1406.85 1710.01,1406.85 1710.03,1406.85 1710.04,1406.85 1710.06,1406.85 1710.08,1406.85 1710.09,1406.85 1710.11,1406.85 1710.12,1406.85 1710.14,1406.85 1710.15,1406.85 1710.17,1406.85 1710.18,1406.85 1710.2,1406.85 1710.21,1406.85 1710.23,1406.85 1710.24,1406.85 1710.26,1406.85 1710.27,1406.85 1710.29,1406.85 1710.31,1406.85 1710.32,1406.85 1710.34,1406.85 1710.35,1406.85 1710.37,1406.85 1710.38,1406.85 1710.4,1406.85 1710.41,1406.85 1710.43,1406.85 1710.44,1406.85 1710.46,1406.85 1710.47,1406.85 1710.49,1406.85 1710.5,1406.85 1710.52,1406.85 1710.54,1406.85 1710.55,1406.85 1710.57,1406.85 1710.58,1406.85 1710.6,1406.85 1710.61,1406.85 1710.63,1406.84 1710.64,1406.84 1710.66,1406.84 1710.67,1406.84 1710.69,1406.84 1710.7,1406.84 1710.72,1406.84 1710.73,1406.84 1710.75,1406.84 1710.77,1406.84 1710.78,1406.84 1710.8,1406.84 1710.81,1406.84 1710.83,1406.84 1710.84,1406.84 1710.86,1406.84 1710.87,1406.84 1710.89,1406.84 1710.9,1406.84 1710.92,1406.84 1710.93,1406.84 1710.95,1406.84 1710.96,1406.84 1710.98,1406.84 1710.99,1406.84 1711.01,1406.84 1711.03,1406.84 1711.04,1406.84 1711.06,1406.84 1711.07,1406.84 1711.09,1406.84 1711.1,1406.84 1711.12,1406.84 1711.13,1406.84 1711.15,1406.84 1711.16,1406.84 1711.18,1406.84 1711.19,1406.84 1711.21,1406.84 1711.22,1406.84 1711.24,1406.84 1711.25,1406.84 1711.27,1406.84 1711.28,1406.84 1711.3,1406.84 1711.32,1406.84 1711.33,1406.84 1711.35,1406.84 1711.36,1406.84 1711.38,1406.84 1711.39,1406.84 1711.41,1406.84 1711.42,1406.84 1711.44,1406.84 1711.45,1406.84 1711.47,1406.84 1711.48,1406.84 1711.5,1406.84 1711.51,1406.84 1711.53,1406.84 1711.54,1406.84 1711.56,1406.84 1711.57,1406.84 1711.59,1406.84 1711.6,1406.84 1711.62,1406.84 1711.63,1406.84 1711.65,1406.84 1711.67,1406.84 1711.68,1406.84 1711.7,1406.84 1711.71,1406.84 1711.73,1406.84 1711.74,1406.84 1711.76,1406.84 1711.77,1406.84 1711.79,1406.84 1711.8,1406.84 1711.82,1406.84 1711.83,1406.84 1711.85,1406.84 1711.86,1406.84 1711.88,1406.84 1711.89,1406.84 1711.91,1406.84 1711.92,1406.84 1711.94,1406.84 1711.95,1406.84 1711.97,1406.84 1711.98,1406.84 1712,1406.84 1712.01,1406.84 1712.03,1406.84 1712.04,1406.84 1712.06,1406.84 1712.08,1406.84 1712.09,1406.84 1712.11,1406.84 1712.12,1406.84 1712.14,1406.84 1712.15,1406.84 1712.17,1406.84 1712.18,1406.84 1712.2,1406.84 1712.21,1406.84 1712.23,1406.84 1712.24,1406.84 1712.26,1406.84 1712.27,1406.84 1712.29,1406.84 1712.3,1406.84 1712.32,1406.84 1712.33,1406.84 1712.35,1406.84 1712.36,1406.84 1712.38,1406.84 1712.39,1406.84 1712.41,1406.84 1712.42,1406.84 1712.44,1406.84 1712.45,1406.84 1712.47,1406.84 1712.48,1406.84 1712.5,1406.84 1712.51,1406.84 1712.53,1406.84 1712.54,1406.84 1712.56,1406.84 1712.57,1406.84 1712.59,1406.84 1712.6,1406.84 1712.62,1406.84 1712.64,1406.84 1712.65,1406.84 1712.67,1406.84 1712.68,1406.84 1712.7,1406.84 1712.71,1406.84 1712.73,1406.84 1712.74,1406.84 1712.76,1406.84 1712.77,1406.84 1712.79,1406.83 1712.8,1406.83 1712.82,1406.83 1712.83,1406.83 1712.85,1406.83 1712.86,1406.83 1712.88,1406.83 1712.89,1406.83 1712.91,1406.83 1712.92,1406.83 1712.94,1406.83 1712.95,1406.83 1712.97,1406.83 1712.98,1406.83 1713,1406.83 1713.01,1406.83 1713.03,1406.83 1713.04,1406.83 1713.06,1406.83 1713.07,1406.83 1713.09,1406.83 1713.1,1406.83 1713.12,1406.83 1713.13,1406.83 1713.15,1406.83 1713.16,1406.83 1713.18,1406.83 1713.19,1406.83 1713.21,1406.83 1713.22,1406.83 1713.24,1406.83 1713.25,1406.83 1713.27,1406.83 1713.28,1406.83 1713.3,1406.83 1713.31,1406.83 1713.33,1406.83 1713.34,1406.83 1713.36,1406.83 1713.37,1406.83 1713.39,1406.83 1713.4,1406.83 1713.42,1406.83 1713.43,1406.83 1713.45,1406.83 1713.46,1406.83 1713.48,1406.83 1713.49,1406.83 1713.51,1406.83 1713.52,1406.83 1713.54,1406.83 1713.55,1406.83 1713.57,1406.83 1713.58,1406.83 1713.6,1406.83 1713.61,1406.83 1713.63,1406.83 1713.64,1406.83 1713.66,1406.83 1713.67,1406.83 1713.69,1406.83 1713.7,1406.83 1713.72,1406.83 1713.73,1406.83 1713.75,1406.83 1713.76,1406.83 1713.78,1406.83 1713.79,1406.83 1713.81,1406.83 1713.82,1406.83 1713.84,1406.83 1713.85,1406.83 1713.87,1406.83 1713.88,1406.83 1713.9,1406.83 1713.91,1406.83 1713.93,1406.83 1713.94,1406.83 1713.96,1406.83 1713.97,1406.83 1713.99,1406.83 1714,1406.83 1714.02,1406.83 1714.03,1406.83 1714.05,1406.83 1714.06,1406.83 1714.08,1406.83 1714.09,1406.83 1714.11,1406.83 1714.12,1406.83 1714.14,1406.83 1714.15,1406.83 1714.17,1406.83 1714.18,1406.83 1714.2,1406.83 1714.21,1406.83 1714.23,1406.83 1714.24,1406.83 1714.26,1406.83 1714.27,1406.83 1714.29,1406.83 1714.3,1406.83 1714.32,1406.83 1714.33,1406.83 1714.35,1406.83 1714.36,1406.83 1714.38,1406.83 1714.39,1406.83 1714.41,1406.83 1714.42,1406.83 1714.44,1406.83 1714.45,1406.83 1714.47,1406.83 1714.48,1406.83 1714.5,1406.83 1714.51,1406.83 1714.53,1406.83 1714.54,1406.83 1714.56,1406.83 1714.57,1406.83 1714.59,1406.83 1714.6,1406.83 1714.62,1406.83 1714.63,1406.83 1714.65,1406.83 1714.66,1406.83 1714.68,1406.83 1714.69,1406.83 1714.7,1406.82 1714.72,1406.82 1714.73,1406.82 1714.75,1406.82 1714.76,1406.82 1714.78,1406.82 1714.79,1406.82 1714.81,1406.82 1714.82,1406.82 1714.84,1406.82 1714.85,1406.82 1714.87,1406.82 1714.88,1406.82 1714.9,1406.82 1714.91,1406.82 1714.93,1406.82 1714.94,1406.82 1714.96,1406.82 1714.97,1406.82 1714.99,1406.82 1715,1406.82 1715.02,1406.82 1715.03,1406.82 1715.05,1406.82 1715.06,1406.82 1715.08,1406.82 1715.09,1406.82 1715.11,1406.82 1715.12,1406.82 1715.14,1406.82 1715.15,1406.82 1715.17,1406.82 1715.18,1406.82 1715.2,1406.82 1715.21,1406.82 1715.23,1406.82 1715.24,1406.82 1715.25,1406.82 1715.27,1406.82 1715.28,1406.82 1715.3,1406.82 1715.31,1406.82 1715.33,1406.82 1715.34,1406.82 1715.36,1406.82 1715.37,1406.82 1715.39,1406.82 1715.4,1406.82 1715.42,1406.82 1715.43,1406.82 1715.45,1406.82 1715.46,1406.82 1715.48,1406.82 1715.49,1406.82 1715.51,1406.82 1715.52,1406.82 1715.54,1406.82 1715.55,1406.82 1715.57,1406.82 1715.58,1406.82 1715.6,1406.82 1715.61,1406.82 1715.63,1406.82 1715.64,1406.82 1715.65,1406.82 1715.67,1406.82 1715.68,1406.82 1715.7,1406.82 1715.71,1406.82 1715.73,1406.82 1715.74,1406.82 1715.76,1406.82 1715.77,1406.82 1715.79,1406.82 1715.8,1406.82 1715.82,1406.82 1715.83,1406.82 1715.85,1406.82 1715.86,1406.82 1715.88,1406.82 1715.89,1406.82 1715.91,1406.82 1715.92,1406.82 1715.94,1406.82 1715.95,1406.82 1715.97,1406.82 1715.98,1406.82 1715.99,1406.82 1716.01,1406.82 1716.02,1406.82 1716.04,1406.82 1716.05,1406.82 1716.07,1406.82 1716.08,1406.82 1716.1,1406.82 1716.11,1406.82 1716.13,1406.82 1716.14,1406.82 1716.16,1406.82 1716.17,1406.82 1716.19,1406.82 1716.2,1406.82 1716.22,1406.82 1716.23,1406.82 1716.25,1406.82 1716.26,1406.82 1716.27,1406.82 1716.29,1406.82 1716.3,1406.82 1716.32,1406.82 1716.33,1406.82 1716.35,1406.82 1716.36,1406.82 1716.38,1406.82 1716.39,1406.82 1716.41,1406.82 1716.42,1406.82 1716.44,1406.82 1716.45,1406.82 1716.47,1406.82 1716.48,1406.81 1716.5,1406.81 1716.51,1406.81 1716.52,1406.81 1716.54,1406.81 1716.55,1406.81 1716.57,1406.81 1716.58,1406.81 1716.6,1406.81 1716.61,1406.81 1716.63,1406.81 1716.64,1406.81 1716.66,1406.81 1716.67,1406.81 1716.69,1406.81 1716.7,1406.81 1716.72,1406.81 1716.73,1406.81 1716.75,1406.81 1716.76,1406.81 1716.77,1406.81 1716.79,1406.81 1716.8,1406.81 1716.82,1406.81 1716.83,1406.81 1716.85,1406.81 1716.86,1406.81 1716.88,1406.81 1716.89,1406.81 1716.91,1406.81 1716.92,1406.81 1716.94,1406.81 1716.95,1406.81 1716.97,1406.81 1716.98,1406.81 1716.99,1406.81 1717.01,1406.81 1717.02,1406.81 1717.04,1406.81 1717.05,1406.81 1717.07,1406.81 1717.08,1406.81 1717.1,1406.81 1717.11,1406.81 1717.13,1406.81 1717.14,1406.81 1717.16,1406.81 1717.17,1406.81 1717.18,1406.81 1717.2,1406.81 1717.21,1406.81 1717.23,1406.81 1717.24,1406.81 1717.26,1406.81 1717.27,1406.81 1717.29,1406.81 1717.3,1406.81 1717.32,1406.81 1717.33,1406.81 1717.35,1406.81 1717.36,1406.81 1717.37,1406.81 1717.39,1406.81 1717.4,1406.81 1717.42,1406.81 1717.43,1406.81 1717.45,1406.81 1717.46,1406.81 1717.48,1406.81 1717.49,1406.81 1717.51,1406.81 1717.52,1406.81 1717.54,1406.81 1717.55,1406.81 1717.56,1406.81 1717.58,1406.81 1717.59,1406.81 1717.61,1406.81 1717.62,1406.81 1717.64,1406.81 1717.65,1406.81 1717.67,1406.81 1717.68,1406.81 1717.7,1406.81 1717.71,1406.81 1717.73,1406.81 1717.74,1406.81 1717.75,1406.81 1717.77,1406.81 1717.78,1406.81 1717.8,1406.81 1717.81,1406.81 1717.83,1406.81 1717.84,1406.81 1717.86,1406.81 1717.87,1406.81 1717.89,1406.81 1717.9,1406.81 1717.91,1406.81 1717.93,1406.81 1717.94,1406.81 1717.96,1406.81 1717.97,1406.81 1717.99,1406.81 1718,1406.81 1718.02,1406.81 1718.03,1406.81 1718.05,1406.81 1718.06,1406.81 1718.07,1406.81 1718.09,1406.81 1718.1,1406.81 1718.12,1406.8 1718.13,1406.8 1718.15,1406.8 1718.16,1406.8 1718.18,1406.8 1718.19,1406.8 1718.21,1406.8 1718.22,1406.8 1718.23,1406.8 1718.25,1406.8 1718.26,1406.8 1718.28,1406.8 1718.29,1406.8 1718.31,1406.8 1718.32,1406.8 1718.34,1406.8 1718.35,1406.8 1718.36,1406.8 1718.38,1406.8 1718.39,1406.8 1718.41,1406.8 1718.42,1406.8 1718.44,1406.8 1718.45,1406.8 1718.47,1406.8 1718.48,1406.8 1718.5,1406.8 1718.51,1406.8 1718.52,1406.8 1718.54,1406.8 1718.55,1406.8 1718.57,1406.8 1718.58,1406.8 1718.6,1406.8 1718.61,1406.8 1718.63,1406.8 1718.64,1406.8 1718.65,1406.8 1718.67,1406.8 1718.68,1406.8 1718.7,1406.8 1718.71,1406.8 1718.73,1406.8 1718.74,1406.8 1718.76,1406.8 1718.77,1406.8 1718.78,1406.8 1718.8,1406.8 1718.81,1406.8 1718.83,1406.8 1718.84,1406.8 1718.86,1406.8 1718.87,1406.8 1718.89,1406.8 1718.9,1406.8 1718.91,1406.8 1718.93,1406.8 1718.94,1406.8 1718.96,1406.8 1718.97,1406.8 1718.99,1406.8 1719,1406.8 1719.02,1406.8 1719.03,1406.8 1719.04,1406.8 1719.06,1406.8 1719.07,1406.8 1719.09,1406.8 1719.1,1406.8 1719.12,1406.8 1719.13,1406.8 1719.15,1406.8 1719.16,1406.8 1719.17,1406.8 1719.19,1406.8 1719.2,1406.8 1719.22,1406.8 1719.23,1406.8 1719.25,1406.8 1719.26,1406.8 1719.28,1406.8 1719.29,1406.8 1719.3,1406.8 1719.32,1406.8 1719.33,1406.8 1719.35,1406.8 1719.36,1406.8 1719.38,1406.8 1719.39,1406.8 1719.41,1406.8 1719.42,1406.8 1719.43,1406.8 1719.45,1406.8 1719.46,1406.8 1719.48,1406.8 1719.49,1406.8 1719.51,1406.8 1719.52,1406.8 1719.53,1406.8 1719.55,1406.8 1719.56,1406.8 1719.58,1406.8 1719.59,1406.8 1719.61,1406.8 1719.62,1406.8 1719.64,1406.8 1719.65,1406.8 1719.66,1406.79 1719.68,1406.79 1719.69,1406.79 1719.71,1406.79 1719.72,1406.79 1719.74,1406.79 1719.75,1406.79 1719.76,1406.79 1719.78,1406.79 1719.79,1406.79 1719.81,1406.79 1719.82,1406.79 1719.84,1406.79 1719.85,1406.79 1719.87,1406.79 1719.88,1406.79 1719.89,1406.79 1719.91,1406.79 1719.92,1406.79 1719.94,1406.79 1719.95,1406.79 1719.97,1406.79 1719.98,1406.79 1719.99,1406.79 1720.01,1406.79 1720.02,1406.79 1720.04,1406.79 1720.05,1406.79 1720.07,1406.79 1720.08,1406.79 1720.09,1406.79 1720.11,1406.79 1720.12,1406.79 1720.14,1406.79 1720.15,1406.79 1720.17,1406.79 1720.18,1406.79 1720.19,1406.79 1720.21,1406.79 1720.22,1406.79 1720.24,1406.79 1720.25,1406.79 1720.27,1406.79 1720.28,1406.79 1720.3,1406.79 1720.31,1406.79 1720.32,1406.79 1720.34,1406.79 1720.35,1406.79 1720.37,1406.79 1720.38,1406.79 1720.4,1406.79 1720.41,1406.79 1720.42,1406.79 1720.44,1406.79 1720.45,1406.79 1720.47,1406.79 1720.48,1406.79 1720.5,1406.79 1720.51,1406.79 1720.52,1406.79 1720.54,1406.79 1720.55,1406.79 1720.57,1406.79 1720.58,1406.79 1720.6,1406.79 1720.61,1406.79 1720.62,1406.79 1720.64,1406.79 1720.65,1406.79 1720.67,1406.79 1720.68,1406.79 1720.7,1406.79 1720.71,1406.79 1720.72,1406.79 1720.74,1406.79 1720.75,1406.79 1720.77,1406.79 1720.78,1406.79 1720.79,1406.79 1720.81,1406.79 1720.82,1406.79 1720.84,1406.79 1720.85,1406.79 1720.87,1406.79 1720.88,1406.79 1720.89,1406.79 1720.91,1406.79 1720.92,1406.79 1720.94,1406.79 1720.95,1406.79 1720.97,1406.79 1720.98,1406.79 1720.99,1406.79 1721.01,1406.79 1721.02,1406.79 1721.04,1406.79 1721.05,1406.79 1721.07,1406.79 1721.08,1406.79 1721.09,1406.79 1721.11,1406.79 1721.12,1406.78 1721.14,1406.78 1721.15,1406.78 1721.16,1406.78 1721.18,1406.78 1721.19,1406.78 1721.21,1406.78 1721.22,1406.78 1721.24,1406.78 1721.25,1406.78 1721.26,1406.78 1721.28,1406.78 1721.29,1406.78 1721.31,1406.78 1721.32,1406.78 1721.34,1406.78 1721.35,1406.78 1721.36,1406.78 1721.38,1406.78 1721.39,1406.78 1721.41,1406.78 1721.42,1406.78 1721.43,1406.78 1721.45,1406.78 1721.46,1406.78 1721.48,1406.78 1721.49,1406.78 1721.51,1406.78 1721.52,1406.78 1721.53,1406.78 1721.55,1406.78 1721.56,1406.78 1721.58,1406.78 1721.59,1406.78 1721.6,1406.78 1721.62,1406.78 1721.63,1406.78 1721.65,1406.78 1721.66,1406.78 1721.68,1406.78 1721.69,1406.78 1721.7,1406.78 1721.72,1406.78 1721.73,1406.78 1721.75,1406.78 1721.76,1406.78 1721.77,1406.78 1721.79,1406.78 1721.8,1406.78 1721.82,1406.78 1721.83,1406.78 1721.85,1406.78 1721.86,1406.78 1721.87,1406.78 1721.89,1406.78 1721.9,1406.78 1721.92,1406.78 1721.93,1406.78 1721.94,1406.78 1721.96,1406.78 1721.97,1406.78 1721.99,1406.78 1722,1406.78 1722.01,1406.78 1722.03,1406.78 1722.04,1406.78 1722.06,1406.78 1722.07,1406.78 1722.09,1406.78 1722.1,1406.78 1722.11,1406.78 1722.13,1406.78 1722.14,1406.78 1722.16,1406.78 1722.17,1406.78 1722.18,1406.78 1722.2,1406.78 1722.21,1406.78 1722.23,1406.78 1722.24,1406.78 1722.25,1406.78 1722.27,1406.78 1722.28,1406.78 1722.3,1406.78 1722.31,1406.78 1722.33,1406.78 1722.34,1406.78 1722.35,1406.78 1722.37,1406.78 1722.38,1406.78 1722.4,1406.78 1722.41,1406.78 1722.42,1406.78 1722.44,1406.78 1722.45,1406.78 1722.47,1406.78 1722.48,1406.78 1722.49,1406.78 1722.51,1406.77 1722.52,1406.77 1722.54,1406.77 1722.55,1406.77 1722.56,1406.77 1722.58,1406.77 1722.59,1406.77 1722.61,1406.77 1722.62,1406.77 1722.63,1406.77 1722.65,1406.77 1722.66,1406.77 1722.68,1406.77 1722.69,1406.77 1722.71,1406.77 1722.72,1406.77 1722.73,1406.77 1722.75,1406.77 1722.76,1406.77 1722.78,1406.77 1722.79,1406.77 1722.8,1406.77 1722.82,1406.77 1722.83,1406.77 1722.85,1406.77 1722.86,1406.77 1722.87,1406.77 1722.89,1406.77 1722.9,1406.77 1722.92,1406.77 1722.93,1406.77 1722.94,1406.77 1722.96,1406.77 1722.97,1406.77 1722.99,1406.77 1723,1406.77 1723.01,1406.77 1723.03,1406.77 1723.04,1406.77 1723.06,1406.77 1723.07,1406.77 1723.08,1406.77 1723.1,1406.77 1723.11,1406.77 1723.13,1406.77 1723.14,1406.77 1723.15,1406.77 1723.17,1406.77 1723.18,1406.77 1723.2,1406.77 1723.21,1406.77 1723.22,1406.77 1723.24,1406.77 1723.25,1406.77 1723.27,1406.77 1723.28,1406.77 1723.29,1406.77 1723.31,1406.77 1723.32,1406.77 1723.34,1406.77 1723.35,1406.77 1723.36,1406.77 1723.38,1406.77 1723.39,1406.77 1723.41,1406.77 1723.42,1406.77 1723.43,1406.77 1723.45,1406.77 1723.46,1406.77 1723.48,1406.77 1723.49,1406.77 1723.5,1406.77 1723.52,1406.77 1723.53,1406.77 1723.55,1406.77 1723.56,1406.77 1723.57,1406.77 1723.59,1406.77 1723.6,1406.77 1723.62,1406.77 1723.63,1406.77 1723.64,1406.77 1723.66,1406.77 1723.67,1406.77 1723.69,1406.77 1723.7,1406.77 1723.71,1406.77 1723.73,1406.77 1723.74,1406.77 1723.75,1406.77 1723.77,1406.77 1723.78,1406.77 1723.8,1406.77 1723.81,1406.77 1723.82,1406.77 1723.84,1406.76 1723.85,1406.76 1723.87,1406.76 1723.88,1406.76 1723.89,1406.76 1723.91,1406.76 1723.92,1406.76 1723.94,1406.76 1723.95,1406.76 1723.96,1406.76 1723.98,1406.76 1723.99,1406.76 1724.01,1406.76 1724.02,1406.76 1724.03,1406.76 1724.05,1406.76 1724.06,1406.76 1724.08,1406.76 1724.09,1406.76 1724.1,1406.76 1724.12,1406.76 1724.13,1406.76 1724.14,1406.76 1724.16,1406.76 1724.17,1406.76 1724.19,1406.76 1724.2,1406.76 1724.21,1406.76 1724.23,1406.76 1724.24,1406.76 1724.26,1406.76 1724.27,1406.76 1724.28,1406.76 1724.3,1406.76 1724.31,1406.76 1724.33,1406.76 1724.34,1406.76 1724.35,1406.76 1724.37,1406.76 1724.38,1406.76 1724.39,1406.76 1724.41,1406.76 1724.42,1406.76 1724.44,1406.76 1724.45,1406.76 1724.46,1406.76 1724.48,1406.76 1724.49,1406.76 1724.51,1406.76 1724.52,1406.76 1724.53,1406.76 1724.55,1406.76 1724.56,1406.76 1724.57,1406.76 1724.59,1406.76 1724.6,1406.76 1724.62,1406.76 1724.63,1406.76 1724.64,1406.76 1724.66,1406.76 1724.67,1406.76 1724.69,1406.76 1724.7,1406.76 1724.71,1406.76 1724.73,1406.76 1724.74,1406.76 1724.75,1406.76 1724.77,1406.76 1724.78,1406.76 1724.8,1406.76 1724.81,1406.76 1724.82,1406.76 1724.84,1406.76 1724.85,1406.76 1724.87,1406.76 1724.88,1406.76 1724.89,1406.76 1724.91,1406.76 1724.92,1406.76 1724.93,1406.76 1724.95,1406.76 1724.96,1406.76 1724.98,1406.76 1724.99,1406.76 1725,1406.76 1725.02,1406.76 1725.03,1406.76 1725.04,1406.76 1725.06,1406.76 1725.07,1406.76 1725.09,1406.76 1725.1,1406.76 1725.11,1406.75 1725.13,1406.75 1725.14,1406.75 1725.16,1406.75 1725.17,1406.75 1725.18,1406.75 1725.2,1406.75 1725.21,1406.75 1725.22,1406.75 1725.24,1406.75 1725.25,1406.75 1725.27,1406.75 1725.28,1406.75 1725.29,1406.75 1725.31,1406.75 1725.32,1406.75 1725.33,1406.75 1725.35,1406.75 1725.36,1406.75 1725.38,1406.75 1725.39,1406.75 1725.4,1406.75 1725.42,1406.75 1725.43,1406.75 1725.44,1406.75 1725.46,1406.75 1725.47,1406.75 1725.49,1406.75 1725.5,1406.75 1725.51,1406.75 1725.53,1406.75 1725.54,1406.75 1725.55,1406.75 1725.57,1406.75 1725.58,1406.75 1725.6,1406.75 1725.61,1406.75 1725.62,1406.75 1725.64,1406.75 1725.65,1406.75 1725.66,1406.75 1725.68,1406.75 1725.69,1406.75 1725.71,1406.75 1725.72,1406.75 1725.73,1406.75 1725.75,1406.75 1725.76,1406.75 1725.77,1406.75 1725.79,1406.75 1725.8,1406.75 1725.82,1406.75 1725.83,1406.75 1725.84,1406.75 1725.86,1406.75 1725.87,1406.75 1725.88,1406.75 1725.9,1406.75 1725.91,1406.75 1725.93,1406.75 1725.94,1406.75 1725.95,1406.75 1725.97,1406.75 1725.98,1406.75 1725.99,1406.75 1726.01,1406.75 1726.02,1406.75 1726.03,1406.75 1726.05,1406.75 1726.06,1406.75 1726.08,1406.75 1726.09,1406.75 1726.1,1406.75 1726.12,1406.75 1726.13,1406.75 1726.14,1406.75 1726.16,1406.75 1726.17,1406.75 1726.19,1406.75 1726.2,1406.75 1726.21,1406.75 1726.23,1406.75 1726.24,1406.75 1726.25,1406.75 1726.27,1406.75 1726.28,1406.75 1726.29,1406.75 1726.31,1406.75 1726.32,1406.75 1726.34,1406.74 1726.35,1406.74 1726.36,1406.74 1726.38,1406.74 1726.39,1406.74 1726.4,1406.74 1726.42,1406.74 1726.43,1406.74 1726.45,1406.74 1726.46,1406.74 1726.47,1406.74 1726.49,1406.74 1726.5,1406.74 1726.51,1406.74 1726.53,1406.74 1726.54,1406.74 1726.55,1406.74 1726.57,1406.74 1726.58,1406.74 1726.6,1406.74 1726.61,1406.74 1726.62,1406.74 1726.64,1406.74 1726.65,1406.74 1726.66,1406.74 1726.68,1406.74 1726.69,1406.74 1726.7,1406.74 1726.72,1406.74 1726.73,1406.74 1726.75,1406.74 1726.76,1406.74 1726.77,1406.74 1726.79,1406.74 1726.8,1406.74 1726.81,1406.74 1726.83,1406.74 1726.84,1406.74 1726.85,1406.74 1726.87,1406.74 1726.88,1406.74 1726.89,1406.74 1726.91,1406.74 1726.92,1406.74 1726.94,1406.74 1726.95,1406.74 1726.96,1406.74 1726.98,1406.74 1726.99,1406.74 1727,1406.74 1727.02,1406.74 1727.03,1406.74 1727.04,1406.74 1727.06,1406.74 1727.07,1406.74 1727.09,1406.74 1727.1,1406.74 1727.11,1406.74 1727.13,1406.74 1727.14,1406.74 1727.15,1406.74 1727.17,1406.74 1727.18,1406.74 1727.19,1406.74 1727.21,1406.74 1727.22,1406.74 1727.23,1406.74 1727.25,1406.74 1727.26,1406.74 1727.28,1406.74 1727.29,1406.74 1727.3,1406.74 1727.32,1406.74 1727.33,1406.74 1727.34,1406.74 1727.36,1406.74 1727.37,1406.74 1727.38,1406.74 1727.4,1406.74 1727.41,1406.74 1727.42,1406.74 1727.44,1406.74 1727.45,1406.74 1727.46,1406.74 1727.48,1406.74 1727.49,1406.74 1727.51,1406.74 1727.52,1406.73 1727.53,1406.73 1727.55,1406.73 1727.56,1406.73 1727.57,1406.73 1727.59,1406.73 1727.6,1406.73 1727.61,1406.73 1727.63,1406.73 1727.64,1406.73 1727.65,1406.73 1727.67,1406.73 1727.68,1406.73 1727.7,1406.73 1727.71,1406.73 1727.72,1406.73 1727.74,1406.73 1727.75,1406.73 1727.76,1406.73 1727.78,1406.73 1727.79,1406.73 1727.8,1406.73 1727.82,1406.73 1727.83,1406.73 1727.84,1406.73 1727.86,1406.73 1727.87,1406.73 1727.88,1406.73 1727.9,1406.73 1727.91,1406.73 1727.92,1406.73 1727.94,1406.73 1727.95,1406.73 1727.97,1406.73 1727.98,1406.73 1727.99,1406.73 1728.01,1406.73 1728.02,1406.73 1728.03,1406.73 1728.05,1406.73 1728.06,1406.73 1728.07,1406.73 1728.09,1406.73 1728.1,1406.73 1728.11,1406.73 1728.13,1406.73 1728.14,1406.73 1728.15,1406.73 1728.17,1406.73 1728.18,1406.73 1728.19,1406.73 1728.21,1406.73 1728.22,1406.73 1728.23,1406.73 1728.25,1406.73 1728.26,1406.73 1728.28,1406.73 1728.29,1406.73 1728.3,1406.73 1728.32,1406.73 1728.33,1406.73 1728.34,1406.73 1728.36,1406.73 1728.37,1406.73 1728.38,1406.73 1728.4,1406.73 1728.41,1406.73 1728.42,1406.73 1728.44,1406.73 1728.45,1406.73 1728.46,1406.73 1728.48,1406.73 1728.49,1406.73 1728.5,1406.73 1728.52,1406.73 1728.53,1406.73 1728.54,1406.73 1728.56,1406.73 1728.57,1406.73 1728.58,1406.73 1728.6,1406.73 1728.61,1406.73 1728.62,1406.73 1728.64,1406.73 1728.65,1406.73 1728.66,1406.72 1728.68,1406.72 1728.69,1406.72 1728.71,1406.72 1728.72,1406.72 1728.73,1406.72 1728.75,1406.72 1728.76,1406.72 1728.77,1406.72 1728.79,1406.72 1728.8,1406.72 1728.81,1406.72 1728.83,1406.72 1728.84,1406.72 1728.85,1406.72 1728.87,1406.72 1728.88,1406.72 1728.89,1406.72 1728.91,1406.72 1728.92,1406.72 1728.93,1406.72 1728.95,1406.72 1728.96,1406.72 1728.97,1406.72 1728.99,1406.72 1729,1406.72 1729.01,1406.72 1729.03,1406.72 1729.04,1406.72 1729.05,1406.72 1729.07,1406.72 1729.08,1406.72 1729.09,1406.72 1729.11,1406.72 1729.12,1406.72 1729.13,1406.72 1729.15,1406.72 1729.16,1406.72 1729.17,1406.72 1729.19,1406.72 1729.2,1406.72 1729.21,1406.72 1729.23,1406.72 1729.24,1406.72 1729.25,1406.72 1729.27,1406.72 1729.28,1406.72 1729.29,1406.72 1729.31,1406.72 1729.32,1406.72 1729.33,1406.72 1729.35,1406.72 1729.36,1406.72 1729.37,1406.72 1729.39,1406.72 1729.4,1406.72 1729.41,1406.72 1729.43,1406.72 1729.44,1406.72 1729.45,1406.72 1729.47,1406.72 1729.48,1406.72 1729.49,1406.72 1729.51,1406.72 1729.52,1406.72 1729.53,1406.72 1729.55,1406.72 1729.56,1406.72 1729.57,1406.72 1729.59,1406.72 1729.6,1406.72 1729.61,1406.72 1729.63,1406.72 1729.64,1406.72 1729.65,1406.72 1729.67,1406.72 1729.68,1406.72 1729.69,1406.72 1729.71,1406.72 1729.72,1406.72 1729.73,1406.72 1729.75,1406.72 1729.76,1406.72 1729.77,1406.72 1729.79,1406.71 1729.8,1406.71 1729.81,1406.71 1729.83,1406.71 1729.84,1406.71 1729.85,1406.71 1729.87,1406.71 1729.88,1406.71 1729.89,1406.71 1729.91,1406.71 1729.92,1406.71 1729.93,1406.71 1729.95,1406.71 1729.96,1406.71 1729.97,1406.71 1729.99,1406.71 1730,1406.71 1730.01,1406.71 1730.03,1406.71 1730.04,1406.71 1730.05,1406.71 1730.07,1406.71 1730.08,1406.71 1730.09,1406.71 1730.11,1406.71 1730.12,1406.71 1730.13,1406.71 1730.15,1406.71 1730.16,1406.71 1730.17,1406.71 1730.19,1406.71 1730.2,1406.71 1730.21,1406.71 1730.22,1406.71 1730.24,1406.71 1730.25,1406.71 1730.26,1406.71 1730.28,1406.71 1730.29,1406.71 1730.3,1406.71 1730.32,1406.71 1730.33,1406.71 1730.34,1406.71 1730.36,1406.71 1730.37,1406.71 1730.38,1406.71 1730.4,1406.71 1730.41,1406.71 1730.42,1406.71 1730.44,1406.71 1730.45,1406.71 1730.46,1406.71 1730.48,1406.71 1730.49,1406.71 1730.5,1406.71 1730.52,1406.71 1730.53,1406.71 1730.54,1406.71 1730.56,1406.71 1730.57,1406.71 1730.58,1406.71 1730.6,1406.71 1730.61,1406.71 1730.62,1406.71 1730.64,1406.71 1730.65,1406.71 1730.66,1406.71 1730.67,1406.71 1730.69,1406.71 1730.7,1406.71 1730.71,1406.71 1730.73,1406.71 1730.74,1406.71 1730.75,1406.71 1730.77,1406.71 1730.78,1406.71 1730.79,1406.71 1730.81,1406.71 1730.82,1406.71 1730.83,1406.71 1730.85,1406.71 1730.86,1406.71 1730.87,1406.7 1730.89,1406.7 1730.9,1406.7 1730.91,1406.7 1730.93,1406.7 1730.94,1406.7 1730.95,1406.7 1730.96,1406.7 1730.98,1406.7 1730.99,1406.7 1731,1406.7 1731.02,1406.7 1731.03,1406.7 1731.04,1406.7 1731.06,1406.7 1731.07,1406.7 1731.08,1406.7 1731.1,1406.7 1731.11,1406.7 1731.12,1406.7 1731.14,1406.7 1731.15,1406.7 1731.16,1406.7 1731.18,1406.7 1731.19,1406.7 1731.2,1406.7 1731.21,1406.7 1731.23,1406.7 1731.24,1406.7 1731.25,1406.7 1731.27,1406.7 1731.28,1406.7 1731.29,1406.7 1731.31,1406.7 1731.32,1406.7 1731.33,1406.7 1731.35,1406.7 1731.36,1406.7 1731.37,1406.7 1731.39,1406.7 1731.4,1406.7 1731.41,1406.7 1731.42,1406.7 1731.44,1406.7 1731.45,1406.7 1731.46,1406.7 1731.48,1406.7 1731.49,1406.7 1731.5,1406.7 1731.52,1406.7 1731.53,1406.7 1731.54,1406.7 1731.56,1406.7 1731.57,1406.7 1731.58,1406.7 1731.6,1406.7 1731.61,1406.7 1731.62,1406.7 1731.63,1406.7 1731.65,1406.7 1731.66,1406.7 1731.67,1406.7 1731.69,1406.7 1731.7,1406.7 1731.71,1406.7 1731.73,1406.7 1731.74,1406.7 1731.75,1406.7 1731.77,1406.7 1731.78,1406.7 1731.79,1406.7 1731.8,1406.7 1731.82,1406.7 1731.83,1406.7 1731.84,1406.7 1731.86,1406.7 1731.87,1406.7 1731.88,1406.7 1731.9,1406.7 1731.91,1406.7 1731.92,1406.69 1731.94,1406.69 1731.95,1406.69 1731.96,1406.69 1731.97,1406.69 1731.99,1406.69 1732,1406.69 1732.01,1406.69 1732.03,1406.69 1732.04,1406.69 1732.05,1406.69 1732.07,1406.69 1732.08,1406.69 1732.09,1406.69 1732.11,1406.69 1732.12,1406.69 1732.13,1406.69 1732.14,1406.69 1732.16,1406.69 1732.17,1406.69 1732.18,1406.69 1732.2,1406.69 1732.21,1406.69 1732.22,1406.69 1732.24,1406.69 1732.25,1406.69 1732.26,1406.69 1732.28,1406.69 1732.29,1406.69 1732.3,1406.69 1732.31,1406.69 1732.33,1406.69 1732.34,1406.69 1732.35,1406.69 1732.37,1406.69 1732.38,1406.69 1732.39,1406.69 1732.41,1406.69 1732.42,1406.69 1732.43,1406.69 1732.44,1406.69 1732.46,1406.69 1732.47,1406.69 1732.48,1406.69 1732.5,1406.69 1732.51,1406.69 1732.52,1406.69 1732.54,1406.69 1732.55,1406.69 1732.56,1406.69 1732.57,1406.69 1732.59,1406.69 1732.6,1406.69 1732.61,1406.69 1732.63,1406.69 1732.64,1406.69 1732.65,1406.69 1732.67,1406.69 1732.68,1406.69 1732.69,1406.69 1732.7,1406.69 1732.72,1406.69 1732.73,1406.69 1732.74,1406.69 1732.76,1406.69 1732.77,1406.69 1732.78,1406.69 1732.8,1406.69 1732.81,1406.69 1732.82,1406.69 1732.83,1406.69 1732.85,1406.69 1732.86,1406.69 1732.87,1406.69 1732.89,1406.69 1732.9,1406.69 1732.91,1406.69 1732.92,1406.69 1732.94,1406.69 1732.95,1406.68 1732.96,1406.68 1732.98,1406.68 1732.99,1406.68 1733,1406.68 1733.02,1406.68 1733.03,1406.68 1733.04,1406.68 1733.05,1406.68 1733.07,1406.68 1733.08,1406.68 1733.09,1406.68 1733.11,1406.68 1733.12,1406.68 1733.13,1406.68 1733.15,1406.68 1733.16,1406.68 1733.17,1406.68 1733.18,1406.68 1733.2,1406.68 1733.21,1406.68 1733.22,1406.68 1733.24,1406.68 1733.25,1406.68 1733.26,1406.68 1733.27,1406.68 1733.29,1406.68 1733.3,1406.68 1733.31,1406.68 1733.33,1406.68 1733.34,1406.68 1733.35,1406.68 1733.36,1406.68 1733.38,1406.68 1733.39,1406.68 1733.4,1406.68 1733.42,1406.68 1733.43,1406.68 1733.44,1406.68 1733.46,1406.68 1733.47,1406.68 1733.48,1406.68 1733.49,1406.68 1733.51,1406.68 1733.52,1406.68 1733.53,1406.68 1733.55,1406.68 1733.56,1406.68 1733.57,1406.68 1733.58,1406.68 1733.6,1406.68 1733.61,1406.68 1733.62,1406.68 1733.64,1406.68 1733.65,1406.68 1733.66,1406.68 1733.67,1406.68 1733.69,1406.68 1733.7,1406.68 1733.71,1406.68 1733.73,1406.68 1733.74,1406.68 1733.75,1406.68 1733.76,1406.68 1733.78,1406.68 1733.79,1406.68 1733.8,1406.68 1733.82,1406.68 1733.83,1406.68 1733.84,1406.68 1733.85,1406.68 1733.87,1406.68 1733.88,1406.68 1733.89,1406.68 1733.91,1406.68 1733.92,1406.68 1733.93,1406.68 1733.94,1406.68 1733.96,1406.67 1733.97,1406.67 1733.98,1406.67 1734,1406.67 1734.01,1406.67 1734.02,1406.67 1734.03,1406.67 1734.05,1406.67 1734.06,1406.67 1734.07,1406.67 1734.09,1406.67 1734.1,1406.67 1734.11,1406.67 1734.12,1406.67 1734.14,1406.67 1734.15,1406.67 1734.16,1406.67 1734.18,1406.67 1734.19,1406.67 1734.2,1406.67 1734.21,1406.67 1734.23,1406.67 1734.24,1406.67 1734.25,1406.67 1734.27,1406.67 1734.28,1406.67 1734.29,1406.67 1734.3,1406.67 1734.32,1406.67 1734.33,1406.67 1734.34,1406.67 1734.36,1406.67 1734.37,1406.67 1734.38,1406.67 1734.39,1406.67 1734.41,1406.67 1734.42,1406.67 1734.43,1406.67 1734.44,1406.67 1734.46,1406.67 1734.47,1406.67 1734.48,1406.67 1734.5,1406.67 1734.51,1406.67 1734.52,1406.67 1734.53,1406.67 1734.55,1406.67 1734.56,1406.67 1734.57,1406.67 1734.59,1406.67 1734.6,1406.67 1734.61,1406.67 1734.62,1406.67 1734.64,1406.67 1734.65,1406.67 1734.66,1406.67 1734.68,1406.67 1734.69,1406.67 1734.7,1406.67 1734.71,1406.67 1734.73,1406.67 1734.74,1406.67 1734.75,1406.67 1734.76,1406.67 1734.78,1406.67 1734.79,1406.67 1734.8,1406.67 1734.82,1406.67 1734.83,1406.67 1734.84,1406.67 1734.85,1406.67 1734.87,1406.67 1734.88,1406.67 1734.89,1406.67 1734.9,1406.67 1734.92,1406.67 1734.93,1406.67 1734.94,1406.66 1734.96,1406.66 1734.97,1406.66 1734.98,1406.66 1734.99,1406.66 1735.01,1406.66 1735.02,1406.66 1735.03,1406.66 1735.05,1406.66 1735.06,1406.66 1735.07,1406.66 1735.08,1406.66 1735.1,1406.66 1735.11,1406.66 1735.12,1406.66 1735.13,1406.66 1735.15,1406.66 1735.16,1406.66 1735.17,1406.66 1735.19,1406.66 1735.2,1406.66 1735.21,1406.66 1735.22,1406.66 1735.24,1406.66 1735.25,1406.66 1735.26,1406.66 1735.27,1406.66 1735.29,1406.66 1735.3,1406.66 1735.31,1406.66 1735.32,1406.66 1735.34,1406.66 1735.35,1406.66 1735.36,1406.66 1735.38,1406.66 1735.39,1406.66 1735.4,1406.66 1735.41,1406.66 1735.43,1406.66 1735.44,1406.66 1735.45,1406.66 1735.46,1406.66 1735.48,1406.66 1735.49,1406.66 1735.5,1406.66 1735.52,1406.66 1735.53,1406.66 1735.54,1406.66 1735.55,1406.66 1735.57,1406.66 1735.58,1406.66 1735.59,1406.66 1735.6,1406.66 1735.62,1406.66 1735.63,1406.66 1735.64,1406.66 1735.65,1406.66 1735.67,1406.66 1735.68,1406.66 1735.69,1406.66 1735.71,1406.66 1735.72,1406.66 1735.73,1406.66 1735.74,1406.66 1735.76,1406.66 1735.77,1406.66 1735.78,1406.66 1735.79,1406.66 1735.81,1406.66 1735.82,1406.66 1735.83,1406.66 1735.84,1406.66 1735.86,1406.66 1735.87,1406.66 1735.88,1406.66 1735.9,1406.65 1735.91,1406.65 1735.92,1406.65 1735.93,1406.65 1735.95,1406.65 1735.96,1406.65 1735.97,1406.65 1735.98,1406.65 1736,1406.65 1736.01,1406.65 1736.02,1406.65 1736.03,1406.65 1736.05,1406.65 1736.06,1406.65 1736.07,1406.65 1736.08,1406.65 1736.1,1406.65 1736.11,1406.65 1736.12,1406.65 1736.14,1406.65 1736.15,1406.65 1736.16,1406.65 1736.17,1406.65 1736.19,1406.65 1736.2,1406.65 1736.21,1406.65 1736.22,1406.65 1736.24,1406.65 1736.25,1406.65 1736.26,1406.65 1736.27,1406.65 1736.29,1406.65 1736.3,1406.65 1736.31,1406.65 1736.32,1406.65 1736.34,1406.65 1736.35,1406.65 1736.36,1406.65 1736.37,1406.65 1736.39,1406.65 1736.4,1406.65 1736.41,1406.65 1736.43,1406.65 1736.44,1406.65 1736.45,1406.65 1736.46,1406.65 1736.48,1406.65 1736.49,1406.65 1736.5,1406.65 1736.51,1406.65 1736.53,1406.65 1736.54,1406.65 1736.55,1406.65 1736.56,1406.65 1736.58,1406.65 1736.59,1406.65 1736.6,1406.65 1736.61,1406.65 1736.63,1406.65 1736.64,1406.65 1736.65,1406.65 1736.66,1406.65 1736.68,1406.65 1736.69,1406.65 1736.7,1406.65 1736.71,1406.65 1736.73,1406.65 1736.74,1406.65 1736.75,1406.65 1736.76,1406.65 1736.78,1406.65 1736.79,1406.65 1736.8,1406.65 1736.81,1406.65 1736.83,1406.65 1736.84,1406.64 1736.85,1406.64 1736.87,1406.64 1736.88,1406.64 1736.89,1406.64 1736.9,1406.64 1736.92,1406.64 1736.93,1406.64 1736.94,1406.64 1736.95,1406.64 1736.97,1406.64 1736.98,1406.64 1736.99,1406.64 1737,1406.64 1737.02,1406.64 1737.03,1406.64 1737.04,1406.64 1737.05,1406.64 1737.07,1406.64 1737.08,1406.64 1737.09,1406.64 1737.1,1406.64 1737.12,1406.64 1737.13,1406.64 1737.14,1406.64 1737.15,1406.64 1737.17,1406.64 1737.18,1406.64 1737.19,1406.64 1737.2,1406.64 1737.22,1406.64 1737.23,1406.64 1737.24,1406.64 1737.25,1406.64 1737.27,1406.64 1737.28,1406.64 1737.29,1406.64 1737.3,1406.64 1737.32,1406.64 1737.33,1406.64 1737.34,1406.64 1737.35,1406.64 1737.37,1406.64 1737.38,1406.64 1737.39,1406.64 1737.4,1406.64 1737.42,1406.64 1737.43,1406.64 1737.44,1406.64 1737.45,1406.64 1737.47,1406.64 1737.48,1406.64 1737.49,1406.64 1737.5,1406.64 1737.52,1406.64 1737.53,1406.64 1737.54,1406.64 1737.55,1406.64 1737.57,1406.64 1737.58,1406.64 1737.59,1406.64 1737.6,1406.64 1737.62,1406.64 1737.63,1406.64 1737.64,1406.64 1737.65,1406.64 1737.67,1406.64 1737.68,1406.64 1737.69,1406.64 1737.7,1406.64 1737.71,1406.64 1737.73,1406.64 1737.74,1406.64 1737.75,1406.64 1737.76,1406.63 1737.78,1406.63 1737.79,1406.63 1737.8,1406.63 1737.81,1406.63 1737.83,1406.63 1737.84,1406.63 1737.85,1406.63 1737.86,1406.63 1737.88,1406.63 1737.89,1406.63 1737.9,1406.63 1737.91,1406.63 1737.93,1406.63 1737.94,1406.63 1737.95,1406.63 1737.96,1406.63 1737.98,1406.63 1737.99,1406.63 1738,1406.63 1738.01,1406.63 1738.03,1406.63 1738.04,1406.63 1738.05,1406.63 1738.06,1406.63 1738.08,1406.63 1738.09,1406.63 1738.1,1406.63 1738.11,1406.63 1738.13,1406.63 1738.14,1406.63 1738.15,1406.63 1738.16,1406.63 1738.17,1406.63 1738.19,1406.63 1738.2,1406.63 1738.21,1406.63 1738.22,1406.63 1738.24,1406.63 1738.25,1406.63 1738.26,1406.63 1738.27,1406.63 1738.29,1406.63 1738.3,1406.63 1738.31,1406.63 1738.32,1406.63 1738.34,1406.63 1738.35,1406.63 1738.36,1406.63 1738.37,1406.63 1738.39,1406.63 1738.4,1406.63 1738.41,1406.63 1738.42,1406.63 1738.43,1406.63 1738.45,1406.63 1738.46,1406.63 1738.47,1406.63 1738.48,1406.63 1738.5,1406.63 1738.51,1406.63 1738.52,1406.63 1738.53,1406.63 1738.55,1406.63 1738.56,1406.63 1738.57,1406.63 1738.58,1406.63 1738.6,1406.63 1738.61,1406.63 1738.62,1406.63 1738.63,1406.63 1738.64,1406.63 1738.66,1406.63 1738.67,1406.63 1738.68,1406.62 1738.69,1406.62 1738.71,1406.62 1738.72,1406.62 1738.73,1406.62 1738.74,1406.62 1738.76,1406.62 1738.77,1406.62 1738.78,1406.62 1738.79,1406.62 1738.81,1406.62 1738.82,1406.62 1738.83,1406.62 1738.84,1406.62 1738.85,1406.62 1738.87,1406.62 1738.88,1406.62 1738.89,1406.62 1738.9,1406.62 1738.92,1406.62 1738.93,1406.62 1738.94,1406.62 1738.95,1406.62 1738.97,1406.62 1738.98,1406.62 1738.99,1406.62 1739,1406.62 1739.01,1406.62 1739.03,1406.62 1739.04,1406.62 1739.05,1406.62 1739.06,1406.62 1739.08,1406.62 1739.09,1406.62 1739.1,1406.62 1739.11,1406.62 1739.13,1406.62 1739.14,1406.62 1739.15,1406.62 1739.16,1406.62 1739.17,1406.62 1739.19,1406.62 1739.2,1406.62 1739.21,1406.62 1739.22,1406.62 1739.24,1406.62 1739.25,1406.62 1739.26,1406.62 1739.27,1406.62 1739.29,1406.62 1739.3,1406.62 1739.31,1406.62 1739.32,1406.62 1739.33,1406.62 1739.35,1406.62 1739.36,1406.62 1739.37,1406.62 1739.38,1406.62 1739.4,1406.62 1739.41,1406.62 1739.42,1406.62 1739.43,1406.62 1739.44,1406.62 1739.46,1406.62 1739.47,1406.62 1739.48,1406.62 1739.49,1406.62 1739.51,1406.62 1739.52,1406.62 1739.53,1406.62 1739.54,1406.62 1739.56,1406.62 1739.57,1406.61 1739.58,1406.61 1739.59,1406.61 1739.6,1406.61 1739.62,1406.61 1739.63,1406.61 1739.64,1406.61 1739.65,1406.61 1739.67,1406.61 1739.68,1406.61 1739.69,1406.61 1739.7,1406.61 1739.71,1406.61 1739.73,1406.61 1739.74,1406.61 1739.75,1406.61 1739.76,1406.61 1739.78,1406.61 1739.79,1406.61 1739.8,1406.61 1739.81,1406.61 1739.82,1406.61 1739.84,1406.61 1739.85,1406.61 1739.86,1406.61 1739.87,1406.61 1739.89,1406.61 1739.9,1406.61 1739.91,1406.61 1739.92,1406.61 1739.93,1406.61 1739.95,1406.61 1739.96,1406.61 1739.97,1406.61 1739.98,1406.61 1740,1406.61 1740.01,1406.61 1740.02,1406.61 1740.03,1406.61 1740.04,1406.61 1740.06,1406.61 1740.07,1406.61 1740.08,1406.61 1740.09,1406.61 1740.11,1406.61 1740.12,1406.61 1740.13,1406.61 1740.14,1406.61 1740.15,1406.61 1740.17,1406.61 1740.18,1406.61 1740.19,1406.61 1740.2,1406.61 1740.22,1406.61 1740.23,1406.61 1740.24,1406.61 1740.25,1406.61 1740.26,1406.61 1740.28,1406.61 1740.29,1406.61 1740.3,1406.61 1740.31,1406.61 1740.32,1406.61 1740.34,1406.61 1740.35,1406.61 1740.36,1406.61 1740.37,1406.61 1740.39,1406.61 1740.4,1406.61 1740.41,1406.61 1740.42,1406.61 1740.43,1406.61 1740.45,1406.6 1740.46,1406.6 1740.47,1406.6 1740.48,1406.6 1740.49,1406.6 1740.51,1406.6 1740.52,1406.6 1740.53,1406.6 1740.54,1406.6 1740.56,1406.6 1740.57,1406.6 1740.58,1406.6 1740.59,1406.6 1740.6,1406.6 1740.62,1406.6 1740.63,1406.6 1740.64,1406.6 1740.65,1406.6 1740.66,1406.6 1740.68,1406.6 1740.69,1406.6 1740.7,1406.6 1740.71,1406.6 1740.73,1406.6 1740.74,1406.6 1740.75,1406.6 1740.76,1406.6 1740.77,1406.6 1740.79,1406.6 1740.8,1406.6 1740.81,1406.6 1740.82,1406.6 1740.83,1406.6 1740.85,1406.6 1740.86,1406.6 1740.87,1406.6 1740.88,1406.6 1740.9,1406.6 1740.91,1406.6 1740.92,1406.6 1740.93,1406.6 1740.94,1406.6 1740.96,1406.6 1740.97,1406.6 1740.98,1406.6 1740.99,1406.6 1741,1406.6 1741.02,1406.6 1741.03,1406.6 1741.04,1406.6 1741.05,1406.6 1741.06,1406.6 1741.08,1406.6 1741.09,1406.6 1741.1,1406.6 1741.11,1406.6 1741.13,1406.6 1741.14,1406.6 1741.15,1406.6 1741.16,1406.6 1741.17,1406.6 1741.19,1406.6 1741.2,1406.6 1741.21,1406.6 1741.22,1406.6 1741.23,1406.6 1741.25,1406.6 1741.26,1406.6 1741.27,1406.6 1741.28,1406.6 1741.29,1406.6 1741.31,1406.59 1741.32,1406.59 1741.33,1406.59 1741.34,1406.59 1741.35,1406.59 1741.37,1406.59 1741.38,1406.59 1741.39,1406.59 1741.4,1406.59 1741.41,1406.59 1741.43,1406.59 1741.44,1406.59 1741.45,1406.59 1741.46,1406.59 1741.48,1406.59 1741.49,1406.59 1741.5,1406.59 1741.51,1406.59 1741.52,1406.59 1741.54,1406.59 1741.55,1406.59 1741.56,1406.59 1741.57,1406.59 1741.58,1406.59 1741.6,1406.59 1741.61,1406.59 1741.62,1406.59 1741.63,1406.59 1741.64,1406.59 1741.66,1406.59 1741.67,1406.59 1741.68,1406.59 1741.69,1406.59 1741.7,1406.59 1741.72,1406.59 1741.73,1406.59 1741.74,1406.59 1741.75,1406.59 1741.76,1406.59 1741.78,1406.59 1741.79,1406.59 1741.8,1406.59 1741.81,1406.59 1741.82,1406.59 1741.84,1406.59 1741.85,1406.59 1741.86,1406.59 1741.87,1406.59 1741.88,1406.59 1741.9,1406.59 1741.91,1406.59 1741.92,1406.59 1741.93,1406.59 1741.94,1406.59 1741.96,1406.59 1741.97,1406.59 1741.98,1406.59 1741.99,1406.59 1742,1406.59 1742.02,1406.59 1742.03,1406.59 1742.04,1406.59 1742.05,1406.59 1742.06,1406.59 1742.08,1406.59 1742.09,1406.59 1742.1,1406.59 1742.11,1406.59 1742.12,1406.59 1742.14,1406.59 1742.15,1406.59 1742.16,1406.58 1742.17,1406.58 1742.18,1406.58 1742.2,1406.58 1742.21,1406.58 1742.22,1406.58 1742.23,1406.58 1742.24,1406.58 1742.26,1406.58 1742.27,1406.58 1742.28,1406.58 1742.29,1406.58 1742.3,1406.58 1742.32,1406.58 1742.33,1406.58 1742.34,1406.58 1742.35,1406.58 1742.36,1406.58 1742.37,1406.58 1742.39,1406.58 1742.4,1406.58 1742.41,1406.58 1742.42,1406.58 1742.43,1406.58 1742.45,1406.58 1742.46,1406.58 1742.47,1406.58 1742.48,1406.58 1742.49,1406.58 1742.51,1406.58 1742.52,1406.58 1742.53,1406.58 1742.54,1406.58 1742.55,1406.58 1742.57,1406.58 1742.58,1406.58 1742.59,1406.58 1742.6,1406.58 1742.61,1406.58 1742.63,1406.58 1742.64,1406.58 1742.65,1406.58 1742.66,1406.58 1742.67,1406.58 1742.69,1406.58 1742.7,1406.58 1742.71,1406.58 1742.72,1406.58 1742.73,1406.58 1742.74,1406.58 1742.76,1406.58 1742.77,1406.58 1742.78,1406.58 1742.79,1406.58 1742.8,1406.58 1742.82,1406.58 1742.83,1406.58 1742.84,1406.58 1742.85,1406.58 1742.86,1406.58 1742.88,1406.58 1742.89,1406.58 1742.9,1406.58 1742.91,1406.58 1742.92,1406.58 1742.94,1406.58 1742.95,1406.58 1742.96,1406.58 1742.97,1406.58 1742.98,1406.58 1742.99,1406.57 1743.01,1406.57 1743.02,1406.57 1743.03,1406.57 1743.04,1406.57 1743.05,1406.57 1743.07,1406.57 1743.08,1406.57 1743.09,1406.57 1743.1,1406.57 1743.11,1406.57 1743.13,1406.57 1743.14,1406.57 1743.15,1406.57 1743.16,1406.57 1743.17,1406.57 1743.18,1406.57 1743.2,1406.57 1743.21,1406.57 1743.22,1406.57 1743.23,1406.57 1743.24,1406.57 1743.26,1406.57 1743.27,1406.57 1743.28,1406.57 1743.29,1406.57 1743.3,1406.57 1743.32,1406.57 1743.33,1406.57 1743.34,1406.57 1743.35,1406.57 1743.36,1406.57 1743.37,1406.57 1743.39,1406.57 1743.4,1406.57 1743.41,1406.57 1743.42,1406.57 1743.43,1406.57 1743.45,1406.57 1743.46,1406.57 1743.47,1406.57 1743.48,1406.57 1743.49,1406.57 1743.5,1406.57 1743.52,1406.57 1743.53,1406.57 1743.54,1406.57 1743.55,1406.57 1743.56,1406.57 1743.58,1406.57 1743.59,1406.57 1743.6,1406.57 1743.61,1406.57 1743.62,1406.57 1743.63,1406.57 1743.65,1406.57 1743.66,1406.57 1743.67,1406.57 1743.68,1406.57 1743.69,1406.57 1743.71,1406.57 1743.72,1406.57 1743.73,1406.57 1743.74,1406.57 1743.75,1406.57 1743.76,1406.57 1743.78,1406.57 1743.79,1406.57 1743.8,1406.57 1743.81,1406.57 1743.82,1406.56 1743.84,1406.56 1743.85,1406.56 1743.86,1406.56 1743.87,1406.56 1743.88,1406.56 1743.89,1406.56 1743.91,1406.56 1743.92,1406.56 1743.93,1406.56 1743.94,1406.56 1743.95,1406.56 1743.97,1406.56 1743.98,1406.56 1743.99,1406.56 1744,1406.56 1744.01,1406.56 1744.02,1406.56 1744.04,1406.56 1744.05,1406.56 1744.06,1406.56 1744.07,1406.56 1744.08,1406.56 1744.09,1406.56 1744.11,1406.56 1744.12,1406.56 1744.13,1406.56 1744.14,1406.56 1744.15,1406.56 1744.17,1406.56 1744.18,1406.56 1744.19,1406.56 1744.2,1406.56 1744.21,1406.56 1744.22,1406.56 1744.24,1406.56 1744.25,1406.56 1744.26,1406.56 1744.27,1406.56 1744.28,1406.56 1744.29,1406.56 1744.31,1406.56 1744.32,1406.56 1744.33,1406.56 1744.34,1406.56 1744.35,1406.56 1744.36,1406.56 1744.38,1406.56 1744.39,1406.56 1744.4,1406.56 1744.41,1406.56 1744.42,1406.56 1744.44,1406.56 1744.45,1406.56 1744.46,1406.56 1744.47,1406.56 1744.48,1406.56 1744.49,1406.56 1744.51,1406.56 1744.52,1406.56 1744.53,1406.56 1744.54,1406.56 1744.55,1406.56 1744.56,1406.56 1744.58,1406.56 1744.59,1406.56 1744.6,1406.56 1744.61,1406.56 1744.62,1406.56 1744.63,1406.55 1744.65,1406.55 1744.66,1406.55 1744.67,1406.55 1744.68,1406.55 1744.69,1406.55 1744.7,1406.55 1744.72,1406.55 1744.73,1406.55 1744.74,1406.55 1744.75,1406.55 1744.76,1406.55 1744.77,1406.55 1744.79,1406.55 1744.8,1406.55 1744.81,1406.55 1744.82,1406.55 1744.83,1406.55 1744.85,1406.55 1744.86,1406.55 1744.87,1406.55 1744.88,1406.55 1744.89,1406.55 1744.9,1406.55 1744.92,1406.55 1744.93,1406.55 1744.94,1406.55 1744.95,1406.55 1744.96,1406.55 1744.97,1406.55 1744.99,1406.55 1745,1406.55 1745.01,1406.55 1745.02,1406.55 1745.03,1406.55 1745.04,1406.55 1745.06,1406.55 1745.07,1406.55 1745.08,1406.55 1745.09,1406.55 1745.1,1406.55 1745.11,1406.55 1745.13,1406.55 1745.14,1406.55 1745.15,1406.55 1745.16,1406.55 1745.17,1406.55 1745.18,1406.55 1745.2,1406.55 1745.21,1406.55 1745.22,1406.55 1745.23,1406.55 1745.24,1406.55 1745.25,1406.55 1745.26,1406.55 1745.28,1406.55 1745.29,1406.55 1745.3,1406.55 1745.31,1406.55 1745.32,1406.55 1745.33,1406.55 1745.35,1406.55 1745.36,1406.55 1745.37,1406.55 1745.38,1406.55 1745.39,1406.55 1745.4,1406.55 1745.42,1406.55 1745.43,1406.54 1745.44,1406.54 1745.45,1406.54 1745.46,1406.54 1745.47,1406.54 1745.49,1406.54 1745.5,1406.54 1745.51,1406.54 1745.52,1406.54 1745.53,1406.54 1745.54,1406.54 1745.56,1406.54 1745.57,1406.54 1745.58,1406.54 1745.59,1406.54 1745.6,1406.54 1745.61,1406.54 1745.63,1406.54 1745.64,1406.54 1745.65,1406.54 1745.66,1406.54 1745.67,1406.54 1745.68,1406.54 1745.69,1406.54 1745.71,1406.54 1745.72,1406.54 1745.73,1406.54 1745.74,1406.54 1745.75,1406.54 1745.76,1406.54 1745.78,1406.54 1745.79,1406.54 1745.8,1406.54 1745.81,1406.54 1745.82,1406.54 1745.83,1406.54 1745.85,1406.54 1745.86,1406.54 1745.87,1406.54 1745.88,1406.54 1745.89,1406.54 1745.9,1406.54 1745.91,1406.54 1745.93,1406.54 1745.94,1406.54 1745.95,1406.54 1745.96,1406.54 1745.97,1406.54 1745.98,1406.54 1746,1406.54 1746.01,1406.54 1746.02,1406.54 1746.03,1406.54 1746.04,1406.54 1746.05,1406.54 1746.07,1406.54 1746.08,1406.54 1746.09,1406.54 1746.1,1406.54 1746.11,1406.54 1746.12,1406.54 1746.13,1406.54 1746.15,1406.54 1746.16,1406.54 1746.17,1406.54 1746.18,1406.54 1746.19,1406.54 1746.2,1406.54 1746.22,1406.54 1746.23,1406.53 1746.24,1406.53 1746.25,1406.53 1746.26,1406.53 1746.27,1406.53 1746.28,1406.53 1746.3,1406.53 1746.31,1406.53 1746.32,1406.53 1746.33,1406.53 1746.34,1406.53 1746.35,1406.53 1746.37,1406.53 1746.38,1406.53 1746.39,1406.53 1746.4,1406.53 1746.41,1406.53 1746.42,1406.53 1746.43,1406.53 1746.45,1406.53 1746.46,1406.53 1746.47,1406.53 1746.48,1406.53 1746.49,1406.53 1746.5,1406.53 1746.51,1406.53 1746.53,1406.53 1746.54,1406.53 1746.55,1406.53 1746.56,1406.53 1746.57,1406.53 1746.58,1406.53 1746.6,1406.53 1746.61,1406.53 1746.62,1406.53 1746.63,1406.53 1746.64,1406.53 1746.65,1406.53 1746.66,1406.53 1746.68,1406.53 1746.69,1406.53 1746.7,1406.53 1746.71,1406.53 1746.72,1406.53 1746.73,1406.53 1746.74,1406.53 1746.76,1406.53 1746.77,1406.53 1746.78,1406.53 1746.79,1406.53 1746.8,1406.53 1746.81,1406.53 1746.83,1406.53 1746.84,1406.53 1746.85,1406.53 1746.86,1406.53 1746.87,1406.53 1746.88,1406.53 1746.89,1406.53 1746.91,1406.53 1746.92,1406.53 1746.93,1406.53 1746.94,1406.53 1746.95,1406.53 1746.96,1406.53 1746.97,1406.53 1746.99,1406.53 1747,1406.53 1747.01,1406.52 1747.02,1406.52 1747.03,1406.52 1747.04,1406.52 1747.05,1406.52 1747.07,1406.52 1747.08,1406.52 1747.09,1406.52 1747.1,1406.52 1747.11,1406.52 1747.12,1406.52 1747.13,1406.52 1747.15,1406.52 1747.16,1406.52 1747.17,1406.52 1747.18,1406.52 1747.19,1406.52 1747.2,1406.52 1747.21,1406.52 1747.23,1406.52 1747.24,1406.52 1747.25,1406.52 1747.26,1406.52 1747.27,1406.52 1747.28,1406.52 1747.29,1406.52 1747.31,1406.52 1747.32,1406.52 1747.33,1406.52 1747.34,1406.52 1747.35,1406.52 1747.36,1406.52 1747.37,1406.52 1747.39,1406.52 1747.4,1406.52 1747.41,1406.52 1747.42,1406.52 1747.43,1406.52 1747.44,1406.52 1747.45,1406.52 1747.47,1406.52 1747.48,1406.52 1747.49,1406.52 1747.5,1406.52 1747.51,1406.52 1747.52,1406.52 1747.53,1406.52 1747.55,1406.52 1747.56,1406.52 1747.57,1406.52 1747.58,1406.52 1747.59,1406.52 1747.6,1406.52 1747.61,1406.52 1747.63,1406.52 1747.64,1406.52 1747.65,1406.52 1747.66,1406.52 1747.67,1406.52 1747.68,1406.52 1747.69,1406.52 1747.71,1406.52 1747.72,1406.52 1747.73,1406.52 1747.74,1406.52 1747.75,1406.52 1747.76,1406.52 1747.77,1406.51 1747.78,1406.51 1747.8,1406.51 1747.81,1406.51 1747.82,1406.51 1747.83,1406.51 1747.84,1406.51 1747.85,1406.51 1747.86,1406.51 1747.88,1406.51 1747.89,1406.51 1747.9,1406.51 1747.91,1406.51 1747.92,1406.51 1747.93,1406.51 1747.94,1406.51 1747.96,1406.51 1747.97,1406.51 1747.98,1406.51 1747.99,1406.51 1748,1406.51 1748.01,1406.51 1748.02,1406.51 1748.03,1406.51 1748.05,1406.51 1748.06,1406.51 1748.07,1406.51 1748.08,1406.51 1748.09,1406.51 1748.1,1406.51 1748.11,1406.51 1748.13,1406.51 1748.14,1406.51 1748.15,1406.51 1748.16,1406.51 1748.17,1406.51 1748.18,1406.51 1748.19,1406.51 1748.2,1406.51 1748.22,1406.51 1748.23,1406.51 1748.24,1406.51 1748.25,1406.51 1748.26,1406.51 1748.27,1406.51 1748.28,1406.51 1748.3,1406.51 1748.31,1406.51 1748.32,1406.51 1748.33,1406.51 1748.34,1406.51 1748.35,1406.51 1748.36,1406.51 1748.37,1406.51 1748.39,1406.51 1748.4,1406.51 1748.41,1406.51 1748.42,1406.51 1748.43,1406.51 1748.44,1406.51 1748.45,1406.51 1748.46,1406.51 1748.48,1406.51 1748.49,1406.51 1748.5,1406.51 1748.51,1406.51 1748.52,1406.51 1748.53,1406.5 1748.54,1406.5 1748.56,1406.5 1748.57,1406.5 1748.58,1406.5 1748.59,1406.5 1748.6,1406.5 1748.61,1406.5 1748.62,1406.5 1748.63,1406.5 1748.65,1406.5 1748.66,1406.5 1748.67,1406.5 1748.68,1406.5 1748.69,1406.5 1748.7,1406.5 1748.71,1406.5 1748.72,1406.5 1748.74,1406.5 1748.75,1406.5 1748.76,1406.5 1748.77,1406.5 1748.78,1406.5 1748.79,1406.5 1748.8,1406.5 1748.81,1406.5 1748.83,1406.5 1748.84,1406.5 1748.85,1406.5 1748.86,1406.5 1748.87,1406.5 1748.88,1406.5 1748.89,1406.5 1748.9,1406.5 1748.92,1406.5 1748.93,1406.5 1748.94,1406.5 1748.95,1406.5 1748.96,1406.5 1748.97,1406.5 1748.98,1406.5 1748.99,1406.5 1749.01,1406.5 1749.02,1406.5 1749.03,1406.5 1749.04,1406.5 1749.05,1406.5 1749.06,1406.5 1749.07,1406.5 1749.08,1406.5 1749.1,1406.5 1749.11,1406.5 1749.12,1406.5 1749.13,1406.5 1749.14,1406.5 1749.15,1406.5 1749.16,1406.5 1749.17,1406.5 1749.19,1406.5 1749.2,1406.5 1749.21,1406.5 1749.22,1406.5 1749.23,1406.5 1749.24,1406.5 1749.25,1406.5 1749.26,1406.5 1749.28,1406.5 1749.29,1406.49 1749.3,1406.49 1749.31,1406.49 1749.32,1406.49 1749.33,1406.49 1749.34,1406.49 1749.35,1406.49 1749.36,1406.49 1749.38,1406.49 1749.39,1406.49 1749.4,1406.49 1749.41,1406.49 1749.42,1406.49 1749.43,1406.49 1749.44,1406.49 1749.45,1406.49 1749.47,1406.49 1749.48,1406.49 1749.49,1406.49 1749.5,1406.49 1749.51,1406.49 1749.52,1406.49 1749.53,1406.49 1749.54,1406.49 1749.56,1406.49 1749.57,1406.49 1749.58,1406.49 1749.59,1406.49 1749.6,1406.49 1749.61,1406.49 1749.62,1406.49 1749.63,1406.49 1749.64,1406.49 1749.66,1406.49 1749.67,1406.49 1749.68,1406.49 1749.69,1406.49 1749.7,1406.49 1749.71,1406.49 1749.72,1406.49 1749.73,1406.49 1749.75,1406.49 1749.76,1406.49 1749.77,1406.49 1749.78,1406.49 1749.79,1406.49 1749.8,1406.49 1749.81,1406.49 1749.82,1406.49 1749.83,1406.49 1749.85,1406.49 1749.86,1406.49 1749.87,1406.49 1749.88,1406.49 1749.89,1406.49 1749.9,1406.49 1749.91,1406.49 1749.92,1406.49 1749.93,1406.49 1749.95,1406.49 1749.96,1406.49 1749.97,1406.49 1749.98,1406.49 1749.99,1406.49 1750,1406.49 1750.01,1406.49 1750.02,1406.49 1750.03,1406.48 1750.05,1406.48 1750.06,1406.48 1750.07,1406.48 1750.08,1406.48 1750.09,1406.48 1750.1,1406.48 1750.11,1406.48 1750.12,1406.48 1750.13,1406.48 1750.15,1406.48 1750.16,1406.48 1750.17,1406.48 1750.18,1406.48 1750.19,1406.48 1750.2,1406.48 1750.21,1406.48 1750.22,1406.48 1750.24,1406.48 1750.25,1406.48 1750.26,1406.48 1750.27,1406.48 1750.28,1406.48 1750.29,1406.48 1750.3,1406.48 1750.31,1406.48 1750.32,1406.48 1750.33,1406.48 1750.35,1406.48 1750.36,1406.48 1750.37,1406.48 1750.38,1406.48 1750.39,1406.48 1750.4,1406.48 1750.41,1406.48 1750.42,1406.48 1750.43,1406.48 1750.45,1406.48 1750.46,1406.48 1750.47,1406.48 1750.48,1406.48 1750.49,1406.48 1750.5,1406.48 1750.51,1406.48 1750.52,1406.48 1750.53,1406.48 1750.55,1406.48 1750.56,1406.48 1750.57,1406.48 1750.58,1406.48 1750.59,1406.48 1750.6,1406.48 1750.61,1406.48 1750.62,1406.48 1750.63,1406.48 1750.65,1406.48 1750.66,1406.48 1750.67,1406.48 1750.68,1406.48 1750.69,1406.48 1750.7,1406.48 1750.71,1406.48 1750.72,1406.48 1750.73,1406.48 1750.74,1406.48 1750.76,1406.48 1750.77,1406.47 1750.78,1406.47 1750.79,1406.47 1750.8,1406.47 1750.81,1406.47 1750.82,1406.47 1750.83,1406.47 1750.84,1406.47 1750.86,1406.47 1750.87,1406.47 1750.88,1406.47 1750.89,1406.47 1750.9,1406.47 1750.91,1406.47 1750.92,1406.47 1750.93,1406.47 1750.94,1406.47 1750.95,1406.47 1750.97,1406.47 1750.98,1406.47 1750.99,1406.47 1751,1406.47 1751.01,1406.47 1751.02,1406.47 1751.03,1406.47 1751.04,1406.47 1751.05,1406.47 1751.06,1406.47 1751.08,1406.47 1751.09,1406.47 1751.1,1406.47 1751.11,1406.47 1751.12,1406.47 1751.13,1406.47 1751.14,1406.47 1751.15,1406.47 1751.16,1406.47 1751.18,1406.47 1751.19,1406.47 1751.2,1406.47 1751.21,1406.47 1751.22,1406.47 1751.23,1406.47 1751.24,1406.47 1751.25,1406.47 1751.26,1406.47 1751.27,1406.47 1751.29,1406.47 1751.3,1406.47 1751.31,1406.47 1751.32,1406.47 1751.33,1406.47 1751.34,1406.47 1751.35,1406.47 1751.36,1406.47 1751.37,1406.47 1751.38,1406.47 1751.39,1406.47 1751.41,1406.47 1751.42,1406.47 1751.43,1406.47 1751.44,1406.47 1751.45,1406.47 1751.46,1406.47 1751.47,1406.47 1751.48,1406.47 1751.49,1406.47 1751.5,1406.46 1751.52,1406.46 1751.53,1406.46 1751.54,1406.46 1751.55,1406.46 1751.56,1406.46 1751.57,1406.46 1751.58,1406.46 1751.59,1406.46 1751.6,1406.46 1751.61,1406.46 1751.63,1406.46 1751.64,1406.46 1751.65,1406.46 1751.66,1406.46 1751.67,1406.46 1751.68,1406.46 1751.69,1406.46 1751.7,1406.46 1751.71,1406.46 1751.72,1406.46 1751.73,1406.46 1751.75,1406.46 1751.76,1406.46 1751.77,1406.46 1751.78,1406.46 1751.79,1406.46 1751.8,1406.46 1751.81,1406.46 1751.82,1406.46 1751.83,1406.46 1751.84,1406.46 1751.86,1406.46 1751.87,1406.46 1751.88,1406.46 1751.89,1406.46 1751.9,1406.46 1751.91,1406.46 1751.92,1406.46 1751.93,1406.46 1751.94,1406.46 1751.95,1406.46 1751.96,1406.46 1751.98,1406.46 1751.99,1406.46 1752,1406.46 1752.01,1406.46 1752.02,1406.46 1752.03,1406.46 1752.04,1406.46 1752.05,1406.46 1752.06,1406.46 1752.07,1406.46 1752.08,1406.46 1752.1,1406.46 1752.11,1406.46 1752.12,1406.46 1752.13,1406.46 1752.14,1406.46 1752.15,1406.46 1752.16,1406.46 1752.17,1406.46 1752.18,1406.46 1752.19,1406.46 1752.2,1406.46 1752.22,1406.46 1752.23,1406.45 1752.24,1406.45 1752.25,1406.45 1752.26,1406.45 1752.27,1406.45 1752.28,1406.45 1752.29,1406.45 1752.3,1406.45 1752.31,1406.45 1752.32,1406.45 1752.34,1406.45 1752.35,1406.45 1752.36,1406.45 1752.37,1406.45 1752.38,1406.45 1752.39,1406.45 1752.4,1406.45 1752.41,1406.45 1752.42,1406.45 1752.43,1406.45 1752.44,1406.45 1752.46,1406.45 1752.47,1406.45 1752.48,1406.45 1752.49,1406.45 1752.5,1406.45 1752.51,1406.45 1752.52,1406.45 1752.53,1406.45 1752.54,1406.45 1752.55,1406.45 1752.56,1406.45 1752.57,1406.45 1752.59,1406.45 1752.6,1406.45 1752.61,1406.45 1752.62,1406.45 1752.63,1406.45 1752.64,1406.45 1752.65,1406.45 1752.66,1406.45 1752.67,1406.45 1752.68,1406.45 1752.69,1406.45 1752.7,1406.45 1752.72,1406.45 1752.73,1406.45 1752.74,1406.45 1752.75,1406.45 1752.76,1406.45 1752.77,1406.45 1752.78,1406.45 1752.79,1406.45 1752.8,1406.45 1752.81,1406.45 1752.82,1406.45 1752.83,1406.45 1752.85,1406.45 1752.86,1406.45 1752.87,1406.45 1752.88,1406.45 1752.89,1406.45 1752.9,1406.45 1752.91,1406.45 1752.92,1406.45 1752.93,1406.44 1752.94,1406.44 1752.95,1406.44 1752.96,1406.44 1752.98,1406.44 1752.99,1406.44 1753,1406.44 1753.01,1406.44 1753.02,1406.44 1753.03,1406.44 1753.04,1406.44 1753.05,1406.44 1753.06,1406.44 1753.07,1406.44 1753.08,1406.44 1753.09,1406.44 1753.11,1406.44 1753.12,1406.44 1753.13,1406.44 1753.14,1406.44 1753.15,1406.44 1753.16,1406.44 1753.17,1406.44 1753.18,1406.44 1753.19,1406.44 1753.2,1406.44 1753.21,1406.44 1753.22,1406.44 1753.23,1406.44 1753.25,1406.44 1753.26,1406.44 1753.27,1406.44 1753.28,1406.44 1753.29,1406.44 1753.3,1406.44 1753.31,1406.44 1753.32,1406.44 1753.33,1406.44 1753.34,1406.44 1753.35,1406.44 1753.36,1406.44 1753.38,1406.44 1753.39,1406.44 1753.4,1406.44 1753.41,1406.44 1753.42,1406.44 1753.43,1406.44 1753.44,1406.44 1753.45,1406.44 1753.46,1406.44 1753.47,1406.44 1753.48,1406.44 1753.49,1406.44 1753.5,1406.44 1753.51,1406.44 1753.53,1406.44 1753.54,1406.44 1753.55,1406.44 1753.56,1406.44 1753.57,1406.44 1753.58,1406.44 1753.59,1406.44 1753.6,1406.44 1753.61,1406.44 1753.62,1406.44 1753.63,1406.44 1753.64,1406.43 1753.65,1406.43 1753.67,1406.43 1753.68,1406.43 1753.69,1406.43 1753.7,1406.43 1753.71,1406.43 1753.72,1406.43 1753.73,1406.43 1753.74,1406.43 1753.75,1406.43 1753.76,1406.43 1753.77,1406.43 1753.78,1406.43 1753.79,1406.43 1753.81,1406.43 1753.82,1406.43 1753.83,1406.43 1753.84,1406.43 1753.85,1406.43 1753.86,1406.43 1753.87,1406.43 1753.88,1406.43 1753.89,1406.43 1753.9,1406.43 1753.91,1406.43 1753.92,1406.43 1753.93,1406.43 1753.94,1406.43 1753.96,1406.43 1753.97,1406.43 1753.98,1406.43 1753.99,1406.43 1754,1406.43 1754.01,1406.43 1754.02,1406.43 1754.03,1406.43 1754.04,1406.43 1754.05,1406.43 1754.06,1406.43 1754.07,1406.43 1754.08,1406.43 1754.09,1406.43 1754.1,1406.43 1754.12,1406.43 1754.13,1406.43 1754.14,1406.43 1754.15,1406.43 1754.16,1406.43 1754.17,1406.43 1754.18,1406.43 1754.19,1406.43 1754.2,1406.43 1754.21,1406.43 1754.22,1406.43 1754.23,1406.43 1754.24,1406.43 1754.25,1406.43 1754.27,1406.43 1754.28,1406.43 1754.29,1406.43 1754.3,1406.43 1754.31,1406.43 1754.32,1406.43 1754.33,1406.43 1754.34,1406.42 1754.35,1406.42 1754.36,1406.42 1754.37,1406.42 1754.38,1406.42 1754.39,1406.42 1754.4,1406.42 1754.41,1406.42 1754.43,1406.42 1754.44,1406.42 1754.45,1406.42 1754.46,1406.42 1754.47,1406.42 1754.48,1406.42 1754.49,1406.42 1754.5,1406.42 1754.51,1406.42 1754.52,1406.42 1754.53,1406.42 1754.54,1406.42 1754.55,1406.42 1754.56,1406.42 1754.57,1406.42 1754.59,1406.42 1754.6,1406.42 1754.61,1406.42 1754.62,1406.42 1754.63,1406.42 1754.64,1406.42 1754.65,1406.42 1754.66,1406.42 1754.67,1406.42 1754.68,1406.42 1754.69,1406.42 1754.7,1406.42 1754.71,1406.42 1754.72,1406.42 1754.73,1406.42 1754.74,1406.42 1754.76,1406.42 1754.77,1406.42 1754.78,1406.42 1754.79,1406.42 1754.8,1406.42 1754.81,1406.42 1754.82,1406.42 1754.83,1406.42 1754.84,1406.42 1754.85,1406.42 1754.86,1406.42 1754.87,1406.42 1754.88,1406.42 1754.89,1406.42 1754.9,1406.42 1754.91,1406.42 1754.93,1406.42 1754.94,1406.42 1754.95,1406.42 1754.96,1406.42 1754.97,1406.42 1754.98,1406.42 1754.99,1406.42 1755,1406.42 1755.01,1406.42 1755.02,1406.42 1755.03,1406.41 1755.04,1406.41 1755.05,1406.41 1755.06,1406.41 1755.07,1406.41 1755.08,1406.41 1755.09,1406.41 1755.11,1406.41 1755.12,1406.41 1755.13,1406.41 1755.14,1406.41 1755.15,1406.41 1755.16,1406.41 1755.17,1406.41 1755.18,1406.41 1755.19,1406.41 1755.2,1406.41 1755.21,1406.41 1755.22,1406.41 1755.23,1406.41 1755.24,1406.41 1755.25,1406.41 1755.26,1406.41 1755.27,1406.41 1755.29,1406.41 1755.3,1406.41 1755.31,1406.41 1755.32,1406.41 1755.33,1406.41 1755.34,1406.41 1755.35,1406.41 1755.36,1406.41 1755.37,1406.41 1755.38,1406.41 1755.39,1406.41 1755.4,1406.41 1755.41,1406.41 1755.42,1406.41 1755.43,1406.41 1755.44,1406.41 1755.45,1406.41 1755.46,1406.41 1755.48,1406.41 1755.49,1406.41 1755.5,1406.41 1755.51,1406.41 1755.52,1406.41 1755.53,1406.41 1755.54,1406.41 1755.55,1406.41 1755.56,1406.41 1755.57,1406.41 1755.58,1406.41 1755.59,1406.41 1755.6,1406.41 1755.61,1406.41 1755.62,1406.41 1755.63,1406.41 1755.64,1406.41 1755.65,1406.41 1755.67,1406.41 1755.68,1406.41 1755.69,1406.41 1755.7,1406.41 1755.71,1406.41 1755.72,1406.4 1755.73,1406.4 1755.74,1406.4 1755.75,1406.4 1755.76,1406.4 1755.77,1406.4 1755.78,1406.4 1755.79,1406.4 1755.8,1406.4 1755.81,1406.4 1755.82,1406.4 1755.83,1406.4 1755.84,1406.4 1755.85,1406.4 1755.86,1406.4 1755.88,1406.4 1755.89,1406.4 1755.9,1406.4 1755.91,1406.4 1755.92,1406.4 1755.93,1406.4 1755.94,1406.4 1755.95,1406.4 1755.96,1406.4 1755.97,1406.4 1755.98,1406.4 1755.99,1406.4 1756,1406.4 1756.01,1406.4 1756.02,1406.4 1756.03,1406.4 1756.04,1406.4 1756.05,1406.4 1756.06,1406.4 1756.07,1406.4 1756.09,1406.4 1756.1,1406.4 1756.11,1406.4 1756.12,1406.4 1756.13,1406.4 1756.14,1406.4 1756.15,1406.4 1756.16,1406.4 1756.17,1406.4 1756.18,1406.4 1756.19,1406.4 1756.2,1406.4 1756.21,1406.4 1756.22,1406.4 1756.23,1406.4 1756.24,1406.4 1756.25,1406.4 1756.26,1406.4 1756.27,1406.4 1756.28,1406.4 1756.29,1406.4 1756.31,1406.4 1756.32,1406.4 1756.33,1406.4 1756.34,1406.4 1756.35,1406.4 1756.36,1406.4 1756.37,1406.4 1756.38,1406.4 1756.39,1406.4 1756.4,1406.39 1756.41,1406.39 1756.42,1406.39 1756.43,1406.39 1756.44,1406.39 1756.45,1406.39 1756.46,1406.39 1756.47,1406.39 1756.48,1406.39 1756.49,1406.39 1756.5,1406.39 1756.51,1406.39 1756.52,1406.39 1756.54,1406.39 1756.55,1406.39 1756.56,1406.39 1756.57,1406.39 1756.58,1406.39 1756.59,1406.39 1756.6,1406.39 1756.61,1406.39 1756.62,1406.39 1756.63,1406.39 1756.64,1406.39 1756.65,1406.39 1756.66,1406.39 1756.67,1406.39 1756.68,1406.39 1756.69,1406.39 1756.7,1406.39 1756.71,1406.39 1756.72,1406.39 1756.73,1406.39 1756.74,1406.39 1756.75,1406.39 1756.76,1406.39 1756.77,1406.39 1756.79,1406.39 1756.8,1406.39 1756.81,1406.39 1756.82,1406.39 1756.83,1406.39 1756.84,1406.39 1756.85,1406.39 1756.86,1406.39 1756.87,1406.39 1756.88,1406.39 1756.89,1406.39 1756.9,1406.39 1756.91,1406.39 1756.92,1406.39 1756.93,1406.39 1756.94,1406.39 1756.95,1406.39 1756.96,1406.39 1756.97,1406.39 1756.98,1406.39 1756.99,1406.39 1757,1406.39 1757.01,1406.39 1757.02,1406.39 1757.03,1406.39 1757.05,1406.39 1757.06,1406.39 1757.07,1406.39 1757.08,1406.38 1757.09,1406.38 1757.1,1406.38 1757.11,1406.38 1757.12,1406.38 1757.13,1406.38 1757.14,1406.38 1757.15,1406.38 1757.16,1406.38 1757.17,1406.38 1757.18,1406.38 1757.19,1406.38 1757.2,1406.38 1757.21,1406.38 1757.22,1406.38 1757.23,1406.38 1757.24,1406.38 1757.25,1406.38 1757.26,1406.38 1757.27,1406.38 1757.28,1406.38 1757.29,1406.38 1757.3,1406.38 1757.31,1406.38 1757.33,1406.38 1757.34,1406.38 1757.35,1406.38 1757.36,1406.38 1757.37,1406.38 1757.38,1406.38 1757.39,1406.38 1757.4,1406.38 1757.41,1406.38 1757.42,1406.38 1757.43,1406.38 1757.44,1406.38 1757.45,1406.38 1757.46,1406.38 1757.47,1406.38 1757.48,1406.38 1757.49,1406.38 1757.5,1406.38 1757.51,1406.38 1757.52,1406.38 1757.53,1406.38 1757.54,1406.38 1757.55,1406.38 1757.56,1406.38 1757.57,1406.38 1757.58,1406.38 1757.59,1406.38 1757.6,1406.38 1757.61,1406.38 1757.63,1406.38 1757.64,1406.38 1757.65,1406.38 1757.66,1406.38 1757.67,1406.38 1757.68,1406.38 1757.69,1406.38 1757.7,1406.38 1757.71,1406.38 1757.72,1406.38 1757.73,1406.38 1757.74,1406.37 1757.75,1406.37 1757.76,1406.37 1757.77,1406.37 1757.78,1406.37 1757.79,1406.37 1757.8,1406.37 1757.81,1406.37 1757.82,1406.37 1757.83,1406.37 1757.84,1406.37 1757.85,1406.37 1757.86,1406.37 1757.87,1406.37 1757.88,1406.37 1757.89,1406.37 1757.9,1406.37 1757.91,1406.37 1757.92,1406.37 1757.93,1406.37 1757.94,1406.37 1757.95,1406.37 1757.97,1406.37 1757.98,1406.37 1757.99,1406.37 1758,1406.37 1758.01,1406.37 1758.02,1406.37 1758.03,1406.37 1758.04,1406.37 1758.05,1406.37 1758.06,1406.37 1758.07,1406.37 1758.08,1406.37 1758.09,1406.37 1758.1,1406.37 1758.11,1406.37 1758.12,1406.37 1758.13,1406.37 1758.14,1406.37 1758.15,1406.37 1758.16,1406.37 1758.17,1406.37 1758.18,1406.37 1758.19,1406.37 1758.2,1406.37 1758.21,1406.37 1758.22,1406.37 1758.23,1406.37 1758.24,1406.37 1758.25,1406.37 1758.26,1406.37 1758.27,1406.37 1758.28,1406.37 1758.29,1406.37 1758.3,1406.37 1758.31,1406.37 1758.32,1406.37 1758.33,1406.37 1758.34,1406.37 1758.36,1406.37 1758.37,1406.37 1758.38,1406.37 1758.39,1406.37 1758.4,1406.37 1758.41,1406.36 1758.42,1406.36 1758.43,1406.36 1758.44,1406.36 1758.45,1406.36 1758.46,1406.36 1758.47,1406.36 1758.48,1406.36 1758.49,1406.36 1758.5,1406.36 1758.51,1406.36 1758.52,1406.36 1758.53,1406.36 1758.54,1406.36 1758.55,1406.36 1758.56,1406.36 1758.57,1406.36 1758.58,1406.36 1758.59,1406.36 1758.6,1406.36 1758.61,1406.36 1758.62,1406.36 1758.63,1406.36 1758.64,1406.36 1758.65,1406.36 1758.66,1406.36 1758.67,1406.36 1758.68,1406.36 1758.69,1406.36 1758.7,1406.36 1758.71,1406.36 1758.72,1406.36 1758.73,1406.36 1758.74,1406.36 1758.75,1406.36 1758.76,1406.36 1758.77,1406.36 1758.78,1406.36 1758.79,1406.36 1758.8,1406.36 1758.82,1406.36 1758.83,1406.36 1758.84,1406.36 1758.85,1406.36 1758.86,1406.36 1758.87,1406.36 1758.88,1406.36 1758.89,1406.36 1758.9,1406.36 1758.91,1406.36 1758.92,1406.36 1758.93,1406.36 1758.94,1406.36 1758.95,1406.36 1758.96,1406.36 1758.97,1406.36 1758.98,1406.36 1758.99,1406.36 1759,1406.36 1759.01,1406.36 1759.02,1406.36 1759.03,1406.36 1759.04,1406.36 1759.05,1406.36 1759.06,1406.35 1759.07,1406.35 1759.08,1406.35 1759.09,1406.35 1759.1,1406.35 1759.11,1406.35 1759.12,1406.35 1759.13,1406.35 1759.14,1406.35 1759.15,1406.35 1759.16,1406.35 1759.17,1406.35 1759.18,1406.35 1759.19,1406.35 1759.2,1406.35 1759.21,1406.35 1759.22,1406.35 1759.23,1406.35 1759.24,1406.35 1759.25,1406.35 1759.26,1406.35 1759.27,1406.35 1759.28,1406.35 1759.29,1406.35 1759.3,1406.35 1759.31,1406.35 1759.32,1406.35 1759.33,1406.35 1759.34,1406.35 1759.35,1406.35 1759.36,1406.35 1759.37,1406.35 1759.38,1406.35 1759.39,1406.35 1759.4,1406.35 1759.41,1406.35 1759.42,1406.35 1759.43,1406.35 1759.45,1406.35 1759.46,1406.35 1759.47,1406.35 1759.48,1406.35 1759.49,1406.35 1759.5,1406.35 1759.51,1406.35 1759.52,1406.35 1759.53,1406.35 1759.54,1406.35 1759.55,1406.35 1759.56,1406.35 1759.57,1406.35 1759.58,1406.35 1759.59,1406.35 1759.6,1406.35 1759.61,1406.35 1759.62,1406.35 1759.63,1406.35 1759.64,1406.35 1759.65,1406.35 1759.66,1406.35 1759.67,1406.35 1759.68,1406.35 1759.69,1406.35 1759.7,1406.35 1759.71,1406.35 1759.72,1406.34 1759.73,1406.34 1759.74,1406.34 1759.75,1406.34 1759.76,1406.34 1759.77,1406.34 1759.78,1406.34 1759.79,1406.34 1759.8,1406.34 1759.81,1406.34 1759.82,1406.34 1759.83,1406.34 1759.84,1406.34 1759.85,1406.34 1759.86,1406.34 1759.87,1406.34 1759.88,1406.34 1759.89,1406.34 1759.9,1406.34 1759.91,1406.34 1759.92,1406.34 1759.93,1406.34 1759.94,1406.34 1759.95,1406.34 1759.96,1406.34 1759.97,1406.34 1759.98,1406.34 1759.99,1406.34 1760,1406.34 1760.01,1406.34 1760.02,1406.34 1760.03,1406.34 1760.04,1406.34 1760.05,1406.34 1760.06,1406.34 1760.07,1406.34 1760.08,1406.34 1760.09,1406.34 1760.1,1406.34 1760.11,1406.34 1760.12,1406.34 1760.13,1406.34 1760.14,1406.34 1760.15,1406.34 1760.16,1406.34 1760.17,1406.34 1760.18,1406.34 1760.19,1406.34 1760.2,1406.34 1760.21,1406.34 1760.22,1406.34 1760.23,1406.34 1760.24,1406.34 1760.25,1406.34 1760.26,1406.34 1760.27,1406.34 1760.28,1406.34 1760.29,1406.34 1760.3,1406.34 1760.31,1406.34 1760.32,1406.34 1760.33,1406.34 1760.34,1406.34 1760.35,1406.34 1760.36,1406.33 1760.37,1406.33 1760.38,1406.33 1760.39,1406.33 1760.4,1406.33 1760.41,1406.33 1760.42,1406.33 1760.43,1406.33 1760.44,1406.33 1760.45,1406.33 1760.46,1406.33 1760.47,1406.33 1760.48,1406.33 1760.49,1406.33 1760.5,1406.33 1760.51,1406.33 1760.52,1406.33 1760.53,1406.33 1760.54,1406.33 1760.55,1406.33 1760.56,1406.33 1760.57,1406.33 1760.58,1406.33 1760.59,1406.33 1760.6,1406.33 1760.61,1406.33 1760.62,1406.33 1760.63,1406.33 1760.64,1406.33 1760.65,1406.33 1760.66,1406.33 1760.67,1406.33 1760.68,1406.33 1760.69,1406.33 1760.7,1406.33 1760.71,1406.33 1760.72,1406.33 1760.73,1406.33 1760.74,1406.33 1760.75,1406.33 1760.76,1406.33 1760.77,1406.33 1760.78,1406.33 1760.79,1406.33 1760.8,1406.33 1760.81,1406.33 1760.82,1406.33 1760.83,1406.33 1760.84,1406.33 1760.85,1406.33 1760.86,1406.33 1760.87,1406.33 1760.88,1406.33 1760.89,1406.33 1760.9,1406.33 1760.91,1406.33 1760.92,1406.33 1760.93,1406.33 1760.94,1406.33 1760.95,1406.33 1760.96,1406.33 1760.97,1406.33 1760.98,1406.33 1760.99,1406.33 1761,1406.32 1761.01,1406.32 1761.02,1406.32 1761.03,1406.32 1761.04,1406.32 1761.05,1406.32 1761.06,1406.32 1761.07,1406.32 1761.08,1406.32 1761.09,1406.32 1761.1,1406.32 1761.11,1406.32 1761.12,1406.32 1761.13,1406.32 1761.14,1406.32 1761.15,1406.32 1761.16,1406.32 1761.17,1406.32 1761.18,1406.32 1761.19,1406.32 1761.2,1406.32 1761.21,1406.32 1761.22,1406.32 1761.23,1406.32 1761.24,1406.32 1761.25,1406.32 1761.26,1406.32 1761.27,1406.32 1761.28,1406.32 1761.29,1406.32 1761.3,1406.32 1761.31,1406.32 1761.32,1406.32 1761.33,1406.32 1761.34,1406.32 1761.35,1406.32 1761.36,1406.32 1761.37,1406.32 1761.38,1406.32 1761.39,1406.32 1761.4,1406.32 1761.41,1406.32 1761.42,1406.32 1761.43,1406.32 1761.44,1406.32 1761.45,1406.32 1761.46,1406.32 1761.47,1406.32 1761.48,1406.32 1761.49,1406.32 1761.5,1406.32 1761.51,1406.32 1761.52,1406.32 1761.53,1406.32 1761.54,1406.32 1761.55,1406.32 1761.56,1406.32 1761.57,1406.32 1761.58,1406.32 1761.59,1406.32 1761.6,1406.32 1761.61,1406.32 1761.62,1406.32 1761.63,1406.32 1761.64,1406.31 1761.65,1406.31 1761.66,1406.31 1761.67,1406.31 1761.68,1406.31 1761.69,1406.31 1761.7,1406.31 1761.71,1406.31 1761.72,1406.31 1761.73,1406.31 1761.74,1406.31 1761.75,1406.31 1761.76,1406.31 1761.77,1406.31 1761.78,1406.31 1761.79,1406.31 1761.8,1406.31 1761.81,1406.31 1761.82,1406.31 1761.83,1406.31 1761.84,1406.31 1761.85,1406.31 1761.86,1406.31 1761.87,1406.31 1761.88,1406.31 1761.88,1406.31 1761.89,1406.31 1761.9,1406.31 1761.91,1406.31 1761.92,1406.31 1761.93,1406.31 1761.94,1406.31 1761.95,1406.31 1761.96,1406.31 1761.97,1406.31 1761.98,1406.31 1761.99,1406.31 1762,1406.31 1762.01,1406.31 1762.02,1406.31 1762.03,1406.31 1762.04,1406.31 1762.05,1406.31 1762.06,1406.31 1762.07,1406.31 1762.08,1406.31 1762.09,1406.31 1762.1,1406.31 1762.11,1406.31 1762.12,1406.31 1762.13,1406.31 1762.14,1406.31 1762.15,1406.31 1762.16,1406.31 1762.17,1406.31 1762.18,1406.31 1762.19,1406.31 1762.2,1406.31 1762.21,1406.31 1762.22,1406.31 1762.23,1406.31 1762.24,1406.31 1762.25,1406.31 1762.26,1406.31 1762.27,1406.3 1762.28,1406.3 1762.29,1406.3 1762.3,1406.3 1762.31,1406.3 1762.32,1406.3 1762.33,1406.3 1762.34,1406.3 1762.35,1406.3 1762.36,1406.3 1762.37,1406.3 1762.38,1406.3 1762.39,1406.3 1762.4,1406.3 1762.41,1406.3 1762.42,1406.3 1762.43,1406.3 1762.44,1406.3 1762.45,1406.3 1762.46,1406.3 1762.47,1406.3 1762.48,1406.3 1762.49,1406.3 1762.49,1406.3 1762.5,1406.3 1762.51,1406.3 1762.52,1406.3 1762.53,1406.3 1762.54,1406.3 1762.55,1406.3 1762.56,1406.3 1762.57,1406.3 1762.58,1406.3 1762.59,1406.3 1762.6,1406.3 1762.61,1406.3 1762.62,1406.3 1762.63,1406.3 1762.64,1406.3 1762.65,1406.3 1762.66,1406.3 1762.67,1406.3 1762.68,1406.3 1762.69,1406.3 1762.7,1406.3 1762.71,1406.3 1762.72,1406.3 1762.73,1406.3 1762.74,1406.3 1762.75,1406.3 1762.76,1406.3 1762.77,1406.3 1762.78,1406.3 1762.79,1406.3 1762.8,1406.3 1762.81,1406.3 1762.82,1406.3 1762.83,1406.3 1762.84,1406.3 1762.85,1406.3 1762.86,1406.3 1762.87,1406.3 1762.88,1406.3 1762.89,1406.3 1762.9,1406.3 1762.91,1406.29 1762.92,1406.29 1762.93,1406.29 1762.94,1406.29 1762.94,1406.29 1762.95,1406.29 1762.96,1406.29 1762.97,1406.29 1762.98,1406.29 1762.99,1406.29 1763,1406.29 1763.01,1406.29 1763.02,1406.29 1763.03,1406.29 1763.04,1406.29 1763.05,1406.29 1763.06,1406.29 1763.07,1406.29 1763.08,1406.29 1763.09,1406.29 1763.1,1406.29 1763.11,1406.29 1763.12,1406.29 1763.13,1406.29 1763.14,1406.29 1763.15,1406.29 1763.16,1406.29 1763.17,1406.29 1763.18,1406.29 1763.19,1406.29 1763.2,1406.29 1763.21,1406.29 1763.22,1406.29 1763.23,1406.29 1763.24,1406.29 1763.25,1406.29 1763.26,1406.29 1763.27,1406.29 1763.28,1406.29 1763.29,1406.29 1763.3,1406.29 1763.31,1406.29 1763.32,1406.29 1763.32,1406.29 1763.33,1406.29 1763.34,1406.29 1763.35,1406.29 1763.36,1406.29 1763.37,1406.29 1763.38,1406.29 1763.39,1406.29 1763.4,1406.29 1763.41,1406.29 1763.42,1406.29 1763.43,1406.29 1763.44,1406.29 1763.45,1406.29 1763.46,1406.29 1763.47,1406.29 1763.48,1406.29 1763.49,1406.29 1763.5,1406.29 1763.51,1406.29 1763.52,1406.29 1763.53,1406.28 1763.54,1406.28 1763.55,1406.28 1763.56,1406.28 1763.57,1406.28 1763.58,1406.28 1763.59,1406.28 1763.6,1406.28 1763.61,1406.28 1763.62,1406.28 1763.63,1406.28 1763.64,1406.28 1763.64,1406.28 1763.65,1406.28 1763.66,1406.28 1763.67,1406.28 1763.68,1406.28 1763.69,1406.28 1763.7,1406.28 1763.71,1406.28 1763.72,1406.28 1763.73,1406.28 1763.74,1406.28 1763.75,1406.28 1763.76,1406.28 1763.77,1406.28 1763.78,1406.28 1763.79,1406.28 1763.8,1406.28 1763.81,1406.28 1763.82,1406.28 1763.83,1406.28 1763.84,1406.28 1763.85,1406.28 1763.86,1406.28 1763.87,1406.28 1763.88,1406.28 1763.89,1406.28 1763.9,1406.28 1763.91,1406.28 1763.92,1406.28 1763.93,1406.28 1763.94,1406.28 1763.94,1406.28 1763.95,1406.28 1763.96,1406.28 1763.97,1406.28 1763.98,1406.28 1763.99,1406.28 1764,1406.28 1764.01,1406.28 1764.02,1406.28 1764.03,1406.28 1764.04,1406.28 1764.05,1406.28 1764.06,1406.28 1764.07,1406.28 1764.08,1406.28 1764.09,1406.28 1764.1,1406.28 1764.11,1406.28 1764.12,1406.28 1764.13,1406.28 1764.14,1406.28 1764.15,1406.27 1764.16,1406.27 1764.17,1406.27 1764.18,1406.27 1764.19,1406.27 1764.2,1406.27 1764.21,1406.27 1764.21,1406.27 1764.22,1406.27 1764.23,1406.27 1764.24,1406.27 1764.25,1406.27 1764.26,1406.27 1764.27,1406.27 1764.28,1406.27 1764.29,1406.27 1764.3,1406.27 1764.31,1406.27 1764.32,1406.27 1764.33,1406.27 1764.34,1406.27 1764.35,1406.27 1764.36,1406.27 1764.37,1406.27 1764.38,1406.27 1764.39,1406.27 1764.4,1406.27 1764.41,1406.27 1764.42,1406.27 1764.43,1406.27 1764.44,1406.27 1764.45,1406.27 1764.45,1406.27 1764.46,1406.27 1764.47,1406.27 1764.48,1406.27 1764.49,1406.27 1764.5,1406.27 1764.51,1406.27 1764.52,1406.27 1764.53,1406.27 1764.54,1406.27 1764.55,1406.27 1764.56,1406.27 1764.57,1406.27 1764.58,1406.27 1764.59,1406.27 1764.6,1406.27 1764.61,1406.27 1764.62,1406.27 1764.63,1406.27 1764.64,1406.27 1764.65,1406.27 1764.66,1406.27 1764.67,1406.27 1764.68,1406.27 1764.69,1406.27 1764.69,1406.27 1764.7,1406.27 1764.71,1406.27 1764.72,1406.27 1764.73,1406.27 1764.74,1406.27 1764.75,1406.27 1764.76,1406.26 1764.77,1406.26 1764.78,1406.26 1764.79,1406.26 1764.8,1406.26 1764.81,1406.26 1764.82,1406.26 1764.83,1406.26 1764.84,1406.26 1764.85,1406.26 1764.86,1406.26 1764.87,1406.26 1764.88,1406.26 1764.89,1406.26 1764.9,1406.26 1764.91,1406.26 1764.91,1406.26 1764.92,1406.26 1764.93,1406.26 1764.94,1406.26 1764.95,1406.26 1764.96,1406.26 1764.97,1406.26 1764.98,1406.26 1764.99,1406.26 1765,1406.26 1765.01,1406.26 1765.02,1406.26 1765.03,1406.26 1765.04,1406.26 1765.05,1406.26 1765.06,1406.26 1765.07,1406.26 1765.08,1406.26 1765.09,1406.26 1765.1,1406.26 1765.11,1406.26 1765.12,1406.26 1765.12,1406.26 1765.13,1406.26 1765.14,1406.26 1765.15,1406.26 1765.16,1406.26 1765.17,1406.26 1765.18,1406.26 1765.19,1406.26 1765.2,1406.26 1765.21,1406.26 1765.22,1406.26 1765.23,1406.26 1765.24,1406.26 1765.25,1406.26 1765.26,1406.26 1765.27,1406.26 1765.28,1406.26 1765.29,1406.26 1765.3,1406.26 1765.31,1406.26 1765.31,1406.26 1765.32,1406.26 1765.33,1406.26 1765.34,1406.26 1765.35,1406.26 1765.36,1406.26 1765.37,1406.25 1765.38,1406.25 1765.39,1406.25 1765.4,1406.25 1765.41,1406.25 1765.42,1406.25 1765.43,1406.25 1765.44,1406.25 1765.45,1406.25 1765.46,1406.25 1765.47,1406.25 1765.48,1406.25 1765.49,1406.25 1765.5,1406.25 1765.51,1406.25 1765.51,1406.25 1765.52,1406.25 1765.53,1406.25 1765.54,1406.25 1765.55,1406.25 1765.56,1406.25 1765.57,1406.25 1765.58,1406.25 1765.59,1406.25 1765.6,1406.25 1765.61,1406.25 1765.62,1406.25 1765.63,1406.25 1765.64,1406.25 1765.65,1406.25 1765.66,1406.25 1765.67,1406.25 1765.68,1406.25 1765.69,1406.25 1765.69,1406.25 1765.7,1406.25 1765.71,1406.25 1765.72,1406.25 1765.73,1406.25 1765.74,1406.25 1765.75,1406.25 1765.76,1406.25 1765.77,1406.25 1765.78,1406.25 1765.79,1406.25 1765.8,1406.25 1765.81,1406.25 1765.82,1406.25 1765.83,1406.25 1765.84,1406.25 1765.85,1406.25 1765.86,1406.25 1765.86,1406.25 1765.87,1406.25 1765.88,1406.25 1765.89,1406.25 1765.9,1406.25 1765.91,1406.25 1765.92,1406.25 1765.93,1406.25 1765.94,1406.25 1765.95,1406.25 1765.96,1406.25 1765.97,1406.25 1765.98,1406.24 1765.99,1406.24 1766,1406.24 1766.01,1406.24 1766.02,1406.24 1766.03,1406.24 1766.03,1406.24 1766.04,1406.24 1766.05,1406.24 1766.06,1406.24 1766.07,1406.24 1766.08,1406.24 1766.09,1406.24 1766.1,1406.24 1766.11,1406.24 1766.12,1406.24 1766.13,1406.24 1766.14,1406.24 1766.15,1406.24 1766.16,1406.24 1766.17,1406.24 1766.18,1406.24 1766.19,1406.24 1766.2,1406.24 1766.2,1406.24 1766.21,1406.24 1766.22,1406.24 1766.23,1406.24 1766.24,1406.24 1766.25,1406.24 1766.26,1406.24 1766.27,1406.24 1766.28,1406.24 1766.29,1406.24 1766.3,1406.24 1766.31,1406.24 1766.32,1406.24 1766.33,1406.24 1766.34,1406.24 1766.35,1406.24 1766.36,1406.24 1766.36,1406.24 1766.37,1406.24 1766.38,1406.24 1766.39,1406.24 1766.4,1406.24 1766.41,1406.24 1766.42,1406.24 1766.43,1406.24 1766.44,1406.24 1766.45,1406.24 1766.46,1406.24 1766.47,1406.24 1766.48,1406.24 1766.49,1406.24 1766.5,1406.24 1766.51,1406.24 1766.51,1406.24 1766.52,1406.24 1766.53,1406.24 1766.54,1406.24 1766.55,1406.24 1766.56,1406.24 1766.57,1406.24 1766.58,1406.23 1766.59,1406.23 1766.6,1406.23 1766.61,1406.23 1766.62,1406.23 1766.63,1406.23 1766.64,1406.23 1766.65,1406.23 1766.66,1406.23 1766.66,1406.23 1766.67,1406.23 1766.68,1406.23 1766.69,1406.23 1766.7,1406.23 1766.71,1406.23 1766.72,1406.23 1766.73,1406.23 1766.74,1406.23 1766.75,1406.23 1766.76,1406.23 1766.77,1406.23 1766.78,1406.23 1766.79,1406.23 1766.8,1406.23 1766.81,1406.23 1766.81,1406.23 1766.82,1406.23 1766.83,1406.23 1766.84,1406.23 1766.85,1406.23 1766.86,1406.23 1766.87,1406.23 1766.88,1406.23 1766.89,1406.23 1766.9,1406.23 1766.91,1406.23 1766.92,1406.23 1766.93,1406.23 1766.94,1406.23 1766.95,1406.23 1766.95,1406.23 1766.96,1406.23 1766.97,1406.23 1766.98,1406.23 1766.99,1406.23 1767,1406.23 1767.01,1406.23 1767.02,1406.23 1767.03,1406.23 1767.04,1406.23 1767.05,1406.23 1767.06,1406.23 1767.07,1406.23 1767.08,1406.23 1767.09,1406.23 1767.09,1406.23 1767.1,1406.23 1767.11,1406.23 1767.12,1406.23 1767.13,1406.23 1767.14,1406.23 1767.15,1406.23 1767.16,1406.23 1767.17,1406.23 1767.18,1406.22 1767.19,1406.22 1767.2,1406.22 1767.21,1406.22 1767.22,1406.22 1767.23,1406.22 1767.23,1406.22 1767.24,1406.22 1767.25,1406.22 1767.26,1406.22 1767.27,1406.22 1767.28,1406.22 1767.29,1406.22 1767.3,1406.22 1767.31,1406.22 1767.32,1406.22 1767.33,1406.22 1767.34,1406.22 1767.35,1406.22 1767.36,1406.22 1767.36,1406.22 1767.37,1406.22 1767.38,1406.22 1767.39,1406.22 1767.4,1406.22 1767.41,1406.22 1767.42,1406.22 1767.43,1406.22 1767.44,1406.22 1767.45,1406.22 1767.46,1406.22 1767.47,1406.22 1767.48,1406.22 1767.49,1406.22 1767.49,1406.22 1767.5,1406.22 1767.51,1406.22 1767.52,1406.22 1767.53,1406.22 1767.54,1406.22 1767.55,1406.22 1767.56,1406.22 1767.57,1406.22 1767.58,1406.22 1767.59,1406.22 1767.6,1406.22 1767.61,1406.22 1767.62,1406.22 1767.62,1406.22 1767.63,1406.22 1767.64,1406.22 1767.65,1406.22 1767.66,1406.22 1767.67,1406.22 1767.68,1406.22 1767.69,1406.22 1767.7,1406.22 1767.71,1406.22 1767.72,1406.22 1767.73,1406.22 1767.74,1406.22 1767.75,1406.22 1767.75,1406.22 1767.76,1406.22 1767.77,1406.21 1767.78,1406.21 1767.79,1406.21 1767.8,1406.21 1767.81,1406.21 1767.82,1406.21 1767.83,1406.21 1767.84,1406.21 1767.85,1406.21 1767.86,1406.21 1767.87,1406.21 1767.87,1406.21 1767.88,1406.21 1767.89,1406.21 1767.9,1406.21 1767.91,1406.21 1767.92,1406.21 1767.93,1406.21 1767.94,1406.21 1767.95,1406.21 1767.96,1406.21 1767.97,1406.21 1767.98,1406.21 1767.99,1406.21 1767.99,1406.21 1768,1406.21 1768.01,1406.21 1768.02,1406.21 1768.03,1406.21 1768.04,1406.21 1768.05,1406.21 1768.06,1406.21 1768.07,1406.21 1768.08,1406.21 1768.09,1406.21 1768.1,1406.21 1768.11,1406.21 1768.11,1406.21 1768.12,1406.21 1768.13,1406.21 1768.14,1406.21 1768.15,1406.21 1768.16,1406.21 1768.17,1406.21 1768.18,1406.21 1768.19,1406.21 1768.2,1406.21 1768.21,1406.21 1768.22,1406.21 1768.23,1406.21 1768.23,1406.21 1768.24,1406.21 1768.25,1406.21 1768.26,1406.21 1768.27,1406.21 1768.28,1406.21 1768.29,1406.21 1768.3,1406.21 1768.31,1406.21 1768.32,1406.21 1768.33,1406.21 1768.34,1406.21 1768.34,1406.21 1768.35,1406.21 1768.36,1406.2 1768.37,1406.2 1768.38,1406.2 1768.39,1406.2 1768.4,1406.2 1768.41,1406.2 1768.42,1406.2 1768.43,1406.2 1768.44,1406.2 1768.45,1406.2 1768.46,1406.2 1768.46,1406.2 1768.47,1406.2 1768.48,1406.2 1768.49,1406.2 1768.5,1406.2 1768.51,1406.2 1768.52,1406.2 1768.53,1406.2 1768.54,1406.2 1768.55,1406.2 1768.56,1406.2 1768.57,1406.2 1768.57,1406.2 1768.58,1406.2 1768.59,1406.2 1768.6,1406.2 1768.61,1406.2 1768.62,1406.2 1768.63,1406.2 1768.64,1406.2 1768.65,1406.2 1768.66,1406.2 1768.67,1406.2 1768.68,1406.2 1768.68,1406.2 1768.69,1406.2 1768.7,1406.2 1768.71,1406.2 1768.72,1406.2 1768.73,1406.2 1768.74,1406.2 1768.75,1406.2 1768.76,1406.2 1768.77,1406.2 1768.78,1406.2 1768.79,1406.2 1768.79,1406.2 1768.8,1406.2 1768.81,1406.2 1768.82,1406.2 1768.83,1406.2 1768.84,1406.2 1768.85,1406.2 1768.86,1406.2 1768.87,1406.2 1768.88,1406.2 1768.89,1406.2 1768.89,1406.2 1768.9,1406.2 1768.91,1406.2 1768.92,1406.2 1768.93,1406.2 1768.94,1406.2 1768.95,1406.19 1768.96,1406.19 1768.97,1406.19 1768.98,1406.19 1768.99,1406.19 1769,1406.19 1769,1406.19 1769.01,1406.19 1769.02,1406.19 1769.03,1406.19 1769.04,1406.19 1769.05,1406.19 1769.06,1406.19 1769.07,1406.19 1769.08,1406.19 1769.09,1406.19 1769.1,1406.19 1769.1,1406.19 1769.11,1406.19 1769.12,1406.19 1769.13,1406.19 1769.14,1406.19 1769.15,1406.19 1769.16,1406.19 1769.17,1406.19 1769.18,1406.19 1769.19,1406.19 1769.2,1406.19 1769.2,1406.19 1769.21,1406.19 1769.22,1406.19 1769.23,1406.19 1769.24,1406.19 1769.25,1406.19 1769.26,1406.19 1769.27,1406.19 1769.28,1406.19 1769.29,1406.19 1769.3,1406.19 1769.31,1406.19 1769.31,1406.19 1769.32,1406.19 1769.33,1406.19 1769.34,1406.19 1769.35,1406.19 1769.36,1406.19 1769.37,1406.19 1769.38,1406.19 1769.39,1406.19 1769.4,1406.19 1769.41,1406.19 1769.41,1406.19 1769.42,1406.19 1769.43,1406.19 1769.44,1406.19 1769.45,1406.19 1769.46,1406.19 1769.47,1406.19 1769.48,1406.19 1769.49,1406.19 1769.5,1406.19 1769.5,1406.19 1769.51,1406.19 1769.52,1406.19 1769.53,1406.18 1769.54,1406.18 1769.55,1406.18 1769.56,1406.18 1769.57,1406.18 1769.58,1406.18 1769.59,1406.18 1769.6,1406.18 1769.6,1406.18 1769.61,1406.18 1769.62,1406.18 1769.63,1406.18 1769.64,1406.18 1769.65,1406.18 1769.66,1406.18 1769.67,1406.18 1769.68,1406.18 1769.69,1406.18 1769.7,1406.18 1769.7,1406.18 1769.71,1406.18 1769.72,1406.18 1769.73,1406.18 1769.74,1406.18 1769.75,1406.18 1769.76,1406.18 1769.77,1406.18 1769.78,1406.18 1769.79,1406.18 1769.79,1406.18 1769.8,1406.18 1769.81,1406.18 1769.82,1406.18 1769.83,1406.18 1769.84,1406.18 1769.85,1406.18 1769.86,1406.18 1769.87,1406.18 1769.88,1406.18 1769.89,1406.18 1769.89,1406.18 1769.9,1406.18 1769.91,1406.18 1769.92,1406.18 1769.93,1406.18 1769.94,1406.18 1769.95,1406.18 1769.96,1406.18 1769.97,1406.18 1769.98,1406.18 1769.98,1406.18 1769.99,1406.18 1770,1406.18 1770.01,1406.18 1770.02,1406.18 1770.03,1406.18 1770.04,1406.18 1770.05,1406.18 1770.06,1406.18 1770.07,1406.18 1770.07,1406.18 1770.08,1406.18 1770.09,1406.18 1770.1,1406.18 1770.11,1406.17 1770.12,1406.17 1770.13,1406.17 1770.14,1406.17 1770.15,1406.17 1770.16,1406.17 1770.16,1406.17 1770.17,1406.17 1770.18,1406.17 1770.19,1406.17 1770.2,1406.17 1770.21,1406.17 1770.22,1406.17 1770.23,1406.17 1770.24,1406.17 1770.25,1406.17 1770.25,1406.17 1770.26,1406.17 1770.27,1406.17 1770.28,1406.17 1770.29,1406.17 1770.3,1406.17 1770.31,1406.17 1770.32,1406.17 1770.33,1406.17 1770.34,1406.17 1770.34,1406.17 1770.35,1406.17 1770.36,1406.17 1770.37,1406.17 1770.38,1406.17 1770.39,1406.17 1770.4,1406.17 1770.41,1406.17 1770.42,1406.17 1770.43,1406.17 1770.43,1406.17 1770.44,1406.17 1770.45,1406.17 1770.46,1406.17 1770.47,1406.17 1770.48,1406.17 1770.49,1406.17 1770.5,1406.17 1770.51,1406.17 1770.52,1406.17 1770.52,1406.17 1770.53,1406.17 1770.54,1406.17 1770.55,1406.17 1770.56,1406.17 1770.57,1406.17 1770.58,1406.17 1770.59,1406.17 1770.6,1406.17 1770.61,1406.17 1770.61,1406.17 1770.62,1406.17 1770.63,1406.17 1770.64,1406.17 1770.65,1406.17 1770.66,1406.17 1770.67,1406.17 1770.68,1406.17 1770.69,1406.16 1770.69,1406.16 1770.7,1406.16 1770.71,1406.16 1770.72,1406.16 1770.73,1406.16 1770.74,1406.16 1770.75,1406.16 1770.76,1406.16 1770.77,1406.16 1770.78,1406.16 1770.78,1406.16 1770.79,1406.16 1770.8,1406.16 1770.81,1406.16 1770.82,1406.16 1770.83,1406.16 1770.84,1406.16 1770.85,1406.16 1770.86,1406.16 1770.86,1406.16 1770.87,1406.16 1770.88,1406.16 1770.89,1406.16 1770.9,1406.16 1770.91,1406.16 1770.92,1406.16 1770.93,1406.16 1770.94,1406.16 1770.94,1406.16 1770.95,1406.16 1770.96,1406.16 1770.97,1406.16 1770.98,1406.16 1770.99,1406.16 1771,1406.16 1771.01,1406.16 1771.02,1406.16 1771.03,1406.16 1771.03,1406.16 1771.04,1406.16 1771.05,1406.16 1771.06,1406.16 1771.07,1406.16 1771.08,1406.16 1771.09,1406.16 1771.1,1406.16 1771.11,1406.16 1771.11,1406.16 1771.12,1406.16 1771.13,1406.16 1771.14,1406.16 1771.15,1406.16 1771.16,1406.16 1771.17,1406.16 1771.18,1406.16 1771.19,1406.16 1771.19,1406.16 1771.2,1406.16 1771.21,1406.16 1771.22,1406.16 1771.23,1406.16 1771.24,1406.16 1771.25,1406.16 1771.26,1406.16 1771.27,1406.15 1771.27,1406.15 1771.28,1406.15 1771.29,1406.15 1771.3,1406.15 1771.31,1406.15 1771.32,1406.15 1771.33,1406.15 1771.34,1406.15 1771.35,1406.15 1771.35,1406.15 1771.36,1406.15 1771.37,1406.15 1771.38,1406.15 1771.39,1406.15 1771.4,1406.15 1771.41,1406.15 1771.42,1406.15 1771.43,1406.15 1771.43,1406.15 1771.44,1406.15 1771.45,1406.15 1771.46,1406.15 1771.47,1406.15 1771.48,1406.15 1771.49,1406.15 1771.5,1406.15 1771.51,1406.15 1771.51,1406.15 1771.52,1406.15 1771.53,1406.15 1771.54,1406.15 1771.55,1406.15 1771.56,1406.15 1771.57,1406.15 1771.58,1406.15 1771.59,1406.15 1771.59,1406.15 1771.6,1406.15 1771.61,1406.15 1771.62,1406.15 1771.63,1406.15 1771.64,1406.15 1771.65,1406.15 1771.66,1406.15 1771.66,1406.15 1771.67,1406.15 1771.68,1406.15 1771.69,1406.15 1771.7,1406.15 1771.71,1406.15 1771.72,1406.15 1771.73,1406.15 1771.74,1406.15 1771.74,1406.15 1771.75,1406.15 1771.76,1406.15 1771.77,1406.15 1771.78,1406.15 1771.79,1406.15 1771.8,1406.15 1771.81,1406.15 1771.82,1406.15 1771.82,1406.15 1771.83,1406.14 1771.84,1406.14 1771.85,1406.14 1771.86,1406.14 1771.87,1406.14 1771.88,1406.14 1771.89,1406.14 1771.89,1406.14 1771.9,1406.14 1771.91,1406.14 1771.92,1406.14 1771.93,1406.14 1771.94,1406.14 1771.95,1406.14 1771.96,1406.14 1771.97,1406.14 1771.97,1406.14 1771.98,1406.14 1771.99,1406.14 1772,1406.14 1772.01,1406.14 1772.02,1406.14 1772.03,1406.14 1772.04,1406.14 1772.04,1406.14 1772.05,1406.14 1772.06,1406.14 1772.07,1406.14 1772.08,1406.14 1772.09,1406.14 1772.1,1406.14 1772.11,1406.14 1772.12,1406.14 1772.12,1406.14 1772.13,1406.14 1772.14,1406.14 1772.15,1406.14 1772.16,1406.14 1772.17,1406.14 1772.18,1406.14 1772.19,1406.14 1772.19,1406.14 1772.2,1406.14 1772.21,1406.14 1772.22,1406.14 1772.23,1406.14 1772.24,1406.14 1772.25,1406.14 1772.26,1406.14 1772.26,1406.14 1772.27,1406.14 1772.28,1406.14 1772.29,1406.14 1772.3,1406.14 1772.31,1406.14 1772.32,1406.14 1772.33,1406.14 1772.33,1406.14 1772.34,1406.14 1772.35,1406.14 1772.36,1406.14 1772.37,1406.14 1772.38,1406.14 1772.39,1406.14 1772.4,1406.13 1772.41,1406.13 1772.41,1406.13 1772.42,1406.13 1772.43,1406.13 1772.44,1406.13 1772.45,1406.13 1772.46,1406.13 1772.47,1406.13 1772.48,1406.13 1772.48,1406.13 1772.49,1406.13 1772.5,1406.13 1772.51,1406.13 1772.52,1406.13 1772.53,1406.13 1772.54,1406.13 1772.55,1406.13 1772.55,1406.13 1772.56,1406.13 1772.57,1406.13 1772.58,1406.13 1772.59,1406.13 1772.6,1406.13 1772.61,1406.13 1772.62,1406.13 1772.62,1406.13 1772.63,1406.13 1772.64,1406.13 1772.65,1406.13 1772.66,1406.13 1772.67,1406.13 1772.68,1406.13 1772.69,1406.13 1772.69,1406.13 1772.7,1406.13 1772.71,1406.13 1772.72,1406.13 1772.73,1406.13 1772.74,1406.13 1772.75,1406.13 1772.76,1406.13 1772.76,1406.13 1772.77,1406.13 1772.78,1406.13 1772.79,1406.13 1772.8,1406.13 1772.81,1406.13 1772.82,1406.13 1772.83,1406.13 1772.83,1406.13 1772.84,1406.13 1772.85,1406.13 1772.86,1406.13 1772.87,1406.13 1772.88,1406.13 1772.89,1406.13 1772.9,1406.13 1772.9,1406.13 1772.91,1406.13 1772.92,1406.13 1772.93,1406.13 1772.94,1406.13 1772.95,1406.13 1772.96,1406.13 1772.96,1406.12 1772.97,1406.12 1772.98,1406.12 1772.99,1406.12 1773,1406.12 1773.01,1406.12 1773.02,1406.12 1773.03,1406.12 1773.03,1406.12 1773.04,1406.12 1773.05,1406.12 1773.06,1406.12 1773.07,1406.12 1773.08,1406.12 1773.09,1406.12 1773.1,1406.12 1773.1,1406.12 1773.11,1406.12 1773.12,1406.12 1773.13,1406.12 1773.14,1406.12 1773.15,1406.12 1773.16,1406.12 1773.17,1406.12 1773.17,1406.12 1773.18,1406.12 1773.19,1406.12 1773.2,1406.12 1773.21,1406.12 1773.22,1406.12 1773.23,1406.12 1773.23,1406.12 1773.24,1406.12 1773.25,1406.12 1773.26,1406.12 1773.27,1406.12 1773.28,1406.12 1773.29,1406.12 1773.3,1406.12 1773.3,1406.12 1773.31,1406.12 1773.32,1406.12 1773.33,1406.12 1773.34,1406.12 1773.35,1406.12 1773.36,1406.12 1773.36,1406.12 1773.37,1406.12 1773.38,1406.12 1773.39,1406.12 1773.4,1406.12 1773.41,1406.12 1773.42,1406.12 1773.43,1406.12 1773.43,1406.12 1773.44,1406.12 1773.45,1406.12 1773.46,1406.12 1773.47,1406.12 1773.48,1406.12 1773.49,1406.12 1773.5,1406.12 1773.5,1406.12 1773.51,1406.12 1773.52,1406.11 1773.53,1406.11 1773.54,1406.11 1773.55,1406.11 1773.56,1406.11 1773.56,1406.11 1773.57,1406.11 1773.58,1406.11 1773.59,1406.11 1773.6,1406.11 1773.61,1406.11 1773.62,1406.11 1773.62,1406.11 1773.63,1406.11 1773.64,1406.11 1773.65,1406.11 1773.66,1406.11 1773.67,1406.11 1773.68,1406.11 1773.69,1406.11 1773.69,1406.11 1773.7,1406.11 1773.71,1406.11 1773.72,1406.11 1773.73,1406.11 1773.74,1406.11 1773.75,1406.11 1773.75,1406.11 1773.76,1406.11 1773.77,1406.11 1773.78,1406.11 1773.79,1406.11 1773.8,1406.11 1773.81,1406.11 1773.81,1406.11 1773.82,1406.11 1773.83,1406.11 1773.84,1406.11 1773.85,1406.11 1773.86,1406.11 1773.87,1406.11 1773.88,1406.11 1773.88,1406.11 1773.89,1406.11 1773.9,1406.11 1773.91,1406.11 1773.92,1406.11 1773.93,1406.11 1773.94,1406.11 1773.94,1406.11 1773.95,1406.11 1773.96,1406.11 1773.97,1406.11 1773.98,1406.11 1773.99,1406.11 1774,1406.11 1774,1406.11 1774.01,1406.11 1774.02,1406.11 1774.03,1406.11 1774.04,1406.11 1774.05,1406.11 1774.06,1406.11 1774.06,1406.11 1774.07,1406.11 1774.08,1406.1 1774.09,1406.1 1774.1,1406.1 1774.11,1406.1 1774.12,1406.1 1774.13,1406.1 1774.13,1406.1 1774.14,1406.1 1774.15,1406.1 1774.16,1406.1 1774.17,1406.1 1774.18,1406.1 1774.19,1406.1 1774.19,1406.1 1774.2,1406.1 1774.21,1406.1 1774.22,1406.1 1774.23,1406.1 1774.24,1406.1 1774.25,1406.1 1774.25,1406.1 1774.26,1406.1 1774.27,1406.1 1774.28,1406.1 1774.29,1406.1 1774.3,1406.1 1774.31,1406.1 1774.31,1406.1 1774.32,1406.1 1774.33,1406.1 1774.34,1406.1 1774.35,1406.1 1774.36,1406.1 1774.37,1406.1 1774.37,1406.1 1774.38,1406.1 1774.39,1406.1 1774.4,1406.1 1774.41,1406.1 1774.42,1406.1 1774.43,1406.1 1774.43,1406.1 1774.44,1406.1 1774.45,1406.1 1774.46,1406.1 1774.47,1406.1 1774.48,1406.1 1774.49,1406.1 1774.49,1406.1 1774.5,1406.1 1774.51,1406.1 1774.52,1406.1 1774.53,1406.1 1774.54,1406.1 1774.55,1406.1 1774.55,1406.1 1774.56,1406.1 1774.57,1406.1 1774.58,1406.1 1774.59,1406.1 1774.6,1406.1 1774.61,1406.1 1774.61,1406.1 1774.62,1406.1 1774.63,1406.1 1774.64,1406.09 1774.65,1406.09 1774.66,1406.09 1774.67,1406.09 1774.67,1406.09 1774.68,1406.09 1774.69,1406.09 1774.7,1406.09 1774.71,1406.09 1774.72,1406.09 1774.72,1406.09 1774.73,1406.09 1774.74,1406.09 1774.75,1406.09 1774.76,1406.09 1774.77,1406.09 1774.78,1406.09 1774.78,1406.09 1774.79,1406.09 1774.8,1406.09 1774.81,1406.09 1774.82,1406.09 1774.83,1406.09 1774.84,1406.09 1774.84,1406.09 1774.85,1406.09 1774.86,1406.09 1774.87,1406.09 1774.88,1406.09 1774.89,1406.09 1774.9,1406.09 1774.9,1406.09 1774.91,1406.09 1774.92,1406.09 1774.93,1406.09 1774.94,1406.09 1774.95,1406.09 1774.96,1406.09 1774.96,1406.09 1774.97,1406.09 1774.98,1406.09 1774.99,1406.09 1775,1406.09 1775.01,1406.09 1775.01,1406.09 1775.02,1406.09 1775.03,1406.09 1775.04,1406.09 1775.05,1406.09 1775.06,1406.09 1775.07,1406.09 1775.07,1406.09 1775.08,1406.09 1775.09,1406.09 1775.1,1406.09 1775.11,1406.09 1775.12,1406.09 1775.13,1406.09 1775.13,1406.09 1775.14,1406.09 1775.15,1406.09 1775.16,1406.09 1775.17,1406.09 1775.18,1406.09 1775.18,1406.09 1775.19,1406.08 1775.2,1406.08 1775.21,1406.08 1775.22,1406.08 1775.23,1406.08 1775.24,1406.08 1775.24,1406.08 1775.25,1406.08 1775.26,1406.08 1775.27,1406.08 1775.28,1406.08 1775.29,1406.08 1775.29,1406.08 1775.3,1406.08 1775.31,1406.08 1775.32,1406.08 1775.33,1406.08 1775.34,1406.08 1775.35,1406.08 1775.35,1406.08 1775.36,1406.08 1775.37,1406.08 1775.38,1406.08 1775.39,1406.08 1775.4,1406.08 1775.41,1406.08 1775.41,1406.08 1775.42,1406.08 1775.43,1406.08 1775.44,1406.08 1775.45,1406.08 1775.46,1406.08 1775.46,1406.08 1775.47,1406.08 1775.48,1406.08 1775.49,1406.08 1775.5,1406.08 1775.51,1406.08 1775.52,1406.08 1775.52,1406.08 1775.53,1406.08 1775.54,1406.08 1775.55,1406.08 1775.56,1406.08 1775.57,1406.08 1775.57,1406.08 1775.58,1406.08 1775.59,1406.08 1775.6,1406.08 1775.61,1406.08 1775.62,1406.08 1775.63,1406.08 1775.63,1406.08 1775.64,1406.08 1775.65,1406.08 1775.66,1406.08 1775.67,1406.08 1775.68,1406.08 1775.68,1406.08 1775.69,1406.08 1775.7,1406.08 1775.71,1406.08 1775.72,1406.08 1775.73,1406.08 1775.73,1406.08 1775.74,1406.07 1775.75,1406.07 1775.76,1406.07 1775.77,1406.07 1775.78,1406.07 1775.79,1406.07 1775.79,1406.07 1775.8,1406.07 1775.81,1406.07 1775.82,1406.07 1775.83,1406.07 1775.84,1406.07 1775.84,1406.07 1775.85,1406.07 1775.86,1406.07 1775.87,1406.07 1775.88,1406.07 1775.89,1406.07 1775.89,1406.07 1775.9,1406.07 1775.91,1406.07 1775.92,1406.07 1775.93,1406.07 1775.94,1406.07 1775.95,1406.07 1775.95,1406.07 1775.96,1406.07 1775.97,1406.07 1775.98,1406.07 1775.99,1406.07 1776,1406.07 1776,1406.07 1776.01,1406.07 1776.02,1406.07 1776.03,1406.07 1776.04,1406.07 1776.05,1406.07 1776.05,1406.07 1776.06,1406.07 1776.07,1406.07 1776.08,1406.07 1776.09,1406.07 1776.1,1406.07 1776.11,1406.07 1776.11,1406.07 1776.12,1406.07 1776.13,1406.07 1776.14,1406.07 1776.15,1406.07 1776.16,1406.07 1776.16,1406.07 1776.17,1406.07 1776.18,1406.07 1776.19,1406.07 1776.2,1406.07 1776.21,1406.07 1776.21,1406.07 1776.22,1406.07 1776.23,1406.07 1776.24,1406.07 1776.25,1406.07 1776.26,1406.07 1776.26,1406.07 1776.27,1406.07 1776.28,1406.07 1776.29,1406.06 1776.3,1406.06 1776.31,1406.06 1776.31,1406.06 1776.32,1406.06 1776.33,1406.06 1776.34,1406.06 1776.35,1406.06 1776.36,1406.06 1776.36,1406.06 1776.37,1406.06 1776.38,1406.06 1776.39,1406.06 1776.4,1406.06 1776.41,1406.06 1776.42,1406.06 1776.42,1406.06 1776.43,1406.06 1776.44,1406.06 1776.45,1406.06 1776.46,1406.06 1776.47,1406.06 1776.47,1406.06 1776.48,1406.06 1776.49,1406.06 1776.5,1406.06 1776.51,1406.06 1776.52,1406.06 1776.52,1406.06 1776.53,1406.06 1776.54,1406.06 1776.55,1406.06 1776.56,1406.06 1776.57,1406.06 1776.57,1406.06 1776.58,1406.06 1776.59,1406.06 1776.6,1406.06 1776.61,1406.06 1776.62,1406.06 1776.62,1406.06 1776.63,1406.06 1776.64,1406.06 1776.65,1406.06 1776.66,1406.06 1776.67,1406.06 1776.67,1406.06 1776.68,1406.06 1776.69,1406.06 1776.7,1406.06 1776.71,1406.06 1776.72,1406.06 1776.72,1406.06 1776.73,1406.06 1776.74,1406.06 1776.75,1406.06 1776.76,1406.06 1776.77,1406.06 1776.77,1406.06 1776.78,1406.06 1776.79,1406.06 1776.8,1406.06 1776.81,1406.06 1776.82,1406.06 1776.82,1406.06 1776.83,1406.05 1776.84,1406.05 1776.85,1406.05 1776.86,1406.05 1776.87,1406.05 1776.87,1406.05 1776.88,1406.05 1776.89,1406.05 1776.9,1406.05 1776.91,1406.05 1776.92,1406.05 1776.92,1406.05 1776.93,1406.05 1776.94,1406.05 1776.95,1406.05 1776.96,1406.05 1776.97,1406.05 1776.97,1406.05 1776.98,1406.05 1776.99,1406.05 1777,1406.05 1777.01,1406.05 1777.02,1406.05 1777.02,1406.05 1777.03,1406.05 1777.04,1406.05 1777.05,1406.05 1777.06,1406.05 1777.07,1406.05 1777.07,1406.05 1777.08,1406.05 1777.09,1406.05 1777.1,1406.05 1777.11,1406.05 1777.11,1406.05 1777.12,1406.05 1777.13,1406.05 1777.14,1406.05 1777.15,1406.05 1777.16,1406.05 1777.16,1406.05 1777.17,1406.05 1777.18,1406.05 1777.19,1406.05 1777.2,1406.05 1777.21,1406.05 1777.21,1406.05 1777.22,1406.05 1777.23,1406.05 1777.24,1406.05 1777.25,1406.05 1777.26,1406.05 1777.26,1406.05 1777.27,1406.05 1777.28,1406.05 1777.29,1406.05 1777.3,1406.05 1777.31,1406.05 1777.31,1406.05 1777.32,1406.05 1777.33,1406.05 1777.34,1406.05 1777.35,1406.05 1777.36,1406.05 1777.36,1406.05 1777.37,1406.04 1777.38,1406.04 1777.39,1406.04 1777.4,1406.04 1777.4,1406.04 1777.41,1406.04 1777.42,1406.04 1777.43,1406.04 1777.44,1406.04 1777.45,1406.04 1777.45,1406.04 1777.46,1406.04 1777.47,1406.04 1777.48,1406.04 1777.49,1406.04 1777.5,1406.04 1777.5,1406.04 1777.51,1406.04 1777.52,1406.04 1777.53,1406.04 1777.54,1406.04 1777.55,1406.04 1777.55,1406.04 1777.56,1406.04 1777.57,1406.04 1777.58,1406.04 1777.59,1406.04 1777.59,1406.04 1777.6,1406.04 1777.61,1406.04 1777.62,1406.04 1777.63,1406.04 1777.64,1406.04 1777.64,1406.04 1777.65,1406.04 1777.66,1406.04 1777.67,1406.04 1777.68,1406.04 1777.69,1406.04 1777.69,1406.04 1777.7,1406.04 1777.71,1406.04 1777.72,1406.04 1777.73,1406.04 1777.73,1406.04 1777.74,1406.04 1777.75,1406.04 1777.76,1406.04 1777.77,1406.04 1777.78,1406.04 1777.78,1406.04 1777.79,1406.04 1777.8,1406.04 1777.81,1406.04 1777.82,1406.04 1777.83,1406.04 1777.83,1406.04 1777.84,1406.04 1777.85,1406.04 1777.86,1406.04 1777.87,1406.04 1777.87,1406.04 1777.88,1406.04 1777.89,1406.04 1777.9,1406.04 1777.91,1406.03 1777.92,1406.03 1777.92,1406.03 1777.93,1406.03 1777.94,1406.03 1777.95,1406.03 1777.96,1406.03 1777.96,1406.03 1777.97,1406.03 1777.98,1406.03 1777.99,1406.03 1778,1406.03 1778.01,1406.03 1778.01,1406.03 1778.02,1406.03 1778.03,1406.03 1778.04,1406.03 1778.05,1406.03 1778.06,1406.03 1778.06,1406.03 1778.07,1406.03 1778.08,1406.03 1778.09,1406.03 1778.1,1406.03 1778.1,1406.03 1778.11,1406.03 1778.12,1406.03 1778.13,1406.03 1778.14,1406.03 1778.15,1406.03 1778.15,1406.03 1778.16,1406.03 1778.17,1406.03 1778.18,1406.03 1778.19,1406.03 1778.19,1406.03 1778.2,1406.03 1778.21,1406.03 1778.22,1406.03 1778.23,1406.03 1778.24,1406.03 1778.24,1406.03 1778.25,1406.03 1778.26,1406.03 1778.27,1406.03 1778.28,1406.03 1778.28,1406.03 1778.29,1406.03 1778.3,1406.03 1778.31,1406.03 1778.32,1406.03 1778.33,1406.03 1778.33,1406.03 1778.34,1406.03 1778.35,1406.03 1778.36,1406.03 1778.37,1406.03 1778.37,1406.03 1778.38,1406.03 1778.39,1406.03 1778.4,1406.03 1778.41,1406.03 1778.42,1406.03 1778.42,1406.03 1778.43,1406.03 1778.44,1406.03 1778.45,1406.02 1778.46,1406.02 1778.46,1406.02 1778.47,1406.02 1778.48,1406.02 1778.49,1406.02 1778.5,1406.02 1778.5,1406.02 1778.51,1406.02 1778.52,1406.02 1778.53,1406.02 1778.54,1406.02 1778.55,1406.02 1778.55,1406.02 1778.56,1406.02 1778.57,1406.02 1778.58,1406.02 1778.59,1406.02 1778.59,1406.02 1778.6,1406.02 1778.61,1406.02 1778.62,1406.02 1778.63,1406.02 1778.64,1406.02 1778.64,1406.02 1778.65,1406.02 1778.66,1406.02 1778.67,1406.02 1778.68,1406.02 1778.68,1406.02 1778.69,1406.02 1778.7,1406.02 1778.71,1406.02 1778.72,1406.02 1778.72,1406.02 1778.73,1406.02 1778.74,1406.02 1778.75,1406.02 1778.76,1406.02 1778.77,1406.02 1778.77,1406.02 1778.78,1406.02 1778.79,1406.02 1778.8,1406.02 1778.81,1406.02 1778.81,1406.02 1778.82,1406.02 1778.83,1406.02 1778.84,1406.02 1778.85,1406.02 1778.85,1406.02 1778.86,1406.02 1778.87,1406.02 1778.88,1406.02 1778.89,1406.02 1778.9,1406.02 1778.9,1406.02 1778.91,1406.02 1778.92,1406.02 1778.93,1406.02 1778.94,1406.02 1778.94,1406.02 1778.95,1406.02 1778.96,1406.02 1778.97,1406.02 1778.98,1406.02 1778.98,1406.01 1778.99,1406.01 1779,1406.01 1779.01,1406.01 1779.02,1406.01 1779.03,1406.01 1779.03,1406.01 1779.04,1406.01 1779.05,1406.01 1779.06,1406.01 1779.07,1406.01 1779.07,1406.01 1779.08,1406.01 1779.09,1406.01 1779.1,1406.01 1779.11,1406.01 1779.11,1406.01 1779.12,1406.01 1779.13,1406.01 1779.14,1406.01 1779.15,1406.01 1779.15,1406.01 1779.16,1406.01 1779.17,1406.01 1779.18,1406.01 1779.19,1406.01 1779.2,1406.01 1779.2,1406.01 1779.21,1406.01 1779.22,1406.01 1779.23,1406.01 1779.24,1406.01 1779.24,1406.01 1779.25,1406.01 1779.26,1406.01 1779.27,1406.01 1779.28,1406.01 1779.28,1406.01 1779.29,1406.01 1779.3,1406.01 1779.31,1406.01 1779.32,1406.01 1779.32,1406.01 1779.33,1406.01 1779.34,1406.01 1779.35,1406.01 1779.36,1406.01 1779.36,1406.01 1779.37,1406.01 1779.38,1406.01 1779.39,1406.01 1779.4,1406.01 1779.41,1406.01 1779.41,1406.01 1779.42,1406.01 1779.43,1406.01 1779.44,1406.01 1779.45,1406.01 1779.45,1406.01 1779.46,1406.01 1779.47,1406.01 1779.48,1406.01 1779.49,1406.01 1779.49,1406.01 1779.5,1406.01 1779.51,1406 1779.52,1406 1779.53,1406 1779.53,1406 1779.54,1406 1779.55,1406 1779.56,1406 1779.57,1406 1779.57,1406 1779.58,1406 1779.59,1406 1779.6,1406 1779.61,1406 1779.61,1406 1779.62,1406 1779.63,1406 1779.64,1406 1779.65,1406 1779.65,1406 1779.66,1406 1779.67,1406 1779.68,1406 1779.69,1406 1779.7,1406 1779.7,1406 1779.71,1406 1779.72,1406 1779.73,1406 1779.74,1406 1779.74,1406 1779.75,1406 1779.76,1406 1779.77,1406 1779.78,1406 1779.78,1406 1779.79,1406 1779.8,1406 1779.81,1406 1779.82,1406 1779.82,1406 1779.83,1406 1779.84,1406 1779.85,1406 1779.86,1406 1779.86,1406 1779.87,1406 1779.88,1406 1779.89,1406 1779.9,1406 1779.9,1406 1779.91,1406 1779.92,1406 1779.93,1406 1779.94,1406 1779.94,1406 1779.95,1406 1779.96,1406 1779.97,1406 1779.98,1406 1779.98,1406 1779.99,1406 1780,1406 1780.01,1406 1780.02,1406 1780.02,1406 1780.03,1406 1780.04,1405.99 1780.05,1405.99 1780.06,1405.99 1780.06,1405.99 1780.07,1405.99 1780.08,1405.99 1780.09,1405.99 1780.1,1405.99 1780.1,1405.99 1780.11,1405.99 1780.12,1405.99 1780.13,1405.99 1780.14,1405.99 1780.14,1405.99 1780.15,1405.99 1780.16,1405.99 1780.17,1405.99 1780.18,1405.99 1780.18,1405.99 1780.19,1405.99 1780.2,1405.99 1780.21,1405.99 1780.22,1405.99 1780.22,1405.99 1780.23,1405.99 1780.24,1405.99 1780.25,1405.99 1780.26,1405.99 1780.26,1405.99 1780.27,1405.99 1780.28,1405.99 1780.29,1405.99 1780.3,1405.99 1780.3,1405.99 1780.31,1405.99 1780.32,1405.99 1780.33,1405.99 1780.34,1405.99 1780.34,1405.99 1780.35,1405.99 1780.36,1405.99 1780.37,1405.99 1780.38,1405.99 1780.38,1405.99 1780.39,1405.99 1780.4,1405.99 1780.41,1405.99 1780.42,1405.99 1780.42,1405.99 1780.43,1405.99 1780.44,1405.99 1780.45,1405.99 1780.45,1405.99 1780.46,1405.99 1780.47,1405.99 1780.48,1405.99 1780.49,1405.99 1780.49,1405.99 1780.5,1405.99 1780.51,1405.99 1780.52,1405.99 1780.53,1405.99 1780.53,1405.99 1780.54,1405.99 1780.55,1405.99 1780.56,1405.99 1780.57,1405.98 1780.57,1405.98 1780.58,1405.98 1780.59,1405.98 1780.6,1405.98 1780.61,1405.98 1780.61,1405.98 1780.62,1405.98 1780.63,1405.98 1780.64,1405.98 1780.65,1405.98 1780.65,1405.98 1780.66,1405.98 1780.67,1405.98 1780.68,1405.98 1780.69,1405.98 1780.69,1405.98 1780.7,1405.98 1780.71,1405.98 1780.72,1405.98 1780.73,1405.98 1780.73,1405.98 1780.74,1405.98 1780.75,1405.98 1780.76,1405.98 1780.76,1405.98 1780.77,1405.98 1780.78,1405.98 1780.79,1405.98 1780.8,1405.98 1780.8,1405.98 1780.81,1405.98 1780.82,1405.98 1780.83,1405.98 1780.84,1405.98 1780.84,1405.98 1780.85,1405.98 1780.86,1405.98 1780.87,1405.98 1780.88,1405.98 1780.88,1405.98 1780.89,1405.98 1780.9,1405.98 1780.91,1405.98 1780.92,1405.98 1780.92,1405.98 1780.93,1405.98 1780.94,1405.98 1780.95,1405.98 1780.95,1405.98 1780.96,1405.98 1780.97,1405.98 1780.98,1405.98 1780.99,1405.98 1780.99,1405.98 1781,1405.98 1781.01,1405.98 1781.02,1405.98 1781.03,1405.98 1781.03,1405.98 1781.04,1405.98 1781.05,1405.98 1781.06,1405.98 1781.07,1405.98 1781.07,1405.98 1781.08,1405.98 1781.09,1405.98 1781.1,1405.97 1781.1,1405.97 1781.11,1405.97 1781.12,1405.97 1781.13,1405.97 1781.14,1405.97 1781.14,1405.97 1781.15,1405.97 1781.16,1405.97 1781.17,1405.97 1781.18,1405.97 1781.18,1405.97 1781.19,1405.97 1781.2,1405.97 1781.21,1405.97 1781.22,1405.97 1781.22,1405.97 1781.23,1405.97 1781.24,1405.97 1781.25,1405.97 1781.25,1405.97 1781.26,1405.97 1781.27,1405.97 1781.28,1405.97 1781.29,1405.97 1781.29,1405.97 1781.3,1405.97 1781.31,1405.97 1781.32,1405.97 1781.33,1405.97 1781.33,1405.97 1781.34,1405.97 1781.35,1405.97 1781.36,1405.97 1781.37,1405.97 1781.37,1405.97 1781.38,1405.97 1781.39,1405.97 1781.4,1405.97 1781.4,1405.97 1781.41,1405.97 1781.42,1405.97 1781.43,1405.97 1781.44,1405.97 1781.44,1405.97 1781.45,1405.97 1781.46,1405.97 1781.47,1405.97 1781.48,1405.97 1781.48,1405.97 1781.49,1405.97 1781.5,1405.97 1781.51,1405.97 1781.51,1405.97 1781.52,1405.97 1781.53,1405.97 1781.54,1405.97 1781.55,1405.97 1781.55,1405.97 1781.56,1405.97 1781.57,1405.97 1781.58,1405.97 1781.59,1405.97 1781.59,1405.97 1781.6,1405.97 1781.61,1405.97 1781.62,1405.96 1781.62,1405.96 1781.63,1405.96 1781.64,1405.96 1781.65,1405.96 1781.66,1405.96 1781.66,1405.96 1781.67,1405.96 1781.68,1405.96 1781.69,1405.96 1781.69,1405.96 1781.7,1405.96 1781.71,1405.96 1781.72,1405.96 1781.73,1405.96 1781.73,1405.96 1781.74,1405.96 1781.75,1405.96 1781.76,1405.96 1781.77,1405.96 1781.77,1405.96 1781.78,1405.96 1781.79,1405.96 1781.8,1405.96 1781.8,1405.96 1781.81,1405.96 1781.82,1405.96 1781.83,1405.96 1781.84,1405.96 1781.84,1405.96 1781.85,1405.96 1781.86,1405.96 1781.87,1405.96 1781.87,1405.96 1781.88,1405.96 1781.89,1405.96 1781.9,1405.96 1781.91,1405.96 1781.91,1405.96 1781.92,1405.96 1781.93,1405.96 1781.94,1405.96 1781.95,1405.96 1781.95,1405.96 1781.96,1405.96 1781.97,1405.96 1781.98,1405.96 1781.98,1405.96 1781.99,1405.96 1782,1405.96 1782.01,1405.96 1782.02,1405.96 1782.02,1405.96 1782.03,1405.96 1782.04,1405.96 1782.05,1405.96 1782.05,1405.96 1782.06,1405.96 1782.07,1405.96 1782.08,1405.96 1782.09,1405.96 1782.09,1405.96 1782.1,1405.96 1782.11,1405.96 1782.12,1405.96 1782.12,1405.96 1782.13,1405.95 1782.14,1405.95 1782.15,1405.95 1782.16,1405.95 1782.16,1405.95 1782.17,1405.95 1782.18,1405.95 1782.19,1405.95 1782.19,1405.95 1782.2,1405.95 1782.21,1405.95 1782.22,1405.95 1782.23,1405.95 1782.23,1405.95 1782.24,1405.95 1782.25,1405.95 1782.26,1405.95 1782.26,1405.95 1782.27,1405.95 1782.28,1405.95 1782.29,1405.95 1782.3,1405.95 1782.3,1405.95 1782.31,1405.95 1782.32,1405.95 1782.33,1405.95 1782.33,1405.95 1782.34,1405.95 1782.35,1405.95 1782.36,1405.95 1782.37,1405.95 1782.37,1405.95 1782.38,1405.95 1782.39,1405.95 1782.4,1405.95 1782.4,1405.95 1782.41,1405.95 1782.42,1405.95 1782.43,1405.95 1782.44,1405.95 1782.44,1405.95 1782.45,1405.95 1782.46,1405.95 1782.47,1405.95 1782.47,1405.95 1782.48,1405.95 1782.49,1405.95 1782.5,1405.95 1782.51,1405.95 1782.51,1405.95 1782.52,1405.95 1782.53,1405.95 1782.54,1405.95 1782.54,1405.95 1782.55,1405.95 1782.56,1405.95 1782.57,1405.95 1782.58,1405.95 1782.58,1405.95 1782.59,1405.95 1782.6,1405.95 1782.61,1405.95 1782.61,1405.95 1782.62,1405.95 1782.63,1405.95 1782.64,1405.95 1782.65,1405.95 1782.65,1405.94 1782.66,1405.94 1782.67,1405.94 1782.68,1405.94 1782.68,1405.94 1782.69,1405.94 1782.7,1405.94 1782.71,1405.94 1782.71,1405.94 1782.72,1405.94 1782.73,1405.94 1782.74,1405.94 1782.75,1405.94 1782.75,1405.94 1782.76,1405.94 1782.77,1405.94 1782.78,1405.94 1782.78,1405.94 1782.79,1405.94 1782.8,1405.94 1782.81,1405.94 1782.82,1405.94 1782.82,1405.94 1782.83,1405.94 1782.84,1405.94 1782.85,1405.94 1782.85,1405.94 1782.86,1405.94 1782.87,1405.94 1782.88,1405.94 1782.89,1405.94 1782.89,1405.94 1782.9,1405.94 1782.91,1405.94 1782.92,1405.94 1782.92,1405.94 1782.93,1405.94 1782.94,1405.94 1782.95,1405.94 1782.95,1405.94 1782.96,1405.94 1782.97,1405.94 1782.98,1405.94 1782.99,1405.94 1782.99,1405.94 1783,1405.94 1783.01,1405.94 1783.02,1405.94 1783.02,1405.94 1783.03,1405.94 1783.04,1405.94 1783.05,1405.94 1783.05,1405.94 1783.06,1405.94 1783.07,1405.94 1783.08,1405.94 1783.09,1405.94 1783.09,1405.94 1783.1,1405.94 1783.11,1405.94 1783.12,1405.94 1783.12,1405.94 1783.13,1405.94 1783.14,1405.94 1783.15,1405.94 1783.15,1405.94 1783.16,1405.94 1783.17,1405.93 1783.18,1405.93 1783.19,1405.93 1783.19,1405.93 1783.2,1405.93 1783.21,1405.93 1783.22,1405.93 1783.22,1405.93 1783.23,1405.93 1783.24,1405.93 1783.25,1405.93 1783.25,1405.93 1783.26,1405.93 1783.27,1405.93 1783.28,1405.93 1783.29,1405.93 1783.29,1405.93 1783.3,1405.93 1783.31,1405.93 1783.32,1405.93 1783.32,1405.93 1783.33,1405.93 1783.34,1405.93 1783.35,1405.93 1783.35,1405.93 1783.36,1405.93 1783.37,1405.93 1783.38,1405.93 1783.39,1405.93 1783.39,1405.93 1783.4,1405.93 1783.41,1405.93 1783.42,1405.93 1783.42,1405.93 1783.43,1405.93 1783.44,1405.93 1783.45,1405.93 1783.45,1405.93 1783.46,1405.93 1783.47,1405.93 1783.48,1405.93 1783.48,1405.93 1783.49,1405.93 1783.5,1405.93 1783.51,1405.93 1783.52,1405.93 1783.52,1405.93 1783.53,1405.93 1783.54,1405.93 1783.55,1405.93 1783.55,1405.93 1783.56,1405.93 1783.57,1405.93 1783.58,1405.93 1783.58,1405.93 1783.59,1405.93 1783.6,1405.93 1783.61,1405.93 1783.61,1405.93 1783.62,1405.93 1783.63,1405.93 1783.64,1405.93 1783.65,1405.93 1783.65,1405.93 1783.66,1405.93 1783.67,1405.93 1783.68,1405.93 1783.68,1405.92 1783.69,1405.92 1783.7,1405.92 1783.71,1405.92 1783.71,1405.92 1783.72,1405.92 1783.73,1405.92 1783.74,1405.92 1783.74,1405.92 1783.75,1405.92 1783.76,1405.92 1783.77,1405.92 1783.78,1405.92 1783.78,1405.92 1783.79,1405.92 1783.8,1405.92 1783.81,1405.92 1783.81,1405.92 1783.82,1405.92 1783.83,1405.92 1783.84,1405.92 1783.84,1405.92 1783.85,1405.92 1783.86,1405.92 1783.87,1405.92 1783.87,1405.92 1783.88,1405.92 1783.89,1405.92 1783.9,1405.92 1783.91,1405.92 1783.91,1405.92 1783.92,1405.92 1783.93,1405.92 1783.94,1405.92 1783.94,1405.92 1783.95,1405.92 1783.96,1405.92 1783.97,1405.92 1783.97,1405.92 1783.98,1405.92 1783.99,1405.92 1784,1405.92 1784,1405.92 1784.01,1405.92 1784.02,1405.92 1784.03,1405.92 1784.03,1405.92 1784.04,1405.92 1784.05,1405.92 1784.06,1405.92 1784.06,1405.92 1784.07,1405.92 1784.08,1405.92 1784.09,1405.92 1784.1,1405.92 1784.1,1405.92 1784.11,1405.92 1784.12,1405.92 1784.13,1405.92 1784.13,1405.92 1784.14,1405.92 1784.15,1405.92 1784.16,1405.92 1784.16,1405.92 1784.17,1405.92 1784.18,1405.92 1784.19,1405.92 1784.19,1405.91 1784.2,1405.91 1784.21,1405.91 1784.22,1405.91 1784.22,1405.91 1784.23,1405.91 1784.24,1405.91 1784.25,1405.91 1784.25,1405.91 1784.26,1405.91 1784.27,1405.91 1784.28,1405.91 1784.29,1405.91 1784.29,1405.91 1784.3,1405.91 1784.31,1405.91 1784.32,1405.91 1784.32,1405.91 1784.33,1405.91 1784.34,1405.91 1784.35,1405.91 1784.35,1405.91 1784.36,1405.91 1784.37,1405.91 1784.38,1405.91 1784.38,1405.91 1784.39,1405.91 1784.4,1405.91 1784.41,1405.91 1784.41,1405.91 1784.42,1405.91 1784.43,1405.91 1784.44,1405.91 1784.44,1405.91 1784.45,1405.91 1784.46,1405.91 1784.47,1405.91 1784.47,1405.91 1784.48,1405.91 1784.49,1405.91 1784.5,1405.91 1784.5,1405.91 1784.51,1405.91 1784.52,1405.91 1784.53,1405.91 1784.53,1405.91 1784.54,1405.91 1784.55,1405.91 1784.56,1405.91 1784.57,1405.91 1784.57,1405.91 1784.58,1405.91 1784.59,1405.91 1784.6,1405.91 1784.6,1405.91 1784.61,1405.91 1784.62,1405.91 1784.63,1405.91 1784.63,1405.91 1784.64,1405.91 1784.65,1405.91 1784.66,1405.91 1784.66,1405.91 1784.67,1405.91 1784.68,1405.91 1784.69,1405.91 1784.69,1405.91 1784.7,1405.9 1784.71,1405.9 1784.72,1405.9 1784.72,1405.9 1784.73,1405.9 1784.74,1405.9 1784.75,1405.9 1784.75,1405.9 1784.76,1405.9 1784.77,1405.9 1784.78,1405.9 1784.78,1405.9 1784.79,1405.9 1784.8,1405.9 1784.81,1405.9 1784.81,1405.9 1784.82,1405.9 1784.83,1405.9 1784.84,1405.9 1784.84,1405.9 1784.85,1405.9 1784.86,1405.9 1784.87,1405.9 1784.87,1405.9 1784.88,1405.9 1784.89,1405.9 1784.9,1405.9 1784.9,1405.9 1784.91,1405.9 1784.92,1405.9 1784.93,1405.9 1784.93,1405.9 1784.94,1405.9 1784.95,1405.9 1784.96,1405.9 1784.96,1405.9 1784.97,1405.9 1784.98,1405.9 1784.99,1405.9 1784.99,1405.9 1785,1405.9 1785.01,1405.9 1785.02,1405.9 1785.02,1405.9 1785.03,1405.9 1785.04,1405.9 1785.05,1405.9 1785.05,1405.9 1785.06,1405.9 1785.07,1405.9 1785.08,1405.9 1785.08,1405.9 1785.09,1405.9 1785.1,1405.9 1785.11,1405.9 1785.11,1405.9 1785.12,1405.9 1785.13,1405.9 1785.14,1405.9 1785.14,1405.9 1785.15,1405.9 1785.16,1405.9 1785.17,1405.9 1785.17,1405.9 1785.18,1405.9 1785.19,1405.9 1785.2,1405.9 1785.2,1405.9 1785.21,1405.89 1785.22,1405.89 1785.23,1405.89 1785.23,1405.89 1785.24,1405.89 1785.25,1405.89 1785.26,1405.89 1785.26,1405.89 1785.27,1405.89 1785.28,1405.89 1785.29,1405.89 1785.29,1405.89 1785.3,1405.89 1785.31,1405.89 1785.32,1405.89 1785.32,1405.89 1785.33,1405.89 1785.34,1405.89 1785.35,1405.89 1785.35,1405.89 1785.36,1405.89 1785.37,1405.89 1785.38,1405.89 1785.38,1405.89 1785.39,1405.89 1785.4,1405.89 1785.41,1405.89 1785.41,1405.89 1785.42,1405.89 1785.43,1405.89 1785.44,1405.89 1785.44,1405.89 1785.45,1405.89 1785.46,1405.89 1785.47,1405.89 1785.47,1405.89 1785.48,1405.89 1785.49,1405.89 1785.5,1405.89 1785.5,1405.89 1785.51,1405.89 1785.52,1405.89 1785.53,1405.89 1785.53,1405.89 1785.54,1405.89 1785.55,1405.89 1785.56,1405.89 1785.56,1405.89 1785.57,1405.89 1785.58,1405.89 1785.59,1405.89 1785.59,1405.89 1785.6,1405.89 1785.61,1405.89 1785.62,1405.89 1785.62,1405.89 1785.63,1405.89 1785.64,1405.89 1785.65,1405.89 1785.65,1405.89 1785.66,1405.89 1785.67,1405.89 1785.68,1405.89 1785.68,1405.89 1785.69,1405.89 1785.7,1405.89 1785.71,1405.89 1785.71,1405.89 1785.72,1405.88 1785.73,1405.88 1785.73,1405.88 1785.74,1405.88 1785.75,1405.88 1785.76,1405.88 1785.76,1405.88 1785.77,1405.88 1785.78,1405.88 1785.79,1405.88 1785.79,1405.88 1785.8,1405.88 1785.81,1405.88 1785.82,1405.88 1785.82,1405.88 1785.83,1405.88 1785.84,1405.88 1785.85,1405.88 1785.85,1405.88 1785.86,1405.88 1785.87,1405.88 1785.88,1405.88 1785.88,1405.88 1785.89,1405.88 1785.9,1405.88 1785.91,1405.88 1785.91,1405.88 1785.92,1405.88 1785.93,1405.88 1785.94,1405.88 1785.94,1405.88 1785.95,1405.88 1785.96,1405.88 1785.97,1405.88 1785.97,1405.88 1785.98,1405.88 1785.99,1405.88 1785.99,1405.88 1786,1405.88 1786.01,1405.88 1786.02,1405.88 1786.02,1405.88 1786.03,1405.88 1786.04,1405.88 1786.05,1405.88 1786.05,1405.88 1786.06,1405.88 1786.07,1405.88 1786.08,1405.88 1786.08,1405.88 1786.09,1405.88 1786.1,1405.88 1786.11,1405.88 1786.11,1405.88 1786.12,1405.88 1786.13,1405.88 1786.14,1405.88 1786.14,1405.88 1786.15,1405.88 1786.16,1405.88 1786.17,1405.88 1786.17,1405.88 1786.18,1405.88 1786.19,1405.88 1786.19,1405.88 1786.2,1405.88 1786.21,1405.88 1786.22,1405.87 1786.22,1405.87 1786.23,1405.87 1786.24,1405.87 1786.25,1405.87 1786.25,1405.87 1786.26,1405.87 1786.27,1405.87 1786.28,1405.87 1786.28,1405.87 1786.29,1405.87 1786.3,1405.87 1786.31,1405.87 1786.31,1405.87 1786.32,1405.87 1786.33,1405.87 1786.34,1405.87 1786.34,1405.87 1786.35,1405.87 1786.36,1405.87 1786.36,1405.87 1786.37,1405.87 1786.38,1405.87 1786.39,1405.87 1786.39,1405.87 1786.4,1405.87 1786.41,1405.87 1786.42,1405.87 1786.42,1405.87 1786.43,1405.87 1786.44,1405.87 1786.45,1405.87 1786.45,1405.87 1786.46,1405.87 1786.47,1405.87 1786.48,1405.87 1786.48,1405.87 1786.49,1405.87 1786.5,1405.87 1786.5,1405.87 1786.51,1405.87 1786.52,1405.87 1786.53,1405.87 1786.53,1405.87 1786.54,1405.87 1786.55,1405.87 1786.56,1405.87 1786.56,1405.87 1786.57,1405.87 1786.58,1405.87 1786.59,1405.87 1786.59,1405.87 1786.6,1405.87 1786.61,1405.87 1786.62,1405.87 1786.62,1405.87 1786.63,1405.87 1786.64,1405.87 1786.64,1405.87 1786.65,1405.87 1786.66,1405.87 1786.67,1405.87 1786.67,1405.87 1786.68,1405.87 1786.69,1405.87 1786.7,1405.87 1786.7,1405.87 1786.71,1405.87 1786.72,1405.87 1786.73,1405.86 1786.73,1405.86 1786.74,1405.86 1786.75,1405.86 1786.75,1405.86 1786.76,1405.86 1786.77,1405.86 1786.78,1405.86 1786.78,1405.86 1786.79,1405.86 1786.8,1405.86 1786.81,1405.86 1786.81,1405.86 1786.82,1405.86 1786.83,1405.86 1786.84,1405.86 1786.84,1405.86 1786.85,1405.86 1786.86,1405.86 1786.86,1405.86 1786.87,1405.86 1786.88,1405.86 1786.89,1405.86 1786.89,1405.86 1786.9,1405.86 1786.91,1405.86 1786.92,1405.86 1786.92,1405.86 1786.93,1405.86 1786.94,1405.86 1786.95,1405.86 1786.95,1405.86 1786.96,1405.86 1786.97,1405.86 1786.97,1405.86 1786.98,1405.86 1786.99,1405.86 1787,1405.86 1787,1405.86 1787.01,1405.86 1787.02,1405.86 1787.03,1405.86 1787.03,1405.86 1787.04,1405.86 1787.05,1405.86 1787.06,1405.86 1787.06,1405.86 1787.07,1405.86 1787.08,1405.86 1787.08,1405.86 1787.09,1405.86 1787.1,1405.86 1787.11,1405.86 1787.11,1405.86 1787.12,1405.86 1787.13,1405.86 1787.14,1405.86 1787.14,1405.86 1787.15,1405.86 1787.16,1405.86 1787.16,1405.86 1787.17,1405.86 1787.18,1405.86 1787.19,1405.86 1787.19,1405.86 1787.2,1405.86 1787.21,1405.86 1787.22,1405.86 1787.22,1405.85 1787.23,1405.85 1787.24,1405.85 1787.25,1405.85 1787.25,1405.85 1787.26,1405.85 1787.27,1405.85 1787.27,1405.85 1787.28,1405.85 1787.29,1405.85 1787.3,1405.85 1787.3,1405.85 1787.31,1405.85 1787.32,1405.85 1787.33,1405.85 1787.33,1405.85 1787.34,1405.85 1787.35,1405.85 1787.35,1405.85 1787.36,1405.85 1787.37,1405.85 1787.38,1405.85 1787.38,1405.85 1787.39,1405.85 1787.4,1405.85 1787.41,1405.85 1787.41,1405.85 1787.42,1405.85 1787.43,1405.85 1787.43,1405.85 1787.44,1405.85 1787.45,1405.85 1787.46,1405.85 1787.46,1405.85 1787.47,1405.85 1787.48,1405.85 1787.49,1405.85 1787.49,1405.85 1787.5,1405.85 1787.51,1405.85 1787.51,1405.85 1787.52,1405.85 1787.53,1405.85 1787.54,1405.85 1787.54,1405.85 1787.55,1405.85 1787.56,1405.85 1787.57,1405.85 1787.57,1405.85 1787.58,1405.85 1787.59,1405.85 1787.59,1405.85 1787.6,1405.85 1787.61,1405.85 1787.62,1405.85 1787.62,1405.85 1787.63,1405.85 1787.64,1405.85 1787.65,1405.85 1787.65,1405.85 1787.66,1405.85 1787.67,1405.85 1787.67,1405.85 1787.68,1405.85 1787.69,1405.85 1787.7,1405.85 1787.7,1405.85 1787.71,1405.85 1787.72,1405.84 1787.73,1405.84 1787.73,1405.84 1787.74,1405.84 1787.75,1405.84 1787.75,1405.84 1787.76,1405.84 1787.77,1405.84 1787.78,1405.84 1787.78,1405.84 1787.79,1405.84 1787.8,1405.84 1787.8,1405.84 1787.81,1405.84 1787.82,1405.84 1787.83,1405.84 1787.83,1405.84 1787.84,1405.84 1787.85,1405.84 1787.86,1405.84 1787.86,1405.84 1787.87,1405.84 1787.88,1405.84 1787.88,1405.84 1787.89,1405.84 1787.9,1405.84 1787.91,1405.84 1787.91,1405.84 1787.92,1405.84 1787.93,1405.84 1787.94,1405.84 1787.94,1405.84 1787.95,1405.84 1787.96,1405.84 1787.96,1405.84 1787.97,1405.84 1787.98,1405.84 1787.99,1405.84 1787.99,1405.84 1788,1405.84 1788.01,1405.84 1788.01,1405.84 1788.02,1405.84 1788.03,1405.84 1788.04,1405.84 1788.04,1405.84 1788.05,1405.84 1788.06,1405.84 1788.07,1405.84 1788.07,1405.84 1788.08,1405.84 1788.09,1405.84 1788.09,1405.84 1788.1,1405.84 1788.11,1405.84 1788.12,1405.84 1788.12,1405.84 1788.13,1405.84 1788.14,1405.84 1788.14,1405.84 1788.15,1405.84 1788.16,1405.84 1788.17,1405.84 1788.17,1405.84 1788.18,1405.84 1788.19,1405.84 1788.19,1405.84 1788.2,1405.84 1788.21,1405.84 1788.22,1405.83 1788.22,1405.83 1788.23,1405.83 1788.24,1405.83 1788.25,1405.83 1788.25,1405.83 1788.26,1405.83 1788.27,1405.83 1788.27,1405.83 1788.28,1405.83 1788.29,1405.83 1788.3,1405.83 1788.3,1405.83 1788.31,1405.83 1788.32,1405.83 1788.32,1405.83 1788.33,1405.83 1788.34,1405.83 1788.35,1405.83 1788.35,1405.83 1788.36,1405.83 1788.37,1405.83 1788.37,1405.83 1788.38,1405.83 1788.39,1405.83 1788.4,1405.83 1788.4,1405.83 1788.41,1405.83 1788.42,1405.83 1788.43,1405.83 1788.43,1405.83 1788.44,1405.83 1788.45,1405.83 1788.45,1405.83 1788.46,1405.83 1788.47,1405.83 1788.48,1405.83 1788.48,1405.83 1788.49,1405.83 1788.5,1405.83 1788.5,1405.83 1788.51,1405.83 1788.52,1405.83 1788.53,1405.83 1788.53,1405.83 1788.54,1405.83 1788.55,1405.83 1788.55,1405.83 1788.56,1405.83 1788.57,1405.83 1788.58,1405.83 1788.58,1405.83 1788.59,1405.83 1788.6,1405.83 1788.6,1405.83 1788.61,1405.83 1788.62,1405.83 1788.63,1405.83 1788.63,1405.83 1788.64,1405.83 1788.65,1405.83 1788.65,1405.83 1788.66,1405.83 1788.67,1405.83 1788.68,1405.83 1788.68,1405.83 1788.69,1405.83 1788.7,1405.83 1788.7,1405.83 1788.71,1405.82 1788.72,1405.82 1788.73,1405.82 1788.73,1405.82 1788.74,1405.82 1788.75,1405.82 1788.75,1405.82 1788.76,1405.82 1788.77,1405.82 1788.78,1405.82 1788.78,1405.82 1788.79,1405.82 1788.8,1405.82 1788.8,1405.82 1788.81,1405.82 1788.82,1405.82 1788.83,1405.82 1788.83,1405.82 1788.84,1405.82 1788.85,1405.82 1788.85,1405.82 1788.86,1405.82 1788.87,1405.82 1788.88,1405.82 1788.88,1405.82 1788.89,1405.82 1788.9,1405.82 1788.9,1405.82 1788.91,1405.82 1788.92,1405.82 1788.93,1405.82 1788.93,1405.82 1788.94,1405.82 1788.95,1405.82 1788.95,1405.82 1788.96,1405.82 1788.97,1405.82 1788.98,1405.82 1788.98,1405.82 1788.99,1405.82 1789,1405.82 1789,1405.82 1789.01,1405.82 1789.02,1405.82 1789.03,1405.82 1789.03,1405.82 1789.04,1405.82 1789.05,1405.82 1789.05,1405.82 1789.06,1405.82 1789.07,1405.82 1789.08,1405.82 1789.08,1405.82 1789.09,1405.82 1789.1,1405.82 1789.1,1405.82 1789.11,1405.82 1789.12,1405.82 1789.13,1405.82 1789.13,1405.82 1789.14,1405.82 1789.15,1405.82 1789.15,1405.82 1789.16,1405.82 1789.17,1405.82 1789.18,1405.82 1789.18,1405.82 1789.19,1405.82 1789.2,1405.82 1789.2,1405.81 1789.21,1405.81 1789.22,1405.81 1789.23,1405.81 1789.23,1405.81 1789.24,1405.81 1789.25,1405.81 1789.25,1405.81 1789.26,1405.81 1789.27,1405.81 1789.28,1405.81 1789.28,1405.81 1789.29,1405.81 1789.3,1405.81 1789.3,1405.81 1789.31,1405.81 1789.32,1405.81 1789.32,1405.81 1789.33,1405.81 1789.34,1405.81 1789.35,1405.81 1789.35,1405.81 1789.36,1405.81 1789.37,1405.81 1789.37,1405.81 1789.38,1405.81 1789.39,1405.81 1789.4,1405.81 1789.4,1405.81 1789.41,1405.81 1789.42,1405.81 1789.42,1405.81 1789.43,1405.81 1789.44,1405.81 1789.45,1405.81 1789.45,1405.81 1789.46,1405.81 1789.47,1405.81 1789.47,1405.81 1789.48,1405.81 1789.49,1405.81 1789.49,1405.81 1789.5,1405.81 1789.51,1405.81 1789.52,1405.81 1789.52,1405.81 1789.53,1405.81 1789.54,1405.81 1789.54,1405.81 1789.55,1405.81 1789.56,1405.81 1789.57,1405.81 1789.57,1405.81 1789.58,1405.81 1789.59,1405.81 1789.59,1405.81 1789.6,1405.81 1789.61,1405.81 1789.62,1405.81 1789.62,1405.81 1789.63,1405.81 1789.64,1405.81 1789.64,1405.81 1789.65,1405.81 1789.66,1405.81 1789.66,1405.81 1789.67,1405.81 1789.68,1405.81 1789.69,1405.81 1789.69,1405.8 1789.7,1405.8 1789.71,1405.8 1789.71,1405.8 1789.72,1405.8 1789.73,1405.8 1789.74,1405.8 1789.74,1405.8 1789.75,1405.8 1789.76,1405.8 1789.76,1405.8 1789.77,1405.8 1789.78,1405.8 1789.78,1405.8 1789.79,1405.8 1789.8,1405.8 1789.81,1405.8 1789.81,1405.8 1789.82,1405.8 1789.83,1405.8 1789.83,1405.8 1789.84,1405.8 1789.85,1405.8 1789.86,1405.8 1789.86,1405.8 1789.87,1405.8 1789.88,1405.8 1789.88,1405.8 1789.89,1405.8 1789.9,1405.8 1789.9,1405.8 1789.91,1405.8 1789.92,1405.8 1789.93,1405.8 1789.93,1405.8 1789.94,1405.8 1789.95,1405.8 1789.95,1405.8 1789.96,1405.8 1789.97,1405.8 1789.97,1405.8 1789.98,1405.8 1789.99,1405.8 1790,1405.8 1790,1405.8 1790.01,1405.8 1790.02,1405.8 1790.02,1405.8 1790.03,1405.8 1790.04,1405.8 1790.05,1405.8 1790.05,1405.8 1790.06,1405.8 1790.07,1405.8 1790.07,1405.8 1790.08,1405.8 1790.09,1405.8 1790.09,1405.8 1790.1,1405.8 1790.11,1405.8 1790.12,1405.8 1790.12,1405.8 1790.13,1405.8 1790.14,1405.8 1790.14,1405.8 1790.15,1405.8 1790.16,1405.8 1790.16,1405.8 1790.17,1405.8 1790.18,1405.8 1790.19,1405.79 1790.19,1405.79 1790.2,1405.79 1790.21,1405.79 1790.21,1405.79 1790.22,1405.79 1790.23,1405.79 1790.23,1405.79 1790.24,1405.79 1790.25,1405.79 1790.26,1405.79 1790.26,1405.79 1790.27,1405.79 1790.28,1405.79 1790.28,1405.79 1790.29,1405.79 1790.3,1405.79 1790.3,1405.79 1790.31,1405.79 1790.32,1405.79 1790.33,1405.79 1790.33,1405.79 1790.34,1405.79 1790.35,1405.79 1790.35,1405.79 1790.36,1405.79 1790.37,1405.79 1790.37,1405.79 1790.38,1405.79 1790.39,1405.79 1790.4,1405.79 1790.4,1405.79 1790.41,1405.79 1790.42,1405.79 1790.42,1405.79 1790.43,1405.79 1790.44,1405.79 1790.44,1405.79 1790.45,1405.79 1790.46,1405.79 1790.47,1405.79 1790.47,1405.79 1790.48,1405.79 1790.49,1405.79 1790.49,1405.79 1790.5,1405.79 1790.51,1405.79 1790.51,1405.79 1790.52,1405.79 1790.53,1405.79 1790.54,1405.79 1790.54,1405.79 1790.55,1405.79 1790.56,1405.79 1790.56,1405.79 1790.57,1405.79 1790.58,1405.79 1790.58,1405.79 1790.59,1405.79 1790.6,1405.79 1790.61,1405.79 1790.61,1405.79 1790.62,1405.79 1790.63,1405.79 1790.63,1405.79 1790.64,1405.79 1790.65,1405.79 1790.65,1405.79 1790.66,1405.79 1790.67,1405.78 1790.68,1405.78 1790.68,1405.78 1790.69,1405.78 1790.7,1405.78 1790.7,1405.78 1790.71,1405.78 1790.72,1405.78 1790.72,1405.78 1790.73,1405.78 1790.74,1405.78 1790.74,1405.78 1790.75,1405.78 1790.76,1405.78 1790.77,1405.78 1790.77,1405.78 1790.78,1405.78 1790.79,1405.78 1790.79,1405.78 1790.8,1405.78 1790.81,1405.78 1790.81,1405.78 1790.82,1405.78 1790.83,1405.78 1790.84,1405.78 1790.84,1405.78 1790.85,1405.78 1790.86,1405.78 1790.86,1405.78 1790.87,1405.78 1790.88,1405.78 1790.88,1405.78 1790.89,1405.78 1790.9,1405.78 1790.9,1405.78 1790.91,1405.78 1790.92,1405.78 1790.93,1405.78 1790.93,1405.78 1790.94,1405.78 1790.95,1405.78 1790.95,1405.78 1790.96,1405.78 1790.97,1405.78 1790.97,1405.78 1790.98,1405.78 1790.99,1405.78 1790.99,1405.78 1791,1405.78 1791.01,1405.78 1791.02,1405.78 1791.02,1405.78 1791.03,1405.78 1791.04,1405.78 1791.04,1405.78 1791.05,1405.78 1791.06,1405.78 1791.06,1405.78 1791.07,1405.78 1791.08,1405.78 1791.09,1405.78 1791.09,1405.78 1791.1,1405.78 1791.11,1405.78 1791.11,1405.78 1791.12,1405.78 1791.13,1405.78 1791.13,1405.78 1791.14,1405.78 1791.15,1405.78 1791.15,1405.77 1791.16,1405.77 1791.17,1405.77 1791.18,1405.77 1791.18,1405.77 1791.19,1405.77 1791.2,1405.77 1791.2,1405.77 1791.21,1405.77 1791.22,1405.77 1791.22,1405.77 1791.23,1405.77 1791.24,1405.77 1791.24,1405.77 1791.25,1405.77 1791.26,1405.77 1791.27,1405.77 1791.27,1405.77 1791.28,1405.77 1791.29,1405.77 1791.29,1405.77 1791.3,1405.77 1791.31,1405.77 1791.31,1405.77 1791.32,1405.77 1791.33,1405.77 1791.33,1405.77 1791.34,1405.77 1791.35,1405.77 1791.35,1405.77 1791.36,1405.77 1791.37,1405.77 1791.38,1405.77 1791.38,1405.77 1791.39,1405.77 1791.4,1405.77 1791.4,1405.77 1791.41,1405.77 1791.42,1405.77 1791.42,1405.77 1791.43,1405.77 1791.44,1405.77 1791.44,1405.77 1791.45,1405.77 1791.46,1405.77 1791.47,1405.77 1791.47,1405.77 1791.48,1405.77 1791.49,1405.77 1791.49,1405.77 1791.5,1405.77 1791.51,1405.77 1791.51,1405.77 1791.52,1405.77 1791.53,1405.77 1791.53,1405.77 1791.54,1405.77 1791.55,1405.77 1791.55,1405.77 1791.56,1405.77 1791.57,1405.77 1791.58,1405.77 1791.58,1405.77 1791.59,1405.77 1791.6,1405.77 1791.6,1405.77 1791.61,1405.77 1791.62,1405.77 1791.62,1405.77 1791.63,1405.77 1791.64,1405.77 1791.64,1405.76 1791.65,1405.76 1791.66,1405.76 1791.66,1405.76 1791.67,1405.76 1791.68,1405.76 1791.69,1405.76 1791.69,1405.76 1791.7,1405.76 1791.71,1405.76 1791.71,1405.76 1791.72,1405.76 1791.73,1405.76 1791.73,1405.76 1791.74,1405.76 1791.75,1405.76 1791.75,1405.76 1791.76,1405.76 1791.77,1405.76 1791.77,1405.76 1791.78,1405.76 1791.79,1405.76 1791.8,1405.76 1791.8,1405.76 1791.81,1405.76 1791.82,1405.76 1791.82,1405.76 1791.83,1405.76 1791.84,1405.76 1791.84,1405.76 1791.85,1405.76 1791.86,1405.76 1791.86,1405.76 1791.87,1405.76 1791.88,1405.76 1791.88,1405.76 1791.89,1405.76 1791.9,1405.76 1791.91,1405.76 1791.91,1405.76 1791.92,1405.76 1791.93,1405.76 1791.93,1405.76 1791.94,1405.76 1791.95,1405.76 1791.95,1405.76 1791.96,1405.76 1791.97,1405.76 1791.97,1405.76 1791.98,1405.76 1791.99,1405.76 1791.99,1405.76 1792,1405.76 1792.01,1405.76 1792.01,1405.76 1792.02,1405.76 1792.03,1405.76 1792.04,1405.76 1792.04,1405.76 1792.05,1405.76 1792.06,1405.76 1792.06,1405.76 1792.07,1405.76 1792.08,1405.76 1792.08,1405.76 1792.09,1405.76 1792.1,1405.76 1792.1,1405.76 1792.11,1405.76 1792.12,1405.76 1792.12,1405.75 1792.13,1405.75 1792.14,1405.75 1792.14,1405.75 1792.15,1405.75 1792.16,1405.75 1792.17,1405.75 1792.17,1405.75 1792.18,1405.75 1792.19,1405.75 1792.19,1405.75 1792.2,1405.75 1792.21,1405.75 1792.21,1405.75 1792.22,1405.75 1792.23,1405.75 1792.23,1405.75 1792.24,1405.75 1792.25,1405.75 1792.25,1405.75 1792.26,1405.75 1792.27,1405.75 1792.27,1405.75 1792.28,1405.75 1792.29,1405.75 1792.29,1405.75 1792.3,1405.75 1792.31,1405.75 1792.32,1405.75 1792.32,1405.75 1792.33,1405.75 1792.34,1405.75 1792.34,1405.75 1792.35,1405.75 1792.36,1405.75 1792.36,1405.75 1792.37,1405.75 1792.38,1405.75 1792.38,1405.75 1792.39,1405.75 1792.4,1405.75 1792.4,1405.75 1792.41,1405.75 1792.42,1405.75 1792.42,1405.75 1792.43,1405.75 1792.44,1405.75 1792.44,1405.75 1792.45,1405.75 1792.46,1405.75 1792.47,1405.75 1792.47,1405.75 1792.48,1405.75 1792.49,1405.75 1792.49,1405.75 1792.5,1405.75 1792.51,1405.75 1792.51,1405.75 1792.52,1405.75 1792.53,1405.75 1792.53,1405.75 1792.54,1405.75 1792.55,1405.75 1792.55,1405.75 1792.56,1405.75 1792.57,1405.75 1792.57,1405.75 1792.58,1405.75 1792.59,1405.75 1792.59,1405.75 1792.6,1405.75 1792.61,1405.74 1792.61,1405.74 1792.62,1405.74 1792.63,1405.74 1792.63,1405.74 1792.64,1405.74 1792.65,1405.74 1792.66,1405.74 1792.66,1405.74 1792.67,1405.74 1792.68,1405.74 1792.68,1405.74 1792.69,1405.74 1792.7,1405.74 1792.7,1405.74 1792.71,1405.74 1792.72,1405.74 1792.72,1405.74 1792.73,1405.74 1792.74,1405.74 1792.74,1405.74 1792.75,1405.74 1792.76,1405.74 1792.76,1405.74 1792.77,1405.74 1792.78,1405.74 1792.78,1405.74 1792.79,1405.74 1792.8,1405.74 1792.8,1405.74 1792.81,1405.74 1792.82,1405.74 1792.82,1405.74 1792.83,1405.74 1792.84,1405.74 1792.85,1405.74 1792.85,1405.74 1792.86,1405.74 1792.87,1405.74 1792.87,1405.74 1792.88,1405.74 1792.89,1405.74 1792.89,1405.74 1792.9,1405.74 1792.91,1405.74 1792.91,1405.74 1792.92,1405.74 1792.93,1405.74 1792.93,1405.74 1792.94,1405.74 1792.95,1405.74 1792.95,1405.74 1792.96,1405.74 1792.97,1405.74 1792.97,1405.74 1792.98,1405.74 1792.99,1405.74 1792.99,1405.74 1793,1405.74 1793.01,1405.74 1793.01,1405.74 1793.02,1405.74 1793.03,1405.74 1793.03,1405.74 1793.04,1405.74 1793.05,1405.74 1793.05,1405.74 1793.06,1405.74 1793.07,1405.74 1793.07,1405.74 1793.08,1405.73 1793.09,1405.73 1793.09,1405.73 1793.1,1405.73 1793.11,1405.73 1793.12,1405.73 1793.12,1405.73 1793.13,1405.73 1793.14,1405.73 1793.14,1405.73 1793.15,1405.73 1793.16,1405.73 1793.16,1405.73 1793.17,1405.73 1793.18,1405.73 1793.18,1405.73 1793.19,1405.73 1793.2,1405.73 1793.2,1405.73 1793.21,1405.73 1793.22,1405.73 1793.22,1405.73 1793.23,1405.73 1793.24,1405.73 1793.24,1405.73 1793.25,1405.73 1793.26,1405.73 1793.26,1405.73 1793.27,1405.73 1793.28,1405.73 1793.28,1405.73 1793.29,1405.73 1793.3,1405.73 1793.3,1405.73 1793.31,1405.73 1793.32,1405.73 1793.32,1405.73 1793.33,1405.73 1793.34,1405.73 1793.34,1405.73 1793.35,1405.73 1793.36,1405.73 1793.36,1405.73 1793.37,1405.73 1793.38,1405.73 1793.38,1405.73 1793.39,1405.73 1793.4,1405.73 1793.4,1405.73 1793.41,1405.73 1793.42,1405.73 1793.42,1405.73 1793.43,1405.73 1793.44,1405.73 1793.44,1405.73 1793.45,1405.73 1793.46,1405.73 1793.46,1405.73 1793.47,1405.73 1793.48,1405.73 1793.49,1405.73 1793.49,1405.73 1793.5,1405.73 1793.51,1405.73 1793.51,1405.73 1793.52,1405.73 1793.53,1405.73 1793.53,1405.73 1793.54,1405.73 1793.55,1405.73 1793.55,1405.73 1793.56,1405.73 1793.57,1405.72 1793.57,1405.72 1793.58,1405.72 1793.59,1405.72 1793.59,1405.72 1793.6,1405.72 1793.61,1405.72 1793.61,1405.72 1793.62,1405.72 1793.63,1405.72 1793.63,1405.72 1793.64,1405.72 1793.65,1405.72 1793.65,1405.72 1793.66,1405.72 1793.67,1405.72 1793.67,1405.72 1793.68,1405.72 1793.69,1405.72 1793.69,1405.72 1793.7,1405.72 1793.71,1405.72 1793.71,1405.72 1793.72,1405.72 1793.73,1405.72 1793.73,1405.72 1793.74,1405.72 1793.75,1405.72 1793.75,1405.72 1793.76,1405.72 1793.77,1405.72 1793.77,1405.72 1793.78,1405.72 1793.79,1405.72 1793.79,1405.72 1793.8,1405.72 1793.81,1405.72 1793.81,1405.72 1793.82,1405.72 1793.83,1405.72 1793.83,1405.72 1793.84,1405.72 1793.85,1405.72 1793.85,1405.72 1793.86,1405.72 1793.87,1405.72 1793.87,1405.72 1793.88,1405.72 1793.89,1405.72 1793.89,1405.72 1793.9,1405.72 1793.91,1405.72 1793.91,1405.72 1793.92,1405.72 1793.93,1405.72 1793.93,1405.72 1793.94,1405.72 1793.95,1405.72 1793.95,1405.72 1793.96,1405.72 1793.97,1405.72 1793.97,1405.72 1793.98,1405.72 1793.99,1405.72 1793.99,1405.72 1794,1405.72 1794.01,1405.72 1794.01,1405.72 1794.02,1405.72 1794.03,1405.72 1794.03,1405.72 1794.04,1405.71 1794.05,1405.71 1794.05,1405.71 1794.06,1405.71 1794.07,1405.71 1794.07,1405.71 1794.08,1405.71 1794.09,1405.71 1794.09,1405.71 1794.1,1405.71 1794.11,1405.71 1794.11,1405.71 1794.12,1405.71 1794.13,1405.71 1794.13,1405.71 1794.14,1405.71 1794.15,1405.71 1794.15,1405.71 1794.16,1405.71 1794.17,1405.71 1794.17,1405.71 1794.18,1405.71 1794.19,1405.71 1794.19,1405.71 1794.2,1405.71 1794.21,1405.71 1794.21,1405.71 1794.22,1405.71 1794.23,1405.71 1794.23,1405.71 1794.24,1405.71 1794.25,1405.71 1794.25,1405.71 1794.26,1405.71 1794.27,1405.71 1794.27,1405.71 1794.28,1405.71 1794.29,1405.71 1794.29,1405.71 1794.3,1405.71 1794.31,1405.71 1794.31,1405.71 1794.32,1405.71 1794.33,1405.71 1794.33,1405.71 1794.34,1405.71 1794.35,1405.71 1794.35,1405.71 1794.36,1405.71 1794.37,1405.71 1794.37,1405.71 1794.38,1405.71 1794.38,1405.71 1794.39,1405.71 1794.4,1405.71 1794.4,1405.71 1794.41,1405.71 1794.42,1405.71 1794.42,1405.71 1794.43,1405.71 1794.44,1405.71 1794.44,1405.71 1794.45,1405.71 1794.46,1405.71 1794.46,1405.71 1794.47,1405.71 1794.48,1405.71 1794.48,1405.71 1794.49,1405.71 1794.5,1405.71 1794.5,1405.71 1794.51,1405.71 1794.52,1405.7 1794.52,1405.7 1794.53,1405.7 1794.54,1405.7 1794.54,1405.7 1794.55,1405.7 1794.56,1405.7 1794.56,1405.7 1794.57,1405.7 1794.58,1405.7 1794.58,1405.7 1794.59,1405.7 1794.6,1405.7 1794.6,1405.7 1794.61,1405.7 1794.62,1405.7 1794.62,1405.7 1794.63,1405.7 1794.64,1405.7 1794.64,1405.7 1794.65,1405.7 1794.66,1405.7 1794.66,1405.7 1794.67,1405.7 1794.68,1405.7 1794.68,1405.7 1794.69,1405.7 1794.7,1405.7 1794.7,1405.7 1794.71,1405.7 1794.72,1405.7 1794.72,1405.7 1794.73,1405.7 1794.74,1405.7 1794.74,1405.7 1794.75,1405.7 1794.75,1405.7 1794.76,1405.7 1794.77,1405.7 1794.77,1405.7 1794.78,1405.7 1794.79,1405.7 1794.79,1405.7 1794.8,1405.7 1794.81,1405.7 1794.81,1405.7 1794.82,1405.7 1794.83,1405.7 1794.83,1405.7 1794.84,1405.7 1794.85,1405.7 1794.85,1405.7 1794.86,1405.7 1794.87,1405.7 1794.87,1405.7 1794.88,1405.7 1794.89,1405.7 1794.89,1405.7 1794.9,1405.7 1794.91,1405.7 1794.91,1405.7 1794.92,1405.7 1794.93,1405.7 1794.93,1405.7 1794.94,1405.7 1794.95,1405.7 1794.95,1405.7 1794.96,1405.7 1794.97,1405.7 1794.97,1405.7 1794.98,1405.7 1794.99,1405.69 1794.99,1405.69 1795,1405.69 1795,1405.69 1795.01,1405.69 1795.02,1405.69 1795.02,1405.69 1795.03,1405.69 1795.04,1405.69 1795.04,1405.69 1795.05,1405.69 1795.06,1405.69 1795.06,1405.69 1795.07,1405.69 1795.08,1405.69 1795.08,1405.69 1795.09,1405.69 1795.1,1405.69 1795.1,1405.69 1795.11,1405.69 1795.12,1405.69 1795.12,1405.69 1795.13,1405.69 1795.14,1405.69 1795.14,1405.69 1795.15,1405.69 1795.16,1405.69 1795.16,1405.69 1795.17,1405.69 1795.18,1405.69 1795.18,1405.69 1795.19,1405.69 1795.2,1405.69 1795.2,1405.69 1795.21,1405.69 1795.21,1405.69 1795.22,1405.69 1795.23,1405.69 1795.23,1405.69 1795.24,1405.69 1795.25,1405.69 1795.25,1405.69 1795.26,1405.69 1795.27,1405.69 1795.27,1405.69 1795.28,1405.69 1795.29,1405.69 1795.29,1405.69 1795.3,1405.69 1795.31,1405.69 1795.31,1405.69 1795.32,1405.69 1795.33,1405.69 1795.33,1405.69 1795.34,1405.69 1795.35,1405.69 1795.35,1405.69 1795.36,1405.69 1795.37,1405.69 1795.37,1405.69 1795.38,1405.69 1795.38,1405.69 1795.39,1405.69 1795.4,1405.69 1795.4,1405.69 1795.41,1405.69 1795.42,1405.69 1795.42,1405.69 1795.43,1405.69 1795.44,1405.69 1795.44,1405.69 1795.45,1405.69 1795.46,1405.68 1795.46,1405.68 1795.47,1405.68 1795.48,1405.68 1795.48,1405.68 1795.49,1405.68 1795.5,1405.68 1795.5,1405.68 1795.51,1405.68 1795.52,1405.68 1795.52,1405.68 1795.53,1405.68 1795.54,1405.68 1795.54,1405.68 1795.55,1405.68 1795.55,1405.68 1795.56,1405.68 1795.57,1405.68 1795.57,1405.68 1795.58,1405.68 1795.59,1405.68 1795.59,1405.68 1795.6,1405.68 1795.61,1405.68 1795.61,1405.68 1795.62,1405.68 1795.63,1405.68 1795.63,1405.68 1795.64,1405.68 1795.65,1405.68 1795.65,1405.68 1795.66,1405.68 1795.67,1405.68 1795.67,1405.68 1795.68,1405.68 1795.68,1405.68 1795.69,1405.68 1795.7,1405.68 1795.7,1405.68 1795.71,1405.68 1795.72,1405.68 1795.72,1405.68 1795.73,1405.68 1795.74,1405.68 1795.74,1405.68 1795.75,1405.68 1795.76,1405.68 1795.76,1405.68 1795.77,1405.68 1795.78,1405.68 1795.78,1405.68 1795.79,1405.68 1795.8,1405.68 1795.8,1405.68 1795.81,1405.68 1795.81,1405.68 1795.82,1405.68 1795.83,1405.68 1795.83,1405.68 1795.84,1405.68 1795.85,1405.68 1795.85,1405.68 1795.86,1405.68 1795.87,1405.68 1795.87,1405.68 1795.88,1405.68 1795.89,1405.68 1795.89,1405.68 1795.9,1405.68 1795.91,1405.68 1795.91,1405.68 1795.92,1405.68 1795.93,1405.68 1795.93,1405.67 1795.94,1405.67 1795.94,1405.67 1795.95,1405.67 1795.96,1405.67 1795.96,1405.67 1795.97,1405.67 1795.98,1405.67 1795.98,1405.67 1795.99,1405.67 1796,1405.67 1796,1405.67 1796.01,1405.67 1796.02,1405.67 1796.02,1405.67 1796.03,1405.67 1796.04,1405.67 1796.04,1405.67 1796.05,1405.67 1796.05,1405.67 1796.06,1405.67 1796.07,1405.67 1796.07,1405.67 1796.08,1405.67 1796.09,1405.67 1796.09,1405.67 1796.1,1405.67 1796.11,1405.67 1796.11,1405.67 1796.12,1405.67 1796.13,1405.67 1796.13,1405.67 1796.14,1405.67 1796.15,1405.67 1796.15,1405.67 1796.16,1405.67 1796.16,1405.67 1796.17,1405.67 1796.18,1405.67 1796.18,1405.67 1796.19,1405.67 1796.2,1405.67 1796.2,1405.67 1796.21,1405.67 1796.22,1405.67 1796.22,1405.67 1796.23,1405.67 1796.24,1405.67 1796.24,1405.67 1796.25,1405.67 1796.26,1405.67 1796.26,1405.67 1796.27,1405.67 1796.27,1405.67 1796.28,1405.67 1796.29,1405.67 1796.29,1405.67 1796.3,1405.67 1796.31,1405.67 1796.31,1405.67 1796.32,1405.67 1796.33,1405.67 1796.33,1405.67 1796.34,1405.67 1796.35,1405.67 1796.35,1405.67 1796.36,1405.67 1796.36,1405.67 1796.37,1405.67 1796.38,1405.67 1796.38,1405.67 1796.39,1405.67 1796.4,1405.66 1796.4,1405.66 1796.41,1405.66 1796.42,1405.66 1796.42,1405.66 1796.43,1405.66 1796.44,1405.66 1796.44,1405.66 1796.45,1405.66 1796.45,1405.66 1796.46,1405.66 1796.47,1405.66 1796.47,1405.66 1796.48,1405.66 1796.49,1405.66 1796.49,1405.66 1796.5,1405.66 1796.51,1405.66 1796.51,1405.66 1796.52,1405.66 1796.53,1405.66 1796.53,1405.66 1796.54,1405.66 1796.54,1405.66 1796.55,1405.66 1796.56,1405.66 1796.56,1405.66 1796.57,1405.66 1796.58,1405.66 1796.58,1405.66 1796.59,1405.66 1796.6,1405.66 1796.6,1405.66 1796.61,1405.66 1796.62,1405.66 1796.62,1405.66 1796.63,1405.66 1796.63,1405.66 1796.64,1405.66 1796.65,1405.66 1796.65,1405.66 1796.66,1405.66 1796.67,1405.66 1796.67,1405.66 1796.68,1405.66 1796.69,1405.66 1796.69,1405.66 1796.7,1405.66 1796.71,1405.66 1796.71,1405.66 1796.72,1405.66 1796.72,1405.66 1796.73,1405.66 1796.74,1405.66 1796.74,1405.66 1796.75,1405.66 1796.76,1405.66 1796.76,1405.66 1796.77,1405.66 1796.78,1405.66 1796.78,1405.66 1796.79,1405.66 1796.8,1405.66 1796.8,1405.66 1796.81,1405.66 1796.81,1405.66 1796.82,1405.66 1796.83,1405.66 1796.83,1405.66 1796.84,1405.66 1796.85,1405.66 1796.85,1405.66 1796.86,1405.66 1796.87,1405.65 1796.87,1405.65 1796.88,1405.65 1796.88,1405.65 1796.89,1405.65 1796.9,1405.65 1796.9,1405.65 1796.91,1405.65 1796.92,1405.65 1796.92,1405.65 1796.93,1405.65 1796.94,1405.65 1796.94,1405.65 1796.95,1405.65 1796.96,1405.65 1796.96,1405.65 1796.97,1405.65 1796.97,1405.65 1796.98,1405.65 1796.99,1405.65 1796.99,1405.65 1797,1405.65 1797.01,1405.65 1797.01,1405.65 1797.02,1405.65 1797.03,1405.65 1797.03,1405.65 1797.04,1405.65 1797.04,1405.65 1797.05,1405.65 1797.06,1405.65 1797.06,1405.65 1797.07,1405.65 1797.08,1405.65 1797.08,1405.65 1797.09,1405.65 1797.1,1405.65 1797.1,1405.65 1797.11,1405.65 1797.11,1405.65 1797.12,1405.65 1797.13,1405.65 1797.13,1405.65 1797.14,1405.65 1797.15,1405.65 1797.15,1405.65 1797.16,1405.65 1797.17,1405.65 1797.17,1405.65 1797.18,1405.65 1797.18,1405.65 1797.19,1405.65 1797.2,1405.65 1797.2,1405.65 1797.21,1405.65 1797.22,1405.65 1797.22,1405.65 1797.23,1405.65 1797.24,1405.65 1797.24,1405.65 1797.25,1405.65 1797.25,1405.65 1797.26,1405.65 1797.27,1405.65 1797.27,1405.65 1797.28,1405.65 1797.29,1405.65 1797.29,1405.65 1797.3,1405.65 1797.31,1405.65 1797.31,1405.65 1797.32,1405.65 1797.32,1405.65 1797.33,1405.65 1797.34,1405.64 1797.34,1405.64 1797.35,1405.64 1797.36,1405.64 1797.36,1405.64 1797.37,1405.64 1797.38,1405.64 1797.38,1405.64 1797.39,1405.64 1797.39,1405.64 1797.4,1405.64 1797.41,1405.64 1797.41,1405.64 1797.42,1405.64 1797.43,1405.64 1797.43,1405.64 1797.44,1405.64 1797.45,1405.64 1797.45,1405.64 1797.46,1405.64 1797.46,1405.64 1797.47,1405.64 1797.48,1405.64 1797.48,1405.64 1797.49,1405.64 1797.5,1405.64 1797.5,1405.64 1797.51,1405.64 1797.52,1405.64 1797.52,1405.64 1797.53,1405.64 1797.53,1405.64 1797.54,1405.64 1797.55,1405.64 1797.55,1405.64 1797.56,1405.64 1797.57,1405.64 1797.57,1405.64 1797.58,1405.64 1797.59,1405.64 1797.59,1405.64 1797.6,1405.64 1797.6,1405.64 1797.61,1405.64 1797.62,1405.64 1797.62,1405.64 1797.63,1405.64 1797.64,1405.64 1797.64,1405.64 1797.65,1405.64 1797.65,1405.64 1797.66,1405.64 1797.67,1405.64 1797.67,1405.64 1797.68,1405.64 1797.69,1405.64 1797.69,1405.64 1797.7,1405.64 1797.71,1405.64 1797.71,1405.64 1797.72,1405.64 1797.72,1405.64 1797.73,1405.64 1797.74,1405.64 1797.74,1405.64 1797.75,1405.64 1797.76,1405.64 1797.76,1405.64 1797.77,1405.64 1797.77,1405.64 1797.78,1405.64 1797.79,1405.64 1797.79,1405.64 1797.8,1405.63 1797.81,1405.63 1797.81,1405.63 1797.82,1405.63 1797.83,1405.63 1797.83,1405.63 1797.84,1405.63 1797.84,1405.63 1797.85,1405.63 1797.86,1405.63 1797.86,1405.63 1797.87,1405.63 1797.88,1405.63 1797.88,1405.63 1797.89,1405.63 1797.89,1405.63 1797.9,1405.63 1797.91,1405.63 1797.91,1405.63 1797.92,1405.63 1797.93,1405.63 1797.93,1405.63 1797.94,1405.63 1797.95,1405.63 1797.95,1405.63 1797.96,1405.63 1797.96,1405.63 1797.97,1405.63 1797.98,1405.63 1797.98,1405.63 1797.99,1405.63 1798,1405.63 1798,1405.63 1798.01,1405.63 1798.01,1405.63 1798.02,1405.63 1798.03,1405.63 1798.03,1405.63 1798.04,1405.63 1798.05,1405.63 1798.05,1405.63 1798.06,1405.63 1798.07,1405.63 1798.07,1405.63 1798.08,1405.63 1798.08,1405.63 1798.09,1405.63 1798.1,1405.63 1798.1,1405.63 1798.11,1405.63 1798.12,1405.63 1798.12,1405.63 1798.13,1405.63 1798.13,1405.63 1798.14,1405.63 1798.15,1405.63 1798.15,1405.63 1798.16,1405.63 1798.17,1405.63 1798.17,1405.63 1798.18,1405.63 1798.18,1405.63 1798.19,1405.63 1798.2,1405.63 1798.2,1405.63 1798.21,1405.63 1798.22,1405.63 1798.22,1405.63 1798.23,1405.63 1798.23,1405.63 1798.24,1405.63 1798.25,1405.63 1798.25,1405.63 1798.26,1405.63 1798.27,1405.62 1798.27,1405.62 1798.28,1405.62 1798.28,1405.62 1798.29,1405.62 1798.3,1405.62 1798.3,1405.62 1798.31,1405.62 1798.32,1405.62 1798.32,1405.62 1798.33,1405.62 1798.34,1405.62 1798.34,1405.62 1798.35,1405.62 1798.35,1405.62 1798.36,1405.62 1798.37,1405.62 1798.37,1405.62 1798.38,1405.62 1798.39,1405.62 1798.39,1405.62 1798.4,1405.62 1798.4,1405.62 1798.41,1405.62 1798.42,1405.62 1798.42,1405.62 1798.43,1405.62 1798.44,1405.62 1798.44,1405.62 1798.45,1405.62 1798.45,1405.62 1798.46,1405.62 1798.47,1405.62 1798.47,1405.62 1798.48,1405.62 1798.49,1405.62 1798.49,1405.62 1798.5,1405.62 1798.5,1405.62 1798.51,1405.62 1798.52,1405.62 1798.52,1405.62 1798.53,1405.62 1798.54,1405.62 1798.54,1405.62 1798.55,1405.62 1798.55,1405.62 1798.56,1405.62 1798.57,1405.62 1798.57,1405.62 1798.58,1405.62 1798.59,1405.62 1798.59,1405.62 1798.6,1405.62 1798.6,1405.62 1798.61,1405.62 1798.62,1405.62 1798.62,1405.62 1798.63,1405.62 1798.64,1405.62 1798.64,1405.62 1798.65,1405.62 1798.65,1405.62 1798.66,1405.62 1798.67,1405.62 1798.67,1405.62 1798.68,1405.62 1798.69,1405.62 1798.69,1405.62 1798.7,1405.62 1798.7,1405.62 1798.71,1405.62 1798.72,1405.62 1798.72,1405.62 1798.73,1405.61 1798.74,1405.61 1798.74,1405.61 1798.75,1405.61 1798.75,1405.61 1798.76,1405.61 1798.77,1405.61 1798.77,1405.61 1798.78,1405.61 1798.78,1405.61 1798.79,1405.61 1798.8,1405.61 1798.8,1405.61 1798.81,1405.61 1798.82,1405.61 1798.82,1405.61 1798.83,1405.61 1798.83,1405.61 1798.84,1405.61 1798.85,1405.61 1798.85,1405.61 1798.86,1405.61 1798.87,1405.61 1798.87,1405.61 1798.88,1405.61 1798.88,1405.61 1798.89,1405.61 1798.9,1405.61 1798.9,1405.61 1798.91,1405.61 1798.92,1405.61 1798.92,1405.61 1798.93,1405.61 1798.93,1405.61 1798.94,1405.61 1798.95,1405.61 1798.95,1405.61 1798.96,1405.61 1798.97,1405.61 1798.97,1405.61 1798.98,1405.61 1798.98,1405.61 1798.99,1405.61 1799,1405.61 1799,1405.61 1799.01,1405.61 1799.02,1405.61 1799.02,1405.61 1799.03,1405.61 1799.03,1405.61 1799.04,1405.61 1799.05,1405.61 1799.05,1405.61 1799.06,1405.61 1799.06,1405.61 1799.07,1405.61 1799.08,1405.61 1799.08,1405.61 1799.09,1405.61 1799.1,1405.61 1799.1,1405.61 1799.11,1405.61 1799.11,1405.61 1799.12,1405.61 1799.13,1405.61 1799.13,1405.61 1799.14,1405.61 1799.15,1405.61 1799.15,1405.61 1799.16,1405.61 1799.16,1405.61 1799.17,1405.61 1799.18,1405.61 1799.18,1405.61 1799.19,1405.6 1799.19,1405.6 1799.2,1405.6 1799.21,1405.6 1799.21,1405.6 1799.22,1405.6 1799.23,1405.6 1799.23,1405.6 1799.24,1405.6 1799.24,1405.6 1799.25,1405.6 1799.26,1405.6 1799.26,1405.6 1799.27,1405.6 1799.28,1405.6 1799.28,1405.6 1799.29,1405.6 1799.29,1405.6 1799.3,1405.6 1799.31,1405.6 1799.31,1405.6 1799.32,1405.6 1799.32,1405.6 1799.33,1405.6 1799.34,1405.6 1799.34,1405.6 1799.35,1405.6 1799.36,1405.6 1799.36,1405.6 1799.37,1405.6 1799.37,1405.6 1799.38,1405.6 1799.39,1405.6 1799.39,1405.6 1799.4,1405.6 1799.41,1405.6 1799.41,1405.6 1799.42,1405.6 1799.42,1405.6 1799.43,1405.6 1799.44,1405.6 1799.44,1405.6 1799.45,1405.6 1799.45,1405.6 1799.46,1405.6 1799.47,1405.6 1799.47,1405.6 1799.48,1405.6 1799.49,1405.6 1799.49,1405.6 1799.5,1405.6 1799.5,1405.6 1799.51,1405.6 1799.52,1405.6 1799.52,1405.6 1799.53,1405.6 1799.53,1405.6 1799.54,1405.6 1799.55,1405.6 1799.55,1405.6 1799.56,1405.6 1799.57,1405.6 1799.57,1405.6 1799.58,1405.6 1799.58,1405.6 1799.59,1405.6 1799.6,1405.6 1799.6,1405.6 1799.61,1405.6 1799.61,1405.6 1799.62,1405.6 1799.63,1405.6 1799.63,1405.6 1799.64,1405.6 1799.65,1405.6 1799.65,1405.59 1799.66,1405.59 1799.66,1405.59 1799.67,1405.59 1799.68,1405.59 1799.68,1405.59 1799.69,1405.59 1799.69,1405.59 1799.7,1405.59 1799.71,1405.59 1799.71,1405.59 1799.72,1405.59 1799.73,1405.59 1799.73,1405.59 1799.74,1405.59 1799.74,1405.59 1799.75,1405.59 1799.76,1405.59 1799.76,1405.59 1799.77,1405.59 1799.77,1405.59 1799.78,1405.59 1799.79,1405.59 1799.79,1405.59 1799.8,1405.59 1799.81,1405.59 1799.81,1405.59 1799.82,1405.59 1799.82,1405.59 1799.83,1405.59 1799.84,1405.59 1799.84,1405.59 1799.85,1405.59 1799.85,1405.59 1799.86,1405.59 1799.87,1405.59 1799.87,1405.59 1799.88,1405.59 1799.89,1405.59 1799.89,1405.59 1799.9,1405.59 1799.9,1405.59 1799.91,1405.59 1799.92,1405.59 1799.92,1405.59 1799.93,1405.59 1799.93,1405.59 1799.94,1405.59 1799.95,1405.59 1799.95,1405.59 1799.96,1405.59 1799.96,1405.59 1799.97,1405.59 1799.98,1405.59 1799.98,1405.59 1799.99,1405.59 1800,1405.59 1800,1405.59 1800.01,1405.59 1800.01,1405.59 1800.02,1405.59 1800.03,1405.59 1800.03,1405.59 1800.04,1405.59 1800.04,1405.59 1800.05,1405.59 1800.06,1405.59 1800.06,1405.59 1800.07,1405.59 1800.07,1405.59 1800.08,1405.59 1800.09,1405.59 1800.09,1405.59 1800.1,1405.59 1800.11,1405.58 1800.11,1405.58 1800.12,1405.58 1800.12,1405.58 1800.13,1405.58 1800.14,1405.58 1800.14,1405.58 1800.15,1405.58 1800.15,1405.58 1800.16,1405.58 1800.17,1405.58 1800.17,1405.58 1800.18,1405.58 1800.18,1405.58 1800.19,1405.58 1800.2,1405.58 1800.2,1405.58 1800.21,1405.58 1800.22,1405.58 1800.22,1405.58 1800.23,1405.58 1800.23,1405.58 1800.24,1405.58 1800.25,1405.58 1800.25,1405.58 1800.26,1405.58 1800.26,1405.58 1800.27,1405.58 1800.28,1405.58 1800.28,1405.58 1800.29,1405.58 1800.29,1405.58 1800.3,1405.58 1800.31,1405.58 1800.31,1405.58 1800.32,1405.58 1800.33,1405.58 1800.33,1405.58 1800.34,1405.58 1800.34,1405.58 1800.35,1405.58 1800.36,1405.58 1800.36,1405.58 1800.37,1405.58 1800.37,1405.58 1800.38,1405.58 1800.39,1405.58 1800.39,1405.58 1800.4,1405.58 1800.4,1405.58 1800.41,1405.58 1800.42,1405.58 1800.42,1405.58 1800.43,1405.58 1800.43,1405.58 1800.44,1405.58 1800.45,1405.58 1800.45,1405.58 1800.46,1405.58 1800.47,1405.58 1800.47,1405.58 1800.48,1405.58 1800.48,1405.58 1800.49,1405.58 1800.5,1405.58 1800.5,1405.58 1800.51,1405.58 1800.51,1405.58 1800.52,1405.58 1800.53,1405.58 1800.53,1405.58 1800.54,1405.58 1800.54,1405.58 1800.55,1405.58 1800.56,1405.58 1800.56,1405.58 1800.57,1405.57 1800.57,1405.57 1800.58,1405.57 1800.59,1405.57 1800.59,1405.57 1800.6,1405.57 1800.6,1405.57 1800.61,1405.57 1800.62,1405.57 1800.62,1405.57 1800.63,1405.57 1800.64,1405.57 1800.64,1405.57 1800.65,1405.57 1800.65,1405.57 1800.66,1405.57 1800.67,1405.57 1800.67,1405.57 1800.68,1405.57 1800.68,1405.57 1800.69,1405.57 1800.7,1405.57 1800.7,1405.57 1800.71,1405.57 1800.71,1405.57 1800.72,1405.57 1800.73,1405.57 1800.73,1405.57 1800.74,1405.57 1800.74,1405.57 1800.75,1405.57 1800.76,1405.57 1800.76,1405.57 1800.77,1405.57 1800.77,1405.57 1800.78,1405.57 1800.79,1405.57 1800.79,1405.57 1800.8,1405.57 1800.8,1405.57 1800.81,1405.57 1800.82,1405.57 1800.82,1405.57 1800.83,1405.57 1800.84,1405.57 1800.84,1405.57 1800.85,1405.57 1800.85,1405.57 1800.86,1405.57 1800.87,1405.57 1800.87,1405.57 1800.88,1405.57 1800.88,1405.57 1800.89,1405.57 1800.9,1405.57 1800.9,1405.57 1800.91,1405.57 1800.91,1405.57 1800.92,1405.57 1800.93,1405.57 1800.93,1405.57 1800.94,1405.57 1800.94,1405.57 1800.95,1405.57 1800.96,1405.57 1800.96,1405.57 1800.97,1405.57 1800.97,1405.57 1800.98,1405.57 1800.99,1405.57 1800.99,1405.57 1801,1405.57 1801,1405.57 1801.01,1405.57 1801.02,1405.57 1801.02,1405.56 1801.03,1405.56 1801.03,1405.56 1801.04,1405.56 1801.05,1405.56 1801.05,1405.56 1801.06,1405.56 1801.06,1405.56 1801.07,1405.56 1801.08,1405.56 1801.08,1405.56 1801.09,1405.56 1801.09,1405.56 1801.1,1405.56 1801.11,1405.56 1801.11,1405.56 1801.12,1405.56 1801.12,1405.56 1801.13,1405.56 1801.14,1405.56 1801.14,1405.56 1801.15,1405.56 1801.15,1405.56 1801.16,1405.56 1801.17,1405.56 1801.17,1405.56 1801.18,1405.56 1801.19,1405.56 1801.19,1405.56 1801.2,1405.56 1801.2,1405.56 1801.21,1405.56 1801.22,1405.56 1801.22,1405.56 1801.23,1405.56 1801.23,1405.56 1801.24,1405.56 1801.25,1405.56 1801.25,1405.56 1801.26,1405.56 1801.26,1405.56 1801.27,1405.56 1801.28,1405.56 1801.28,1405.56 1801.29,1405.56 1801.29,1405.56 1801.3,1405.56 1801.31,1405.56 1801.31,1405.56 1801.32,1405.56 1801.32,1405.56 1801.33,1405.56 1801.34,1405.56 1801.34,1405.56 1801.35,1405.56 1801.35,1405.56 1801.36,1405.56 1801.37,1405.56 1801.37,1405.56 1801.38,1405.56 1801.38,1405.56 1801.39,1405.56 1801.4,1405.56 1801.4,1405.56 1801.41,1405.56 1801.41,1405.56 1801.42,1405.56 1801.43,1405.56 1801.43,1405.56 1801.44,1405.56 1801.44,1405.56 1801.45,1405.56 1801.46,1405.56 1801.46,1405.56 1801.47,1405.56 1801.47,1405.56 1801.48,1405.55 1801.49,1405.55 1801.49,1405.55 1801.5,1405.55 1801.5,1405.55 1801.51,1405.55 1801.52,1405.55 1801.52,1405.55 1801.53,1405.55 1801.53,1405.55 1801.54,1405.55 1801.55,1405.55 1801.55,1405.55 1801.56,1405.55 1801.56,1405.55 1801.57,1405.55 1801.58,1405.55 1801.58,1405.55 1801.59,1405.55 1801.59,1405.55 1801.6,1405.55 1801.61,1405.55 1801.61,1405.55 1801.62,1405.55 1801.62,1405.55 1801.63,1405.55 1801.64,1405.55 1801.64,1405.55 1801.65,1405.55 1801.65,1405.55 1801.66,1405.55 1801.66,1405.55 1801.67,1405.55 1801.68,1405.55 1801.68,1405.55 1801.69,1405.55 1801.69,1405.55 1801.7,1405.55 1801.71,1405.55 1801.71,1405.55 1801.72,1405.55 1801.72,1405.55 1801.73,1405.55 1801.74,1405.55 1801.74,1405.55 1801.75,1405.55 1801.75,1405.55 1801.76,1405.55 1801.77,1405.55 1801.77,1405.55 1801.78,1405.55 1801.78,1405.55 1801.79,1405.55 1801.8,1405.55 1801.8,1405.55 1801.81,1405.55 1801.81,1405.55 1801.82,1405.55 1801.83,1405.55 1801.83,1405.55 1801.84,1405.55 1801.84,1405.55 1801.85,1405.55 1801.86,1405.55 1801.86,1405.55 1801.87,1405.55 1801.87,1405.55 1801.88,1405.55 1801.89,1405.55 1801.89,1405.55 1801.9,1405.55 1801.9,1405.55 1801.91,1405.55 1801.92,1405.55 1801.92,1405.55 1801.93,1405.55 1801.93,1405.54 1801.94,1405.54 1801.95,1405.54 1801.95,1405.54 1801.96,1405.54 1801.96,1405.54 1801.97,1405.54 1801.98,1405.54 1801.98,1405.54 1801.99,1405.54 1801.99,1405.54 1802,1405.54 1802,1405.54 1802.01,1405.54 1802.02,1405.54 1802.02,1405.54 1802.03,1405.54 1802.03,1405.54 1802.04,1405.54 1802.05,1405.54 1802.05,1405.54 1802.06,1405.54 1802.06,1405.54 1802.07,1405.54 1802.08,1405.54 1802.08,1405.54 1802.09,1405.54 1802.09,1405.54 1802.1,1405.54 1802.11,1405.54 1802.11,1405.54 1802.12,1405.54 1802.12,1405.54 1802.13,1405.54 1802.14,1405.54 1802.14,1405.54 1802.15,1405.54 1802.15,1405.54 1802.16,1405.54 1802.17,1405.54 1802.17,1405.54 1802.18,1405.54 1802.18,1405.54 1802.19,1405.54 1802.19,1405.54 1802.2,1405.54 1802.21,1405.54 1802.21,1405.54 1802.22,1405.54 1802.22,1405.54 1802.23,1405.54 1802.24,1405.54 1802.24,1405.54 1802.25,1405.54 1802.25,1405.54 1802.26,1405.54 1802.27,1405.54 1802.27,1405.54 1802.28,1405.54 1802.28,1405.54 1802.29,1405.54 1802.3,1405.54 1802.3,1405.54 1802.31,1405.54 1802.31,1405.54 1802.32,1405.54 1802.33,1405.54 1802.33,1405.54 1802.34,1405.54 1802.34,1405.54 1802.35,1405.54 1802.35,1405.54 1802.36,1405.54 1802.37,1405.54 1802.37,1405.54 1802.38,1405.54 1802.38,1405.53 1802.39,1405.53 1802.4,1405.53 1802.4,1405.53 1802.41,1405.53 1802.41,1405.53 1802.42,1405.53 1802.43,1405.53 1802.43,1405.53 1802.44,1405.53 1802.44,1405.53 1802.45,1405.53 1802.46,1405.53 1802.46,1405.53 1802.47,1405.53 1802.47,1405.53 1802.48,1405.53 1802.48,1405.53 1802.49,1405.53 1802.5,1405.53 1802.5,1405.53 1802.51,1405.53 1802.51,1405.53 1802.52,1405.53 1802.53,1405.53 1802.53,1405.53 1802.54,1405.53 1802.54,1405.53 1802.55,1405.53 1802.56,1405.53 1802.56,1405.53 1802.57,1405.53 1802.57,1405.53 1802.58,1405.53 1802.59,1405.53 1802.59,1405.53 1802.6,1405.53 1802.6,1405.53 1802.61,1405.53 1802.61,1405.53 1802.62,1405.53 1802.63,1405.53 1802.63,1405.53 1802.64,1405.53 1802.64,1405.53 1802.65,1405.53 1802.66,1405.53 1802.66,1405.53 1802.67,1405.53 1802.67,1405.53 1802.68,1405.53 1802.69,1405.53 1802.69,1405.53 1802.7,1405.53 1802.7,1405.53 1802.71,1405.53 1802.71,1405.53 1802.72,1405.53 1802.73,1405.53 1802.73,1405.53 1802.74,1405.53 1802.74,1405.53 1802.75,1405.53 1802.76,1405.53 1802.76,1405.53 1802.77,1405.53 1802.77,1405.53 1802.78,1405.53 1802.79,1405.53 1802.79,1405.53 1802.8,1405.53 1802.8,1405.53 1802.81,1405.53 1802.82,1405.53 1802.82,1405.53 1802.83,1405.53 1802.83,1405.53 1802.84,1405.52 1802.84,1405.52 1802.85,1405.52 1802.86,1405.52 1802.86,1405.52 1802.87,1405.52 1802.87,1405.52 1802.88,1405.52 1802.89,1405.52 1802.89,1405.52 1802.9,1405.52 1802.9,1405.52 1802.91,1405.52 1802.91,1405.52 1802.92,1405.52 1802.93,1405.52 1802.93,1405.52 1802.94,1405.52 1802.94,1405.52 1802.95,1405.52 1802.96,1405.52 1802.96,1405.52 1802.97,1405.52 1802.97,1405.52 1802.98,1405.52 1802.99,1405.52 1802.99,1405.52 1803,1405.52 1803,1405.52 1803.01,1405.52 1803.01,1405.52 1803.02,1405.52 1803.03,1405.52 1803.03,1405.52 1803.04,1405.52 1803.04,1405.52 1803.05,1405.52 1803.06,1405.52 1803.06,1405.52 1803.07,1405.52 1803.07,1405.52 1803.08,1405.52 1803.08,1405.52 1803.09,1405.52 1803.1,1405.52 1803.1,1405.52 1803.11,1405.52 1803.11,1405.52 1803.12,1405.52 1803.13,1405.52 1803.13,1405.52 1803.14,1405.52 1803.14,1405.52 1803.15,1405.52 1803.16,1405.52 1803.16,1405.52 1803.17,1405.52 1803.17,1405.52 1803.18,1405.52 1803.18,1405.52 1803.19,1405.52 1803.2,1405.52 1803.2,1405.52 1803.21,1405.52 1803.21,1405.52 1803.22,1405.52 1803.23,1405.52 1803.23,1405.52 1803.24,1405.52 1803.24,1405.52 1803.25,1405.52 1803.25,1405.52 1803.26,1405.52 1803.27,1405.52 1803.27,1405.52 1803.28,1405.52 1803.28,1405.52 1803.29,1405.51 1803.3,1405.51 1803.3,1405.51 1803.31,1405.51 1803.31,1405.51 1803.32,1405.51 1803.32,1405.51 1803.33,1405.51 1803.34,1405.51 1803.34,1405.51 1803.35,1405.51 1803.35,1405.51 1803.36,1405.51 1803.37,1405.51 1803.37,1405.51 1803.38,1405.51 1803.38,1405.51 1803.39,1405.51 1803.39,1405.51 1803.4,1405.51 1803.41,1405.51 1803.41,1405.51 1803.42,1405.51 1803.42,1405.51 1803.43,1405.51 1803.44,1405.51 1803.44,1405.51 1803.45,1405.51 1803.45,1405.51 1803.46,1405.51 1803.46,1405.51 1803.47,1405.51 1803.48,1405.51 1803.48,1405.51 1803.49,1405.51 1803.49,1405.51 1803.5,1405.51 1803.51,1405.51 1803.51,1405.51 1803.52,1405.51 1803.52,1405.51 1803.53,1405.51 1803.53,1405.51 1803.54,1405.51 1803.55,1405.51 1803.55,1405.51 1803.56,1405.51 1803.56,1405.51 1803.57,1405.51 1803.58,1405.51 1803.58,1405.51 1803.59,1405.51 1803.59,1405.51 1803.6,1405.51 1803.6,1405.51 1803.61,1405.51 1803.62,1405.51 1803.62,1405.51 1803.63,1405.51 1803.63,1405.51 1803.64,1405.51 1803.64,1405.51 1803.65,1405.51 1803.66,1405.51 1803.66,1405.51 1803.67,1405.51 1803.67,1405.51 1803.68,1405.51 1803.69,1405.51 1803.69,1405.51 1803.7,1405.51 1803.7,1405.51 1803.71,1405.51 1803.71,1405.51 1803.72,1405.51 1803.73,1405.51 1803.73,1405.51 1803.74,1405.5 1803.74,1405.5 1803.75,1405.5 1803.76,1405.5 1803.76,1405.5 1803.77,1405.5 1803.77,1405.5 1803.78,1405.5 1803.78,1405.5 1803.79,1405.5 1803.8,1405.5 1803.8,1405.5 1803.81,1405.5 1803.81,1405.5 1803.82,1405.5 1803.82,1405.5 1803.83,1405.5 1803.84,1405.5 1803.84,1405.5 1803.85,1405.5 1803.85,1405.5 1803.86,1405.5 1803.87,1405.5 1803.87,1405.5 1803.88,1405.5 1803.88,1405.5 1803.89,1405.5 1803.89,1405.5 1803.9,1405.5 1803.91,1405.5 1803.91,1405.5 1803.92,1405.5 1803.92,1405.5 1803.93,1405.5 1803.93,1405.5 1803.94,1405.5 1803.95,1405.5 1803.95,1405.5 1803.96,1405.5 1803.96,1405.5 1803.97,1405.5 1803.98,1405.5 1803.98,1405.5 1803.99,1405.5 1803.99,1405.5 1804,1405.5 1804,1405.5 1804.01,1405.5 1804.02,1405.5 1804.02,1405.5 1804.03,1405.5 1804.03,1405.5 1804.04,1405.5 1804.04,1405.5 1804.05,1405.5 1804.06,1405.5 1804.06,1405.5 1804.07,1405.5 1804.07,1405.5 1804.08,1405.5 1804.08,1405.5 1804.09,1405.5 1804.1,1405.5 1804.1,1405.5 1804.11,1405.5 1804.11,1405.5 1804.12,1405.5 1804.13,1405.5 1804.13,1405.5 1804.14,1405.5 1804.14,1405.5 1804.15,1405.5 1804.15,1405.5 1804.16,1405.5 1804.17,1405.5 1804.17,1405.5 1804.18,1405.5 1804.18,1405.5 1804.19,1405.49 1804.19,1405.49 1804.2,1405.49 1804.21,1405.49 1804.21,1405.49 1804.22,1405.49 1804.22,1405.49 1804.23,1405.49 1804.23,1405.49 1804.24,1405.49 1804.25,1405.49 1804.25,1405.49 1804.26,1405.49 1804.26,1405.49 1804.27,1405.49 1804.28,1405.49 1804.28,1405.49 1804.29,1405.49 1804.29,1405.49 1804.3,1405.49 1804.3,1405.49 1804.31,1405.49 1804.32,1405.49 1804.32,1405.49 1804.33,1405.49 1804.33,1405.49 1804.34,1405.49 1804.34,1405.49 1804.35,1405.49 1804.36,1405.49 1804.36,1405.49 1804.37,1405.49 1804.37,1405.49 1804.38,1405.49 1804.38,1405.49 1804.39,1405.49 1804.4,1405.49 1804.4,1405.49 1804.41,1405.49 1804.41,1405.49 1804.42,1405.49 1804.42,1405.49 1804.43,1405.49 1804.44,1405.49 1804.44,1405.49 1804.45,1405.49 1804.45,1405.49 1804.46,1405.49 1804.46,1405.49 1804.47,1405.49 1804.48,1405.49 1804.48,1405.49 1804.49,1405.49 1804.49,1405.49 1804.5,1405.49 1804.51,1405.49 1804.51,1405.49 1804.52,1405.49 1804.52,1405.49 1804.53,1405.49 1804.53,1405.49 1804.54,1405.49 1804.55,1405.49 1804.55,1405.49 1804.56,1405.49 1804.56,1405.49 1804.57,1405.49 1804.57,1405.49 1804.58,1405.49 1804.59,1405.49 1804.59,1405.49 1804.6,1405.49 1804.6,1405.49 1804.61,1405.49 1804.61,1405.49 1804.62,1405.49 1804.63,1405.49 1804.63,1405.49 1804.64,1405.48 1804.64,1405.48 1804.65,1405.48 1804.65,1405.48 1804.66,1405.48 1804.67,1405.48 1804.67,1405.48 1804.68,1405.48 1804.68,1405.48 1804.69,1405.48 1804.69,1405.48 1804.7,1405.48 1804.71,1405.48 1804.71,1405.48 1804.72,1405.48 1804.72,1405.48 1804.73,1405.48 1804.73,1405.48 1804.74,1405.48 1804.75,1405.48 1804.75,1405.48 1804.76,1405.48 1804.76,1405.48 1804.77,1405.48 1804.77,1405.48 1804.78,1405.48 1804.79,1405.48 1804.79,1405.48 1804.8,1405.48 1804.8,1405.48 1804.81,1405.48 1804.81,1405.48 1804.82,1405.48 1804.83,1405.48 1804.83,1405.48 1804.84,1405.48 1804.84,1405.48 1804.85,1405.48 1804.85,1405.48 1804.86,1405.48 1804.87,1405.48 1804.87,1405.48 1804.88,1405.48 1804.88,1405.48 1804.89,1405.48 1804.89,1405.48 1804.9,1405.48 1804.91,1405.48 1804.91,1405.48 1804.92,1405.48 1804.92,1405.48 1804.93,1405.48 1804.93,1405.48 1804.94,1405.48 1804.95,1405.48 1804.95,1405.48 1804.96,1405.48 1804.96,1405.48 1804.97,1405.48 1804.97,1405.48 1804.98,1405.48 1804.99,1405.48 1804.99,1405.48 1805,1405.48 1805,1405.48 1805.01,1405.48 1805.01,1405.48 1805.02,1405.48 1805.03,1405.48 1805.03,1405.48 1805.04,1405.48 1805.04,1405.48 1805.05,1405.48 1805.05,1405.48 1805.06,1405.48 1805.06,1405.48 1805.07,1405.48 1805.08,1405.48 1805.08,1405.47 1805.09,1405.47 1805.09,1405.47 1805.1,1405.47 1805.1,1405.47 1805.11,1405.47 1805.12,1405.47 1805.12,1405.47 1805.13,1405.47 1805.13,1405.47 1805.14,1405.47 1805.14,1405.47 1805.15,1405.47 1805.16,1405.47 1805.16,1405.47 1805.17,1405.47 1805.17,1405.47 1805.18,1405.47 1805.18,1405.47 1805.19,1405.47 1805.2,1405.47 1805.2,1405.47 1805.21,1405.47 1805.21,1405.47 1805.22,1405.47 1805.22,1405.47 1805.23,1405.47 1805.24,1405.47 1805.24,1405.47 1805.25,1405.47 1805.25,1405.47 1805.26,1405.47 1805.26,1405.47 1805.27,1405.47 1805.28,1405.47 1805.28,1405.47 1805.29,1405.47 1805.29,1405.47 1805.3,1405.47 1805.3,1405.47 1805.31,1405.47 1805.31,1405.47 1805.32,1405.47 1805.33,1405.47 1805.33,1405.47 1805.34,1405.47 1805.34,1405.47 1805.35,1405.47 1805.35,1405.47 1805.36,1405.47 1805.37,1405.47 1805.37,1405.47 1805.38,1405.47 1805.38,1405.47 1805.39,1405.47 1805.39,1405.47 1805.4,1405.47 1805.41,1405.47 1805.41,1405.47 1805.42,1405.47 1805.42,1405.47 1805.43,1405.47 1805.43,1405.47 1805.44,1405.47 1805.45,1405.47 1805.45,1405.47 1805.46,1405.47 1805.46,1405.47 1805.47,1405.47 1805.47,1405.47 1805.48,1405.47 1805.48,1405.47 1805.49,1405.47 1805.5,1405.47 1805.5,1405.47 1805.51,1405.47 1805.51,1405.47 1805.52,1405.47 1805.52,1405.46 1805.53,1405.46 1805.54,1405.46 1805.54,1405.46 1805.55,1405.46 1805.55,1405.46 1805.56,1405.46 1805.56,1405.46 1805.57,1405.46 1805.58,1405.46 1805.58,1405.46 1805.59,1405.46 1805.59,1405.46 1805.6,1405.46 1805.6,1405.46 1805.61,1405.46 1805.61,1405.46 1805.62,1405.46 1805.63,1405.46 1805.63,1405.46 1805.64,1405.46 1805.64,1405.46 1805.65,1405.46 1805.65,1405.46 1805.66,1405.46 1805.67,1405.46 1805.67,1405.46 1805.68,1405.46 1805.68,1405.46 1805.69,1405.46 1805.69,1405.46 1805.7,1405.46 1805.7,1405.46 1805.71,1405.46 1805.72,1405.46 1805.72,1405.46 1805.73,1405.46 1805.73,1405.46 1805.74,1405.46 1805.74,1405.46 1805.75,1405.46 1805.76,1405.46 1805.76,1405.46 1805.77,1405.46 1805.77,1405.46 1805.78,1405.46 1805.78,1405.46 1805.79,1405.46 1805.8,1405.46 1805.8,1405.46 1805.81,1405.46 1805.81,1405.46 1805.82,1405.46 1805.82,1405.46 1805.83,1405.46 1805.83,1405.46 1805.84,1405.46 1805.85,1405.46 1805.85,1405.46 1805.86,1405.46 1805.86,1405.46 1805.87,1405.46 1805.87,1405.46 1805.88,1405.46 1805.89,1405.46 1805.89,1405.46 1805.9,1405.46 1805.9,1405.46 1805.91,1405.46 1805.91,1405.46 1805.92,1405.46 1805.92,1405.46 1805.93,1405.46 1805.94,1405.46 1805.94,1405.46 1805.95,1405.46 1805.95,1405.46 1805.96,1405.46 1805.96,1405.46 1805.97,1405.45 1805.98,1405.45 1805.98,1405.45 1805.99,1405.45 1805.99,1405.45 1806,1405.45 1806,1405.45 1806.01,1405.45 1806.01,1405.45 1806.02,1405.45 1806.03,1405.45 1806.03,1405.45 1806.04,1405.45 1806.04,1405.45 1806.05,1405.45 1806.05,1405.45 1806.06,1405.45 1806.06,1405.45 1806.07,1405.45 1806.08,1405.45 1806.08,1405.45 1806.09,1405.45 1806.09,1405.45 1806.1,1405.45 1806.1,1405.45 1806.11,1405.45 1806.12,1405.45 1806.12,1405.45 1806.13,1405.45 1806.13,1405.45 1806.14,1405.45 1806.14,1405.45 1806.15,1405.45 1806.15,1405.45 1806.16,1405.45 1806.17,1405.45 1806.17,1405.45 1806.18,1405.45 1806.18,1405.45 1806.19,1405.45 1806.19,1405.45 1806.2,1405.45 1806.2,1405.45 1806.21,1405.45 1806.22,1405.45 1806.22,1405.45 1806.23,1405.45 1806.23,1405.45 1806.24,1405.45 1806.24,1405.45 1806.25,1405.45 1806.26,1405.45 1806.26,1405.45 1806.27,1405.45 1806.27,1405.45 1806.28,1405.45 1806.28,1405.45 1806.29,1405.45 1806.29,1405.45 1806.3,1405.45 1806.31,1405.45 1806.31,1405.45 1806.32,1405.45 1806.32,1405.45 1806.33,1405.45 1806.33,1405.45 1806.34,1405.45 1806.34,1405.45 1806.35,1405.45 1806.36,1405.45 1806.36,1405.45 1806.37,1405.45 1806.37,1405.45 1806.38,1405.45 1806.38,1405.45 1806.39,1405.45 1806.39,1405.45 1806.4,1405.45 1806.41,1405.45 1806.41,1405.44 1806.42,1405.44 1806.42,1405.44 1806.43,1405.44 1806.43,1405.44 1806.44,1405.44 1806.45,1405.44 1806.45,1405.44 1806.46,1405.44 1806.46,1405.44 1806.47,1405.44 1806.47,1405.44 1806.48,1405.44 1806.48,1405.44 1806.49,1405.44 1806.5,1405.44 1806.5,1405.44 1806.51,1405.44 1806.51,1405.44 1806.52,1405.44 1806.52,1405.44 1806.53,1405.44 1806.53,1405.44 1806.54,1405.44 1806.55,1405.44 1806.55,1405.44 1806.56,1405.44 1806.56,1405.44 1806.57,1405.44 1806.57,1405.44 1806.58,1405.44 1806.58,1405.44 1806.59,1405.44 1806.6,1405.44 1806.6,1405.44 1806.61,1405.44 1806.61,1405.44 1806.62,1405.44 1806.62,1405.44 1806.63,1405.44 1806.63,1405.44 1806.64,1405.44 1806.65,1405.44 1806.65,1405.44 1806.66,1405.44 1806.66,1405.44 1806.67,1405.44 1806.67,1405.44 1806.68,1405.44 1806.68,1405.44 1806.69,1405.44 1806.7,1405.44 1806.7,1405.44 1806.71,1405.44 1806.71,1405.44 1806.72,1405.44 1806.72,1405.44 1806.73,1405.44 1806.73,1405.44 1806.74,1405.44 1806.75,1405.44 1806.75,1405.44 1806.76,1405.44 1806.76,1405.44 1806.77,1405.44 1806.77,1405.44 1806.78,1405.44 1806.78,1405.44 1806.79,1405.44 1806.8,1405.44 1806.8,1405.44 1806.81,1405.44 1806.81,1405.44 1806.82,1405.44 1806.82,1405.44 1806.83,1405.44 1806.83,1405.44 1806.84,1405.44 1806.85,1405.44 1806.85,1405.44 1806.86,1405.43 1806.86,1405.43 1806.87,1405.43 1806.87,1405.43 1806.88,1405.43 1806.88,1405.43 1806.89,1405.43 1806.9,1405.43 1806.9,1405.43 1806.91,1405.43 1806.91,1405.43 1806.92,1405.43 1806.92,1405.43 1806.93,1405.43 1806.93,1405.43 1806.94,1405.43 1806.95,1405.43 1806.95,1405.43 1806.96,1405.43 1806.96,1405.43 1806.97,1405.43 1806.97,1405.43 1806.98,1405.43 1806.98,1405.43 1806.99,1405.43 1806.99,1405.43 1807,1405.43 1807.01,1405.43 1807.01,1405.43 1807.02,1405.43 1807.02,1405.43 1807.03,1405.43 1807.03,1405.43 1807.04,1405.43 1807.04,1405.43 1807.05,1405.43 1807.06,1405.43 1807.06,1405.43 1807.07,1405.43 1807.07,1405.43 1807.08,1405.43 1807.08,1405.43 1807.09,1405.43 1807.09,1405.43 1807.1,1405.43 1807.11,1405.43 1807.11,1405.43 1807.12,1405.43 1807.12,1405.43 1807.13,1405.43 1807.13,1405.43 1807.14,1405.43 1807.14,1405.43 1807.15,1405.43 1807.16,1405.43 1807.16,1405.43 1807.17,1405.43 1807.17,1405.43 1807.18,1405.43 1807.18,1405.43 1807.19,1405.43 1807.19,1405.43 1807.2,1405.43 1807.2,1405.43 1807.21,1405.43 1807.22,1405.43 1807.22,1405.43 1807.23,1405.43 1807.23,1405.43 1807.24,1405.43 1807.24,1405.43 1807.25,1405.43 1807.25,1405.43 1807.26,1405.43 1807.27,1405.43 1807.27,1405.43 1807.28,1405.43 1807.28,1405.43 1807.29,1405.43 1807.29,1405.43 1807.3,1405.42 1807.3,1405.42 1807.31,1405.42 1807.32,1405.42 1807.32,1405.42 1807.33,1405.42 1807.33,1405.42 1807.34,1405.42 1807.34,1405.42 1807.35,1405.42 1807.35,1405.42 1807.36,1405.42 1807.36,1405.42 1807.37,1405.42 1807.38,1405.42 1807.38,1405.42 1807.39,1405.42 1807.39,1405.42 1807.4,1405.42 1807.4,1405.42 1807.41,1405.42 1807.41,1405.42 1807.42,1405.42 1807.43,1405.42 1807.43,1405.42 1807.44,1405.42 1807.44,1405.42 1807.45,1405.42 1807.45,1405.42 1807.46,1405.42 1807.46,1405.42 1807.47,1405.42 1807.47,1405.42 1807.48,1405.42 1807.49,1405.42 1807.49,1405.42 1807.5,1405.42 1807.5,1405.42 1807.51,1405.42 1807.51,1405.42 1807.52,1405.42 1807.52,1405.42 1807.53,1405.42 1807.53,1405.42 1807.54,1405.42 1807.55,1405.42 1807.55,1405.42 1807.56,1405.42 1807.56,1405.42 1807.57,1405.42 1807.57,1405.42 1807.58,1405.42 1807.58,1405.42 1807.59,1405.42 1807.6,1405.42 1807.6,1405.42 1807.61,1405.42 1807.61,1405.42 1807.62,1405.42 1807.62,1405.42 1807.63,1405.42 1807.63,1405.42 1807.64,1405.42 1807.64,1405.42 1807.65,1405.42 1807.66,1405.42 1807.66,1405.42 1807.67,1405.42 1807.67,1405.42 1807.68,1405.42 1807.68,1405.42 1807.69,1405.42 1807.69,1405.42 1807.7,1405.42 1807.7,1405.42 1807.71,1405.42 1807.72,1405.42 1807.72,1405.42 1807.73,1405.42 1807.73,1405.42 1807.74,1405.41 1807.74,1405.41 1807.75,1405.41 1807.75,1405.41 1807.76,1405.41 1807.77,1405.41 1807.77,1405.41 1807.78,1405.41 1807.78,1405.41 1807.79,1405.41 1807.79,1405.41 1807.8,1405.41 1807.8,1405.41 1807.81,1405.41 1807.81,1405.41 1807.82,1405.41 1807.83,1405.41 1807.83,1405.41 1807.84,1405.41 1807.84,1405.41 1807.85,1405.41 1807.85,1405.41 1807.86,1405.41 1807.86,1405.41 1807.87,1405.41 1807.87,1405.41 1807.88,1405.41 1807.89,1405.41 1807.89,1405.41 1807.9,1405.41 1807.9,1405.41 1807.91,1405.41 1807.91,1405.41 1807.92,1405.41 1807.92,1405.41 1807.93,1405.41 1807.93,1405.41 1807.94,1405.41 1807.95,1405.41 1807.95,1405.41 1807.96,1405.41 1807.96,1405.41 1807.97,1405.41 1807.97,1405.41 1807.98,1405.41 1807.98,1405.41 1807.99,1405.41 1807.99,1405.41 1808,1405.41 1808.01,1405.41 1808.01,1405.41 1808.02,1405.41 1808.02,1405.41 1808.03,1405.41 1808.03,1405.41 1808.04,1405.41 1808.04,1405.41 1808.05,1405.41 1808.05,1405.41 1808.06,1405.41 1808.07,1405.41 1808.07,1405.41 1808.08,1405.41 1808.08,1405.41 1808.09,1405.41 1808.09,1405.41 1808.1,1405.41 1808.1,1405.41 1808.11,1405.41 1808.11,1405.41 1808.12,1405.41 1808.13,1405.41 1808.13,1405.41 1808.14,1405.41 1808.14,1405.41 1808.15,1405.41 1808.15,1405.41 1808.16,1405.41 1808.16,1405.41 1808.17,1405.41 1808.17,1405.41 1808.18,1405.4 1808.18,1405.4 1808.19,1405.4 1808.2,1405.4 1808.2,1405.4 1808.21,1405.4 1808.21,1405.4 1808.22,1405.4 1808.22,1405.4 1808.23,1405.4 1808.23,1405.4 1808.24,1405.4 1808.24,1405.4 1808.25,1405.4 1808.26,1405.4 1808.26,1405.4 1808.27,1405.4 1808.27,1405.4 1808.28,1405.4 1808.28,1405.4 1808.29,1405.4 1808.29,1405.4 1808.3,1405.4 1808.3,1405.4 1808.31,1405.4 1808.32,1405.4 1808.32,1405.4 1808.33,1405.4 1808.33,1405.4 1808.34,1405.4 1808.34,1405.4 1808.35,1405.4 1808.35,1405.4 1808.36,1405.4 1808.36,1405.4 1808.37,1405.4 1808.37,1405.4 1808.38,1405.4 1808.39,1405.4 1808.39,1405.4 1808.4,1405.4 1808.4,1405.4 1808.41,1405.4 1808.41,1405.4 1808.42,1405.4 1808.42,1405.4 1808.43,1405.4 1808.43,1405.4 1808.44,1405.4 1808.45,1405.4 1808.45,1405.4 1808.46,1405.4 1808.46,1405.4 1808.47,1405.4 1808.47,1405.4 1808.48,1405.4 1808.48,1405.4 1808.49,1405.4 1808.49,1405.4 1808.5,1405.4 1808.5,1405.4 1808.51,1405.4 1808.52,1405.4 1808.52,1405.4 1808.53,1405.4 1808.53,1405.4 1808.54,1405.4 1808.54,1405.4 1808.55,1405.4 1808.55,1405.4 1808.56,1405.4 1808.56,1405.4 1808.57,1405.4 1808.58,1405.4 1808.58,1405.4 1808.59,1405.4 1808.59,1405.4 1808.6,1405.4 1808.6,1405.4 1808.61,1405.4 1808.61,1405.4 1808.62,1405.39 1808.62,1405.39 1808.63,1405.39 1808.63,1405.39 1808.64,1405.39 1808.65,1405.39 1808.65,1405.39 1808.66,1405.39 1808.66,1405.39 1808.67,1405.39 1808.67,1405.39 1808.68,1405.39 1808.68,1405.39 1808.69,1405.39 1808.69,1405.39 1808.7,1405.39 1808.7,1405.39 1808.71,1405.39 1808.72,1405.39 1808.72,1405.39 1808.73,1405.39 1808.73,1405.39 1808.74,1405.39 1808.74,1405.39 1808.75,1405.39 1808.75,1405.39 1808.76,1405.39 1808.76,1405.39 1808.77,1405.39 1808.77,1405.39 1808.78,1405.39 1808.79,1405.39 1808.79,1405.39 1808.8,1405.39 1808.8,1405.39 1808.81,1405.39 1808.81,1405.39 1808.82,1405.39 1808.82,1405.39 1808.83,1405.39 1808.83,1405.39 1808.84,1405.39 1808.84,1405.39 1808.85,1405.39 1808.86,1405.39 1808.86,1405.39 1808.87,1405.39 1808.87,1405.39 1808.88,1405.39 1808.88,1405.39 1808.89,1405.39 1808.89,1405.39 1808.9,1405.39 1808.9,1405.39 1808.91,1405.39 1808.91,1405.39 1808.92,1405.39 1808.93,1405.39 1808.93,1405.39 1808.94,1405.39 1808.94,1405.39 1808.95,1405.39 1808.95,1405.39 1808.96,1405.39 1808.96,1405.39 1808.97,1405.39 1808.97,1405.39 1808.98,1405.39 1808.98,1405.39 1808.99,1405.39 1809,1405.39 1809,1405.39 1809.01,1405.39 1809.01,1405.39 1809.02,1405.39 1809.02,1405.39 1809.03,1405.39 1809.03,1405.39 1809.04,1405.39 1809.04,1405.39 1809.05,1405.39 1809.05,1405.38 1809.06,1405.38 1809.07,1405.38 1809.07,1405.38 1809.08,1405.38 1809.08,1405.38 1809.09,1405.38 1809.09,1405.38 1809.1,1405.38 1809.1,1405.38 1809.11,1405.38 1809.11,1405.38 1809.12,1405.38 1809.12,1405.38 1809.13,1405.38 1809.13,1405.38 1809.14,1405.38 1809.15,1405.38 1809.15,1405.38 1809.16,1405.38 1809.16,1405.38 1809.17,1405.38 1809.17,1405.38 1809.18,1405.38 1809.18,1405.38 1809.19,1405.38 1809.19,1405.38 1809.2,1405.38 1809.2,1405.38 1809.21,1405.38 1809.22,1405.38 1809.22,1405.38 1809.23,1405.38 1809.23,1405.38 1809.24,1405.38 1809.24,1405.38 1809.25,1405.38 1809.25,1405.38 1809.26,1405.38 1809.26,1405.38 1809.27,1405.38 1809.27,1405.38 1809.28,1405.38 1809.28,1405.38 1809.29,1405.38 1809.3,1405.38 1809.3,1405.38 1809.31,1405.38 1809.31,1405.38 1809.32,1405.38 1809.32,1405.38 1809.33,1405.38 1809.33,1405.38 1809.34,1405.38 1809.34,1405.38 1809.35,1405.38 1809.35,1405.38 1809.36,1405.38 1809.37,1405.38 1809.37,1405.38 1809.38,1405.38 1809.38,1405.38 1809.39,1405.38 1809.39,1405.38 1809.4,1405.38 1809.4,1405.38 1809.41,1405.38 1809.41,1405.38 1809.42,1405.38 1809.42,1405.38 1809.43,1405.38 1809.43,1405.38 1809.44,1405.38 1809.45,1405.38 1809.45,1405.38 1809.46,1405.38 1809.46,1405.38 1809.47,1405.38 1809.47,1405.38 1809.48,1405.38 1809.48,1405.38 1809.49,1405.38 1809.49,1405.37 1809.5,1405.37 1809.5,1405.37 1809.51,1405.37 1809.51,1405.37 1809.52,1405.37 1809.53,1405.37 1809.53,1405.37 1809.54,1405.37 1809.54,1405.37 1809.55,1405.37 1809.55,1405.37 1809.56,1405.37 1809.56,1405.37 1809.57,1405.37 1809.57,1405.37 1809.58,1405.37 1809.58,1405.37 1809.59,1405.37 1809.59,1405.37 1809.6,1405.37 1809.61,1405.37 1809.61,1405.37 1809.62,1405.37 1809.62,1405.37 1809.63,1405.37 1809.63,1405.37 1809.64,1405.37 1809.64,1405.37 1809.65,1405.37 1809.65,1405.37 1809.66,1405.37 1809.66,1405.37 1809.67,1405.37 1809.67,1405.37 1809.68,1405.37 1809.68,1405.37 1809.69,1405.37 1809.7,1405.37 1809.7,1405.37 1809.71,1405.37 1809.71,1405.37 1809.72,1405.37 1809.72,1405.37 1809.73,1405.37 1809.73,1405.37 1809.74,1405.37 1809.74,1405.37 1809.75,1405.37 1809.75,1405.37 1809.76,1405.37 1809.76,1405.37 1809.77,1405.37 1809.78,1405.37 1809.78,1405.37 1809.79,1405.37 1809.79,1405.37 1809.8,1405.37 1809.8,1405.37 1809.81,1405.37 1809.81,1405.37 1809.82,1405.37 1809.82,1405.37 1809.83,1405.37 1809.83,1405.37 1809.84,1405.37 1809.84,1405.37 1809.85,1405.37 1809.85,1405.37 1809.86,1405.37 1809.87,1405.37 1809.87,1405.37 1809.88,1405.37 1809.88,1405.37 1809.89,1405.37 1809.89,1405.37 1809.9,1405.37 1809.9,1405.37 1809.91,1405.37 1809.91,1405.37 1809.92,1405.37 1809.92,1405.37 1809.93,1405.36 1809.93,1405.36 1809.94,1405.36 1809.94,1405.36 1809.95,1405.36 1809.96,1405.36 1809.96,1405.36 1809.97,1405.36 1809.97,1405.36 1809.98,1405.36 1809.98,1405.36 1809.99,1405.36 1809.99,1405.36 1810,1405.36 1810,1405.36 1810.01,1405.36 1810.01,1405.36 1810.02,1405.36 1810.02,1405.36 1810.03,1405.36 1810.03,1405.36 1810.04,1405.36 1810.05,1405.36 1810.05,1405.36 1810.06,1405.36 1810.06,1405.36 1810.07,1405.36 1810.07,1405.36 1810.08,1405.36 1810.08,1405.36 1810.09,1405.36 1810.09,1405.36 1810.1,1405.36 1810.1,1405.36 1810.11,1405.36 1810.11,1405.36 1810.12,1405.36 1810.12,1405.36 1810.13,1405.36 1810.14,1405.36 1810.14,1405.36 1810.15,1405.36 1810.15,1405.36 1810.16,1405.36 1810.16,1405.36 1810.17,1405.36 1810.17,1405.36 1810.18,1405.36 1810.18,1405.36 1810.19,1405.36 1810.19,1405.36 1810.2,1405.36 1810.2,1405.36 1810.21,1405.36 1810.21,1405.36 1810.22,1405.36 1810.23,1405.36 1810.23,1405.36 1810.24,1405.36 1810.24,1405.36 1810.25,1405.36 1810.25,1405.36 1810.26,1405.36 1810.26,1405.36 1810.27,1405.36 1810.27,1405.36 1810.28,1405.36 1810.28,1405.36 1810.29,1405.36 1810.29,1405.36 1810.3,1405.36 1810.3,1405.36 1810.31,1405.36 1810.31,1405.36 1810.32,1405.36 1810.33,1405.36 1810.33,1405.36 1810.34,1405.36 1810.34,1405.36 1810.35,1405.36 1810.35,1405.36 1810.36,1405.36 1810.36,1405.35 1810.37,1405.35 1810.37,1405.35 1810.38,1405.35 1810.38,1405.35 1810.39,1405.35 1810.39,1405.35 1810.4,1405.35 1810.4,1405.35 1810.41,1405.35 1810.41,1405.35 1810.42,1405.35 1810.43,1405.35 1810.43,1405.35 1810.44,1405.35 1810.44,1405.35 1810.45,1405.35 1810.45,1405.35 1810.46,1405.35 1810.46,1405.35 1810.47,1405.35 1810.47,1405.35 1810.48,1405.35 1810.48,1405.35 1810.49,1405.35 1810.49,1405.35 1810.5,1405.35 1810.5,1405.35 1810.51,1405.35 1810.51,1405.35 1810.52,1405.35 1810.53,1405.35 1810.53,1405.35 1810.54,1405.35 1810.54,1405.35 1810.55,1405.35 1810.55,1405.35 1810.56,1405.35 1810.56,1405.35 1810.57,1405.35 1810.57,1405.35 1810.58,1405.35 1810.58,1405.35 1810.59,1405.35 1810.59,1405.35 1810.6,1405.35 1810.6,1405.35 1810.61,1405.35 1810.61,1405.35 1810.62,1405.35 1810.62,1405.35 1810.63,1405.35 1810.64,1405.35 1810.64,1405.35 1810.65,1405.35 1810.65,1405.35 1810.66,1405.35 1810.66,1405.35 1810.67,1405.35 1810.67,1405.35 1810.68,1405.35 1810.68,1405.35 1810.69,1405.35 1810.69,1405.35 1810.7,1405.35 1810.7,1405.35 1810.71,1405.35 1810.71,1405.35 1810.72,1405.35 1810.72,1405.35 1810.73,1405.35 1810.73,1405.35 1810.74,1405.35 1810.75,1405.35 1810.75,1405.35 1810.76,1405.35 1810.76,1405.35 1810.77,1405.35 1810.77,1405.35 1810.78,1405.35 1810.78,1405.35 1810.79,1405.35 1810.79,1405.35 1810.8,1405.34 1810.8,1405.34 1810.81,1405.34 1810.81,1405.34 1810.82,1405.34 1810.82,1405.34 1810.83,1405.34 1810.83,1405.34 1810.84,1405.34 1810.84,1405.34 1810.85,1405.34 1810.86,1405.34 1810.86,1405.34 1810.87,1405.34 1810.87,1405.34 1810.88,1405.34 1810.88,1405.34 1810.89,1405.34 1810.89,1405.34 1810.9,1405.34 1810.9,1405.34 1810.91,1405.34 1810.91,1405.34 1810.92,1405.34 1810.92,1405.34 1810.93,1405.34 1810.93,1405.34 1810.94,1405.34 1810.94,1405.34 1810.95,1405.34 1810.95,1405.34 1810.96,1405.34 1810.96,1405.34 1810.97,1405.34 1810.98,1405.34 1810.98,1405.34 1810.99,1405.34 1810.99,1405.34 1811,1405.34 1811,1405.34 1811.01,1405.34 1811.01,1405.34 1811.02,1405.34 1811.02,1405.34 1811.03,1405.34 1811.03,1405.34 1811.04,1405.34 1811.04,1405.34 1811.05,1405.34 1811.05,1405.34 1811.06,1405.34 1811.06,1405.34 1811.07,1405.34 1811.07,1405.34 1811.08,1405.34 1811.08,1405.34 1811.09,1405.34 1811.1,1405.34 1811.1,1405.34 1811.11,1405.34 1811.11,1405.34 1811.12,1405.34 1811.12,1405.34 1811.13,1405.34 1811.13,1405.34 1811.14,1405.34 1811.14,1405.34 1811.15,1405.34 1811.15,1405.34 1811.16,1405.34 1811.16,1405.34 1811.17,1405.34 1811.17,1405.34 1811.18,1405.34 1811.18,1405.34 1811.19,1405.34 1811.19,1405.34 1811.2,1405.34 1811.2,1405.34 1811.21,1405.34 1811.21,1405.34 1811.22,1405.34 1811.23,1405.34 1811.23,1405.33 1811.24,1405.33 1811.24,1405.33 1811.25,1405.33 1811.25,1405.33 1811.26,1405.33 1811.26,1405.33 1811.27,1405.33 1811.27,1405.33 1811.28,1405.33 1811.28,1405.33 1811.29,1405.33 1811.29,1405.33 1811.3,1405.33 1811.3,1405.33 1811.31,1405.33 1811.31,1405.33 1811.32,1405.33 1811.32,1405.33 1811.33,1405.33 1811.33,1405.33 1811.34,1405.33 1811.34,1405.33 1811.35,1405.33 1811.35,1405.33 1811.36,1405.33 1811.37,1405.33 1811.37,1405.33 1811.38,1405.33 1811.38,1405.33 1811.39,1405.33 1811.39,1405.33 1811.4,1405.33 1811.4,1405.33 1811.41,1405.33 1811.41,1405.33 1811.42,1405.33 1811.42,1405.33 1811.43,1405.33 1811.43,1405.33 1811.44,1405.33 1811.44,1405.33 1811.45,1405.33 1811.45,1405.33 1811.46,1405.33 1811.46,1405.33 1811.47,1405.33 1811.47,1405.33 1811.48,1405.33 1811.48,1405.33 1811.49,1405.33 1811.49,1405.33 1811.5,1405.33 1811.51,1405.33 1811.51,1405.33 1811.52,1405.33 1811.52,1405.33 1811.53,1405.33 1811.53,1405.33 1811.54,1405.33 1811.54,1405.33 1811.55,1405.33 1811.55,1405.33 1811.56,1405.33 1811.56,1405.33 1811.57,1405.33 1811.57,1405.33 1811.58,1405.33 1811.58,1405.33 1811.59,1405.33 1811.59,1405.33 1811.6,1405.33 1811.6,1405.33 1811.61,1405.33 1811.61,1405.33 1811.62,1405.33 1811.62,1405.33 1811.63,1405.33 1811.63,1405.33 1811.64,1405.33 1811.64,1405.33 1811.65,1405.33 1811.66,1405.33 1811.66,1405.33 1811.67,1405.32 1811.67,1405.32 1811.68,1405.32 1811.68,1405.32 1811.69,1405.32 1811.69,1405.32 1811.7,1405.32 1811.7,1405.32 1811.71,1405.32 1811.71,1405.32 1811.72,1405.32 1811.72,1405.32 1811.73,1405.32 1811.73,1405.32 1811.74,1405.32 1811.74,1405.32 1811.75,1405.32 1811.75,1405.32 1811.76,1405.32 1811.76,1405.32 1811.77,1405.32 1811.77,1405.32 1811.78,1405.32 1811.78,1405.32 1811.79,1405.32 1811.79,1405.32 1811.8,1405.32 1811.8,1405.32 1811.81,1405.32 1811.82,1405.32 1811.82,1405.32 1811.83,1405.32 1811.83,1405.32 1811.84,1405.32 1811.84,1405.32 1811.85,1405.32 1811.85,1405.32 1811.86,1405.32 1811.86,1405.32 1811.87,1405.32 1811.87,1405.32 1811.88,1405.32 1811.88,1405.32 1811.89,1405.32 1811.89,1405.32 1811.9,1405.32 1811.9,1405.32 1811.91,1405.32 1811.91,1405.32 1811.92,1405.32 1811.92,1405.32 1811.93,1405.32 1811.93,1405.32 1811.94,1405.32 1811.94,1405.32 1811.95,1405.32 1811.95,1405.32 1811.96,1405.32 1811.96,1405.32 1811.97,1405.32 1811.97,1405.32 1811.98,1405.32 1811.98,1405.32 1811.99,1405.32 1812,1405.32 1812,1405.32 1812.01,1405.32 1812.01,1405.32 1812.02,1405.32 1812.02,1405.32 1812.03,1405.32 1812.03,1405.32 1812.04,1405.32 1812.04,1405.32 1812.05,1405.32 1812.05,1405.32 1812.06,1405.32 1812.06,1405.32 1812.07,1405.32 1812.07,1405.32 1812.08,1405.32 1812.08,1405.32 1812.09,1405.32 1812.09,1405.31 1812.1,1405.31 1812.1,1405.31 1812.11,1405.31 1812.11,1405.31 1812.12,1405.31 1812.12,1405.31 1812.13,1405.31 1812.13,1405.31 1812.14,1405.31 1812.14,1405.31 1812.15,1405.31 1812.15,1405.31 1812.16,1405.31 1812.16,1405.31 1812.17,1405.31 1812.17,1405.31 1812.18,1405.31 1812.19,1405.31 1812.19,1405.31 1812.2,1405.31 1812.2,1405.31 1812.21,1405.31 1812.21,1405.31 1812.22,1405.31 1812.22,1405.31 1812.23,1405.31 1812.23,1405.31 1812.24,1405.31 1812.24,1405.31 1812.25,1405.31 1812.25,1405.31 1812.26,1405.31 1812.26,1405.31 1812.27,1405.31 1812.27,1405.31 1812.28,1405.31 1812.28,1405.31 1812.29,1405.31 1812.29,1405.31 1812.3,1405.31 1812.3,1405.31 1812.31,1405.31 1812.31,1405.31 1812.32,1405.31 1812.32,1405.31 1812.33,1405.31 1812.33,1405.31 1812.34,1405.31 1812.34,1405.31 1812.35,1405.31 1812.35,1405.31 1812.36,1405.31 1812.36,1405.31 1812.37,1405.31 1812.37,1405.31 1812.38,1405.31 1812.38,1405.31 1812.39,1405.31 1812.39,1405.31 1812.4,1405.31 1812.41,1405.31 1812.41,1405.31 1812.42,1405.31 1812.42,1405.31 1812.43,1405.31 1812.43,1405.31 1812.44,1405.31 1812.44,1405.31 1812.45,1405.31 1812.45,1405.31 1812.46,1405.31 1812.46,1405.31 1812.47,1405.31 1812.47,1405.31 1812.48,1405.31 1812.48,1405.31 1812.49,1405.31 1812.49,1405.31 1812.5,1405.31 1812.5,1405.31 1812.51,1405.31 1812.51,1405.31 1812.52,1405.31 1812.52,1405.31 1812.53,1405.3 1812.53,1405.3 1812.54,1405.3 1812.54,1405.3 1812.55,1405.3 1812.55,1405.3 1812.56,1405.3 1812.56,1405.3 1812.57,1405.3 1812.57,1405.3 1812.58,1405.3 1812.58,1405.3 1812.59,1405.3 1812.59,1405.3 1812.6,1405.3 1812.6,1405.3 1812.61,1405.3 1812.61,1405.3 1812.62,1405.3 1812.62,1405.3 1812.63,1405.3 1812.63,1405.3 1812.64,1405.3 1812.64,1405.3 1812.65,1405.3 1812.65,1405.3 1812.66,1405.3 1812.67,1405.3 1812.67,1405.3 1812.68,1405.3 1812.68,1405.3 1812.69,1405.3 1812.69,1405.3 1812.7,1405.3 1812.7,1405.3 1812.71,1405.3 1812.71,1405.3 1812.72,1405.3 1812.72,1405.3 1812.73,1405.3 1812.73,1405.3 1812.74,1405.3 1812.74,1405.3 1812.75,1405.3 1812.75,1405.3 1812.76,1405.3 1812.76,1405.3 1812.77,1405.3 1812.77,1405.3 1812.78,1405.3 1812.78,1405.3 1812.79,1405.3 1812.79,1405.3 1812.8,1405.3 1812.8,1405.3 1812.81,1405.3 1812.81,1405.3 1812.82,1405.3 1812.82,1405.3 1812.83,1405.3 1812.83,1405.3 1812.84,1405.3 1812.84,1405.3 1812.85,1405.3 1812.85,1405.3 1812.86,1405.3 1812.86,1405.3 1812.87,1405.3 1812.87,1405.3 1812.88,1405.3 1812.88,1405.3 1812.89,1405.3 1812.89,1405.3 1812.9,1405.3 1812.9,1405.3 1812.91,1405.3 1812.91,1405.3 1812.92,1405.3 1812.92,1405.3 1812.93,1405.3 1812.93,1405.3 1812.94,1405.3 1812.94,1405.3 1812.95,1405.3 1812.95,1405.29 1812.96,1405.29 1812.96,1405.29 1812.97,1405.29 1812.97,1405.29 1812.98,1405.29 1812.98,1405.29 1812.99,1405.29 1812.99,1405.29 1813,1405.29 1813.01,1405.29 1813.01,1405.29 1813.02,1405.29 1813.02,1405.29 1813.03,1405.29 1813.03,1405.29 1813.04,1405.29 1813.04,1405.29 1813.05,1405.29 1813.05,1405.29 1813.06,1405.29 1813.06,1405.29 1813.07,1405.29 1813.07,1405.29 1813.08,1405.29 1813.08,1405.29 1813.09,1405.29 1813.09,1405.29 1813.1,1405.29 1813.1,1405.29 1813.11,1405.29 1813.11,1405.29 1813.12,1405.29 1813.12,1405.29 1813.13,1405.29 1813.13,1405.29 1813.14,1405.29 1813.14,1405.29 1813.15,1405.29 1813.15,1405.29 1813.16,1405.29 1813.16,1405.29 1813.17,1405.29 1813.17,1405.29 1813.18,1405.29 1813.18,1405.29 1813.19,1405.29 1813.19,1405.29 1813.2,1405.29 1813.2,1405.29 1813.21,1405.29 1813.21,1405.29 1813.22,1405.29 1813.22,1405.29 1813.23,1405.29 1813.23,1405.29 1813.24,1405.29 1813.24,1405.29 1813.25,1405.29 1813.25,1405.29 1813.26,1405.29 1813.26,1405.29 1813.27,1405.29 1813.27,1405.29 1813.28,1405.29 1813.28,1405.29 1813.29,1405.29 1813.29,1405.29 1813.3,1405.29 1813.3,1405.29 1813.31,1405.29 1813.31,1405.29 1813.32,1405.29 1813.32,1405.29 1813.33,1405.29 1813.33,1405.29 1813.34,1405.29 1813.34,1405.29 1813.35,1405.29 1813.35,1405.29 1813.36,1405.29 1813.36,1405.29 1813.37,1405.29 1813.37,1405.29 1813.38,1405.29 1813.38,1405.28 1813.39,1405.28 1813.39,1405.28 1813.4,1405.28 1813.4,1405.28 1813.41,1405.28 1813.41,1405.28 1813.42,1405.28 1813.42,1405.28 1813.43,1405.28 1813.43,1405.28 1813.44,1405.28 1813.44,1405.28 1813.45,1405.28 1813.45,1405.28 1813.46,1405.28 1813.46,1405.28 1813.47,1405.28 1813.47,1405.28 1813.48,1405.28 1813.48,1405.28 1813.49,1405.28 1813.49,1405.28 1813.5,1405.28 1813.5,1405.28 1813.51,1405.28 1813.51,1405.28 1813.52,1405.28 1813.52,1405.28 1813.53,1405.28 1813.53,1405.28 1813.54,1405.28 1813.54,1405.28 1813.55,1405.28 1813.55,1405.28 1813.56,1405.28 1813.56,1405.28 1813.57,1405.28 1813.57,1405.28 1813.58,1405.28 1813.58,1405.28 1813.59,1405.28 1813.59,1405.28 1813.6,1405.28 1813.6,1405.28 1813.61,1405.28 1813.61,1405.28 1813.62,1405.28 1813.62,1405.28 1813.63,1405.28 1813.63,1405.28 1813.64,1405.28 1813.64,1405.28 1813.65,1405.28 1813.65,1405.28 1813.66,1405.28 1813.66,1405.28 1813.67,1405.28 1813.68,1405.28 1813.68,1405.28 1813.69,1405.28 1813.69,1405.28 1813.7,1405.28 1813.7,1405.28 1813.71,1405.28 1813.71,1405.28 1813.72,1405.28 1813.72,1405.28 1813.73,1405.28 1813.73,1405.28 1813.74,1405.28 1813.74,1405.28 1813.75,1405.28 1813.75,1405.28 1813.76,1405.28 1813.76,1405.28 1813.77,1405.28 1813.77,1405.28 1813.78,1405.28 1813.78,1405.28 1813.79,1405.28 1813.79,1405.28 1813.8,1405.28 1813.8,1405.28 1813.81,1405.28 1813.81,1405.28 1813.82,1405.27 1813.82,1405.27 1813.83,1405.27 1813.83,1405.27 1813.84,1405.27 1813.84,1405.27 1813.85,1405.27 1813.85,1405.27 1813.86,1405.27 1813.86,1405.27 1813.87,1405.27 1813.87,1405.27 1813.88,1405.27 1813.88,1405.27 1813.89,1405.27 1813.89,1405.27 1813.9,1405.27 1813.9,1405.27 1813.91,1405.27 1813.91,1405.27 1813.92,1405.27 1813.92,1405.27 1813.93,1405.27 1813.93,1405.27 1813.94,1405.27 1813.94,1405.27 1813.95,1405.27 1813.95,1405.27 1813.96,1405.27 1813.96,1405.27 1813.97,1405.27 1813.97,1405.27 1813.98,1405.27 1813.98,1405.27 1813.99,1405.27 1813.99,1405.27 1814,1405.27 1814,1405.27 1814.01,1405.27 1814.01,1405.27 1814.01,1405.27 1814.02,1405.27 1814.02,1405.27 1814.03,1405.27 1814.03,1405.27 1814.04,1405.27 1814.04,1405.27 1814.05,1405.27 1814.05,1405.27 1814.06,1405.27 1814.06,1405.27 1814.07,1405.27 1814.07,1405.27 1814.08,1405.27 1814.08,1405.27 1814.09,1405.27 1814.09,1405.27 1814.1,1405.27 1814.1,1405.27 1814.11,1405.27 1814.11,1405.27 1814.12,1405.27 1814.12,1405.27 1814.13,1405.27 1814.13,1405.27 1814.14,1405.27 1814.14,1405.27 1814.15,1405.27 1814.15,1405.27 1814.16,1405.27 1814.16,1405.27 1814.17,1405.27 1814.17,1405.27 1814.18,1405.27 1814.18,1405.27 1814.19,1405.27 1814.19,1405.27 1814.2,1405.27 1814.2,1405.27 1814.21,1405.27 1814.21,1405.27 1814.22,1405.27 1814.22,1405.27 1814.23,1405.27 1814.23,1405.27 1814.24,1405.26 1814.24,1405.26 1814.25,1405.26 1814.25,1405.26 1814.26,1405.26 1814.26,1405.26 1814.27,1405.26 1814.27,1405.26 1814.28,1405.26 1814.28,1405.26 1814.29,1405.26 1814.29,1405.26 1814.3,1405.26 1814.3,1405.26 1814.31,1405.26 1814.31,1405.26 1814.32,1405.26 1814.32,1405.26 1814.33,1405.26 1814.33,1405.26 1814.34,1405.26 1814.34,1405.26 1814.35,1405.26 1814.35,1405.26 1814.36,1405.26 1814.36,1405.26 1814.37,1405.26 1814.37,1405.26 1814.38,1405.26 1814.38,1405.26 1814.39,1405.26 1814.39,1405.26 1814.4,1405.26 1814.4,1405.26 1814.41,1405.26 1814.41,1405.26 1814.42,1405.26 1814.42,1405.26 1814.43,1405.26 1814.43,1405.26 1814.44,1405.26 1814.44,1405.26 1814.45,1405.26 1814.45,1405.26 1814.46,1405.26 1814.46,1405.26 1814.47,1405.26 1814.47,1405.26 1814.48,1405.26 1814.48,1405.26 1814.49,1405.26 1814.49,1405.26 1814.5,1405.26 1814.5,1405.26 1814.51,1405.26 1814.51,1405.26 1814.52,1405.26 1814.52,1405.26 1814.53,1405.26 1814.53,1405.26 1814.54,1405.26 1814.54,1405.26 1814.55,1405.26 1814.55,1405.26 1814.56,1405.26 1814.56,1405.26 1814.57,1405.26 1814.57,1405.26 1814.58,1405.26 1814.58,1405.26 1814.59,1405.26 1814.59,1405.26 1814.6,1405.26 1814.6,1405.26 1814.61,1405.26 1814.61,1405.26 1814.62,1405.26 1814.62,1405.26 1814.63,1405.26 1814.63,1405.26 1814.64,1405.26 1814.64,1405.26 1814.65,1405.26 1814.65,1405.26 1814.66,1405.26 1814.66,1405.26 1814.67,1405.26 1814.67,1405.25 1814.68,1405.25 1814.68,1405.25 1814.68,1405.25 1814.69,1405.25 1814.69,1405.25 1814.7,1405.25 1814.7,1405.25 1814.71,1405.25 1814.71,1405.25 1814.72,1405.25 1814.72,1405.25 1814.73,1405.25 1814.73,1405.25 1814.74,1405.25 1814.74,1405.25 1814.75,1405.25 1814.75,1405.25 1814.76,1405.25 1814.76,1405.25 1814.77,1405.25 1814.77,1405.25 1814.78,1405.25 1814.78,1405.25 1814.79,1405.25 1814.79,1405.25 1814.8,1405.25 1814.8,1405.25 1814.81,1405.25 1814.81,1405.25 1814.82,1405.25 1814.82,1405.25 1814.83,1405.25 1814.83,1405.25 1814.84,1405.25 1814.84,1405.25 1814.85,1405.25 1814.85,1405.25 1814.86,1405.25 1814.86,1405.25 1814.87,1405.25 1814.87,1405.25 1814.88,1405.25 1814.88,1405.25 1814.89,1405.25 1814.89,1405.25 1814.9,1405.25 1814.9,1405.25 1814.91,1405.25 1814.91,1405.25 1814.92,1405.25 1814.92,1405.25 1814.93,1405.25 1814.93,1405.25 1814.94,1405.25 1814.94,1405.25 1814.95,1405.25 1814.95,1405.25 1814.96,1405.25 1814.96,1405.25 1814.97,1405.25 1814.97,1405.25 1814.98,1405.25 1814.98,1405.25 1814.99,1405.25 1814.99,1405.25 1815,1405.25 1815,1405.25 1815.01,1405.25 1815.01,1405.25 1815.01,1405.25 1815.02,1405.25 1815.02,1405.25 1815.03,1405.25 1815.03,1405.25 1815.04,1405.25 1815.04,1405.25 1815.05,1405.25 1815.05,1405.25 1815.06,1405.25 1815.06,1405.25 1815.07,1405.25 1815.07,1405.25 1815.08,1405.25 1815.08,1405.25 1815.09,1405.25 1815.09,1405.24 1815.1,1405.24 1815.1,1405.24 1815.11,1405.24 1815.11,1405.24 1815.12,1405.24 1815.12,1405.24 1815.13,1405.24 1815.13,1405.24 1815.14,1405.24 1815.14,1405.24 1815.15,1405.24 1815.15,1405.24 1815.16,1405.24 1815.16,1405.24 1815.17,1405.24 1815.17,1405.24 1815.18,1405.24 1815.18,1405.24 1815.19,1405.24 1815.19,1405.24 1815.2,1405.24 1815.2,1405.24 1815.21,1405.24 1815.21,1405.24 1815.22,1405.24 1815.22,1405.24 1815.23,1405.24 1815.23,1405.24 1815.24,1405.24 1815.24,1405.24 1815.25,1405.24 1815.25,1405.24 1815.26,1405.24 1815.26,1405.24 1815.27,1405.24 1815.27,1405.24 1815.27,1405.24 1815.28,1405.24 1815.28,1405.24 1815.29,1405.24 1815.29,1405.24 1815.3,1405.24 1815.3,1405.24 1815.31,1405.24 1815.31,1405.24 1815.32,1405.24 1815.32,1405.24 1815.33,1405.24 1815.33,1405.24 1815.34,1405.24 1815.34,1405.24 1815.35,1405.24 1815.35,1405.24 1815.36,1405.24 1815.36,1405.24 1815.37,1405.24 1815.37,1405.24 1815.38,1405.24 1815.38,1405.24 1815.39,1405.24 1815.39,1405.24 1815.4,1405.24 1815.4,1405.24 1815.41,1405.24 1815.41,1405.24 1815.42,1405.24 1815.42,1405.24 1815.43,1405.24 1815.43,1405.24 1815.44,1405.24 1815.44,1405.24 1815.45,1405.24 1815.45,1405.24 1815.46,1405.24 1815.46,1405.24 1815.47,1405.24 1815.47,1405.24 1815.48,1405.24 1815.48,1405.24 1815.49,1405.24 1815.49,1405.24 1815.49,1405.24 1815.5,1405.24 1815.5,1405.24 1815.51,1405.24 1815.51,1405.24 1815.52,1405.23 1815.52,1405.23 1815.53,1405.23 1815.53,1405.23 1815.54,1405.23 1815.54,1405.23 1815.55,1405.23 1815.55,1405.23 1815.56,1405.23 1815.56,1405.23 1815.57,1405.23 1815.57,1405.23 1815.58,1405.23 1815.58,1405.23 1815.59,1405.23 1815.59,1405.23 1815.6,1405.23 1815.6,1405.23 1815.61,1405.23 1815.61,1405.23 1815.62,1405.23 1815.62,1405.23 1815.63,1405.23 1815.63,1405.23 1815.64,1405.23 1815.64,1405.23 1815.65,1405.23 1815.65,1405.23 1815.66,1405.23 1815.66,1405.23 1815.67,1405.23 1815.67,1405.23 1815.68,1405.23 1815.68,1405.23 1815.68,1405.23 1815.69,1405.23 1815.69,1405.23 1815.7,1405.23 1815.7,1405.23 1815.71,1405.23 1815.71,1405.23 1815.72,1405.23 1815.72,1405.23 1815.73,1405.23 1815.73,1405.23 1815.74,1405.23 1815.74,1405.23 1815.75,1405.23 1815.75,1405.23 1815.76,1405.23 1815.76,1405.23 1815.77,1405.23 1815.77,1405.23 1815.78,1405.23 1815.78,1405.23 1815.79,1405.23 1815.79,1405.23 1815.8,1405.23 1815.8,1405.23 1815.81,1405.23 1815.81,1405.23 1815.82,1405.23 1815.82,1405.23 1815.83,1405.23 1815.83,1405.23 1815.84,1405.23 1815.84,1405.23 1815.85,1405.23 1815.85,1405.23 1815.85,1405.23 1815.86,1405.23 1815.86,1405.23 1815.87,1405.23 1815.87,1405.23 1815.88,1405.23 1815.88,1405.23 1815.89,1405.23 1815.89,1405.23 1815.9,1405.23 1815.9,1405.23 1815.91,1405.23 1815.91,1405.23 1815.92,1405.23 1815.92,1405.23 1815.93,1405.23 1815.93,1405.23 1815.94,1405.23 1815.94,1405.23 1815.95,1405.22 1815.95,1405.22 1815.96,1405.22 1815.96,1405.22 1815.97,1405.22 1815.97,1405.22 1815.98,1405.22 1815.98,1405.22 1815.99,1405.22 1815.99,1405.22 1816,1405.22 1816,1405.22 1816.01,1405.22 1816.01,1405.22 1816.01,1405.22 1816.02,1405.22 1816.02,1405.22 1816.03,1405.22 1816.03,1405.22 1816.04,1405.22 1816.04,1405.22 1816.05,1405.22 1816.05,1405.22 1816.06,1405.22 1816.06,1405.22 1816.07,1405.22 1816.07,1405.22 1816.08,1405.22 1816.08,1405.22 1816.09,1405.22 1816.09,1405.22 1816.1,1405.22 1816.1,1405.22 1816.11,1405.22 1816.11,1405.22 1816.12,1405.22 1816.12,1405.22 1816.13,1405.22 1816.13,1405.22 1816.14,1405.22 1816.14,1405.22 1816.15,1405.22 1816.15,1405.22 1816.16,1405.22 1816.16,1405.22 1816.16,1405.22 1816.17,1405.22 1816.17,1405.22 1816.18,1405.22 1816.18,1405.22 1816.19,1405.22 1816.19,1405.22 1816.2,1405.22 1816.2,1405.22 1816.21,1405.22 1816.21,1405.22 1816.22,1405.22 1816.22,1405.22 1816.23,1405.22 1816.23,1405.22 1816.24,1405.22 1816.24,1405.22 1816.25,1405.22 1816.25,1405.22 1816.26,1405.22 1816.26,1405.22 1816.27,1405.22 1816.27,1405.22 1816.28,1405.22 1816.28,1405.22 1816.29,1405.22 1816.29,1405.22 1816.3,1405.22 1816.3,1405.22 1816.3,1405.22 1816.31,1405.22 1816.31,1405.22 1816.32,1405.22 1816.32,1405.22 1816.33,1405.22 1816.33,1405.22 1816.34,1405.22 1816.34,1405.22 1816.35,1405.22 1816.35,1405.22 1816.36,1405.22 1816.36,1405.22 1816.37,1405.21 1816.37,1405.21 1816.38,1405.21 1816.38,1405.21 1816.39,1405.21 1816.39,1405.21 1816.4,1405.21 1816.4,1405.21 1816.41,1405.21 1816.41,1405.21 1816.42,1405.21 1816.42,1405.21 1816.43,1405.21 1816.43,1405.21 1816.43,1405.21 1816.44,1405.21 1816.44,1405.21 1816.45,1405.21 1816.45,1405.21 1816.46,1405.21 1816.46,1405.21 1816.47,1405.21 1816.47,1405.21 1816.48,1405.21 1816.48,1405.21 1816.49,1405.21 1816.49,1405.21 1816.5,1405.21 1816.5,1405.21 1816.51,1405.21 1816.51,1405.21 1816.52,1405.21 1816.52,1405.21 1816.53,1405.21 1816.53,1405.21 1816.54,1405.21 1816.54,1405.21 1816.55,1405.21 1816.55,1405.21 1816.55,1405.21 1816.56,1405.21 1816.56,1405.21 1816.57,1405.21 1816.57,1405.21 1816.58,1405.21 1816.58,1405.21 1816.59,1405.21 1816.59,1405.21 1816.6,1405.21 1816.6,1405.21 1816.61,1405.21 1816.61,1405.21 1816.62,1405.21 1816.62,1405.21 1816.63,1405.21 1816.63,1405.21 1816.64,1405.21 1816.64,1405.21 1816.65,1405.21 1816.65,1405.21 1816.66,1405.21 1816.66,1405.21 1816.67,1405.21 1816.67,1405.21 1816.67,1405.21 1816.68,1405.21 1816.68,1405.21 1816.69,1405.21 1816.69,1405.21 1816.7,1405.21 1816.7,1405.21 1816.71,1405.21 1816.71,1405.21 1816.72,1405.21 1816.72,1405.21 1816.73,1405.21 1816.73,1405.21 1816.74,1405.21 1816.74,1405.21 1816.75,1405.21 1816.75,1405.21 1816.76,1405.21 1816.76,1405.21 1816.77,1405.21 1816.77,1405.21 1816.78,1405.21 1816.78,1405.21 1816.79,1405.21 1816.79,1405.2 1816.79,1405.2 1816.8,1405.2 1816.8,1405.2 1816.81,1405.2 1816.81,1405.2 1816.82,1405.2 1816.82,1405.2 1816.83,1405.2 1816.83,1405.2 1816.84,1405.2 1816.84,1405.2 1816.85,1405.2 1816.85,1405.2 1816.86,1405.2 1816.86,1405.2 1816.87,1405.2 1816.87,1405.2 1816.88,1405.2 1816.88,1405.2 1816.89,1405.2 1816.89,1405.2 1816.9,1405.2 1816.9,1405.2 1816.9,1405.2 1816.91,1405.2 1816.91,1405.2 1816.92,1405.2 1816.92,1405.2 1816.93,1405.2 1816.93,1405.2 1816.94,1405.2 1816.94,1405.2 1816.95,1405.2 1816.95,1405.2 1816.96,1405.2 1816.96,1405.2 1816.97,1405.2 1816.97,1405.2 1816.98,1405.2 1816.98,1405.2 1816.99,1405.2 1816.99,1405.2 1817,1405.2 1817,1405.2 1817,1405.2 1817.01,1405.2 1817.01,1405.2 1817.02,1405.2 1817.02,1405.2 1817.03,1405.2 1817.03,1405.2 1817.04,1405.2 1817.04,1405.2 1817.05,1405.2 1817.05,1405.2 1817.06,1405.2 1817.06,1405.2 1817.07,1405.2 1817.07,1405.2 1817.08,1405.2 1817.08,1405.2 1817.09,1405.2 1817.09,1405.2 1817.1,1405.2 1817.1,1405.2 1817.11,1405.2 1817.11,1405.2 1817.11,1405.2 1817.12,1405.2 1817.12,1405.2 1817.13,1405.2 1817.13,1405.2 1817.14,1405.2 1817.14,1405.2 1817.15,1405.2 1817.15,1405.2 1817.16,1405.2 1817.16,1405.2 1817.17,1405.2 1817.17,1405.2 1817.18,1405.2 1817.18,1405.2 1817.19,1405.2 1817.19,1405.2 1817.2,1405.2 1817.2,1405.2 1817.21,1405.2 1817.21,1405.2 1817.21,1405.19 1817.22,1405.19 1817.22,1405.19 1817.23,1405.19 1817.23,1405.19 1817.24,1405.19 1817.24,1405.19 1817.25,1405.19 1817.25,1405.19 1817.26,1405.19 1817.26,1405.19 1817.27,1405.19 1817.27,1405.19 1817.28,1405.19 1817.28,1405.19 1817.29,1405.19 1817.29,1405.19 1817.3,1405.19 1817.3,1405.19 1817.3,1405.19 1817.31,1405.19 1817.31,1405.19 1817.32,1405.19 1817.32,1405.19 1817.33,1405.19 1817.33,1405.19 1817.34,1405.19 1817.34,1405.19 1817.35,1405.19 1817.35,1405.19 1817.36,1405.19 1817.36,1405.19 1817.37,1405.19 1817.37,1405.19 1817.38,1405.19 1817.38,1405.19 1817.39,1405.19 1817.39,1405.19 1817.4,1405.19 1817.4,1405.19 1817.4,1405.19 1817.41,1405.19 1817.41,1405.19 1817.42,1405.19 1817.42,1405.19 1817.43,1405.19 1817.43,1405.19 1817.44,1405.19 1817.44,1405.19 1817.45,1405.19 1817.45,1405.19 1817.46,1405.19 1817.46,1405.19 1817.47,1405.19 1817.47,1405.19 1817.48,1405.19 1817.48,1405.19 1817.49,1405.19 1817.49,1405.19 1817.49,1405.19 1817.5,1405.19 1817.5,1405.19 1817.51,1405.19 1817.51,1405.19 1817.52,1405.19 1817.52,1405.19 1817.53,1405.19 1817.53,1405.19 1817.54,1405.19 1817.54,1405.19 1817.55,1405.19 1817.55,1405.19 1817.56,1405.19 1817.56,1405.19 1817.57,1405.19 1817.57,1405.19 1817.58,1405.19 1817.58,1405.19 1817.58,1405.19 1817.59,1405.19 1817.59,1405.19 1817.6,1405.19 1817.6,1405.19 1817.61,1405.19 1817.61,1405.19 1817.62,1405.19 1817.62,1405.19 1817.63,1405.19 1817.63,1405.19 1817.64,1405.18 1817.64,1405.18 1817.65,1405.18 1817.65,1405.18 1817.66,1405.18 1817.66,1405.18 1817.66,1405.18 1817.67,1405.18 1817.67,1405.18 1817.68,1405.18 1817.68,1405.18 1817.69,1405.18 1817.69,1405.18 1817.7,1405.18 1817.7,1405.18 1817.71,1405.18 1817.71,1405.18 1817.72,1405.18 1817.72,1405.18 1817.73,1405.18 1817.73,1405.18 1817.74,1405.18 1817.74,1405.18 1817.75,1405.18 1817.75,1405.18 1817.75,1405.18 1817.76,1405.18 1817.76,1405.18 1817.77,1405.18 1817.77,1405.18 1817.78,1405.18 1817.78,1405.18 1817.79,1405.18 1817.79,1405.18 1817.8,1405.18 1817.8,1405.18 1817.81,1405.18 1817.81,1405.18 1817.82,1405.18 1817.82,1405.18 1817.83,1405.18 1817.83,1405.18 1817.83,1405.18 1817.84,1405.18 1817.84,1405.18 1817.85,1405.18 1817.85,1405.18 1817.86,1405.18 1817.86,1405.18 1817.87,1405.18 1817.87,1405.18 1817.88,1405.18 1817.88,1405.18 1817.89,1405.18 1817.89,1405.18 1817.9,1405.18 1817.9,1405.18 1817.91,1405.18 1817.91,1405.18 1817.91,1405.18 1817.92,1405.18 1817.92,1405.18 1817.93,1405.18 1817.93,1405.18 1817.94,1405.18 1817.94,1405.18 1817.95,1405.18 1817.95,1405.18 1817.96,1405.18 1817.96,1405.18 1817.97,1405.18 1817.97,1405.18 1817.98,1405.18 1817.98,1405.18 1817.99,1405.18 1817.99,1405.18 1817.99,1405.18 1818,1405.18 1818,1405.18 1818.01,1405.18 1818.01,1405.18 1818.02,1405.18 1818.02,1405.18 1818.03,1405.18 1818.03,1405.18 1818.04,1405.18 1818.04,1405.18 1818.05,1405.18 1818.05,1405.18 1818.06,1405.17 1818.06,1405.17 1818.07,1405.17 1818.07,1405.17 1818.07,1405.17 1818.08,1405.17 1818.08,1405.17 1818.09,1405.17 1818.09,1405.17 1818.1,1405.17 1818.1,1405.17 1818.11,1405.17 1818.11,1405.17 1818.12,1405.17 1818.12,1405.17 1818.13,1405.17 1818.13,1405.17 1818.14,1405.17 1818.14,1405.17 1818.15,1405.17 1818.15,1405.17 1818.15,1405.17 1818.16,1405.17 1818.16,1405.17 1818.17,1405.17 1818.17,1405.17 1818.18,1405.17 1818.18,1405.17 1818.19,1405.17 1818.19,1405.17 1818.2,1405.17 1818.2,1405.17 1818.21,1405.17 1818.21,1405.17 1818.22,1405.17 1818.22,1405.17 1818.22,1405.17 1818.23,1405.17 1818.23,1405.17 1818.24,1405.17 1818.24,1405.17 1818.25,1405.17 1818.25,1405.17 1818.26,1405.17 1818.26,1405.17 1818.27,1405.17 1818.27,1405.17 1818.28,1405.17 1818.28,1405.17 1818.29,1405.17 1818.29,1405.17 1818.3,1405.17 1818.3,1405.17 1818.3,1405.17 1818.31,1405.17 1818.31,1405.17 1818.32,1405.17 1818.32,1405.17 1818.33,1405.17 1818.33,1405.17 1818.34,1405.17 1818.34,1405.17 1818.35,1405.17 1818.35,1405.17 1818.36,1405.17 1818.36,1405.17 1818.37,1405.17 1818.37,1405.17 1818.37,1405.17 1818.38,1405.17 1818.38,1405.17 1818.39,1405.17 1818.39,1405.17 1818.4,1405.17 1818.4,1405.17 1818.41,1405.17 1818.41,1405.17 1818.42,1405.17 1818.42,1405.17 1818.43,1405.17 1818.43,1405.17 1818.44,1405.17 1818.44,1405.17 1818.44,1405.17 1818.45,1405.17 1818.45,1405.17 1818.46,1405.17 1818.46,1405.17 1818.47,1405.17 1818.47,1405.17 1818.48,1405.16 1818.48,1405.16 1818.49,1405.16 1818.49,1405.16 1818.5,1405.16 1818.5,1405.16 1818.51,1405.16 1818.51,1405.16 1818.51,1405.16 1818.52,1405.16 1818.52,1405.16 1818.53,1405.16 1818.53,1405.16 1818.54,1405.16 1818.54,1405.16 1818.55,1405.16 1818.55,1405.16 1818.56,1405.16 1818.56,1405.16 1818.57,1405.16 1818.57,1405.16 1818.58,1405.16 1818.58,1405.16 1818.58,1405.16 1818.59,1405.16 1818.59,1405.16 1818.6,1405.16 1818.6,1405.16 1818.61,1405.16 1818.61,1405.16 1818.62,1405.16 1818.62,1405.16 1818.63,1405.16 1818.63,1405.16 1818.64,1405.16 1818.64,1405.16 1818.65,1405.16 1818.65,1405.16 1818.65,1405.16 1818.66,1405.16 1818.66,1405.16 1818.67,1405.16 1818.67,1405.16 1818.68,1405.16 1818.68,1405.16 1818.69,1405.16 1818.69,1405.16 1818.7,1405.16 1818.7,1405.16 1818.71,1405.16 1818.71,1405.16 1818.72,1405.16 1818.72,1405.16 1818.72,1405.16 1818.73,1405.16 1818.73,1405.16 1818.74,1405.16 1818.74,1405.16 1818.75,1405.16 1818.75,1405.16 1818.76,1405.16 1818.76,1405.16 1818.77,1405.16 1818.77,1405.16 1818.78,1405.16 1818.78,1405.16 1818.78,1405.16 1818.79,1405.16 1818.79,1405.16 1818.8,1405.16 1818.8,1405.16 1818.81,1405.16 1818.81,1405.16 1818.82,1405.16 1818.82,1405.16 1818.83,1405.16 1818.83,1405.16 1818.84,1405.16 1818.84,1405.16 1818.85,1405.16 1818.85,1405.16 1818.85,1405.16 1818.86,1405.16 1818.86,1405.16 1818.87,1405.16 1818.87,1405.16 1818.88,1405.16 1818.88,1405.16 1818.89,1405.16 1818.89,1405.16 1818.9,1405.15 1818.9,1405.15 1818.91,1405.15 1818.91,1405.15 1818.91,1405.15 1818.92,1405.15 1818.92,1405.15 1818.93,1405.15 1818.93,1405.15 1818.94,1405.15 1818.94,1405.15 1818.95,1405.15 1818.95,1405.15 1818.96,1405.15 1818.96,1405.15 1818.97,1405.15 1818.97,1405.15 1818.98,1405.15 1818.98,1405.15 1818.98,1405.15 1818.99,1405.15 1818.99,1405.15 1819,1405.15 1819,1405.15 1819.01,1405.15 1819.01,1405.15 1819.02,1405.15 1819.02,1405.15 1819.03,1405.15 1819.03,1405.15 1819.04,1405.15 1819.04,1405.15 1819.04,1405.15 1819.05,1405.15 1819.05,1405.15 1819.06,1405.15 1819.06,1405.15 1819.07,1405.15 1819.07,1405.15 1819.08,1405.15 1819.08,1405.15 1819.09,1405.15 1819.09,1405.15 1819.1,1405.15 1819.1,1405.15 1819.1,1405.15 1819.11,1405.15 1819.11,1405.15 1819.12,1405.15 1819.12,1405.15 1819.13,1405.15 1819.13,1405.15 1819.14,1405.15 1819.14,1405.15 1819.15,1405.15 1819.15,1405.15 1819.16,1405.15 1819.16,1405.15 1819.16,1405.15 1819.17,1405.15 1819.17,1405.15 1819.18,1405.15 1819.18,1405.15 1819.19,1405.15 1819.19,1405.15 1819.2,1405.15 1819.2,1405.15 1819.21,1405.15 1819.21,1405.15 1819.22,1405.15 1819.22,1405.15 1819.22,1405.15 1819.23,1405.15 1819.23,1405.15 1819.24,1405.15 1819.24,1405.15 1819.25,1405.15 1819.25,1405.15 1819.26,1405.15 1819.26,1405.15 1819.27,1405.15 1819.27,1405.15 1819.28,1405.15 1819.28,1405.15 1819.28,1405.15 1819.29,1405.15 1819.29,1405.15 1819.3,1405.15 1819.3,1405.15 1819.31,1405.15 1819.31,1405.15 1819.32,1405.14 1819.32,1405.14 1819.33,1405.14 1819.33,1405.14 1819.34,1405.14 1819.34,1405.14 1819.34,1405.14 1819.35,1405.14 1819.35,1405.14 1819.36,1405.14 1819.36,1405.14 1819.37,1405.14 1819.37,1405.14 1819.38,1405.14 1819.38,1405.14 1819.39,1405.14 1819.39,1405.14 1819.4,1405.14 1819.4,1405.14 1819.4,1405.14 1819.41,1405.14 1819.41,1405.14 1819.42,1405.14 1819.42,1405.14 1819.43,1405.14 1819.43,1405.14 1819.44,1405.14 1819.44,1405.14 1819.45,1405.14 1819.45,1405.14 1819.46,1405.14 1819.46,1405.14 1819.46,1405.14 1819.47,1405.14 1819.47,1405.14 1819.48,1405.14 1819.48,1405.14 1819.49,1405.14 1819.49,1405.14 1819.5,1405.14 1819.5,1405.14 1819.51,1405.14 1819.51,1405.14 1819.52,1405.14 1819.52,1405.14 1819.52,1405.14 1819.53,1405.14 1819.53,1405.14 1819.54,1405.14 1819.54,1405.14 1819.55,1405.14 1819.55,1405.14 1819.56,1405.14 1819.56,1405.14 1819.57,1405.14 1819.57,1405.14 1819.57,1405.14 1819.58,1405.14 1819.58,1405.14 1819.59,1405.14 1819.59,1405.14 1819.6,1405.14 1819.6,1405.14 1819.61,1405.14 1819.61,1405.14 1819.62,1405.14 1819.62,1405.14 1819.63,1405.14 1819.63,1405.14 1819.63,1405.14 1819.64,1405.14 1819.64,1405.14 1819.65,1405.14 1819.65,1405.14 1819.66,1405.14 1819.66,1405.14 1819.67,1405.14 1819.67,1405.14 1819.68,1405.14 1819.68,1405.14 1819.69,1405.14 1819.69,1405.14 1819.69,1405.14 1819.7,1405.14 1819.7,1405.14 1819.71,1405.14 1819.71,1405.14 1819.72,1405.14 1819.72,1405.14 1819.73,1405.14 1819.73,1405.14 1819.74,1405.13 1819.74,1405.13 1819.74,1405.13 1819.75,1405.13 1819.75,1405.13 1819.76,1405.13 1819.76,1405.13 1819.77,1405.13 1819.77,1405.13 1819.78,1405.13 1819.78,1405.13 1819.79,1405.13 1819.79,1405.13 1819.8,1405.13 1819.8,1405.13 1819.8,1405.13 1819.81,1405.13 1819.81,1405.13 1819.82,1405.13 1819.82,1405.13 1819.83,1405.13 1819.83,1405.13 1819.84,1405.13 1819.84,1405.13 1819.85,1405.13 1819.85,1405.13 1819.85,1405.13 1819.86,1405.13 1819.86,1405.13 1819.87,1405.13 1819.87,1405.13 1819.88,1405.13 1819.88,1405.13 1819.89,1405.13 1819.89,1405.13 1819.9,1405.13 1819.9,1405.13 1819.9,1405.13 1819.91,1405.13 1819.91,1405.13 1819.92,1405.13 1819.92,1405.13 1819.93,1405.13 1819.93,1405.13 1819.94,1405.13 1819.94,1405.13 1819.95,1405.13 1819.95,1405.13 1819.96,1405.13 1819.96,1405.13 1819.96,1405.13 1819.97,1405.13 1819.97,1405.13 1819.98,1405.13 1819.98,1405.13 1819.99,1405.13 1819.99,1405.13 1820,1405.13 1820,1405.13 1820.01,1405.13 1820.01,1405.13 1820.01,1405.13 1820.02,1405.13 1820.02,1405.13 1820.03,1405.13 1820.03,1405.13 1820.04,1405.13 1820.04,1405.13 1820.05,1405.13 1820.05,1405.13 1820.06,1405.13 1820.06,1405.13 1820.06,1405.13 1820.07,1405.13 1820.07,1405.13 1820.08,1405.13 1820.08,1405.13 1820.09,1405.13 1820.09,1405.13 1820.1,1405.13 1820.1,1405.13 1820.11,1405.13 1820.11,1405.13 1820.11,1405.13 1820.12,1405.13 1820.12,1405.13 1820.13,1405.13 1820.13,1405.13 1820.14,1405.13 1820.14,1405.13 1820.15,1405.13 1820.15,1405.13 1820.16,1405.12 1820.16,1405.12 1820.16,1405.12 1820.17,1405.12 1820.17,1405.12 1820.18,1405.12 1820.18,1405.12 1820.19,1405.12 1820.19,1405.12 1820.2,1405.12 1820.2,1405.12 1820.21,1405.12 1820.21,1405.12 1820.22,1405.12 1820.22,1405.12 1820.22,1405.12 1820.23,1405.12 1820.23,1405.12 1820.24,1405.12 1820.24,1405.12 1820.25,1405.12 1820.25,1405.12 1820.26,1405.12 1820.26,1405.12 1820.27,1405.12 1820.27,1405.12 1820.27,1405.12 1820.28,1405.12 1820.28,1405.12 1820.29,1405.12 1820.29,1405.12 1820.3,1405.12 1820.3,1405.12 1820.31,1405.12 1820.31,1405.12 1820.32,1405.12 1820.32,1405.12 1820.32,1405.12 1820.33,1405.12 1820.33,1405.12 1820.34,1405.12 1820.34,1405.12 1820.35,1405.12 1820.35,1405.12 1820.36,1405.12 1820.36,1405.12 1820.37,1405.12 1820.37,1405.12 1820.37,1405.12 1820.38,1405.12 1820.38,1405.12 1820.39,1405.12 1820.39,1405.12 1820.4,1405.12 1820.4,1405.12 1820.41,1405.12 1820.41,1405.12 1820.41,1405.12 1820.42,1405.12 1820.42,1405.12 1820.43,1405.12 1820.43,1405.12 1820.44,1405.12 1820.44,1405.12 1820.45,1405.12 1820.45,1405.12 1820.46,1405.12 1820.46,1405.12 1820.46,1405.12 1820.47,1405.12 1820.47,1405.12 1820.48,1405.12 1820.48,1405.12 1820.49,1405.12 1820.49,1405.12 1820.5,1405.12 1820.5,1405.12 1820.51,1405.12 1820.51,1405.12 1820.51,1405.12 1820.52,1405.12 1820.52,1405.12 1820.53,1405.12 1820.53,1405.12 1820.54,1405.12 1820.54,1405.12 1820.55,1405.12 1820.55,1405.12 1820.56,1405.12 1820.56,1405.12 1820.56,1405.12 1820.57,1405.12 1820.57,1405.11 1820.58,1405.11 1820.58,1405.11 1820.59,1405.11 1820.59,1405.11 1820.6,1405.11 1820.6,1405.11 1820.61,1405.11 1820.61,1405.11 1820.61,1405.11 1820.62,1405.11 1820.62,1405.11 1820.63,1405.11 1820.63,1405.11 1820.64,1405.11 1820.64,1405.11 1820.65,1405.11 1820.65,1405.11 1820.66,1405.11 1820.66,1405.11 1820.66,1405.11 1820.67,1405.11 1820.67,1405.11 1820.68,1405.11 1820.68,1405.11 1820.69,1405.11 1820.69,1405.11 1820.7,1405.11 1820.7,1405.11 1820.7,1405.11 1820.71,1405.11 1820.71,1405.11 1820.72,1405.11 1820.72,1405.11 1820.73,1405.11 1820.73,1405.11 1820.74,1405.11 1820.74,1405.11 1820.75,1405.11 1820.75,1405.11 1820.75,1405.11 1820.76,1405.11 1820.76,1405.11 1820.77,1405.11 1820.77,1405.11 1820.78,1405.11 1820.78,1405.11 1820.79,1405.11 1820.79,1405.11 1820.8,1405.11 1820.8,1405.11 1820.8,1405.11 1820.81,1405.11 1820.81,1405.11 1820.82,1405.11 1820.82,1405.11 1820.83,1405.11 1820.83,1405.11 1820.84,1405.11 1820.84,1405.11 1820.84,1405.11 1820.85,1405.11 1820.85,1405.11 1820.86,1405.11 1820.86,1405.11 1820.87,1405.11 1820.87,1405.11 1820.88,1405.11 1820.88,1405.11 1820.89,1405.11 1820.89,1405.11 1820.89,1405.11 1820.9,1405.11 1820.9,1405.11 1820.91,1405.11 1820.91,1405.11 1820.92,1405.11 1820.92,1405.11 1820.93,1405.11 1820.93,1405.11 1820.93,1405.11 1820.94,1405.11 1820.94,1405.11 1820.95,1405.11 1820.95,1405.11 1820.96,1405.11 1820.96,1405.11 1820.97,1405.11 1820.97,1405.11 1820.98,1405.11 1820.98,1405.11 1820.98,1405.11 1820.99,1405.1 1820.99,1405.1 1821,1405.1 1821,1405.1 1821.01,1405.1 1821.01,1405.1 1821.02,1405.1 1821.02,1405.1 1821.02,1405.1 1821.03,1405.1 1821.03,1405.1 1821.04,1405.1 1821.04,1405.1 1821.05,1405.1 1821.05,1405.1 1821.06,1405.1 1821.06,1405.1 1821.07,1405.1 1821.07,1405.1 1821.07,1405.1 1821.08,1405.1 1821.08,1405.1 1821.09,1405.1 1821.09,1405.1 1821.1,1405.1 1821.1,1405.1 1821.11,1405.1 1821.11,1405.1 1821.11,1405.1 1821.12,1405.1 1821.12,1405.1 1821.13,1405.1 1821.13,1405.1 1821.14,1405.1 1821.14,1405.1 1821.15,1405.1 1821.15,1405.1 1821.16,1405.1 1821.16,1405.1 1821.16,1405.1 1821.17,1405.1 1821.17,1405.1 1821.18,1405.1 1821.18,1405.1 1821.19,1405.1 1821.19,1405.1 1821.2,1405.1 1821.2,1405.1 1821.2,1405.1 1821.21,1405.1 1821.21,1405.1 1821.22,1405.1 1821.22,1405.1 1821.23,1405.1 1821.23,1405.1 1821.24,1405.1 1821.24,1405.1 1821.24,1405.1 1821.25,1405.1 1821.25,1405.1 1821.26,1405.1 1821.26,1405.1 1821.27,1405.1 1821.27,1405.1 1821.28,1405.1 1821.28,1405.1 1821.29,1405.1 1821.29,1405.1 1821.29,1405.1 1821.3,1405.1 1821.3,1405.1 1821.31,1405.1 1821.31,1405.1 1821.32,1405.1 1821.32,1405.1 1821.33,1405.1 1821.33,1405.1 1821.33,1405.1 1821.34,1405.1 1821.34,1405.1 1821.35,1405.1 1821.35,1405.1 1821.36,1405.1 1821.36,1405.1 1821.37,1405.1 1821.37,1405.1 1821.37,1405.1 1821.38,1405.1 1821.38,1405.1 1821.39,1405.1 1821.39,1405.1 1821.4,1405.1 1821.4,1405.1 1821.41,1405.09 1821.41,1405.09 1821.41,1405.09 1821.42,1405.09 1821.42,1405.09 1821.43,1405.09 1821.43,1405.09 1821.44,1405.09 1821.44,1405.09 1821.45,1405.09 1821.45,1405.09 1821.46,1405.09 1821.46,1405.09 1821.46,1405.09 1821.47,1405.09 1821.47,1405.09 1821.48,1405.09 1821.48,1405.09 1821.49,1405.09 1821.49,1405.09 1821.5,1405.09 1821.5,1405.09 1821.5,1405.09 1821.51,1405.09 1821.51,1405.09 1821.52,1405.09 1821.52,1405.09 1821.53,1405.09 1821.53,1405.09 1821.54,1405.09 1821.54,1405.09 1821.54,1405.09 1821.55,1405.09 1821.55,1405.09 1821.56,1405.09 1821.56,1405.09 1821.57,1405.09 1821.57,1405.09 1821.58,1405.09 1821.58,1405.09 1821.58,1405.09 1821.59,1405.09 1821.59,1405.09 1821.6,1405.09 1821.6,1405.09 1821.61,1405.09 1821.61,1405.09 1821.62,1405.09 1821.62,1405.09 1821.62,1405.09 1821.63,1405.09 1821.63,1405.09 1821.64,1405.09 1821.64,1405.09 1821.65,1405.09 1821.65,1405.09 1821.66,1405.09 1821.66,1405.09 1821.66,1405.09 1821.67,1405.09 1821.67,1405.09 1821.68,1405.09 1821.68,1405.09 1821.69,1405.09 1821.69,1405.09 1821.7,1405.09 1821.7,1405.09 1821.7,1405.09 1821.71,1405.09 1821.71,1405.09 1821.72,1405.09 1821.72,1405.09 1821.73,1405.09 1821.73,1405.09 1821.74,1405.09 1821.74,1405.09 1821.75,1405.09 1821.75,1405.09 1821.75,1405.09 1821.76,1405.09 1821.76,1405.09 1821.77,1405.09 1821.77,1405.09 1821.78,1405.09 1821.78,1405.09 1821.79,1405.09 1821.79,1405.09 1821.79,1405.09 1821.8,1405.09 1821.8,1405.09 1821.81,1405.09 1821.81,1405.09 1821.82,1405.09 1821.82,1405.08 1821.83,1405.08 1821.83,1405.08 1821.83,1405.08 1821.84,1405.08 1821.84,1405.08 1821.85,1405.08 1821.85,1405.08 1821.86,1405.08 1821.86,1405.08 1821.87,1405.08 1821.87,1405.08 1821.87,1405.08 1821.88,1405.08 1821.88,1405.08 1821.89,1405.08 1821.89,1405.08 1821.9,1405.08 1821.9,1405.08 1821.91,1405.08 1821.91,1405.08 1821.91,1405.08 1821.92,1405.08 1821.92,1405.08 1821.93,1405.08 1821.93,1405.08 1821.94,1405.08 1821.94,1405.08 1821.94,1405.08 1821.95,1405.08 1821.95,1405.08 1821.96,1405.08 1821.96,1405.08 1821.97,1405.08 1821.97,1405.08 1821.98,1405.08 1821.98,1405.08 1821.98,1405.08 1821.99,1405.08 1821.99,1405.08 1822,1405.08 1822,1405.08 1822.01,1405.08 1822.01,1405.08 1822.02,1405.08 1822.02,1405.08 1822.02,1405.08 1822.03,1405.08 1822.03,1405.08 1822.04,1405.08 1822.04,1405.08 1822.05,1405.08 1822.05,1405.08 1822.06,1405.08 1822.06,1405.08 1822.06,1405.08 1822.07,1405.08 1822.07,1405.08 1822.08,1405.08 1822.08,1405.08 1822.09,1405.08 1822.09,1405.08 1822.1,1405.08 1822.1,1405.08 1822.1,1405.08 1822.11,1405.08 1822.11,1405.08 1822.12,1405.08 1822.12,1405.08 1822.13,1405.08 1822.13,1405.08 1822.14,1405.08 1822.14,1405.08 1822.14,1405.08 1822.15,1405.08 1822.15,1405.08 1822.16,1405.08 1822.16,1405.08 1822.17,1405.08 1822.17,1405.08 1822.18,1405.08 1822.18,1405.08 1822.18,1405.08 1822.19,1405.08 1822.19,1405.08 1822.2,1405.08 1822.2,1405.08 1822.21,1405.08 1822.21,1405.08 1822.22,1405.08 1822.22,1405.08 1822.22,1405.08 1822.23,1405.08 1822.23,1405.08 1822.24,1405.07 1822.24,1405.07 1822.25,1405.07 1822.25,1405.07 1822.25,1405.07 1822.26,1405.07 1822.26,1405.07 1822.27,1405.07 1822.27,1405.07 1822.28,1405.07 1822.28,1405.07 1822.29,1405.07 1822.29,1405.07 1822.29,1405.07 1822.3,1405.07 1822.3,1405.07 1822.31,1405.07 1822.31,1405.07 1822.32,1405.07 1822.32,1405.07 1822.33,1405.07 1822.33,1405.07 1822.33,1405.07 1822.34,1405.07 1822.34,1405.07 1822.35,1405.07 1822.35,1405.07 1822.36,1405.07 1822.36,1405.07 1822.37,1405.07 1822.37,1405.07 1822.37,1405.07 1822.38,1405.07 1822.38,1405.07 1822.39,1405.07 1822.39,1405.07 1822.4,1405.07 1822.4,1405.07 1822.4,1405.07 1822.41,1405.07 1822.41,1405.07 1822.42,1405.07 1822.42,1405.07 1822.43,1405.07 1822.43,1405.07 1822.44,1405.07 1822.44,1405.07 1822.44,1405.07 1822.45,1405.07 1822.45,1405.07 1822.46,1405.07 1822.46,1405.07 1822.47,1405.07 1822.47,1405.07 1822.48,1405.07 1822.48,1405.07 1822.48,1405.07 1822.49,1405.07 1822.49,1405.07 1822.5,1405.07 1822.5,1405.07 1822.51,1405.07 1822.51,1405.07 1822.51,1405.07 1822.52,1405.07 1822.52,1405.07 1822.53,1405.07 1822.53,1405.07 1822.54,1405.07 1822.54,1405.07 1822.55,1405.07 1822.55,1405.07 1822.55,1405.07 1822.56,1405.07 1822.56,1405.07 1822.57,1405.07 1822.57,1405.07 1822.58,1405.07 1822.58,1405.07 1822.59,1405.07 1822.59,1405.07 1822.59,1405.07 1822.6,1405.07 1822.6,1405.07 1822.61,1405.07 1822.61,1405.07 1822.62,1405.07 1822.62,1405.07 1822.62,1405.07 1822.63,1405.07 1822.63,1405.07 1822.64,1405.07 1822.64,1405.07 1822.65,1405.07 1822.65,1405.06 1822.66,1405.06 1822.66,1405.06 1822.66,1405.06 1822.67,1405.06 1822.67,1405.06 1822.68,1405.06 1822.68,1405.06 1822.69,1405.06 1822.69,1405.06 1822.7,1405.06 1822.7,1405.06 1822.7,1405.06 1822.71,1405.06 1822.71,1405.06 1822.72,1405.06 1822.72,1405.06 1822.73,1405.06 1822.73,1405.06 1822.73,1405.06 1822.74,1405.06 1822.74,1405.06 1822.75,1405.06 1822.75,1405.06 1822.76,1405.06 1822.76,1405.06 1822.77,1405.06 1822.77,1405.06 1822.77,1405.06 1822.78,1405.06 1822.78,1405.06 1822.79,1405.06 1822.79,1405.06 1822.8,1405.06 1822.8,1405.06 1822.8,1405.06 1822.81,1405.06 1822.81,1405.06 1822.82,1405.06 1822.82,1405.06 1822.83,1405.06 1822.83,1405.06 1822.84,1405.06 1822.84,1405.06 1822.84,1405.06 1822.85,1405.06 1822.85,1405.06 1822.86,1405.06 1822.86,1405.06 1822.87,1405.06 1822.87,1405.06 1822.87,1405.06 1822.88,1405.06 1822.88,1405.06 1822.89,1405.06 1822.89,1405.06 1822.9,1405.06 1822.9,1405.06 1822.91,1405.06 1822.91,1405.06 1822.91,1405.06 1822.92,1405.06 1822.92,1405.06 1822.93,1405.06 1822.93,1405.06 1822.94,1405.06 1822.94,1405.06 1822.94,1405.06 1822.95,1405.06 1822.95,1405.06 1822.96,1405.06 1822.96,1405.06 1822.97,1405.06 1822.97,1405.06 1822.98,1405.06 1822.98,1405.06 1822.98,1405.06 1822.99,1405.06 1822.99,1405.06 1823,1405.06 1823,1405.06 1823.01,1405.06 1823.01,1405.06 1823.01,1405.06 1823.02,1405.06 1823.02,1405.06 1823.03,1405.06 1823.03,1405.06 1823.04,1405.06 1823.04,1405.06 1823.05,1405.06 1823.05,1405.06 1823.05,1405.06 1823.06,1405.06 1823.06,1405.05 1823.07,1405.05 1823.07,1405.05 1823.08,1405.05 1823.08,1405.05 1823.08,1405.05 1823.09,1405.05 1823.09,1405.05 1823.1,1405.05 1823.1,1405.05 1823.11,1405.05 1823.11,1405.05 1823.12,1405.05 1823.12,1405.05 1823.12,1405.05 1823.13,1405.05 1823.13,1405.05 1823.14,1405.05 1823.14,1405.05 1823.15,1405.05 1823.15,1405.05 1823.15,1405.05 1823.16,1405.05 1823.16,1405.05 1823.17,1405.05 1823.17,1405.05 1823.18,1405.05 1823.18,1405.05 1823.18,1405.05 1823.19,1405.05 1823.19,1405.05 1823.2,1405.05 1823.2,1405.05 1823.21,1405.05 1823.21,1405.05 1823.22,1405.05 1823.22,1405.05 1823.22,1405.05 1823.23,1405.05 1823.23,1405.05 1823.24,1405.05 1823.24,1405.05 1823.25,1405.05 1823.25,1405.05 1823.25,1405.05 1823.26,1405.05 1823.26,1405.05 1823.27,1405.05 1823.27,1405.05 1823.28,1405.05 1823.28,1405.05 1823.29,1405.05 1823.29,1405.05 1823.29,1405.05 1823.3,1405.05 1823.3,1405.05 1823.31,1405.05 1823.31,1405.05 1823.32,1405.05 1823.32,1405.05 1823.32,1405.05 1823.33,1405.05 1823.33,1405.05 1823.34,1405.05 1823.34,1405.05 1823.35,1405.05 1823.35,1405.05 1823.35,1405.05 1823.36,1405.05 1823.36,1405.05 1823.37,1405.05 1823.37,1405.05 1823.38,1405.05 1823.38,1405.05 1823.39,1405.05 1823.39,1405.05 1823.39,1405.05 1823.4,1405.05 1823.4,1405.05 1823.41,1405.05 1823.41,1405.05 1823.42,1405.05 1823.42,1405.05 1823.42,1405.05 1823.43,1405.05 1823.43,1405.05 1823.44,1405.05 1823.44,1405.05 1823.45,1405.05 1823.45,1405.05 1823.45,1405.05 1823.46,1405.05 1823.46,1405.05 1823.47,1405.05 1823.47,1405.05 1823.48,1405.04 1823.48,1405.04 1823.49,1405.04 1823.49,1405.04 1823.49,1405.04 1823.5,1405.04 1823.5,1405.04 1823.51,1405.04 1823.51,1405.04 1823.52,1405.04 1823.52,1405.04 1823.52,1405.04 1823.53,1405.04 1823.53,1405.04 1823.54,1405.04 1823.54,1405.04 1823.55,1405.04 1823.55,1405.04 1823.55,1405.04 1823.56,1405.04 1823.56,1405.04 1823.57,1405.04 1823.57,1405.04 1823.58,1405.04 1823.58,1405.04 1823.58,1405.04 1823.59,1405.04 1823.59,1405.04 1823.6,1405.04 1823.6,1405.04 1823.61,1405.04 1823.61,1405.04 1823.62,1405.04 1823.62,1405.04 1823.62,1405.04 1823.63,1405.04 1823.63,1405.04 1823.64,1405.04 1823.64,1405.04 1823.65,1405.04 1823.65,1405.04 1823.65,1405.04 1823.66,1405.04 1823.66,1405.04 1823.67,1405.04 1823.67,1405.04 1823.68,1405.04 1823.68,1405.04 1823.68,1405.04 1823.69,1405.04 1823.69,1405.04 1823.7,1405.04 1823.7,1405.04 1823.71,1405.04 1823.71,1405.04 1823.71,1405.04 1823.72,1405.04 1823.72,1405.04 1823.73,1405.04 1823.73,1405.04 1823.74,1405.04 1823.74,1405.04 1823.74,1405.04 1823.75,1405.04 1823.75,1405.04 1823.76,1405.04 1823.76,1405.04 1823.77,1405.04 1823.77,1405.04 1823.78,1405.04 1823.78,1405.04 1823.78,1405.04 1823.79,1405.04 1823.79,1405.04 1823.8,1405.04 1823.8,1405.04 1823.81,1405.04 1823.81,1405.04 1823.81,1405.04 1823.82,1405.04 1823.82,1405.04 1823.83,1405.04 1823.83,1405.04 1823.84,1405.04 1823.84,1405.04 1823.84,1405.04 1823.85,1405.04 1823.85,1405.04 1823.86,1405.04 1823.86,1405.04 1823.87,1405.04 1823.87,1405.04 1823.87,1405.04 1823.88,1405.04 1823.88,1405.04 1823.89,1405.04 1823.89,1405.03 1823.9,1405.03 1823.9,1405.03 1823.9,1405.03 1823.91,1405.03 1823.91,1405.03 1823.92,1405.03 1823.92,1405.03 1823.93,1405.03 1823.93,1405.03 1823.93,1405.03 1823.94,1405.03 1823.94,1405.03 1823.95,1405.03 1823.95,1405.03 1823.96,1405.03 1823.96,1405.03 1823.96,1405.03 1823.97,1405.03 1823.97,1405.03 1823.98,1405.03 1823.98,1405.03 1823.99,1405.03 1823.99,1405.03 1824,1405.03 1824,1405.03 1824,1405.03 1824.01,1405.03 1824.01,1405.03 1824.02,1405.03 1824.02,1405.03 1824.03,1405.03 1824.03,1405.03 1824.03,1405.03 1824.04,1405.03 1824.04,1405.03 1824.05,1405.03 1824.05,1405.03 1824.06,1405.03 1824.06,1405.03 1824.06,1405.03 1824.07,1405.03 1824.07,1405.03 1824.08,1405.03 1824.08,1405.03 1824.09,1405.03 1824.09,1405.03 1824.09,1405.03 1824.1,1405.03 1824.1,1405.03 1824.11,1405.03 1824.11,1405.03 1824.12,1405.03 1824.12,1405.03 1824.12,1405.03 1824.13,1405.03 1824.13,1405.03 1824.14,1405.03 1824.14,1405.03 1824.15,1405.03 1824.15,1405.03 1824.15,1405.03 1824.16,1405.03 1824.16,1405.03 1824.17,1405.03 1824.17,1405.03 1824.18,1405.03 1824.18,1405.03 1824.18,1405.03 1824.19,1405.03 1824.19,1405.03 1824.2,1405.03 1824.2,1405.03 1824.21,1405.03 1824.21,1405.03 1824.21,1405.03 1824.22,1405.03 1824.22,1405.03 1824.23,1405.03 1824.23,1405.03 1824.24,1405.03 1824.24,1405.03 1824.24,1405.03 1824.25,1405.03 1824.25,1405.03 1824.26,1405.03 1824.26,1405.03 1824.27,1405.03 1824.27,1405.03 1824.27,1405.03 1824.28,1405.03 1824.28,1405.03 1824.29,1405.03 1824.29,1405.03 1824.3,1405.03 1824.3,1405.02 1824.3,1405.02 1824.31,1405.02 1824.31,1405.02 1824.32,1405.02 1824.32,1405.02 1824.33,1405.02 1824.33,1405.02 1824.33,1405.02 1824.34,1405.02 1824.34,1405.02 1824.35,1405.02 1824.35,1405.02 1824.36,1405.02 1824.36,1405.02 1824.36,1405.02 1824.37,1405.02 1824.37,1405.02 1824.38,1405.02 1824.38,1405.02 1824.39,1405.02 1824.39,1405.02 1824.39,1405.02 1824.4,1405.02 1824.4,1405.02 1824.41,1405.02 1824.41,1405.02 1824.42,1405.02 1824.42,1405.02 1824.42,1405.02 1824.43,1405.02 1824.43,1405.02 1824.44,1405.02 1824.44,1405.02 1824.45,1405.02 1824.45,1405.02 1824.45,1405.02 1824.46,1405.02 1824.46,1405.02 1824.47,1405.02 1824.47,1405.02 1824.48,1405.02 1824.48,1405.02 1824.48,1405.02 1824.49,1405.02 1824.49,1405.02 1824.5,1405.02 1824.5,1405.02 1824.51,1405.02 1824.51,1405.02 1824.51,1405.02 1824.52,1405.02 1824.52,1405.02 1824.53,1405.02 1824.53,1405.02 1824.54,1405.02 1824.54,1405.02 1824.54,1405.02 1824.55,1405.02 1824.55,1405.02 1824.56,1405.02 1824.56,1405.02 1824.57,1405.02 1824.57,1405.02 1824.57,1405.02 1824.58,1405.02 1824.58,1405.02 1824.59,1405.02 1824.59,1405.02 1824.6,1405.02 1824.6,1405.02 1824.6,1405.02 1824.61,1405.02 1824.61,1405.02 1824.62,1405.02 1824.62,1405.02 1824.63,1405.02 1824.63,1405.02 1824.63,1405.02 1824.64,1405.02 1824.64,1405.02 1824.65,1405.02 1824.65,1405.02 1824.66,1405.02 1824.66,1405.02 1824.66,1405.02 1824.67,1405.02 1824.67,1405.02 1824.68,1405.02 1824.68,1405.02 1824.69,1405.02 1824.69,1405.02 1824.69,1405.02 1824.7,1405.02 1824.7,1405.02 1824.71,1405.02 1824.71,1405.02 1824.71,1405.01 1824.72,1405.01 1824.72,1405.01 1824.73,1405.01 1824.73,1405.01 1824.74,1405.01 1824.74,1405.01 1824.74,1405.01 1824.75,1405.01 1824.75,1405.01 1824.76,1405.01 1824.76,1405.01 1824.77,1405.01 1824.77,1405.01 1824.77,1405.01 1824.78,1405.01 1824.78,1405.01 1824.79,1405.01 1824.79,1405.01 1824.8,1405.01 1824.8,1405.01 1824.8,1405.01 1824.81,1405.01 1824.81,1405.01 1824.82,1405.01 1824.82,1405.01 1824.83,1405.01 1824.83,1405.01 1824.83,1405.01 1824.84,1405.01 1824.84,1405.01 1824.85,1405.01 1824.85,1405.01 1824.86,1405.01 1824.86,1405.01 1824.86,1405.01 1824.87,1405.01 1824.87,1405.01 1824.88,1405.01 1824.88,1405.01 1824.89,1405.01 1824.89,1405.01 1824.89,1405.01 1824.9,1405.01 1824.9,1405.01 1824.91,1405.01 1824.91,1405.01 1824.92,1405.01 1824.92,1405.01 1824.92,1405.01 1824.93,1405.01 1824.93,1405.01 1824.94,1405.01 1824.94,1405.01 1824.94,1405.01 1824.95,1405.01 1824.95,1405.01 1824.96,1405.01 1824.96,1405.01 1824.97,1405.01 1824.97,1405.01 1824.97,1405.01 1824.98,1405.01 1824.98,1405.01 1824.99,1405.01 1824.99,1405.01 1825,1405.01 1825,1405.01 1825,1405.01 1825.01,1405.01 1825.01,1405.01 1825.02,1405.01 1825.02,1405.01 1825.03,1405.01 1825.03,1405.01 1825.03,1405.01 1825.04,1405.01 1825.04,1405.01 1825.05,1405.01 1825.05,1405.01 1825.06,1405.01 1825.06,1405.01 1825.06,1405.01 1825.07,1405.01 1825.07,1405.01 1825.08,1405.01 1825.08,1405.01 1825.08,1405.01 1825.09,1405.01 1825.09,1405.01 1825.1,1405.01 1825.1,1405.01 1825.11,1405.01 1825.11,1405.01 1825.11,1405.01 1825.12,1405.01 1825.12,1405 1825.13,1405 1825.13,1405 1825.14,1405 1825.14,1405 1825.14,1405 1825.15,1405 1825.15,1405 1825.16,1405 1825.16,1405 1825.17,1405 1825.17,1405 1825.17,1405 1825.18,1405 1825.18,1405 1825.19,1405 1825.19,1405 1825.19,1405 1825.2,1405 1825.2,1405 1825.21,1405 1825.21,1405 1825.22,1405 1825.22,1405 1825.22,1405 1825.23,1405 1825.23,1405 1825.24,1405 1825.24,1405 1825.25,1405 1825.25,1405 1825.25,1405 1825.26,1405 1825.26,1405 1825.27,1405 1825.27,1405 1825.28,1405 1825.28,1405 1825.28,1405 1825.29,1405 1825.29,1405 1825.3,1405 1825.3,1405 1825.3,1405 1825.31,1405 1825.31,1405 1825.32,1405 1825.32,1405 1825.33,1405 1825.33,1405 1825.33,1405 1825.34,1405 1825.34,1405 1825.35,1405 1825.35,1405 1825.36,1405 1825.36,1405 1825.36,1405 1825.37,1405 1825.37,1405 1825.38,1405 1825.38,1405 1825.39,1405 1825.39,1405 1825.39,1405 1825.4,1405 1825.4,1405 1825.41,1405 1825.41,1405 1825.41,1405 1825.42,1405 1825.42,1405 1825.43,1405 1825.43,1405 1825.44,1405 1825.44,1405 1825.44,1405 1825.45,1405 1825.45,1405 1825.46,1405 1825.46,1405 1825.47,1405 1825.47,1405 1825.47,1405 1825.48,1405 1825.48,1405 1825.49,1405 1825.49,1405 1825.49,1405 1825.5,1405 1825.5,1405 1825.51,1405 1825.51,1405 1825.52,1405 1825.52,1405 1825.52,1405 1825.53,1405 1825.53,1405 1825.54,1404.99 1825.54,1404.99 1825.55,1404.99 1825.55,1404.99 1825.55,1404.99 1825.56,1404.99 1825.56,1404.99 1825.57,1404.99 1825.57,1404.99 1825.57,1404.99 1825.58,1404.99 1825.58,1404.99 1825.59,1404.99 1825.59,1404.99 1825.6,1404.99 1825.6,1404.99 1825.6,1404.99 1825.61,1404.99 1825.61,1404.99 1825.62,1404.99 1825.62,1404.99 1825.63,1404.99 1825.63,1404.99 1825.63,1404.99 1825.64,1404.99 1825.64,1404.99 1825.65,1404.99 1825.65,1404.99 1825.65,1404.99 1825.66,1404.99 1825.66,1404.99 1825.67,1404.99 1825.67,1404.99 1825.68,1404.99 1825.68,1404.99 1825.68,1404.99 1825.69,1404.99 1825.69,1404.99 1825.7,1404.99 1825.7,1404.99 1825.71,1404.99 1825.71,1404.99 1825.71,1404.99 1825.72,1404.99 1825.72,1404.99 1825.73,1404.99 1825.73,1404.99 1825.73,1404.99 1825.74,1404.99 1825.74,1404.99 1825.75,1404.99 1825.75,1404.99 1825.76,1404.99 1825.76,1404.99 1825.76,1404.99 1825.77,1404.99 1825.77,1404.99 1825.78,1404.99 1825.78,1404.99 1825.79,1404.99 1825.79,1404.99 1825.79,1404.99 1825.8,1404.99 1825.8,1404.99 1825.81,1404.99 1825.81,1404.99 1825.81,1404.99 1825.82,1404.99 1825.82,1404.99 1825.83,1404.99 1825.83,1404.99 1825.84,1404.99 1825.84,1404.99 1825.84,1404.99 1825.85,1404.99 1825.85,1404.99 1825.86,1404.99 1825.86,1404.99 1825.86,1404.99 1825.87,1404.99 1825.87,1404.99 1825.88,1404.99 1825.88,1404.99 1825.89,1404.99 1825.89,1404.99 1825.89,1404.99 1825.9,1404.99 1825.9,1404.99 1825.91,1404.99 1825.91,1404.99 1825.92,1404.99 1825.92,1404.99 1825.92,1404.99 1825.93,1404.99 1825.93,1404.99 1825.94,1404.99 1825.94,1404.99 1825.94,1404.98 1825.95,1404.98 1825.95,1404.98 1825.96,1404.98 1825.96,1404.98 1825.97,1404.98 1825.97,1404.98 1825.97,1404.98 1825.98,1404.98 1825.98,1404.98 1825.99,1404.98 1825.99,1404.98 1825.99,1404.98 1826,1404.98 1826,1404.98 1826.01,1404.98 1826.01,1404.98 1826.02,1404.98 1826.02,1404.98 1826.02,1404.98 1826.03,1404.98 1826.03,1404.98 1826.04,1404.98 1826.04,1404.98 1826.04,1404.98 1826.05,1404.98 1826.05,1404.98 1826.06,1404.98 1826.06,1404.98 1826.07,1404.98 1826.07,1404.98 1826.07,1404.98 1826.08,1404.98 1826.08,1404.98 1826.09,1404.98 1826.09,1404.98 1826.1,1404.98 1826.1,1404.98 1826.1,1404.98 1826.11,1404.98 1826.11,1404.98 1826.12,1404.98 1826.12,1404.98 1826.12,1404.98 1826.13,1404.98 1826.13,1404.98 1826.14,1404.98 1826.14,1404.98 1826.15,1404.98 1826.15,1404.98 1826.15,1404.98 1826.16,1404.98 1826.16,1404.98 1826.17,1404.98 1826.17,1404.98 1826.17,1404.98 1826.18,1404.98 1826.18,1404.98 1826.19,1404.98 1826.19,1404.98 1826.2,1404.98 1826.2,1404.98 1826.2,1404.98 1826.21,1404.98 1826.21,1404.98 1826.22,1404.98 1826.22,1404.98 1826.22,1404.98 1826.23,1404.98 1826.23,1404.98 1826.24,1404.98 1826.24,1404.98 1826.25,1404.98 1826.25,1404.98 1826.25,1404.98 1826.26,1404.98 1826.26,1404.98 1826.27,1404.98 1826.27,1404.98 1826.27,1404.98 1826.28,1404.98 1826.28,1404.98 1826.29,1404.98 1826.29,1404.98 1826.3,1404.98 1826.3,1404.98 1826.3,1404.98 1826.31,1404.98 1826.31,1404.98 1826.32,1404.98 1826.32,1404.98 1826.32,1404.98 1826.33,1404.98 1826.33,1404.98 1826.34,1404.98 1826.34,1404.98 1826.35,1404.98 1826.35,1404.98 1826.35,1404.97 1826.36,1404.97 1826.36,1404.97 1826.37,1404.97 1826.37,1404.97 1826.37,1404.97 1826.38,1404.97 1826.38,1404.97 1826.39,1404.97 1826.39,1404.97 1826.4,1404.97 1826.4,1404.97 1826.4,1404.97 1826.41,1404.97 1826.41,1404.97 1826.42,1404.97 1826.42,1404.97 1826.42,1404.97 1826.43,1404.97 1826.43,1404.97 1826.44,1404.97 1826.44,1404.97 1826.45,1404.97 1826.45,1404.97 1826.45,1404.97 1826.46,1404.97 1826.46,1404.97 1826.47,1404.97 1826.47,1404.97 1826.47,1404.97 1826.48,1404.97 1826.48,1404.97 1826.49,1404.97 1826.49,1404.97 1826.5,1404.97 1826.5,1404.97 1826.5,1404.97 1826.51,1404.97 1826.51,1404.97 1826.52,1404.97 1826.52,1404.97 1826.52,1404.97 1826.53,1404.97 1826.53,1404.97 1826.54,1404.97 1826.54,1404.97 1826.55,1404.97 1826.55,1404.97 1826.55,1404.97 1826.56,1404.97 1826.56,1404.97 1826.57,1404.97 1826.57,1404.97 1826.57,1404.97 1826.58,1404.97 1826.58,1404.97 1826.59,1404.97 1826.59,1404.97 1826.59,1404.97 1826.6,1404.97 1826.6,1404.97 1826.61,1404.97 1826.61,1404.97 1826.62,1404.97 1826.62,1404.97 1826.62,1404.97 1826.63,1404.97 1826.63,1404.97 1826.64,1404.97 1826.64,1404.97 1826.64,1404.97 1826.65,1404.97 1826.65,1404.97 1826.66,1404.97 1826.66,1404.97 1826.67,1404.97 1826.67,1404.97 1826.67,1404.97 1826.68,1404.97 1826.68,1404.97 1826.69,1404.97 1826.69,1404.97 1826.69,1404.97 1826.7,1404.97 1826.7,1404.97 1826.71,1404.97 1826.71,1404.97 1826.72,1404.97 1826.72,1404.97 1826.72,1404.97 1826.73,1404.97 1826.73,1404.97 1826.74,1404.97 1826.74,1404.97 1826.74,1404.97 1826.75,1404.97 1826.75,1404.97 1826.76,1404.97 1826.76,1404.97 1826.76,1404.96 1826.77,1404.96 1826.77,1404.96 1826.78,1404.96 1826.78,1404.96 1826.79,1404.96 1826.79,1404.96 1826.79,1404.96 1826.8,1404.96 1826.8,1404.96 1826.81,1404.96 1826.81,1404.96 1826.81,1404.96 1826.82,1404.96 1826.82,1404.96 1826.83,1404.96 1826.83,1404.96 1826.84,1404.96 1826.84,1404.96 1826.84,1404.96 1826.85,1404.96 1826.85,1404.96 1826.86,1404.96 1826.86,1404.96 1826.86,1404.96 1826.87,1404.96 1826.87,1404.96 1826.88,1404.96 1826.88,1404.96 1826.88,1404.96 1826.89,1404.96 1826.89,1404.96 1826.9,1404.96 1826.9,1404.96 1826.91,1404.96 1826.91,1404.96 1826.91,1404.96 1826.92,1404.96 1826.92,1404.96 1826.93,1404.96 1826.93,1404.96 1826.93,1404.96 1826.94,1404.96 1826.94,1404.96 1826.95,1404.96 1826.95,1404.96 1826.95,1404.96 1826.96,1404.96 1826.96,1404.96 1826.97,1404.96 1826.97,1404.96 1826.98,1404.96 1826.98,1404.96 1826.98,1404.96 1826.99,1404.96 1826.99,1404.96 1827,1404.96 1827,1404.96 1827,1404.96 1827.01,1404.96 1827.01,1404.96 1827.02,1404.96 1827.02,1404.96 1827.03,1404.96 1827.03,1404.96 1827.03,1404.96 1827.04,1404.96 1827.04,1404.96 1827.05,1404.96 1827.05,1404.96 1827.05,1404.96 1827.06,1404.96 1827.06,1404.96 1827.07,1404.96 1827.07,1404.96 1827.07,1404.96 1827.08,1404.96 1827.08,1404.96 1827.09,1404.96 1827.09,1404.96 1827.1,1404.96 1827.1,1404.96 1827.1,1404.96 1827.11,1404.96 1827.11,1404.96 1827.12,1404.96 1827.12,1404.96 1827.12,1404.96 1827.13,1404.96 1827.13,1404.96 1827.14,1404.96 1827.14,1404.96 1827.14,1404.96 1827.15,1404.96 1827.15,1404.96 1827.16,1404.96 1827.16,1404.96 1827.17,1404.96 1827.17,1404.96 1827.17,1404.95 1827.18,1404.95 1827.18,1404.95 1827.19,1404.95 1827.19,1404.95 1827.19,1404.95 1827.2,1404.95 1827.2,1404.95 1827.21,1404.95 1827.21,1404.95 1827.21,1404.95 1827.22,1404.95 1827.22,1404.95 1827.23,1404.95 1827.23,1404.95 1827.24,1404.95 1827.24,1404.95 1827.24,1404.95 1827.25,1404.95 1827.25,1404.95 1827.26,1404.95 1827.26,1404.95 1827.26,1404.95 1827.27,1404.95 1827.27,1404.95 1827.28,1404.95 1827.28,1404.95 1827.28,1404.95 1827.29,1404.95 1827.29,1404.95 1827.3,1404.95 1827.3,1404.95 1827.31,1404.95 1827.31,1404.95 1827.31,1404.95 1827.32,1404.95 1827.32,1404.95 1827.33,1404.95 1827.33,1404.95 1827.33,1404.95 1827.34,1404.95 1827.34,1404.95 1827.35,1404.95 1827.35,1404.95 1827.35,1404.95 1827.36,1404.95 1827.36,1404.95 1827.37,1404.95 1827.37,1404.95 1827.37,1404.95 1827.38,1404.95 1827.38,1404.95 1827.39,1404.95 1827.39,1404.95 1827.4,1404.95 1827.4,1404.95 1827.4,1404.95 1827.41,1404.95 1827.41,1404.95 1827.42,1404.95 1827.42,1404.95 1827.42,1404.95 1827.43,1404.95 1827.43,1404.95 1827.44,1404.95 1827.44,1404.95 1827.44,1404.95 1827.45,1404.95 1827.45,1404.95 1827.46,1404.95 1827.46,1404.95 1827.47,1404.95 1827.47,1404.95 1827.47,1404.95 1827.48,1404.95 1827.48,1404.95 1827.49,1404.95 1827.49,1404.95 1827.49,1404.95 1827.5,1404.95 1827.5,1404.95 1827.51,1404.95 1827.51,1404.95 1827.51,1404.95 1827.52,1404.95 1827.52,1404.95 1827.53,1404.95 1827.53,1404.95 1827.53,1404.95 1827.54,1404.95 1827.54,1404.95 1827.55,1404.95 1827.55,1404.95 1827.56,1404.95 1827.56,1404.95 1827.56,1404.95 1827.57,1404.95 1827.57,1404.95 1827.58,1404.95 1827.58,1404.94 1827.58,1404.94 1827.59,1404.94 1827.59,1404.94 1827.6,1404.94 1827.6,1404.94 1827.6,1404.94 1827.61,1404.94 1827.61,1404.94 1827.62,1404.94 1827.62,1404.94 1827.62,1404.94 1827.63,1404.94 1827.63,1404.94 1827.64,1404.94 1827.64,1404.94 1827.65,1404.94 1827.65,1404.94 1827.65,1404.94 1827.66,1404.94 1827.66,1404.94 1827.67,1404.94 1827.67,1404.94 1827.67,1404.94 1827.68,1404.94 1827.68,1404.94 1827.69,1404.94 1827.69,1404.94 1827.69,1404.94 1827.7,1404.94 1827.7,1404.94 1827.71,1404.94 1827.71,1404.94 1827.71,1404.94 1827.72,1404.94 1827.72,1404.94 1827.73,1404.94 1827.73,1404.94 1827.74,1404.94 1827.74,1404.94 1827.74,1404.94 1827.75,1404.94 1827.75,1404.94 1827.76,1404.94 1827.76,1404.94 1827.76,1404.94 1827.77,1404.94 1827.77,1404.94 1827.78,1404.94 1827.78,1404.94 1827.78,1404.94 1827.79,1404.94 1827.79,1404.94 1827.8,1404.94 1827.8,1404.94 1827.8,1404.94 1827.81,1404.94 1827.81,1404.94 1827.82,1404.94 1827.82,1404.94 1827.82,1404.94 1827.83,1404.94 1827.83,1404.94 1827.84,1404.94 1827.84,1404.94 1827.85,1404.94 1827.85,1404.94 1827.85,1404.94 1827.86,1404.94 1827.86,1404.94 1827.87,1404.94 1827.87,1404.94 1827.87,1404.94 1827.88,1404.94 1827.88,1404.94 1827.89,1404.94 1827.89,1404.94 1827.89,1404.94 1827.9,1404.94 1827.9,1404.94 1827.91,1404.94 1827.91,1404.94 1827.91,1404.94 1827.92,1404.94 1827.92,1404.94 1827.93,1404.94 1827.93,1404.94 1827.93,1404.94 1827.94,1404.94 1827.94,1404.94 1827.95,1404.94 1827.95,1404.94 1827.96,1404.94 1827.96,1404.94 1827.96,1404.94 1827.97,1404.94 1827.97,1404.94 1827.98,1404.94 1827.98,1404.94 1827.98,1404.94 1827.99,1404.93 1827.99,1404.93 1828,1404.93 1828,1404.93 1828,1404.93 1828.01,1404.93 1828.01,1404.93 1828.02,1404.93 1828.02,1404.93 1828.02,1404.93 1828.03,1404.93 1828.03,1404.93 1828.04,1404.93 1828.04,1404.93 1828.04,1404.93 1828.05,1404.93 1828.05,1404.93 1828.06,1404.93 1828.06,1404.93 1828.07,1404.93 1828.07,1404.93 1828.07,1404.93 1828.08,1404.93 1828.08,1404.93 1828.09,1404.93 1828.09,1404.93 1828.09,1404.93 1828.1,1404.93 1828.1,1404.93 1828.11,1404.93 1828.11,1404.93 1828.11,1404.93 1828.12,1404.93 1828.12,1404.93 1828.13,1404.93 1828.13,1404.93 1828.13,1404.93 1828.14,1404.93 1828.14,1404.93 1828.15,1404.93 1828.15,1404.93 1828.15,1404.93 1828.16,1404.93 1828.16,1404.93 1828.17,1404.93 1828.17,1404.93 1828.17,1404.93 1828.18,1404.93 1828.18,1404.93 1828.19,1404.93 1828.19,1404.93 1828.2,1404.93 1828.2,1404.93 1828.2,1404.93 1828.21,1404.93 1828.21,1404.93 1828.22,1404.93 1828.22,1404.93 1828.22,1404.93 1828.23,1404.93 1828.23,1404.93 1828.24,1404.93 1828.24,1404.93 1828.24,1404.93 1828.25,1404.93 1828.25,1404.93 1828.26,1404.93 1828.26,1404.93 1828.26,1404.93 1828.27,1404.93 1828.27,1404.93 1828.28,1404.93 1828.28,1404.93 1828.28,1404.93 1828.29,1404.93 1828.29,1404.93 1828.3,1404.93 1828.3,1404.93 1828.3,1404.93 1828.31,1404.93 1828.31,1404.93 1828.32,1404.93 1828.32,1404.93 1828.32,1404.93 1828.33,1404.93 1828.33,1404.93 1828.34,1404.93 1828.34,1404.93 1828.35,1404.93 1828.35,1404.93 1828.35,1404.93 1828.36,1404.93 1828.36,1404.93 1828.37,1404.93 1828.37,1404.93 1828.37,1404.93 1828.38,1404.93 1828.38,1404.93 1828.39,1404.93 1828.39,1404.93 1828.39,1404.93 1828.4,1404.92 1828.4,1404.92 1828.41,1404.92 1828.41,1404.92 1828.41,1404.92 1828.42,1404.92 1828.42,1404.92 1828.43,1404.92 1828.43,1404.92 1828.43,1404.92 1828.44,1404.92 1828.44,1404.92 1828.45,1404.92 1828.45,1404.92 1828.45,1404.92 1828.46,1404.92 1828.46,1404.92 1828.47,1404.92 1828.47,1404.92 1828.47,1404.92 1828.48,1404.92 1828.48,1404.92 1828.49,1404.92 1828.49,1404.92 1828.49,1404.92 1828.5,1404.92 1828.5,1404.92 1828.51,1404.92 1828.51,1404.92 1828.51,1404.92 1828.52,1404.92 1828.52,1404.92 1828.53,1404.92 1828.53,1404.92 1828.54,1404.92 1828.54,1404.92 1828.54,1404.92 1828.55,1404.92 1828.55,1404.92 1828.56,1404.92 1828.56,1404.92 1828.56,1404.92 1828.57,1404.92 1828.57,1404.92 1828.58,1404.92 1828.58,1404.92 1828.58,1404.92 1828.59,1404.92 1828.59,1404.92 1828.6,1404.92 1828.6,1404.92 1828.6,1404.92 1828.61,1404.92 1828.61,1404.92 1828.62,1404.92 1828.62,1404.92 1828.62,1404.92 1828.63,1404.92 1828.63,1404.92 1828.64,1404.92 1828.64,1404.92 1828.64,1404.92 1828.65,1404.92 1828.65,1404.92 1828.66,1404.92 1828.66,1404.92 1828.66,1404.92 1828.67,1404.92 1828.67,1404.92 1828.68,1404.92 1828.68,1404.92 1828.68,1404.92 1828.69,1404.92 1828.69,1404.92 1828.7,1404.92 1828.7,1404.92 1828.7,1404.92 1828.71,1404.92 1828.71,1404.92 1828.72,1404.92 1828.72,1404.92 1828.72,1404.92 1828.73,1404.92 1828.73,1404.92 1828.74,1404.92 1828.74,1404.92 1828.74,1404.92 1828.75,1404.92 1828.75,1404.92 1828.76,1404.92 1828.76,1404.92 1828.76,1404.92 1828.77,1404.92 1828.77,1404.92 1828.78,1404.92 1828.78,1404.92 1828.79,1404.92 1828.79,1404.92 1828.79,1404.92 1828.8,1404.92 1828.8,1404.92 1828.81,1404.91 1828.81,1404.91 1828.81,1404.91 1828.82,1404.91 1828.82,1404.91 1828.83,1404.91 1828.83,1404.91 1828.83,1404.91 1828.84,1404.91 1828.84,1404.91 1828.85,1404.91 1828.85,1404.91 1828.85,1404.91 1828.86,1404.91 1828.86,1404.91 1828.87,1404.91 1828.87,1404.91 1828.87,1404.91 1828.88,1404.91 1828.88,1404.91 1828.89,1404.91 1828.89,1404.91 1828.89,1404.91 1828.9,1404.91 1828.9,1404.91 1828.91,1404.91 1828.91,1404.91 1828.91,1404.91 1828.92,1404.91 1828.92,1404.91 1828.93,1404.91 1828.93,1404.91 1828.93,1404.91 1828.94,1404.91 1828.94,1404.91 1828.95,1404.91 1828.95,1404.91 1828.95,1404.91 1828.96,1404.91 1828.96,1404.91 1828.97,1404.91 1828.97,1404.91 1828.97,1404.91 1828.98,1404.91 1828.98,1404.91 1828.99,1404.91 1828.99,1404.91 1828.99,1404.91 1829,1404.91 1829,1404.91 1829.01,1404.91 1829.01,1404.91 1829.01,1404.91 1829.02,1404.91 1829.02,1404.91 1829.03,1404.91 1829.03,1404.91 1829.03,1404.91 1829.04,1404.91 1829.04,1404.91 1829.05,1404.91 1829.05,1404.91 1829.05,1404.91 1829.06,1404.91 1829.06,1404.91 1829.07,1404.91 1829.07,1404.91 1829.07,1404.91 1829.08,1404.91 1829.08,1404.91 1829.09,1404.91 1829.09,1404.91 1829.09,1404.91 1829.1,1404.91 1829.1,1404.91 1829.11,1404.91 1829.11,1404.91 1829.11,1404.91 1829.12,1404.91 1829.12,1404.91 1829.13,1404.91 1829.13,1404.91 1829.13,1404.91 1829.14,1404.91 1829.14,1404.91 1829.15,1404.91 1829.15,1404.91 1829.15,1404.91 1829.16,1404.91 1829.16,1404.91 1829.17,1404.91 1829.17,1404.91 1829.17,1404.91 1829.18,1404.91 1829.18,1404.91 1829.19,1404.91 1829.19,1404.91 1829.19,1404.91 1829.2,1404.91 1829.2,1404.91 1829.21,1404.91 1829.21,1404.9 1829.21,1404.9 1829.22,1404.9 1829.22,1404.9 1829.23,1404.9 1829.23,1404.9 1829.23,1404.9 1829.24,1404.9 1829.24,1404.9 1829.25,1404.9 1829.25,1404.9 1829.25,1404.9 1829.26,1404.9 1829.26,1404.9 1829.27,1404.9 1829.27,1404.9 1829.27,1404.9 1829.28,1404.9 1829.28,1404.9 1829.29,1404.9 1829.29,1404.9 1829.29,1404.9 1829.3,1404.9 1829.3,1404.9 1829.31,1404.9 1829.31,1404.9 1829.31,1404.9 1829.32,1404.9 1829.32,1404.9 1829.33,1404.9 1829.33,1404.9 1829.33,1404.9 1829.34,1404.9 1829.34,1404.9 1829.35,1404.9 1829.35,1404.9 1829.35,1404.9 1829.36,1404.9 1829.36,1404.9 1829.37,1404.9 1829.37,1404.9 1829.37,1404.9 1829.38,1404.9 1829.38,1404.9 1829.39,1404.9 1829.39,1404.9 1829.39,1404.9 1829.4,1404.9 1829.4,1404.9 1829.41,1404.9 1829.41,1404.9 1829.41,1404.9 1829.42,1404.9 1829.42,1404.9 1829.43,1404.9 1829.43,1404.9 1829.43,1404.9 1829.44,1404.9 1829.44,1404.9 1829.45,1404.9 1829.45,1404.9 1829.45,1404.9 1829.46,1404.9 1829.46,1404.9 1829.47,1404.9 1829.47,1404.9 1829.47,1404.9 1829.48,1404.9 1829.48,1404.9 1829.49,1404.9 1829.49,1404.9 1829.49,1404.9 1829.5,1404.9 1829.5,1404.9 1829.51,1404.9 1829.51,1404.9 1829.51,1404.9 1829.52,1404.9 1829.52,1404.9 1829.53,1404.9 1829.53,1404.9 1829.53,1404.9 1829.54,1404.9 1829.54,1404.9 1829.55,1404.9 1829.55,1404.9 1829.55,1404.9 1829.56,1404.9 1829.56,1404.9 1829.57,1404.9 1829.57,1404.9 1829.57,1404.9 1829.58,1404.9 1829.58,1404.9 1829.59,1404.9 1829.59,1404.9 1829.59,1404.9 1829.6,1404.9 1829.6,1404.9 1829.61,1404.9 1829.61,1404.9 1829.61,1404.9 1829.62,1404.89 1829.62,1404.89 1829.63,1404.89 1829.63,1404.89 1829.63,1404.89 1829.64,1404.89 1829.64,1404.89 1829.65,1404.89 1829.65,1404.89 1829.65,1404.89 1829.66,1404.89 1829.66,1404.89 1829.66,1404.89 1829.67,1404.89 1829.67,1404.89 1829.68,1404.89 1829.68,1404.89 1829.68,1404.89 1829.69,1404.89 1829.69,1404.89 1829.7,1404.89 1829.7,1404.89 1829.7,1404.89 1829.71,1404.89 1829.71,1404.89 1829.72,1404.89 1829.72,1404.89 1829.72,1404.89 1829.73,1404.89 1829.73,1404.89 1829.74,1404.89 1829.74,1404.89 1829.74,1404.89 1829.75,1404.89 1829.75,1404.89 1829.76,1404.89 1829.76,1404.89 1829.76,1404.89 1829.77,1404.89 1829.77,1404.89 1829.78,1404.89 1829.78,1404.89 1829.78,1404.89 1829.79,1404.89 1829.79,1404.89 1829.8,1404.89 1829.8,1404.89 1829.8,1404.89 1829.81,1404.89 1829.81,1404.89 1829.82,1404.89 1829.82,1404.89 1829.82,1404.89 1829.83,1404.89 1829.83,1404.89 1829.84,1404.89 1829.84,1404.89 1829.84,1404.89 1829.85,1404.89 1829.85,1404.89 1829.86,1404.89 1829.86,1404.89 1829.86,1404.89 1829.87,1404.89 1829.87,1404.89 1829.88,1404.89 1829.88,1404.89 1829.88,1404.89 1829.89,1404.89 1829.89,1404.89 1829.9,1404.89 1829.9,1404.89 1829.9,1404.89 1829.91,1404.89 1829.91,1404.89 1829.91,1404.89 1829.92,1404.89 1829.92,1404.89 1829.93,1404.89 1829.93,1404.89 1829.93,1404.89 1829.94,1404.89 1829.94,1404.89 1829.95,1404.89 1829.95,1404.89 1829.95,1404.89 1829.96,1404.89 1829.96,1404.89 1829.97,1404.89 1829.97,1404.89 1829.97,1404.89 1829.98,1404.89 1829.98,1404.89 1829.99,1404.89 1829.99,1404.89 1829.99,1404.89 1830,1404.89 1830,1404.89 1830.01,1404.89 1830.01,1404.89 1830.01,1404.89 1830.02,1404.89 1830.02,1404.88 1830.03,1404.88 1830.03,1404.88 1830.03,1404.88 1830.04,1404.88 1830.04,1404.88 1830.05,1404.88 1830.05,1404.88 1830.05,1404.88 1830.06,1404.88 1830.06,1404.88 1830.07,1404.88 1830.07,1404.88 1830.07,1404.88 1830.08,1404.88 1830.08,1404.88 1830.09,1404.88 1830.09,1404.88 1830.09,1404.88 1830.1,1404.88 1830.1,1404.88 1830.1,1404.88 1830.11,1404.88 1830.11,1404.88 1830.12,1404.88 1830.12,1404.88 1830.12,1404.88 1830.13,1404.88 1830.13,1404.88 1830.14,1404.88 1830.14,1404.88 1830.14,1404.88 1830.15,1404.88 1830.15,1404.88 1830.16,1404.88 1830.16,1404.88 1830.16,1404.88 1830.17,1404.88 1830.17,1404.88 1830.18,1404.88 1830.18,1404.88 1830.18,1404.88 1830.19,1404.88 1830.19,1404.88 1830.2,1404.88 1830.2,1404.88 1830.2,1404.88 1830.21,1404.88 1830.21,1404.88 1830.22,1404.88 1830.22,1404.88 1830.22,1404.88 1830.23,1404.88 1830.23,1404.88 1830.24,1404.88 1830.24,1404.88 1830.24,1404.88 1830.25,1404.88 1830.25,1404.88 1830.25,1404.88 1830.26,1404.88 1830.26,1404.88 1830.27,1404.88 1830.27,1404.88 1830.27,1404.88 1830.28,1404.88 1830.28,1404.88 1830.29,1404.88 1830.29,1404.88 1830.29,1404.88 1830.3,1404.88 1830.3,1404.88 1830.31,1404.88 1830.31,1404.88 1830.31,1404.88 1830.32,1404.88 1830.32,1404.88 1830.33,1404.88 1830.33,1404.88 1830.33,1404.88 1830.34,1404.88 1830.34,1404.88 1830.35,1404.88 1830.35,1404.88 1830.35,1404.88 1830.36,1404.88 1830.36,1404.88 1830.37,1404.88 1830.37,1404.88 1830.37,1404.88 1830.38,1404.88 1830.38,1404.88 1830.38,1404.88 1830.39,1404.88 1830.39,1404.88 1830.4,1404.88 1830.4,1404.88 1830.4,1404.88 1830.41,1404.88 1830.41,1404.88 1830.42,1404.88 1830.42,1404.88 1830.42,1404.88 1830.43,1404.87 1830.43,1404.87 1830.44,1404.87 1830.44,1404.87 1830.44,1404.87 1830.45,1404.87 1830.45,1404.87 1830.46,1404.87 1830.46,1404.87 1830.46,1404.87 1830.47,1404.87 1830.47,1404.87 1830.48,1404.87 1830.48,1404.87 1830.48,1404.87 1830.49,1404.87 1830.49,1404.87 1830.49,1404.87 1830.5,1404.87 1830.5,1404.87 1830.51,1404.87 1830.51,1404.87 1830.51,1404.87 1830.52,1404.87 1830.52,1404.87 1830.53,1404.87 1830.53,1404.87 1830.53,1404.87 1830.54,1404.87 1830.54,1404.87 1830.55,1404.87 1830.55,1404.87 1830.55,1404.87 1830.56,1404.87 1830.56,1404.87 1830.57,1404.87 1830.57,1404.87 1830.57,1404.87 1830.58,1404.87 1830.58,1404.87 1830.59,1404.87 1830.59,1404.87 1830.59,1404.87 1830.6,1404.87 1830.6,1404.87 1830.6,1404.87 1830.61,1404.87 1830.61,1404.87 1830.62,1404.87 1830.62,1404.87 1830.62,1404.87 1830.63,1404.87 1830.63,1404.87 1830.64,1404.87 1830.64,1404.87 1830.64,1404.87 1830.65,1404.87 1830.65,1404.87 1830.66,1404.87 1830.66,1404.87 1830.66,1404.87 1830.67,1404.87 1830.67,1404.87 1830.68,1404.87 1830.68,1404.87 1830.68,1404.87 1830.69,1404.87 1830.69,1404.87 1830.7,1404.87 1830.7,1404.87 1830.7,1404.87 1830.71,1404.87 1830.71,1404.87 1830.71,1404.87 1830.72,1404.87 1830.72,1404.87 1830.73,1404.87 1830.73,1404.87 1830.73,1404.87 1830.74,1404.87 1830.74,1404.87 1830.75,1404.87 1830.75,1404.87 1830.75,1404.87 1830.76,1404.87 1830.76,1404.87 1830.77,1404.87 1830.77,1404.87 1830.77,1404.87 1830.78,1404.87 1830.78,1404.87 1830.79,1404.87 1830.79,1404.87 1830.79,1404.87 1830.8,1404.87 1830.8,1404.87 1830.8,1404.87 1830.81,1404.87 1830.81,1404.87 1830.82,1404.87 1830.82,1404.87 1830.82,1404.87 1830.83,1404.87 1830.83,1404.86 1830.84,1404.86 1830.84,1404.86 1830.84,1404.86 1830.85,1404.86 1830.85,1404.86 1830.86,1404.86 1830.86,1404.86 1830.86,1404.86 1830.87,1404.86 1830.87,1404.86 1830.88,1404.86 1830.88,1404.86 1830.88,1404.86 1830.89,1404.86 1830.89,1404.86 1830.89,1404.86 1830.9,1404.86 1830.9,1404.86 1830.91,1404.86 1830.91,1404.86 1830.91,1404.86 1830.92,1404.86 1830.92,1404.86 1830.93,1404.86 1830.93,1404.86 1830.93,1404.86 1830.94,1404.86 1830.94,1404.86 1830.95,1404.86 1830.95,1404.86 1830.95,1404.86 1830.96,1404.86 1830.96,1404.86 1830.96,1404.86 1830.97,1404.86 1830.97,1404.86 1830.98,1404.86 1830.98,1404.86 1830.98,1404.86 1830.99,1404.86 1830.99,1404.86 1831,1404.86 1831,1404.86 1831,1404.86 1831.01,1404.86 1831.01,1404.86 1831.02,1404.86 1831.02,1404.86 1831.02,1404.86 1831.03,1404.86 1831.03,1404.86 1831.04,1404.86 1831.04,1404.86 1831.04,1404.86 1831.05,1404.86 1831.05,1404.86 1831.05,1404.86 1831.06,1404.86 1831.06,1404.86 1831.07,1404.86 1831.07,1404.86 1831.07,1404.86 1831.08,1404.86 1831.08,1404.86 1831.09,1404.86 1831.09,1404.86 1831.09,1404.86 1831.1,1404.86 1831.1,1404.86 1831.11,1404.86 1831.11,1404.86 1831.11,1404.86 1831.12,1404.86 1831.12,1404.86 1831.12,1404.86 1831.13,1404.86 1831.13,1404.86 1831.14,1404.86 1831.14,1404.86 1831.14,1404.86 1831.15,1404.86 1831.15,1404.86 1831.16,1404.86 1831.16,1404.86 1831.16,1404.86 1831.17,1404.86 1831.17,1404.86 1831.18,1404.86 1831.18,1404.86 1831.18,1404.86 1831.19,1404.86 1831.19,1404.86 1831.2,1404.86 1831.2,1404.86 1831.2,1404.86 1831.21,1404.86 1831.21,1404.86 1831.21,1404.86 1831.22,1404.86 1831.22,1404.86 1831.23,1404.86 1831.23,1404.86 1831.23,1404.85 1831.24,1404.85 1831.24,1404.85 1831.25,1404.85 1831.25,1404.85 1831.25,1404.85 1831.26,1404.85 1831.26,1404.85 1831.27,1404.85 1831.27,1404.85 1831.27,1404.85 1831.28,1404.85 1831.28,1404.85 1831.28,1404.85 1831.29,1404.85 1831.29,1404.85 1831.3,1404.85 1831.3,1404.85 1831.3,1404.85 1831.31,1404.85 1831.31,1404.85 1831.32,1404.85 1831.32,1404.85 1831.32,1404.85 1831.33,1404.85 1831.33,1404.85 1831.34,1404.85 1831.34,1404.85 1831.34,1404.85 1831.35,1404.85 1831.35,1404.85 1831.35,1404.85 1831.36,1404.85 1831.36,1404.85 1831.37,1404.85 1831.37,1404.85 1831.37,1404.85 1831.38,1404.85 1831.38,1404.85 1831.39,1404.85 1831.39,1404.85 1831.39,1404.85 1831.4,1404.85 1831.4,1404.85 1831.4,1404.85 1831.41,1404.85 1831.41,1404.85 1831.42,1404.85 1831.42,1404.85 1831.42,1404.85 1831.43,1404.85 1831.43,1404.85 1831.44,1404.85 1831.44,1404.85 1831.44,1404.85 1831.45,1404.85 1831.45,1404.85 1831.46,1404.85 1831.46,1404.85 1831.46,1404.85 1831.47,1404.85 1831.47,1404.85 1831.47,1404.85 1831.48,1404.85 1831.48,1404.85 1831.49,1404.85 1831.49,1404.85 1831.49,1404.85 1831.5,1404.85 1831.5,1404.85 1831.51,1404.85 1831.51,1404.85 1831.51,1404.85 1831.52,1404.85 1831.52,1404.85 1831.53,1404.85 1831.53,1404.85 1831.53,1404.85 1831.54,1404.85 1831.54,1404.85 1831.54,1404.85 1831.55,1404.85 1831.55,1404.85 1831.56,1404.85 1831.56,1404.85 1831.56,1404.85 1831.57,1404.85 1831.57,1404.85 1831.58,1404.85 1831.58,1404.85 1831.58,1404.85 1831.59,1404.85 1831.59,1404.85 1831.59,1404.85 1831.6,1404.85 1831.6,1404.85 1831.61,1404.85 1831.61,1404.85 1831.61,1404.85 1831.62,1404.85 1831.62,1404.85 1831.63,1404.85 1831.63,1404.85 1831.63,1404.85 1831.64,1404.85 1831.64,1404.84 1831.65,1404.84 1831.65,1404.84 1831.65,1404.84 1831.66,1404.84 1831.66,1404.84 1831.66,1404.84 1831.67,1404.84 1831.67,1404.84 1831.68,1404.84 1831.68,1404.84 1831.68,1404.84 1831.69,1404.84 1831.69,1404.84 1831.7,1404.84 1831.7,1404.84 1831.7,1404.84 1831.71,1404.84 1831.71,1404.84 1831.71,1404.84 1831.72,1404.84 1831.72,1404.84 1831.73,1404.84 1831.73,1404.84 1831.73,1404.84 1831.74,1404.84 1831.74,1404.84 1831.75,1404.84 1831.75,1404.84 1831.75,1404.84 1831.76,1404.84 1831.76,1404.84 1831.77,1404.84 1831.77,1404.84 1831.77,1404.84 1831.78,1404.84 1831.78,1404.84 1831.78,1404.84 1831.79,1404.84 1831.79,1404.84 1831.8,1404.84 1831.8,1404.84 1831.8,1404.84 1831.81,1404.84 1831.81,1404.84 1831.82,1404.84 1831.82,1404.84 1831.82,1404.84 1831.83,1404.84 1831.83,1404.84 1831.83,1404.84 1831.84,1404.84 1831.84,1404.84 1831.85,1404.84 1831.85,1404.84 1831.85,1404.84 1831.86,1404.84 1831.86,1404.84 1831.87,1404.84 1831.87,1404.84 1831.87,1404.84 1831.88,1404.84 1831.88,1404.84 1831.88,1404.84 1831.89,1404.84 1831.89,1404.84 1831.9,1404.84 1831.9,1404.84 1831.9,1404.84 1831.91,1404.84 1831.91,1404.84 1831.92,1404.84 1831.92,1404.84 1831.92,1404.84 1831.93,1404.84 1831.93,1404.84 1831.93,1404.84 1831.94,1404.84 1831.94,1404.84 1831.95,1404.84 1831.95,1404.84 1831.95,1404.84 1831.96,1404.84 1831.96,1404.84 1831.97,1404.84 1831.97,1404.84 1831.97,1404.84 1831.98,1404.84 1831.98,1404.84 1831.98,1404.84 1831.99,1404.84 1831.99,1404.84 1832,1404.84 1832,1404.84 1832,1404.84 1832.01,1404.84 1832.01,1404.84 1832.02,1404.84 1832.02,1404.84 1832.02,1404.84 1832.03,1404.84 1832.03,1404.84 1832.03,1404.84 1832.04,1404.84 1832.04,1404.83 1832.05,1404.83 1832.05,1404.83 1832.05,1404.83 1832.06,1404.83 1832.06,1404.83 1832.07,1404.83 1832.07,1404.83 1832.07,1404.83 1832.08,1404.83 1832.08,1404.83 1832.08,1404.83 1832.09,1404.83 1832.09,1404.83 1832.1,1404.83 1832.1,1404.83 1832.1,1404.83 1832.11,1404.83 1832.11,1404.83 1832.12,1404.83 1832.12,1404.83 1832.12,1404.83 1832.13,1404.83 1832.13,1404.83 1832.13,1404.83 1832.14,1404.83 1832.14,1404.83 1832.15,1404.83 1832.15,1404.83 1832.15,1404.83 1832.16,1404.83 1832.16,1404.83 1832.17,1404.83 1832.17,1404.83 1832.17,1404.83 1832.18,1404.83 1832.18,1404.83 1832.18,1404.83 1832.19,1404.83 1832.19,1404.83 1832.2,1404.83 1832.2,1404.83 1832.2,1404.83 1832.21,1404.83 1832.21,1404.83 1832.22,1404.83 1832.22,1404.83 1832.22,1404.83 1832.23,1404.83 1832.23,1404.83 1832.23,1404.83 1832.24,1404.83 1832.24,1404.83 1832.25,1404.83 1832.25,1404.83 1832.25,1404.83 1832.26,1404.83 1832.26,1404.83 1832.27,1404.83 1832.27,1404.83 1832.27,1404.83 1832.28,1404.83 1832.28,1404.83 1832.28,1404.83 1832.29,1404.83 1832.29,1404.83 1832.3,1404.83 1832.3,1404.83 1832.3,1404.83 1832.31,1404.83 1832.31,1404.83 1832.32,1404.83 1832.32,1404.83 1832.32,1404.83 1832.33,1404.83 1832.33,1404.83 1832.33,1404.83 1832.34,1404.83 1832.34,1404.83 1832.35,1404.83 1832.35,1404.83 1832.35,1404.83 1832.36,1404.83 1832.36,1404.83 1832.37,1404.83 1832.37,1404.83 1832.37,1404.83 1832.38,1404.83 1832.38,1404.83 1832.38,1404.83 1832.39,1404.83 1832.39,1404.83 1832.4,1404.83 1832.4,1404.83 1832.4,1404.83 1832.41,1404.83 1832.41,1404.83 1832.41,1404.83 1832.42,1404.83 1832.42,1404.83 1832.43,1404.83 1832.43,1404.83 1832.43,1404.83 1832.44,1404.83 1832.44,1404.83 1832.45,1404.82 1832.45,1404.82 1832.45,1404.82 1832.46,1404.82 1832.46,1404.82 1832.46,1404.82 1832.47,1404.82 1832.47,1404.82 1832.48,1404.82 1832.48,1404.82 1832.48,1404.82 1832.49,1404.82 1832.49,1404.82 1832.5,1404.82 1832.5,1404.82 1832.5,1404.82 1832.51,1404.82 1832.51,1404.82 1832.51,1404.82 1832.52,1404.82 1832.52,1404.82 1832.53,1404.82 1832.53,1404.82 1832.53,1404.82 1832.54,1404.82 1832.54,1404.82 1832.55,1404.82 1832.55,1404.82 1832.55,1404.82 1832.56,1404.82 1832.56,1404.82 1832.56,1404.82 1832.57,1404.82 1832.57,1404.82 1832.58,1404.82 1832.58,1404.82 1832.58,1404.82 1832.59,1404.82 1832.59,1404.82 1832.59,1404.82 1832.6,1404.82 1832.6,1404.82 1832.61,1404.82 1832.61,1404.82 1832.61,1404.82 1832.62,1404.82 1832.62,1404.82 1832.63,1404.82 1832.63,1404.82 1832.63,1404.82 1832.64,1404.82 1832.64,1404.82 1832.64,1404.82 1832.65,1404.82 1832.65,1404.82 1832.66,1404.82 1832.66,1404.82 1832.66,1404.82 1832.67,1404.82 1832.67,1404.82 1832.67,1404.82 1832.68,1404.82 1832.68,1404.82 1832.69,1404.82 1832.69,1404.82 1832.69,1404.82 1832.7,1404.82 1832.7,1404.82 1832.71,1404.82 1832.71,1404.82 1832.71,1404.82 1832.72,1404.82 1832.72,1404.82 1832.72,1404.82 1832.73,1404.82 1832.73,1404.82 1832.74,1404.82 1832.74,1404.82 1832.74,1404.82 1832.75,1404.82 1832.75,1404.82 1832.75,1404.82 1832.76,1404.82 1832.76,1404.82 1832.77,1404.82 1832.77,1404.82 1832.77,1404.82 1832.78,1404.82 1832.78,1404.82 1832.79,1404.82 1832.79,1404.82 1832.79,1404.82 1832.8,1404.82 1832.8,1404.82 1832.8,1404.82 1832.81,1404.82 1832.81,1404.82 1832.82,1404.82 1832.82,1404.82 1832.82,1404.82 1832.83,1404.82 1832.83,1404.82 1832.83,1404.82 1832.84,1404.82 1832.84,1404.82 1832.85,1404.82 1832.85,1404.81 1832.85,1404.81 1832.86,1404.81 1832.86,1404.81 1832.87,1404.81 1832.87,1404.81 1832.87,1404.81 1832.88,1404.81 1832.88,1404.81 1832.88,1404.81 1832.89,1404.81 1832.89,1404.81 1832.9,1404.81 1832.9,1404.81 1832.9,1404.81 1832.91,1404.81 1832.91,1404.81 1832.91,1404.81 1832.92,1404.81 1832.92,1404.81 1832.93,1404.81 1832.93,1404.81 1832.93,1404.81 1832.94,1404.81 1832.94,1404.81 1832.95,1404.81 1832.95,1404.81 1832.95,1404.81 1832.96,1404.81 1832.96,1404.81 1832.96,1404.81 1832.97,1404.81 1832.97,1404.81 1832.98,1404.81 1832.98,1404.81 1832.98,1404.81 1832.99,1404.81 1832.99,1404.81 1832.99,1404.81 1833,1404.81 1833,1404.81 1833.01,1404.81 1833.01,1404.81 1833.01,1404.81 1833.02,1404.81 1833.02,1404.81 1833.03,1404.81 1833.03,1404.81 1833.03,1404.81 1833.04,1404.81 1833.04,1404.81 1833.04,1404.81 1833.05,1404.81 1833.05,1404.81 1833.06,1404.81 1833.06,1404.81 1833.06,1404.81 1833.07,1404.81 1833.07,1404.81 1833.07,1404.81 1833.08,1404.81 1833.08,1404.81 1833.09,1404.81 1833.09,1404.81 1833.09,1404.81 1833.1,1404.81 1833.1,1404.81 1833.1,1404.81 1833.11,1404.81 1833.11,1404.81 1833.12,1404.81 1833.12,1404.81 1833.12,1404.81 1833.13,1404.81 1833.13,1404.81 1833.14,1404.81 1833.14,1404.81 1833.14,1404.81 1833.15,1404.81 1833.15,1404.81 1833.15,1404.81 1833.16,1404.81 1833.16,1404.81 1833.17,1404.81 1833.17,1404.81 1833.17,1404.81 1833.18,1404.81 1833.18,1404.81 1833.18,1404.81 1833.19,1404.81 1833.19,1404.81 1833.2,1404.81 1833.2,1404.81 1833.2,1404.81 1833.21,1404.81 1833.21,1404.81 1833.21,1404.81 1833.22,1404.81 1833.22,1404.81 1833.23,1404.81 1833.23,1404.81 1833.23,1404.81 1833.24,1404.81 1833.24,1404.81 1833.25,1404.81 1833.25,1404.81 1833.25,1404.8 1833.26,1404.8 1833.26,1404.8 1833.26,1404.8 1833.27,1404.8 1833.27,1404.8 1833.28,1404.8 1833.28,1404.8 1833.28,1404.8 1833.29,1404.8 1833.29,1404.8 1833.29,1404.8 1833.3,1404.8 1833.3,1404.8 1833.31,1404.8 1833.31,1404.8 1833.31,1404.8 1833.32,1404.8 1833.32,1404.8 1833.32,1404.8 1833.33,1404.8 1833.33,1404.8 1833.34,1404.8 1833.34,1404.8 1833.34,1404.8 1833.35,1404.8 1833.35,1404.8 1833.35,1404.8 1833.36,1404.8 1833.36,1404.8 1833.37,1404.8 1833.37,1404.8 1833.37,1404.8 1833.38,1404.8 1833.38,1404.8 1833.39,1404.8 1833.39,1404.8 1833.39,1404.8 1833.4,1404.8 1833.4,1404.8 1833.4,1404.8 1833.41,1404.8 1833.41,1404.8 1833.42,1404.8 1833.42,1404.8 1833.42,1404.8 1833.43,1404.8 1833.43,1404.8 1833.43,1404.8 1833.44,1404.8 1833.44,1404.8 1833.45,1404.8 1833.45,1404.8 1833.45,1404.8 1833.46,1404.8 1833.46,1404.8 1833.46,1404.8 1833.47,1404.8 1833.47,1404.8 1833.48,1404.8 1833.48,1404.8 1833.48,1404.8 1833.49,1404.8 1833.49,1404.8 1833.49,1404.8 1833.5,1404.8 1833.5,1404.8 1833.51,1404.8 1833.51,1404.8 1833.51,1404.8 1833.52,1404.8 1833.52,1404.8 1833.52,1404.8 1833.53,1404.8 1833.53,1404.8 1833.54,1404.8 1833.54,1404.8 1833.54,1404.8 1833.55,1404.8 1833.55,1404.8 1833.55,1404.8 1833.56,1404.8 1833.56,1404.8 1833.57,1404.8 1833.57,1404.8 1833.57,1404.8 1833.58,1404.8 1833.58,1404.8 1833.59,1404.8 1833.59,1404.8 1833.59,1404.8 1833.6,1404.8 1833.6,1404.8 1833.6,1404.8 1833.61,1404.8 1833.61,1404.8 1833.62,1404.8 1833.62,1404.8 1833.62,1404.8 1833.63,1404.8 1833.63,1404.8 1833.63,1404.8 1833.64,1404.8 1833.64,1404.8 1833.65,1404.8 1833.65,1404.8 1833.65,1404.79 1833.66,1404.79 1833.66,1404.79 1833.66,1404.79 1833.67,1404.79 1833.67,1404.79 1833.68,1404.79 1833.68,1404.79 1833.68,1404.79 1833.69,1404.79 1833.69,1404.79 1833.69,1404.79 1833.7,1404.79 1833.7,1404.79 1833.71,1404.79 1833.71,1404.79 1833.71,1404.79 1833.72,1404.79 1833.72,1404.79 1833.72,1404.79 1833.73,1404.79 1833.73,1404.79 1833.74,1404.79 1833.74,1404.79 1833.74,1404.79 1833.75,1404.79 1833.75,1404.79 1833.75,1404.79 1833.76,1404.79 1833.76,1404.79 1833.77,1404.79 1833.77,1404.79 1833.77,1404.79 1833.78,1404.79 1833.78,1404.79 1833.78,1404.79 1833.79,1404.79 1833.79,1404.79 1833.8,1404.79 1833.8,1404.79 1833.8,1404.79 1833.81,1404.79 1833.81,1404.79 1833.81,1404.79 1833.82,1404.79 1833.82,1404.79 1833.83,1404.79 1833.83,1404.79 1833.83,1404.79 1833.84,1404.79 1833.84,1404.79 1833.84,1404.79 1833.85,1404.79 1833.85,1404.79 1833.86,1404.79 1833.86,1404.79 1833.86,1404.79 1833.87,1404.79 1833.87,1404.79 1833.87,1404.79 1833.88,1404.79 1833.88,1404.79 1833.89,1404.79 1833.89,1404.79 1833.89,1404.79 1833.9,1404.79 1833.9,1404.79 1833.9,1404.79 1833.91,1404.79 1833.91,1404.79 1833.92,1404.79 1833.92,1404.79 1833.92,1404.79 1833.93,1404.79 1833.93,1404.79 1833.93,1404.79 1833.94,1404.79 1833.94,1404.79 1833.95,1404.79 1833.95,1404.79 1833.95,1404.79 1833.96,1404.79 1833.96,1404.79 1833.96,1404.79 1833.97,1404.79 1833.97,1404.79 1833.98,1404.79 1833.98,1404.79 1833.98,1404.79 1833.99,1404.79 1833.99,1404.79 1833.99,1404.79 1834,1404.79 1834,1404.79 1834.01,1404.79 1834.01,1404.79 1834.01,1404.79 1834.02,1404.79 1834.02,1404.79 1834.02,1404.79 1834.03,1404.79 1834.03,1404.79 1834.04,1404.79 1834.04,1404.79 1834.04,1404.79 1834.05,1404.79 1834.05,1404.79 1834.05,1404.78 1834.06,1404.78 1834.06,1404.78 1834.07,1404.78 1834.07,1404.78 1834.07,1404.78 1834.08,1404.78 1834.08,1404.78 1834.08,1404.78 1834.09,1404.78 1834.09,1404.78 1834.1,1404.78 1834.1,1404.78 1834.1,1404.78 1834.11,1404.78 1834.11,1404.78 1834.11,1404.78 1834.12,1404.78 1834.12,1404.78 1834.13,1404.78 1834.13,1404.78 1834.13,1404.78 1834.14,1404.78 1834.14,1404.78 1834.14,1404.78 1834.15,1404.78 1834.15,1404.78 1834.16,1404.78 1834.16,1404.78 1834.16,1404.78 1834.17,1404.78 1834.17,1404.78 1834.17,1404.78 1834.18,1404.78 1834.18,1404.78 1834.19,1404.78 1834.19,1404.78 1834.19,1404.78 1834.2,1404.78 1834.2,1404.78 1834.2,1404.78 1834.21,1404.78 1834.21,1404.78 1834.22,1404.78 1834.22,1404.78 1834.22,1404.78 1834.23,1404.78 1834.23,1404.78 1834.23,1404.78 1834.24,1404.78 1834.24,1404.78 1834.25,1404.78 1834.25,1404.78 1834.25,1404.78 1834.26,1404.78 1834.26,1404.78 1834.26,1404.78 1834.27,1404.78 1834.27,1404.78 1834.28,1404.78 1834.28,1404.78 1834.28,1404.78 1834.29,1404.78 1834.29,1404.78 1834.29,1404.78 1834.3,1404.78 1834.3,1404.78 1834.31,1404.78 1834.31,1404.78 1834.31,1404.78 1834.32,1404.78 1834.32,1404.78 1834.32,1404.78 1834.33,1404.78 1834.33,1404.78 1834.34,1404.78 1834.34,1404.78 1834.34,1404.78 1834.35,1404.78 1834.35,1404.78 1834.35,1404.78 1834.36,1404.78 1834.36,1404.78 1834.37,1404.78 1834.37,1404.78 1834.37,1404.78 1834.38,1404.78 1834.38,1404.78 1834.38,1404.78 1834.39,1404.78 1834.39,1404.78 1834.39,1404.78 1834.4,1404.78 1834.4,1404.78 1834.41,1404.78 1834.41,1404.78 1834.41,1404.78 1834.42,1404.78 1834.42,1404.78 1834.42,1404.78 1834.43,1404.78 1834.43,1404.78 1834.44,1404.78 1834.44,1404.78 1834.44,1404.78 1834.45,1404.78 1834.45,1404.78 1834.45,1404.78 1834.46,1404.77 1834.46,1404.77 1834.47,1404.77 1834.47,1404.77 1834.47,1404.77 1834.48,1404.77 1834.48,1404.77 1834.48,1404.77 1834.49,1404.77 1834.49,1404.77 1834.5,1404.77 1834.5,1404.77 1834.5,1404.77 1834.51,1404.77 1834.51,1404.77 1834.51,1404.77 1834.52,1404.77 1834.52,1404.77 1834.53,1404.77 1834.53,1404.77 1834.53,1404.77 1834.54,1404.77 1834.54,1404.77 1834.54,1404.77 1834.55,1404.77 1834.55,1404.77 1834.56,1404.77 1834.56,1404.77 1834.56,1404.77 1834.57,1404.77 1834.57,1404.77 1834.57,1404.77 1834.58,1404.77 1834.58,1404.77 1834.58,1404.77 1834.59,1404.77 1834.59,1404.77 1834.6,1404.77 1834.6,1404.77 1834.6,1404.77 1834.61,1404.77 1834.61,1404.77 1834.61,1404.77 1834.62,1404.77 1834.62,1404.77 1834.63,1404.77 1834.63,1404.77 1834.63,1404.77 1834.64,1404.77 1834.64,1404.77 1834.64,1404.77 1834.65,1404.77 1834.65,1404.77 1834.66,1404.77 1834.66,1404.77 1834.66,1404.77 1834.67,1404.77 1834.67,1404.77 1834.67,1404.77 1834.68,1404.77 1834.68,1404.77 1834.69,1404.77 1834.69,1404.77 1834.69,1404.77 1834.7,1404.77 1834.7,1404.77 1834.7,1404.77 1834.71,1404.77 1834.71,1404.77 1834.72,1404.77 1834.72,1404.77 1834.72,1404.77 1834.73,1404.77 1834.73,1404.77 1834.73,1404.77 1834.74,1404.77 1834.74,1404.77 1834.74,1404.77 1834.75,1404.77 1834.75,1404.77 1834.76,1404.77 1834.76,1404.77 1834.76,1404.77 1834.77,1404.77 1834.77,1404.77 1834.77,1404.77 1834.78,1404.77 1834.78,1404.77 1834.79,1404.77 1834.79,1404.77 1834.79,1404.77 1834.8,1404.77 1834.8,1404.77 1834.8,1404.77 1834.81,1404.77 1834.81,1404.77 1834.82,1404.77 1834.82,1404.77 1834.82,1404.77 1834.83,1404.77 1834.83,1404.77 1834.83,1404.77 1834.84,1404.77 1834.84,1404.77 1834.84,1404.77 1834.85,1404.77 1834.85,1404.77 1834.86,1404.77 1834.86,1404.76 1834.86,1404.76 1834.87,1404.76 1834.87,1404.76 1834.87,1404.76 1834.88,1404.76 1834.88,1404.76 1834.89,1404.76 1834.89,1404.76 1834.89,1404.76 1834.9,1404.76 1834.9,1404.76 1834.9,1404.76 1834.91,1404.76 1834.91,1404.76 1834.92,1404.76 1834.92,1404.76 1834.92,1404.76 1834.93,1404.76 1834.93,1404.76 1834.93,1404.76 1834.94,1404.76 1834.94,1404.76 1834.95,1404.76 1834.95,1404.76 1834.95,1404.76 1834.96,1404.76 1834.96,1404.76 1834.96,1404.76 1834.97,1404.76 1834.97,1404.76 1834.97,1404.76 1834.98,1404.76 1834.98,1404.76 1834.99,1404.76 1834.99,1404.76 1834.99,1404.76 1835,1404.76 1835,1404.76 1835,1404.76 1835.01,1404.76 1835.01,1404.76 1835.02,1404.76 1835.02,1404.76 1835.02,1404.76 1835.03,1404.76 1835.03,1404.76 1835.03,1404.76 1835.04,1404.76 1835.04,1404.76 1835.04,1404.76 1835.05,1404.76 1835.05,1404.76 1835.06,1404.76 1835.06,1404.76 1835.06,1404.76 1835.07,1404.76 1835.07,1404.76 1835.07,1404.76 1835.08,1404.76 1835.08,1404.76 1835.09,1404.76 1835.09,1404.76 1835.09,1404.76 1835.1,1404.76 1835.1,1404.76 1835.1,1404.76 1835.11,1404.76 1835.11,1404.76 1835.12,1404.76 1835.12,1404.76 1835.12,1404.76 1835.13,1404.76 1835.13,1404.76 1835.13,1404.76 1835.14,1404.76 1835.14,1404.76 1835.14,1404.76 1835.15,1404.76 1835.15,1404.76 1835.16,1404.76 1835.16,1404.76 1835.16,1404.76 1835.17,1404.76 1835.17,1404.76 1835.17,1404.76 1835.18,1404.76 1835.18,1404.76 1835.19,1404.76 1835.19,1404.76 1835.19,1404.76 1835.2,1404.76 1835.2,1404.76 1835.2,1404.76 1835.21,1404.76 1835.21,1404.76 1835.21,1404.76 1835.22,1404.76 1835.22,1404.76 1835.23,1404.76 1835.23,1404.76 1835.23,1404.76 1835.24,1404.76 1835.24,1404.76 1835.24,1404.76 1835.25,1404.76 1835.25,1404.76 1835.26,1404.76 1835.26,1404.75 1835.26,1404.75 1835.27,1404.75 1835.27,1404.75 1835.27,1404.75 1835.28,1404.75 1835.28,1404.75 1835.28,1404.75 1835.29,1404.75 1835.29,1404.75 1835.3,1404.75 1835.3,1404.75 1835.3,1404.75 1835.31,1404.75 1835.31,1404.75 1835.31,1404.75 1835.32,1404.75 1835.32,1404.75 1835.33,1404.75 1835.33,1404.75 1835.33,1404.75 1835.34,1404.75 1835.34,1404.75 1835.34,1404.75 1835.35,1404.75 1835.35,1404.75 1835.35,1404.75 1835.36,1404.75 1835.36,1404.75 1835.37,1404.75 1835.37,1404.75 1835.37,1404.75 1835.38,1404.75 1835.38,1404.75 1835.38,1404.75 1835.39,1404.75 1835.39,1404.75 1835.4,1404.75 1835.4,1404.75 1835.4,1404.75 1835.41,1404.75 1835.41,1404.75 1835.41,1404.75 1835.42,1404.75 1835.42,1404.75 1835.42,1404.75 1835.43,1404.75 1835.43,1404.75 1835.44,1404.75 1835.44,1404.75 1835.44,1404.75 1835.45,1404.75 1835.45,1404.75 1835.45,1404.75 1835.46,1404.75 1835.46,1404.75 1835.47,1404.75 1835.47,1404.75 1835.47,1404.75 1835.48,1404.75 1835.48,1404.75 1835.48,1404.75 1835.49,1404.75 1835.49,1404.75 1835.49,1404.75 1835.5,1404.75 1835.5,1404.75 1835.51,1404.75 1835.51,1404.75 1835.51,1404.75 1835.52,1404.75 1835.52,1404.75 1835.52,1404.75 1835.53,1404.75 1835.53,1404.75 1835.54,1404.75 1835.54,1404.75 1835.54,1404.75 1835.55,1404.75 1835.55,1404.75 1835.55,1404.75 1835.56,1404.75 1835.56,1404.75 1835.56,1404.75 1835.57,1404.75 1835.57,1404.75 1835.58,1404.75 1835.58,1404.75 1835.58,1404.75 1835.59,1404.75 1835.59,1404.75 1835.59,1404.75 1835.6,1404.75 1835.6,1404.75 1835.61,1404.75 1835.61,1404.75 1835.61,1404.75 1835.62,1404.75 1835.62,1404.75 1835.62,1404.75 1835.63,1404.75 1835.63,1404.75 1835.63,1404.75 1835.64,1404.75 1835.64,1404.75 1835.65,1404.75 1835.65,1404.75 1835.65,1404.75 1835.66,1404.75 1835.66,1404.74 1835.66,1404.74 1835.67,1404.74 1835.67,1404.74 1835.67,1404.74 1835.68,1404.74 1835.68,1404.74 1835.69,1404.74 1835.69,1404.74 1835.69,1404.74 1835.7,1404.74 1835.7,1404.74 1835.7,1404.74 1835.71,1404.74 1835.71,1404.74 1835.72,1404.74 1835.72,1404.74 1835.72,1404.74 1835.73,1404.74 1835.73,1404.74 1835.73,1404.74 1835.74,1404.74 1835.74,1404.74 1835.74,1404.74 1835.75,1404.74 1835.75,1404.74 1835.76,1404.74 1835.76,1404.74 1835.76,1404.74 1835.77,1404.74 1835.77,1404.74 1835.77,1404.74 1835.78,1404.74 1835.78,1404.74 1835.78,1404.74 1835.79,1404.74 1835.79,1404.74 1835.8,1404.74 1835.8,1404.74 1835.8,1404.74 1835.81,1404.74 1835.81,1404.74 1835.81,1404.74 1835.82,1404.74 1835.82,1404.74 1835.82,1404.74 1835.83,1404.74 1835.83,1404.74 1835.84,1404.74 1835.84,1404.74 1835.84,1404.74 1835.85,1404.74 1835.85,1404.74 1835.85,1404.74 1835.86,1404.74 1835.86,1404.74 1835.87,1404.74 1835.87,1404.74 1835.87,1404.74 1835.88,1404.74 1835.88,1404.74 1835.88,1404.74 1835.89,1404.74 1835.89,1404.74 1835.89,1404.74 1835.9,1404.74 1835.9,1404.74 1835.91,1404.74 1835.91,1404.74 1835.91,1404.74 1835.92,1404.74 1835.92,1404.74 1835.92,1404.74 1835.93,1404.74 1835.93,1404.74 1835.93,1404.74 1835.94,1404.74 1835.94,1404.74 1835.95,1404.74 1835.95,1404.74 1835.95,1404.74 1835.96,1404.74 1835.96,1404.74 1835.96,1404.74 1835.97,1404.74 1835.97,1404.74 1835.97,1404.74 1835.98,1404.74 1835.98,1404.74 1835.99,1404.74 1835.99,1404.74 1835.99,1404.74 1836,1404.74 1836,1404.74 1836,1404.74 1836.01,1404.74 1836.01,1404.74 1836.02,1404.74 1836.02,1404.74 1836.02,1404.74 1836.03,1404.74 1836.03,1404.74 1836.03,1404.74 1836.04,1404.74 1836.04,1404.74 1836.04,1404.74 1836.05,1404.74 1836.05,1404.74 1836.06,1404.74 1836.06,1404.73 1836.06,1404.73 1836.07,1404.73 1836.07,1404.73 1836.07,1404.73 1836.08,1404.73 1836.08,1404.73 1836.08,1404.73 1836.09,1404.73 1836.09,1404.73 1836.1,1404.73 1836.1,1404.73 1836.1,1404.73 1836.11,1404.73 1836.11,1404.73 1836.11,1404.73 1836.12,1404.73 1836.12,1404.73 1836.12,1404.73 1836.13,1404.73 1836.13,1404.73 1836.14,1404.73 1836.14,1404.73 1836.14,1404.73 1836.15,1404.73 1836.15,1404.73 1836.15,1404.73 1836.16,1404.73 1836.16,1404.73 1836.16,1404.73 1836.17,1404.73 1836.17,1404.73 1836.18,1404.73 1836.18,1404.73 1836.18,1404.73 1836.19,1404.73 1836.19,1404.73 1836.19,1404.73 1836.2,1404.73 1836.2,1404.73 1836.2,1404.73 1836.21,1404.73 1836.21,1404.73 1836.22,1404.73 1836.22,1404.73 1836.22,1404.73 1836.23,1404.73 1836.23,1404.73 1836.23,1404.73 1836.24,1404.73 1836.24,1404.73 1836.24,1404.73 1836.25,1404.73 1836.25,1404.73 1836.26,1404.73 1836.26,1404.73 1836.26,1404.73 1836.27,1404.73 1836.27,1404.73 1836.27,1404.73 1836.28,1404.73 1836.28,1404.73 1836.28,1404.73 1836.29,1404.73 1836.29,1404.73 1836.3,1404.73 1836.3,1404.73 1836.3,1404.73 1836.31,1404.73 1836.31,1404.73 1836.31,1404.73 1836.32,1404.73 1836.32,1404.73 1836.32,1404.73 1836.33,1404.73 1836.33,1404.73 1836.34,1404.73 1836.34,1404.73 1836.34,1404.73 1836.35,1404.73 1836.35,1404.73 1836.35,1404.73 1836.36,1404.73 1836.36,1404.73 1836.36,1404.73 1836.37,1404.73 1836.37,1404.73 1836.38,1404.73 1836.38,1404.73 1836.38,1404.73 1836.39,1404.73 1836.39,1404.73 1836.39,1404.73 1836.4,1404.73 1836.4,1404.73 1836.4,1404.73 1836.41,1404.73 1836.41,1404.73 1836.42,1404.73 1836.42,1404.73 1836.42,1404.73 1836.43,1404.73 1836.43,1404.73 1836.43,1404.73 1836.44,1404.73 1836.44,1404.73 1836.44,1404.73 1836.45,1404.73 1836.45,1404.73 1836.46,1404.73 1836.46,1404.72 1836.46,1404.72 1836.47,1404.72 1836.47,1404.72 1836.47,1404.72 1836.48,1404.72 1836.48,1404.72 1836.48,1404.72 1836.49,1404.72 1836.49,1404.72 1836.5,1404.72 1836.5,1404.72 1836.5,1404.72 1836.51,1404.72 1836.51,1404.72 1836.51,1404.72 1836.52,1404.72 1836.52,1404.72 1836.52,1404.72 1836.53,1404.72 1836.53,1404.72 1836.54,1404.72 1836.54,1404.72 1836.54,1404.72 1836.55,1404.72 1836.55,1404.72 1836.55,1404.72 1836.56,1404.72 1836.56,1404.72 1836.56,1404.72 1836.57,1404.72 1836.57,1404.72 1836.58,1404.72 1836.58,1404.72 1836.58,1404.72 1836.59,1404.72 1836.59,1404.72 1836.59,1404.72 1836.6,1404.72 1836.6,1404.72 1836.6,1404.72 1836.61,1404.72 1836.61,1404.72 1836.62,1404.72 1836.62,1404.72 1836.62,1404.72 1836.63,1404.72 1836.63,1404.72 1836.63,1404.72 1836.64,1404.72 1836.64,1404.72 1836.64,1404.72 1836.65,1404.72 1836.65,1404.72 1836.66,1404.72 1836.66,1404.72 1836.66,1404.72 1836.67,1404.72 1836.67,1404.72 1836.67,1404.72 1836.68,1404.72 1836.68,1404.72 1836.68,1404.72 1836.69,1404.72 1836.69,1404.72 1836.7,1404.72 1836.7,1404.72 1836.7,1404.72 1836.71,1404.72 1836.71,1404.72 1836.71,1404.72 1836.72,1404.72 1836.72,1404.72 1836.72,1404.72 1836.73,1404.72 1836.73,1404.72 1836.73,1404.72 1836.74,1404.72 1836.74,1404.72 1836.75,1404.72 1836.75,1404.72 1836.75,1404.72 1836.76,1404.72 1836.76,1404.72 1836.76,1404.72 1836.77,1404.72 1836.77,1404.72 1836.77,1404.72 1836.78,1404.72 1836.78,1404.72 1836.79,1404.72 1836.79,1404.72 1836.79,1404.72 1836.8,1404.72 1836.8,1404.72 1836.8,1404.72 1836.81,1404.72 1836.81,1404.72 1836.81,1404.72 1836.82,1404.72 1836.82,1404.72 1836.83,1404.72 1836.83,1404.72 1836.83,1404.72 1836.84,1404.72 1836.84,1404.72 1836.84,1404.72 1836.85,1404.72 1836.85,1404.72 1836.85,1404.72 1836.86,1404.71 1836.86,1404.71 1836.87,1404.71 1836.87,1404.71 1836.87,1404.71 1836.88,1404.71 1836.88,1404.71 1836.88,1404.71 1836.89,1404.71 1836.89,1404.71 1836.89,1404.71 1836.9,1404.71 1836.9,1404.71 1836.9,1404.71 1836.91,1404.71 1836.91,1404.71 1836.92,1404.71 1836.92,1404.71 1836.92,1404.71 1836.93,1404.71 1836.93,1404.71 1836.93,1404.71 1836.94,1404.71 1836.94,1404.71 1836.94,1404.71 1836.95,1404.71 1836.95,1404.71 1836.96,1404.71 1836.96,1404.71 1836.96,1404.71 1836.97,1404.71 1836.97,1404.71 1836.97,1404.71 1836.98,1404.71 1836.98,1404.71 1836.98,1404.71 1836.99,1404.71 1836.99,1404.71 1837,1404.71 1837,1404.71 1837,1404.71 1837.01,1404.71 1837.01,1404.71 1837.01,1404.71 1837.02,1404.71 1837.02,1404.71 1837.02,1404.71 1837.03,1404.71 1837.03,1404.71 1837.03,1404.71 1837.04,1404.71 1837.04,1404.71 1837.05,1404.71 1837.05,1404.71 1837.05,1404.71 1837.06,1404.71 1837.06,1404.71 1837.06,1404.71 1837.07,1404.71 1837.07,1404.71 1837.07,1404.71 1837.08,1404.71 1837.08,1404.71 1837.09,1404.71 1837.09,1404.71 1837.09,1404.71 1837.1,1404.71 1837.1,1404.71 1837.1,1404.71 1837.11,1404.71 1837.11,1404.71 1837.11,1404.71 1837.12,1404.71 1837.12,1404.71 1837.12,1404.71 1837.13,1404.71 1837.13,1404.71 1837.14,1404.71 1837.14,1404.71 1837.14,1404.71 1837.15,1404.71 1837.15,1404.71 1837.15,1404.71 1837.16,1404.71 1837.16,1404.71 1837.16,1404.71 1837.17,1404.71 1837.17,1404.71 1837.18,1404.71 1837.18,1404.71 1837.18,1404.71 1837.19,1404.71 1837.19,1404.71 1837.19,1404.71 1837.2,1404.71 1837.2,1404.71 1837.2,1404.71 1837.21,1404.71 1837.21,1404.71 1837.21,1404.71 1837.22,1404.71 1837.22,1404.71 1837.23,1404.71 1837.23,1404.71 1837.23,1404.71 1837.24,1404.71 1837.24,1404.71 1837.24,1404.71 1837.25,1404.71 1837.25,1404.71 1837.25,1404.71 1837.26,1404.7 1837.26,1404.7 1837.27,1404.7 1837.27,1404.7 1837.27,1404.7 1837.28,1404.7 1837.28,1404.7 1837.28,1404.7 1837.29,1404.7 1837.29,1404.7 1837.29,1404.7 1837.3,1404.7 1837.3,1404.7 1837.3,1404.7 1837.31,1404.7 1837.31,1404.7 1837.32,1404.7 1837.32,1404.7 1837.32,1404.7 1837.33,1404.7 1837.33,1404.7 1837.33,1404.7 1837.34,1404.7 1837.34,1404.7 1837.34,1404.7 1837.35,1404.7 1837.35,1404.7 1837.35,1404.7 1837.36,1404.7 1837.36,1404.7 1837.37,1404.7 1837.37,1404.7 1837.37,1404.7 1837.38,1404.7 1837.38,1404.7 1837.38,1404.7 1837.39,1404.7 1837.39,1404.7 1837.39,1404.7 1837.4,1404.7 1837.4,1404.7 1837.41,1404.7 1837.41,1404.7 1837.41,1404.7 1837.42,1404.7 1837.42,1404.7 1837.42,1404.7 1837.43,1404.7 1837.43,1404.7 1837.43,1404.7 1837.44,1404.7 1837.44,1404.7 1837.44,1404.7 1837.45,1404.7 1837.45,1404.7 1837.46,1404.7 1837.46,1404.7 1837.46,1404.7 1837.47,1404.7 1837.47,1404.7 1837.47,1404.7 1837.48,1404.7 1837.48,1404.7 1837.48,1404.7 1837.49,1404.7 1837.49,1404.7 1837.49,1404.7 1837.5,1404.7 1837.5,1404.7 1837.51,1404.7 1837.51,1404.7 1837.51,1404.7 1837.52,1404.7 1837.52,1404.7 1837.52,1404.7 1837.53,1404.7 1837.53,1404.7 1837.53,1404.7 1837.54,1404.7 1837.54,1404.7 1837.55,1404.7 1837.55,1404.7 1837.55,1404.7 1837.56,1404.7 1837.56,1404.7 1837.56,1404.7 1837.57,1404.7 1837.57,1404.7 1837.57,1404.7 1837.58,1404.7 1837.58,1404.7 1837.58,1404.7 1837.59,1404.7 1837.59,1404.7 1837.6,1404.7 1837.6,1404.7 1837.6,1404.7 1837.61,1404.7 1837.61,1404.7 1837.61,1404.7 1837.62,1404.7 1837.62,1404.7 1837.62,1404.7 1837.63,1404.7 1837.63,1404.7 1837.63,1404.7 1837.64,1404.7 1837.64,1404.7 1837.65,1404.7 1837.65,1404.7 1837.65,1404.7 1837.66,1404.69 1837.66,1404.69 1837.66,1404.69 1837.67,1404.69 1837.67,1404.69 1837.67,1404.69 1837.68,1404.69 1837.68,1404.69 1837.68,1404.69 1837.69,1404.69 1837.69,1404.69 1837.7,1404.69 1837.7,1404.69 1837.7,1404.69 1837.71,1404.69 1837.71,1404.69 1837.71,1404.69 1837.72,1404.69 1837.72,1404.69 1837.72,1404.69 1837.73,1404.69 1837.73,1404.69 1837.73,1404.69 1837.74,1404.69 1837.74,1404.69 1837.75,1404.69 1837.75,1404.69 1837.75,1404.69 1837.76,1404.69 1837.76,1404.69 1837.76,1404.69 1837.77,1404.69 1837.77,1404.69 1837.77,1404.69 1837.78,1404.69 1837.78,1404.69 1837.78,1404.69 1837.79,1404.69 1837.79,1404.69 1837.8,1404.69 1837.8,1404.69 1837.8,1404.69 1837.81,1404.69 1837.81,1404.69 1837.81,1404.69 1837.82,1404.69 1837.82,1404.69 1837.82,1404.69 1837.83,1404.69 1837.83,1404.69 1837.83,1404.69 1837.84,1404.69 1837.84,1404.69 1837.85,1404.69 1837.85,1404.69 1837.85,1404.69 1837.86,1404.69 1837.86,1404.69 1837.86,1404.69 1837.87,1404.69 1837.87,1404.69 1837.87,1404.69 1837.88,1404.69 1837.88,1404.69 1837.88,1404.69 1837.89,1404.69 1837.89,1404.69 1837.9,1404.69 1837.9,1404.69 1837.9,1404.69 1837.91,1404.69 1837.91,1404.69 1837.91,1404.69 1837.92,1404.69 1837.92,1404.69 1837.92,1404.69 1837.93,1404.69 1837.93,1404.69 1837.93,1404.69 1837.94,1404.69 1837.94,1404.69 1837.95,1404.69 1837.95,1404.69 1837.95,1404.69 1837.96,1404.69 1837.96,1404.69 1837.96,1404.69 1837.97,1404.69 1837.97,1404.69 1837.97,1404.69 1837.98,1404.69 1837.98,1404.69 1837.98,1404.69 1837.99,1404.69 1837.99,1404.69 1838,1404.69 1838,1404.69 1838,1404.69 1838.01,1404.69 1838.01,1404.69 1838.01,1404.69 1838.02,1404.69 1838.02,1404.69 1838.02,1404.69 1838.03,1404.69 1838.03,1404.69 1838.03,1404.69 1838.04,1404.69 1838.04,1404.69 1838.04,1404.69 1838.05,1404.69 1838.05,1404.69 1838.06,1404.68 1838.06,1404.68 1838.06,1404.68 1838.07,1404.68 1838.07,1404.68 1838.07,1404.68 1838.08,1404.68 1838.08,1404.68 1838.08,1404.68 1838.09,1404.68 1838.09,1404.68 1838.09,1404.68 1838.1,1404.68 1838.1,1404.68 1838.11,1404.68 1838.11,1404.68 1838.11,1404.68 1838.12,1404.68 1838.12,1404.68 1838.12,1404.68 1838.13,1404.68 1838.13,1404.68 1838.13,1404.68 1838.14,1404.68 1838.14,1404.68 1838.14,1404.68 1838.15,1404.68 1838.15,1404.68 1838.16,1404.68 1838.16,1404.68 1838.16,1404.68 1838.17,1404.68 1838.17,1404.68 1838.17,1404.68 1838.18,1404.68 1838.18,1404.68 1838.18,1404.68 1838.19,1404.68 1838.19,1404.68 1838.19,1404.68 1838.2,1404.68 1838.2,1404.68 1838.21,1404.68 1838.21,1404.68 1838.21,1404.68 1838.22,1404.68 1838.22,1404.68 1838.22,1404.68 1838.23,1404.68 1838.23,1404.68 1838.23,1404.68 1838.24,1404.68 1838.24,1404.68 1838.24,1404.68 1838.25,1404.68 1838.25,1404.68 1838.25,1404.68 1838.26,1404.68 1838.26,1404.68 1838.27,1404.68 1838.27,1404.68 1838.27,1404.68 1838.28,1404.68 1838.28,1404.68 1838.28,1404.68 1838.29,1404.68 1838.29,1404.68 1838.29,1404.68 1838.3,1404.68 1838.3,1404.68 1838.3,1404.68 1838.31,1404.68 1838.31,1404.68 1838.32,1404.68 1838.32,1404.68 1838.32,1404.68 1838.33,1404.68 1838.33,1404.68 1838.33,1404.68 1838.34,1404.68 1838.34,1404.68 1838.34,1404.68 1838.35,1404.68 1838.35,1404.68 1838.35,1404.68 1838.36,1404.68 1838.36,1404.68 1838.36,1404.68 1838.37,1404.68 1838.37,1404.68 1838.38,1404.68 1838.38,1404.68 1838.38,1404.68 1838.39,1404.68 1838.39,1404.68 1838.39,1404.68 1838.4,1404.68 1838.4,1404.68 1838.4,1404.68 1838.41,1404.68 1838.41,1404.68 1838.41,1404.68 1838.42,1404.68 1838.42,1404.68 1838.42,1404.68 1838.43,1404.68 1838.43,1404.68 1838.44,1404.68 1838.44,1404.68 1838.44,1404.68 1838.45,1404.68 1838.45,1404.68 1838.45,1404.67 1838.46,1404.67 1838.46,1404.67 1838.46,1404.67 1838.47,1404.67 1838.47,1404.67 1838.47,1404.67 1838.48,1404.67 1838.48,1404.67 1838.49,1404.67 1838.49,1404.67 1838.49,1404.67 1838.5,1404.67 1838.5,1404.67 1838.5,1404.67 1838.51,1404.67 1838.51,1404.67 1838.51,1404.67 1838.52,1404.67 1838.52,1404.67 1838.52,1404.67 1838.53,1404.67 1838.53,1404.67 1838.53,1404.67 1838.54,1404.67 1838.54,1404.67 1838.55,1404.67 1838.55,1404.67 1838.55,1404.67 1838.56,1404.67 1838.56,1404.67 1838.56,1404.67 1838.57,1404.67 1838.57,1404.67 1838.57,1404.67 1838.58,1404.67 1838.58,1404.67 1838.58,1404.67 1838.59,1404.67 1838.59,1404.67 1838.59,1404.67 1838.6,1404.67 1838.6,1404.67 1838.61,1404.67 1838.61,1404.67 1838.61,1404.67 1838.62,1404.67 1838.62,1404.67 1838.62,1404.67 1838.63,1404.67 1838.63,1404.67 1838.63,1404.67 1838.64,1404.67 1838.64,1404.67 1838.64,1404.67 1838.65,1404.67 1838.65,1404.67 1838.65,1404.67 1838.66,1404.67 1838.66,1404.67 1838.67,1404.67 1838.67,1404.67 1838.67,1404.67 1838.68,1404.67 1838.68,1404.67 1838.68,1404.67 1838.69,1404.67 1838.69,1404.67 1838.69,1404.67 1838.7,1404.67 1838.7,1404.67 1838.7,1404.67 1838.71,1404.67 1838.71,1404.67 1838.71,1404.67 1838.72,1404.67 1838.72,1404.67 1838.73,1404.67 1838.73,1404.67 1838.73,1404.67 1838.74,1404.67 1838.74,1404.67 1838.74,1404.67 1838.75,1404.67 1838.75,1404.67 1838.75,1404.67 1838.76,1404.67 1838.76,1404.67 1838.76,1404.67 1838.77,1404.67 1838.77,1404.67 1838.77,1404.67 1838.78,1404.67 1838.78,1404.67 1838.79,1404.67 1838.79,1404.67 1838.79,1404.67 1838.8,1404.67 1838.8,1404.67 1838.8,1404.67 1838.81,1404.67 1838.81,1404.67 1838.81,1404.67 1838.82,1404.67 1838.82,1404.67 1838.82,1404.67 1838.83,1404.67 1838.83,1404.67 1838.83,1404.67 1838.84,1404.67 1838.84,1404.67 1838.85,1404.67 1838.85,1404.67 1838.85,1404.66 1838.86,1404.66 1838.86,1404.66 1838.86,1404.66 1838.87,1404.66 1838.87,1404.66 1838.87,1404.66 1838.88,1404.66 1838.88,1404.66 1838.88,1404.66 1838.89,1404.66 1838.89,1404.66 1838.89,1404.66 1838.9,1404.66 1838.9,1404.66 1838.91,1404.66 1838.91,1404.66 1838.91,1404.66 1838.92,1404.66 1838.92,1404.66 1838.92,1404.66 1838.93,1404.66 1838.93,1404.66 1838.93,1404.66 1838.94,1404.66 1838.94,1404.66 1838.94,1404.66 1838.95,1404.66 1838.95,1404.66 1838.95,1404.66 1838.96,1404.66 1838.96,1404.66 1838.97,1404.66 1838.97,1404.66 1838.97,1404.66 1838.98,1404.66 1838.98,1404.66 1838.98,1404.66 1838.99,1404.66 1838.99,1404.66 1838.99,1404.66 1839,1404.66 1839,1404.66 1839,1404.66 1839.01,1404.66 1839.01,1404.66 1839.01,1404.66 1839.02,1404.66 1839.02,1404.66 1839.03,1404.66 1839.03,1404.66 1839.03,1404.66 1839.04,1404.66 1839.04,1404.66 1839.04,1404.66 1839.05,1404.66 1839.05,1404.66 1839.05,1404.66 1839.06,1404.66 1839.06,1404.66 1839.06,1404.66 1839.07,1404.66 1839.07,1404.66 1839.07,1404.66 1839.08,1404.66 1839.08,1404.66 1839.08,1404.66 1839.09,1404.66 1839.09,1404.66 1839.1,1404.66 1839.1,1404.66 1839.1,1404.66 1839.11,1404.66 1839.11,1404.66 1839.11,1404.66 1839.12,1404.66 1839.12,1404.66 1839.12,1404.66 1839.13,1404.66 1839.13,1404.66 1839.13,1404.66 1839.14,1404.66 1839.14,1404.66 1839.14,1404.66 1839.15,1404.66 1839.15,1404.66 1839.16,1404.66 1839.16,1404.66 1839.16,1404.66 1839.17,1404.66 1839.17,1404.66 1839.17,1404.66 1839.18,1404.66 1839.18,1404.66 1839.18,1404.66 1839.19,1404.66 1839.19,1404.66 1839.19,1404.66 1839.2,1404.66 1839.2,1404.66 1839.2,1404.66 1839.21,1404.66 1839.21,1404.66 1839.21,1404.66 1839.22,1404.66 1839.22,1404.66 1839.23,1404.66 1839.23,1404.66 1839.23,1404.66 1839.24,1404.66 1839.24,1404.66 1839.24,1404.66 1839.25,1404.66 1839.25,1404.65 1839.25,1404.65 1839.26,1404.65 1839.26,1404.65 1839.26,1404.65 1839.27,1404.65 1839.27,1404.65 1839.27,1404.65 1839.28,1404.65 1839.28,1404.65 1839.28,1404.65 1839.29,1404.65 1839.29,1404.65 1839.3,1404.65 1839.3,1404.65 1839.3,1404.65 1839.31,1404.65 1839.31,1404.65 1839.31,1404.65 1839.32,1404.65 1839.32,1404.65 1839.32,1404.65 1839.33,1404.65 1839.33,1404.65 1839.33,1404.65 1839.34,1404.65 1839.34,1404.65 1839.34,1404.65 1839.35,1404.65 1839.35,1404.65 1839.36,1404.65 1839.36,1404.65 1839.36,1404.65 1839.37,1404.65 1839.37,1404.65 1839.37,1404.65 1839.38,1404.65 1839.38,1404.65 1839.38,1404.65 1839.39,1404.65 1839.39,1404.65 1839.39,1404.65 1839.4,1404.65 1839.4,1404.65 1839.4,1404.65 1839.41,1404.65 1839.41,1404.65 1839.41,1404.65 1839.42,1404.65 1839.42,1404.65 1839.43,1404.65 1839.43,1404.65 1839.43,1404.65 1839.44,1404.65 1839.44,1404.65 1839.44,1404.65 1839.45,1404.65 1839.45,1404.65 1839.45,1404.65 1839.46,1404.65 1839.46,1404.65 1839.46,1404.65 1839.47,1404.65 1839.47,1404.65 1839.47,1404.65 1839.48,1404.65 1839.48,1404.65 1839.48,1404.65 1839.49,1404.65 1839.49,1404.65 1839.5,1404.65 1839.5,1404.65 1839.5,1404.65 1839.51,1404.65 1839.51,1404.65 1839.51,1404.65 1839.52,1404.65 1839.52,1404.65 1839.52,1404.65 1839.53,1404.65 1839.53,1404.65 1839.53,1404.65 1839.54,1404.65 1839.54,1404.65 1839.54,1404.65 1839.55,1404.65 1839.55,1404.65 1839.55,1404.65 1839.56,1404.65 1839.56,1404.65 1839.56,1404.65 1839.57,1404.65 1839.57,1404.65 1839.58,1404.65 1839.58,1404.65 1839.58,1404.65 1839.59,1404.65 1839.59,1404.65 1839.59,1404.65 1839.6,1404.65 1839.6,1404.65 1839.6,1404.65 1839.61,1404.65 1839.61,1404.65 1839.61,1404.65 1839.62,1404.65 1839.62,1404.65 1839.62,1404.65 1839.63,1404.65 1839.63,1404.65 1839.63,1404.65 1839.64,1404.65 1839.64,1404.65 1839.65,1404.64 1839.65,1404.64 1839.65,1404.64 1839.66,1404.64 1839.66,1404.64 1839.66,1404.64 1839.67,1404.64 1839.67,1404.64 1839.67,1404.64 1839.68,1404.64 1839.68,1404.64 1839.68,1404.64 1839.69,1404.64 1839.69,1404.64 1839.69,1404.64 1839.7,1404.64 1839.7,1404.64 1839.7,1404.64 1839.71,1404.64 1839.71,1404.64 1839.72,1404.64 1839.72,1404.64 1839.72,1404.64 1839.73,1404.64 1839.73,1404.64 1839.73,1404.64 1839.74,1404.64 1839.74,1404.64 1839.74,1404.64 1839.75,1404.64 1839.75,1404.64 1839.75,1404.64 1839.76,1404.64 1839.76,1404.64 1839.76,1404.64 1839.77,1404.64 1839.77,1404.64 1839.77,1404.64 1839.78,1404.64 1839.78,1404.64 1839.78,1404.64 1839.79,1404.64 1839.79,1404.64 1839.8,1404.64 1839.8,1404.64 1839.8,1404.64 1839.81,1404.64 1839.81,1404.64 1839.81,1404.64 1839.82,1404.64 1839.82,1404.64 1839.82,1404.64 1839.83,1404.64 1839.83,1404.64 1839.83,1404.64 1839.84,1404.64 1839.84,1404.64 1839.84,1404.64 1839.85,1404.64 1839.85,1404.64 1839.85,1404.64 1839.86,1404.64 1839.86,1404.64 1839.86,1404.64 1839.87,1404.64 1839.87,1404.64 1839.88,1404.64 1839.88,1404.64 1839.88,1404.64 1839.89,1404.64 1839.89,1404.64 1839.89,1404.64 1839.9,1404.64 1839.9,1404.64 1839.9,1404.64 1839.91,1404.64 1839.91,1404.64 1839.91,1404.64 1839.92,1404.64 1839.92,1404.64 1839.92,1404.64 1839.93,1404.64 1839.93,1404.64 1839.93,1404.64 1839.94,1404.64 1839.94,1404.64 1839.94,1404.64 1839.95,1404.64 1839.95,1404.64 1839.96,1404.64 1839.96,1404.64 1839.96,1404.64 1839.97,1404.64 1839.97,1404.64 1839.97,1404.64 1839.98,1404.64 1839.98,1404.64 1839.98,1404.64 1839.99,1404.64 1839.99,1404.64 1839.99,1404.64 1840,1404.64 1840,1404.64 1840,1404.64 1840.01,1404.64 1840.01,1404.64 1840.01,1404.64 1840.02,1404.64 1840.02,1404.64 1840.02,1404.64 1840.03,1404.64 1840.03,1404.64 1840.04,1404.64 1840.04,1404.64 1840.04,1404.63 1840.05,1404.63 1840.05,1404.63 1840.05,1404.63 1840.06,1404.63 1840.06,1404.63 1840.06,1404.63 1840.07,1404.63 1840.07,1404.63 1840.07,1404.63 1840.08,1404.63 1840.08,1404.63 1840.08,1404.63 1840.09,1404.63 1840.09,1404.63 1840.09,1404.63 1840.1,1404.63 1840.1,1404.63 1840.1,1404.63 1840.11,1404.63 1840.11,1404.63 1840.12,1404.63 1840.12,1404.63 1840.12,1404.63 1840.13,1404.63 1840.13,1404.63 1840.13,1404.63 1840.14,1404.63 1840.14,1404.63 1840.14,1404.63 1840.15,1404.63 1840.15,1404.63 1840.15,1404.63 1840.16,1404.63 1840.16,1404.63 1840.16,1404.63 1840.17,1404.63 1840.17,1404.63 1840.17,1404.63 1840.18,1404.63 1840.18,1404.63 1840.18,1404.63 1840.19,1404.63 1840.19,1404.63 1840.19,1404.63 1840.2,1404.63 1840.2,1404.63 1840.21,1404.63 1840.21,1404.63 1840.21,1404.63 1840.22,1404.63 1840.22,1404.63 1840.22,1404.63 1840.23,1404.63 1840.23,1404.63 1840.23,1404.63 1840.24,1404.63 1840.24,1404.63 1840.24,1404.63 1840.25,1404.63 1840.25,1404.63 1840.25,1404.63 1840.26,1404.63 1840.26,1404.63 1840.26,1404.63 1840.27,1404.63 1840.27,1404.63 1840.27,1404.63 1840.28,1404.63 1840.28,1404.63 1840.29,1404.63 1840.29,1404.63 1840.29,1404.63 1840.3,1404.63 1840.3,1404.63 1840.3,1404.63 1840.31,1404.63 1840.31,1404.63 1840.31,1404.63 1840.32,1404.63 1840.32,1404.63 1840.32,1404.63 1840.33,1404.63 1840.33,1404.63 1840.33,1404.63 1840.34,1404.63 1840.34,1404.63 1840.34,1404.63 1840.35,1404.63 1840.35,1404.63 1840.35,1404.63 1840.36,1404.63 1840.36,1404.63 1840.36,1404.63 1840.37,1404.63 1840.37,1404.63 1840.38,1404.63 1840.38,1404.63 1840.38,1404.63 1840.39,1404.63 1840.39,1404.63 1840.39,1404.63 1840.4,1404.63 1840.4,1404.63 1840.4,1404.63 1840.41,1404.63 1840.41,1404.63 1840.41,1404.63 1840.42,1404.63 1840.42,1404.63 1840.42,1404.63 1840.43,1404.63 1840.43,1404.63 1840.43,1404.63 1840.44,1404.63 1840.44,1404.62 1840.44,1404.62 1840.45,1404.62 1840.45,1404.62 1840.45,1404.62 1840.46,1404.62 1840.46,1404.62 1840.46,1404.62 1840.47,1404.62 1840.47,1404.62 1840.48,1404.62 1840.48,1404.62 1840.48,1404.62 1840.49,1404.62 1840.49,1404.62 1840.49,1404.62 1840.5,1404.62 1840.5,1404.62 1840.5,1404.62 1840.51,1404.62 1840.51,1404.62 1840.51,1404.62 1840.52,1404.62 1840.52,1404.62 1840.52,1404.62 1840.53,1404.62 1840.53,1404.62 1840.53,1404.62 1840.54,1404.62 1840.54,1404.62 1840.54,1404.62 1840.55,1404.62 1840.55,1404.62 1840.55,1404.62 1840.56,1404.62 1840.56,1404.62 1840.57,1404.62 1840.57,1404.62 1840.57,1404.62 1840.58,1404.62 1840.58,1404.62 1840.58,1404.62 1840.59,1404.62 1840.59,1404.62 1840.59,1404.62 1840.6,1404.62 1840.6,1404.62 1840.6,1404.62 1840.61,1404.62 1840.61,1404.62 1840.61,1404.62 1840.62,1404.62 1840.62,1404.62 1840.62,1404.62 1840.63,1404.62 1840.63,1404.62 1840.63,1404.62 1840.64,1404.62 1840.64,1404.62 1840.64,1404.62 1840.65,1404.62 1840.65,1404.62 1840.65,1404.62 1840.66,1404.62 1840.66,1404.62 1840.67,1404.62 1840.67,1404.62 1840.67,1404.62 1840.68,1404.62 1840.68,1404.62 1840.68,1404.62 1840.69,1404.62 1840.69,1404.62 1840.69,1404.62 1840.7,1404.62 1840.7,1404.62 1840.7,1404.62 1840.71,1404.62 1840.71,1404.62 1840.71,1404.62 1840.72,1404.62 1840.72,1404.62 1840.72,1404.62 1840.73,1404.62 1840.73,1404.62 1840.73,1404.62 1840.74,1404.62 1840.74,1404.62 1840.74,1404.62 1840.75,1404.62 1840.75,1404.62 1840.75,1404.62 1840.76,1404.62 1840.76,1404.62 1840.77,1404.62 1840.77,1404.62 1840.77,1404.62 1840.78,1404.62 1840.78,1404.62 1840.78,1404.62 1840.79,1404.62 1840.79,1404.62 1840.79,1404.62 1840.8,1404.62 1840.8,1404.62 1840.8,1404.62 1840.81,1404.62 1840.81,1404.62 1840.81,1404.62 1840.82,1404.62 1840.82,1404.62 1840.82,1404.62 1840.83,1404.62 1840.83,1404.62 1840.83,1404.62 1840.84,1404.61 1840.84,1404.61 1840.84,1404.61 1840.85,1404.61 1840.85,1404.61 1840.85,1404.61 1840.86,1404.61 1840.86,1404.61 1840.86,1404.61 1840.87,1404.61 1840.87,1404.61 1840.88,1404.61 1840.88,1404.61 1840.88,1404.61 1840.89,1404.61 1840.89,1404.61 1840.89,1404.61 1840.9,1404.61 1840.9,1404.61 1840.9,1404.61 1840.91,1404.61 1840.91,1404.61 1840.91,1404.61 1840.92,1404.61 1840.92,1404.61 1840.92,1404.61 1840.93,1404.61 1840.93,1404.61 1840.93,1404.61 1840.94,1404.61 1840.94,1404.61 1840.94,1404.61 1840.95,1404.61 1840.95,1404.61 1840.95,1404.61 1840.96,1404.61 1840.96,1404.61 1840.96,1404.61 1840.97,1404.61 1840.97,1404.61 1840.97,1404.61 1840.98,1404.61 1840.98,1404.61 1840.99,1404.61 1840.99,1404.61 1840.99,1404.61 1841,1404.61 1841,1404.61 1841,1404.61 1841.01,1404.61 1841.01,1404.61 1841.01,1404.61 1841.02,1404.61 1841.02,1404.61 1841.02,1404.61 1841.03,1404.61 1841.03,1404.61 1841.03,1404.61 1841.04,1404.61 1841.04,1404.61 1841.04,1404.61 1841.05,1404.61 1841.05,1404.61 1841.05,1404.61 1841.06,1404.61 1841.06,1404.61 1841.06,1404.61 1841.07,1404.61 1841.07,1404.61 1841.07,1404.61 1841.08,1404.61 1841.08,1404.61 1841.08,1404.61 1841.09,1404.61 1841.09,1404.61 1841.1,1404.61 1841.1,1404.61 1841.1,1404.61 1841.11,1404.61 1841.11,1404.61 1841.11,1404.61 1841.12,1404.61 1841.12,1404.61 1841.12,1404.61 1841.13,1404.61 1841.13,1404.61 1841.13,1404.61 1841.14,1404.61 1841.14,1404.61 1841.14,1404.61 1841.15,1404.61 1841.15,1404.61 1841.15,1404.61 1841.16,1404.61 1841.16,1404.61 1841.16,1404.61 1841.17,1404.61 1841.17,1404.61 1841.17,1404.61 1841.18,1404.61 1841.18,1404.61 1841.18,1404.61 1841.19,1404.61 1841.19,1404.61 1841.19,1404.61 1841.2,1404.61 1841.2,1404.61 1841.2,1404.61 1841.21,1404.61 1841.21,1404.61 1841.22,1404.61 1841.22,1404.61 1841.22,1404.61 1841.23,1404.61 1841.23,1404.61 1841.23,1404.6 1841.24,1404.6 1841.24,1404.6 1841.24,1404.6 1841.25,1404.6 1841.25,1404.6 1841.25,1404.6 1841.26,1404.6 1841.26,1404.6 1841.26,1404.6 1841.27,1404.6 1841.27,1404.6 1841.27,1404.6 1841.28,1404.6 1841.28,1404.6 1841.28,1404.6 1841.29,1404.6 1841.29,1404.6 1841.29,1404.6 1841.3,1404.6 1841.3,1404.6 1841.3,1404.6 1841.31,1404.6 1841.31,1404.6 1841.31,1404.6 1841.32,1404.6 1841.32,1404.6 1841.32,1404.6 1841.33,1404.6 1841.33,1404.6 1841.33,1404.6 1841.34,1404.6 1841.34,1404.6 1841.35,1404.6 1841.35,1404.6 1841.35,1404.6 1841.36,1404.6 1841.36,1404.6 1841.36,1404.6 1841.37,1404.6 1841.37,1404.6 1841.37,1404.6 1841.38,1404.6 1841.38,1404.6 1841.38,1404.6 1841.39,1404.6 1841.39,1404.6 1841.39,1404.6 1841.4,1404.6 1841.4,1404.6 1841.4,1404.6 1841.41,1404.6 1841.41,1404.6 1841.41,1404.6 1841.42,1404.6 1841.42,1404.6 1841.42,1404.6 1841.43,1404.6 1841.43,1404.6 1841.43,1404.6 1841.44,1404.6 1841.44,1404.6 1841.44,1404.6 1841.45,1404.6 1841.45,1404.6 1841.45,1404.6 1841.46,1404.6 1841.46,1404.6 1841.46,1404.6 1841.47,1404.6 1841.47,1404.6 1841.48,1404.6 1841.48,1404.6 1841.48,1404.6 1841.49,1404.6 1841.49,1404.6 1841.49,1404.6 1841.5,1404.6 1841.5,1404.6 1841.5,1404.6 1841.51,1404.6 1841.51,1404.6 1841.51,1404.6 1841.52,1404.6 1841.52,1404.6 1841.52,1404.6 1841.53,1404.6 1841.53,1404.6 1841.53,1404.6 1841.54,1404.6 1841.54,1404.6 1841.54,1404.6 1841.55,1404.6 1841.55,1404.6 1841.55,1404.6 1841.56,1404.6 1841.56,1404.6 1841.56,1404.6 1841.57,1404.6 1841.57,1404.6 1841.57,1404.6 1841.58,1404.6 1841.58,1404.6 1841.58,1404.6 1841.59,1404.6 1841.59,1404.6 1841.59,1404.6 1841.6,1404.6 1841.6,1404.6 1841.6,1404.6 1841.61,1404.6 1841.61,1404.6 1841.62,1404.6 1841.62,1404.6 1841.62,1404.6 1841.63,1404.6 1841.63,1404.59 1841.63,1404.59 1841.64,1404.59 1841.64,1404.59 1841.64,1404.59 1841.65,1404.59 1841.65,1404.59 1841.65,1404.59 1841.66,1404.59 1841.66,1404.59 1841.66,1404.59 1841.67,1404.59 1841.67,1404.59 1841.67,1404.59 1841.68,1404.59 1841.68,1404.59 1841.68,1404.59 1841.69,1404.59 1841.69,1404.59 1841.69,1404.59 1841.7,1404.59 1841.7,1404.59 1841.7,1404.59 1841.71,1404.59 1841.71,1404.59 1841.71,1404.59 1841.72,1404.59 1841.72,1404.59 1841.72,1404.59 1841.73,1404.59 1841.73,1404.59 1841.73,1404.59 1841.74,1404.59 1841.74,1404.59 1841.74,1404.59 1841.75,1404.59 1841.75,1404.59 1841.75,1404.59 1841.76,1404.59 1841.76,1404.59 1841.76,1404.59 1841.77,1404.59 1841.77,1404.59 1841.78,1404.59 1841.78,1404.59 1841.78,1404.59 1841.79,1404.59 1841.79,1404.59 1841.79,1404.59 1841.8,1404.59 1841.8,1404.59 1841.8,1404.59 1841.81,1404.59 1841.81,1404.59 1841.81,1404.59 1841.82,1404.59 1841.82,1404.59 1841.82,1404.59 1841.83,1404.59 1841.83,1404.59 1841.83,1404.59 1841.84,1404.59 1841.84,1404.59 1841.84,1404.59 1841.85,1404.59 1841.85,1404.59 1841.85,1404.59 1841.86,1404.59 1841.86,1404.59 1841.86,1404.59 1841.87,1404.59 1841.87,1404.59 1841.87,1404.59 1841.88,1404.59 1841.88,1404.59 1841.88,1404.59 1841.89,1404.59 1841.89,1404.59 1841.89,1404.59 1841.9,1404.59 1841.9,1404.59 1841.9,1404.59 1841.91,1404.59 1841.91,1404.59 1841.91,1404.59 1841.92,1404.59 1841.92,1404.59 1841.92,1404.59 1841.93,1404.59 1841.93,1404.59 1841.93,1404.59 1841.94,1404.59 1841.94,1404.59 1841.95,1404.59 1841.95,1404.59 1841.95,1404.59 1841.96,1404.59 1841.96,1404.59 1841.96,1404.59 1841.97,1404.59 1841.97,1404.59 1841.97,1404.59 1841.98,1404.59 1841.98,1404.59 1841.98,1404.59 1841.99,1404.59 1841.99,1404.59 1841.99,1404.59 1842,1404.59 1842,1404.59 1842,1404.59 1842.01,1404.59 1842.01,1404.59 1842.01,1404.59 1842.02,1404.59 1842.02,1404.59 1842.02,1404.59 1842.03,1404.58 1842.03,1404.58 1842.03,1404.58 1842.04,1404.58 1842.04,1404.58 1842.04,1404.58 1842.05,1404.58 1842.05,1404.58 1842.05,1404.58 1842.06,1404.58 1842.06,1404.58 1842.06,1404.58 1842.07,1404.58 1842.07,1404.58 1842.07,1404.58 1842.08,1404.58 1842.08,1404.58 1842.08,1404.58 1842.09,1404.58 1842.09,1404.58 1842.09,1404.58 1842.1,1404.58 1842.1,1404.58 1842.1,1404.58 1842.11,1404.58 1842.11,1404.58 1842.11,1404.58 1842.12,1404.58 1842.12,1404.58 1842.12,1404.58 1842.13,1404.58 1842.13,1404.58 1842.14,1404.58 1842.14,1404.58 1842.14,1404.58 1842.15,1404.58 1842.15,1404.58 1842.15,1404.58 1842.16,1404.58 1842.16,1404.58 1842.16,1404.58 1842.17,1404.58 1842.17,1404.58 1842.17,1404.58 1842.18,1404.58 1842.18,1404.58 1842.18,1404.58 1842.19,1404.58 1842.19,1404.58 1842.19,1404.58 1842.2,1404.58 1842.2,1404.58 1842.2,1404.58 1842.21,1404.58 1842.21,1404.58 1842.21,1404.58 1842.22,1404.58 1842.22,1404.58 1842.22,1404.58 1842.23,1404.58 1842.23,1404.58 1842.23,1404.58 1842.24,1404.58 1842.24,1404.58 1842.24,1404.58 1842.25,1404.58 1842.25,1404.58 1842.25,1404.58 1842.26,1404.58 1842.26,1404.58 1842.26,1404.58 1842.27,1404.58 1842.27,1404.58 1842.27,1404.58 1842.28,1404.58 1842.28,1404.58 1842.28,1404.58 1842.29,1404.58 1842.29,1404.58 1842.29,1404.58 1842.3,1404.58 1842.3,1404.58 1842.3,1404.58 1842.31,1404.58 1842.31,1404.58 1842.31,1404.58 1842.32,1404.58 1842.32,1404.58 1842.32,1404.58 1842.33,1404.58 1842.33,1404.58 1842.33,1404.58 1842.34,1404.58 1842.34,1404.58 1842.35,1404.58 1842.35,1404.58 1842.35,1404.58 1842.36,1404.58 1842.36,1404.58 1842.36,1404.58 1842.37,1404.58 1842.37,1404.58 1842.37,1404.58 1842.38,1404.58 1842.38,1404.58 1842.38,1404.58 1842.39,1404.58 1842.39,1404.58 1842.39,1404.58 1842.4,1404.58 1842.4,1404.58 1842.4,1404.58 1842.41,1404.58 1842.41,1404.58 1842.41,1404.58 1842.42,1404.58 1842.42,1404.58 1842.42,1404.57 1842.43,1404.57 1842.43,1404.57 1842.43,1404.57 1842.44,1404.57 1842.44,1404.57 1842.44,1404.57 1842.45,1404.57 1842.45,1404.57 1842.45,1404.57 1842.46,1404.57 1842.46,1404.57 1842.46,1404.57 1842.47,1404.57 1842.47,1404.57 1842.47,1404.57 1842.48,1404.57 1842.48,1404.57 1842.48,1404.57 1842.49,1404.57 1842.49,1404.57 1842.49,1404.57 1842.5,1404.57 1842.5,1404.57 1842.5,1404.57 1842.51,1404.57 1842.51,1404.57 1842.51,1404.57 1842.52,1404.57 1842.52,1404.57 1842.52,1404.57 1842.53,1404.57 1842.53,1404.57 1842.53,1404.57 1842.54,1404.57 1842.54,1404.57 1842.54,1404.57 1842.55,1404.57 1842.55,1404.57 1842.55,1404.57 1842.56,1404.57 1842.56,1404.57 1842.56,1404.57 1842.57,1404.57 1842.57,1404.57 1842.57,1404.57 1842.58,1404.57 1842.58,1404.57 1842.58,1404.57 1842.59,1404.57 1842.59,1404.57 1842.59,1404.57 1842.6,1404.57 1842.6,1404.57 1842.6,1404.57 1842.61,1404.57 1842.61,1404.57 1842.62,1404.57 1842.62,1404.57 1842.62,1404.57 1842.63,1404.57 1842.63,1404.57 1842.63,1404.57 1842.64,1404.57 1842.64,1404.57 1842.64,1404.57 1842.65,1404.57 1842.65,1404.57 1842.65,1404.57 1842.66,1404.57 1842.66,1404.57 1842.66,1404.57 1842.67,1404.57 1842.67,1404.57 1842.67,1404.57 1842.68,1404.57 1842.68,1404.57 1842.68,1404.57 1842.69,1404.57 1842.69,1404.57 1842.69,1404.57 1842.7,1404.57 1842.7,1404.57 1842.7,1404.57 1842.71,1404.57 1842.71,1404.57 1842.71,1404.57 1842.72,1404.57 1842.72,1404.57 1842.72,1404.57 1842.73,1404.57 1842.73,1404.57 1842.73,1404.57 1842.74,1404.57 1842.74,1404.57 1842.74,1404.57 1842.75,1404.57 1842.75,1404.57 1842.75,1404.57 1842.76,1404.57 1842.76,1404.57 1842.76,1404.57 1842.77,1404.57 1842.77,1404.57 1842.77,1404.57 1842.78,1404.57 1842.78,1404.57 1842.78,1404.57 1842.79,1404.57 1842.79,1404.57 1842.79,1404.57 1842.8,1404.57 1842.8,1404.57 1842.8,1404.57 1842.81,1404.57 1842.81,1404.57 1842.81,1404.57 1842.82,1404.56 1842.82,1404.56 1842.82,1404.56 1842.83,1404.56 1842.83,1404.56 1842.83,1404.56 1842.84,1404.56 1842.84,1404.56 1842.84,1404.56 1842.85,1404.56 1842.85,1404.56 1842.85,1404.56 1842.86,1404.56 1842.86,1404.56 1842.86,1404.56 1842.87,1404.56 1842.87,1404.56 1842.87,1404.56 1842.88,1404.56 1842.88,1404.56 1842.88,1404.56 1842.89,1404.56 1842.89,1404.56 1842.89,1404.56 1842.9,1404.56 1842.9,1404.56 1842.9,1404.56 1842.91,1404.56 1842.91,1404.56 1842.91,1404.56 1842.92,1404.56 1842.92,1404.56 1842.92,1404.56 1842.93,1404.56 1842.93,1404.56 1842.93,1404.56 1842.94,1404.56 1842.94,1404.56 1842.94,1404.56 1842.95,1404.56 1842.95,1404.56 1842.95,1404.56 1842.96,1404.56 1842.96,1404.56 1842.96,1404.56 1842.97,1404.56 1842.97,1404.56 1842.97,1404.56 1842.98,1404.56 1842.98,1404.56 1842.99,1404.56 1842.99,1404.56 1842.99,1404.56 1843,1404.56 1843,1404.56 1843,1404.56 1843.01,1404.56 1843.01,1404.56 1843.01,1404.56 1843.02,1404.56 1843.02,1404.56 1843.02,1404.56 1843.03,1404.56 1843.03,1404.56 1843.03,1404.56 1843.04,1404.56 1843.04,1404.56 1843.04,1404.56 1843.05,1404.56 1843.05,1404.56 1843.05,1404.56 1843.06,1404.56 1843.06,1404.56 1843.06,1404.56 1843.07,1404.56 1843.07,1404.56 1843.07,1404.56 1843.08,1404.56 1843.08,1404.56 1843.08,1404.56 1843.09,1404.56 1843.09,1404.56 1843.09,1404.56 1843.1,1404.56 1843.1,1404.56 1843.1,1404.56 1843.11,1404.56 1843.11,1404.56 1843.11,1404.56 1843.12,1404.56 1843.12,1404.56 1843.12,1404.56 1843.13,1404.56 1843.13,1404.56 1843.13,1404.56 1843.14,1404.56 1843.14,1404.56 1843.14,1404.56 1843.15,1404.56 1843.15,1404.56 1843.15,1404.56 1843.16,1404.56 1843.16,1404.56 1843.16,1404.56 1843.17,1404.56 1843.17,1404.56 1843.17,1404.56 1843.18,1404.56 1843.18,1404.56 1843.18,1404.56 1843.19,1404.56 1843.19,1404.56 1843.19,1404.56 1843.2,1404.56 1843.2,1404.56 1843.2,1404.56 1843.21,1404.56 1843.21,1404.56 1843.21,1404.55 1843.22,1404.55 1843.22,1404.55 1843.22,1404.55 1843.23,1404.55 1843.23,1404.55 1843.23,1404.55 1843.24,1404.55 1843.24,1404.55 1843.24,1404.55 1843.25,1404.55 1843.25,1404.55 1843.25,1404.55 1843.26,1404.55 1843.26,1404.55 1843.26,1404.55 1843.27,1404.55 1843.27,1404.55 1843.27,1404.55 1843.28,1404.55 1843.28,1404.55 1843.28,1404.55 1843.29,1404.55 1843.29,1404.55 1843.29,1404.55 1843.3,1404.55 1843.3,1404.55 1843.3,1404.55 1843.31,1404.55 1843.31,1404.55 1843.31,1404.55 1843.32,1404.55 1843.32,1404.55 1843.32,1404.55 1843.33,1404.55 1843.33,1404.55 1843.33,1404.55 1843.34,1404.55 1843.34,1404.55 1843.34,1404.55 1843.35,1404.55 1843.35,1404.55 1843.35,1404.55 1843.36,1404.55 1843.36,1404.55 1843.36,1404.55 1843.37,1404.55 1843.37,1404.55 1843.37,1404.55 1843.38,1404.55 1843.38,1404.55 1843.38,1404.55 1843.39,1404.55 1843.39,1404.55 1843.39,1404.55 1843.4,1404.55 1843.4,1404.55 1843.4,1404.55 1843.41,1404.55 1843.41,1404.55 1843.41,1404.55 1843.42,1404.55 1843.42,1404.55 1843.42,1404.55 1843.43,1404.55 1843.43,1404.55 1843.43,1404.55 1843.44,1404.55 1843.44,1404.55 1843.44,1404.55 1843.45,1404.55 1843.45,1404.55 1843.45,1404.55 1843.46,1404.55 1843.46,1404.55 1843.46,1404.55 1843.47,1404.55 1843.47,1404.55 1843.47,1404.55 1843.48,1404.55 1843.48,1404.55 1843.48,1404.55 1843.49,1404.55 1843.49,1404.55 1843.49,1404.55 1843.5,1404.55 1843.5,1404.55 1843.5,1404.55 1843.51,1404.55 1843.51,1404.55 1843.51,1404.55 1843.52,1404.55 1843.52,1404.55 1843.52,1404.55 1843.53,1404.55 1843.53,1404.55 1843.53,1404.55 1843.54,1404.55 1843.54,1404.55 1843.54,1404.55 1843.55,1404.55 1843.55,1404.55 1843.55,1404.55 1843.56,1404.55 1843.56,1404.55 1843.56,1404.55 1843.57,1404.55 1843.57,1404.55 1843.57,1404.55 1843.58,1404.55 1843.58,1404.55 1843.58,1404.55 1843.59,1404.55 1843.59,1404.55 1843.59,1404.55 1843.6,1404.55 1843.6,1404.55 1843.6,1404.55 1843.61,1404.54 1843.61,1404.54 1843.61,1404.54 1843.62,1404.54 1843.62,1404.54 1843.62,1404.54 1843.63,1404.54 1843.63,1404.54 1843.63,1404.54 1843.64,1404.54 1843.64,1404.54 1843.64,1404.54 1843.65,1404.54 1843.65,1404.54 1843.65,1404.54 1843.66,1404.54 1843.66,1404.54 1843.66,1404.54 1843.67,1404.54 1843.67,1404.54 1843.67,1404.54 1843.68,1404.54 1843.68,1404.54 1843.68,1404.54 1843.69,1404.54 1843.69,1404.54 1843.69,1404.54 1843.7,1404.54 1843.7,1404.54 1843.7,1404.54 1843.71,1404.54 1843.71,1404.54 1843.71,1404.54 1843.72,1404.54 1843.72,1404.54 1843.72,1404.54 1843.73,1404.54 1843.73,1404.54 1843.73,1404.54 1843.74,1404.54 1843.74,1404.54 1843.74,1404.54 1843.75,1404.54 1843.75,1404.54 1843.75,1404.54 1843.76,1404.54 1843.76,1404.54 1843.76,1404.54 1843.77,1404.54 1843.77,1404.54 1843.77,1404.54 1843.78,1404.54 1843.78,1404.54 1843.78,1404.54 1843.79,1404.54 1843.79,1404.54 1843.79,1404.54 1843.8,1404.54 1843.8,1404.54 1843.8,1404.54 1843.81,1404.54 1843.81,1404.54 1843.81,1404.54 1843.82,1404.54 1843.82,1404.54 1843.82,1404.54 1843.83,1404.54 1843.83,1404.54 1843.83,1404.54 1843.84,1404.54 1843.84,1404.54 1843.84,1404.54 1843.85,1404.54 1843.85,1404.54 1843.85,1404.54 1843.86,1404.54 1843.86,1404.54 1843.86,1404.54 1843.87,1404.54 1843.87,1404.54 1843.87,1404.54 1843.88,1404.54 1843.88,1404.54 1843.88,1404.54 1843.89,1404.54 1843.89,1404.54 1843.89,1404.54 1843.9,1404.54 1843.9,1404.54 1843.9,1404.54 1843.91,1404.54 1843.91,1404.54 1843.91,1404.54 1843.92,1404.54 1843.92,1404.54 1843.92,1404.54 1843.93,1404.54 1843.93,1404.54 1843.93,1404.54 1843.94,1404.54 1843.94,1404.54 1843.94,1404.54 1843.95,1404.54 1843.95,1404.54 1843.95,1404.54 1843.96,1404.54 1843.96,1404.54 1843.96,1404.54 1843.97,1404.54 1843.97,1404.54 1843.97,1404.54 1843.98,1404.54 1843.98,1404.54 1843.98,1404.54 1843.99,1404.54 1843.99,1404.54 1843.99,1404.54 1844,1404.54 1844,1404.54 1844,1404.53 1844.01,1404.53 1844.01,1404.53 1844.01,1404.53 1844.02,1404.53 1844.02,1404.53 1844.02,1404.53 1844.03,1404.53 1844.03,1404.53 1844.03,1404.53 1844.04,1404.53 1844.04,1404.53 1844.04,1404.53 1844.05,1404.53 1844.05,1404.53 1844.05,1404.53 1844.06,1404.53 1844.06,1404.53 1844.06,1404.53 1844.07,1404.53 1844.07,1404.53 1844.07,1404.53 1844.08,1404.53 1844.08,1404.53 1844.08,1404.53 1844.09,1404.53 1844.09,1404.53 1844.09,1404.53 1844.1,1404.53 1844.1,1404.53 1844.1,1404.53 1844.11,1404.53 1844.11,1404.53 1844.11,1404.53 1844.12,1404.53 1844.12,1404.53 1844.12,1404.53 1844.13,1404.53 1844.13,1404.53 1844.13,1404.53 1844.14,1404.53 1844.14,1404.53 1844.14,1404.53 1844.15,1404.53 1844.15,1404.53 1844.15,1404.53 1844.16,1404.53 1844.16,1404.53 1844.16,1404.53 1844.17,1404.53 1844.17,1404.53 1844.17,1404.53 1844.18,1404.53 1844.18,1404.53 1844.18,1404.53 1844.19,1404.53 1844.19,1404.53 1844.19,1404.53 1844.2,1404.53 1844.2,1404.53 1844.2,1404.53 1844.21,1404.53 1844.21,1404.53 1844.21,1404.53 1844.21,1404.53 1844.22,1404.53 1844.22,1404.53 1844.22,1404.53 1844.23,1404.53 1844.23,1404.53 1844.23,1404.53 1844.24,1404.53 1844.24,1404.53 1844.24,1404.53 1844.25,1404.53 1844.25,1404.53 1844.25,1404.53 1844.26,1404.53 1844.26,1404.53 1844.26,1404.53 1844.27,1404.53 1844.27,1404.53 1844.27,1404.53 1844.28,1404.53 1844.28,1404.53 1844.28,1404.53 1844.29,1404.53 1844.29,1404.53 1844.29,1404.53 1844.3,1404.53 1844.3,1404.53 1844.3,1404.53 1844.31,1404.53 1844.31,1404.53 1844.31,1404.53 1844.32,1404.53 1844.32,1404.53 1844.32,1404.53 1844.33,1404.53 1844.33,1404.53 1844.33,1404.53 1844.34,1404.53 1844.34,1404.53 1844.34,1404.53 1844.35,1404.53 1844.35,1404.53 1844.35,1404.53 1844.36,1404.53 1844.36,1404.53 1844.36,1404.53 1844.37,1404.53 1844.37,1404.53 1844.37,1404.53 1844.38,1404.53 1844.38,1404.53 1844.38,1404.53 1844.39,1404.53 1844.39,1404.53 1844.39,1404.53 1844.4,1404.52 1844.4,1404.52 1844.4,1404.52 1844.41,1404.52 1844.41,1404.52 1844.41,1404.52 1844.42,1404.52 1844.42,1404.52 1844.42,1404.52 1844.43,1404.52 1844.43,1404.52 1844.43,1404.52 1844.44,1404.52 1844.44,1404.52 1844.44,1404.52 1844.45,1404.52 1844.45,1404.52 1844.45,1404.52 1844.46,1404.52 1844.46,1404.52 1844.46,1404.52 1844.47,1404.52 1844.47,1404.52 1844.47,1404.52 1844.48,1404.52 1844.48,1404.52 1844.48,1404.52 1844.49,1404.52 1844.49,1404.52 1844.49,1404.52 1844.5,1404.52 1844.5,1404.52 1844.5,1404.52 1844.51,1404.52 1844.51,1404.52 1844.51,1404.52 1844.52,1404.52 1844.52,1404.52 1844.52,1404.52 1844.53,1404.52 1844.53,1404.52 1844.53,1404.52 1844.54,1404.52 1844.54,1404.52 1844.54,1404.52 1844.55,1404.52 1844.55,1404.52 1844.55,1404.52 1844.56,1404.52 1844.56,1404.52 1844.56,1404.52 1844.57,1404.52 1844.57,1404.52 1844.57,1404.52 1844.58,1404.52 1844.58,1404.52 1844.58,1404.52 1844.58,1404.52 1844.59,1404.52 1844.59,1404.52 1844.59,1404.52 1844.6,1404.52 1844.6,1404.52 1844.6,1404.52 1844.61,1404.52 1844.61,1404.52 1844.61,1404.52 1844.62,1404.52 1844.62,1404.52 1844.62,1404.52 1844.63,1404.52 1844.63,1404.52 1844.63,1404.52 1844.64,1404.52 1844.64,1404.52 1844.64,1404.52 1844.65,1404.52 1844.65,1404.52 1844.65,1404.52 1844.66,1404.52 1844.66,1404.52 1844.66,1404.52 1844.67,1404.52 1844.67,1404.52 1844.67,1404.52 1844.68,1404.52 1844.68,1404.52 1844.68,1404.52 1844.69,1404.52 1844.69,1404.52 1844.69,1404.52 1844.7,1404.52 1844.7,1404.52 1844.7,1404.52 1844.71,1404.52 1844.71,1404.52 1844.71,1404.52 1844.72,1404.52 1844.72,1404.52 1844.72,1404.52 1844.73,1404.52 1844.73,1404.52 1844.73,1404.52 1844.74,1404.52 1844.74,1404.52 1844.74,1404.52 1844.75,1404.52 1844.75,1404.52 1844.75,1404.52 1844.76,1404.52 1844.76,1404.52 1844.76,1404.52 1844.77,1404.52 1844.77,1404.52 1844.77,1404.52 1844.78,1404.52 1844.78,1404.52 1844.78,1404.52 1844.79,1404.52 1844.79,1404.52 1844.79,1404.51 1844.8,1404.51 1844.8,1404.51 1844.8,1404.51 1844.81,1404.51 1844.81,1404.51 1844.81,1404.51 1844.82,1404.51 1844.82,1404.51 1844.82,1404.51 1844.83,1404.51 1844.83,1404.51 1844.83,1404.51 1844.84,1404.51 1844.84,1404.51 1844.84,1404.51 1844.84,1404.51 1844.85,1404.51 1844.85,1404.51 1844.85,1404.51 1844.86,1404.51 1844.86,1404.51 1844.86,1404.51 1844.87,1404.51 1844.87,1404.51 1844.87,1404.51 1844.88,1404.51 1844.88,1404.51 1844.88,1404.51 1844.89,1404.51 1844.89,1404.51 1844.89,1404.51 1844.9,1404.51 1844.9,1404.51 1844.9,1404.51 1844.91,1404.51 1844.91,1404.51 1844.91,1404.51 1844.92,1404.51 1844.92,1404.51 1844.92,1404.51 1844.93,1404.51 1844.93,1404.51 1844.93,1404.51 1844.94,1404.51 1844.94,1404.51 1844.94,1404.51 1844.95,1404.51 1844.95,1404.51 1844.95,1404.51 1844.96,1404.51 1844.96,1404.51 1844.96,1404.51 1844.97,1404.51 1844.97,1404.51 1844.97,1404.51 1844.98,1404.51 1844.98,1404.51 1844.98,1404.51 1844.99,1404.51 1844.99,1404.51 1844.99,1404.51 1845,1404.51 1845,1404.51 1845,1404.51 1845.01,1404.51 1845.01,1404.51 1845.01,1404.51 1845.02,1404.51 1845.02,1404.51 1845.02,1404.51 1845.03,1404.51 1845.03,1404.51 1845.03,1404.51 1845.04,1404.51 1845.04,1404.51 1845.04,1404.51 1845.05,1404.51 1845.05,1404.51 1845.05,1404.51 1845.06,1404.51 1845.06,1404.51 1845.06,1404.51 1845.06,1404.51 1845.07,1404.51 1845.07,1404.51 1845.07,1404.51 1845.08,1404.51 1845.08,1404.51 1845.08,1404.51 1845.09,1404.51 1845.09,1404.51 1845.09,1404.51 1845.1,1404.51 1845.1,1404.51 1845.1,1404.51 1845.11,1404.51 1845.11,1404.51 1845.11,1404.51 1845.12,1404.51 1845.12,1404.51 1845.12,1404.51 1845.13,1404.51 1845.13,1404.51 1845.13,1404.51 1845.14,1404.51 1845.14,1404.51 1845.14,1404.51 1845.15,1404.51 1845.15,1404.51 1845.15,1404.51 1845.16,1404.51 1845.16,1404.51 1845.16,1404.51 1845.17,1404.51 1845.17,1404.51 1845.17,1404.51 1845.18,1404.51 1845.18,1404.51 1845.18,1404.51 1845.19,1404.5 1845.19,1404.5 1845.19,1404.5 1845.2,1404.5 1845.2,1404.5 1845.2,1404.5 1845.21,1404.5 1845.21,1404.5 1845.21,1404.5 1845.22,1404.5 1845.22,1404.5 1845.22,1404.5 1845.23,1404.5 1845.23,1404.5 1845.23,1404.5 1845.24,1404.5 1845.24,1404.5 1845.24,1404.5 1845.25,1404.5 1845.25,1404.5 1845.25,1404.5 1845.25,1404.5 1845.26,1404.5 1845.26,1404.5 1845.26,1404.5 1845.27,1404.5 1845.27,1404.5 1845.27,1404.5 1845.28,1404.5 1845.28,1404.5 1845.28,1404.5 1845.29,1404.5 1845.29,1404.5 1845.29,1404.5 1845.3,1404.5 1845.3,1404.5 1845.3,1404.5 1845.31,1404.5 1845.31,1404.5 1845.31,1404.5 1845.32,1404.5 1845.32,1404.5 1845.32,1404.5 1845.33,1404.5 1845.33,1404.5 1845.33,1404.5 1845.34,1404.5 1845.34,1404.5 1845.34,1404.5 1845.35,1404.5 1845.35,1404.5 1845.35,1404.5 1845.36,1404.5 1845.36,1404.5 1845.36,1404.5 1845.37,1404.5 1845.37,1404.5 1845.37,1404.5 1845.38,1404.5 1845.38,1404.5 1845.38,1404.5 1845.39,1404.5 1845.39,1404.5 1845.39,1404.5 1845.4,1404.5 1845.4,1404.5 1845.4,1404.5 1845.41,1404.5 1845.41,1404.5 1845.41,1404.5 1845.42,1404.5 1845.42,1404.5 1845.42,1404.5 1845.42,1404.5 1845.43,1404.5 1845.43,1404.5 1845.43,1404.5 1845.44,1404.5 1845.44,1404.5 1845.44,1404.5 1845.45,1404.5 1845.45,1404.5 1845.45,1404.5 1845.46,1404.5 1845.46,1404.5 1845.46,1404.5 1845.47,1404.5 1845.47,1404.5 1845.47,1404.5 1845.48,1404.5 1845.48,1404.5 1845.48,1404.5 1845.49,1404.5 1845.49,1404.5 1845.49,1404.5 1845.5,1404.5 1845.5,1404.5 1845.5,1404.5 1845.51,1404.5 1845.51,1404.5 1845.51,1404.5 1845.52,1404.5 1845.52,1404.5 1845.52,1404.5 1845.53,1404.5 1845.53,1404.5 1845.53,1404.5 1845.54,1404.5 1845.54,1404.5 1845.54,1404.5 1845.55,1404.5 1845.55,1404.5 1845.55,1404.5 1845.56,1404.5 1845.56,1404.5 1845.56,1404.5 1845.57,1404.5 1845.57,1404.5 1845.57,1404.5 1845.58,1404.5 1845.58,1404.49 1845.58,1404.49 1845.58,1404.49 1845.59,1404.49 1845.59,1404.49 1845.59,1404.49 1845.6,1404.49 1845.6,1404.49 1845.6,1404.49 1845.61,1404.49 1845.61,1404.49 1845.61,1404.49 1845.62,1404.49 1845.62,1404.49 1845.62,1404.49 1845.63,1404.49 1845.63,1404.49 1845.63,1404.49 1845.64,1404.49 1845.64,1404.49 1845.64,1404.49 1845.65,1404.49 1845.65,1404.49 1845.65,1404.49 1845.66,1404.49 1845.66,1404.49 1845.66,1404.49 1845.67,1404.49 1845.67,1404.49 1845.67,1404.49 1845.68,1404.49 1845.68,1404.49 1845.68,1404.49 1845.69,1404.49 1845.69,1404.49 1845.69,1404.49 1845.7,1404.49 1845.7,1404.49 1845.7,1404.49 1845.71,1404.49 1845.71,1404.49 1845.71,1404.49 1845.72,1404.49 1845.72,1404.49 1845.72,1404.49 1845.73,1404.49 1845.73,1404.49 1845.73,1404.49 1845.73,1404.49 1845.74,1404.49 1845.74,1404.49 1845.74,1404.49 1845.75,1404.49 1845.75,1404.49 1845.75,1404.49 1845.76,1404.49 1845.76,1404.49 1845.76,1404.49 1845.77,1404.49 1845.77,1404.49 1845.77,1404.49 1845.78,1404.49 1845.78,1404.49 1845.78,1404.49 1845.79,1404.49 1845.79,1404.49 1845.79,1404.49 1845.8,1404.49 1845.8,1404.49 1845.8,1404.49 1845.81,1404.49 1845.81,1404.49 1845.81,1404.49 1845.82,1404.49 1845.82,1404.49 1845.82,1404.49 1845.83,1404.49 1845.83,1404.49 1845.83,1404.49 1845.84,1404.49 1845.84,1404.49 1845.84,1404.49 1845.85,1404.49 1845.85,1404.49 1845.85,1404.49 1845.86,1404.49 1845.86,1404.49 1845.86,1404.49 1845.86,1404.49 1845.87,1404.49 1845.87,1404.49 1845.87,1404.49 1845.88,1404.49 1845.88,1404.49 1845.88,1404.49 1845.89,1404.49 1845.89,1404.49 1845.89,1404.49 1845.9,1404.49 1845.9,1404.49 1845.9,1404.49 1845.91,1404.49 1845.91,1404.49 1845.91,1404.49 1845.92,1404.49 1845.92,1404.49 1845.92,1404.49 1845.93,1404.49 1845.93,1404.49 1845.93,1404.49 1845.94,1404.49 1845.94,1404.49 1845.94,1404.49 1845.95,1404.49 1845.95,1404.49 1845.95,1404.49 1845.96,1404.49 1845.96,1404.49 1845.96,1404.49 1845.97,1404.49 1845.97,1404.49 1845.97,1404.48 1845.98,1404.48 1845.98,1404.48 1845.98,1404.48 1845.99,1404.48 1845.99,1404.48 1845.99,1404.48 1845.99,1404.48 1846,1404.48 1846,1404.48 1846,1404.48 1846.01,1404.48 1846.01,1404.48 1846.01,1404.48 1846.02,1404.48 1846.02,1404.48 1846.02,1404.48 1846.03,1404.48 1846.03,1404.48 1846.03,1404.48 1846.04,1404.48 1846.04,1404.48 1846.04,1404.48 1846.05,1404.48 1846.05,1404.48 1846.05,1404.48 1846.06,1404.48 1846.06,1404.48 1846.06,1404.48 1846.07,1404.48 1846.07,1404.48 1846.07,1404.48 1846.08,1404.48 1846.08,1404.48 1846.08,1404.48 1846.09,1404.48 1846.09,1404.48 1846.09,1404.48 1846.1,1404.48 1846.1,1404.48 1846.1,1404.48 1846.11,1404.48 1846.11,1404.48 1846.11,1404.48 1846.11,1404.48 1846.12,1404.48 1846.12,1404.48 1846.12,1404.48 1846.13,1404.48 1846.13,1404.48 1846.13,1404.48 1846.14,1404.48 1846.14,1404.48 1846.14,1404.48 1846.15,1404.48 1846.15,1404.48 1846.15,1404.48 1846.16,1404.48 1846.16,1404.48 1846.16,1404.48 1846.17,1404.48 1846.17,1404.48 1846.17,1404.48 1846.18,1404.48 1846.18,1404.48 1846.18,1404.48 1846.19,1404.48 1846.19,1404.48 1846.19,1404.48 1846.2,1404.48 1846.2,1404.48 1846.2,1404.48 1846.21,1404.48 1846.21,1404.48 1846.21,1404.48 1846.22,1404.48 1846.22,1404.48 1846.22,1404.48 1846.23,1404.48 1846.23,1404.48 1846.23,1404.48 1846.23,1404.48 1846.24,1404.48 1846.24,1404.48 1846.24,1404.48 1846.25,1404.48 1846.25,1404.48 1846.25,1404.48 1846.26,1404.48 1846.26,1404.48 1846.26,1404.48 1846.27,1404.48 1846.27,1404.48 1846.27,1404.48 1846.28,1404.48 1846.28,1404.48 1846.28,1404.48 1846.29,1404.48 1846.29,1404.48 1846.29,1404.48 1846.3,1404.48 1846.3,1404.48 1846.3,1404.48 1846.31,1404.48 1846.31,1404.48 1846.31,1404.48 1846.32,1404.48 1846.32,1404.48 1846.32,1404.48 1846.33,1404.48 1846.33,1404.48 1846.33,1404.48 1846.34,1404.48 1846.34,1404.48 1846.34,1404.48 1846.34,1404.48 1846.35,1404.48 1846.35,1404.48 1846.35,1404.48 1846.36,1404.48 1846.36,1404.48 1846.36,1404.48 1846.37,1404.47 1846.37,1404.47 1846.37,1404.47 1846.38,1404.47 1846.38,1404.47 1846.38,1404.47 1846.39,1404.47 1846.39,1404.47 1846.39,1404.47 1846.4,1404.47 1846.4,1404.47 1846.4,1404.47 1846.41,1404.47 1846.41,1404.47 1846.41,1404.47 1846.42,1404.47 1846.42,1404.47 1846.42,1404.47 1846.43,1404.47 1846.43,1404.47 1846.43,1404.47 1846.44,1404.47 1846.44,1404.47 1846.44,1404.47 1846.45,1404.47 1846.45,1404.47 1846.45,1404.47 1846.45,1404.47 1846.46,1404.47 1846.46,1404.47 1846.46,1404.47 1846.47,1404.47 1846.47,1404.47 1846.47,1404.47 1846.48,1404.47 1846.48,1404.47 1846.48,1404.47 1846.49,1404.47 1846.49,1404.47 1846.49,1404.47 1846.5,1404.47 1846.5,1404.47 1846.5,1404.47 1846.51,1404.47 1846.51,1404.47 1846.51,1404.47 1846.52,1404.47 1846.52,1404.47 1846.52,1404.47 1846.53,1404.47 1846.53,1404.47 1846.53,1404.47 1846.54,1404.47 1846.54,1404.47 1846.54,1404.47 1846.55,1404.47 1846.55,1404.47 1846.55,1404.47 1846.55,1404.47 1846.56,1404.47 1846.56,1404.47 1846.56,1404.47 1846.57,1404.47 1846.57,1404.47 1846.57,1404.47 1846.58,1404.47 1846.58,1404.47 1846.58,1404.47 1846.59,1404.47 1846.59,1404.47 1846.59,1404.47 1846.6,1404.47 1846.6,1404.47 1846.6,1404.47 1846.61,1404.47 1846.61,1404.47 1846.61,1404.47 1846.62,1404.47 1846.62,1404.47 1846.62,1404.47 1846.63,1404.47 1846.63,1404.47 1846.63,1404.47 1846.64,1404.47 1846.64,1404.47 1846.64,1404.47 1846.65,1404.47 1846.65,1404.47 1846.65,1404.47 1846.65,1404.47 1846.66,1404.47 1846.66,1404.47 1846.66,1404.47 1846.67,1404.47 1846.67,1404.47 1846.67,1404.47 1846.68,1404.47 1846.68,1404.47 1846.68,1404.47 1846.69,1404.47 1846.69,1404.47 1846.69,1404.47 1846.7,1404.47 1846.7,1404.47 1846.7,1404.47 1846.71,1404.47 1846.71,1404.47 1846.71,1404.47 1846.72,1404.47 1846.72,1404.47 1846.72,1404.47 1846.73,1404.47 1846.73,1404.47 1846.73,1404.47 1846.74,1404.47 1846.74,1404.47 1846.74,1404.47 1846.75,1404.47 1846.75,1404.47 1846.75,1404.47 1846.75,1404.47 1846.76,1404.47 1846.76,1404.46 1846.76,1404.46 1846.77,1404.46 1846.77,1404.46 1846.77,1404.46 1846.78,1404.46 1846.78,1404.46 1846.78,1404.46 1846.79,1404.46 1846.79,1404.46 1846.79,1404.46 1846.8,1404.46 1846.8,1404.46 1846.8,1404.46 1846.81,1404.46 1846.81,1404.46 1846.81,1404.46 1846.82,1404.46 1846.82,1404.46 1846.82,1404.46 1846.83,1404.46 1846.83,1404.46 1846.83,1404.46 1846.84,1404.46 1846.84,1404.46 1846.84,1404.46 1846.84,1404.46 1846.85,1404.46 1846.85,1404.46 1846.85,1404.46 1846.86,1404.46 1846.86,1404.46 1846.86,1404.46 1846.87,1404.46 1846.87,1404.46 1846.87,1404.46 1846.88,1404.46 1846.88,1404.46 1846.88,1404.46 1846.89,1404.46 1846.89,1404.46 1846.89,1404.46 1846.9,1404.46 1846.9,1404.46 1846.9,1404.46 1846.91,1404.46 1846.91,1404.46 1846.91,1404.46 1846.92,1404.46 1846.92,1404.46 1846.92,1404.46 1846.93,1404.46 1846.93,1404.46 1846.93,1404.46 1846.93,1404.46 1846.94,1404.46 1846.94,1404.46 1846.94,1404.46 1846.95,1404.46 1846.95,1404.46 1846.95,1404.46 1846.96,1404.46 1846.96,1404.46 1846.96,1404.46 1846.97,1404.46 1846.97,1404.46 1846.97,1404.46 1846.98,1404.46 1846.98,1404.46 1846.98,1404.46 1846.99,1404.46 1846.99,1404.46 1846.99,1404.46 1847,1404.46 1847,1404.46 1847,1404.46 1847.01,1404.46 1847.01,1404.46 1847.01,1404.46 1847.02,1404.46 1847.02,1404.46 1847.02,1404.46 1847.02,1404.46 1847.03,1404.46 1847.03,1404.46 1847.03,1404.46 1847.04,1404.46 1847.04,1404.46 1847.04,1404.46 1847.05,1404.46 1847.05,1404.46 1847.05,1404.46 1847.06,1404.46 1847.06,1404.46 1847.06,1404.46 1847.07,1404.46 1847.07,1404.46 1847.07,1404.46 1847.08,1404.46 1847.08,1404.46 1847.08,1404.46 1847.09,1404.46 1847.09,1404.46 1847.09,1404.46 1847.1,1404.46 1847.1,1404.46 1847.1,1404.46 1847.11,1404.46 1847.11,1404.46 1847.11,1404.46 1847.11,1404.46 1847.12,1404.46 1847.12,1404.46 1847.12,1404.46 1847.13,1404.46 1847.13,1404.46 1847.13,1404.46 1847.14,1404.46 1847.14,1404.46 1847.14,1404.46 1847.15,1404.46 1847.15,1404.46 1847.15,1404.45 1847.16,1404.45 1847.16,1404.45 1847.16,1404.45 1847.17,1404.45 1847.17,1404.45 1847.17,1404.45 1847.18,1404.45 1847.18,1404.45 1847.18,1404.45 1847.19,1404.45 1847.19,1404.45 1847.19,1404.45 1847.19,1404.45 1847.2,1404.45 1847.2,1404.45 1847.2,1404.45 1847.21,1404.45 1847.21,1404.45 1847.21,1404.45 1847.22,1404.45 1847.22,1404.45 1847.22,1404.45 1847.23,1404.45 1847.23,1404.45 1847.23,1404.45 1847.24,1404.45 1847.24,1404.45 1847.24,1404.45 1847.25,1404.45 1847.25,1404.45 1847.25,1404.45 1847.26,1404.45 1847.26,1404.45 1847.26,1404.45 1847.27,1404.45 1847.27,1404.45 1847.27,1404.45 1847.27,1404.45 1847.28,1404.45 1847.28,1404.45 1847.28,1404.45 1847.29,1404.45 1847.29,1404.45 1847.29,1404.45 1847.3,1404.45 1847.3,1404.45 1847.3,1404.45 1847.31,1404.45 1847.31,1404.45 1847.31,1404.45 1847.32,1404.45 1847.32,1404.45 1847.32,1404.45 1847.33,1404.45 1847.33,1404.45 1847.33,1404.45 1847.34,1404.45 1847.34,1404.45 1847.34,1404.45 1847.35,1404.45 1847.35,1404.45 1847.35,1404.45 1847.36,1404.45 1847.36,1404.45 1847.36,1404.45 1847.36,1404.45 1847.37,1404.45 1847.37,1404.45 1847.37,1404.45 1847.38,1404.45 1847.38,1404.45 1847.38,1404.45 1847.39,1404.45 1847.39,1404.45 1847.39,1404.45 1847.4,1404.45 1847.4,1404.45 1847.4,1404.45 1847.41,1404.45 1847.41,1404.45 1847.41,1404.45 1847.42,1404.45 1847.42,1404.45 1847.42,1404.45 1847.43,1404.45 1847.43,1404.45 1847.43,1404.45 1847.43,1404.45 1847.44,1404.45 1847.44,1404.45 1847.44,1404.45 1847.45,1404.45 1847.45,1404.45 1847.45,1404.45 1847.46,1404.45 1847.46,1404.45 1847.46,1404.45 1847.47,1404.45 1847.47,1404.45 1847.47,1404.45 1847.48,1404.45 1847.48,1404.45 1847.48,1404.45 1847.49,1404.45 1847.49,1404.45 1847.49,1404.45 1847.5,1404.45 1847.5,1404.45 1847.5,1404.45 1847.51,1404.45 1847.51,1404.45 1847.51,1404.45 1847.51,1404.45 1847.52,1404.45 1847.52,1404.45 1847.52,1404.45 1847.53,1404.45 1847.53,1404.45 1847.53,1404.45 1847.54,1404.45 1847.54,1404.45 1847.54,1404.45 1847.55,1404.44 1847.55,1404.44 1847.55,1404.44 1847.56,1404.44 1847.56,1404.44 1847.56,1404.44 1847.57,1404.44 1847.57,1404.44 1847.57,1404.44 1847.58,1404.44 1847.58,1404.44 1847.58,1404.44 1847.59,1404.44 1847.59,1404.44 1847.59,1404.44 1847.59,1404.44 1847.6,1404.44 1847.6,1404.44 1847.6,1404.44 1847.61,1404.44 1847.61,1404.44 1847.61,1404.44 1847.62,1404.44 1847.62,1404.44 1847.62,1404.44 1847.63,1404.44 1847.63,1404.44 1847.63,1404.44 1847.64,1404.44 1847.64,1404.44 1847.64,1404.44 1847.65,1404.44 1847.65,1404.44 1847.65,1404.44 1847.66,1404.44 1847.66,1404.44 1847.66,1404.44 1847.66,1404.44 1847.67,1404.44 1847.67,1404.44 1847.67,1404.44 1847.68,1404.44 1847.68,1404.44 1847.68,1404.44 1847.69,1404.44 1847.69,1404.44 1847.69,1404.44 1847.7,1404.44 1847.7,1404.44 1847.7,1404.44 1847.71,1404.44 1847.71,1404.44 1847.71,1404.44 1847.72,1404.44 1847.72,1404.44 1847.72,1404.44 1847.73,1404.44 1847.73,1404.44 1847.73,1404.44 1847.74,1404.44 1847.74,1404.44 1847.74,1404.44 1847.74,1404.44 1847.75,1404.44 1847.75,1404.44 1847.75,1404.44 1847.76,1404.44 1847.76,1404.44 1847.76,1404.44 1847.77,1404.44 1847.77,1404.44 1847.77,1404.44 1847.78,1404.44 1847.78,1404.44 1847.78,1404.44 1847.79,1404.44 1847.79,1404.44 1847.79,1404.44 1847.8,1404.44 1847.8,1404.44 1847.8,1404.44 1847.81,1404.44 1847.81,1404.44 1847.81,1404.44 1847.81,1404.44 1847.82,1404.44 1847.82,1404.44 1847.82,1404.44 1847.83,1404.44 1847.83,1404.44 1847.83,1404.44 1847.84,1404.44 1847.84,1404.44 1847.84,1404.44 1847.85,1404.44 1847.85,1404.44 1847.85,1404.44 1847.86,1404.44 1847.86,1404.44 1847.86,1404.44 1847.87,1404.44 1847.87,1404.44 1847.87,1404.44 1847.88,1404.44 1847.88,1404.44 1847.88,1404.44 1847.88,1404.44 1847.89,1404.44 1847.89,1404.44 1847.89,1404.44 1847.9,1404.44 1847.9,1404.44 1847.9,1404.44 1847.91,1404.44 1847.91,1404.44 1847.91,1404.44 1847.92,1404.44 1847.92,1404.44 1847.92,1404.44 1847.93,1404.44 1847.93,1404.44 1847.93,1404.44 1847.94,1404.44 1847.94,1404.43 1847.94,1404.43 1847.95,1404.43 1847.95,1404.43 1847.95,1404.43 1847.95,1404.43 1847.96,1404.43 1847.96,1404.43 1847.96,1404.43 1847.97,1404.43 1847.97,1404.43 1847.97,1404.43 1847.98,1404.43 1847.98,1404.43 1847.98,1404.43 1847.99,1404.43 1847.99,1404.43 1847.99,1404.43 1848,1404.43 1848,1404.43 1848,1404.43 1848.01,1404.43 1848.01,1404.43 1848.01,1404.43 1848.02,1404.43 1848.02,1404.43 1848.02,1404.43 1848.02,1404.43 1848.03,1404.43 1848.03,1404.43 1848.03,1404.43 1848.04,1404.43 1848.04,1404.43 1848.04,1404.43 1848.05,1404.43 1848.05,1404.43 1848.05,1404.43 1848.06,1404.43 1848.06,1404.43 1848.06,1404.43 1848.07,1404.43 1848.07,1404.43 1848.07,1404.43 1848.08,1404.43 1848.08,1404.43 1848.08,1404.43 1848.09,1404.43 1848.09,1404.43 1848.09,1404.43 1848.09,1404.43 1848.1,1404.43 1848.1,1404.43 1848.1,1404.43 1848.11,1404.43 1848.11,1404.43 1848.11,1404.43 1848.12,1404.43 1848.12,1404.43 1848.12,1404.43 1848.13,1404.43 1848.13,1404.43 1848.13,1404.43 1848.14,1404.43 1848.14,1404.43 1848.14,1404.43 1848.15,1404.43 1848.15,1404.43 1848.15,1404.43 1848.15,1404.43 1848.16,1404.43 1848.16,1404.43 1848.16,1404.43 1848.17,1404.43 1848.17,1404.43 1848.17,1404.43 1848.18,1404.43 1848.18,1404.43 1848.18,1404.43 1848.19,1404.43 1848.19,1404.43 1848.19,1404.43 1848.2,1404.43 1848.2,1404.43 1848.2,1404.43 1848.21,1404.43 1848.21,1404.43 1848.21,1404.43 1848.22,1404.43 1848.22,1404.43 1848.22,1404.43 1848.22,1404.43 1848.23,1404.43 1848.23,1404.43 1848.23,1404.43 1848.24,1404.43 1848.24,1404.43 1848.24,1404.43 1848.25,1404.43 1848.25,1404.43 1848.25,1404.43 1848.26,1404.43 1848.26,1404.43 1848.26,1404.43 1848.27,1404.43 1848.27,1404.43 1848.27,1404.43 1848.28,1404.43 1848.28,1404.43 1848.28,1404.43 1848.29,1404.43 1848.29,1404.43 1848.29,1404.43 1848.29,1404.43 1848.3,1404.43 1848.3,1404.43 1848.3,1404.43 1848.31,1404.43 1848.31,1404.43 1848.31,1404.43 1848.32,1404.43 1848.32,1404.43 1848.32,1404.43 1848.33,1404.43 1848.33,1404.43 1848.33,1404.42 1848.34,1404.42 1848.34,1404.42 1848.34,1404.42 1848.35,1404.42 1848.35,1404.42 1848.35,1404.42 1848.35,1404.42 1848.36,1404.42 1848.36,1404.42 1848.36,1404.42 1848.37,1404.42 1848.37,1404.42 1848.37,1404.42 1848.38,1404.42 1848.38,1404.42 1848.38,1404.42 1848.39,1404.42 1848.39,1404.42 1848.39,1404.42 1848.4,1404.42 1848.4,1404.42 1848.4,1404.42 1848.41,1404.42 1848.41,1404.42 1848.41,1404.42 1848.41,1404.42 1848.42,1404.42 1848.42,1404.42 1848.42,1404.42 1848.43,1404.42 1848.43,1404.42 1848.43,1404.42 1848.44,1404.42 1848.44,1404.42 1848.44,1404.42 1848.45,1404.42 1848.45,1404.42 1848.45,1404.42 1848.46,1404.42 1848.46,1404.42 1848.46,1404.42 1848.47,1404.42 1848.47,1404.42 1848.47,1404.42 1848.48,1404.42 1848.48,1404.42 1848.48,1404.42 1848.48,1404.42 1848.49,1404.42 1848.49,1404.42 1848.49,1404.42 1848.5,1404.42 1848.5,1404.42 1848.5,1404.42 1848.51,1404.42 1848.51,1404.42 1848.51,1404.42 1848.52,1404.42 1848.52,1404.42 1848.52,1404.42 1848.53,1404.42 1848.53,1404.42 1848.53,1404.42 1848.54,1404.42 1848.54,1404.42 1848.54,1404.42 1848.54,1404.42 1848.55,1404.42 1848.55,1404.42 1848.55,1404.42 1848.56,1404.42 1848.56,1404.42 1848.56,1404.42 1848.57,1404.42 1848.57,1404.42 1848.57,1404.42 1848.58,1404.42 1848.58,1404.42 1848.58,1404.42 1848.59,1404.42 1848.59,1404.42 1848.59,1404.42 1848.6,1404.42 1848.6,1404.42 1848.6,1404.42 1848.6,1404.42 1848.61,1404.42 1848.61,1404.42 1848.61,1404.42 1848.62,1404.42 1848.62,1404.42 1848.62,1404.42 1848.63,1404.42 1848.63,1404.42 1848.63,1404.42 1848.64,1404.42 1848.64,1404.42 1848.64,1404.42 1848.65,1404.42 1848.65,1404.42 1848.65,1404.42 1848.66,1404.42 1848.66,1404.42 1848.66,1404.42 1848.66,1404.42 1848.67,1404.42 1848.67,1404.42 1848.67,1404.42 1848.68,1404.42 1848.68,1404.42 1848.68,1404.42 1848.69,1404.42 1848.69,1404.42 1848.69,1404.42 1848.7,1404.42 1848.7,1404.42 1848.7,1404.42 1848.71,1404.42 1848.71,1404.42 1848.71,1404.42 1848.72,1404.42 1848.72,1404.42 1848.72,1404.42 1848.72,1404.41 1848.73,1404.41 1848.73,1404.41 1848.73,1404.41 1848.74,1404.41 1848.74,1404.41 1848.74,1404.41 1848.75,1404.41 1848.75,1404.41 1848.75,1404.41 1848.76,1404.41 1848.76,1404.41 1848.76,1404.41 1848.77,1404.41 1848.77,1404.41 1848.77,1404.41 1848.78,1404.41 1848.78,1404.41 1848.78,1404.41 1848.78,1404.41 1848.79,1404.41 1848.79,1404.41 1848.79,1404.41 1848.8,1404.41 1848.8,1404.41 1848.8,1404.41 1848.81,1404.41 1848.81,1404.41 1848.81,1404.41 1848.82,1404.41 1848.82,1404.41 1848.82,1404.41 1848.83,1404.41 1848.83,1404.41 1848.83,1404.41 1848.84,1404.41 1848.84,1404.41 1848.84,1404.41 1848.84,1404.41 1848.85,1404.41 1848.85,1404.41 1848.85,1404.41 1848.86,1404.41 1848.86,1404.41 1848.86,1404.41 1848.87,1404.41 1848.87,1404.41 1848.87,1404.41 1848.88,1404.41 1848.88,1404.41 1848.88,1404.41 1848.89,1404.41 1848.89,1404.41 1848.89,1404.41 1848.89,1404.41 1848.9,1404.41 1848.9,1404.41 1848.9,1404.41 1848.91,1404.41 1848.91,1404.41 1848.91,1404.41 1848.92,1404.41 1848.92,1404.41 1848.92,1404.41 1848.93,1404.41 1848.93,1404.41 1848.93,1404.41 1848.94,1404.41 1848.94,1404.41 1848.94,1404.41 1848.95,1404.41 1848.95,1404.41 1848.95,1404.41 1848.95,1404.41 1848.96,1404.41 1848.96,1404.41 1848.96,1404.41 1848.97,1404.41 1848.97,1404.41 1848.97,1404.41 1848.98,1404.41 1848.98,1404.41 1848.98,1404.41 1848.99,1404.41 1848.99,1404.41 1848.99,1404.41 1849,1404.41 1849,1404.41 1849,1404.41 1849.01,1404.41 1849.01,1404.41 1849.01,1404.41 1849.01,1404.41 1849.02,1404.41 1849.02,1404.41 1849.02,1404.41 1849.03,1404.41 1849.03,1404.41 1849.03,1404.41 1849.04,1404.41 1849.04,1404.41 1849.04,1404.41 1849.05,1404.41 1849.05,1404.41 1849.05,1404.41 1849.06,1404.41 1849.06,1404.41 1849.06,1404.41 1849.06,1404.41 1849.07,1404.41 1849.07,1404.41 1849.07,1404.41 1849.08,1404.41 1849.08,1404.41 1849.08,1404.41 1849.09,1404.41 1849.09,1404.41 1849.09,1404.41 1849.1,1404.41 1849.1,1404.41 1849.1,1404.41 1849.11,1404.41 1849.11,1404.41 1849.11,1404.41 1849.12,1404.41 1849.12,1404.4 1849.12,1404.4 1849.12,1404.4 1849.13,1404.4 1849.13,1404.4 1849.13,1404.4 1849.14,1404.4 1849.14,1404.4 1849.14,1404.4 1849.15,1404.4 1849.15,1404.4 1849.15,1404.4 1849.16,1404.4 1849.16,1404.4 1849.16,1404.4 1849.17,1404.4 1849.17,1404.4 1849.17,1404.4 1849.17,1404.4 1849.18,1404.4 1849.18,1404.4 1849.18,1404.4 1849.19,1404.4 1849.19,1404.4 1849.19,1404.4 1849.2,1404.4 1849.2,1404.4 1849.2,1404.4 1849.21,1404.4 1849.21,1404.4 1849.21,1404.4 1849.22,1404.4 1849.22,1404.4 1849.22,1404.4 1849.23,1404.4 1849.23,1404.4 1849.23,1404.4 1849.23,1404.4 1849.24,1404.4 1849.24,1404.4 1849.24,1404.4 1849.25,1404.4 1849.25,1404.4 1849.25,1404.4 1849.26,1404.4 1849.26,1404.4 1849.26,1404.4 1849.27,1404.4 1849.27,1404.4 1849.27,1404.4 1849.28,1404.4 1849.28,1404.4 1849.28,1404.4 1849.28,1404.4 1849.29,1404.4 1849.29,1404.4 1849.29,1404.4 1849.3,1404.4 1849.3,1404.4 1849.3,1404.4 1849.31,1404.4 1849.31,1404.4 1849.31,1404.4 1849.32,1404.4 1849.32,1404.4 1849.32,1404.4 1849.33,1404.4 1849.33,1404.4 1849.33,1404.4 1849.33,1404.4 1849.34,1404.4 1849.34,1404.4 1849.34,1404.4 1849.35,1404.4 1849.35,1404.4 1849.35,1404.4 1849.36,1404.4 1849.36,1404.4 1849.36,1404.4 1849.37,1404.4 1849.37,1404.4 1849.37,1404.4 1849.38,1404.4 1849.38,1404.4 1849.38,1404.4 1849.39,1404.4 1849.39,1404.4 1849.39,1404.4 1849.39,1404.4 1849.4,1404.4 1849.4,1404.4 1849.4,1404.4 1849.41,1404.4 1849.41,1404.4 1849.41,1404.4 1849.42,1404.4 1849.42,1404.4 1849.42,1404.4 1849.43,1404.4 1849.43,1404.4 1849.43,1404.4 1849.44,1404.4 1849.44,1404.4 1849.44,1404.4 1849.44,1404.4 1849.45,1404.4 1849.45,1404.4 1849.45,1404.4 1849.46,1404.4 1849.46,1404.4 1849.46,1404.4 1849.47,1404.4 1849.47,1404.4 1849.47,1404.4 1849.48,1404.4 1849.48,1404.4 1849.48,1404.4 1849.49,1404.4 1849.49,1404.4 1849.49,1404.4 1849.49,1404.4 1849.5,1404.4 1849.5,1404.4 1849.5,1404.4 1849.51,1404.4 1849.51,1404.39 1849.51,1404.39 1849.52,1404.39 1849.52,1404.39 1849.52,1404.39 1849.53,1404.39 1849.53,1404.39 1849.53,1404.39 1849.54,1404.39 1849.54,1404.39 1849.54,1404.39 1849.54,1404.39 1849.55,1404.39 1849.55,1404.39 1849.55,1404.39 1849.56,1404.39 1849.56,1404.39 1849.56,1404.39 1849.57,1404.39 1849.57,1404.39 1849.57,1404.39 1849.58,1404.39 1849.58,1404.39 1849.58,1404.39 1849.59,1404.39 1849.59,1404.39 1849.59,1404.39 1849.59,1404.39 1849.6,1404.39 1849.6,1404.39 1849.6,1404.39 1849.61,1404.39 1849.61,1404.39 1849.61,1404.39 1849.62,1404.39 1849.62,1404.39 1849.62,1404.39 1849.63,1404.39 1849.63,1404.39 1849.63,1404.39 1849.64,1404.39 1849.64,1404.39 1849.64,1404.39 1849.65,1404.39 1849.65,1404.39 1849.65,1404.39 1849.65,1404.39 1849.66,1404.39 1849.66,1404.39 1849.66,1404.39 1849.67,1404.39 1849.67,1404.39 1849.67,1404.39 1849.68,1404.39 1849.68,1404.39 1849.68,1404.39 1849.69,1404.39 1849.69,1404.39 1849.69,1404.39 1849.7,1404.39 1849.7,1404.39 1849.7,1404.39 1849.7,1404.39 1849.71,1404.39 1849.71,1404.39 1849.71,1404.39 1849.72,1404.39 1849.72,1404.39 1849.72,1404.39 1849.73,1404.39 1849.73,1404.39 1849.73,1404.39 1849.74,1404.39 1849.74,1404.39 1849.74,1404.39 1849.75,1404.39 1849.75,1404.39 1849.75,1404.39 1849.75,1404.39 1849.76,1404.39 1849.76,1404.39 1849.76,1404.39 1849.77,1404.39 1849.77,1404.39 1849.77,1404.39 1849.78,1404.39 1849.78,1404.39 1849.78,1404.39 1849.79,1404.39 1849.79,1404.39 1849.79,1404.39 1849.79,1404.39 1849.8,1404.39 1849.8,1404.39 1849.8,1404.39 1849.81,1404.39 1849.81,1404.39 1849.81,1404.39 1849.82,1404.39 1849.82,1404.39 1849.82,1404.39 1849.83,1404.39 1849.83,1404.39 1849.83,1404.39 1849.84,1404.39 1849.84,1404.39 1849.84,1404.39 1849.84,1404.39 1849.85,1404.39 1849.85,1404.39 1849.85,1404.39 1849.86,1404.39 1849.86,1404.39 1849.86,1404.39 1849.87,1404.39 1849.87,1404.39 1849.87,1404.39 1849.88,1404.39 1849.88,1404.39 1849.88,1404.39 1849.89,1404.39 1849.89,1404.39 1849.89,1404.39 1849.89,1404.39 1849.9,1404.39 1849.9,1404.38 1849.9,1404.38 1849.91,1404.38 1849.91,1404.38 1849.91,1404.38 1849.92,1404.38 1849.92,1404.38 1849.92,1404.38 1849.93,1404.38 1849.93,1404.38 1849.93,1404.38 1849.94,1404.38 1849.94,1404.38 1849.94,1404.38 1849.94,1404.38 1849.95,1404.38 1849.95,1404.38 1849.95,1404.38 1849.96,1404.38 1849.96,1404.38 1849.96,1404.38 1849.97,1404.38 1849.97,1404.38 1849.97,1404.38 1849.98,1404.38 1849.98,1404.38 1849.98,1404.38 1849.99,1404.38 1849.99,1404.38 1849.99,1404.38 1849.99,1404.38 1850,1404.38 1850,1404.38 1850,1404.38 1850.01,1404.38 1850.01,1404.38 1850.01,1404.38 1850.02,1404.38 1850.02,1404.38 1850.02,1404.38 1850.03,1404.38 1850.03,1404.38 1850.03,1404.38 1850.04,1404.38 1850.04,1404.38 1850.04,1404.38 1850.04,1404.38 1850.05,1404.38 1850.05,1404.38 1850.05,1404.38 1850.06,1404.38 1850.06,1404.38 1850.06,1404.38 1850.07,1404.38 1850.07,1404.38 1850.07,1404.38 1850.08,1404.38 1850.08,1404.38 1850.08,1404.38 1850.08,1404.38 1850.09,1404.38 1850.09,1404.38 1850.09,1404.38 1850.1,1404.38 1850.1,1404.38 1850.1,1404.38 1850.11,1404.38 1850.11,1404.38 1850.11,1404.38 1850.12,1404.38 1850.12,1404.38 1850.12,1404.38 1850.13,1404.38 1850.13,1404.38 1850.13,1404.38 1850.13,1404.38 1850.14,1404.38 1850.14,1404.38 1850.14,1404.38 1850.15,1404.38 1850.15,1404.38 1850.15,1404.38 1850.16,1404.38 1850.16,1404.38 1850.16,1404.38 1850.17,1404.38 1850.17,1404.38 1850.17,1404.38 1850.18,1404.38 1850.18,1404.38 1850.18,1404.38 1850.18,1404.38 1850.19,1404.38 1850.19,1404.38 1850.19,1404.38 1850.2,1404.38 1850.2,1404.38 1850.2,1404.38 1850.21,1404.38 1850.21,1404.38 1850.21,1404.38 1850.22,1404.38 1850.22,1404.38 1850.22,1404.38 1850.22,1404.38 1850.23,1404.38 1850.23,1404.38 1850.23,1404.38 1850.24,1404.38 1850.24,1404.38 1850.24,1404.38 1850.25,1404.38 1850.25,1404.38 1850.25,1404.38 1850.26,1404.38 1850.26,1404.38 1850.26,1404.38 1850.27,1404.38 1850.27,1404.38 1850.27,1404.38 1850.27,1404.38 1850.28,1404.38 1850.28,1404.38 1850.28,1404.38 1850.29,1404.38 1850.29,1404.38 1850.29,1404.37 1850.3,1404.37 1850.3,1404.37 1850.3,1404.37 1850.31,1404.37 1850.31,1404.37 1850.31,1404.37 1850.32,1404.37 1850.32,1404.37 1850.32,1404.37 1850.32,1404.37 1850.33,1404.37 1850.33,1404.37 1850.33,1404.37 1850.34,1404.37 1850.34,1404.37 1850.34,1404.37 1850.35,1404.37 1850.35,1404.37 1850.35,1404.37 1850.36,1404.37 1850.36,1404.37 1850.36,1404.37 1850.36,1404.37 1850.37,1404.37 1850.37,1404.37 1850.37,1404.37 1850.38,1404.37 1850.38,1404.37 1850.38,1404.37 1850.39,1404.37 1850.39,1404.37 1850.39,1404.37 1850.4,1404.37 1850.4,1404.37 1850.4,1404.37 1850.41,1404.37 1850.41,1404.37 1850.41,1404.37 1850.41,1404.37 1850.42,1404.37 1850.42,1404.37 1850.42,1404.37 1850.43,1404.37 1850.43,1404.37 1850.43,1404.37 1850.44,1404.37 1850.44,1404.37 1850.44,1404.37 1850.45,1404.37 1850.45,1404.37 1850.45,1404.37 1850.45,1404.37 1850.46,1404.37 1850.46,1404.37 1850.46,1404.37 1850.47,1404.37 1850.47,1404.37 1850.47,1404.37 1850.48,1404.37 1850.48,1404.37 1850.48,1404.37 1850.49,1404.37 1850.49,1404.37 1850.49,1404.37 1850.5,1404.37 1850.5,1404.37 1850.5,1404.37 1850.5,1404.37 1850.51,1404.37 1850.51,1404.37 1850.51,1404.37 1850.52,1404.37 1850.52,1404.37 1850.52,1404.37 1850.53,1404.37 1850.53,1404.37 1850.53,1404.37 1850.54,1404.37 1850.54,1404.37 1850.54,1404.37 1850.54,1404.37 1850.55,1404.37 1850.55,1404.37 1850.55,1404.37 1850.56,1404.37 1850.56,1404.37 1850.56,1404.37 1850.57,1404.37 1850.57,1404.37 1850.57,1404.37 1850.58,1404.37 1850.58,1404.37 1850.58,1404.37 1850.58,1404.37 1850.59,1404.37 1850.59,1404.37 1850.59,1404.37 1850.6,1404.37 1850.6,1404.37 1850.6,1404.37 1850.61,1404.37 1850.61,1404.37 1850.61,1404.37 1850.62,1404.37 1850.62,1404.37 1850.62,1404.37 1850.63,1404.37 1850.63,1404.37 1850.63,1404.37 1850.63,1404.37 1850.64,1404.37 1850.64,1404.37 1850.64,1404.37 1850.65,1404.37 1850.65,1404.37 1850.65,1404.37 1850.66,1404.37 1850.66,1404.37 1850.66,1404.37 1850.67,1404.37 1850.67,1404.37 1850.67,1404.37 1850.67,1404.37 1850.68,1404.37 1850.68,1404.37 1850.68,1404.36 1850.69,1404.36 1850.69,1404.36 1850.69,1404.36 1850.7,1404.36 1850.7,1404.36 1850.7,1404.36 1850.71,1404.36 1850.71,1404.36 1850.71,1404.36 1850.72,1404.36 1850.72,1404.36 1850.72,1404.36 1850.72,1404.36 1850.73,1404.36 1850.73,1404.36 1850.73,1404.36 1850.74,1404.36 1850.74,1404.36 1850.74,1404.36 1850.75,1404.36 1850.75,1404.36 1850.75,1404.36 1850.76,1404.36 1850.76,1404.36 1850.76,1404.36 1850.76,1404.36 1850.77,1404.36 1850.77,1404.36 1850.77,1404.36 1850.78,1404.36 1850.78,1404.36 1850.78,1404.36 1850.79,1404.36 1850.79,1404.36 1850.79,1404.36 1850.8,1404.36 1850.8,1404.36 1850.8,1404.36 1850.8,1404.36 1850.81,1404.36 1850.81,1404.36 1850.81,1404.36 1850.82,1404.36 1850.82,1404.36 1850.82,1404.36 1850.83,1404.36 1850.83,1404.36 1850.83,1404.36 1850.84,1404.36 1850.84,1404.36 1850.84,1404.36 1850.84,1404.36 1850.85,1404.36 1850.85,1404.36 1850.85,1404.36 1850.86,1404.36 1850.86,1404.36 1850.86,1404.36 1850.87,1404.36 1850.87,1404.36 1850.87,1404.36 1850.88,1404.36 1850.88,1404.36 1850.88,1404.36 1850.89,1404.36 1850.89,1404.36 1850.89,1404.36 1850.89,1404.36 1850.9,1404.36 1850.9,1404.36 1850.9,1404.36 1850.91,1404.36 1850.91,1404.36 1850.91,1404.36 1850.92,1404.36 1850.92,1404.36 1850.92,1404.36 1850.93,1404.36 1850.93,1404.36 1850.93,1404.36 1850.93,1404.36 1850.94,1404.36 1850.94,1404.36 1850.94,1404.36 1850.95,1404.36 1850.95,1404.36 1850.95,1404.36 1850.96,1404.36 1850.96,1404.36 1850.96,1404.36 1850.97,1404.36 1850.97,1404.36 1850.97,1404.36 1850.97,1404.36 1850.98,1404.36 1850.98,1404.36 1850.98,1404.36 1850.99,1404.36 1850.99,1404.36 1850.99,1404.36 1851,1404.36 1851,1404.36 1851,1404.36 1851.01,1404.36 1851.01,1404.36 1851.01,1404.36 1851.01,1404.36 1851.02,1404.36 1851.02,1404.36 1851.02,1404.36 1851.03,1404.36 1851.03,1404.36 1851.03,1404.36 1851.04,1404.36 1851.04,1404.36 1851.04,1404.36 1851.05,1404.36 1851.05,1404.36 1851.05,1404.36 1851.05,1404.36 1851.06,1404.36 1851.06,1404.36 1851.06,1404.36 1851.07,1404.36 1851.07,1404.36 1851.07,1404.36 1851.08,1404.35 1851.08,1404.35 1851.08,1404.35 1851.09,1404.35 1851.09,1404.35 1851.09,1404.35 1851.09,1404.35 1851.1,1404.35 1851.1,1404.35 1851.1,1404.35 1851.11,1404.35 1851.11,1404.35 1851.11,1404.35 1851.12,1404.35 1851.12,1404.35 1851.12,1404.35 1851.13,1404.35 1851.13,1404.35 1851.13,1404.35 1851.14,1404.35 1851.14,1404.35 1851.14,1404.35 1851.14,1404.35 1851.15,1404.35 1851.15,1404.35 1851.15,1404.35 1851.16,1404.35 1851.16,1404.35 1851.16,1404.35 1851.17,1404.35 1851.17,1404.35 1851.17,1404.35 1851.18,1404.35 1851.18,1404.35 1851.18,1404.35 1851.18,1404.35 1851.19,1404.35 1851.19,1404.35 1851.19,1404.35 1851.2,1404.35 1851.2,1404.35 1851.2,1404.35 1851.21,1404.35 1851.21,1404.35 1851.21,1404.35 1851.22,1404.35 1851.22,1404.35 1851.22,1404.35 1851.22,1404.35 1851.23,1404.35 1851.23,1404.35 1851.23,1404.35 1851.24,1404.35 1851.24,1404.35 1851.24,1404.35 1851.25,1404.35 1851.25,1404.35 1851.25,1404.35 1851.26,1404.35 1851.26,1404.35 1851.26,1404.35 1851.26,1404.35 1851.27,1404.35 1851.27,1404.35 1851.27,1404.35 1851.28,1404.35 1851.28,1404.35 1851.28,1404.35 1851.29,1404.35 1851.29,1404.35 1851.29,1404.35 1851.3,1404.35 1851.3,1404.35 1851.3,1404.35 1851.3,1404.35 1851.31,1404.35 1851.31,1404.35 1851.31,1404.35 1851.32,1404.35 1851.32,1404.35 1851.32,1404.35 1851.33,1404.35 1851.33,1404.35 1851.33,1404.35 1851.34,1404.35 1851.34,1404.35 1851.34,1404.35 1851.34,1404.35 1851.35,1404.35 1851.35,1404.35 1851.35,1404.35 1851.36,1404.35 1851.36,1404.35 1851.36,1404.35 1851.37,1404.35 1851.37,1404.35 1851.37,1404.35 1851.38,1404.35 1851.38,1404.35 1851.38,1404.35 1851.38,1404.35 1851.39,1404.35 1851.39,1404.35 1851.39,1404.35 1851.4,1404.35 1851.4,1404.35 1851.4,1404.35 1851.41,1404.35 1851.41,1404.35 1851.41,1404.35 1851.42,1404.35 1851.42,1404.35 1851.42,1404.35 1851.42,1404.35 1851.43,1404.35 1851.43,1404.35 1851.43,1404.35 1851.44,1404.35 1851.44,1404.35 1851.44,1404.35 1851.45,1404.35 1851.45,1404.35 1851.45,1404.35 1851.46,1404.35 1851.46,1404.35 1851.46,1404.35 1851.46,1404.35 1851.47,1404.34 1851.47,1404.34 1851.47,1404.34 1851.48,1404.34 1851.48,1404.34 1851.48,1404.34 1851.49,1404.34 1851.49,1404.34 1851.49,1404.34 1851.5,1404.34 1851.5,1404.34 1851.5,1404.34 1851.5,1404.34 1851.51,1404.34 1851.51,1404.34 1851.51,1404.34 1851.52,1404.34 1851.52,1404.34 1851.52,1404.34 1851.53,1404.34 1851.53,1404.34 1851.53,1404.34 1851.53,1404.34 1851.54,1404.34 1851.54,1404.34 1851.54,1404.34 1851.55,1404.34 1851.55,1404.34 1851.55,1404.34 1851.56,1404.34 1851.56,1404.34 1851.56,1404.34 1851.57,1404.34 1851.57,1404.34 1851.57,1404.34 1851.57,1404.34 1851.58,1404.34 1851.58,1404.34 1851.58,1404.34 1851.59,1404.34 1851.59,1404.34 1851.59,1404.34 1851.6,1404.34 1851.6,1404.34 1851.6,1404.34 1851.61,1404.34 1851.61,1404.34 1851.61,1404.34 1851.61,1404.34 1851.62,1404.34 1851.62,1404.34 1851.62,1404.34 1851.63,1404.34 1851.63,1404.34 1851.63,1404.34 1851.64,1404.34 1851.64,1404.34 1851.64,1404.34 1851.65,1404.34 1851.65,1404.34 1851.65,1404.34 1851.65,1404.34 1851.66,1404.34 1851.66,1404.34 1851.66,1404.34 1851.67,1404.34 1851.67,1404.34 1851.67,1404.34 1851.68,1404.34 1851.68,1404.34 1851.68,1404.34 1851.69,1404.34 1851.69,1404.34 1851.69,1404.34 1851.69,1404.34 1851.7,1404.34 1851.7,1404.34 1851.7,1404.34 1851.71,1404.34 1851.71,1404.34 1851.71,1404.34 1851.72,1404.34 1851.72,1404.34 1851.72,1404.34 1851.73,1404.34 1851.73,1404.34 1851.73,1404.34 1851.73,1404.34 1851.74,1404.34 1851.74,1404.34 1851.74,1404.34 1851.75,1404.34 1851.75,1404.34 1851.75,1404.34 1851.76,1404.34 1851.76,1404.34 1851.76,1404.34 1851.76,1404.34 1851.77,1404.34 1851.77,1404.34 1851.77,1404.34 1851.78,1404.34 1851.78,1404.34 1851.78,1404.34 1851.79,1404.34 1851.79,1404.34 1851.79,1404.34 1851.8,1404.34 1851.8,1404.34 1851.8,1404.34 1851.8,1404.34 1851.81,1404.34 1851.81,1404.34 1851.81,1404.34 1851.82,1404.34 1851.82,1404.34 1851.82,1404.34 1851.83,1404.34 1851.83,1404.34 1851.83,1404.34 1851.84,1404.34 1851.84,1404.34 1851.84,1404.34 1851.84,1404.34 1851.85,1404.34 1851.85,1404.34 1851.85,1404.34 1851.86,1404.34 1851.86,1404.33 1851.86,1404.33 1851.87,1404.33 1851.87,1404.33 1851.87,1404.33 1851.88,1404.33 1851.88,1404.33 1851.88,1404.33 1851.88,1404.33 1851.89,1404.33 1851.89,1404.33 1851.89,1404.33 1851.9,1404.33 1851.9,1404.33 1851.9,1404.33 1851.91,1404.33 1851.91,1404.33 1851.91,1404.33 1851.91,1404.33 1851.92,1404.33 1851.92,1404.33 1851.92,1404.33 1851.93,1404.33 1851.93,1404.33 1851.93,1404.33 1851.94,1404.33 1851.94,1404.33 1851.94,1404.33 1851.95,1404.33 1851.95,1404.33 1851.95,1404.33 1851.95,1404.33 1851.96,1404.33 1851.96,1404.33 1851.96,1404.33 1851.97,1404.33 1851.97,1404.33 1851.97,1404.33 1851.98,1404.33 1851.98,1404.33 1851.98,1404.33 1851.99,1404.33 1851.99,1404.33 1851.99,1404.33 1851.99,1404.33 1852,1404.33 1852,1404.33 1852,1404.33 1852.01,1404.33 1852.01,1404.33 1852.01,1404.33 1852.02,1404.33 1852.02,1404.33 1852.02,1404.33 1852.03,1404.33 1852.03,1404.33 1852.03,1404.33 1852.03,1404.33 1852.04,1404.33 1852.04,1404.33 1852.04,1404.33 1852.05,1404.33 1852.05,1404.33 1852.05,1404.33 1852.06,1404.33 1852.06,1404.33 1852.06,1404.33 1852.06,1404.33 1852.07,1404.33 1852.07,1404.33 1852.07,1404.33 1852.08,1404.33 1852.08,1404.33 1852.08,1404.33 1852.09,1404.33 1852.09,1404.33 1852.09,1404.33 1852.1,1404.33 1852.1,1404.33 1852.1,1404.33 1852.1,1404.33 1852.11,1404.33 1852.11,1404.33 1852.11,1404.33 1852.12,1404.33 1852.12,1404.33 1852.12,1404.33 1852.13,1404.33 1852.13,1404.33 1852.13,1404.33 1852.14,1404.33 1852.14,1404.33 1852.14,1404.33 1852.14,1404.33 1852.15,1404.33 1852.15,1404.33 1852.15,1404.33 1852.16,1404.33 1852.16,1404.33 1852.16,1404.33 1852.17,1404.33 1852.17,1404.33 1852.17,1404.33 1852.17,1404.33 1852.18,1404.33 1852.18,1404.33 1852.18,1404.33 1852.19,1404.33 1852.19,1404.33 1852.19,1404.33 1852.2,1404.33 1852.2,1404.33 1852.2,1404.33 1852.21,1404.33 1852.21,1404.33 1852.21,1404.33 1852.21,1404.33 1852.22,1404.33 1852.22,1404.33 1852.22,1404.33 1852.23,1404.33 1852.23,1404.33 1852.23,1404.33 1852.24,1404.33 1852.24,1404.33 1852.24,1404.33 1852.24,1404.33 1852.25,1404.33 1852.25,1404.32 1852.25,1404.32 1852.26,1404.32 1852.26,1404.32 1852.26,1404.32 1852.27,1404.32 1852.27,1404.32 1852.27,1404.32 1852.28,1404.32 1852.28,1404.32 1852.28,1404.32 1852.28,1404.32 1852.29,1404.32 1852.29,1404.32 1852.29,1404.32 1852.3,1404.32 1852.3,1404.32 1852.3,1404.32 1852.31,1404.32 1852.31,1404.32 1852.31,1404.32 1852.32,1404.32 1852.32,1404.32 1852.32,1404.32 1852.32,1404.32 1852.33,1404.32 1852.33,1404.32 1852.33,1404.32 1852.34,1404.32 1852.34,1404.32 1852.34,1404.32 1852.35,1404.32 1852.35,1404.32 1852.35,1404.32 1852.35,1404.32 1852.36,1404.32 1852.36,1404.32 1852.36,1404.32 1852.37,1404.32 1852.37,1404.32 1852.37,1404.32 1852.38,1404.32 1852.38,1404.32 1852.38,1404.32 1852.39,1404.32 1852.39,1404.32 1852.39,1404.32 1852.39,1404.32 1852.4,1404.32 1852.4,1404.32 1852.4,1404.32 1852.41,1404.32 1852.41,1404.32 1852.41,1404.32 1852.42,1404.32 1852.42,1404.32 1852.42,1404.32 1852.42,1404.32 1852.43,1404.32 1852.43,1404.32 1852.43,1404.32 1852.44,1404.32 1852.44,1404.32 1852.44,1404.32 1852.45,1404.32 1852.45,1404.32 1852.45,1404.32 1852.46,1404.32 1852.46,1404.32 1852.46,1404.32 1852.46,1404.32 1852.47,1404.32 1852.47,1404.32 1852.47,1404.32 1852.48,1404.32 1852.48,1404.32 1852.48,1404.32 1852.49,1404.32 1852.49,1404.32 1852.49,1404.32 1852.49,1404.32 1852.5,1404.32 1852.5,1404.32 1852.5,1404.32 1852.51,1404.32 1852.51,1404.32 1852.51,1404.32 1852.52,1404.32 1852.52,1404.32 1852.52,1404.32 1852.53,1404.32 1852.53,1404.32 1852.53,1404.32 1852.53,1404.32 1852.54,1404.32 1852.54,1404.32 1852.54,1404.32 1852.55,1404.32 1852.55,1404.32 1852.55,1404.32 1852.56,1404.32 1852.56,1404.32 1852.56,1404.32 1852.56,1404.32 1852.57,1404.32 1852.57,1404.32 1852.57,1404.32 1852.58,1404.32 1852.58,1404.32 1852.58,1404.32 1852.59,1404.32 1852.59,1404.32 1852.59,1404.32 1852.6,1404.32 1852.6,1404.32 1852.6,1404.32 1852.6,1404.32 1852.61,1404.32 1852.61,1404.32 1852.61,1404.32 1852.62,1404.32 1852.62,1404.32 1852.62,1404.32 1852.63,1404.32 1852.63,1404.32 1852.63,1404.32 1852.63,1404.32 1852.64,1404.32 1852.64,1404.32 1852.64,1404.31 1852.65,1404.31 1852.65,1404.31 1852.65,1404.31 1852.66,1404.31 1852.66,1404.31 1852.66,1404.31 1852.67,1404.31 1852.67,1404.31 1852.67,1404.31 1852.67,1404.31 1852.68,1404.31 1852.68,1404.31 1852.68,1404.31 1852.69,1404.31 1852.69,1404.31 1852.69,1404.31 1852.7,1404.31 1852.7,1404.31 1852.7,1404.31 1852.7,1404.31 1852.71,1404.31 1852.71,1404.31 1852.71,1404.31 1852.72,1404.31 1852.72,1404.31 1852.72,1404.31 1852.73,1404.31 1852.73,1404.31 1852.73,1404.31 1852.73,1404.31 1852.74,1404.31 1852.74,1404.31 1852.74,1404.31 1852.75,1404.31 1852.75,1404.31 1852.75,1404.31 1852.76,1404.31 1852.76,1404.31 1852.76,1404.31 1852.77,1404.31 1852.77,1404.31 1852.77,1404.31 1852.77,1404.31 1852.78,1404.31 1852.78,1404.31 1852.78,1404.31 1852.79,1404.31 1852.79,1404.31 1852.79,1404.31 1852.8,1404.31 1852.8,1404.31 1852.8,1404.31 1852.8,1404.31 1852.81,1404.31 1852.81,1404.31 1852.81,1404.31 1852.82,1404.31 1852.82,1404.31 1852.82,1404.31 1852.83,1404.31 1852.83,1404.31 1852.83,1404.31 1852.84,1404.31 1852.84,1404.31 1852.84,1404.31 1852.84,1404.31 1852.85,1404.31 1852.85,1404.31 1852.85,1404.31 1852.86,1404.31 1852.86,1404.31 1852.86,1404.31 1852.87,1404.31 1852.87,1404.31 1852.87,1404.31 1852.87,1404.31 1852.88,1404.31 1852.88,1404.31 1852.88,1404.31 1852.89,1404.31 1852.89,1404.31 1852.89,1404.31 1852.9,1404.31 1852.9,1404.31 1852.9,1404.31 1852.9,1404.31 1852.91,1404.31 1852.91,1404.31 1852.91,1404.31 1852.92,1404.31 1852.92,1404.31 1852.92,1404.31 1852.93,1404.31 1852.93,1404.31 1852.93,1404.31 1852.94,1404.31 1852.94,1404.31 1852.94,1404.31 1852.94,1404.31 1852.95,1404.31 1852.95,1404.31 1852.95,1404.31 1852.96,1404.31 1852.96,1404.31 1852.96,1404.31 1852.97,1404.31 1852.97,1404.31 1852.97,1404.31 1852.97,1404.31 1852.98,1404.31 1852.98,1404.31 1852.98,1404.31 1852.99,1404.31 1852.99,1404.31 1852.99,1404.31 1853,1404.31 1853,1404.31 1853,1404.31 1853,1404.31 1853.01,1404.31 1853.01,1404.31 1853.01,1404.31 1853.02,1404.31 1853.02,1404.31 1853.02,1404.31 1853.03,1404.31 1853.03,1404.31 1853.03,1404.3 1853.04,1404.3 1853.04,1404.3 1853.04,1404.3 1853.04,1404.3 1853.05,1404.3 1853.05,1404.3 1853.05,1404.3 1853.06,1404.3 1853.06,1404.3 1853.06,1404.3 1853.07,1404.3 1853.07,1404.3 1853.07,1404.3 1853.07,1404.3 1853.08,1404.3 1853.08,1404.3 1853.08,1404.3 1853.09,1404.3 1853.09,1404.3 1853.09,1404.3 1853.1,1404.3 1853.1,1404.3 1853.1,1404.3 1853.1,1404.3 1853.11,1404.3 1853.11,1404.3 1853.11,1404.3 1853.12,1404.3 1853.12,1404.3 1853.12,1404.3 1853.13,1404.3 1853.13,1404.3 1853.13,1404.3 1853.13,1404.3 1853.14,1404.3 1853.14,1404.3 1853.14,1404.3 1853.15,1404.3 1853.15,1404.3 1853.15,1404.3 1853.16,1404.3 1853.16,1404.3 1853.16,1404.3 1853.17,1404.3 1853.17,1404.3 1853.17,1404.3 1853.17,1404.3 1853.18,1404.3 1853.18,1404.3 1853.18,1404.3 1853.19,1404.3 1853.19,1404.3 1853.19,1404.3 1853.2,1404.3 1853.2,1404.3 1853.2,1404.3 1853.2,1404.3 1853.21,1404.3 1853.21,1404.3 1853.21,1404.3 1853.22,1404.3 1853.22,1404.3 1853.22,1404.3 1853.23,1404.3 1853.23,1404.3 1853.23,1404.3 1853.23,1404.3 1853.24,1404.3 1853.24,1404.3 1853.24,1404.3 1853.25,1404.3 1853.25,1404.3 1853.25,1404.3 1853.26,1404.3 1853.26,1404.3 1853.26,1404.3 1853.26,1404.3 1853.27,1404.3 1853.27,1404.3 1853.27,1404.3 1853.28,1404.3 1853.28,1404.3 1853.28,1404.3 1853.29,1404.3 1853.29,1404.3 1853.29,1404.3 1853.3,1404.3 1853.3,1404.3 1853.3,1404.3 1853.3,1404.3 1853.31,1404.3 1853.31,1404.3 1853.31,1404.3 1853.32,1404.3 1853.32,1404.3 1853.32,1404.3 1853.33,1404.3 1853.33,1404.3 1853.33,1404.3 1853.33,1404.3 1853.34,1404.3 1853.34,1404.3 1853.34,1404.3 1853.35,1404.3 1853.35,1404.3 1853.35,1404.3 1853.36,1404.3 1853.36,1404.3 1853.36,1404.3 1853.36,1404.3 1853.37,1404.3 1853.37,1404.3 1853.37,1404.3 1853.38,1404.3 1853.38,1404.3 1853.38,1404.3 1853.39,1404.3 1853.39,1404.3 1853.39,1404.3 1853.39,1404.3 1853.4,1404.3 1853.4,1404.3 1853.4,1404.3 1853.41,1404.3 1853.41,1404.3 1853.41,1404.3 1853.42,1404.3 1853.42,1404.3 1853.42,1404.3 1853.43,1404.29 1853.43,1404.29 1853.43,1404.29 1853.43,1404.29 1853.44,1404.29 1853.44,1404.29 1853.44,1404.29 1853.45,1404.29 1853.45,1404.29 1853.45,1404.29 1853.46,1404.29 1853.46,1404.29 1853.46,1404.29 1853.46,1404.29 1853.47,1404.29 1853.47,1404.29 1853.47,1404.29 1853.48,1404.29 1853.48,1404.29 1853.48,1404.29 1853.49,1404.29 1853.49,1404.29 1853.49,1404.29 1853.49,1404.29 1853.5,1404.29 1853.5,1404.29 1853.5,1404.29 1853.51,1404.29 1853.51,1404.29 1853.51,1404.29 1853.52,1404.29 1853.52,1404.29 1853.52,1404.29 1853.52,1404.29 1853.53,1404.29 1853.53,1404.29 1853.53,1404.29 1853.54,1404.29 1853.54,1404.29 1853.54,1404.29 1853.55,1404.29 1853.55,1404.29 1853.55,1404.29 1853.55,1404.29 1853.56,1404.29 1853.56,1404.29 1853.56,1404.29 1853.57,1404.29 1853.57,1404.29 1853.57,1404.29 1853.58,1404.29 1853.58,1404.29 1853.58,1404.29 1853.58,1404.29 1853.59,1404.29 1853.59,1404.29 1853.59,1404.29 1853.6,1404.29 1853.6,1404.29 1853.6,1404.29 1853.61,1404.29 1853.61,1404.29 1853.61,1404.29 1853.61,1404.29 1853.62,1404.29 1853.62,1404.29 1853.62,1404.29 1853.63,1404.29 1853.63,1404.29 1853.63,1404.29 1853.64,1404.29 1853.64,1404.29 1853.64,1404.29 1853.65,1404.29 1853.65,1404.29 1853.65,1404.29 1853.65,1404.29 1853.66,1404.29 1853.66,1404.29 1853.66,1404.29 1853.67,1404.29 1853.67,1404.29 1853.67,1404.29 1853.68,1404.29 1853.68,1404.29 1853.68,1404.29 1853.68,1404.29 1853.69,1404.29 1853.69,1404.29 1853.69,1404.29 1853.7,1404.29 1853.7,1404.29 1853.7,1404.29 1853.71,1404.29 1853.71,1404.29 1853.71,1404.29 1853.71,1404.29 1853.72,1404.29 1853.72,1404.29 1853.72,1404.29 1853.73,1404.29 1853.73,1404.29 1853.73,1404.29 1853.74,1404.29 1853.74,1404.29 1853.74,1404.29 1853.74,1404.29 1853.75,1404.29 1853.75,1404.29 1853.75,1404.29 1853.76,1404.29 1853.76,1404.29 1853.76,1404.29 1853.77,1404.29 1853.77,1404.29 1853.77,1404.29 1853.77,1404.29 1853.78,1404.29 1853.78,1404.29 1853.78,1404.29 1853.79,1404.29 1853.79,1404.29 1853.79,1404.29 1853.8,1404.29 1853.8,1404.29 1853.8,1404.29 1853.8,1404.29 1853.81,1404.29 1853.81,1404.29 1853.81,1404.29 1853.82,1404.28 1853.82,1404.28 1853.82,1404.28 1853.83,1404.28 1853.83,1404.28 1853.83,1404.28 1853.83,1404.28 1853.84,1404.28 1853.84,1404.28 1853.84,1404.28 1853.85,1404.28 1853.85,1404.28 1853.85,1404.28 1853.86,1404.28 1853.86,1404.28 1853.86,1404.28 1853.86,1404.28 1853.87,1404.28 1853.87,1404.28 1853.87,1404.28 1853.88,1404.28 1853.88,1404.28 1853.88,1404.28 1853.89,1404.28 1853.89,1404.28 1853.89,1404.28 1853.89,1404.28 1853.9,1404.28 1853.9,1404.28 1853.9,1404.28 1853.91,1404.28 1853.91,1404.28 1853.91,1404.28 1853.92,1404.28 1853.92,1404.28 1853.92,1404.28 1853.92,1404.28 1853.93,1404.28 1853.93,1404.28 1853.93,1404.28 1853.94,1404.28 1853.94,1404.28 1853.94,1404.28 1853.95,1404.28 1853.95,1404.28 1853.95,1404.28 1853.95,1404.28 1853.96,1404.28 1853.96,1404.28 1853.96,1404.28 1853.97,1404.28 1853.97,1404.28 1853.97,1404.28 1853.98,1404.28 1853.98,1404.28 1853.98,1404.28 1853.98,1404.28 1853.99,1404.28 1853.99,1404.28 1853.99,1404.28 1854,1404.28 1854,1404.28 1854,1404.28 1854.01,1404.28 1854.01,1404.28 1854.01,1404.28 1854.01,1404.28 1854.02,1404.28 1854.02,1404.28 1854.02,1404.28 1854.03,1404.28 1854.03,1404.28 1854.03,1404.28 1854.04,1404.28 1854.04,1404.28 1854.04,1404.28 1854.04,1404.28 1854.05,1404.28 1854.05,1404.28 1854.05,1404.28 1854.06,1404.28 1854.06,1404.28 1854.06,1404.28 1854.07,1404.28 1854.07,1404.28 1854.07,1404.28 1854.07,1404.28 1854.08,1404.28 1854.08,1404.28 1854.08,1404.28 1854.09,1404.28 1854.09,1404.28 1854.09,1404.28 1854.1,1404.28 1854.1,1404.28 1854.1,1404.28 1854.1,1404.28 1854.11,1404.28 1854.11,1404.28 1854.11,1404.28 1854.12,1404.28 1854.12,1404.28 1854.12,1404.28 1854.13,1404.28 1854.13,1404.28 1854.13,1404.28 1854.13,1404.28 1854.14,1404.28 1854.14,1404.28 1854.14,1404.28 1854.15,1404.28 1854.15,1404.28 1854.15,1404.28 1854.16,1404.28 1854.16,1404.28 1854.16,1404.28 1854.16,1404.28 1854.17,1404.28 1854.17,1404.28 1854.17,1404.28 1854.18,1404.28 1854.18,1404.28 1854.18,1404.28 1854.19,1404.28 1854.19,1404.28 1854.19,1404.28 1854.19,1404.28 1854.2,1404.28 1854.2,1404.28 1854.2,1404.28 1854.21,1404.27 1854.21,1404.27 1854.21,1404.27 1854.22,1404.27 1854.22,1404.27 1854.22,1404.27 1854.22,1404.27 1854.23,1404.27 1854.23,1404.27 1854.23,1404.27 1854.24,1404.27 1854.24,1404.27 1854.24,1404.27 1854.25,1404.27 1854.25,1404.27 1854.25,1404.27 1854.25,1404.27 1854.26,1404.27 1854.26,1404.27 1854.26,1404.27 1854.27,1404.27 1854.27,1404.27 1854.27,1404.27 1854.28,1404.27 1854.28,1404.27 1854.28,1404.27 1854.28,1404.27 1854.29,1404.27 1854.29,1404.27 1854.29,1404.27 1854.3,1404.27 1854.3,1404.27 1854.3,1404.27 1854.31,1404.27 1854.31,1404.27 1854.31,1404.27 1854.31,1404.27 1854.32,1404.27 1854.32,1404.27 1854.32,1404.27 1854.33,1404.27 1854.33,1404.27 1854.33,1404.27 1854.34,1404.27 1854.34,1404.27 1854.34,1404.27 1854.34,1404.27 1854.35,1404.27 1854.35,1404.27 1854.35,1404.27 1854.36,1404.27 1854.36,1404.27 1854.36,1404.27 1854.37,1404.27 1854.37,1404.27 1854.37,1404.27 1854.37,1404.27 1854.38,1404.27 1854.38,1404.27 1854.38,1404.27 1854.39,1404.27 1854.39,1404.27 1854.39,1404.27 1854.4,1404.27 1854.4,1404.27 1854.4,1404.27 1854.4,1404.27 1854.41,1404.27 1854.41,1404.27 1854.41,1404.27 1854.42,1404.27 1854.42,1404.27 1854.42,1404.27 1854.43,1404.27 1854.43,1404.27 1854.43,1404.27 1854.43,1404.27 1854.44,1404.27 1854.44,1404.27 1854.44,1404.27 1854.45,1404.27 1854.45,1404.27 1854.45,1404.27 1854.46,1404.27 1854.46,1404.27 1854.46,1404.27 1854.46,1404.27 1854.47,1404.27 1854.47,1404.27 1854.47,1404.27 1854.48,1404.27 1854.48,1404.27 1854.48,1404.27 1854.49,1404.27 1854.49,1404.27 1854.49,1404.27 1854.49,1404.27 1854.5,1404.27 1854.5,1404.27 1854.5,1404.27 1854.51,1404.27 1854.51,1404.27 1854.51,1404.27 1854.52,1404.27 1854.52,1404.27 1854.52,1404.27 1854.52,1404.27 1854.53,1404.27 1854.53,1404.27 1854.53,1404.27 1854.54,1404.27 1854.54,1404.27 1854.54,1404.27 1854.54,1404.27 1854.55,1404.27 1854.55,1404.27 1854.55,1404.27 1854.56,1404.27 1854.56,1404.27 1854.56,1404.27 1854.57,1404.27 1854.57,1404.27 1854.57,1404.27 1854.57,1404.27 1854.58,1404.27 1854.58,1404.27 1854.58,1404.27 1854.59,1404.27 1854.59,1404.27 1854.59,1404.27 1854.6,1404.26 1854.6,1404.26 1854.6,1404.26 1854.6,1404.26 1854.61,1404.26 1854.61,1404.26 1854.61,1404.26 1854.62,1404.26 1854.62,1404.26 1854.62,1404.26 1854.63,1404.26 1854.63,1404.26 1854.63,1404.26 1854.63,1404.26 1854.64,1404.26 1854.64,1404.26 1854.64,1404.26 1854.65,1404.26 1854.65,1404.26 1854.65,1404.26 1854.66,1404.26 1854.66,1404.26 1854.66,1404.26 1854.66,1404.26 1854.67,1404.26 1854.67,1404.26 1854.67,1404.26 1854.68,1404.26 1854.68,1404.26 1854.68,1404.26 1854.69,1404.26 1854.69,1404.26 1854.69,1404.26 1854.69,1404.26 1854.7,1404.26 1854.7,1404.26 1854.7,1404.26 1854.71,1404.26 1854.71,1404.26 1854.71,1404.26 1854.72,1404.26 1854.72,1404.26 1854.72,1404.26 1854.72,1404.26 1854.73,1404.26 1854.73,1404.26 1854.73,1404.26 1854.74,1404.26 1854.74,1404.26 1854.74,1404.26 1854.74,1404.26 1854.75,1404.26 1854.75,1404.26 1854.75,1404.26 1854.76,1404.26 1854.76,1404.26 1854.76,1404.26 1854.77,1404.26 1854.77,1404.26 1854.77,1404.26 1854.77,1404.26 1854.78,1404.26 1854.78,1404.26 1854.78,1404.26 1854.79,1404.26 1854.79,1404.26 1854.79,1404.26 1854.8,1404.26 1854.8,1404.26 1854.8,1404.26 1854.8,1404.26 1854.81,1404.26 1854.81,1404.26 1854.81,1404.26 1854.82,1404.26 1854.82,1404.26 1854.82,1404.26 1854.83,1404.26 1854.83,1404.26 1854.83,1404.26 1854.83,1404.26 1854.84,1404.26 1854.84,1404.26 1854.84,1404.26 1854.85,1404.26 1854.85,1404.26 1854.85,1404.26 1854.86,1404.26 1854.86,1404.26 1854.86,1404.26 1854.86,1404.26 1854.87,1404.26 1854.87,1404.26 1854.87,1404.26 1854.88,1404.26 1854.88,1404.26 1854.88,1404.26 1854.89,1404.26 1854.89,1404.26 1854.89,1404.26 1854.89,1404.26 1854.9,1404.26 1854.9,1404.26 1854.9,1404.26 1854.91,1404.26 1854.91,1404.26 1854.91,1404.26 1854.91,1404.26 1854.92,1404.26 1854.92,1404.26 1854.92,1404.26 1854.93,1404.26 1854.93,1404.26 1854.93,1404.26 1854.94,1404.26 1854.94,1404.26 1854.94,1404.26 1854.94,1404.26 1854.95,1404.26 1854.95,1404.26 1854.95,1404.26 1854.96,1404.26 1854.96,1404.26 1854.96,1404.26 1854.97,1404.26 1854.97,1404.26 1854.97,1404.26 1854.97,1404.26 1854.98,1404.26 1854.98,1404.26 1854.98,1404.26 1854.99,1404.25 1854.99,1404.25 1854.99,1404.25 1855,1404.25 1855,1404.25 1855,1404.25 1855,1404.25 1855.01,1404.25 1855.01,1404.25 1855.01,1404.25 1855.02,1404.25 1855.02,1404.25 1855.02,1404.25 1855.02,1404.25 1855.03,1404.25 1855.03,1404.25 1855.03,1404.25 1855.04,1404.25 1855.04,1404.25 1855.04,1404.25 1855.05,1404.25 1855.05,1404.25 1855.05,1404.25 1855.05,1404.25 1855.06,1404.25 1855.06,1404.25 1855.06,1404.25 1855.07,1404.25 1855.07,1404.25 1855.07,1404.25 1855.08,1404.25 1855.08,1404.25 1855.08,1404.25 1855.08,1404.25 1855.09,1404.25 1855.09,1404.25 1855.09,1404.25 1855.1,1404.25 1855.1,1404.25 1855.1,1404.25 1855.11,1404.25 1855.11,1404.25 1855.11,1404.25 1855.11,1404.25 1855.12,1404.25 1855.12,1404.25 1855.12,1404.25 1855.13,1404.25 1855.13,1404.25 1855.13,1404.25 1855.13,1404.25 1855.14,1404.25 1855.14,1404.25 1855.14,1404.25 1855.15,1404.25 1855.15,1404.25 1855.15,1404.25 1855.16,1404.25 1855.16,1404.25 1855.16,1404.25 1855.16,1404.25 1855.17,1404.25 1855.17,1404.25 1855.17,1404.25 1855.18,1404.25 1855.18,1404.25 1855.18,1404.25 1855.19,1404.25 1855.19,1404.25 1855.19,1404.25 1855.19,1404.25 1855.2,1404.25 1855.2,1404.25 1855.2,1404.25 1855.21,1404.25 1855.21,1404.25 1855.21,1404.25 1855.22,1404.25 1855.22,1404.25 1855.22,1404.25 1855.22,1404.25 1855.23,1404.25 1855.23,1404.25 1855.23,1404.25 1855.24,1404.25 1855.24,1404.25 1855.24,1404.25 1855.24,1404.25 1855.25,1404.25 1855.25,1404.25 1855.25,1404.25 1855.26,1404.25 1855.26,1404.25 1855.26,1404.25 1855.27,1404.25 1855.27,1404.25 1855.27,1404.25 1855.27,1404.25 1855.28,1404.25 1855.28,1404.25 1855.28,1404.25 1855.29,1404.25 1855.29,1404.25 1855.29,1404.25 1855.3,1404.25 1855.3,1404.25 1855.3,1404.25 1855.3,1404.25 1855.31,1404.25 1855.31,1404.25 1855.31,1404.25 1855.32,1404.25 1855.32,1404.25 1855.32,1404.25 1855.33,1404.25 1855.33,1404.25 1855.33,1404.25 1855.33,1404.25 1855.34,1404.25 1855.34,1404.25 1855.34,1404.25 1855.35,1404.25 1855.35,1404.25 1855.35,1404.25 1855.35,1404.25 1855.36,1404.25 1855.36,1404.25 1855.36,1404.25 1855.37,1404.25 1855.37,1404.25 1855.37,1404.25 1855.38,1404.25 1855.38,1404.24 1855.38,1404.24 1855.38,1404.24 1855.39,1404.24 1855.39,1404.24 1855.39,1404.24 1855.4,1404.24 1855.4,1404.24 1855.4,1404.24 1855.41,1404.24 1855.41,1404.24 1855.41,1404.24 1855.41,1404.24 1855.42,1404.24 1855.42,1404.24 1855.42,1404.24 1855.43,1404.24 1855.43,1404.24 1855.43,1404.24 1855.43,1404.24 1855.44,1404.24 1855.44,1404.24 1855.44,1404.24 1855.45,1404.24 1855.45,1404.24 1855.45,1404.24 1855.46,1404.24 1855.46,1404.24 1855.46,1404.24 1855.46,1404.24 1855.47,1404.24 1855.47,1404.24 1855.47,1404.24 1855.48,1404.24 1855.48,1404.24 1855.48,1404.24 1855.49,1404.24 1855.49,1404.24 1855.49,1404.24 1855.49,1404.24 1855.5,1404.24 1855.5,1404.24 1855.5,1404.24 1855.51,1404.24 1855.51,1404.24 1855.51,1404.24 1855.51,1404.24 1855.52,1404.24 1855.52,1404.24 1855.52,1404.24 1855.53,1404.24 1855.53,1404.24 1855.53,1404.24 1855.54,1404.24 1855.54,1404.24 1855.54,1404.24 1855.54,1404.24 1855.55,1404.24 1855.55,1404.24 1855.55,1404.24 1855.56,1404.24 1855.56,1404.24 1855.56,1404.24 1855.57,1404.24 1855.57,1404.24 1855.57,1404.24 1855.57,1404.24 1855.58,1404.24 1855.58,1404.24 1855.58,1404.24 1855.59,1404.24 1855.59,1404.24 1855.59,1404.24 1855.59,1404.24 1855.6,1404.24 1855.6,1404.24 1855.6,1404.24 1855.61,1404.24 1855.61,1404.24 1855.61,1404.24 1855.62,1404.24 1855.62,1404.24 1855.62,1404.24 1855.62,1404.24 1855.63,1404.24 1855.63,1404.24 1855.63,1404.24 1855.64,1404.24 1855.64,1404.24 1855.64,1404.24 1855.65,1404.24 1855.65,1404.24 1855.65,1404.24 1855.65,1404.24 1855.66,1404.24 1855.66,1404.24 1855.66,1404.24 1855.67,1404.24 1855.67,1404.24 1855.67,1404.24 1855.67,1404.24 1855.68,1404.24 1855.68,1404.24 1855.68,1404.24 1855.69,1404.24 1855.69,1404.24 1855.69,1404.24 1855.7,1404.24 1855.7,1404.24 1855.7,1404.24 1855.7,1404.24 1855.71,1404.24 1855.71,1404.24 1855.71,1404.24 1855.72,1404.24 1855.72,1404.24 1855.72,1404.24 1855.72,1404.24 1855.73,1404.24 1855.73,1404.24 1855.73,1404.24 1855.74,1404.24 1855.74,1404.24 1855.74,1404.24 1855.75,1404.24 1855.75,1404.24 1855.75,1404.24 1855.75,1404.24 1855.76,1404.24 1855.76,1404.24 1855.76,1404.24 1855.77,1404.23 1855.77,1404.23 1855.77,1404.23 1855.78,1404.23 1855.78,1404.23 1855.78,1404.23 1855.78,1404.23 1855.79,1404.23 1855.79,1404.23 1855.79,1404.23 1855.8,1404.23 1855.8,1404.23 1855.8,1404.23 1855.8,1404.23 1855.81,1404.23 1855.81,1404.23 1855.81,1404.23 1855.82,1404.23 1855.82,1404.23 1855.82,1404.23 1855.83,1404.23 1855.83,1404.23 1855.83,1404.23 1855.83,1404.23 1855.84,1404.23 1855.84,1404.23 1855.84,1404.23 1855.85,1404.23 1855.85,1404.23 1855.85,1404.23 1855.86,1404.23 1855.86,1404.23 1855.86,1404.23 1855.86,1404.23 1855.87,1404.23 1855.87,1404.23 1855.87,1404.23 1855.88,1404.23 1855.88,1404.23 1855.88,1404.23 1855.88,1404.23 1855.89,1404.23 1855.89,1404.23 1855.89,1404.23 1855.9,1404.23 1855.9,1404.23 1855.9,1404.23 1855.91,1404.23 1855.91,1404.23 1855.91,1404.23 1855.91,1404.23 1855.92,1404.23 1855.92,1404.23 1855.92,1404.23 1855.93,1404.23 1855.93,1404.23 1855.93,1404.23 1855.93,1404.23 1855.94,1404.23 1855.94,1404.23 1855.94,1404.23 1855.95,1404.23 1855.95,1404.23 1855.95,1404.23 1855.96,1404.23 1855.96,1404.23 1855.96,1404.23 1855.96,1404.23 1855.97,1404.23 1855.97,1404.23 1855.97,1404.23 1855.98,1404.23 1855.98,1404.23 1855.98,1404.23 1855.98,1404.23 1855.99,1404.23 1855.99,1404.23 1855.99,1404.23 1856,1404.23 1856,1404.23 1856,1404.23 1856.01,1404.23 1856.01,1404.23 1856.01,1404.23 1856.01,1404.23 1856.02,1404.23 1856.02,1404.23 1856.02,1404.23 1856.03,1404.23 1856.03,1404.23 1856.03,1404.23 1856.04,1404.23 1856.04,1404.23 1856.04,1404.23 1856.04,1404.23 1856.05,1404.23 1856.05,1404.23 1856.05,1404.23 1856.06,1404.23 1856.06,1404.23 1856.06,1404.23 1856.06,1404.23 1856.07,1404.23 1856.07,1404.23 1856.07,1404.23 1856.08,1404.23 1856.08,1404.23 1856.08,1404.23 1856.09,1404.23 1856.09,1404.23 1856.09,1404.23 1856.09,1404.23 1856.1,1404.23 1856.1,1404.23 1856.1,1404.23 1856.11,1404.23 1856.11,1404.23 1856.11,1404.23 1856.11,1404.23 1856.12,1404.23 1856.12,1404.23 1856.12,1404.23 1856.13,1404.23 1856.13,1404.23 1856.13,1404.23 1856.14,1404.23 1856.14,1404.23 1856.14,1404.23 1856.14,1404.23 1856.15,1404.23 1856.15,1404.23 1856.15,1404.23 1856.16,1404.23 1856.16,1404.22 1856.16,1404.22 1856.16,1404.22 1856.17,1404.22 1856.17,1404.22 1856.17,1404.22 1856.18,1404.22 1856.18,1404.22 1856.18,1404.22 1856.19,1404.22 1856.19,1404.22 1856.19,1404.22 1856.19,1404.22 1856.2,1404.22 1856.2,1404.22 1856.2,1404.22 1856.21,1404.22 1856.21,1404.22 1856.21,1404.22 1856.21,1404.22 1856.22,1404.22 1856.22,1404.22 1856.22,1404.22 1856.23,1404.22 1856.23,1404.22 1856.23,1404.22 1856.24,1404.22 1856.24,1404.22 1856.24,1404.22 1856.24,1404.22 1856.25,1404.22 1856.25,1404.22 1856.25,1404.22 1856.26,1404.22 1856.26,1404.22 1856.26,1404.22 1856.26,1404.22 1856.27,1404.22 1856.27,1404.22 1856.27,1404.22 1856.28,1404.22 1856.28,1404.22 1856.28,1404.22 1856.29,1404.22 1856.29,1404.22 1856.29,1404.22 1856.29,1404.22 1856.3,1404.22 1856.3,1404.22 1856.3,1404.22 1856.31,1404.22 1856.31,1404.22 1856.31,1404.22 1856.32,1404.22 1856.32,1404.22 1856.32,1404.22 1856.32,1404.22 1856.33,1404.22 1856.33,1404.22 1856.33,1404.22 1856.34,1404.22 1856.34,1404.22 1856.34,1404.22 1856.34,1404.22 1856.35,1404.22 1856.35,1404.22 1856.35,1404.22 1856.36,1404.22 1856.36,1404.22 1856.36,1404.22 1856.37,1404.22 1856.37,1404.22 1856.37,1404.22 1856.37,1404.22 1856.38,1404.22 1856.38,1404.22 1856.38,1404.22 1856.39,1404.22 1856.39,1404.22 1856.39,1404.22 1856.39,1404.22 1856.4,1404.22 1856.4,1404.22 1856.4,1404.22 1856.41,1404.22 1856.41,1404.22 1856.41,1404.22 1856.42,1404.22 1856.42,1404.22 1856.42,1404.22 1856.42,1404.22 1856.43,1404.22 1856.43,1404.22 1856.43,1404.22 1856.44,1404.22 1856.44,1404.22 1856.44,1404.22 1856.44,1404.22 1856.45,1404.22 1856.45,1404.22 1856.45,1404.22 1856.46,1404.22 1856.46,1404.22 1856.46,1404.22 1856.47,1404.22 1856.47,1404.22 1856.47,1404.22 1856.47,1404.22 1856.48,1404.22 1856.48,1404.22 1856.48,1404.22 1856.49,1404.22 1856.49,1404.22 1856.49,1404.22 1856.49,1404.22 1856.5,1404.22 1856.5,1404.22 1856.5,1404.22 1856.51,1404.22 1856.51,1404.22 1856.51,1404.22 1856.51,1404.22 1856.52,1404.22 1856.52,1404.22 1856.52,1404.22 1856.53,1404.22 1856.53,1404.22 1856.53,1404.22 1856.54,1404.22 1856.54,1404.22 1856.54,1404.22 1856.54,1404.22 1856.55,1404.21 1856.55,1404.21 1856.55,1404.21 1856.56,1404.21 1856.56,1404.21 1856.56,1404.21 1856.56,1404.21 1856.57,1404.21 1856.57,1404.21 1856.57,1404.21 1856.58,1404.21 1856.58,1404.21 1856.58,1404.21 1856.59,1404.21 1856.59,1404.21 1856.59,1404.21 1856.59,1404.21 1856.6,1404.21 1856.6,1404.21 1856.6,1404.21 1856.61,1404.21 1856.61,1404.21 1856.61,1404.21 1856.61,1404.21 1856.62,1404.21 1856.62,1404.21 1856.62,1404.21 1856.63,1404.21 1856.63,1404.21 1856.63,1404.21 1856.64,1404.21 1856.64,1404.21 1856.64,1404.21 1856.64,1404.21 1856.65,1404.21 1856.65,1404.21 1856.65,1404.21 1856.66,1404.21 1856.66,1404.21 1856.66,1404.21 1856.66,1404.21 1856.67,1404.21 1856.67,1404.21 1856.67,1404.21 1856.68,1404.21 1856.68,1404.21 1856.68,1404.21 1856.69,1404.21 1856.69,1404.21 1856.69,1404.21 1856.69,1404.21 1856.7,1404.21 1856.7,1404.21 1856.7,1404.21 1856.71,1404.21 1856.71,1404.21 1856.71,1404.21 1856.71,1404.21 1856.72,1404.21 1856.72,1404.21 1856.72,1404.21 1856.73,1404.21 1856.73,1404.21 1856.73,1404.21 1856.74,1404.21 1856.74,1404.21 1856.74,1404.21 1856.74,1404.21 1856.75,1404.21 1856.75,1404.21 1856.75,1404.21 1856.76,1404.21 1856.76,1404.21 1856.76,1404.21 1856.76,1404.21 1856.77,1404.21 1856.77,1404.21 1856.77,1404.21 1856.78,1404.21 1856.78,1404.21 1856.78,1404.21 1856.78,1404.21 1856.79,1404.21 1856.79,1404.21 1856.79,1404.21 1856.8,1404.21 1856.8,1404.21 1856.8,1404.21 1856.81,1404.21 1856.81,1404.21 1856.81,1404.21 1856.81,1404.21 1856.82,1404.21 1856.82,1404.21 1856.82,1404.21 1856.83,1404.21 1856.83,1404.21 1856.83,1404.21 1856.83,1404.21 1856.84,1404.21 1856.84,1404.21 1856.84,1404.21 1856.85,1404.21 1856.85,1404.21 1856.85,1404.21 1856.86,1404.21 1856.86,1404.21 1856.86,1404.21 1856.86,1404.21 1856.87,1404.21 1856.87,1404.21 1856.87,1404.21 1856.88,1404.21 1856.88,1404.21 1856.88,1404.21 1856.88,1404.21 1856.89,1404.21 1856.89,1404.21 1856.89,1404.21 1856.9,1404.21 1856.9,1404.21 1856.9,1404.21 1856.91,1404.21 1856.91,1404.21 1856.91,1404.21 1856.91,1404.21 1856.92,1404.21 1856.92,1404.21 1856.92,1404.21 1856.93,1404.21 1856.93,1404.21 1856.93,1404.21 1856.93,1404.21 1856.94,1404.2 1856.94,1404.2 1856.94,1404.2 1856.95,1404.2 1856.95,1404.2 1856.95,1404.2 1856.95,1404.2 1856.96,1404.2 1856.96,1404.2 1856.96,1404.2 1856.97,1404.2 1856.97,1404.2 1856.97,1404.2 1856.98,1404.2 1856.98,1404.2 1856.98,1404.2 1856.98,1404.2 1856.99,1404.2 1856.99,1404.2 1856.99,1404.2 1857,1404.2 1857,1404.2 1857,1404.2 1857,1404.2 1857.01,1404.2 1857.01,1404.2 1857.01,1404.2 1857.02,1404.2 1857.02,1404.2 1857.02,1404.2 1857.03,1404.2 1857.03,1404.2 1857.03,1404.2 1857.03,1404.2 1857.04,1404.2 1857.04,1404.2 1857.04,1404.2 1857.05,1404.2 1857.05,1404.2 1857.05,1404.2 1857.05,1404.2 1857.06,1404.2 1857.06,1404.2 1857.06,1404.2 1857.07,1404.2 1857.07,1404.2 1857.07,1404.2 1857.07,1404.2 1857.08,1404.2 1857.08,1404.2 1857.08,1404.2 1857.09,1404.2 1857.09,1404.2 1857.09,1404.2 1857.1,1404.2 1857.1,1404.2 1857.1,1404.2 1857.1,1404.2 1857.11,1404.2 1857.11,1404.2 1857.11,1404.2 1857.12,1404.2 1857.12,1404.2 1857.12,1404.2 1857.12,1404.2 1857.13,1404.2 1857.13,1404.2 1857.13,1404.2 1857.14,1404.2 1857.14,1404.2 1857.14,1404.2 1857.14,1404.2 1857.15,1404.2 1857.15,1404.2 1857.15,1404.2 1857.16,1404.2 1857.16,1404.2 1857.16,1404.2 1857.17,1404.2 1857.17,1404.2 1857.17,1404.2 1857.17,1404.2 1857.18,1404.2 1857.18,1404.2 1857.18,1404.2 1857.19,1404.2 1857.19,1404.2 1857.19,1404.2 1857.19,1404.2 1857.2,1404.2 1857.2,1404.2 1857.2,1404.2 1857.21,1404.2 1857.21,1404.2 1857.21,1404.2 1857.22,1404.2 1857.22,1404.2 1857.22,1404.2 1857.22,1404.2 1857.23,1404.2 1857.23,1404.2 1857.23,1404.2 1857.24,1404.2 1857.24,1404.2 1857.24,1404.2 1857.24,1404.2 1857.25,1404.2 1857.25,1404.2 1857.25,1404.2 1857.26,1404.2 1857.26,1404.2 1857.26,1404.2 1857.26,1404.2 1857.27,1404.2 1857.27,1404.2 1857.27,1404.2 1857.28,1404.2 1857.28,1404.2 1857.28,1404.2 1857.29,1404.2 1857.29,1404.2 1857.29,1404.2 1857.29,1404.2 1857.3,1404.2 1857.3,1404.2 1857.3,1404.2 1857.31,1404.2 1857.31,1404.2 1857.31,1404.2 1857.31,1404.2 1857.32,1404.2 1857.32,1404.2 1857.32,1404.2 1857.33,1404.19 1857.33,1404.19 1857.33,1404.19 1857.33,1404.19 1857.34,1404.19 1857.34,1404.19 1857.34,1404.19 1857.35,1404.19 1857.35,1404.19 1857.35,1404.19 1857.36,1404.19 1857.36,1404.19 1857.36,1404.19 1857.36,1404.19 1857.37,1404.19 1857.37,1404.19 1857.37,1404.19 1857.38,1404.19 1857.38,1404.19 1857.38,1404.19 1857.38,1404.19 1857.39,1404.19 1857.39,1404.19 1857.39,1404.19 1857.4,1404.19 1857.4,1404.19 1857.4,1404.19 1857.4,1404.19 1857.41,1404.19 1857.41,1404.19 1857.41,1404.19 1857.42,1404.19 1857.42,1404.19 1857.42,1404.19 1857.43,1404.19 1857.43,1404.19 1857.43,1404.19 1857.43,1404.19 1857.44,1404.19 1857.44,1404.19 1857.44,1404.19 1857.45,1404.19 1857.45,1404.19 1857.45,1404.19 1857.45,1404.19 1857.46,1404.19 1857.46,1404.19 1857.46,1404.19 1857.47,1404.19 1857.47,1404.19 1857.47,1404.19 1857.47,1404.19 1857.48,1404.19 1857.48,1404.19 1857.48,1404.19 1857.49,1404.19 1857.49,1404.19 1857.49,1404.19 1857.5,1404.19 1857.5,1404.19 1857.5,1404.19 1857.5,1404.19 1857.51,1404.19 1857.51,1404.19 1857.51,1404.19 1857.52,1404.19 1857.52,1404.19 1857.52,1404.19 1857.52,1404.19 1857.53,1404.19 1857.53,1404.19 1857.53,1404.19 1857.54,1404.19 1857.54,1404.19 1857.54,1404.19 1857.54,1404.19 1857.55,1404.19 1857.55,1404.19 1857.55,1404.19 1857.56,1404.19 1857.56,1404.19 1857.56,1404.19 1857.57,1404.19 1857.57,1404.19 1857.57,1404.19 1857.57,1404.19 1857.58,1404.19 1857.58,1404.19 1857.58,1404.19 1857.59,1404.19 1857.59,1404.19 1857.59,1404.19 1857.59,1404.19 1857.6,1404.19 1857.6,1404.19 1857.6,1404.19 1857.61,1404.19 1857.61,1404.19 1857.61,1404.19 1857.61,1404.19 1857.62,1404.19 1857.62,1404.19 1857.62,1404.19 1857.63,1404.19 1857.63,1404.19 1857.63,1404.19 1857.64,1404.19 1857.64,1404.19 1857.64,1404.19 1857.64,1404.19 1857.65,1404.19 1857.65,1404.19 1857.65,1404.19 1857.66,1404.19 1857.66,1404.19 1857.66,1404.19 1857.66,1404.19 1857.67,1404.19 1857.67,1404.19 1857.67,1404.19 1857.68,1404.19 1857.68,1404.19 1857.68,1404.19 1857.68,1404.19 1857.69,1404.19 1857.69,1404.19 1857.69,1404.19 1857.7,1404.19 1857.7,1404.19 1857.7,1404.19 1857.7,1404.19 1857.71,1404.19 1857.71,1404.19 1857.71,1404.19 1857.72,1404.18 1857.72,1404.18 1857.72,1404.18 1857.73,1404.18 1857.73,1404.18 1857.73,1404.18 1857.73,1404.18 1857.74,1404.18 1857.74,1404.18 1857.74,1404.18 1857.75,1404.18 1857.75,1404.18 1857.75,1404.18 1857.75,1404.18 1857.76,1404.18 1857.76,1404.18 1857.76,1404.18 1857.77,1404.18 1857.77,1404.18 1857.77,1404.18 1857.77,1404.18 1857.78,1404.18 1857.78,1404.18 1857.78,1404.18 1857.79,1404.18 1857.79,1404.18 1857.79,1404.18 1857.8,1404.18 1857.8,1404.18 1857.8,1404.18 1857.8,1404.18 1857.81,1404.18 1857.81,1404.18 1857.81,1404.18 1857.82,1404.18 1857.82,1404.18 1857.82,1404.18 1857.82,1404.18 1857.83,1404.18 1857.83,1404.18 1857.83,1404.18 1857.84,1404.18 1857.84,1404.18 1857.84,1404.18 1857.84,1404.18 1857.85,1404.18 1857.85,1404.18 1857.85,1404.18 1857.86,1404.18 1857.86,1404.18 1857.86,1404.18 1857.86,1404.18 1857.87,1404.18 1857.87,1404.18 1857.87,1404.18 1857.88,1404.18 1857.88,1404.18 1857.88,1404.18 1857.89,1404.18 1857.89,1404.18 1857.89,1404.18 1857.89,1404.18 1857.9,1404.18 1857.9,1404.18 1857.9,1404.18 1857.91,1404.18 1857.91,1404.18 1857.91,1404.18 1857.91,1404.18 1857.92,1404.18 1857.92,1404.18 1857.92,1404.18 1857.93,1404.18 1857.93,1404.18 1857.93,1404.18 1857.93,1404.18 1857.94,1404.18 1857.94,1404.18 1857.94,1404.18 1857.95,1404.18 1857.95,1404.18 1857.95,1404.18 1857.95,1404.18 1857.96,1404.18 1857.96,1404.18 1857.96,1404.18 1857.97,1404.18 1857.97,1404.18 1857.97,1404.18 1857.98,1404.18 1857.98,1404.18 1857.98,1404.18 1857.98,1404.18 1857.99,1404.18 1857.99,1404.18 1857.99,1404.18 1858,1404.18 1858,1404.18 1858,1404.18 1858,1404.18 1858.01,1404.18 1858.01,1404.18 1858.01,1404.18 1858.02,1404.18 1858.02,1404.18 1858.02,1404.18 1858.02,1404.18 1858.03,1404.18 1858.03,1404.18 1858.03,1404.18 1858.04,1404.18 1858.04,1404.18 1858.04,1404.18 1858.04,1404.18 1858.05,1404.18 1858.05,1404.18 1858.05,1404.18 1858.06,1404.18 1858.06,1404.18 1858.06,1404.18 1858.07,1404.18 1858.07,1404.18 1858.07,1404.18 1858.07,1404.18 1858.08,1404.18 1858.08,1404.18 1858.08,1404.18 1858.09,1404.18 1858.09,1404.18 1858.09,1404.18 1858.09,1404.18 1858.1,1404.18 1858.1,1404.18 1858.1,1404.18 1858.11,1404.17 1858.11,1404.17 1858.11,1404.17 1858.11,1404.17 1858.12,1404.17 1858.12,1404.17 1858.12,1404.17 1858.13,1404.17 1858.13,1404.17 1858.13,1404.17 1858.13,1404.17 1858.14,1404.17 1858.14,1404.17 1858.14,1404.17 1858.15,1404.17 1858.15,1404.17 1858.15,1404.17 1858.16,1404.17 1858.16,1404.17 1858.16,1404.17 1858.16,1404.17 1858.17,1404.17 1858.17,1404.17 1858.17,1404.17 1858.18,1404.17 1858.18,1404.17 1858.18,1404.17 1858.18,1404.17 1858.19,1404.17 1858.19,1404.17 1858.19,1404.17 1858.2,1404.17 1858.2,1404.17 1858.2,1404.17 1858.2,1404.17 1858.21,1404.17 1858.21,1404.17 1858.21,1404.17 1858.22,1404.17 1858.22,1404.17 1858.22,1404.17 1858.22,1404.17 1858.23,1404.17 1858.23,1404.17 1858.23,1404.17 1858.24,1404.17 1858.24,1404.17 1858.24,1404.17 1858.24,1404.17 1858.25,1404.17 1858.25,1404.17 1858.25,1404.17 1858.26,1404.17 1858.26,1404.17 1858.26,1404.17 1858.27,1404.17 1858.27,1404.17 1858.27,1404.17 1858.27,1404.17 1858.28,1404.17 1858.28,1404.17 1858.28,1404.17 1858.29,1404.17 1858.29,1404.17 1858.29,1404.17 1858.29,1404.17 1858.3,1404.17 1858.3,1404.17 1858.3,1404.17 1858.31,1404.17 1858.31,1404.17 1858.31,1404.17 1858.31,1404.17 1858.32,1404.17 1858.32,1404.17 1858.32,1404.17 1858.33,1404.17 1858.33,1404.17 1858.33,1404.17 1858.33,1404.17 1858.34,1404.17 1858.34,1404.17 1858.34,1404.17 1858.35,1404.17 1858.35,1404.17 1858.35,1404.17 1858.35,1404.17 1858.36,1404.17 1858.36,1404.17 1858.36,1404.17 1858.37,1404.17 1858.37,1404.17 1858.37,1404.17 1858.38,1404.17 1858.38,1404.17 1858.38,1404.17 1858.38,1404.17 1858.39,1404.17 1858.39,1404.17 1858.39,1404.17 1858.4,1404.17 1858.4,1404.17 1858.4,1404.17 1858.4,1404.17 1858.41,1404.17 1858.41,1404.17 1858.41,1404.17 1858.42,1404.17 1858.42,1404.17 1858.42,1404.17 1858.42,1404.17 1858.43,1404.17 1858.43,1404.17 1858.43,1404.17 1858.44,1404.17 1858.44,1404.17 1858.44,1404.17 1858.44,1404.17 1858.45,1404.17 1858.45,1404.17 1858.45,1404.17 1858.46,1404.17 1858.46,1404.17 1858.46,1404.17 1858.46,1404.17 1858.47,1404.17 1858.47,1404.17 1858.47,1404.17 1858.48,1404.17 1858.48,1404.17 1858.48,1404.17 1858.49,1404.17 1858.49,1404.17 1858.49,1404.17 1858.49,1404.17 1858.5,1404.16 1858.5,1404.16 1858.5,1404.16 1858.51,1404.16 1858.51,1404.16 1858.51,1404.16 1858.51,1404.16 1858.52,1404.16 1858.52,1404.16 1858.52,1404.16 1858.53,1404.16 1858.53,1404.16 1858.53,1404.16 1858.53,1404.16 1858.54,1404.16 1858.54,1404.16 1858.54,1404.16 1858.55,1404.16 1858.55,1404.16 1858.55,1404.16 1858.55,1404.16 1858.56,1404.16 1858.56,1404.16 1858.56,1404.16 1858.57,1404.16 1858.57,1404.16 1858.57,1404.16 1858.57,1404.16 1858.58,1404.16 1858.58,1404.16 1858.58,1404.16 1858.59,1404.16 1858.59,1404.16 1858.59,1404.16 1858.59,1404.16 1858.6,1404.16 1858.6,1404.16 1858.6,1404.16 1858.61,1404.16 1858.61,1404.16 1858.61,1404.16 1858.62,1404.16 1858.62,1404.16 1858.62,1404.16 1858.62,1404.16 1858.63,1404.16 1858.63,1404.16 1858.63,1404.16 1858.64,1404.16 1858.64,1404.16 1858.64,1404.16 1858.64,1404.16 1858.65,1404.16 1858.65,1404.16 1858.65,1404.16 1858.66,1404.16 1858.66,1404.16 1858.66,1404.16 1858.66,1404.16 1858.67,1404.16 1858.67,1404.16 1858.67,1404.16 1858.68,1404.16 1858.68,1404.16 1858.68,1404.16 1858.68,1404.16 1858.69,1404.16 1858.69,1404.16 1858.69,1404.16 1858.7,1404.16 1858.7,1404.16 1858.7,1404.16 1858.7,1404.16 1858.71,1404.16 1858.71,1404.16 1858.71,1404.16 1858.72,1404.16 1858.72,1404.16 1858.72,1404.16 1858.72,1404.16 1858.73,1404.16 1858.73,1404.16 1858.73,1404.16 1858.74,1404.16 1858.74,1404.16 1858.74,1404.16 1858.75,1404.16 1858.75,1404.16 1858.75,1404.16 1858.75,1404.16 1858.76,1404.16 1858.76,1404.16 1858.76,1404.16 1858.77,1404.16 1858.77,1404.16 1858.77,1404.16 1858.77,1404.16 1858.78,1404.16 1858.78,1404.16 1858.78,1404.16 1858.79,1404.16 1858.79,1404.16 1858.79,1404.16 1858.79,1404.16 1858.8,1404.16 1858.8,1404.16 1858.8,1404.16 1858.81,1404.16 1858.81,1404.16 1858.81,1404.16 1858.81,1404.16 1858.82,1404.16 1858.82,1404.16 1858.82,1404.16 1858.83,1404.16 1858.83,1404.16 1858.83,1404.16 1858.83,1404.16 1858.84,1404.16 1858.84,1404.16 1858.84,1404.16 1858.85,1404.16 1858.85,1404.16 1858.85,1404.16 1858.85,1404.16 1858.86,1404.16 1858.86,1404.16 1858.86,1404.16 1858.87,1404.16 1858.87,1404.16 1858.87,1404.16 1858.87,1404.16 1858.88,1404.16 1858.88,1404.16 1858.88,1404.16 1858.89,1404.15 1858.89,1404.15 1858.89,1404.15 1858.9,1404.15 1858.9,1404.15 1858.9,1404.15 1858.9,1404.15 1858.91,1404.15 1858.91,1404.15 1858.91,1404.15 1858.92,1404.15 1858.92,1404.15 1858.92,1404.15 1858.92,1404.15 1858.93,1404.15 1858.93,1404.15 1858.93,1404.15 1858.94,1404.15 1858.94,1404.15 1858.94,1404.15 1858.94,1404.15 1858.95,1404.15 1858.95,1404.15 1858.95,1404.15 1858.96,1404.15 1858.96,1404.15 1858.96,1404.15 1858.96,1404.15 1858.97,1404.15 1858.97,1404.15 1858.97,1404.15 1858.98,1404.15 1858.98,1404.15 1858.98,1404.15 1858.98,1404.15 1858.99,1404.15 1858.99,1404.15 1858.99,1404.15 1859,1404.15 1859,1404.15 1859,1404.15 1859,1404.15 1859.01,1404.15 1859.01,1404.15 1859.01,1404.15 1859.02,1404.15 1859.02,1404.15 1859.02,1404.15 1859.02,1404.15 1859.03,1404.15 1859.03,1404.15 1859.03,1404.15 1859.04,1404.15 1859.04,1404.15 1859.04,1404.15 1859.04,1404.15 1859.05,1404.15 1859.05,1404.15 1859.05,1404.15 1859.06,1404.15 1859.06,1404.15 1859.06,1404.15 1859.07,1404.15 1859.07,1404.15 1859.07,1404.15 1859.07,1404.15 1859.08,1404.15 1859.08,1404.15 1859.08,1404.15 1859.09,1404.15 1859.09,1404.15 1859.09,1404.15 1859.09,1404.15 1859.1,1404.15 1859.1,1404.15 1859.1,1404.15 1859.11,1404.15 1859.11,1404.15 1859.11,1404.15 1859.11,1404.15 1859.12,1404.15 1859.12,1404.15 1859.12,1404.15 1859.13,1404.15 1859.13,1404.15 1859.13,1404.15 1859.13,1404.15 1859.14,1404.15 1859.14,1404.15 1859.14,1404.15 1859.15,1404.15 1859.15,1404.15 1859.15,1404.15 1859.15,1404.15 1859.16,1404.15 1859.16,1404.15 1859.16,1404.15 1859.17,1404.15 1859.17,1404.15 1859.17,1404.15 1859.17,1404.15 1859.18,1404.15 1859.18,1404.15 1859.18,1404.15 1859.19,1404.15 1859.19,1404.15 1859.19,1404.15 1859.19,1404.15 1859.2,1404.15 1859.2,1404.15 1859.2,1404.15 1859.21,1404.15 1859.21,1404.15 1859.21,1404.15 1859.21,1404.15 1859.22,1404.15 1859.22,1404.15 1859.22,1404.15 1859.23,1404.15 1859.23,1404.15 1859.23,1404.15 1859.23,1404.15 1859.24,1404.15 1859.24,1404.15 1859.24,1404.15 1859.25,1404.15 1859.25,1404.15 1859.25,1404.15 1859.25,1404.15 1859.26,1404.15 1859.26,1404.15 1859.26,1404.15 1859.27,1404.15 1859.27,1404.15 1859.27,1404.15 1859.27,1404.14 1859.28,1404.14 1859.28,1404.14 1859.28,1404.14 1859.29,1404.14 1859.29,1404.14 1859.29,1404.14 1859.3,1404.14 1859.3,1404.14 1859.3,1404.14 1859.3,1404.14 1859.31,1404.14 1859.31,1404.14 1859.31,1404.14 1859.32,1404.14 1859.32,1404.14 1859.32,1404.14 1859.32,1404.14 1859.33,1404.14 1859.33,1404.14 1859.33,1404.14 1859.34,1404.14 1859.34,1404.14 1859.34,1404.14 1859.34,1404.14 1859.35,1404.14 1859.35,1404.14 1859.35,1404.14 1859.36,1404.14 1859.36,1404.14 1859.36,1404.14 1859.36,1404.14 1859.37,1404.14 1859.37,1404.14 1859.37,1404.14 1859.38,1404.14 1859.38,1404.14 1859.38,1404.14 1859.38,1404.14 1859.39,1404.14 1859.39,1404.14 1859.39,1404.14 1859.4,1404.14 1859.4,1404.14 1859.4,1404.14 1859.4,1404.14 1859.41,1404.14 1859.41,1404.14 1859.41,1404.14 1859.42,1404.14 1859.42,1404.14 1859.42,1404.14 1859.42,1404.14 1859.43,1404.14 1859.43,1404.14 1859.43,1404.14 1859.44,1404.14 1859.44,1404.14 1859.44,1404.14 1859.44,1404.14 1859.45,1404.14 1859.45,1404.14 1859.45,1404.14 1859.46,1404.14 1859.46,1404.14 1859.46,1404.14 1859.46,1404.14 1859.47,1404.14 1859.47,1404.14 1859.47,1404.14 1859.48,1404.14 1859.48,1404.14 1859.48,1404.14 1859.48,1404.14 1859.49,1404.14 1859.49,1404.14 1859.49,1404.14 1859.5,1404.14 1859.5,1404.14 1859.5,1404.14 1859.5,1404.14 1859.51,1404.14 1859.51,1404.14 1859.51,1404.14 1859.52,1404.14 1859.52,1404.14 1859.52,1404.14 1859.52,1404.14 1859.53,1404.14 1859.53,1404.14 1859.53,1404.14 1859.54,1404.14 1859.54,1404.14 1859.54,1404.14 1859.54,1404.14 1859.55,1404.14 1859.55,1404.14 1859.55,1404.14 1859.56,1404.14 1859.56,1404.14 1859.56,1404.14 1859.56,1404.14 1859.57,1404.14 1859.57,1404.14 1859.57,1404.14 1859.58,1404.14 1859.58,1404.14 1859.58,1404.14 1859.58,1404.14 1859.59,1404.14 1859.59,1404.14 1859.59,1404.14 1859.6,1404.14 1859.6,1404.14 1859.6,1404.14 1859.61,1404.14 1859.61,1404.14 1859.61,1404.14 1859.61,1404.14 1859.62,1404.14 1859.62,1404.14 1859.62,1404.14 1859.63,1404.14 1859.63,1404.14 1859.63,1404.14 1859.63,1404.14 1859.64,1404.14 1859.64,1404.14 1859.64,1404.14 1859.65,1404.14 1859.65,1404.14 1859.65,1404.14 1859.65,1404.14 1859.66,1404.14 1859.66,1404.14 1859.66,1404.14 1859.67,1404.13 1859.67,1404.13 1859.67,1404.13 1859.67,1404.13 1859.68,1404.13 1859.68,1404.13 1859.68,1404.13 1859.69,1404.13 1859.69,1404.13 1859.69,1404.13 1859.69,1404.13 1859.7,1404.13 1859.7,1404.13 1859.7,1404.13 1859.71,1404.13 1859.71,1404.13 1859.71,1404.13 1859.71,1404.13 1859.72,1404.13 1859.72,1404.13 1859.72,1404.13 1859.73,1404.13 1859.73,1404.13 1859.73,1404.13 1859.73,1404.13 1859.74,1404.13 1859.74,1404.13 1859.74,1404.13 1859.75,1404.13 1859.75,1404.13 1859.75,1404.13 1859.75,1404.13 1859.76,1404.13 1859.76,1404.13 1859.76,1404.13 1859.77,1404.13 1859.77,1404.13 1859.77,1404.13 1859.77,1404.13 1859.78,1404.13 1859.78,1404.13 1859.78,1404.13 1859.79,1404.13 1859.79,1404.13 1859.79,1404.13 1859.79,1404.13 1859.8,1404.13 1859.8,1404.13 1859.8,1404.13 1859.81,1404.13 1859.81,1404.13 1859.81,1404.13 1859.81,1404.13 1859.82,1404.13 1859.82,1404.13 1859.82,1404.13 1859.83,1404.13 1859.83,1404.13 1859.83,1404.13 1859.83,1404.13 1859.84,1404.13 1859.84,1404.13 1859.84,1404.13 1859.85,1404.13 1859.85,1404.13 1859.85,1404.13 1859.85,1404.13 1859.86,1404.13 1859.86,1404.13 1859.86,1404.13 1859.87,1404.13 1859.87,1404.13 1859.87,1404.13 1859.87,1404.13 1859.88,1404.13 1859.88,1404.13 1859.88,1404.13 1859.89,1404.13 1859.89,1404.13 1859.89,1404.13 1859.89,1404.13 1859.9,1404.13 1859.9,1404.13 1859.9,1404.13 1859.91,1404.13 1859.91,1404.13 1859.91,1404.13 1859.91,1404.13 1859.92,1404.13 1859.92,1404.13 1859.92,1404.13 1859.93,1404.13 1859.93,1404.13 1859.93,1404.13 1859.93,1404.13 1859.94,1404.13 1859.94,1404.13 1859.94,1404.13 1859.95,1404.13 1859.95,1404.13 1859.95,1404.13 1859.95,1404.13 1859.96,1404.13 1859.96,1404.13 1859.96,1404.13 1859.97,1404.13 1859.97,1404.13 1859.97,1404.13 1859.97,1404.13 1859.98,1404.13 1859.98,1404.13 1859.98,1404.13 1859.99,1404.13 1859.99,1404.13 1859.99,1404.13 1859.99,1404.13 1860,1404.13 1860,1404.13 1860,1404.13 1860.01,1404.13 1860.01,1404.13 1860.01,1404.13 1860.01,1404.13 1860.02,1404.13 1860.02,1404.13 1860.02,1404.13 1860.03,1404.13 1860.03,1404.13 1860.03,1404.13 1860.03,1404.13 1860.04,1404.13 1860.04,1404.13 1860.04,1404.13 1860.05,1404.13 1860.05,1404.13 1860.05,1404.13 1860.05,1404.12 1860.06,1404.12 1860.06,1404.12 1860.06,1404.12 1860.07,1404.12 1860.07,1404.12 1860.07,1404.12 1860.07,1404.12 1860.08,1404.12 1860.08,1404.12 1860.08,1404.12 1860.09,1404.12 1860.09,1404.12 1860.09,1404.12 1860.09,1404.12 1860.1,1404.12 1860.1,1404.12 1860.1,1404.12 1860.11,1404.12 1860.11,1404.12 1860.11,1404.12 1860.11,1404.12 1860.12,1404.12 1860.12,1404.12 1860.12,1404.12 1860.13,1404.12 1860.13,1404.12 1860.13,1404.12 1860.13,1404.12 1860.14,1404.12 1860.14,1404.12 1860.14,1404.12 1860.15,1404.12 1860.15,1404.12 1860.15,1404.12 1860.15,1404.12 1860.16,1404.12 1860.16,1404.12 1860.16,1404.12 1860.17,1404.12 1860.17,1404.12 1860.17,1404.12 1860.17,1404.12 1860.18,1404.12 1860.18,1404.12 1860.18,1404.12 1860.19,1404.12 1860.19,1404.12 1860.19,1404.12 1860.19,1404.12 1860.2,1404.12 1860.2,1404.12 1860.2,1404.12 1860.21,1404.12 1860.21,1404.12 1860.21,1404.12 1860.21,1404.12 1860.22,1404.12 1860.22,1404.12 1860.22,1404.12 1860.23,1404.12 1860.23,1404.12 1860.23,1404.12 1860.23,1404.12 1860.24,1404.12 1860.24,1404.12 1860.24,1404.12 1860.25,1404.12 1860.25,1404.12 1860.25,1404.12 1860.25,1404.12 1860.26,1404.12 1860.26,1404.12 1860.26,1404.12 1860.27,1404.12 1860.27,1404.12 1860.27,1404.12 1860.27,1404.12 1860.28,1404.12 1860.28,1404.12 1860.28,1404.12 1860.29,1404.12 1860.29,1404.12 1860.29,1404.12 1860.29,1404.12 1860.3,1404.12 1860.3,1404.12 1860.3,1404.12 1860.31,1404.12 1860.31,1404.12 1860.31,1404.12 1860.31,1404.12 1860.32,1404.12 1860.32,1404.12 1860.32,1404.12 1860.33,1404.12 1860.33,1404.12 1860.33,1404.12 1860.33,1404.12 1860.34,1404.12 1860.34,1404.12 1860.34,1404.12 1860.35,1404.12 1860.35,1404.12 1860.35,1404.12 1860.35,1404.12 1860.36,1404.12 1860.36,1404.12 1860.36,1404.12 1860.37,1404.12 1860.37,1404.12 1860.37,1404.12 1860.37,1404.12 1860.38,1404.12 1860.38,1404.12 1860.38,1404.12 1860.39,1404.12 1860.39,1404.12 1860.39,1404.12 1860.39,1404.12 1860.4,1404.12 1860.4,1404.12 1860.4,1404.12 1860.41,1404.12 1860.41,1404.12 1860.41,1404.12 1860.41,1404.12 1860.42,1404.12 1860.42,1404.12 1860.42,1404.12 1860.43,1404.12 1860.43,1404.12 1860.43,1404.12 1860.43,1404.12 1860.44,1404.12 1860.44,1404.12 1860.44,1404.11 1860.45,1404.11 1860.45,1404.11 1860.45,1404.11 1860.45,1404.11 1860.46,1404.11 1860.46,1404.11 1860.46,1404.11 1860.47,1404.11 1860.47,1404.11 1860.47,1404.11 1860.47,1404.11 1860.48,1404.11 1860.48,1404.11 1860.48,1404.11 1860.49,1404.11 1860.49,1404.11 1860.49,1404.11 1860.49,1404.11 1860.5,1404.11 1860.5,1404.11 1860.5,1404.11 1860.5,1404.11 1860.51,1404.11 1860.51,1404.11 1860.51,1404.11 1860.52,1404.11 1860.52,1404.11 1860.52,1404.11 1860.52,1404.11 1860.53,1404.11 1860.53,1404.11 1860.53,1404.11 1860.54,1404.11 1860.54,1404.11 1860.54,1404.11 1860.54,1404.11 1860.55,1404.11 1860.55,1404.11 1860.55,1404.11 1860.56,1404.11 1860.56,1404.11 1860.56,1404.11 1860.56,1404.11 1860.57,1404.11 1860.57,1404.11 1860.57,1404.11 1860.58,1404.11 1860.58,1404.11 1860.58,1404.11 1860.58,1404.11 1860.59,1404.11 1860.59,1404.11 1860.59,1404.11 1860.6,1404.11 1860.6,1404.11 1860.6,1404.11 1860.6,1404.11 1860.61,1404.11 1860.61,1404.11 1860.61,1404.11 1860.62,1404.11 1860.62,1404.11 1860.62,1404.11 1860.62,1404.11 1860.63,1404.11 1860.63,1404.11 1860.63,1404.11 1860.64,1404.11 1860.64,1404.11 1860.64,1404.11 1860.64,1404.11 1860.65,1404.11 1860.65,1404.11 1860.65,1404.11 1860.66,1404.11 1860.66,1404.11 1860.66,1404.11 1860.66,1404.11 1860.67,1404.11 1860.67,1404.11 1860.67,1404.11 1860.68,1404.11 1860.68,1404.11 1860.68,1404.11 1860.68,1404.11 1860.69,1404.11 1860.69,1404.11 1860.69,1404.11 1860.7,1404.11 1860.7,1404.11 1860.7,1404.11 1860.7,1404.11 1860.71,1404.11 1860.71,1404.11 1860.71,1404.11 1860.72,1404.11 1860.72,1404.11 1860.72,1404.11 1860.72,1404.11 1860.73,1404.11 1860.73,1404.11 1860.73,1404.11 1860.74,1404.11 1860.74,1404.11 1860.74,1404.11 1860.74,1404.11 1860.75,1404.11 1860.75,1404.11 1860.75,1404.11 1860.76,1404.11 1860.76,1404.11 1860.76,1404.11 1860.76,1404.11 1860.77,1404.11 1860.77,1404.11 1860.77,1404.11 1860.78,1404.11 1860.78,1404.11 1860.78,1404.11 1860.78,1404.11 1860.79,1404.11 1860.79,1404.11 1860.79,1404.11 1860.8,1404.11 1860.8,1404.11 1860.8,1404.11 1860.8,1404.11 1860.81,1404.11 1860.81,1404.11 1860.81,1404.11 1860.81,1404.11 1860.82,1404.11 1860.82,1404.11 1860.82,1404.11 1860.83,1404.11 1860.83,1404.11 1860.83,1404.1 1860.83,1404.1 1860.84,1404.1 1860.84,1404.1 1860.84,1404.1 1860.85,1404.1 1860.85,1404.1 1860.85,1404.1 1860.85,1404.1 1860.86,1404.1 1860.86,1404.1 1860.86,1404.1 1860.87,1404.1 1860.87,1404.1 1860.87,1404.1 1860.87,1404.1 1860.88,1404.1 1860.88,1404.1 1860.88,1404.1 1860.89,1404.1 1860.89,1404.1 1860.89,1404.1 1860.89,1404.1 1860.9,1404.1 1860.9,1404.1 1860.9,1404.1 1860.91,1404.1 1860.91,1404.1 1860.91,1404.1 1860.91,1404.1 1860.92,1404.1 1860.92,1404.1 1860.92,1404.1 1860.93,1404.1 1860.93,1404.1 1860.93,1404.1 1860.93,1404.1 1860.94,1404.1 1860.94,1404.1 1860.94,1404.1 1860.95,1404.1 1860.95,1404.1 1860.95,1404.1 1860.95,1404.1 1860.96,1404.1 1860.96,1404.1 1860.96,1404.1 1860.97,1404.1 1860.97,1404.1 1860.97,1404.1 1860.97,1404.1 1860.98,1404.1 1860.98,1404.1 1860.98,1404.1 1860.99,1404.1 1860.99,1404.1 1860.99,1404.1 1860.99,1404.1 1861,1404.1 1861,1404.1 1861,1404.1 1861.01,1404.1 1861.01,1404.1 1861.01,1404.1 1861.01,1404.1 1861.02,1404.1 1861.02,1404.1 1861.02,1404.1 1861.03,1404.1 1861.03,1404.1 1861.03,1404.1 1861.03,1404.1 1861.04,1404.1 1861.04,1404.1 1861.04,1404.1 1861.04,1404.1 1861.05,1404.1 1861.05,1404.1 1861.05,1404.1 1861.06,1404.1 1861.06,1404.1 1861.06,1404.1 1861.06,1404.1 1861.07,1404.1 1861.07,1404.1 1861.07,1404.1 1861.08,1404.1 1861.08,1404.1 1861.08,1404.1 1861.08,1404.1 1861.09,1404.1 1861.09,1404.1 1861.09,1404.1 1861.1,1404.1 1861.1,1404.1 1861.1,1404.1 1861.1,1404.1 1861.11,1404.1 1861.11,1404.1 1861.11,1404.1 1861.12,1404.1 1861.12,1404.1 1861.12,1404.1 1861.12,1404.1 1861.13,1404.1 1861.13,1404.1 1861.13,1404.1 1861.14,1404.1 1861.14,1404.1 1861.14,1404.1 1861.14,1404.1 1861.15,1404.1 1861.15,1404.1 1861.15,1404.1 1861.16,1404.1 1861.16,1404.1 1861.16,1404.1 1861.16,1404.1 1861.17,1404.1 1861.17,1404.1 1861.17,1404.1 1861.18,1404.1 1861.18,1404.1 1861.18,1404.1 1861.18,1404.1 1861.19,1404.1 1861.19,1404.1 1861.19,1404.1 1861.2,1404.1 1861.2,1404.1 1861.2,1404.1 1861.2,1404.1 1861.21,1404.1 1861.21,1404.1 1861.21,1404.1 1861.21,1404.1 1861.22,1404.1 1861.22,1404.09 1861.22,1404.09 1861.23,1404.09 1861.23,1404.09 1861.23,1404.09 1861.23,1404.09 1861.24,1404.09 1861.24,1404.09 1861.24,1404.09 1861.25,1404.09 1861.25,1404.09 1861.25,1404.09 1861.25,1404.09 1861.26,1404.09 1861.26,1404.09 1861.26,1404.09 1861.27,1404.09 1861.27,1404.09 1861.27,1404.09 1861.27,1404.09 1861.28,1404.09 1861.28,1404.09 1861.28,1404.09 1861.29,1404.09 1861.29,1404.09 1861.29,1404.09 1861.29,1404.09 1861.3,1404.09 1861.3,1404.09 1861.3,1404.09 1861.31,1404.09 1861.31,1404.09 1861.31,1404.09 1861.31,1404.09 1861.32,1404.09 1861.32,1404.09 1861.32,1404.09 1861.33,1404.09 1861.33,1404.09 1861.33,1404.09 1861.33,1404.09 1861.34,1404.09 1861.34,1404.09 1861.34,1404.09 1861.35,1404.09 1861.35,1404.09 1861.35,1404.09 1861.35,1404.09 1861.36,1404.09 1861.36,1404.09 1861.36,1404.09 1861.36,1404.09 1861.37,1404.09 1861.37,1404.09 1861.37,1404.09 1861.38,1404.09 1861.38,1404.09 1861.38,1404.09 1861.38,1404.09 1861.39,1404.09 1861.39,1404.09 1861.39,1404.09 1861.4,1404.09 1861.4,1404.09 1861.4,1404.09 1861.4,1404.09 1861.41,1404.09 1861.41,1404.09 1861.41,1404.09 1861.42,1404.09 1861.42,1404.09 1861.42,1404.09 1861.42,1404.09 1861.43,1404.09 1861.43,1404.09 1861.43,1404.09 1861.44,1404.09 1861.44,1404.09 1861.44,1404.09 1861.44,1404.09 1861.45,1404.09 1861.45,1404.09 1861.45,1404.09 1861.46,1404.09 1861.46,1404.09 1861.46,1404.09 1861.46,1404.09 1861.47,1404.09 1861.47,1404.09 1861.47,1404.09 1861.48,1404.09 1861.48,1404.09 1861.48,1404.09 1861.48,1404.09 1861.49,1404.09 1861.49,1404.09 1861.49,1404.09 1861.5,1404.09 1861.5,1404.09 1861.5,1404.09 1861.5,1404.09 1861.51,1404.09 1861.51,1404.09 1861.51,1404.09 1861.51,1404.09 1861.52,1404.09 1861.52,1404.09 1861.52,1404.09 1861.53,1404.09 1861.53,1404.09 1861.53,1404.09 1861.53,1404.09 1861.54,1404.09 1861.54,1404.09 1861.54,1404.09 1861.55,1404.09 1861.55,1404.09 1861.55,1404.09 1861.55,1404.09 1861.56,1404.09 1861.56,1404.09 1861.56,1404.09 1861.57,1404.09 1861.57,1404.09 1861.57,1404.09 1861.57,1404.09 1861.58,1404.09 1861.58,1404.09 1861.58,1404.09 1861.59,1404.09 1861.59,1404.09 1861.59,1404.09 1861.59,1404.09 1861.6,1404.09 1861.6,1404.09 1861.6,1404.09 1861.61,1404.09 1861.61,1404.09 1861.61,1404.08 1861.61,1404.08 1861.62,1404.08 1861.62,1404.08 1861.62,1404.08 1861.62,1404.08 1861.63,1404.08 1861.63,1404.08 1861.63,1404.08 1861.64,1404.08 1861.64,1404.08 1861.64,1404.08 1861.64,1404.08 1861.65,1404.08 1861.65,1404.08 1861.65,1404.08 1861.66,1404.08 1861.66,1404.08 1861.66,1404.08 1861.66,1404.08 1861.67,1404.08 1861.67,1404.08 1861.67,1404.08 1861.68,1404.08 1861.68,1404.08 1861.68,1404.08 1861.68,1404.08 1861.69,1404.08 1861.69,1404.08 1861.69,1404.08 1861.7,1404.08 1861.7,1404.08 1861.7,1404.08 1861.7,1404.08 1861.71,1404.08 1861.71,1404.08 1861.71,1404.08 1861.72,1404.08 1861.72,1404.08 1861.72,1404.08 1861.72,1404.08 1861.73,1404.08 1861.73,1404.08 1861.73,1404.08 1861.74,1404.08 1861.74,1404.08 1861.74,1404.08 1861.74,1404.08 1861.75,1404.08 1861.75,1404.08 1861.75,1404.08 1861.75,1404.08 1861.76,1404.08 1861.76,1404.08 1861.76,1404.08 1861.77,1404.08 1861.77,1404.08 1861.77,1404.08 1861.77,1404.08 1861.78,1404.08 1861.78,1404.08 1861.78,1404.08 1861.79,1404.08 1861.79,1404.08 1861.79,1404.08 1861.79,1404.08 1861.8,1404.08 1861.8,1404.08 1861.8,1404.08 1861.81,1404.08 1861.81,1404.08 1861.81,1404.08 1861.81,1404.08 1861.82,1404.08 1861.82,1404.08 1861.82,1404.08 1861.83,1404.08 1861.83,1404.08 1861.83,1404.08 1861.83,1404.08 1861.84,1404.08 1861.84,1404.08 1861.84,1404.08 1861.85,1404.08 1861.85,1404.08 1861.85,1404.08 1861.85,1404.08 1861.86,1404.08 1861.86,1404.08 1861.86,1404.08 1861.86,1404.08 1861.87,1404.08 1861.87,1404.08 1861.87,1404.08 1861.88,1404.08 1861.88,1404.08 1861.88,1404.08 1861.88,1404.08 1861.89,1404.08 1861.89,1404.08 1861.89,1404.08 1861.9,1404.08 1861.9,1404.08 1861.9,1404.08 1861.9,1404.08 1861.91,1404.08 1861.91,1404.08 1861.91,1404.08 1861.92,1404.08 1861.92,1404.08 1861.92,1404.08 1861.92,1404.08 1861.93,1404.08 1861.93,1404.08 1861.93,1404.08 1861.94,1404.08 1861.94,1404.08 1861.94,1404.08 1861.94,1404.08 1861.95,1404.08 1861.95,1404.08 1861.95,1404.08 1861.95,1404.08 1861.96,1404.08 1861.96,1404.08 1861.96,1404.08 1861.97,1404.08 1861.97,1404.08 1861.97,1404.08 1861.97,1404.08 1861.98,1404.08 1861.98,1404.08 1861.98,1404.08 1861.99,1404.08 1861.99,1404.08 1861.99,1404.08 1861.99,1404.08 1862,1404.08 1862,1404.07 1862,1404.07 1862.01,1404.07 1862.01,1404.07 1862.01,1404.07 1862.01,1404.07 1862.02,1404.07 1862.02,1404.07 1862.02,1404.07 1862.03,1404.07 1862.03,1404.07 1862.03,1404.07 1862.03,1404.07 1862.04,1404.07 1862.04,1404.07 1862.04,1404.07 1862.05,1404.07 1862.05,1404.07 1862.05,1404.07 1862.05,1404.07 1862.06,1404.07 1862.06,1404.07 1862.06,1404.07 1862.06,1404.07 1862.07,1404.07 1862.07,1404.07 1862.07,1404.07 1862.08,1404.07 1862.08,1404.07 1862.08,1404.07 1862.08,1404.07 1862.09,1404.07 1862.09,1404.07 1862.09,1404.07 1862.1,1404.07 1862.1,1404.07 1862.1,1404.07 1862.1,1404.07 1862.11,1404.07 1862.11,1404.07 1862.11,1404.07 1862.12,1404.07 1862.12,1404.07 1862.12,1404.07 1862.12,1404.07 1862.13,1404.07 1862.13,1404.07 1862.13,1404.07 1862.14,1404.07 1862.14,1404.07 1862.14,1404.07 1862.14,1404.07 1862.15,1404.07 1862.15,1404.07 1862.15,1404.07 1862.15,1404.07 1862.16,1404.07 1862.16,1404.07 1862.16,1404.07 1862.17,1404.07 1862.17,1404.07 1862.17,1404.07 1862.17,1404.07 1862.18,1404.07 1862.18,1404.07 1862.18,1404.07 1862.19,1404.07 1862.19,1404.07 1862.19,1404.07 1862.19,1404.07 1862.2,1404.07 1862.2,1404.07 1862.2,1404.07 1862.21,1404.07 1862.21,1404.07 1862.21,1404.07 1862.21,1404.07 1862.22,1404.07 1862.22,1404.07 1862.22,1404.07 1862.23,1404.07 1862.23,1404.07 1862.23,1404.07 1862.23,1404.07 1862.24,1404.07 1862.24,1404.07 1862.24,1404.07 1862.24,1404.07 1862.25,1404.07 1862.25,1404.07 1862.25,1404.07 1862.26,1404.07 1862.26,1404.07 1862.26,1404.07 1862.26,1404.07 1862.27,1404.07 1862.27,1404.07 1862.27,1404.07 1862.28,1404.07 1862.28,1404.07 1862.28,1404.07 1862.28,1404.07 1862.29,1404.07 1862.29,1404.07 1862.29,1404.07 1862.3,1404.07 1862.3,1404.07 1862.3,1404.07 1862.3,1404.07 1862.31,1404.07 1862.31,1404.07 1862.31,1404.07 1862.32,1404.07 1862.32,1404.07 1862.32,1404.07 1862.32,1404.07 1862.33,1404.07 1862.33,1404.07 1862.33,1404.07 1862.33,1404.07 1862.34,1404.07 1862.34,1404.07 1862.34,1404.07 1862.35,1404.07 1862.35,1404.07 1862.35,1404.07 1862.35,1404.07 1862.36,1404.07 1862.36,1404.07 1862.36,1404.07 1862.37,1404.07 1862.37,1404.07 1862.37,1404.07 1862.37,1404.07 1862.38,1404.07 1862.38,1404.07 1862.38,1404.07 1862.39,1404.07 1862.39,1404.06 1862.39,1404.06 1862.39,1404.06 1862.4,1404.06 1862.4,1404.06 1862.4,1404.06 1862.41,1404.06 1862.41,1404.06 1862.41,1404.06 1862.41,1404.06 1862.42,1404.06 1862.42,1404.06 1862.42,1404.06 1862.42,1404.06 1862.43,1404.06 1862.43,1404.06 1862.43,1404.06 1862.44,1404.06 1862.44,1404.06 1862.44,1404.06 1862.44,1404.06 1862.45,1404.06 1862.45,1404.06 1862.45,1404.06 1862.46,1404.06 1862.46,1404.06 1862.46,1404.06 1862.46,1404.06 1862.47,1404.06 1862.47,1404.06 1862.47,1404.06 1862.48,1404.06 1862.48,1404.06 1862.48,1404.06 1862.48,1404.06 1862.49,1404.06 1862.49,1404.06 1862.49,1404.06 1862.49,1404.06 1862.5,1404.06 1862.5,1404.06 1862.5,1404.06 1862.51,1404.06 1862.51,1404.06 1862.51,1404.06 1862.51,1404.06 1862.52,1404.06 1862.52,1404.06 1862.52,1404.06 1862.53,1404.06 1862.53,1404.06 1862.53,1404.06 1862.53,1404.06 1862.54,1404.06 1862.54,1404.06 1862.54,1404.06 1862.55,1404.06 1862.55,1404.06 1862.55,1404.06 1862.55,1404.06 1862.56,1404.06 1862.56,1404.06 1862.56,1404.06 1862.56,1404.06 1862.57,1404.06 1862.57,1404.06 1862.57,1404.06 1862.58,1404.06 1862.58,1404.06 1862.58,1404.06 1862.58,1404.06 1862.59,1404.06 1862.59,1404.06 1862.59,1404.06 1862.6,1404.06 1862.6,1404.06 1862.6,1404.06 1862.6,1404.06 1862.61,1404.06 1862.61,1404.06 1862.61,1404.06 1862.62,1404.06 1862.62,1404.06 1862.62,1404.06 1862.62,1404.06 1862.63,1404.06 1862.63,1404.06 1862.63,1404.06 1862.64,1404.06 1862.64,1404.06 1862.64,1404.06 1862.64,1404.06 1862.65,1404.06 1862.65,1404.06 1862.65,1404.06 1862.65,1404.06 1862.66,1404.06 1862.66,1404.06 1862.66,1404.06 1862.67,1404.06 1862.67,1404.06 1862.67,1404.06 1862.67,1404.06 1862.68,1404.06 1862.68,1404.06 1862.68,1404.06 1862.69,1404.06 1862.69,1404.06 1862.69,1404.06 1862.69,1404.06 1862.7,1404.06 1862.7,1404.06 1862.7,1404.06 1862.71,1404.06 1862.71,1404.06 1862.71,1404.06 1862.71,1404.06 1862.72,1404.06 1862.72,1404.06 1862.72,1404.06 1862.72,1404.06 1862.73,1404.06 1862.73,1404.06 1862.73,1404.06 1862.74,1404.06 1862.74,1404.06 1862.74,1404.06 1862.74,1404.06 1862.75,1404.06 1862.75,1404.06 1862.75,1404.06 1862.76,1404.06 1862.76,1404.06 1862.76,1404.06 1862.76,1404.06 1862.77,1404.06 1862.77,1404.06 1862.77,1404.06 1862.78,1404.06 1862.78,1404.05 1862.78,1404.05 1862.78,1404.05 1862.79,1404.05 1862.79,1404.05 1862.79,1404.05 1862.79,1404.05 1862.8,1404.05 1862.8,1404.05 1862.8,1404.05 1862.81,1404.05 1862.81,1404.05 1862.81,1404.05 1862.81,1404.05 1862.82,1404.05 1862.82,1404.05 1862.82,1404.05 1862.83,1404.05 1862.83,1404.05 1862.83,1404.05 1862.83,1404.05 1862.84,1404.05 1862.84,1404.05 1862.84,1404.05 1862.85,1404.05 1862.85,1404.05 1862.85,1404.05 1862.85,1404.05 1862.86,1404.05 1862.86,1404.05 1862.86,1404.05 1862.86,1404.05 1862.87,1404.05 1862.87,1404.05 1862.87,1404.05 1862.88,1404.05 1862.88,1404.05 1862.88,1404.05 1862.88,1404.05 1862.89,1404.05 1862.89,1404.05 1862.89,1404.05 1862.9,1404.05 1862.9,1404.05 1862.9,1404.05 1862.9,1404.05 1862.91,1404.05 1862.91,1404.05 1862.91,1404.05 1862.92,1404.05 1862.92,1404.05 1862.92,1404.05 1862.92,1404.05 1862.93,1404.05 1862.93,1404.05 1862.93,1404.05 1862.93,1404.05 1862.94,1404.05 1862.94,1404.05 1862.94,1404.05 1862.95,1404.05 1862.95,1404.05 1862.95,1404.05 1862.95,1404.05 1862.96,1404.05 1862.96,1404.05 1862.96,1404.05 1862.97,1404.05 1862.97,1404.05 1862.97,1404.05 1862.97,1404.05 1862.98,1404.05 1862.98,1404.05 1862.98,1404.05 1862.99,1404.05 1862.99,1404.05 1862.99,1404.05 1862.99,1404.05 1863,1404.05 1863,1404.05 1863,1404.05 1863,1404.05 1863.01,1404.05 1863.01,1404.05 1863.01,1404.05 1863.02,1404.05 1863.02,1404.05 1863.02,1404.05 1863.02,1404.05 1863.03,1404.05 1863.03,1404.05 1863.03,1404.05 1863.04,1404.05 1863.04,1404.05 1863.04,1404.05 1863.04,1404.05 1863.05,1404.05 1863.05,1404.05 1863.05,1404.05 1863.06,1404.05 1863.06,1404.05 1863.06,1404.05 1863.06,1404.05 1863.07,1404.05 1863.07,1404.05 1863.07,1404.05 1863.07,1404.05 1863.08,1404.05 1863.08,1404.05 1863.08,1404.05 1863.09,1404.05 1863.09,1404.05 1863.09,1404.05 1863.09,1404.05 1863.1,1404.05 1863.1,1404.05 1863.1,1404.05 1863.11,1404.05 1863.11,1404.05 1863.11,1404.05 1863.11,1404.05 1863.12,1404.05 1863.12,1404.05 1863.12,1404.05 1863.12,1404.05 1863.13,1404.05 1863.13,1404.05 1863.13,1404.05 1863.14,1404.05 1863.14,1404.05 1863.14,1404.05 1863.14,1404.05 1863.15,1404.05 1863.15,1404.05 1863.15,1404.05 1863.16,1404.05 1863.16,1404.05 1863.16,1404.05 1863.16,1404.05 1863.17,1404.04 1863.17,1404.04 1863.17,1404.04 1863.18,1404.04 1863.18,1404.04 1863.18,1404.04 1863.18,1404.04 1863.19,1404.04 1863.19,1404.04 1863.19,1404.04 1863.19,1404.04 1863.2,1404.04 1863.2,1404.04 1863.2,1404.04 1863.21,1404.04 1863.21,1404.04 1863.21,1404.04 1863.21,1404.04 1863.22,1404.04 1863.22,1404.04 1863.22,1404.04 1863.23,1404.04 1863.23,1404.04 1863.23,1404.04 1863.23,1404.04 1863.24,1404.04 1863.24,1404.04 1863.24,1404.04 1863.24,1404.04 1863.25,1404.04 1863.25,1404.04 1863.25,1404.04 1863.26,1404.04 1863.26,1404.04 1863.26,1404.04 1863.26,1404.04 1863.27,1404.04 1863.27,1404.04 1863.27,1404.04 1863.28,1404.04 1863.28,1404.04 1863.28,1404.04 1863.28,1404.04 1863.29,1404.04 1863.29,1404.04 1863.29,1404.04 1863.3,1404.04 1863.3,1404.04 1863.3,1404.04 1863.3,1404.04 1863.31,1404.04 1863.31,1404.04 1863.31,1404.04 1863.31,1404.04 1863.32,1404.04 1863.32,1404.04 1863.32,1404.04 1863.33,1404.04 1863.33,1404.04 1863.33,1404.04 1863.33,1404.04 1863.34,1404.04 1863.34,1404.04 1863.34,1404.04 1863.35,1404.04 1863.35,1404.04 1863.35,1404.04 1863.35,1404.04 1863.36,1404.04 1863.36,1404.04 1863.36,1404.04 1863.36,1404.04 1863.37,1404.04 1863.37,1404.04 1863.37,1404.04 1863.38,1404.04 1863.38,1404.04 1863.38,1404.04 1863.38,1404.04 1863.39,1404.04 1863.39,1404.04 1863.39,1404.04 1863.4,1404.04 1863.4,1404.04 1863.4,1404.04 1863.4,1404.04 1863.41,1404.04 1863.41,1404.04 1863.41,1404.04 1863.42,1404.04 1863.42,1404.04 1863.42,1404.04 1863.42,1404.04 1863.43,1404.04 1863.43,1404.04 1863.43,1404.04 1863.43,1404.04 1863.44,1404.04 1863.44,1404.04 1863.44,1404.04 1863.45,1404.04 1863.45,1404.04 1863.45,1404.04 1863.45,1404.04 1863.46,1404.04 1863.46,1404.04 1863.46,1404.04 1863.47,1404.04 1863.47,1404.04 1863.47,1404.04 1863.47,1404.04 1863.48,1404.04 1863.48,1404.04 1863.48,1404.04 1863.48,1404.04 1863.49,1404.04 1863.49,1404.04 1863.49,1404.04 1863.5,1404.04 1863.5,1404.04 1863.5,1404.04 1863.5,1404.04 1863.51,1404.04 1863.51,1404.04 1863.51,1404.04 1863.52,1404.04 1863.52,1404.04 1863.52,1404.04 1863.52,1404.04 1863.53,1404.04 1863.53,1404.04 1863.53,1404.04 1863.54,1404.04 1863.54,1404.04 1863.54,1404.04 1863.54,1404.04 1863.55,1404.04 1863.55,1404.04 1863.55,1404.04 1863.55,1404.03 1863.56,1404.03 1863.56,1404.03 1863.56,1404.03 1863.57,1404.03 1863.57,1404.03 1863.57,1404.03 1863.57,1404.03 1863.58,1404.03 1863.58,1404.03 1863.58,1404.03 1863.59,1404.03 1863.59,1404.03 1863.59,1404.03 1863.59,1404.03 1863.6,1404.03 1863.6,1404.03 1863.6,1404.03 1863.6,1404.03 1863.61,1404.03 1863.61,1404.03 1863.61,1404.03 1863.62,1404.03 1863.62,1404.03 1863.62,1404.03 1863.62,1404.03 1863.63,1404.03 1863.63,1404.03 1863.63,1404.03 1863.64,1404.03 1863.64,1404.03 1863.64,1404.03 1863.64,1404.03 1863.65,1404.03 1863.65,1404.03 1863.65,1404.03 1863.65,1404.03 1863.66,1404.03 1863.66,1404.03 1863.66,1404.03 1863.67,1404.03 1863.67,1404.03 1863.67,1404.03 1863.67,1404.03 1863.68,1404.03 1863.68,1404.03 1863.68,1404.03 1863.69,1404.03 1863.69,1404.03 1863.69,1404.03 1863.69,1404.03 1863.7,1404.03 1863.7,1404.03 1863.7,1404.03 1863.7,1404.03 1863.71,1404.03 1863.71,1404.03 1863.71,1404.03 1863.72,1404.03 1863.72,1404.03 1863.72,1404.03 1863.72,1404.03 1863.73,1404.03 1863.73,1404.03 1863.73,1404.03 1863.74,1404.03 1863.74,1404.03 1863.74,1404.03 1863.74,1404.03 1863.75,1404.03 1863.75,1404.03 1863.75,1404.03 1863.75,1404.03 1863.76,1404.03 1863.76,1404.03 1863.76,1404.03 1863.77,1404.03 1863.77,1404.03 1863.77,1404.03 1863.77,1404.03 1863.78,1404.03 1863.78,1404.03 1863.78,1404.03 1863.79,1404.03 1863.79,1404.03 1863.79,1404.03 1863.79,1404.03 1863.8,1404.03 1863.8,1404.03 1863.8,1404.03 1863.81,1404.03 1863.81,1404.03 1863.81,1404.03 1863.81,1404.03 1863.82,1404.03 1863.82,1404.03 1863.82,1404.03 1863.82,1404.03 1863.83,1404.03 1863.83,1404.03 1863.83,1404.03 1863.84,1404.03 1863.84,1404.03 1863.84,1404.03 1863.84,1404.03 1863.85,1404.03 1863.85,1404.03 1863.85,1404.03 1863.86,1404.03 1863.86,1404.03 1863.86,1404.03 1863.86,1404.03 1863.87,1404.03 1863.87,1404.03 1863.87,1404.03 1863.87,1404.03 1863.88,1404.03 1863.88,1404.03 1863.88,1404.03 1863.89,1404.03 1863.89,1404.03 1863.89,1404.03 1863.89,1404.03 1863.9,1404.03 1863.9,1404.03 1863.9,1404.03 1863.91,1404.03 1863.91,1404.03 1863.91,1404.03 1863.91,1404.03 1863.92,1404.03 1863.92,1404.03 1863.92,1404.03 1863.92,1404.03 1863.93,1404.03 1863.93,1404.03 1863.93,1404.03 1863.94,1404.03 1863.94,1404.03 1863.94,1404.03 1863.94,1404.02 1863.95,1404.02 1863.95,1404.02 1863.95,1404.02 1863.96,1404.02 1863.96,1404.02 1863.96,1404.02 1863.96,1404.02 1863.97,1404.02 1863.97,1404.02 1863.97,1404.02 1863.97,1404.02 1863.98,1404.02 1863.98,1404.02 1863.98,1404.02 1863.99,1404.02 1863.99,1404.02 1863.99,1404.02 1863.99,1404.02 1864,1404.02 1864,1404.02 1864,1404.02 1864.01,1404.02 1864.01,1404.02 1864.01,1404.02 1864.01,1404.02 1864.02,1404.02 1864.02,1404.02 1864.02,1404.02 1864.02,1404.02 1864.03,1404.02 1864.03,1404.02 1864.03,1404.02 1864.04,1404.02 1864.04,1404.02 1864.04,1404.02 1864.04,1404.02 1864.05,1404.02 1864.05,1404.02 1864.05,1404.02 1864.06,1404.02 1864.06,1404.02 1864.06,1404.02 1864.06,1404.02 1864.07,1404.02 1864.07,1404.02 1864.07,1404.02 1864.07,1404.02 1864.08,1404.02 1864.08,1404.02 1864.08,1404.02 1864.09,1404.02 1864.09,1404.02 1864.09,1404.02 1864.09,1404.02 1864.1,1404.02 1864.1,1404.02 1864.1,1404.02 1864.11,1404.02 1864.11,1404.02 1864.11,1404.02 1864.11,1404.02 1864.12,1404.02 1864.12,1404.02 1864.12,1404.02 1864.12,1404.02 1864.13,1404.02 1864.13,1404.02 1864.13,1404.02 1864.14,1404.02 1864.14,1404.02 1864.14,1404.02 1864.14,1404.02 1864.15,1404.02 1864.15,1404.02 1864.15,1404.02 1864.16,1404.02 1864.16,1404.02 1864.16,1404.02 1864.16,1404.02 1864.17,1404.02 1864.17,1404.02 1864.17,1404.02 1864.17,1404.02 1864.18,1404.02 1864.18,1404.02 1864.18,1404.02 1864.19,1404.02 1864.19,1404.02 1864.19,1404.02 1864.19,1404.02 1864.2,1404.02 1864.2,1404.02 1864.2,1404.02 1864.2,1404.02 1864.21,1404.02 1864.21,1404.02 1864.21,1404.02 1864.22,1404.02 1864.22,1404.02 1864.22,1404.02 1864.22,1404.02 1864.23,1404.02 1864.23,1404.02 1864.23,1404.02 1864.24,1404.02 1864.24,1404.02 1864.24,1404.02 1864.24,1404.02 1864.25,1404.02 1864.25,1404.02 1864.25,1404.02 1864.25,1404.02 1864.26,1404.02 1864.26,1404.02 1864.26,1404.02 1864.27,1404.02 1864.27,1404.02 1864.27,1404.02 1864.27,1404.02 1864.28,1404.02 1864.28,1404.02 1864.28,1404.02 1864.29,1404.02 1864.29,1404.02 1864.29,1404.02 1864.29,1404.02 1864.3,1404.02 1864.3,1404.02 1864.3,1404.02 1864.3,1404.02 1864.31,1404.02 1864.31,1404.02 1864.31,1404.02 1864.32,1404.02 1864.32,1404.02 1864.32,1404.02 1864.32,1404.02 1864.33,1404.02 1864.33,1404.02 1864.33,1404.01 1864.34,1404.01 1864.34,1404.01 1864.34,1404.01 1864.34,1404.01 1864.35,1404.01 1864.35,1404.01 1864.35,1404.01 1864.35,1404.01 1864.36,1404.01 1864.36,1404.01 1864.36,1404.01 1864.37,1404.01 1864.37,1404.01 1864.37,1404.01 1864.37,1404.01 1864.38,1404.01 1864.38,1404.01 1864.38,1404.01 1864.39,1404.01 1864.39,1404.01 1864.39,1404.01 1864.39,1404.01 1864.4,1404.01 1864.4,1404.01 1864.4,1404.01 1864.4,1404.01 1864.41,1404.01 1864.41,1404.01 1864.41,1404.01 1864.42,1404.01 1864.42,1404.01 1864.42,1404.01 1864.42,1404.01 1864.43,1404.01 1864.43,1404.01 1864.43,1404.01 1864.43,1404.01 1864.44,1404.01 1864.44,1404.01 1864.44,1404.01 1864.45,1404.01 1864.45,1404.01 1864.45,1404.01 1864.45,1404.01 1864.46,1404.01 1864.46,1404.01 1864.46,1404.01 1864.47,1404.01 1864.47,1404.01 1864.47,1404.01 1864.47,1404.01 1864.48,1404.01 1864.48,1404.01 1864.48,1404.01 1864.48,1404.01 1864.49,1404.01 1864.49,1404.01 1864.49,1404.01 1864.5,1404.01 1864.5,1404.01 1864.5,1404.01 1864.5,1404.01 1864.51,1404.01 1864.51,1404.01 1864.51,1404.01 1864.52,1404.01 1864.52,1404.01 1864.52,1404.01 1864.52,1404.01 1864.53,1404.01 1864.53,1404.01 1864.53,1404.01 1864.53,1404.01 1864.54,1404.01 1864.54,1404.01 1864.54,1404.01 1864.55,1404.01 1864.55,1404.01 1864.55,1404.01 1864.55,1404.01 1864.56,1404.01 1864.56,1404.01 1864.56,1404.01 1864.57,1404.01 1864.57,1404.01 1864.57,1404.01 1864.57,1404.01 1864.58,1404.01 1864.58,1404.01 1864.58,1404.01 1864.58,1404.01 1864.59,1404.01 1864.59,1404.01 1864.59,1404.01 1864.6,1404.01 1864.6,1404.01 1864.6,1404.01 1864.6,1404.01 1864.61,1404.01 1864.61,1404.01 1864.61,1404.01 1864.61,1404.01 1864.62,1404.01 1864.62,1404.01 1864.62,1404.01 1864.63,1404.01 1864.63,1404.01 1864.63,1404.01 1864.63,1404.01 1864.64,1404.01 1864.64,1404.01 1864.64,1404.01 1864.65,1404.01 1864.65,1404.01 1864.65,1404.01 1864.65,1404.01 1864.66,1404.01 1864.66,1404.01 1864.66,1404.01 1864.66,1404.01 1864.67,1404.01 1864.67,1404.01 1864.67,1404.01 1864.68,1404.01 1864.68,1404.01 1864.68,1404.01 1864.68,1404.01 1864.69,1404.01 1864.69,1404.01 1864.69,1404.01 1864.7,1404.01 1864.7,1404.01 1864.7,1404.01 1864.7,1404.01 1864.71,1404.01 1864.71,1404.01 1864.71,1404.01 1864.71,1404.01 1864.72,1404.01 1864.72,1404 1864.72,1404 1864.73,1404 1864.73,1404 1864.73,1404 1864.73,1404 1864.74,1404 1864.74,1404 1864.74,1404 1864.74,1404 1864.75,1404 1864.75,1404 1864.75,1404 1864.76,1404 1864.76,1404 1864.76,1404 1864.76,1404 1864.77,1404 1864.77,1404 1864.77,1404 1864.78,1404 1864.78,1404 1864.78,1404 1864.78,1404 1864.79,1404 1864.79,1404 1864.79,1404 1864.79,1404 1864.8,1404 1864.8,1404 1864.8,1404 1864.81,1404 1864.81,1404 1864.81,1404 1864.81,1404 1864.82,1404 1864.82,1404 1864.82,1404 1864.82,1404 1864.83,1404 1864.83,1404 1864.83,1404 1864.84,1404 1864.84,1404 1864.84,1404 1864.84,1404 1864.85,1404 1864.85,1404 1864.85,1404 1864.86,1404 1864.86,1404 1864.86,1404 1864.86,1404 1864.87,1404 1864.87,1404 1864.87,1404 1864.87,1404 1864.88,1404 1864.88,1404 1864.88,1404 1864.89,1404 1864.89,1404 1864.89,1404 1864.89,1404 1864.9,1404 1864.9,1404 1864.9,1404 1864.91,1404 1864.91,1404 1864.91,1404 1864.91,1404 1864.92,1404 1864.92,1404 1864.92,1404 1864.92,1404 1864.93,1404 1864.93,1404 1864.93,1404 1864.94,1404 1864.94,1404 1864.94,1404 1864.94,1404 1864.95,1404 1864.95,1404 1864.95,1404 1864.95,1404 1864.96,1404 1864.96,1404 1864.96,1404 1864.97,1404 1864.97,1404 1864.97,1404 1864.97,1404 1864.98,1404 1864.98,1404 1864.98,1404 1864.99,1404 1864.99,1404 1864.99,1404 1864.99,1404 1865,1404 1865,1404 1865,1404 1865,1404 1865.01,1404 1865.01,1404 1865.01,1404 1865.02,1404 1865.02,1404 1865.02,1404 1865.02,1404 1865.03,1404 1865.03,1404 1865.03,1404 1865.03,1404 1865.04,1404 1865.04,1404 1865.04,1404 1865.05,1404 1865.05,1404 1865.05,1404 1865.05,1404 1865.06,1404 1865.06,1404 1865.06,1404 1865.07,1404 1865.07,1404 1865.07,1404 1865.07,1404 1865.08,1404 1865.08,1404 1865.08,1404 1865.08,1404 1865.09,1404 1865.09,1404 1865.09,1404 1865.1,1404 1865.1,1404 1865.1,1404 1865.1,1404 1865.11,1404 1865.11,1403.99 1865.11,1403.99 1865.11,1403.99 1865.12,1403.99 1865.12,1403.99 1865.12,1403.99 1865.13,1403.99 1865.13,1403.99 1865.13,1403.99 1865.13,1403.99 1865.14,1403.99 1865.14,1403.99 1865.14,1403.99 1865.14,1403.99 1865.15,1403.99 1865.15,1403.99 1865.15,1403.99 1865.16,1403.99 1865.16,1403.99 1865.16,1403.99 1865.16,1403.99 1865.17,1403.99 1865.17,1403.99 1865.17,1403.99 1865.18,1403.99 1865.18,1403.99 1865.18,1403.99 1865.18,1403.99 1865.19,1403.99 1865.19,1403.99 1865.19,1403.99 1865.19,1403.99 1865.2,1403.99 1865.2,1403.99 1865.2,1403.99 1865.21,1403.99 1865.21,1403.99 1865.21,1403.99 1865.21,1403.99 1865.22,1403.99 1865.22,1403.99 1865.22,1403.99 1865.22,1403.99 1865.23,1403.99 1865.23,1403.99 1865.23,1403.99 1865.24,1403.99 1865.24,1403.99 1865.24,1403.99 1865.24,1403.99 1865.25,1403.99 1865.25,1403.99 1865.25,1403.99 1865.26,1403.99 1865.26,1403.99 1865.26,1403.99 1865.26,1403.99 1865.27,1403.99 1865.27,1403.99 1865.27,1403.99 1865.27,1403.99 1865.28,1403.99 1865.28,1403.99 1865.28,1403.99 1865.29,1403.99 1865.29,1403.99 1865.29,1403.99 1865.29,1403.99 1865.3,1403.99 1865.3,1403.99 1865.3,1403.99 1865.3,1403.99 1865.31,1403.99 1865.31,1403.99 1865.31,1403.99 1865.32,1403.99 1865.32,1403.99 1865.32,1403.99 1865.32,1403.99 1865.33,1403.99 1865.33,1403.99 1865.33,1403.99 1865.34,1403.99 1865.34,1403.99 1865.34,1403.99 1865.34,1403.99 1865.35,1403.99 1865.35,1403.99 1865.35,1403.99 1865.35,1403.99 1865.36,1403.99 1865.36,1403.99 1865.36,1403.99 1865.37,1403.99 1865.37,1403.99 1865.37,1403.99 1865.37,1403.99 1865.38,1403.99 1865.38,1403.99 1865.38,1403.99 1865.38,1403.99 1865.39,1403.99 1865.39,1403.99 1865.39,1403.99 1865.4,1403.99 1865.4,1403.99 1865.4,1403.99 1865.4,1403.99 1865.41,1403.99 1865.41,1403.99 1865.41,1403.99 1865.41,1403.99 1865.42,1403.99 1865.42,1403.99 1865.42,1403.99 1865.43,1403.99 1865.43,1403.99 1865.43,1403.99 1865.43,1403.99 1865.44,1403.99 1865.44,1403.99 1865.44,1403.99 1865.45,1403.99 1865.45,1403.99 1865.45,1403.99 1865.45,1403.99 1865.46,1403.99 1865.46,1403.99 1865.46,1403.99 1865.46,1403.99 1865.47,1403.99 1865.47,1403.99 1865.47,1403.99 1865.48,1403.99 1865.48,1403.99 1865.48,1403.99 1865.48,1403.99 1865.49,1403.99 1865.49,1403.99 1865.49,1403.99 1865.49,1403.99 1865.5,1403.98 1865.5,1403.98 1865.5,1403.98 1865.51,1403.98 1865.51,1403.98 1865.51,1403.98 1865.51,1403.98 1865.52,1403.98 1865.52,1403.98 1865.52,1403.98 1865.52,1403.98 1865.53,1403.98 1865.53,1403.98 1865.53,1403.98 1865.54,1403.98 1865.54,1403.98 1865.54,1403.98 1865.54,1403.98 1865.55,1403.98 1865.55,1403.98 1865.55,1403.98 1865.56,1403.98 1865.56,1403.98 1865.56,1403.98 1865.56,1403.98 1865.57,1403.98 1865.57,1403.98 1865.57,1403.98 1865.57,1403.98 1865.58,1403.98 1865.58,1403.98 1865.58,1403.98 1865.59,1403.98 1865.59,1403.98 1865.59,1403.98 1865.59,1403.98 1865.6,1403.98 1865.6,1403.98 1865.6,1403.98 1865.6,1403.98 1865.61,1403.98 1865.61,1403.98 1865.61,1403.98 1865.62,1403.98 1865.62,1403.98 1865.62,1403.98 1865.62,1403.98 1865.63,1403.98 1865.63,1403.98 1865.63,1403.98 1865.63,1403.98 1865.64,1403.98 1865.64,1403.98 1865.64,1403.98 1865.65,1403.98 1865.65,1403.98 1865.65,1403.98 1865.65,1403.98 1865.66,1403.98 1865.66,1403.98 1865.66,1403.98 1865.67,1403.98 1865.67,1403.98 1865.67,1403.98 1865.67,1403.98 1865.68,1403.98 1865.68,1403.98 1865.68,1403.98 1865.68,1403.98 1865.69,1403.98 1865.69,1403.98 1865.69,1403.98 1865.7,1403.98 1865.7,1403.98 1865.7,1403.98 1865.7,1403.98 1865.71,1403.98 1865.71,1403.98 1865.71,1403.98 1865.71,1403.98 1865.72,1403.98 1865.72,1403.98 1865.72,1403.98 1865.73,1403.98 1865.73,1403.98 1865.73,1403.98 1865.73,1403.98 1865.74,1403.98 1865.74,1403.98 1865.74,1403.98 1865.74,1403.98 1865.75,1403.98 1865.75,1403.98 1865.75,1403.98 1865.76,1403.98 1865.76,1403.98 1865.76,1403.98 1865.76,1403.98 1865.77,1403.98 1865.77,1403.98 1865.77,1403.98 1865.77,1403.98 1865.78,1403.98 1865.78,1403.98 1865.78,1403.98 1865.79,1403.98 1865.79,1403.98 1865.79,1403.98 1865.79,1403.98 1865.8,1403.98 1865.8,1403.98 1865.8,1403.98 1865.81,1403.98 1865.81,1403.98 1865.81,1403.98 1865.81,1403.98 1865.82,1403.98 1865.82,1403.98 1865.82,1403.98 1865.82,1403.98 1865.83,1403.98 1865.83,1403.98 1865.83,1403.98 1865.84,1403.98 1865.84,1403.98 1865.84,1403.98 1865.84,1403.98 1865.85,1403.98 1865.85,1403.98 1865.85,1403.98 1865.85,1403.98 1865.86,1403.98 1865.86,1403.98 1865.86,1403.98 1865.87,1403.98 1865.87,1403.98 1865.87,1403.98 1865.87,1403.98 1865.88,1403.98 1865.88,1403.98 1865.88,1403.98 1865.88,1403.97 1865.89,1403.97 1865.89,1403.97 1865.89,1403.97 1865.9,1403.97 1865.9,1403.97 1865.9,1403.97 1865.9,1403.97 1865.91,1403.97 1865.91,1403.97 1865.91,1403.97 1865.91,1403.97 1865.92,1403.97 1865.92,1403.97 1865.92,1403.97 1865.93,1403.97 1865.93,1403.97 1865.93,1403.97 1865.93,1403.97 1865.94,1403.97 1865.94,1403.97 1865.94,1403.97 1865.94,1403.97 1865.95,1403.97 1865.95,1403.97 1865.95,1403.97 1865.96,1403.97 1865.96,1403.97 1865.96,1403.97 1865.96,1403.97 1865.97,1403.97 1865.97,1403.97 1865.97,1403.97 1865.98,1403.97 1865.98,1403.97 1865.98,1403.97 1865.98,1403.97 1865.99,1403.97 1865.99,1403.97 1865.99,1403.97 1865.99,1403.97 1866,1403.97 1866,1403.97 1866,1403.97 1866.01,1403.97 1866.01,1403.97 1866.01,1403.97 1866.01,1403.97 1866.02,1403.97 1866.02,1403.97 1866.02,1403.97 1866.02,1403.97 1866.03,1403.97 1866.03,1403.97 1866.03,1403.97 1866.04,1403.97 1866.04,1403.97 1866.04,1403.97 1866.04,1403.97 1866.05,1403.97 1866.05,1403.97 1866.05,1403.97 1866.05,1403.97 1866.06,1403.97 1866.06,1403.97 1866.06,1403.97 1866.07,1403.97 1866.07,1403.97 1866.07,1403.97 1866.07,1403.97 1866.08,1403.97 1866.08,1403.97 1866.08,1403.97 1866.08,1403.97 1866.09,1403.97 1866.09,1403.97 1866.09,1403.97 1866.1,1403.97 1866.1,1403.97 1866.1,1403.97 1866.1,1403.97 1866.11,1403.97 1866.11,1403.97 1866.11,1403.97 1866.11,1403.97 1866.12,1403.97 1866.12,1403.97 1866.12,1403.97 1866.13,1403.97 1866.13,1403.97 1866.13,1403.97 1866.13,1403.97 1866.14,1403.97 1866.14,1403.97 1866.14,1403.97 1866.14,1403.97 1866.15,1403.97 1866.15,1403.97 1866.15,1403.97 1866.16,1403.97 1866.16,1403.97 1866.16,1403.97 1866.16,1403.97 1866.17,1403.97 1866.17,1403.97 1866.17,1403.97 1866.18,1403.97 1866.18,1403.97 1866.18,1403.97 1866.18,1403.97 1866.19,1403.97 1866.19,1403.97 1866.19,1403.97 1866.19,1403.97 1866.2,1403.97 1866.2,1403.97 1866.2,1403.97 1866.21,1403.97 1866.21,1403.97 1866.21,1403.97 1866.21,1403.97 1866.22,1403.97 1866.22,1403.97 1866.22,1403.97 1866.22,1403.97 1866.23,1403.97 1866.23,1403.97 1866.23,1403.97 1866.24,1403.97 1866.24,1403.97 1866.24,1403.97 1866.24,1403.97 1866.25,1403.97 1866.25,1403.97 1866.25,1403.97 1866.25,1403.97 1866.26,1403.97 1866.26,1403.97 1866.26,1403.97 1866.27,1403.97 1866.27,1403.97 1866.27,1403.97 1866.27,1403.96 1866.28,1403.96 1866.28,1403.96 1866.28,1403.96 1866.28,1403.96 1866.29,1403.96 1866.29,1403.96 1866.29,1403.96 1866.3,1403.96 1866.3,1403.96 1866.3,1403.96 1866.3,1403.96 1866.31,1403.96 1866.31,1403.96 1866.31,1403.96 1866.31,1403.96 1866.32,1403.96 1866.32,1403.96 1866.32,1403.96 1866.33,1403.96 1866.33,1403.96 1866.33,1403.96 1866.33,1403.96 1866.34,1403.96 1866.34,1403.96 1866.34,1403.96 1866.34,1403.96 1866.35,1403.96 1866.35,1403.96 1866.35,1403.96 1866.36,1403.96 1866.36,1403.96 1866.36,1403.96 1866.36,1403.96 1866.37,1403.96 1866.37,1403.96 1866.37,1403.96 1866.37,1403.96 1866.38,1403.96 1866.38,1403.96 1866.38,1403.96 1866.39,1403.96 1866.39,1403.96 1866.39,1403.96 1866.39,1403.96 1866.4,1403.96 1866.4,1403.96 1866.4,1403.96 1866.4,1403.96 1866.41,1403.96 1866.41,1403.96 1866.41,1403.96 1866.42,1403.96 1866.42,1403.96 1866.42,1403.96 1866.42,1403.96 1866.43,1403.96 1866.43,1403.96 1866.43,1403.96 1866.43,1403.96 1866.44,1403.96 1866.44,1403.96 1866.44,1403.96 1866.45,1403.96 1866.45,1403.96 1866.45,1403.96 1866.45,1403.96 1866.46,1403.96 1866.46,1403.96 1866.46,1403.96 1866.47,1403.96 1866.47,1403.96 1866.47,1403.96 1866.47,1403.96 1866.48,1403.96 1866.48,1403.96 1866.48,1403.96 1866.48,1403.96 1866.49,1403.96 1866.49,1403.96 1866.49,1403.96 1866.5,1403.96 1866.5,1403.96 1866.5,1403.96 1866.5,1403.96 1866.51,1403.96 1866.51,1403.96 1866.51,1403.96 1866.51,1403.96 1866.52,1403.96 1866.52,1403.96 1866.52,1403.96 1866.53,1403.96 1866.53,1403.96 1866.53,1403.96 1866.53,1403.96 1866.54,1403.96 1866.54,1403.96 1866.54,1403.96 1866.54,1403.96 1866.55,1403.96 1866.55,1403.96 1866.55,1403.96 1866.56,1403.96 1866.56,1403.96 1866.56,1403.96 1866.56,1403.96 1866.57,1403.96 1866.57,1403.96 1866.57,1403.96 1866.57,1403.96 1866.58,1403.96 1866.58,1403.96 1866.58,1403.96 1866.59,1403.96 1866.59,1403.96 1866.59,1403.96 1866.59,1403.96 1866.6,1403.96 1866.6,1403.96 1866.6,1403.96 1866.6,1403.96 1866.61,1403.96 1866.61,1403.96 1866.61,1403.96 1866.62,1403.96 1866.62,1403.96 1866.62,1403.96 1866.62,1403.96 1866.63,1403.96 1866.63,1403.96 1866.63,1403.96 1866.63,1403.96 1866.64,1403.96 1866.64,1403.96 1866.64,1403.96 1866.65,1403.96 1866.65,1403.96 1866.65,1403.96 1866.65,1403.96 1866.66,1403.96 1866.66,1403.96 1866.66,1403.95 1866.66,1403.95 1866.67,1403.95 1866.67,1403.95 1866.67,1403.95 1866.68,1403.95 1866.68,1403.95 1866.68,1403.95 1866.68,1403.95 1866.69,1403.95 1866.69,1403.95 1866.69,1403.95 1866.69,1403.95 1866.7,1403.95 1866.7,1403.95 1866.7,1403.95 1866.71,1403.95 1866.71,1403.95 1866.71,1403.95 1866.71,1403.95 1866.72,1403.95 1866.72,1403.95 1866.72,1403.95 1866.72,1403.95 1866.73,1403.95 1866.73,1403.95 1866.73,1403.95 1866.74,1403.95 1866.74,1403.95 1866.74,1403.95 1866.74,1403.95 1866.75,1403.95 1866.75,1403.95 1866.75,1403.95 1866.75,1403.95 1866.76,1403.95 1866.76,1403.95 1866.76,1403.95 1866.77,1403.95 1866.77,1403.95 1866.77,1403.95 1866.77,1403.95 1866.78,1403.95 1866.78,1403.95 1866.78,1403.95 1866.78,1403.95 1866.79,1403.95 1866.79,1403.95 1866.79,1403.95 1866.8,1403.95 1866.8,1403.95 1866.8,1403.95 1866.8,1403.95 1866.81,1403.95 1866.81,1403.95 1866.81,1403.95 1866.81,1403.95 1866.82,1403.95 1866.82,1403.95 1866.82,1403.95 1866.83,1403.95 1866.83,1403.95 1866.83,1403.95 1866.83,1403.95 1866.84,1403.95 1866.84,1403.95 1866.84,1403.95 1866.84,1403.95 1866.85,1403.95 1866.85,1403.95 1866.85,1403.95 1866.86,1403.95 1866.86,1403.95 1866.86,1403.95 1866.86,1403.95 1866.87,1403.95 1866.87,1403.95 1866.87,1403.95 1866.87,1403.95 1866.88,1403.95 1866.88,1403.95 1866.88,1403.95 1866.89,1403.95 1866.89,1403.95 1866.89,1403.95 1866.89,1403.95 1866.9,1403.95 1866.9,1403.95 1866.9,1403.95 1866.9,1403.95 1866.91,1403.95 1866.91,1403.95 1866.91,1403.95 1866.92,1403.95 1866.92,1403.95 1866.92,1403.95 1866.92,1403.95 1866.93,1403.95 1866.93,1403.95 1866.93,1403.95 1866.93,1403.95 1866.94,1403.95 1866.94,1403.95 1866.94,1403.95 1866.95,1403.95 1866.95,1403.95 1866.95,1403.95 1866.95,1403.95 1866.96,1403.95 1866.96,1403.95 1866.96,1403.95 1866.96,1403.95 1866.97,1403.95 1866.97,1403.95 1866.97,1403.95 1866.98,1403.95 1866.98,1403.95 1866.98,1403.95 1866.98,1403.95 1866.99,1403.95 1866.99,1403.95 1866.99,1403.95 1866.99,1403.95 1867,1403.95 1867,1403.95 1867,1403.95 1867.01,1403.95 1867.01,1403.95 1867.01,1403.95 1867.01,1403.95 1867.02,1403.95 1867.02,1403.95 1867.02,1403.95 1867.02,1403.95 1867.03,1403.95 1867.03,1403.95 1867.03,1403.95 1867.04,1403.95 1867.04,1403.95 1867.04,1403.95 1867.04,1403.95 1867.05,1403.95 1867.05,1403.94 1867.05,1403.94 1867.05,1403.94 1867.06,1403.94 1867.06,1403.94 1867.06,1403.94 1867.07,1403.94 1867.07,1403.94 1867.07,1403.94 1867.07,1403.94 1867.08,1403.94 1867.08,1403.94 1867.08,1403.94 1867.08,1403.94 1867.09,1403.94 1867.09,1403.94 1867.09,1403.94 1867.1,1403.94 1867.1,1403.94 1867.1,1403.94 1867.1,1403.94 1867.11,1403.94 1867.11,1403.94 1867.11,1403.94 1867.11,1403.94 1867.12,1403.94 1867.12,1403.94 1867.12,1403.94 1867.13,1403.94 1867.13,1403.94 1867.13,1403.94 1867.13,1403.94 1867.14,1403.94 1867.14,1403.94 1867.14,1403.94 1867.14,1403.94 1867.15,1403.94 1867.15,1403.94 1867.15,1403.94 1867.15,1403.94 1867.16,1403.94 1867.16,1403.94 1867.16,1403.94 1867.17,1403.94 1867.17,1403.94 1867.17,1403.94 1867.17,1403.94 1867.18,1403.94 1867.18,1403.94 1867.18,1403.94 1867.18,1403.94 1867.19,1403.94 1867.19,1403.94 1867.19,1403.94 1867.2,1403.94 1867.2,1403.94 1867.2,1403.94 1867.2,1403.94 1867.21,1403.94 1867.21,1403.94 1867.21,1403.94 1867.21,1403.94 1867.22,1403.94 1867.22,1403.94 1867.22,1403.94 1867.23,1403.94 1867.23,1403.94 1867.23,1403.94 1867.23,1403.94 1867.24,1403.94 1867.24,1403.94 1867.24,1403.94 1867.24,1403.94 1867.25,1403.94 1867.25,1403.94 1867.25,1403.94 1867.26,1403.94 1867.26,1403.94 1867.26,1403.94 1867.26,1403.94 1867.27,1403.94 1867.27,1403.94 1867.27,1403.94 1867.27,1403.94 1867.28,1403.94 1867.28,1403.94 1867.28,1403.94 1867.29,1403.94 1867.29,1403.94 1867.29,1403.94 1867.29,1403.94 1867.3,1403.94 1867.3,1403.94 1867.3,1403.94 1867.3,1403.94 1867.31,1403.94 1867.31,1403.94 1867.31,1403.94 1867.32,1403.94 1867.32,1403.94 1867.32,1403.94 1867.32,1403.94 1867.33,1403.94 1867.33,1403.94 1867.33,1403.94 1867.33,1403.94 1867.34,1403.94 1867.34,1403.94 1867.34,1403.94 1867.35,1403.94 1867.35,1403.94 1867.35,1403.94 1867.35,1403.94 1867.36,1403.94 1867.36,1403.94 1867.36,1403.94 1867.36,1403.94 1867.37,1403.94 1867.37,1403.94 1867.37,1403.94 1867.38,1403.94 1867.38,1403.94 1867.38,1403.94 1867.38,1403.94 1867.39,1403.94 1867.39,1403.94 1867.39,1403.94 1867.39,1403.94 1867.4,1403.94 1867.4,1403.94 1867.4,1403.94 1867.41,1403.94 1867.41,1403.94 1867.41,1403.94 1867.41,1403.94 1867.42,1403.94 1867.42,1403.94 1867.42,1403.94 1867.42,1403.94 1867.43,1403.94 1867.43,1403.94 1867.43,1403.94 1867.43,1403.94 1867.44,1403.93 1867.44,1403.93 1867.44,1403.93 1867.45,1403.93 1867.45,1403.93 1867.45,1403.93 1867.45,1403.93 1867.46,1403.93 1867.46,1403.93 1867.46,1403.93 1867.46,1403.93 1867.47,1403.93 1867.47,1403.93 1867.47,1403.93 1867.48,1403.93 1867.48,1403.93 1867.48,1403.93 1867.48,1403.93 1867.49,1403.93 1867.49,1403.93 1867.49,1403.93 1867.49,1403.93 1867.5,1403.93 1867.5,1403.93 1867.5,1403.93 1867.51,1403.93 1867.51,1403.93 1867.51,1403.93 1867.51,1403.93 1867.52,1403.93 1867.52,1403.93 1867.52,1403.93 1867.52,1403.93 1867.53,1403.93 1867.53,1403.93 1867.53,1403.93 1867.54,1403.93 1867.54,1403.93 1867.54,1403.93 1867.54,1403.93 1867.55,1403.93 1867.55,1403.93 1867.55,1403.93 1867.55,1403.93 1867.56,1403.93 1867.56,1403.93 1867.56,1403.93 1867.57,1403.93 1867.57,1403.93 1867.57,1403.93 1867.57,1403.93 1867.58,1403.93 1867.58,1403.93 1867.58,1403.93 1867.58,1403.93 1867.59,1403.93 1867.59,1403.93 1867.59,1403.93 1867.6,1403.93 1867.6,1403.93 1867.6,1403.93 1867.6,1403.93 1867.61,1403.93 1867.61,1403.93 1867.61,1403.93 1867.61,1403.93 1867.62,1403.93 1867.62,1403.93 1867.62,1403.93 1867.63,1403.93 1867.63,1403.93 1867.63,1403.93 1867.63,1403.93 1867.64,1403.93 1867.64,1403.93 1867.64,1403.93 1867.64,1403.93 1867.65,1403.93 1867.65,1403.93 1867.65,1403.93 1867.65,1403.93 1867.66,1403.93 1867.66,1403.93 1867.66,1403.93 1867.67,1403.93 1867.67,1403.93 1867.67,1403.93 1867.67,1403.93 1867.68,1403.93 1867.68,1403.93 1867.68,1403.93 1867.68,1403.93 1867.69,1403.93 1867.69,1403.93 1867.69,1403.93 1867.7,1403.93 1867.7,1403.93 1867.7,1403.93 1867.7,1403.93 1867.71,1403.93 1867.71,1403.93 1867.71,1403.93 1867.71,1403.93 1867.72,1403.93 1867.72,1403.93 1867.72,1403.93 1867.73,1403.93 1867.73,1403.93 1867.73,1403.93 1867.73,1403.93 1867.74,1403.93 1867.74,1403.93 1867.74,1403.93 1867.74,1403.93 1867.75,1403.93 1867.75,1403.93 1867.75,1403.93 1867.76,1403.93 1867.76,1403.93 1867.76,1403.93 1867.76,1403.93 1867.77,1403.93 1867.77,1403.93 1867.77,1403.93 1867.77,1403.93 1867.78,1403.93 1867.78,1403.93 1867.78,1403.93 1867.78,1403.93 1867.79,1403.93 1867.79,1403.93 1867.79,1403.93 1867.8,1403.93 1867.8,1403.93 1867.8,1403.93 1867.8,1403.93 1867.81,1403.93 1867.81,1403.93 1867.81,1403.93 1867.81,1403.93 1867.82,1403.93 1867.82,1403.93 1867.82,1403.93 1867.83,1403.92 1867.83,1403.92 1867.83,1403.92 1867.83,1403.92 1867.84,1403.92 1867.84,1403.92 1867.84,1403.92 1867.84,1403.92 1867.85,1403.92 1867.85,1403.92 1867.85,1403.92 1867.86,1403.92 1867.86,1403.92 1867.86,1403.92 1867.86,1403.92 1867.87,1403.92 1867.87,1403.92 1867.87,1403.92 1867.87,1403.92 1867.88,1403.92 1867.88,1403.92 1867.88,1403.92 1867.89,1403.92 1867.89,1403.92 1867.89,1403.92 1867.89,1403.92 1867.9,1403.92 1867.9,1403.92 1867.9,1403.92 1867.9,1403.92 1867.91,1403.92 1867.91,1403.92 1867.91,1403.92 1867.92,1403.92 1867.92,1403.92 1867.92,1403.92 1867.92,1403.92 1867.93,1403.92 1867.93,1403.92 1867.93,1403.92 1867.93,1403.92 1867.94,1403.92 1867.94,1403.92 1867.94,1403.92 1867.94,1403.92 1867.95,1403.92 1867.95,1403.92 1867.95,1403.92 1867.96,1403.92 1867.96,1403.92 1867.96,1403.92 1867.96,1403.92 1867.97,1403.92 1867.97,1403.92 1867.97,1403.92 1867.97,1403.92 1867.98,1403.92 1867.98,1403.92 1867.98,1403.92 1867.99,1403.92 1867.99,1403.92 1867.99,1403.92 1867.99,1403.92 1868,1403.92 1868,1403.92 1868,1403.92 1868,1403.92 1868.01,1403.92 1868.01,1403.92 1868.01,1403.92 1868.02,1403.92 1868.02,1403.92 1868.02,1403.92 1868.02,1403.92 1868.03,1403.92 1868.03,1403.92 1868.03,1403.92 1868.03,1403.92 1868.04,1403.92 1868.04,1403.92 1868.04,1403.92 1868.04,1403.92 1868.05,1403.92 1868.05,1403.92 1868.05,1403.92 1868.06,1403.92 1868.06,1403.92 1868.06,1403.92 1868.06,1403.92 1868.07,1403.92 1868.07,1403.92 1868.07,1403.92 1868.07,1403.92 1868.08,1403.92 1868.08,1403.92 1868.08,1403.92 1868.09,1403.92 1868.09,1403.92 1868.09,1403.92 1868.09,1403.92 1868.1,1403.92 1868.1,1403.92 1868.1,1403.92 1868.1,1403.92 1868.11,1403.92 1868.11,1403.92 1868.11,1403.92 1868.12,1403.92 1868.12,1403.92 1868.12,1403.92 1868.12,1403.92 1868.13,1403.92 1868.13,1403.92 1868.13,1403.92 1868.13,1403.92 1868.14,1403.92 1868.14,1403.92 1868.14,1403.92 1868.15,1403.92 1868.15,1403.92 1868.15,1403.92 1868.15,1403.92 1868.16,1403.92 1868.16,1403.92 1868.16,1403.92 1868.16,1403.92 1868.17,1403.92 1868.17,1403.92 1868.17,1403.92 1868.17,1403.92 1868.18,1403.92 1868.18,1403.92 1868.18,1403.92 1868.19,1403.92 1868.19,1403.92 1868.19,1403.92 1868.19,1403.92 1868.2,1403.92 1868.2,1403.92 1868.2,1403.92 1868.2,1403.92 1868.21,1403.92 1868.21,1403.92 1868.21,1403.91 1868.22,1403.91 1868.22,1403.91 1868.22,1403.91 1868.22,1403.91 1868.23,1403.91 1868.23,1403.91 1868.23,1403.91 1868.23,1403.91 1868.24,1403.91 1868.24,1403.91 1868.24,1403.91 1868.25,1403.91 1868.25,1403.91 1868.25,1403.91 1868.25,1403.91 1868.26,1403.91 1868.26,1403.91 1868.26,1403.91 1868.26,1403.91 1868.27,1403.91 1868.27,1403.91 1868.27,1403.91 1868.27,1403.91 1868.28,1403.91 1868.28,1403.91 1868.28,1403.91 1868.29,1403.91 1868.29,1403.91 1868.29,1403.91 1868.29,1403.91 1868.3,1403.91 1868.3,1403.91 1868.3,1403.91 1868.3,1403.91 1868.31,1403.91 1868.31,1403.91 1868.31,1403.91 1868.32,1403.91 1868.32,1403.91 1868.32,1403.91 1868.32,1403.91 1868.33,1403.91 1868.33,1403.91 1868.33,1403.91 1868.33,1403.91 1868.34,1403.91 1868.34,1403.91 1868.34,1403.91 1868.35,1403.91 1868.35,1403.91 1868.35,1403.91 1868.35,1403.91 1868.36,1403.91 1868.36,1403.91 1868.36,1403.91 1868.36,1403.91 1868.37,1403.91 1868.37,1403.91 1868.37,1403.91 1868.37,1403.91 1868.38,1403.91 1868.38,1403.91 1868.38,1403.91 1868.39,1403.91 1868.39,1403.91 1868.39,1403.91 1868.39,1403.91 1868.4,1403.91 1868.4,1403.91 1868.4,1403.91 1868.4,1403.91 1868.41,1403.91 1868.41,1403.91 1868.41,1403.91 1868.42,1403.91 1868.42,1403.91 1868.42,1403.91 1868.42,1403.91 1868.43,1403.91 1868.43,1403.91 1868.43,1403.91 1868.43,1403.91 1868.44,1403.91 1868.44,1403.91 1868.44,1403.91 1868.45,1403.91 1868.45,1403.91 1868.45,1403.91 1868.45,1403.91 1868.46,1403.91 1868.46,1403.91 1868.46,1403.91 1868.46,1403.91 1868.47,1403.91 1868.47,1403.91 1868.47,1403.91 1868.47,1403.91 1868.48,1403.91 1868.48,1403.91 1868.48,1403.91 1868.49,1403.91 1868.49,1403.91 1868.49,1403.91 1868.49,1403.91 1868.5,1403.91 1868.5,1403.91 1868.5,1403.91 1868.5,1403.91 1868.51,1403.91 1868.51,1403.91 1868.51,1403.91 1868.52,1403.91 1868.52,1403.91 1868.52,1403.91 1868.52,1403.91 1868.53,1403.91 1868.53,1403.91 1868.53,1403.91 1868.53,1403.91 1868.54,1403.91 1868.54,1403.91 1868.54,1403.91 1868.54,1403.91 1868.55,1403.91 1868.55,1403.91 1868.55,1403.91 1868.56,1403.91 1868.56,1403.91 1868.56,1403.91 1868.56,1403.91 1868.57,1403.91 1868.57,1403.91 1868.57,1403.91 1868.57,1403.91 1868.58,1403.91 1868.58,1403.91 1868.58,1403.91 1868.59,1403.91 1868.59,1403.91 1868.59,1403.91 1868.59,1403.91 1868.6,1403.91 1868.6,1403.91 1868.6,1403.9 1868.6,1403.9 1868.61,1403.9 1868.61,1403.9 1868.61,1403.9 1868.62,1403.9 1868.62,1403.9 1868.62,1403.9 1868.62,1403.9 1868.63,1403.9 1868.63,1403.9 1868.63,1403.9 1868.63,1403.9 1868.64,1403.9 1868.64,1403.9 1868.64,1403.9 1868.64,1403.9 1868.65,1403.9 1868.65,1403.9 1868.65,1403.9 1868.66,1403.9 1868.66,1403.9 1868.66,1403.9 1868.66,1403.9 1868.67,1403.9 1868.67,1403.9 1868.67,1403.9 1868.67,1403.9 1868.68,1403.9 1868.68,1403.9 1868.68,1403.9 1868.69,1403.9 1868.69,1403.9 1868.69,1403.9 1868.69,1403.9 1868.7,1403.9 1868.7,1403.9 1868.7,1403.9 1868.7,1403.9 1868.71,1403.9 1868.71,1403.9 1868.71,1403.9 1868.71,1403.9 1868.72,1403.9 1868.72,1403.9 1868.72,1403.9 1868.73,1403.9 1868.73,1403.9 1868.73,1403.9 1868.73,1403.9 1868.74,1403.9 1868.74,1403.9 1868.74,1403.9 1868.74,1403.9 1868.75,1403.9 1868.75,1403.9 1868.75,1403.9 1868.76,1403.9 1868.76,1403.9 1868.76,1403.9 1868.76,1403.9 1868.77,1403.9 1868.77,1403.9 1868.77,1403.9 1868.77,1403.9 1868.78,1403.9 1868.78,1403.9 1868.78,1403.9 1868.78,1403.9 1868.79,1403.9 1868.79,1403.9 1868.79,1403.9 1868.8,1403.9 1868.8,1403.9 1868.8,1403.9 1868.8,1403.9 1868.81,1403.9 1868.81,1403.9 1868.81,1403.9 1868.81,1403.9 1868.82,1403.9 1868.82,1403.9 1868.82,1403.9 1868.83,1403.9 1868.83,1403.9 1868.83,1403.9 1868.83,1403.9 1868.84,1403.9 1868.84,1403.9 1868.84,1403.9 1868.84,1403.9 1868.85,1403.9 1868.85,1403.9 1868.85,1403.9 1868.85,1403.9 1868.86,1403.9 1868.86,1403.9 1868.86,1403.9 1868.87,1403.9 1868.87,1403.9 1868.87,1403.9 1868.87,1403.9 1868.88,1403.9 1868.88,1403.9 1868.88,1403.9 1868.88,1403.9 1868.89,1403.9 1868.89,1403.9 1868.89,1403.9 1868.9,1403.9 1868.9,1403.9 1868.9,1403.9 1868.9,1403.9 1868.91,1403.9 1868.91,1403.9 1868.91,1403.9 1868.91,1403.9 1868.92,1403.9 1868.92,1403.9 1868.92,1403.9 1868.92,1403.9 1868.93,1403.9 1868.93,1403.9 1868.93,1403.9 1868.94,1403.9 1868.94,1403.9 1868.94,1403.9 1868.94,1403.9 1868.95,1403.9 1868.95,1403.9 1868.95,1403.9 1868.95,1403.9 1868.96,1403.9 1868.96,1403.9 1868.96,1403.9 1868.97,1403.9 1868.97,1403.9 1868.97,1403.9 1868.97,1403.9 1868.98,1403.9 1868.98,1403.9 1868.98,1403.9 1868.98,1403.9 1868.99,1403.9 1868.99,1403.89 1868.99,1403.89 1868.99,1403.89 1869,1403.89 1869,1403.89 1869,1403.89 1869.01,1403.89 1869.01,1403.89 1869.01,1403.89 1869.01,1403.89 1869.02,1403.89 1869.02,1403.89 1869.02,1403.89 1869.02,1403.89 1869.03,1403.89 1869.03,1403.89 1869.03,1403.89 1869.04,1403.89 1869.04,1403.89 1869.04,1403.89 1869.04,1403.89 1869.05,1403.89 1869.05,1403.89 1869.05,1403.89 1869.05,1403.89 1869.06,1403.89 1869.06,1403.89 1869.06,1403.89 1869.06,1403.89 1869.07,1403.89 1869.07,1403.89 1869.07,1403.89 1869.08,1403.89 1869.08,1403.89 1869.08,1403.89 1869.08,1403.89 1869.09,1403.89 1869.09,1403.89 1869.09,1403.89 1869.09,1403.89 1869.1,1403.89 1869.1,1403.89 1869.1,1403.89 1869.11,1403.89 1869.11,1403.89 1869.11,1403.89 1869.11,1403.89 1869.12,1403.89 1869.12,1403.89 1869.12,1403.89 1869.12,1403.89 1869.13,1403.89 1869.13,1403.89 1869.13,1403.89 1869.13,1403.89 1869.14,1403.89 1869.14,1403.89 1869.14,1403.89 1869.15,1403.89 1869.15,1403.89 1869.15,1403.89 1869.15,1403.89 1869.16,1403.89 1869.16,1403.89 1869.16,1403.89 1869.16,1403.89 1869.17,1403.89 1869.17,1403.89 1869.17,1403.89 1869.18,1403.89 1869.18,1403.89 1869.18,1403.89 1869.18,1403.89 1869.19,1403.89 1869.19,1403.89 1869.19,1403.89 1869.19,1403.89 1869.2,1403.89 1869.2,1403.89 1869.2,1403.89 1869.2,1403.89 1869.21,1403.89 1869.21,1403.89 1869.21,1403.89 1869.22,1403.89 1869.22,1403.89 1869.22,1403.89 1869.22,1403.89 1869.23,1403.89 1869.23,1403.89 1869.23,1403.89 1869.23,1403.89 1869.24,1403.89 1869.24,1403.89 1869.24,1403.89 1869.24,1403.89 1869.25,1403.89 1869.25,1403.89 1869.25,1403.89 1869.26,1403.89 1869.26,1403.89 1869.26,1403.89 1869.26,1403.89 1869.27,1403.89 1869.27,1403.89 1869.27,1403.89 1869.27,1403.89 1869.28,1403.89 1869.28,1403.89 1869.28,1403.89 1869.29,1403.89 1869.29,1403.89 1869.29,1403.89 1869.29,1403.89 1869.3,1403.89 1869.3,1403.89 1869.3,1403.89 1869.3,1403.89 1869.31,1403.89 1869.31,1403.89 1869.31,1403.89 1869.31,1403.89 1869.32,1403.89 1869.32,1403.89 1869.32,1403.89 1869.33,1403.89 1869.33,1403.89 1869.33,1403.89 1869.33,1403.89 1869.34,1403.89 1869.34,1403.89 1869.34,1403.89 1869.34,1403.89 1869.35,1403.89 1869.35,1403.89 1869.35,1403.89 1869.36,1403.89 1869.36,1403.89 1869.36,1403.89 1869.36,1403.89 1869.37,1403.89 1869.37,1403.89 1869.37,1403.89 1869.37,1403.89 1869.38,1403.88 1869.38,1403.88 1869.38,1403.88 1869.38,1403.88 1869.39,1403.88 1869.39,1403.88 1869.39,1403.88 1869.4,1403.88 1869.4,1403.88 1869.4,1403.88 1869.4,1403.88 1869.41,1403.88 1869.41,1403.88 1869.41,1403.88 1869.41,1403.88 1869.42,1403.88 1869.42,1403.88 1869.42,1403.88 1869.42,1403.88 1869.43,1403.88 1869.43,1403.88 1869.43,1403.88 1869.44,1403.88 1869.44,1403.88 1869.44,1403.88 1869.44,1403.88 1869.45,1403.88 1869.45,1403.88 1869.45,1403.88 1869.45,1403.88 1869.46,1403.88 1869.46,1403.88 1869.46,1403.88 1869.47,1403.88 1869.47,1403.88 1869.47,1403.88 1869.47,1403.88 1869.48,1403.88 1869.48,1403.88 1869.48,1403.88 1869.48,1403.88 1869.49,1403.88 1869.49,1403.88 1869.49,1403.88 1869.49,1403.88 1869.5,1403.88 1869.5,1403.88 1869.5,1403.88 1869.51,1403.88 1869.51,1403.88 1869.51,1403.88 1869.51,1403.88 1869.52,1403.88 1869.52,1403.88 1869.52,1403.88 1869.52,1403.88 1869.53,1403.88 1869.53,1403.88 1869.53,1403.88 1869.53,1403.88 1869.54,1403.88 1869.54,1403.88 1869.54,1403.88 1869.55,1403.88 1869.55,1403.88 1869.55,1403.88 1869.55,1403.88 1869.56,1403.88 1869.56,1403.88 1869.56,1403.88 1869.56,1403.88 1869.57,1403.88 1869.57,1403.88 1869.57,1403.88 1869.58,1403.88 1869.58,1403.88 1869.58,1403.88 1869.58,1403.88 1869.59,1403.88 1869.59,1403.88 1869.59,1403.88 1869.59,1403.88 1869.6,1403.88 1869.6,1403.88 1869.6,1403.88 1869.6,1403.88 1869.61,1403.88 1869.61,1403.88 1869.61,1403.88 1869.62,1403.88 1869.62,1403.88 1869.62,1403.88 1869.62,1403.88 1869.63,1403.88 1869.63,1403.88 1869.63,1403.88 1869.63,1403.88 1869.64,1403.88 1869.64,1403.88 1869.64,1403.88 1869.64,1403.88 1869.65,1403.88 1869.65,1403.88 1869.65,1403.88 1869.66,1403.88 1869.66,1403.88 1869.66,1403.88 1869.66,1403.88 1869.67,1403.88 1869.67,1403.88 1869.67,1403.88 1869.67,1403.88 1869.68,1403.88 1869.68,1403.88 1869.68,1403.88 1869.68,1403.88 1869.69,1403.88 1869.69,1403.88 1869.69,1403.88 1869.7,1403.88 1869.7,1403.88 1869.7,1403.88 1869.7,1403.88 1869.71,1403.88 1869.71,1403.88 1869.71,1403.88 1869.71,1403.88 1869.72,1403.88 1869.72,1403.88 1869.72,1403.88 1869.73,1403.88 1869.73,1403.88 1869.73,1403.88 1869.73,1403.88 1869.74,1403.88 1869.74,1403.88 1869.74,1403.88 1869.74,1403.88 1869.75,1403.88 1869.75,1403.88 1869.75,1403.88 1869.75,1403.88 1869.76,1403.88 1869.76,1403.88 1869.76,1403.88 1869.77,1403.87 1869.77,1403.87 1869.77,1403.87 1869.77,1403.87 1869.78,1403.87 1869.78,1403.87 1869.78,1403.87 1869.78,1403.87 1869.79,1403.87 1869.79,1403.87 1869.79,1403.87 1869.79,1403.87 1869.8,1403.87 1869.8,1403.87 1869.8,1403.87 1869.81,1403.87 1869.81,1403.87 1869.81,1403.87 1869.81,1403.87 1869.82,1403.87 1869.82,1403.87 1869.82,1403.87 1869.82,1403.87 1869.83,1403.87 1869.83,1403.87 1869.83,1403.87 1869.83,1403.87 1869.84,1403.87 1869.84,1403.87 1869.84,1403.87 1869.85,1403.87 1869.85,1403.87 1869.85,1403.87 1869.85,1403.87 1869.86,1403.87 1869.86,1403.87 1869.86,1403.87 1869.86,1403.87 1869.87,1403.87 1869.87,1403.87 1869.87,1403.87 1869.88,1403.87 1869.88,1403.87 1869.88,1403.87 1869.88,1403.87 1869.89,1403.87 1869.89,1403.87 1869.89,1403.87 1869.89,1403.87 1869.9,1403.87 1869.9,1403.87 1869.9,1403.87 1869.9,1403.87 1869.91,1403.87 1869.91,1403.87 1869.91,1403.87 1869.92,1403.87 1869.92,1403.87 1869.92,1403.87 1869.92,1403.87 1869.93,1403.87 1869.93,1403.87 1869.93,1403.87 1869.93,1403.87 1869.94,1403.87 1869.94,1403.87 1869.94,1403.87 1869.94,1403.87 1869.95,1403.87 1869.95,1403.87 1869.95,1403.87 1869.96,1403.87 1869.96,1403.87 1869.96,1403.87 1869.96,1403.87 1869.97,1403.87 1869.97,1403.87 1869.97,1403.87 1869.97,1403.87 1869.98,1403.87 1869.98,1403.87 1869.98,1403.87 1869.98,1403.87 1869.99,1403.87 1869.99,1403.87 1869.99,1403.87 1870,1403.87 1870,1403.87 1870,1403.87 1870,1403.87 1870.01,1403.87 1870.01,1403.87 1870.01,1403.87 1870.01,1403.87 1870.02,1403.87 1870.02,1403.87 1870.02,1403.87 1870.02,1403.87 1870.03,1403.87 1870.03,1403.87 1870.03,1403.87 1870.04,1403.87 1870.04,1403.87 1870.04,1403.87 1870.04,1403.87 1870.05,1403.87 1870.05,1403.87 1870.05,1403.87 1870.05,1403.87 1870.06,1403.87 1870.06,1403.87 1870.06,1403.87 1870.07,1403.87 1870.07,1403.87 1870.07,1403.87 1870.07,1403.87 1870.08,1403.87 1870.08,1403.87 1870.08,1403.87 1870.08,1403.87 1870.09,1403.87 1870.09,1403.87 1870.09,1403.87 1870.09,1403.87 1870.1,1403.87 1870.1,1403.87 1870.1,1403.87 1870.11,1403.87 1870.11,1403.87 1870.11,1403.87 1870.11,1403.87 1870.12,1403.87 1870.12,1403.87 1870.12,1403.87 1870.12,1403.87 1870.13,1403.87 1870.13,1403.87 1870.13,1403.87 1870.13,1403.87 1870.14,1403.87 1870.14,1403.87 1870.14,1403.87 1870.15,1403.87 1870.15,1403.87 1870.15,1403.87 1870.15,1403.86 1870.16,1403.86 1870.16,1403.86 1870.16,1403.86 1870.16,1403.86 1870.17,1403.86 1870.17,1403.86 1870.17,1403.86 1870.17,1403.86 1870.18,1403.86 1870.18,1403.86 1870.18,1403.86 1870.19,1403.86 1870.19,1403.86 1870.19,1403.86 1870.19,1403.86 1870.2,1403.86 1870.2,1403.86 1870.2,1403.86 1870.2,1403.86 1870.21,1403.86 1870.21,1403.86 1870.21,1403.86 1870.21,1403.86 1870.22,1403.86 1870.22,1403.86 1870.22,1403.86 1870.23,1403.86 1870.23,1403.86 1870.23,1403.86 1870.23,1403.86 1870.24,1403.86 1870.24,1403.86 1870.24,1403.86 1870.24,1403.86 1870.25,1403.86 1870.25,1403.86 1870.25,1403.86 1870.25,1403.86 1870.26,1403.86 1870.26,1403.86 1870.26,1403.86 1870.27,1403.86 1870.27,1403.86 1870.27,1403.86 1870.27,1403.86 1870.28,1403.86 1870.28,1403.86 1870.28,1403.86 1870.28,1403.86 1870.29,1403.86 1870.29,1403.86 1870.29,1403.86 1870.29,1403.86 1870.3,1403.86 1870.3,1403.86 1870.3,1403.86 1870.31,1403.86 1870.31,1403.86 1870.31,1403.86 1870.31,1403.86 1870.32,1403.86 1870.32,1403.86 1870.32,1403.86 1870.32,1403.86 1870.33,1403.86 1870.33,1403.86 1870.33,1403.86 1870.33,1403.86 1870.34,1403.86 1870.34,1403.86 1870.34,1403.86 1870.35,1403.86 1870.35,1403.86 1870.35,1403.86 1870.35,1403.86 1870.36,1403.86 1870.36,1403.86 1870.36,1403.86 1870.36,1403.86 1870.37,1403.86 1870.37,1403.86 1870.37,1403.86 1870.37,1403.86 1870.38,1403.86 1870.38,1403.86 1870.38,1403.86 1870.39,1403.86 1870.39,1403.86 1870.39,1403.86 1870.39,1403.86 1870.4,1403.86 1870.4,1403.86 1870.4,1403.86 1870.4,1403.86 1870.41,1403.86 1870.41,1403.86 1870.41,1403.86 1870.42,1403.86 1870.42,1403.86 1870.42,1403.86 1870.42,1403.86 1870.43,1403.86 1870.43,1403.86 1870.43,1403.86 1870.43,1403.86 1870.44,1403.86 1870.44,1403.86 1870.44,1403.86 1870.44,1403.86 1870.45,1403.86 1870.45,1403.86 1870.45,1403.86 1870.46,1403.86 1870.46,1403.86 1870.46,1403.86 1870.46,1403.86 1870.47,1403.86 1870.47,1403.86 1870.47,1403.86 1870.47,1403.86 1870.48,1403.86 1870.48,1403.86 1870.48,1403.86 1870.48,1403.86 1870.49,1403.86 1870.49,1403.86 1870.49,1403.86 1870.5,1403.86 1870.5,1403.86 1870.5,1403.86 1870.5,1403.86 1870.51,1403.86 1870.51,1403.86 1870.51,1403.86 1870.51,1403.86 1870.52,1403.86 1870.52,1403.86 1870.52,1403.86 1870.52,1403.86 1870.53,1403.86 1870.53,1403.86 1870.53,1403.86 1870.54,1403.86 1870.54,1403.86 1870.54,1403.85 1870.54,1403.85 1870.55,1403.85 1870.55,1403.85 1870.55,1403.85 1870.55,1403.85 1870.56,1403.85 1870.56,1403.85 1870.56,1403.85 1870.56,1403.85 1870.57,1403.85 1870.57,1403.85 1870.57,1403.85 1870.58,1403.85 1870.58,1403.85 1870.58,1403.85 1870.58,1403.85 1870.59,1403.85 1870.59,1403.85 1870.59,1403.85 1870.59,1403.85 1870.6,1403.85 1870.6,1403.85 1870.6,1403.85 1870.6,1403.85 1870.61,1403.85 1870.61,1403.85 1870.61,1403.85 1870.62,1403.85 1870.62,1403.85 1870.62,1403.85 1870.62,1403.85 1870.63,1403.85 1870.63,1403.85 1870.63,1403.85 1870.63,1403.85 1870.64,1403.85 1870.64,1403.85 1870.64,1403.85 1870.64,1403.85 1870.65,1403.85 1870.65,1403.85 1870.65,1403.85 1870.66,1403.85 1870.66,1403.85 1870.66,1403.85 1870.66,1403.85 1870.67,1403.85 1870.67,1403.85 1870.67,1403.85 1870.67,1403.85 1870.68,1403.85 1870.68,1403.85 1870.68,1403.85 1870.68,1403.85 1870.69,1403.85 1870.69,1403.85 1870.69,1403.85 1870.69,1403.85 1870.7,1403.85 1870.7,1403.85 1870.7,1403.85 1870.71,1403.85 1870.71,1403.85 1870.71,1403.85 1870.71,1403.85 1870.72,1403.85 1870.72,1403.85 1870.72,1403.85 1870.72,1403.85 1870.73,1403.85 1870.73,1403.85 1870.73,1403.85 1870.73,1403.85 1870.74,1403.85 1870.74,1403.85 1870.74,1403.85 1870.75,1403.85 1870.75,1403.85 1870.75,1403.85 1870.75,1403.85 1870.76,1403.85 1870.76,1403.85 1870.76,1403.85 1870.76,1403.85 1870.77,1403.85 1870.77,1403.85 1870.77,1403.85 1870.77,1403.85 1870.78,1403.85 1870.78,1403.85 1870.78,1403.85 1870.79,1403.85 1870.79,1403.85 1870.79,1403.85 1870.79,1403.85 1870.8,1403.85 1870.8,1403.85 1870.8,1403.85 1870.8,1403.85 1870.81,1403.85 1870.81,1403.85 1870.81,1403.85 1870.81,1403.85 1870.82,1403.85 1870.82,1403.85 1870.82,1403.85 1870.83,1403.85 1870.83,1403.85 1870.83,1403.85 1870.83,1403.85 1870.84,1403.85 1870.84,1403.85 1870.84,1403.85 1870.84,1403.85 1870.85,1403.85 1870.85,1403.85 1870.85,1403.85 1870.85,1403.85 1870.86,1403.85 1870.86,1403.85 1870.86,1403.85 1870.87,1403.85 1870.87,1403.85 1870.87,1403.85 1870.87,1403.85 1870.88,1403.85 1870.88,1403.85 1870.88,1403.85 1870.88,1403.85 1870.89,1403.85 1870.89,1403.85 1870.89,1403.85 1870.89,1403.85 1870.9,1403.85 1870.9,1403.85 1870.9,1403.85 1870.91,1403.85 1870.91,1403.85 1870.91,1403.85 1870.91,1403.85 1870.92,1403.85 1870.92,1403.85 1870.92,1403.85 1870.92,1403.85 1870.93,1403.85 1870.93,1403.84 1870.93,1403.84 1870.93,1403.84 1870.94,1403.84 1870.94,1403.84 1870.94,1403.84 1870.95,1403.84 1870.95,1403.84 1870.95,1403.84 1870.95,1403.84 1870.96,1403.84 1870.96,1403.84 1870.96,1403.84 1870.96,1403.84 1870.97,1403.84 1870.97,1403.84 1870.97,1403.84 1870.97,1403.84 1870.98,1403.84 1870.98,1403.84 1870.98,1403.84 1870.99,1403.84 1870.99,1403.84 1870.99,1403.84 1870.99,1403.84 1871,1403.84 1871,1403.84 1871,1403.84 1871,1403.84 1871.01,1403.84 1871.01,1403.84 1871.01,1403.84 1871.01,1403.84 1871.02,1403.84 1871.02,1403.84 1871.02,1403.84 1871.03,1403.84 1871.03,1403.84 1871.03,1403.84 1871.03,1403.84 1871.04,1403.84 1871.04,1403.84 1871.04,1403.84 1871.04,1403.84 1871.05,1403.84 1871.05,1403.84 1871.05,1403.84 1871.05,1403.84 1871.06,1403.84 1871.06,1403.84 1871.06,1403.84 1871.06,1403.84 1871.07,1403.84 1871.07,1403.84 1871.07,1403.84 1871.08,1403.84 1871.08,1403.84 1871.08,1403.84 1871.08,1403.84 1871.09,1403.84 1871.09,1403.84 1871.09,1403.84 1871.09,1403.84 1871.1,1403.84 1871.1,1403.84 1871.1,1403.84 1871.1,1403.84 1871.11,1403.84 1871.11,1403.84 1871.11,1403.84 1871.12,1403.84 1871.12,1403.84 1871.12,1403.84 1871.12,1403.84 1871.13,1403.84 1871.13,1403.84 1871.13,1403.84 1871.13,1403.84 1871.14,1403.84 1871.14,1403.84 1871.14,1403.84 1871.14,1403.84 1871.15,1403.84 1871.15,1403.84 1871.15,1403.84 1871.16,1403.84 1871.16,1403.84 1871.16,1403.84 1871.16,1403.84 1871.17,1403.84 1871.17,1403.84 1871.17,1403.84 1871.17,1403.84 1871.18,1403.84 1871.18,1403.84 1871.18,1403.84 1871.18,1403.84 1871.19,1403.84 1871.19,1403.84 1871.19,1403.84 1871.2,1403.84 1871.2,1403.84 1871.2,1403.84 1871.2,1403.84 1871.21,1403.84 1871.21,1403.84 1871.21,1403.84 1871.21,1403.84 1871.22,1403.84 1871.22,1403.84 1871.22,1403.84 1871.22,1403.84 1871.23,1403.84 1871.23,1403.84 1871.23,1403.84 1871.24,1403.84 1871.24,1403.84 1871.24,1403.84 1871.24,1403.84 1871.25,1403.84 1871.25,1403.84 1871.25,1403.84 1871.25,1403.84 1871.26,1403.84 1871.26,1403.84 1871.26,1403.84 1871.26,1403.84 1871.27,1403.84 1871.27,1403.84 1871.27,1403.84 1871.27,1403.84 1871.28,1403.84 1871.28,1403.84 1871.28,1403.84 1871.29,1403.84 1871.29,1403.84 1871.29,1403.84 1871.29,1403.84 1871.3,1403.84 1871.3,1403.84 1871.3,1403.84 1871.3,1403.84 1871.31,1403.84 1871.31,1403.84 1871.31,1403.84 1871.31,1403.84 1871.32,1403.83 1871.32,1403.83 1871.32,1403.83 1871.33,1403.83 1871.33,1403.83 1871.33,1403.83 1871.33,1403.83 1871.34,1403.83 1871.34,1403.83 1871.34,1403.83 1871.34,1403.83 1871.35,1403.83 1871.35,1403.83 1871.35,1403.83 1871.35,1403.83 1871.36,1403.83 1871.36,1403.83 1871.36,1403.83 1871.37,1403.83 1871.37,1403.83 1871.37,1403.83 1871.37,1403.83 1871.38,1403.83 1871.38,1403.83 1871.38,1403.83 1871.38,1403.83 1871.39,1403.83 1871.39,1403.83 1871.39,1403.83 1871.39,1403.83 1871.4,1403.83 1871.4,1403.83 1871.4,1403.83 1871.4,1403.83 1871.41,1403.83 1871.41,1403.83 1871.41,1403.83 1871.42,1403.83 1871.42,1403.83 1871.42,1403.83 1871.42,1403.83 1871.43,1403.83 1871.43,1403.83 1871.43,1403.83 1871.43,1403.83 1871.44,1403.83 1871.44,1403.83 1871.44,1403.83 1871.44,1403.83 1871.45,1403.83 1871.45,1403.83 1871.45,1403.83 1871.46,1403.83 1871.46,1403.83 1871.46,1403.83 1871.46,1403.83 1871.47,1403.83 1871.47,1403.83 1871.47,1403.83 1871.47,1403.83 1871.48,1403.83 1871.48,1403.83 1871.48,1403.83 1871.48,1403.83 1871.49,1403.83 1871.49,1403.83 1871.49,1403.83 1871.5,1403.83 1871.5,1403.83 1871.5,1403.83 1871.5,1403.83 1871.51,1403.83 1871.51,1403.83 1871.51,1403.83 1871.51,1403.83 1871.52,1403.83 1871.52,1403.83 1871.52,1403.83 1871.52,1403.83 1871.53,1403.83 1871.53,1403.83 1871.53,1403.83 1871.53,1403.83 1871.54,1403.83 1871.54,1403.83 1871.54,1403.83 1871.55,1403.83 1871.55,1403.83 1871.55,1403.83 1871.55,1403.83 1871.56,1403.83 1871.56,1403.83 1871.56,1403.83 1871.56,1403.83 1871.57,1403.83 1871.57,1403.83 1871.57,1403.83 1871.57,1403.83 1871.58,1403.83 1871.58,1403.83 1871.58,1403.83 1871.59,1403.83 1871.59,1403.83 1871.59,1403.83 1871.59,1403.83 1871.6,1403.83 1871.6,1403.83 1871.6,1403.83 1871.6,1403.83 1871.61,1403.83 1871.61,1403.83 1871.61,1403.83 1871.61,1403.83 1871.62,1403.83 1871.62,1403.83 1871.62,1403.83 1871.63,1403.83 1871.63,1403.83 1871.63,1403.83 1871.63,1403.83 1871.64,1403.83 1871.64,1403.83 1871.64,1403.83 1871.64,1403.83 1871.65,1403.83 1871.65,1403.83 1871.65,1403.83 1871.65,1403.83 1871.66,1403.83 1871.66,1403.83 1871.66,1403.83 1871.66,1403.83 1871.67,1403.83 1871.67,1403.83 1871.67,1403.83 1871.68,1403.83 1871.68,1403.83 1871.68,1403.83 1871.68,1403.83 1871.69,1403.83 1871.69,1403.83 1871.69,1403.83 1871.69,1403.83 1871.7,1403.83 1871.7,1403.83 1871.7,1403.83 1871.7,1403.82 1871.71,1403.82 1871.71,1403.82 1871.71,1403.82 1871.72,1403.82 1871.72,1403.82 1871.72,1403.82 1871.72,1403.82 1871.73,1403.82 1871.73,1403.82 1871.73,1403.82 1871.73,1403.82 1871.74,1403.82 1871.74,1403.82 1871.74,1403.82 1871.74,1403.82 1871.75,1403.82 1871.75,1403.82 1871.75,1403.82 1871.75,1403.82 1871.76,1403.82 1871.76,1403.82 1871.76,1403.82 1871.77,1403.82 1871.77,1403.82 1871.77,1403.82 1871.77,1403.82 1871.78,1403.82 1871.78,1403.82 1871.78,1403.82 1871.78,1403.82 1871.79,1403.82 1871.79,1403.82 1871.79,1403.82 1871.79,1403.82 1871.8,1403.82 1871.8,1403.82 1871.8,1403.82 1871.81,1403.82 1871.81,1403.82 1871.81,1403.82 1871.81,1403.82 1871.82,1403.82 1871.82,1403.82 1871.82,1403.82 1871.82,1403.82 1871.83,1403.82 1871.83,1403.82 1871.83,1403.82 1871.83,1403.82 1871.84,1403.82 1871.84,1403.82 1871.84,1403.82 1871.84,1403.82 1871.85,1403.82 1871.85,1403.82 1871.85,1403.82 1871.86,1403.82 1871.86,1403.82 1871.86,1403.82 1871.86,1403.82 1871.87,1403.82 1871.87,1403.82 1871.87,1403.82 1871.87,1403.82 1871.88,1403.82 1871.88,1403.82 1871.88,1403.82 1871.88,1403.82 1871.89,1403.82 1871.89,1403.82 1871.89,1403.82 1871.9,1403.82 1871.9,1403.82 1871.9,1403.82 1871.9,1403.82 1871.91,1403.82 1871.91,1403.82 1871.91,1403.82 1871.91,1403.82 1871.92,1403.82 1871.92,1403.82 1871.92,1403.82 1871.92,1403.82 1871.93,1403.82 1871.93,1403.82 1871.93,1403.82 1871.93,1403.82 1871.94,1403.82 1871.94,1403.82 1871.94,1403.82 1871.95,1403.82 1871.95,1403.82 1871.95,1403.82 1871.95,1403.82 1871.96,1403.82 1871.96,1403.82 1871.96,1403.82 1871.96,1403.82 1871.97,1403.82 1871.97,1403.82 1871.97,1403.82 1871.97,1403.82 1871.98,1403.82 1871.98,1403.82 1871.98,1403.82 1871.99,1403.82 1871.99,1403.82 1871.99,1403.82 1871.99,1403.82 1872,1403.82 1872,1403.82 1872,1403.82 1872,1403.82 1872.01,1403.82 1872.01,1403.82 1872.01,1403.82 1872.01,1403.82 1872.02,1403.82 1872.02,1403.82 1872.02,1403.82 1872.02,1403.82 1872.03,1403.82 1872.03,1403.82 1872.03,1403.82 1872.04,1403.82 1872.04,1403.82 1872.04,1403.82 1872.04,1403.82 1872.05,1403.82 1872.05,1403.82 1872.05,1403.82 1872.05,1403.82 1872.06,1403.82 1872.06,1403.82 1872.06,1403.82 1872.06,1403.82 1872.07,1403.82 1872.07,1403.82 1872.07,1403.82 1872.08,1403.82 1872.08,1403.82 1872.08,1403.82 1872.08,1403.82 1872.09,1403.82 1872.09,1403.82 1872.09,1403.81 1872.09,1403.81 1872.1,1403.81 1872.1,1403.81 1872.1,1403.81 1872.1,1403.81 1872.11,1403.81 1872.11,1403.81 1872.11,1403.81 1872.11,1403.81 1872.12,1403.81 1872.12,1403.81 1872.12,1403.81 1872.13,1403.81 1872.13,1403.81 1872.13,1403.81 1872.13,1403.81 1872.14,1403.81 1872.14,1403.81 1872.14,1403.81 1872.14,1403.81 1872.15,1403.81 1872.15,1403.81 1872.15,1403.81 1872.15,1403.81 1872.16,1403.81 1872.16,1403.81 1872.16,1403.81 1872.16,1403.81 1872.17,1403.81 1872.17,1403.81 1872.17,1403.81 1872.18,1403.81 1872.18,1403.81 1872.18,1403.81 1872.18,1403.81 1872.19,1403.81 1872.19,1403.81 1872.19,1403.81 1872.19,1403.81 1872.2,1403.81 1872.2,1403.81 1872.2,1403.81 1872.2,1403.81 1872.21,1403.81 1872.21,1403.81 1872.21,1403.81 1872.22,1403.81 1872.22,1403.81 1872.22,1403.81 1872.22,1403.81 1872.23,1403.81 1872.23,1403.81 1872.23,1403.81 1872.23,1403.81 1872.24,1403.81 1872.24,1403.81 1872.24,1403.81 1872.24,1403.81 1872.25,1403.81 1872.25,1403.81 1872.25,1403.81 1872.25,1403.81 1872.26,1403.81 1872.26,1403.81 1872.26,1403.81 1872.27,1403.81 1872.27,1403.81 1872.27,1403.81 1872.27,1403.81 1872.28,1403.81 1872.28,1403.81 1872.28,1403.81 1872.28,1403.81 1872.29,1403.81 1872.29,1403.81 1872.29,1403.81 1872.29,1403.81 1872.3,1403.81 1872.3,1403.81 1872.3,1403.81 1872.3,1403.81 1872.31,1403.81 1872.31,1403.81 1872.31,1403.81 1872.32,1403.81 1872.32,1403.81 1872.32,1403.81 1872.32,1403.81 1872.33,1403.81 1872.33,1403.81 1872.33,1403.81 1872.33,1403.81 1872.34,1403.81 1872.34,1403.81 1872.34,1403.81 1872.34,1403.81 1872.35,1403.81 1872.35,1403.81 1872.35,1403.81 1872.36,1403.81 1872.36,1403.81 1872.36,1403.81 1872.36,1403.81 1872.37,1403.81 1872.37,1403.81 1872.37,1403.81 1872.37,1403.81 1872.38,1403.81 1872.38,1403.81 1872.38,1403.81 1872.38,1403.81 1872.39,1403.81 1872.39,1403.81 1872.39,1403.81 1872.39,1403.81 1872.4,1403.81 1872.4,1403.81 1872.4,1403.81 1872.41,1403.81 1872.41,1403.81 1872.41,1403.81 1872.41,1403.81 1872.42,1403.81 1872.42,1403.81 1872.42,1403.81 1872.42,1403.81 1872.43,1403.81 1872.43,1403.81 1872.43,1403.81 1872.43,1403.81 1872.44,1403.81 1872.44,1403.81 1872.44,1403.81 1872.44,1403.81 1872.45,1403.81 1872.45,1403.81 1872.45,1403.81 1872.46,1403.81 1872.46,1403.81 1872.46,1403.81 1872.46,1403.81 1872.47,1403.81 1872.47,1403.81 1872.47,1403.81 1872.47,1403.81 1872.48,1403.81 1872.48,1403.8 1872.48,1403.8 1872.48,1403.8 1872.49,1403.8 1872.49,1403.8 1872.49,1403.8 1872.5,1403.8 1872.5,1403.8 1872.5,1403.8 1872.5,1403.8 1872.51,1403.8 1872.51,1403.8 1872.51,1403.8 1872.51,1403.8 1872.52,1403.8 1872.52,1403.8 1872.52,1403.8 1872.52,1403.8 1872.53,1403.8 1872.53,1403.8 1872.53,1403.8 1872.53,1403.8 1872.54,1403.8 1872.54,1403.8 1872.54,1403.8 1872.55,1403.8 1872.55,1403.8 1872.55,1403.8 1872.55,1403.8 1872.56,1403.8 1872.56,1403.8 1872.56,1403.8 1872.56,1403.8 1872.57,1403.8 1872.57,1403.8 1872.57,1403.8 1872.57,1403.8 1872.58,1403.8 1872.58,1403.8 1872.58,1403.8 1872.58,1403.8 1872.59,1403.8 1872.59,1403.8 1872.59,1403.8 1872.6,1403.8 1872.6,1403.8 1872.6,1403.8 1872.6,1403.8 1872.61,1403.8 1872.61,1403.8 1872.61,1403.8 1872.61,1403.8 1872.62,1403.8 1872.62,1403.8 1872.62,1403.8 1872.62,1403.8 1872.63,1403.8 1872.63,1403.8 1872.63,1403.8 1872.63,1403.8 1872.64,1403.8 1872.64,1403.8 1872.64,1403.8 1872.65,1403.8 1872.65,1403.8 1872.65,1403.8 1872.65,1403.8 1872.66,1403.8 1872.66,1403.8 1872.66,1403.8 1872.66,1403.8 1872.67,1403.8 1872.67,1403.8 1872.67,1403.8 1872.67,1403.8 1872.68,1403.8 1872.68,1403.8 1872.68,1403.8 1872.68,1403.8 1872.69,1403.8 1872.69,1403.8 1872.69,1403.8 1872.7,1403.8 1872.7,1403.8 1872.7,1403.8 1872.7,1403.8 1872.71,1403.8 1872.71,1403.8 1872.71,1403.8 1872.71,1403.8 1872.72,1403.8 1872.72,1403.8 1872.72,1403.8 1872.72,1403.8 1872.73,1403.8 1872.73,1403.8 1872.73,1403.8 1872.73,1403.8 1872.74,1403.8 1872.74,1403.8 1872.74,1403.8 1872.75,1403.8 1872.75,1403.8 1872.75,1403.8 1872.75,1403.8 1872.76,1403.8 1872.76,1403.8 1872.76,1403.8 1872.76,1403.8 1872.77,1403.8 1872.77,1403.8 1872.77,1403.8 1872.77,1403.8 1872.78,1403.8 1872.78,1403.8 1872.78,1403.8 1872.78,1403.8 1872.79,1403.8 1872.79,1403.8 1872.79,1403.8 1872.8,1403.8 1872.8,1403.8 1872.8,1403.8 1872.8,1403.8 1872.81,1403.8 1872.81,1403.8 1872.81,1403.8 1872.81,1403.8 1872.82,1403.8 1872.82,1403.8 1872.82,1403.8 1872.82,1403.8 1872.83,1403.8 1872.83,1403.8 1872.83,1403.8 1872.83,1403.8 1872.84,1403.8 1872.84,1403.8 1872.84,1403.8 1872.85,1403.8 1872.85,1403.8 1872.85,1403.8 1872.85,1403.8 1872.86,1403.8 1872.86,1403.8 1872.86,1403.8 1872.86,1403.8 1872.87,1403.79 1872.87,1403.79 1872.87,1403.79 1872.87,1403.79 1872.88,1403.79 1872.88,1403.79 1872.88,1403.79 1872.89,1403.79 1872.89,1403.79 1872.89,1403.79 1872.89,1403.79 1872.9,1403.79 1872.9,1403.79 1872.9,1403.79 1872.9,1403.79 1872.91,1403.79 1872.91,1403.79 1872.91,1403.79 1872.91,1403.79 1872.92,1403.79 1872.92,1403.79 1872.92,1403.79 1872.92,1403.79 1872.93,1403.79 1872.93,1403.79 1872.93,1403.79 1872.94,1403.79 1872.94,1403.79 1872.94,1403.79 1872.94,1403.79 1872.95,1403.79 1872.95,1403.79 1872.95,1403.79 1872.95,1403.79 1872.96,1403.79 1872.96,1403.79 1872.96,1403.79 1872.96,1403.79 1872.97,1403.79 1872.97,1403.79 1872.97,1403.79 1872.97,1403.79 1872.98,1403.79 1872.98,1403.79 1872.98,1403.79 1872.99,1403.79 1872.99,1403.79 1872.99,1403.79 1872.99,1403.79 1873,1403.79 1873,1403.79 1873,1403.79 1873,1403.79 1873.01,1403.79 1873.01,1403.79 1873.01,1403.79 1873.01,1403.79 1873.02,1403.79 1873.02,1403.79 1873.02,1403.79 1873.02,1403.79 1873.03,1403.79 1873.03,1403.79 1873.03,1403.79 1873.03,1403.79 1873.04,1403.79 1873.04,1403.79 1873.04,1403.79 1873.05,1403.79 1873.05,1403.79 1873.05,1403.79 1873.05,1403.79 1873.06,1403.79 1873.06,1403.79 1873.06,1403.79 1873.06,1403.79 1873.07,1403.79 1873.07,1403.79 1873.07,1403.79 1873.07,1403.79 1873.08,1403.79 1873.08,1403.79 1873.08,1403.79 1873.08,1403.79 1873.09,1403.79 1873.09,1403.79 1873.09,1403.79 1873.1,1403.79 1873.1,1403.79 1873.1,1403.79 1873.1,1403.79 1873.11,1403.79 1873.11,1403.79 1873.11,1403.79 1873.11,1403.79 1873.12,1403.79 1873.12,1403.79 1873.12,1403.79 1873.12,1403.79 1873.13,1403.79 1873.13,1403.79 1873.13,1403.79 1873.13,1403.79 1873.14,1403.79 1873.14,1403.79 1873.14,1403.79 1873.15,1403.79 1873.15,1403.79 1873.15,1403.79 1873.15,1403.79 1873.16,1403.79 1873.16,1403.79 1873.16,1403.79 1873.16,1403.79 1873.17,1403.79 1873.17,1403.79 1873.17,1403.79 1873.17,1403.79 1873.18,1403.79 1873.18,1403.79 1873.18,1403.79 1873.18,1403.79 1873.19,1403.79 1873.19,1403.79 1873.19,1403.79 1873.2,1403.79 1873.2,1403.79 1873.2,1403.79 1873.2,1403.79 1873.21,1403.79 1873.21,1403.79 1873.21,1403.79 1873.21,1403.79 1873.22,1403.79 1873.22,1403.79 1873.22,1403.79 1873.22,1403.79 1873.23,1403.79 1873.23,1403.79 1873.23,1403.79 1873.23,1403.79 1873.24,1403.79 1873.24,1403.79 1873.24,1403.79 1873.25,1403.79 1873.25,1403.79 1873.25,1403.79 1873.25,1403.79 1873.26,1403.78 1873.26,1403.78 1873.26,1403.78 1873.26,1403.78 1873.27,1403.78 1873.27,1403.78 1873.27,1403.78 1873.27,1403.78 1873.28,1403.78 1873.28,1403.78 1873.28,1403.78 1873.28,1403.78 1873.29,1403.78 1873.29,1403.78 1873.29,1403.78 1873.3,1403.78 1873.3,1403.78 1873.3,1403.78 1873.3,1403.78 1873.31,1403.78 1873.31,1403.78 1873.31,1403.78 1873.31,1403.78 1873.32,1403.78 1873.32,1403.78 1873.32,1403.78 1873.32,1403.78 1873.33,1403.78 1873.33,1403.78 1873.33,1403.78 1873.33,1403.78 1873.34,1403.78 1873.34,1403.78 1873.34,1403.78 1873.35,1403.78 1873.35,1403.78 1873.35,1403.78 1873.35,1403.78 1873.36,1403.78 1873.36,1403.78 1873.36,1403.78 1873.36,1403.78 1873.37,1403.78 1873.37,1403.78 1873.37,1403.78 1873.37,1403.78 1873.38,1403.78 1873.38,1403.78 1873.38,1403.78 1873.38,1403.78 1873.39,1403.78 1873.39,1403.78 1873.39,1403.78 1873.39,1403.78 1873.4,1403.78 1873.4,1403.78 1873.4,1403.78 1873.41,1403.78 1873.41,1403.78 1873.41,1403.78 1873.41,1403.78 1873.42,1403.78 1873.42,1403.78 1873.42,1403.78 1873.42,1403.78 1873.43,1403.78 1873.43,1403.78 1873.43,1403.78 1873.43,1403.78 1873.44,1403.78 1873.44,1403.78 1873.44,1403.78 1873.44,1403.78 1873.45,1403.78 1873.45,1403.78 1873.45,1403.78 1873.46,1403.78 1873.46,1403.78 1873.46,1403.78 1873.46,1403.78 1873.47,1403.78 1873.47,1403.78 1873.47,1403.78 1873.47,1403.78 1873.48,1403.78 1873.48,1403.78 1873.48,1403.78 1873.48,1403.78 1873.49,1403.78 1873.49,1403.78 1873.49,1403.78 1873.49,1403.78 1873.5,1403.78 1873.5,1403.78 1873.5,1403.78 1873.51,1403.78 1873.51,1403.78 1873.51,1403.78 1873.51,1403.78 1873.52,1403.78 1873.52,1403.78 1873.52,1403.78 1873.52,1403.78 1873.53,1403.78 1873.53,1403.78 1873.53,1403.78 1873.53,1403.78 1873.54,1403.78 1873.54,1403.78 1873.54,1403.78 1873.54,1403.78 1873.55,1403.78 1873.55,1403.78 1873.55,1403.78 1873.56,1403.78 1873.56,1403.78 1873.56,1403.78 1873.56,1403.78 1873.57,1403.78 1873.57,1403.78 1873.57,1403.78 1873.57,1403.78 1873.58,1403.78 1873.58,1403.78 1873.58,1403.78 1873.58,1403.78 1873.59,1403.78 1873.59,1403.78 1873.59,1403.78 1873.59,1403.78 1873.6,1403.78 1873.6,1403.78 1873.6,1403.78 1873.6,1403.78 1873.61,1403.78 1873.61,1403.78 1873.61,1403.78 1873.62,1403.78 1873.62,1403.78 1873.62,1403.78 1873.62,1403.78 1873.63,1403.78 1873.63,1403.78 1873.63,1403.78 1873.63,1403.78 1873.64,1403.78 1873.64,1403.78 1873.64,1403.77 1873.64,1403.77 1873.65,1403.77 1873.65,1403.77 1873.65,1403.77 1873.65,1403.77 1873.66,1403.77 1873.66,1403.77 1873.66,1403.77 1873.67,1403.77 1873.67,1403.77 1873.67,1403.77 1873.67,1403.77 1873.68,1403.77 1873.68,1403.77 1873.68,1403.77 1873.68,1403.77 1873.69,1403.77 1873.69,1403.77 1873.69,1403.77 1873.69,1403.77 1873.7,1403.77 1873.7,1403.77 1873.7,1403.77 1873.7,1403.77 1873.71,1403.77 1873.71,1403.77 1873.71,1403.77 1873.71,1403.77 1873.72,1403.77 1873.72,1403.77 1873.72,1403.77 1873.73,1403.77 1873.73,1403.77 1873.73,1403.77 1873.73,1403.77 1873.74,1403.77 1873.74,1403.77 1873.74,1403.77 1873.74,1403.77 1873.75,1403.77 1873.75,1403.77 1873.75,1403.77 1873.75,1403.77 1873.76,1403.77 1873.76,1403.77 1873.76,1403.77 1873.76,1403.77 1873.77,1403.77 1873.77,1403.77 1873.77,1403.77 1873.78,1403.77 1873.78,1403.77 1873.78,1403.77 1873.78,1403.77 1873.79,1403.77 1873.79,1403.77 1873.79,1403.77 1873.79,1403.77 1873.8,1403.77 1873.8,1403.77 1873.8,1403.77 1873.8,1403.77 1873.81,1403.77 1873.81,1403.77 1873.81,1403.77 1873.81,1403.77 1873.82,1403.77 1873.82,1403.77 1873.82,1403.77 1873.83,1403.77 1873.83,1403.77 1873.83,1403.77 1873.83,1403.77 1873.84,1403.77 1873.84,1403.77 1873.84,1403.77 1873.84,1403.77 1873.85,1403.77 1873.85,1403.77 1873.85,1403.77 1873.85,1403.77 1873.86,1403.77 1873.86,1403.77 1873.86,1403.77 1873.86,1403.77 1873.87,1403.77 1873.87,1403.77 1873.87,1403.77 1873.87,1403.77 1873.88,1403.77 1873.88,1403.77 1873.88,1403.77 1873.89,1403.77 1873.89,1403.77 1873.89,1403.77 1873.89,1403.77 1873.9,1403.77 1873.9,1403.77 1873.9,1403.77 1873.9,1403.77 1873.91,1403.77 1873.91,1403.77 1873.91,1403.77 1873.91,1403.77 1873.92,1403.77 1873.92,1403.77 1873.92,1403.77 1873.92,1403.77 1873.93,1403.77 1873.93,1403.77 1873.93,1403.77 1873.94,1403.77 1873.94,1403.77 1873.94,1403.77 1873.94,1403.77 1873.95,1403.77 1873.95,1403.77 1873.95,1403.77 1873.95,1403.77 1873.96,1403.77 1873.96,1403.77 1873.96,1403.77 1873.96,1403.77 1873.97,1403.77 1873.97,1403.77 1873.97,1403.77 1873.97,1403.77 1873.98,1403.77 1873.98,1403.77 1873.98,1403.77 1873.98,1403.77 1873.99,1403.77 1873.99,1403.77 1873.99,1403.77 1874,1403.77 1874,1403.77 1874,1403.77 1874,1403.77 1874.01,1403.77 1874.01,1403.77 1874.01,1403.77 1874.01,1403.77 1874.02,1403.77 1874.02,1403.77 1874.02,1403.77 1874.02,1403.77 1874.03,1403.77 1874.03,1403.76 1874.03,1403.76 1874.03,1403.76 1874.04,1403.76 1874.04,1403.76 1874.04,1403.76 1874.04,1403.76 1874.05,1403.76 1874.05,1403.76 1874.05,1403.76 1874.06,1403.76 1874.06,1403.76 1874.06,1403.76 1874.06,1403.76 1874.07,1403.76 1874.07,1403.76 1874.07,1403.76 1874.07,1403.76 1874.08,1403.76 1874.08,1403.76 1874.08,1403.76 1874.08,1403.76 1874.09,1403.76 1874.09,1403.76 1874.09,1403.76 1874.09,1403.76 1874.1,1403.76 1874.1,1403.76 1874.1,1403.76 1874.11,1403.76 1874.11,1403.76 1874.11,1403.76 1874.11,1403.76 1874.12,1403.76 1874.12,1403.76 1874.12,1403.76 1874.12,1403.76 1874.13,1403.76 1874.13,1403.76 1874.13,1403.76 1874.13,1403.76 1874.14,1403.76 1874.14,1403.76 1874.14,1403.76 1874.14,1403.76 1874.15,1403.76 1874.15,1403.76 1874.15,1403.76 1874.15,1403.76 1874.16,1403.76 1874.16,1403.76 1874.16,1403.76 1874.17,1403.76 1874.17,1403.76 1874.17,1403.76 1874.17,1403.76 1874.18,1403.76 1874.18,1403.76 1874.18,1403.76 1874.18,1403.76 1874.19,1403.76 1874.19,1403.76 1874.19,1403.76 1874.19,1403.76 1874.2,1403.76 1874.2,1403.76 1874.2,1403.76 1874.2,1403.76 1874.21,1403.76 1874.21,1403.76 1874.21,1403.76 1874.21,1403.76 1874.22,1403.76 1874.22,1403.76 1874.22,1403.76 1874.23,1403.76 1874.23,1403.76 1874.23,1403.76 1874.23,1403.76 1874.24,1403.76 1874.24,1403.76 1874.24,1403.76 1874.24,1403.76 1874.25,1403.76 1874.25,1403.76 1874.25,1403.76 1874.25,1403.76 1874.26,1403.76 1874.26,1403.76 1874.26,1403.76 1874.26,1403.76 1874.27,1403.76 1874.27,1403.76 1874.27,1403.76 1874.28,1403.76 1874.28,1403.76 1874.28,1403.76 1874.28,1403.76 1874.29,1403.76 1874.29,1403.76 1874.29,1403.76 1874.29,1403.76 1874.3,1403.76 1874.3,1403.76 1874.3,1403.76 1874.3,1403.76 1874.31,1403.76 1874.31,1403.76 1874.31,1403.76 1874.31,1403.76 1874.32,1403.76 1874.32,1403.76 1874.32,1403.76 1874.32,1403.76 1874.33,1403.76 1874.33,1403.76 1874.33,1403.76 1874.34,1403.76 1874.34,1403.76 1874.34,1403.76 1874.34,1403.76 1874.35,1403.76 1874.35,1403.76 1874.35,1403.76 1874.35,1403.76 1874.36,1403.76 1874.36,1403.76 1874.36,1403.76 1874.36,1403.76 1874.37,1403.76 1874.37,1403.76 1874.37,1403.76 1874.37,1403.76 1874.38,1403.76 1874.38,1403.76 1874.38,1403.76 1874.38,1403.76 1874.39,1403.76 1874.39,1403.76 1874.39,1403.76 1874.4,1403.76 1874.4,1403.76 1874.4,1403.76 1874.4,1403.76 1874.41,1403.76 1874.41,1403.76 1874.41,1403.76 1874.41,1403.76 1874.42,1403.76 1874.42,1403.75 1874.42,1403.75 1874.42,1403.75 1874.43,1403.75 1874.43,1403.75 1874.43,1403.75 1874.43,1403.75 1874.44,1403.75 1874.44,1403.75 1874.44,1403.75 1874.44,1403.75 1874.45,1403.75 1874.45,1403.75 1874.45,1403.75 1874.46,1403.75 1874.46,1403.75 1874.46,1403.75 1874.46,1403.75 1874.47,1403.75 1874.47,1403.75 1874.47,1403.75 1874.47,1403.75 1874.48,1403.75 1874.48,1403.75 1874.48,1403.75 1874.48,1403.75 1874.49,1403.75 1874.49,1403.75 1874.49,1403.75 1874.49,1403.75 1874.5,1403.75 1874.5,1403.75 1874.5,1403.75 1874.5,1403.75 1874.51,1403.75 1874.51,1403.75 1874.51,1403.75 1874.52,1403.75 1874.52,1403.75 1874.52,1403.75 1874.52,1403.75 1874.53,1403.75 1874.53,1403.75 1874.53,1403.75 1874.53,1403.75 1874.54,1403.75 1874.54,1403.75 1874.54,1403.75 1874.54,1403.75 1874.55,1403.75 1874.55,1403.75 1874.55,1403.75 1874.55,1403.75 1874.56,1403.75 1874.56,1403.75 1874.56,1403.75 1874.56,1403.75 1874.57,1403.75 1874.57,1403.75 1874.57,1403.75 1874.58,1403.75 1874.58,1403.75 1874.58,1403.75 1874.58,1403.75 1874.59,1403.75 1874.59,1403.75 1874.59,1403.75 1874.59,1403.75 1874.6,1403.75 1874.6,1403.75 1874.6,1403.75 1874.6,1403.75 1874.61,1403.75 1874.61,1403.75 1874.61,1403.75 1874.61,1403.75 1874.62,1403.75 1874.62,1403.75 1874.62,1403.75 1874.62,1403.75 1874.63,1403.75 1874.63,1403.75 1874.63,1403.75 1874.64,1403.75 1874.64,1403.75 1874.64,1403.75 1874.64,1403.75 1874.65,1403.75 1874.65,1403.75 1874.65,1403.75 1874.65,1403.75 1874.66,1403.75 1874.66,1403.75 1874.66,1403.75 1874.66,1403.75 1874.67,1403.75 1874.67,1403.75 1874.67,1403.75 1874.67,1403.75 1874.68,1403.75 1874.68,1403.75 1874.68,1403.75 1874.68,1403.75 1874.69,1403.75 1874.69,1403.75 1874.69,1403.75 1874.7,1403.75 1874.7,1403.75 1874.7,1403.75 1874.7,1403.75 1874.71,1403.75 1874.71,1403.75 1874.71,1403.75 1874.71,1403.75 1874.72,1403.75 1874.72,1403.75 1874.72,1403.75 1874.72,1403.75 1874.73,1403.75 1874.73,1403.75 1874.73,1403.75 1874.73,1403.75 1874.74,1403.75 1874.74,1403.75 1874.74,1403.75 1874.74,1403.75 1874.75,1403.75 1874.75,1403.75 1874.75,1403.75 1874.76,1403.75 1874.76,1403.75 1874.76,1403.75 1874.76,1403.75 1874.77,1403.75 1874.77,1403.75 1874.77,1403.75 1874.77,1403.75 1874.78,1403.75 1874.78,1403.75 1874.78,1403.75 1874.78,1403.75 1874.79,1403.75 1874.79,1403.75 1874.79,1403.75 1874.79,1403.75 1874.8,1403.75 1874.8,1403.75 1874.8,1403.75 1874.8,1403.74 1874.81,1403.74 1874.81,1403.74 1874.81,1403.74 1874.82,1403.74 1874.82,1403.74 1874.82,1403.74 1874.82,1403.74 1874.83,1403.74 1874.83,1403.74 1874.83,1403.74 1874.83,1403.74 1874.84,1403.74 1874.84,1403.74 1874.84,1403.74 1874.84,1403.74 1874.85,1403.74 1874.85,1403.74 1874.85,1403.74 1874.85,1403.74 1874.86,1403.74 1874.86,1403.74 1874.86,1403.74 1874.86,1403.74 1874.87,1403.74 1874.87,1403.74 1874.87,1403.74 1874.88,1403.74 1874.88,1403.74 1874.88,1403.74 1874.88,1403.74 1874.89,1403.74 1874.89,1403.74 1874.89,1403.74 1874.89,1403.74 1874.9,1403.74 1874.9,1403.74 1874.9,1403.74 1874.9,1403.74 1874.91,1403.74 1874.91,1403.74 1874.91,1403.74 1874.91,1403.74 1874.92,1403.74 1874.92,1403.74 1874.92,1403.74 1874.92,1403.74 1874.93,1403.74 1874.93,1403.74 1874.93,1403.74 1874.93,1403.74 1874.94,1403.74 1874.94,1403.74 1874.94,1403.74 1874.95,1403.74 1874.95,1403.74 1874.95,1403.74 1874.95,1403.74 1874.96,1403.74 1874.96,1403.74 1874.96,1403.74 1874.96,1403.74 1874.97,1403.74 1874.97,1403.74 1874.97,1403.74 1874.97,1403.74 1874.98,1403.74 1874.98,1403.74 1874.98,1403.74 1874.98,1403.74 1874.99,1403.74 1874.99,1403.74 1874.99,1403.74 1874.99,1403.74 1875,1403.74 1875,1403.74 1875,1403.74 1875.01,1403.74 1875.01,1403.74 1875.01,1403.74 1875.01,1403.74 1875.02,1403.74 1875.02,1403.74 1875.02,1403.74 1875.02,1403.74 1875.03,1403.74 1875.03,1403.74 1875.03,1403.74 1875.03,1403.74 1875.04,1403.74 1875.04,1403.74 1875.04,1403.74 1875.04,1403.74 1875.05,1403.74 1875.05,1403.74 1875.05,1403.74 1875.05,1403.74 1875.06,1403.74 1875.06,1403.74 1875.06,1403.74 1875.07,1403.74 1875.07,1403.74 1875.07,1403.74 1875.07,1403.74 1875.08,1403.74 1875.08,1403.74 1875.08,1403.74 1875.08,1403.74 1875.09,1403.74 1875.09,1403.74 1875.09,1403.74 1875.09,1403.74 1875.1,1403.74 1875.1,1403.74 1875.1,1403.74 1875.1,1403.74 1875.11,1403.74 1875.11,1403.74 1875.11,1403.74 1875.11,1403.74 1875.12,1403.74 1875.12,1403.74 1875.12,1403.74 1875.13,1403.74 1875.13,1403.74 1875.13,1403.74 1875.13,1403.74 1875.14,1403.74 1875.14,1403.74 1875.14,1403.74 1875.14,1403.74 1875.15,1403.74 1875.15,1403.74 1875.15,1403.74 1875.15,1403.74 1875.16,1403.74 1875.16,1403.74 1875.16,1403.74 1875.16,1403.74 1875.17,1403.74 1875.17,1403.74 1875.17,1403.74 1875.17,1403.74 1875.18,1403.74 1875.18,1403.74 1875.18,1403.74 1875.18,1403.74 1875.19,1403.74 1875.19,1403.74 1875.19,1403.73 1875.2,1403.73 1875.2,1403.73 1875.2,1403.73 1875.2,1403.73 1875.21,1403.73 1875.21,1403.73 1875.21,1403.73 1875.21,1403.73 1875.22,1403.73 1875.22,1403.73 1875.22,1403.73 1875.22,1403.73 1875.23,1403.73 1875.23,1403.73 1875.23,1403.73 1875.23,1403.73 1875.24,1403.73 1875.24,1403.73 1875.24,1403.73 1875.24,1403.73 1875.25,1403.73 1875.25,1403.73 1875.25,1403.73 1875.26,1403.73 1875.26,1403.73 1875.26,1403.73 1875.26,1403.73 1875.27,1403.73 1875.27,1403.73 1875.27,1403.73 1875.27,1403.73 1875.28,1403.73 1875.28,1403.73 1875.28,1403.73 1875.28,1403.73 1875.29,1403.73 1875.29,1403.73 1875.29,1403.73 1875.29,1403.73 1875.3,1403.73 1875.3,1403.73 1875.3,1403.73 1875.3,1403.73 1875.31,1403.73 1875.31,1403.73 1875.31,1403.73 1875.31,1403.73 1875.32,1403.73 1875.32,1403.73 1875.32,1403.73 1875.33,1403.73 1875.33,1403.73 1875.33,1403.73 1875.33,1403.73 1875.34,1403.73 1875.34,1403.73 1875.34,1403.73 1875.34,1403.73 1875.35,1403.73 1875.35,1403.73 1875.35,1403.73 1875.35,1403.73 1875.36,1403.73 1875.36,1403.73 1875.36,1403.73 1875.36,1403.73 1875.37,1403.73 1875.37,1403.73 1875.37,1403.73 1875.37,1403.73 1875.38,1403.73 1875.38,1403.73 1875.38,1403.73 1875.39,1403.73 1875.39,1403.73 1875.39,1403.73 1875.39,1403.73 1875.4,1403.73 1875.4,1403.73 1875.4,1403.73 1875.4,1403.73 1875.41,1403.73 1875.41,1403.73 1875.41,1403.73 1875.41,1403.73 1875.42,1403.73 1875.42,1403.73 1875.42,1403.73 1875.42,1403.73 1875.43,1403.73 1875.43,1403.73 1875.43,1403.73 1875.43,1403.73 1875.44,1403.73 1875.44,1403.73 1875.44,1403.73 1875.44,1403.73 1875.45,1403.73 1875.45,1403.73 1875.45,1403.73 1875.46,1403.73 1875.46,1403.73 1875.46,1403.73 1875.46,1403.73 1875.47,1403.73 1875.47,1403.73 1875.47,1403.73 1875.47,1403.73 1875.48,1403.73 1875.48,1403.73 1875.48,1403.73 1875.48,1403.73 1875.49,1403.73 1875.49,1403.73 1875.49,1403.73 1875.49,1403.73 1875.5,1403.73 1875.5,1403.73 1875.5,1403.73 1875.5,1403.73 1875.51,1403.73 1875.51,1403.73 1875.51,1403.73 1875.51,1403.73 1875.52,1403.73 1875.52,1403.73 1875.52,1403.73 1875.53,1403.73 1875.53,1403.73 1875.53,1403.73 1875.53,1403.73 1875.54,1403.73 1875.54,1403.73 1875.54,1403.73 1875.54,1403.73 1875.55,1403.73 1875.55,1403.73 1875.55,1403.73 1875.55,1403.73 1875.56,1403.73 1875.56,1403.73 1875.56,1403.73 1875.56,1403.73 1875.57,1403.73 1875.57,1403.73 1875.57,1403.73 1875.57,1403.73 1875.58,1403.73 1875.58,1403.72 1875.58,1403.72 1875.58,1403.72 1875.59,1403.72 1875.59,1403.72 1875.59,1403.72 1875.6,1403.72 1875.6,1403.72 1875.6,1403.72 1875.6,1403.72 1875.61,1403.72 1875.61,1403.72 1875.61,1403.72 1875.61,1403.72 1875.62,1403.72 1875.62,1403.72 1875.62,1403.72 1875.62,1403.72 1875.63,1403.72 1875.63,1403.72 1875.63,1403.72 1875.63,1403.72 1875.64,1403.72 1875.64,1403.72 1875.64,1403.72 1875.64,1403.72 1875.65,1403.72 1875.65,1403.72 1875.65,1403.72 1875.66,1403.72 1875.66,1403.72 1875.66,1403.72 1875.66,1403.72 1875.67,1403.72 1875.67,1403.72 1875.67,1403.72 1875.67,1403.72 1875.68,1403.72 1875.68,1403.72 1875.68,1403.72 1875.68,1403.72 1875.69,1403.72 1875.69,1403.72 1875.69,1403.72 1875.69,1403.72 1875.7,1403.72 1875.7,1403.72 1875.7,1403.72 1875.7,1403.72 1875.71,1403.72 1875.71,1403.72 1875.71,1403.72 1875.71,1403.72 1875.72,1403.72 1875.72,1403.72 1875.72,1403.72 1875.73,1403.72 1875.73,1403.72 1875.73,1403.72 1875.73,1403.72 1875.74,1403.72 1875.74,1403.72 1875.74,1403.72 1875.74,1403.72 1875.75,1403.72 1875.75,1403.72 1875.75,1403.72 1875.75,1403.72 1875.76,1403.72 1875.76,1403.72 1875.76,1403.72 1875.76,1403.72 1875.77,1403.72 1875.77,1403.72 1875.77,1403.72 1875.77,1403.72 1875.78,1403.72 1875.78,1403.72 1875.78,1403.72 1875.78,1403.72 1875.79,1403.72 1875.79,1403.72 1875.79,1403.72 1875.8,1403.72 1875.8,1403.72 1875.8,1403.72 1875.8,1403.72 1875.81,1403.72 1875.81,1403.72 1875.81,1403.72 1875.81,1403.72 1875.82,1403.72 1875.82,1403.72 1875.82,1403.72 1875.82,1403.72 1875.83,1403.72 1875.83,1403.72 1875.83,1403.72 1875.83,1403.72 1875.84,1403.72 1875.84,1403.72 1875.84,1403.72 1875.84,1403.72 1875.85,1403.72 1875.85,1403.72 1875.85,1403.72 1875.85,1403.72 1875.86,1403.72 1875.86,1403.72 1875.86,1403.72 1875.87,1403.72 1875.87,1403.72 1875.87,1403.72 1875.87,1403.72 1875.88,1403.72 1875.88,1403.72 1875.88,1403.72 1875.88,1403.72 1875.89,1403.72 1875.89,1403.72 1875.89,1403.72 1875.89,1403.72 1875.9,1403.72 1875.9,1403.72 1875.9,1403.72 1875.9,1403.72 1875.91,1403.72 1875.91,1403.72 1875.91,1403.72 1875.91,1403.72 1875.92,1403.72 1875.92,1403.72 1875.92,1403.72 1875.92,1403.72 1875.93,1403.72 1875.93,1403.72 1875.93,1403.72 1875.94,1403.72 1875.94,1403.72 1875.94,1403.72 1875.94,1403.72 1875.95,1403.72 1875.95,1403.72 1875.95,1403.72 1875.95,1403.72 1875.96,1403.72 1875.96,1403.72 1875.96,1403.72 1875.96,1403.72 1875.97,1403.71 1875.97,1403.71 1875.97,1403.71 1875.97,1403.71 1875.98,1403.71 1875.98,1403.71 1875.98,1403.71 1875.98,1403.71 1875.99,1403.71 1875.99,1403.71 1875.99,1403.71 1875.99,1403.71 1876,1403.71 1876,1403.71 1876,1403.71 1876.01,1403.71 1876.01,1403.71 1876.01,1403.71 1876.01,1403.71 1876.02,1403.71 1876.02,1403.71 1876.02,1403.71 1876.02,1403.71 1876.03,1403.71 1876.03,1403.71 1876.03,1403.71 1876.03,1403.71 1876.04,1403.71 1876.04,1403.71 1876.04,1403.71 1876.04,1403.71 1876.05,1403.71 1876.05,1403.71 1876.05,1403.71 1876.05,1403.71 1876.06,1403.71 1876.06,1403.71 1876.06,1403.71 1876.06,1403.71 1876.07,1403.71 1876.07,1403.71 1876.07,1403.71 1876.07,1403.71 1876.08,1403.71 1876.08,1403.71 1876.08,1403.71 1876.09,1403.71 1876.09,1403.71 1876.09,1403.71 1876.09,1403.71 1876.1,1403.71 1876.1,1403.71 1876.1,1403.71 1876.1,1403.71 1876.11,1403.71 1876.11,1403.71 1876.11,1403.71 1876.11,1403.71 1876.12,1403.71 1876.12,1403.71 1876.12,1403.71 1876.12,1403.71 1876.13,1403.71 1876.13,1403.71 1876.13,1403.71 1876.13,1403.71 1876.14,1403.71 1876.14,1403.71 1876.14,1403.71 1876.14,1403.71 1876.15,1403.71 1876.15,1403.71 1876.15,1403.71 1876.16,1403.71 1876.16,1403.71 1876.16,1403.71 1876.16,1403.71 1876.17,1403.71 1876.17,1403.71 1876.17,1403.71 1876.17,1403.71 1876.18,1403.71 1876.18,1403.71 1876.18,1403.71 1876.18,1403.71 1876.19,1403.71 1876.19,1403.71 1876.19,1403.71 1876.19,1403.71 1876.2,1403.71 1876.2,1403.71 1876.2,1403.71 1876.2,1403.71 1876.21,1403.71 1876.21,1403.71 1876.21,1403.71 1876.21,1403.71 1876.22,1403.71 1876.22,1403.71 1876.22,1403.71 1876.23,1403.71 1876.23,1403.71 1876.23,1403.71 1876.23,1403.71 1876.24,1403.71 1876.24,1403.71 1876.24,1403.71 1876.24,1403.71 1876.25,1403.71 1876.25,1403.71 1876.25,1403.71 1876.25,1403.71 1876.26,1403.71 1876.26,1403.71 1876.26,1403.71 1876.26,1403.71 1876.27,1403.71 1876.27,1403.71 1876.27,1403.71 1876.27,1403.71 1876.28,1403.71 1876.28,1403.71 1876.28,1403.71 1876.28,1403.71 1876.29,1403.71 1876.29,1403.71 1876.29,1403.71 1876.29,1403.71 1876.3,1403.71 1876.3,1403.71 1876.3,1403.71 1876.31,1403.71 1876.31,1403.71 1876.31,1403.71 1876.31,1403.71 1876.32,1403.71 1876.32,1403.71 1876.32,1403.71 1876.32,1403.71 1876.33,1403.71 1876.33,1403.71 1876.33,1403.71 1876.33,1403.71 1876.34,1403.71 1876.34,1403.71 1876.34,1403.71 1876.34,1403.71 1876.35,1403.71 1876.35,1403.71 1876.35,1403.71 1876.35,1403.7 1876.36,1403.7 1876.36,1403.7 1876.36,1403.7 1876.36,1403.7 1876.37,1403.7 1876.37,1403.7 1876.37,1403.7 1876.38,1403.7 1876.38,1403.7 1876.38,1403.7 1876.38,1403.7 1876.39,1403.7 1876.39,1403.7 1876.39,1403.7 1876.39,1403.7 1876.4,1403.7 1876.4,1403.7 1876.4,1403.7 1876.4,1403.7 1876.41,1403.7 1876.41,1403.7 1876.41,1403.7 1876.41,1403.7 1876.42,1403.7 1876.42,1403.7 1876.42,1403.7 1876.42,1403.7 1876.43,1403.7 1876.43,1403.7 1876.43,1403.7 1876.43,1403.7 1876.44,1403.7 1876.44,1403.7 1876.44,1403.7 1876.44,1403.7 1876.45,1403.7 1876.45,1403.7 1876.45,1403.7 1876.46,1403.7 1876.46,1403.7 1876.46,1403.7 1876.46,1403.7 1876.47,1403.7 1876.47,1403.7 1876.47,1403.7 1876.47,1403.7 1876.48,1403.7 1876.48,1403.7 1876.48,1403.7 1876.48,1403.7 1876.49,1403.7 1876.49,1403.7 1876.49,1403.7 1876.49,1403.7 1876.5,1403.7 1876.5,1403.7 1876.5,1403.7 1876.5,1403.7 1876.51,1403.7 1876.51,1403.7 1876.51,1403.7 1876.51,1403.7 1876.52,1403.7 1876.52,1403.7 1876.52,1403.7 1876.52,1403.7 1876.53,1403.7 1876.53,1403.7 1876.53,1403.7 1876.54,1403.7 1876.54,1403.7 1876.54,1403.7 1876.54,1403.7 1876.55,1403.7 1876.55,1403.7 1876.55,1403.7 1876.55,1403.7 1876.56,1403.7 1876.56,1403.7 1876.56,1403.7 1876.56,1403.7 1876.57,1403.7 1876.57,1403.7 1876.57,1403.7 1876.57,1403.7 1876.58,1403.7 1876.58,1403.7 1876.58,1403.7 1876.58,1403.7 1876.59,1403.7 1876.59,1403.7 1876.59,1403.7 1876.59,1403.7 1876.6,1403.7 1876.6,1403.7 1876.6,1403.7 1876.61,1403.7 1876.61,1403.7 1876.61,1403.7 1876.61,1403.7 1876.62,1403.7 1876.62,1403.7 1876.62,1403.7 1876.62,1403.7 1876.63,1403.7 1876.63,1403.7 1876.63,1403.7 1876.63,1403.7 1876.64,1403.7 1876.64,1403.7 1876.64,1403.7 1876.64,1403.7 1876.65,1403.7 1876.65,1403.7 1876.65,1403.7 1876.65,1403.7 1876.66,1403.7 1876.66,1403.7 1876.66,1403.7 1876.66,1403.7 1876.67,1403.7 1876.67,1403.7 1876.67,1403.7 1876.67,1403.7 1876.68,1403.7 1876.68,1403.7 1876.68,1403.7 1876.69,1403.7 1876.69,1403.7 1876.69,1403.7 1876.69,1403.7 1876.7,1403.7 1876.7,1403.7 1876.7,1403.7 1876.7,1403.7 1876.71,1403.7 1876.71,1403.7 1876.71,1403.7 1876.71,1403.7 1876.72,1403.7 1876.72,1403.7 1876.72,1403.7 1876.72,1403.7 1876.73,1403.7 1876.73,1403.7 1876.73,1403.7 1876.73,1403.7 1876.74,1403.7 1876.74,1403.7 1876.74,1403.69 1876.74,1403.69 1876.75,1403.69 1876.75,1403.69 1876.75,1403.69 1876.75,1403.69 1876.76,1403.69 1876.76,1403.69 1876.76,1403.69 1876.77,1403.69 1876.77,1403.69 1876.77,1403.69 1876.77,1403.69 1876.78,1403.69 1876.78,1403.69 1876.78,1403.69 1876.78,1403.69 1876.79,1403.69 1876.79,1403.69 1876.79,1403.69 1876.79,1403.69 1876.8,1403.69 1876.8,1403.69 1876.8,1403.69 1876.8,1403.69 1876.81,1403.69 1876.81,1403.69 1876.81,1403.69 1876.81,1403.69 1876.82,1403.69 1876.82,1403.69 1876.82,1403.69 1876.82,1403.69 1876.83,1403.69 1876.83,1403.69 1876.83,1403.69 1876.83,1403.69 1876.84,1403.69 1876.84,1403.69 1876.84,1403.69 1876.85,1403.69 1876.85,1403.69 1876.85,1403.69 1876.85,1403.69 1876.86,1403.69 1876.86,1403.69 1876.86,1403.69 1876.86,1403.69 1876.87,1403.69 1876.87,1403.69 1876.87,1403.69 1876.87,1403.69 1876.88,1403.69 1876.88,1403.69 1876.88,1403.69 1876.88,1403.69 1876.89,1403.69 1876.89,1403.69 1876.89,1403.69 1876.89,1403.69 1876.9,1403.69 1876.9,1403.69 1876.9,1403.69 1876.9,1403.69 1876.91,1403.69 1876.91,1403.69 1876.91,1403.69 1876.91,1403.69 1876.92,1403.69 1876.92,1403.69 1876.92,1403.69 1876.93,1403.69 1876.93,1403.69 1876.93,1403.69 1876.93,1403.69 1876.94,1403.69 1876.94,1403.69 1876.94,1403.69 1876.94,1403.69 1876.95,1403.69 1876.95,1403.69 1876.95,1403.69 1876.95,1403.69 1876.96,1403.69 1876.96,1403.69 1876.96,1403.69 1876.96,1403.69 1876.97,1403.69 1876.97,1403.69 1876.97,1403.69 1876.97,1403.69 1876.98,1403.69 1876.98,1403.69 1876.98,1403.69 1876.98,1403.69 1876.99,1403.69 1876.99,1403.69 1876.99,1403.69 1876.99,1403.69 1877,1403.69 1877,1403.69 1877,1403.69 1877,1403.69 1877.01,1403.69 1877.01,1403.69 1877.01,1403.69 1877.02,1403.69 1877.02,1403.69 1877.02,1403.69 1877.02,1403.69 1877.03,1403.69 1877.03,1403.69 1877.03,1403.69 1877.03,1403.69 1877.04,1403.69 1877.04,1403.69 1877.04,1403.69 1877.04,1403.69 1877.05,1403.69 1877.05,1403.69 1877.05,1403.69 1877.05,1403.69 1877.06,1403.69 1877.06,1403.69 1877.06,1403.69 1877.06,1403.69 1877.07,1403.69 1877.07,1403.69 1877.07,1403.69 1877.07,1403.69 1877.08,1403.69 1877.08,1403.69 1877.08,1403.69 1877.08,1403.69 1877.09,1403.69 1877.09,1403.69 1877.09,1403.69 1877.1,1403.69 1877.1,1403.69 1877.1,1403.69 1877.1,1403.69 1877.11,1403.69 1877.11,1403.69 1877.11,1403.69 1877.11,1403.69 1877.12,1403.69 1877.12,1403.69 1877.12,1403.69 1877.12,1403.69 1877.13,1403.69 1877.13,1403.68 1877.13,1403.68 1877.13,1403.68 1877.14,1403.68 1877.14,1403.68 1877.14,1403.68 1877.14,1403.68 1877.15,1403.68 1877.15,1403.68 1877.15,1403.68 1877.15,1403.68 1877.16,1403.68 1877.16,1403.68 1877.16,1403.68 1877.16,1403.68 1877.17,1403.68 1877.17,1403.68 1877.17,1403.68 1877.17,1403.68 1877.18,1403.68 1877.18,1403.68 1877.18,1403.68 1877.19,1403.68 1877.19,1403.68 1877.19,1403.68 1877.19,1403.68 1877.2,1403.68 1877.2,1403.68 1877.2,1403.68 1877.2,1403.68 1877.21,1403.68 1877.21,1403.68 1877.21,1403.68 1877.21,1403.68 1877.22,1403.68 1877.22,1403.68 1877.22,1403.68 1877.22,1403.68 1877.23,1403.68 1877.23,1403.68 1877.23,1403.68 1877.23,1403.68 1877.24,1403.68 1877.24,1403.68 1877.24,1403.68 1877.24,1403.68 1877.25,1403.68 1877.25,1403.68 1877.25,1403.68 1877.25,1403.68 1877.26,1403.68 1877.26,1403.68 1877.26,1403.68 1877.27,1403.68 1877.27,1403.68 1877.27,1403.68 1877.27,1403.68 1877.28,1403.68 1877.28,1403.68 1877.28,1403.68 1877.28,1403.68 1877.29,1403.68 1877.29,1403.68 1877.29,1403.68 1877.29,1403.68 1877.3,1403.68 1877.3,1403.68 1877.3,1403.68 1877.3,1403.68 1877.31,1403.68 1877.31,1403.68 1877.31,1403.68 1877.31,1403.68 1877.32,1403.68 1877.32,1403.68 1877.32,1403.68 1877.32,1403.68 1877.33,1403.68 1877.33,1403.68 1877.33,1403.68 1877.33,1403.68 1877.34,1403.68 1877.34,1403.68 1877.34,1403.68 1877.34,1403.68 1877.35,1403.68 1877.35,1403.68 1877.35,1403.68 1877.36,1403.68 1877.36,1403.68 1877.36,1403.68 1877.36,1403.68 1877.37,1403.68 1877.37,1403.68 1877.37,1403.68 1877.37,1403.68 1877.38,1403.68 1877.38,1403.68 1877.38,1403.68 1877.38,1403.68 1877.39,1403.68 1877.39,1403.68 1877.39,1403.68 1877.39,1403.68 1877.4,1403.68 1877.4,1403.68 1877.4,1403.68 1877.4,1403.68 1877.41,1403.68 1877.41,1403.68 1877.41,1403.68 1877.41,1403.68 1877.42,1403.68 1877.42,1403.68 1877.42,1403.68 1877.42,1403.68 1877.43,1403.68 1877.43,1403.68 1877.43,1403.68 1877.43,1403.68 1877.44,1403.68 1877.44,1403.68 1877.44,1403.68 1877.45,1403.68 1877.45,1403.68 1877.45,1403.68 1877.45,1403.68 1877.46,1403.68 1877.46,1403.68 1877.46,1403.68 1877.46,1403.68 1877.47,1403.68 1877.47,1403.68 1877.47,1403.68 1877.47,1403.68 1877.48,1403.68 1877.48,1403.68 1877.48,1403.68 1877.48,1403.68 1877.49,1403.68 1877.49,1403.68 1877.49,1403.68 1877.49,1403.68 1877.5,1403.68 "/>
<path clip-path="url(#clip400)" d="M1871.39 970.122 L2322.13 970.122 L2322.13 866.442 L1871.39 866.442  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<polyline clip-path="url(#clip400)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1871.39,970.122 2322.13,970.122 2322.13,866.442 1871.39,866.442 1871.39,970.122 "/>
<polyline clip-path="url(#clip400)" style="stroke:#009af9; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1881.6,918.282 1942.86,918.282 "/>
<path clip-path="url(#clip400)" d="M1963.7 899.59 Q1960.6 904.914 1959.09 910.122 Q1957.59 915.331 1957.59 920.678 Q1957.59 926.025 1959.09 931.28 Q1960.62 936.511 1963.7 941.812 L1960 941.812 Q1956.52 936.372 1954.79 931.118 Q1953.07 925.863 1953.07 920.678 Q1953.07 915.516 1954.79 910.284 Q1956.5 905.053 1960 899.59 L1963.7 899.59 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M1972.15 901.002 L1976.82 901.002 L1976.82 931.627 L1993.65 931.627 L1993.65 935.562 L1972.15 935.562 L1972.15 901.002 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2002.26 935.562 L1989.07 901.002 L1993.95 901.002 L2004.9 930.099 L2015.87 901.002 L2020.74 901.002 L2007.56 935.562 L2002.26 935.562 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2034.86 918.919 L2034.86 926.141 L2042.98 926.141 L2042.98 928.34 L2034.86 928.34 L2034.86 935.562 L2032.43 935.562 L2032.43 928.34 L2024.3 928.34 L2024.3 926.141 L2032.43 926.141 L2032.43 918.919 L2034.86 918.919 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2059.72 935.562 L2046.52 901.002 L2051.41 901.002 L2062.36 930.099 L2073.33 901.002 L2078.19 901.002 L2065.02 935.562 L2059.72 935.562 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2093.28 899.59 Q2090.18 904.914 2088.68 910.122 Q2087.17 915.331 2087.17 920.678 Q2087.17 926.025 2088.68 931.28 Q2090.2 936.511 2093.28 941.812 L2089.58 941.812 Q2086.11 936.372 2084.37 931.118 Q2082.66 925.863 2082.66 920.678 Q2082.66 915.516 2084.37 910.284 Q2086.08 905.053 2089.58 899.59 L2093.28 899.59 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2105.76 902.275 L2105.76 909.636 L2114.53 909.636 L2114.53 912.946 L2105.76 912.946 L2105.76 927.02 Q2105.76 930.192 2106.62 931.094 Q2107.49 931.997 2110.16 931.997 L2114.53 931.997 L2114.53 935.562 L2110.16 935.562 Q2105.23 935.562 2103.35 933.733 Q2101.48 931.881 2101.48 927.02 L2101.48 912.946 L2098.35 912.946 L2098.35 909.636 L2101.48 909.636 L2101.48 902.275 L2105.76 902.275 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2119.46 899.59 L2123.17 899.59 Q2126.64 905.053 2128.35 910.284 Q2130.09 915.516 2130.09 920.678 Q2130.09 925.863 2128.35 931.118 Q2126.64 936.372 2123.17 941.812 L2119.46 941.812 Q2122.54 936.511 2124.05 931.28 Q2125.57 926.025 2125.57 920.678 Q2125.57 915.331 2124.05 910.122 Q2122.54 904.914 2119.46 899.59 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2139.72 929.682 L2144.6 929.682 L2144.6 933.664 L2140.8 941.071 L2137.82 941.071 L2139.72 933.664 L2139.72 929.682 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2153.88 901.002 L2158.56 901.002 L2158.56 931.627 L2175.39 931.627 L2175.39 935.562 L2153.88 935.562 L2153.88 901.002 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2184 935.562 L2170.8 901.002 L2175.69 901.002 L2186.64 930.099 L2197.61 901.002 L2202.47 901.002 L2189.3 935.562 L2184 935.562 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2201.82 929.682 L2206.71 929.682 L2206.71 935.562 L2201.82 935.562 L2201.82 929.682 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2220.41 931.673 L2220.41 945.423 L2216.13 945.423 L2216.13 909.636 L2220.41 909.636 L2220.41 913.571 Q2221.75 911.257 2223.79 910.145 Q2225.85 909.011 2228.7 909.011 Q2233.42 909.011 2236.36 912.761 Q2239.32 916.511 2239.32 922.622 Q2239.32 928.733 2236.36 932.483 Q2233.42 936.233 2228.7 936.233 Q2225.85 936.233 2223.79 935.122 Q2221.75 933.988 2220.41 931.673 M2234.9 922.622 Q2234.9 917.923 2232.96 915.261 Q2231.04 912.576 2227.66 912.576 Q2224.28 912.576 2222.33 915.261 Q2220.41 917.923 2220.41 922.622 Q2220.41 927.321 2222.33 930.006 Q2224.28 932.668 2227.66 932.668 Q2231.04 932.668 2232.96 930.006 Q2234.9 927.321 2234.9 922.622 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2256.61 899.59 Q2253.51 904.914 2252.01 910.122 Q2250.5 915.331 2250.5 920.678 Q2250.5 926.025 2252.01 931.28 Q2253.54 936.511 2256.61 941.812 L2252.91 941.812 Q2249.44 936.372 2247.7 931.118 Q2245.99 925.863 2245.99 920.678 Q2245.99 915.516 2247.7 910.284 Q2249.42 905.053 2252.91 899.59 L2256.61 899.59 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2269.09 902.275 L2269.09 909.636 L2277.86 909.636 L2277.86 912.946 L2269.09 912.946 L2269.09 927.02 Q2269.09 930.192 2269.95 931.094 Q2270.83 931.997 2273.49 931.997 L2277.86 931.997 L2277.86 935.562 L2273.49 935.562 Q2268.56 935.562 2266.68 933.733 Q2264.81 931.881 2264.81 927.02 L2264.81 912.946 L2261.68 912.946 L2261.68 909.636 L2264.81 909.636 L2264.81 902.275 L2269.09 902.275 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2282.79 899.59 L2286.5 899.59 Q2289.97 905.053 2291.68 910.284 Q2293.42 915.516 2293.42 920.678 Q2293.42 925.863 2291.68 931.118 Q2289.97 936.372 2286.5 941.812 L2282.79 941.812 Q2285.87 936.511 2287.38 931.28 Q2288.91 926.025 2288.91 920.678 Q2288.91 915.331 2287.38 910.122 Q2285.87 904.914 2282.79 899.59 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip400)" d="M2301.29 899.59 L2304.99 899.59 Q2308.47 905.053 2310.18 910.284 Q2311.92 915.516 2311.92 920.678 Q2311.92 925.863 2310.18 931.118 Q2308.47 936.372 2304.99 941.812 L2301.29 941.812 Q2304.37 936.511 2305.87 931.28 Q2307.4 926.025 2307.4 920.678 Q2307.4 915.331 2305.87 910.122 Q2304.37 904.914 2301.29 899.59 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /></svg>

```

---

*This page was generated using [Literate.jl](https://github.com/fredrikekre/Literate.jl).*

